[
  [
    "https://www.bathstudent.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.bathstudent.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Membership Solutions Limited: BathStudent.com"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bathstudent.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.bathstudent.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.bathstudent.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.bathstudent.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.bathstudent.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.bathstudent.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.bathstudent.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.bathstudent.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.bathstudent.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.bathstudent.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.bathstudent.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.bathstudent.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.bathstudent.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.bathstudent.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.bathstudent.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.bathstudent.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://wifi.espci.fr/saml/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Emmanuel Dreyfus"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Emmanuel.Dreyfus@espci.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jean-Jacques Puig"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Jean-Jacques.Puig@espci.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://wifi.espci.fr/saml/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2011-04-05T10:14:28Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/wifi"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/national"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ecole Sup\u00e9rieure de Physique et de Chimie Industrielles de la Ville de Paris"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.espci.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ecole Sup\u00e9rieure de Physique et de Chimie Industrielles de la Ville de Paris"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://wifi.espci.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Acc\u00e8s au portail captif WiFi \u00e0 l'ESPCI ParisTech, ouvert \u00e0 tous les usagers de la f\u00e9d\u00e9ration."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ESPCI ParisTech - Acc\u00e8s WiFi"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ESPCI ParisTech - Acc\u00e8s WiFi"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFaDCCBFCgAwIBAgIRAIaYj8BPcZAQKLmv64xhNrYwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDA0MDgwMDAwMDBaFw0xNzA0MDcyMzU5NTlaMDsxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEWMBQGA1UEAxMNd2lmaS5lc3Bj\naS5mcjCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIBANg1N9YQejPppU6s\nvgTVJm78QhVwG1qelsOkcrpG4bzhcJN95zBV/ERuyuJ3YjwqZSYsvgcZcdOJymwf\nzVKLKh7AvDuPL+x6Iz3VSqdl3/n0SfnQP3wCM6upabxikEhLg2mROQEDN2ZnKnNq\nNMWzy0oIuf9TBhbJDddJewQtvHS/OJxqOO3f9S76xqLq9dZhKbMNE8GqWXakAr8f\noItuYZvc5UapiqngRjB78aOsHjETH3vkE200Gk97wrjIeN0LrBhKcofG88NDeJhN\nzczseS5FwoawYsgA5AAGTFDkg2dydnvZF6hhd/EJ1uEgguCWVCSZQmPSXkzlaoSg\nGAHKx+qdCFkQDipZqVRRpdWCLfRK+qvchu1E+dhzqkvTe4kX/xcvCwKWUJ0I+vlM\ndwzd8o637i6yn736TMnZG6hSMTFDhv9WN5VjD19RkIA5mETXp3KzpMNG+tmn8TPN\nuIPFpcreqQyD+qbRAH5XX5GNATY5P5HWKd+V3QJtqW0QCjen/Viq7o0avEVgmLCi\ndFuabXZo9ta/GgOIsi0n8D3uQiJ0V1snLPFjBemfXevwoI5PyHA+Yya1lLdFQ2QT\nwHyh7B0I/IoTyMoWQI9pixbiyWel6JkLRPzNJqhlB8bKqnH4HR7kgq9itZkFEz2G\nebZXFLgYWCMvkvj8vXCCYy69I4orAgMBAAGjggFqMIIBZjAfBgNVHSMEGDAWgBQM\nvZNoDPPeq6NJays3V0fqkOO57TAdBgNVHQ4EFgQUFJC/ROWw0QdJWifZ4Eo9CDHp\nMiswDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYB\nBQUHAwEGCCsGAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EM\nAQIBMDoGA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcv\nVEVSRU5BU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0\ncDovL2NydC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUH\nMAGGGmh0dHA6Ly9vY3NwLnRjcy50ZXJlbmEub3JnMBgGA1UdEQQRMA+CDXdpZmku\nZXNwY2kuZnIwDQYJKoZIhvcNAQEFBQADggEBACcP3xTaWd7EVf5hDvqI7vqrbbor\nzjvEAwdsMXGxtDqJm0Y9G3qk0Cin3vf0beZDWK2DtcYfTf1QIjJT23d+434W457S\nFj2gVppPEgZ4eFoPIH7KChRul4LXBkyvY4vLw67fQGk8/sr44j9KBUA7vUTsaqIy\n/NW6SgLNx+/NtLF5w5odwoZc6YLfj/YEIc/pLv5wwK556+2jf0p2YnmO99Up+G2U\ngE9rxe6IbLS5rd9eqf0PzBg/1OS1EYOWmdbnkODnpBi2mcBWfHKVBL2IKbyfFHul\naczMFss205TH+mugaX6YVXl77eIw9xzO7G4SZn+P9tPo0xalGN15rIoQJ1Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFaDCCBFCgAwIBAgIRAIaYj8BPcZAQKLmv64xhNrYwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDA0MDgwMDAwMDBaFw0xNzA0MDcyMzU5NTlaMDsxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEWMBQGA1UEAxMNd2lmaS5lc3Bj\naS5mcjCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIBANg1N9YQejPppU6s\nvgTVJm78QhVwG1qelsOkcrpG4bzhcJN95zBV/ERuyuJ3YjwqZSYsvgcZcdOJymwf\nzVKLKh7AvDuPL+x6Iz3VSqdl3/n0SfnQP3wCM6upabxikEhLg2mROQEDN2ZnKnNq\nNMWzy0oIuf9TBhbJDddJewQtvHS/OJxqOO3f9S76xqLq9dZhKbMNE8GqWXakAr8f\noItuYZvc5UapiqngRjB78aOsHjETH3vkE200Gk97wrjIeN0LrBhKcofG88NDeJhN\nzczseS5FwoawYsgA5AAGTFDkg2dydnvZF6hhd/EJ1uEgguCWVCSZQmPSXkzlaoSg\nGAHKx+qdCFkQDipZqVRRpdWCLfRK+qvchu1E+dhzqkvTe4kX/xcvCwKWUJ0I+vlM\ndwzd8o637i6yn736TMnZG6hSMTFDhv9WN5VjD19RkIA5mETXp3KzpMNG+tmn8TPN\nuIPFpcreqQyD+qbRAH5XX5GNATY5P5HWKd+V3QJtqW0QCjen/Viq7o0avEVgmLCi\ndFuabXZo9ta/GgOIsi0n8D3uQiJ0V1snLPFjBemfXevwoI5PyHA+Yya1lLdFQ2QT\nwHyh7B0I/IoTyMoWQI9pixbiyWel6JkLRPzNJqhlB8bKqnH4HR7kgq9itZkFEz2G\nebZXFLgYWCMvkvj8vXCCYy69I4orAgMBAAGjggFqMIIBZjAfBgNVHSMEGDAWgBQM\nvZNoDPPeq6NJays3V0fqkOO57TAdBgNVHQ4EFgQUFJC/ROWw0QdJWifZ4Eo9CDHp\nMiswDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYB\nBQUHAwEGCCsGAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EM\nAQIBMDoGA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcv\nVEVSRU5BU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0\ncDovL2NydC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUH\nMAGGGmh0dHA6Ly9vY3NwLnRjcy50ZXJlbmEub3JnMBgGA1UdEQQRMA+CDXdpZmku\nZXNwY2kuZnIwDQYJKoZIhvcNAQEFBQADggEBACcP3xTaWd7EVf5hDvqI7vqrbbor\nzjvEAwdsMXGxtDqJm0Y9G3qk0Cin3vf0beZDWK2DtcYfTf1QIjJT23d+434W457S\nFj2gVppPEgZ4eFoPIH7KChRul4LXBkyvY4vLw67fQGk8/sr44j9KBUA7vUTsaqIy\n/NW6SgLNx+/NtLF5w5odwoZc6YLfj/YEIc/pLv5wwK556+2jf0p2YnmO99Up+G2U\ngE9rxe6IbLS5rd9eqf0PzBg/1OS1EYOWmdbnkODnpBi2mcBWfHKVBL2IKbyfFHul\naczMFss205TH+mugaX6YVXl77eIw9xzO7G4SZn+P9tPo0xalGN15rIoQJ1Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFpjCCBI6gAwIBAgIRAOE+20QrI5x/Eygq7lsxhZAwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xMjAzMTkwMDAwMDBaFw0xNTAzMTkyMzU5NTlaMIGCMQswCQYD\nVQQGEwJGUjE8MDoGA1UEChMzRWNvbGUgU3VwZXJpZXVyZSBkZSBQaHlzaXF1ZSBl\ndCBDaGltaWUgSW5kdXN0cmllbGxlMR0wGwYDVQQLExRTZXJ2aWNlIEluZm9ybWF0\naXF1ZTEWMBQGA1UEAxMNd2lmaS5lc3BjaS5mcjCCAiIwDQYJKoZIhvcNAQEBBQAD\nggIPADCCAgoCggIBALok3W16b6iUybJIMb7NeUtTv0h5ygPqEZRH1vVm/tsDE027\n16hrdkpSsSwP7fi2xm8x5vH7BSOjV0EtzTWsYG6R6pWkLQ+ktMGvQe3VbdmNrCAa\n/dBK2vKtwDAHES91rcQkM6mO8JTtXWrO2V+N15ttlt70gS3OgJI9Uhi8jl3JgHBq\nlEGhJz58NI1cVwDeUD0agxoz+KkPve5FB+PHASypzPZZ7GyVx5y9CE+p2+bvD+KL\nEKZR5WjXJi+nhycFsRizWAnCCAf2t0I8oky8PzQSf/eaayv+EuUnkvJNR8UXIhWE\nn6mfee+omYOoSnEgivHHJbVuJIgo1QK/+r2dYrGNPmhA7ApQqQvtjwciwwczjpe+\nvCLsrfl+jT8WFgS118huBWUS6itNG+h5pdifLdB56Y4xg+lxdsRV8XRKTZu5ttzt\nnrfkZivVtJ+1/GOcpFsvD/IHM8Z0pARxhZDbI6flbEFw7Vx2HfLiPfmWwWMK6tSL\n7IU0slg+K2ANtxhhBiFrCn0FAieCVyGHdfR7fDvzJcAYYSUyiumF00tWNDfa8Ac7\nEpbcb2/sNwfoXrLJPAL+Bhgry4kn4k6isN8RtyU6t+MaZ179VWZkOJi4e5Sy4PBx\nERkMP7oD89UZa1sDyzBJ01CNidl83zEp+yVQrhLZb3gpVCJ74ogyazqa59SrAgMB\nAAGjggFgMIIBXDAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3V0fqkOO57TAdBgNV\nHQ4EFgQUMNLf8y6GUobcx6Q1ie9thLI8LUkwDgYDVR0PAQH/BAQDAgWgMAwGA1Ud\nEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMBgGA1UdIAQR\nMA8wDQYLKwYBBAGyMQECAh0wOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50\nY3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUG\nCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENB\nLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwGAYD\nVR0RBBEwD4INd2lmaS5lc3BjaS5mcjANBgkqhkiG9w0BAQUFAAOCAQEAY3w5yCh9\n6lr26I9dpFUQsVkiAJdMaKzXcGnLoI3wUA7CcYG76ae0m7QxNbbIjxXdhYbDgyn8\nPVGsMLejGWbjgePf5UhvVyaPWQVB/burU95HfD6pDS2D+/NJYQowVjgf8Meh4Nb6\n1tURmrwzVkwLkIHvTSQ011dZJEQe6aockASx6GMtd7hlm87Rndk0Jm9a6pQtzHjY\npAVuaQQi/FxV7jkz+Rm4HD8R3bhRdVSCpe+2ukW91t385ZQCJuFawcdTDEeHGaDI\n1bjPX+IrBAd71rGTiMlhH5VUaYUNPJkTxVWJwhCimQztzNGk0CY+ze424o3soWOZ\n2JBnPLINws7O5w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wifi.espci.fr/saml/postResponse",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ESPCI ParisTech - Acc\u00e8s WiFi"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Acc\u00e8s au portail captif WiFi \u00e0 l'ESPCI ParisTech, ouvert \u00e0 tous les usagers de la f\u00e9d\u00e9ration."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.unisi.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@unisi.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.unisi.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2016-03-17T08:30:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDbDCCAlQCCQDCQNjXPb+J3zANBgkqhkiG9w0BAQUFADB4MQswCQYDVQQGEwJJ\nVDEOMAwGA1UECAwFU2llbmExDjAMBgNVBAcMBVNpZW5hMRwwGgYDVQQKDBNVbml2\nZXJzaXRhIGRpIFNpZW5hMQ0wCwYDVQQLDARTUlNTMRwwGgYDVQQDDBNzaGliYm9s\nZXRoLnVuaXNpLml0MB4XDTE1MDgxNDExMjIyMFoXDTI1MDYyMjExMjIyMFoweDEL\nMAkGA1UEBhMCSVQxDjAMBgNVBAgMBVNpZW5hMQ4wDAYDVQQHDAVTaWVuYTEcMBoG\nA1UECgwTVW5pdmVyc2l0YSBkaSBTaWVuYTENMAsGA1UECwwEU1JTUzEcMBoGA1UE\nAwwTc2hpYmJvbGV0aC51bmlzaS5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBAM0DwZPtLOcfVuSGNh9CXbV00bzCF/jQ8lIX9cmsfzg8Z4mqvRCW9TKo\nJNwn1+o+xqbwnnNY+IfbrHcHx0uoOaweQBzJi8CtMFLIvg//r59cCHP3+T/RbT0Q\ndUrDv/eWggyVIW52hqaofkjFXiL7mnp5Mh4hXsTn43TfJx9fQnPBrGVsMIxAT0AW\nbNTFgtukD1d3tCx4sImQU0MGyQb2k3W/eu4GddNZs/Krox7zabiJC+ENcU5uduaV\nlIwi5vJ/f+7qP3Z6dH/SVWZfFeP1+AFn51iAGuj/6/U8XFF8VBt+mfM2ADdmUguN\nbMWz2zeZeXKEMqNaWurjp8fjF4D/NccCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\nTQj+v5d1bx1ctes1sCTIUa6ctqBj5qOh4zFEXNxkMNoCLoCMaVlx4pgu8b8B0bow\nalaHWn2QicrHhu7wVxIGG7FEu0QnTNY6trnft5Ps6skXJuVJjqdJEf1fz1cMTv+b\nhoRp5PTM0xq15JlZTkpJxUtEVhWiPBUUxGwBGHRSgZ87tnQfw5+TX54iRahJOfer\nFcOVtK1g+0cycim0THv3bf8BQXzhhFBNEXDAqkch+Kxp56dV51j+KUZtDKCQpCkL\nBQq/XNsdesbvmPiOtFXYzb7QwydoOR+pPqfHP+MyAbv0aZnyGOv8jtCwpb7KNeX2\nzI5NIIy574GrFouiXR+GCQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unisi.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.unisi.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.unisi.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.unisi.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.unisi.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.unisi.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.unisi.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.unisi.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.unisi.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unisi.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://shibboleth.unisi.it/idem-info-eng.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://shibboleth.unisi.it/idem-info.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 degli Studi di Siena"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Siena"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for users of University of Siena"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti dell'Universit\u00e0 degli Studi di Siena"
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth.unisi.it/idp/images/logo_unisi_60px.png",
                    "height": "59",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://shibboleth.unisi.it/idem-privacy-eng.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://shibboleth.unisi.it/idem-privacy.html"
                  }
                ]
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "unisi.it"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDbDCCAlQCCQDCQNjXPb+J3zANBgkqhkiG9w0BAQUFADB4MQswCQYDVQQGEwJJ\nVDEOMAwGA1UECAwFU2llbmExDjAMBgNVBAcMBVNpZW5hMRwwGgYDVQQKDBNVbml2\nZXJzaXRhIGRpIFNpZW5hMQ0wCwYDVQQLDARTUlNTMRwwGgYDVQQDDBNzaGliYm9s\nZXRoLnVuaXNpLml0MB4XDTE1MDgxNDExMjIyMFoXDTI1MDYyMjExMjIyMFoweDEL\nMAkGA1UEBhMCSVQxDjAMBgNVBAgMBVNpZW5hMQ4wDAYDVQQHDAVTaWVuYTEcMBoG\nA1UECgwTVW5pdmVyc2l0YSBkaSBTaWVuYTENMAsGA1UECwwEU1JTUzEcMBoGA1UE\nAwwTc2hpYmJvbGV0aC51bmlzaS5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBAM0DwZPtLOcfVuSGNh9CXbV00bzCF/jQ8lIX9cmsfzg8Z4mqvRCW9TKo\nJNwn1+o+xqbwnnNY+IfbrHcHx0uoOaweQBzJi8CtMFLIvg//r59cCHP3+T/RbT0Q\ndUrDv/eWggyVIW52hqaofkjFXiL7mnp5Mh4hXsTn43TfJx9fQnPBrGVsMIxAT0AW\nbNTFgtukD1d3tCx4sImQU0MGyQb2k3W/eu4GddNZs/Krox7zabiJC+ENcU5uduaV\nlIwi5vJ/f+7qP3Z6dH/SVWZfFeP1+AFn51iAGuj/6/U8XFF8VBt+mfM2ADdmUguN\nbMWz2zeZeXKEMqNaWurjp8fjF4D/NccCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\nTQj+v5d1bx1ctes1sCTIUa6ctqBj5qOh4zFEXNxkMNoCLoCMaVlx4pgu8b8B0bow\nalaHWn2QicrHhu7wVxIGG7FEu0QnTNY6trnft5Ps6skXJuVJjqdJEf1fz1cMTv+b\nhoRp5PTM0xq15JlZTkpJxUtEVhWiPBUUxGwBGHRSgZ87tnQfw5+TX54iRahJOfer\nFcOVtK1g+0cycim0THv3bf8BQXzhhFBNEXDAqkch+Kxp56dV51j+KUZtDKCQpCkL\nBQq/XNsdesbvmPiOtFXYzb7QwydoOR+pPqfHP+MyAbv0aZnyGOv8jtCwpb7KNeX2\nzI5NIIy574GrFouiXR+GCQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 degli Studi di Siena"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Siena"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unisi.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://en.unisi.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli Studi di Siena"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Siena"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp-v2.suni.se/adfs/services/trust",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46(0)8-6084000"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Legat"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "server@sh.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tomas"
          }
        }
      ],
      "entity_id": "https://idp-v2.suni.se/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "regexp": "false",
            "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
            "text": "suni.se"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-v2.suni.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-v2.suni.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-v2.suni.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-v2.suni.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-v2.suni.se/adfs/services/trust/artifactresolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "suni.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.sh.se/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.sh.se/p3/ext/content.nsf/aget?openagent&key=startsideportal_engelsk_1308725461229"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ny Identitetshanterare f\u00f6r S\u00f6dert\u00f6rns h\u00f6gskola"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "New Identity Provider for S\u00f6dert\u00f6rn University"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.sh.se/p3/ext/res.nsf/vRes/global_1448973984543_sh_ny_logo_eng_png/$File/sh-ny-logo-eng.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "S\u00f6dert\u00f6rns h\u00f6gskola"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "S\u00f6dert\u00f6rn University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute": [
            {
              "friendly_name": "E-Mail Address",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/emailaddress",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Given Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/givenname",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/name",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "UPN",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/upn",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Common Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/CommonName",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "AD FS 1.x E-Mail Address",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/EmailAddress",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Group",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/Group",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "AD FS 1.x UPN",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/UPN",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Role",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/role",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Surname",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/surname",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "PPID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/privatepersonalidentifier",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Name ID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/nameidentifier",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Authentication time stamp",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/authenticationinstant",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Authentication method",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/authenticationmethod",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Deny only group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/denyonlysid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Deny only primary SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/denyonlyprimarysid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Deny only primary group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/denyonlyprimarygroupsid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/groupsid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Primary group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/primarygroupsid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Primary SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/primarysid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Windows account name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/windowsaccountname",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Is Registered User",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/devicecontext/claims/isregistereduser",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Device Identifier",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/devicecontext/claims/identifier",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Device Registration Identifier",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/devicecontext/claims/registrationid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Device Registration DisplayName",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/devicecontext/claims/displayname",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Device OS type",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/devicecontext/claims/ostype",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Device OS Version",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/devicecontext/claims/osversion",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Is Managed Device",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/devicecontext/claims/ismanaged",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Forwarded Client IP",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/requestcontext/claims/x-ms-forwarded-client-ip",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Client Application",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/requestcontext/claims/x-ms-client-application",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Client User Agent",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/requestcontext/claims/x-ms-client-user-agent",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Client IP",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/requestcontext/claims/x-ms-client-ip",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Endpoint Path",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/requestcontext/claims/x-ms-endpoint-absolute-path",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Proxy",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/requestcontext/claims/x-ms-proxy",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Application Identifier",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/requestcontext/claims/relyingpartytrustid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Application policies",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/applicationpolicy",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Authority Key Identifier",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/authoritykeyidentifier",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Basic Constraint",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/basicconstraints",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Enhanced Key Usage",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/eku",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Issuer",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/field/issuer",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Issuer Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/field/issuername",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Key Usage",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/keyusage",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Not After",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/field/notafter",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Not Before",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/field/notbefore",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Certificate Policies",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/certificatepolicy",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Public Key",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/rsa",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Certificate Raw Data",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/field/rawdata",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Subject Alternative Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/san",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Serial Number",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/serialnumber",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Signature Algorithm",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/field/signaturealgorithm",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Subject",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/field/subject",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Subject Key Identifier",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/subjectkeyidentifier",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Subject Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/field/subjectname",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "V2 Template Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/certificatetemplateinformation",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "V1 Template Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/certificatetemplatename",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Thumbprint",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/thumbprint",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "X.509 Version",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/field/x509version",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Inside Corporate Network",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2012/01/insidecorporatenetwork",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Password Expiration Time",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2012/01/passwordexpirationtime",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Password Expiration Days",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2012/01/passwordexpirationdays",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Update Password URL",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2012/01/passwordchangeurl",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Authentication Methods References",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/claims/authnmethodsreferences",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Client Request ID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/requestcontext/claims/client-request-id",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Alternate Login ID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2013/11/alternateloginid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "norEduPersonNIN",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/norEduPersonNIN",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "eduPersonEntitlement",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/eduPersonEntitlement",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "eduPersonScopedAffiliation",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/eduPersonScopedAffiliation",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            }
          ],
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "S\u00f6dert\u00f6rns h\u00f6gskola"
          }
        ],
        "organization_url": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sh.se/"
          }
        ],
        "organization_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "S\u00f6dert\u00f6rns h\u00f6gskola"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-v2.suni.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-v2.suni.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://idp-v2.suni.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://idp-v2.suni.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-v2.suni.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://conext.authenticatie.ru.nl/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://conext.authenticatie.ru.nl/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-04-29T16:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/0d04b328623873aa5fb671116f91cb73",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "An IdP operated by Radboud University Nijmegen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "An IdP operated by Radboud University Nijmegen"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/radboudlogo120.png",
                    "height": "26",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "120"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Radboud Universiteit"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Radboud University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Radboud Universiteit"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Radboud University"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ru.nl/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ru.nl/english/"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Radboud Universiteit"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Radboud University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.bme.hu/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gyenes Tam\u00e1s"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tom@impulzus.bme.hu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gyenes Tam\u00e1s"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tom@impulzus.bme.hu"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gyenes Tam\u00e1s"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tom@impulzus.bme.hu"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.bme.hu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "urn:schac:homeOrganizationType:hu:other"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "bme"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-edugain"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-idps"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:geant:niif.hu:eduid.hu:entity-attributes:processing-info",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "hu",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://metadata.eduid.hu/registration_policy_1_0.txt"
              }
            ],
            "registration_instant": "2013-08-01T07:17:19.807Z",
            "registration_authority": "http://eduid.hu",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.bme.hu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "login.bme.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor"
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.bme.hu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.bme.hu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.bme.hu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.bme.hu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.bme.hu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.bme.hu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Budapesti M\u0171szaki \u00e9s Gazdas\u00e1gtudom\u00e1nyi Egyetem"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Budapest University of Technology and Economics"
                  }
                ],
                "display_name": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Budapesti M\u0171szaki \u00e9s Gazdas\u00e1gtudom\u00e1nyi Egyetem"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Budapest University of Technology and Economics"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bme.hu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "login.bme.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Budapesti M\u0171szaki \u00e9s Gazdas\u00e1gtudom\u00e1nyi Egyetem"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Budapest University of Technology and Economics"
          }
        ],
        "organization_url": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://bme.hu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://bme.hu"
          }
        ],
        "organization_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Budapesti M\u0171szaki \u00e9s Gazdas\u00e1gtudom\u00e1nyi Egyetem"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Budapest University of Technology and Economics"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://cafe.udesc.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Setor de Infraestrutura - SETIC"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "seinfra.setic@udesc.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.udesc.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEgDCCA2gCAQAwDQYJKoZIhvcNAQEFBQAwggEEMTkwNwYDVQQKEzBVREVTQyAt\nIFVuaXZlcnNpZGFkZSBkbyBFc3RhZG8gZGUgU2FudGEgQ2F0YXJpbmExSTBHBgNV\nBAsUQFNFVElDIC0gU2VjcmV0YXJpYSBkZSBUZWNub2xvZ2lhIGRhIEluZm9ybWHD\np8OjbyBlIENvbXVuaWNhw6fDo28xJTAjBgkqhkiG9w0BCQEWFnNlaW5mcmEuc2V0\naWNAdWRlc2MuYnIxFzAVBgNVBAcUDkZsb3JpYW7Ds3BvbGlzMRcwFQYDVQQIEw5T\nYW50YSBDYXRhcmluYTELMAkGA1UEBhMCQlIxFjAUBgNVBAMTDWNhZmUudWRlc2Mu\nYnIwHhcNMTQwNTE1MjAxMjEyWhcNMTcwNTE0MjAxMjEyWjCCAQQxOTA3BgNVBAoT\nMFVERVNDIC0gVW5pdmVyc2lkYWRlIGRvIEVzdGFkbyBkZSBTYW50YSBDYXRhcmlu\nYTFJMEcGA1UECxRAU0VUSUMgLSBTZWNyZXRhcmlhIGRlIFRlY25vbG9naWEgZGEg\nSW5mb3JtYcOnw6NvIGUgQ29tdW5pY2HDp8OjbzElMCMGCSqGSIb3DQEJARYWc2Vp\nbmZyYS5zZXRpY0B1ZGVzYy5icjEXMBUGA1UEBxQORmxvcmlhbsOzcG9saXMxFzAV\nBgNVBAgTDlNhbnRhIENhdGFyaW5hMQswCQYDVQQGEwJCUjEWMBQGA1UEAxMNY2Fm\nZS51ZGVzYy5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL9PTe5l\nWC7jplN9PsFwipaPk1bB5UPXxEOeJgr/6xf5RMT//l1L6T/X4uOj+lK6KI8a4pRc\noD+a83AlKb8cvYzDIQEBCDOPqjruIy+TyTwQ358x45mPM/aNivkugPKMaK8Aidma\nnUgeiRuZ1rtFyVqenDkH7qs9SwExR4NnJ/1l7DNkP6znKksBq7PGlYkj0mryxNCV\n1CAEZT6zEIyptWwd0TRHaybJc2uDD5Kl8HE54IvCwxfdKgJVQ/9FK2W9vvZowUQl\nbOGdUHqFvtudcU6VWOPxuRv4NgmkFGRaNBisnfZ3XfUah8yMIvlYXgkAevQNBjnz\ng3P3o8BU5YU6ieECAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAUu6oCJTJ51HQeuiD\n06G3V1HddwBdddkaHK+WVNux+s8fVQH1Z6ZvkIH2xgmi9ZI9jK7OoBv1H0TfM27g\n4i8RC4jkVM9SHJFR5YFlNs/5tMaohIMZ2zURG72tRLtq603OqSzaeZPIthDasWww\nVEfbfbckLrCcjuLzb608J8d0brg+Cgn8YxQY17r/4GbkXYuC9k9zYshOCZelS703\nC7ZdXXJuI6/VXffvbqifT9BsY3SmAPw/JQAiSxpp2+ZTwauq3YLwxDcIq9b5YX35\nqcmfM3D3mVPH/aUvLhgtMSlmaGYm8o1mD9LUIR5b5C4A+j/qmzu1IIf3JYqMjb/V\nWiKadQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "udesc.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.udesc.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.udesc.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.udesc.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.udesc.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.udesc.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.udesc.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.udesc.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.udesc.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "udesc.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.udesc.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.udesc.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UDESC - Universidade do Estado de Santa Catarina"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UDESC - Universidade do Estado de Santa Catarina"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UDESC - Universidade do Estado de Santa Catarina"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UDESC - Universidade do Estado de Santa Catarina"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEgDCCA2gCAQAwDQYJKoZIhvcNAQEFBQAwggEEMTkwNwYDVQQKEzBVREVTQyAt\nIFVuaXZlcnNpZGFkZSBkbyBFc3RhZG8gZGUgU2FudGEgQ2F0YXJpbmExSTBHBgNV\nBAsUQFNFVElDIC0gU2VjcmV0YXJpYSBkZSBUZWNub2xvZ2lhIGRhIEluZm9ybWHD\np8OjbyBlIENvbXVuaWNhw6fDo28xJTAjBgkqhkiG9w0BCQEWFnNlaW5mcmEuc2V0\naWNAdWRlc2MuYnIxFzAVBgNVBAcUDkZsb3JpYW7Ds3BvbGlzMRcwFQYDVQQIEw5T\nYW50YSBDYXRhcmluYTELMAkGA1UEBhMCQlIxFjAUBgNVBAMTDWNhZmUudWRlc2Mu\nYnIwHhcNMTQwNTE1MjAxMjEyWhcNMTcwNTE0MjAxMjEyWjCCAQQxOTA3BgNVBAoT\nMFVERVNDIC0gVW5pdmVyc2lkYWRlIGRvIEVzdGFkbyBkZSBTYW50YSBDYXRhcmlu\nYTFJMEcGA1UECxRAU0VUSUMgLSBTZWNyZXRhcmlhIGRlIFRlY25vbG9naWEgZGEg\nSW5mb3JtYcOnw6NvIGUgQ29tdW5pY2HDp8OjbzElMCMGCSqGSIb3DQEJARYWc2Vp\nbmZyYS5zZXRpY0B1ZGVzYy5icjEXMBUGA1UEBxQORmxvcmlhbsOzcG9saXMxFzAV\nBgNVBAgTDlNhbnRhIENhdGFyaW5hMQswCQYDVQQGEwJCUjEWMBQGA1UEAxMNY2Fm\nZS51ZGVzYy5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL9PTe5l\nWC7jplN9PsFwipaPk1bB5UPXxEOeJgr/6xf5RMT//l1L6T/X4uOj+lK6KI8a4pRc\noD+a83AlKb8cvYzDIQEBCDOPqjruIy+TyTwQ358x45mPM/aNivkugPKMaK8Aidma\nnUgeiRuZ1rtFyVqenDkH7qs9SwExR4NnJ/1l7DNkP6znKksBq7PGlYkj0mryxNCV\n1CAEZT6zEIyptWwd0TRHaybJc2uDD5Kl8HE54IvCwxfdKgJVQ/9FK2W9vvZowUQl\nbOGdUHqFvtudcU6VWOPxuRv4NgmkFGRaNBisnfZ3XfUah8yMIvlYXgkAevQNBjnz\ng3P3o8BU5YU6ieECAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAUu6oCJTJ51HQeuiD\n06G3V1HddwBdddkaHK+WVNux+s8fVQH1Z6ZvkIH2xgmi9ZI9jK7OoBv1H0TfM27g\n4i8RC4jkVM9SHJFR5YFlNs/5tMaohIMZ2zURG72tRLtq603OqSzaeZPIthDasWww\nVEfbfbckLrCcjuLzb608J8d0brg+Cgn8YxQY17r/4GbkXYuC9k9zYshOCZelS703\nC7ZdXXJuI6/VXffvbqifT9BsY3SmAPw/JQAiSxpp2+ZTwauq3YLwxDcIq9b5YX35\nqcmfM3D3mVPH/aUvLhgtMSlmaGYm8o1mD9LUIR5b5C4A+j/qmzu1IIf3JYqMjb/V\nWiKadQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UDESC - Universidade do Estado de Santa Catarina"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UDESC - Universidade do Estado de Santa Catarina"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.udesc.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.udesc.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UDESC - Universidade do Estado de Santa Catarina"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UDESC - Universidade do Estado de Santa Catarina"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://lobo2.lab.sunet.se/shibboleth",
    {
      "entity_id": "https://lobo2.lab.sunet.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lobo2.lab.sunet.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lobo2.lab.sunet.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lobo2.lab.sunet.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lobo2.lab.sunet.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lobo2.lab.sunet.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://lobo2.lab.sunet.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://lobo2.lab.sunet.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "lobo2.lab.sunet.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAML/7NVXPHgMMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEmxvYm8yLmxhYi5zdW5ldC5zZTAeFw0xNDA2MzAxMjQ2MjlaFw0yNDA2Mjcx\nMjQ2MjlaMB0xGzAZBgNVBAMTEmxvYm8yLmxhYi5zdW5ldC5zZTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBANv+IOxBi0J3ZFp4X+8iAinKpojT4LII8Ost\nwllFgGcjrbarjDe9fZyOP0QJkw8BzQIRRveSrB8hcX/2ekKG6uTOc1klKjE8RfIo\nPUeIDm1qodd5VJKkoejbQZ/PF1Y3gBPdLmXkh1E1k+XlxuvBiC+GLRgwCljCP+Jp\nXJ5p4kP46xNzQeXBAExHgz0zNtOQVBnYJlmT18hoHAvNy1GGXfazXOX5bmDgrzKD\nfZXSsv0dMwJeH/mtkp6zcMMIG8awKSQVB4r7Ps/ok8iDfKU43JXNAbwMywWd7ooj\nf0TVA9VXVxb2sJIEwX96z1l4YqoVTNxdeagPXSNZG3hKjluCyp8CAwEAAaNAMD4w\nHQYDVR0RBBYwFIISbG9ibzIubGFiLnN1bmV0LnNlMB0GA1UdDgQWBBRZkMZIMbgy\nuc/8wmPJMdQ7hqRMRDANBgkqhkiG9w0BAQUFAAOCAQEAR4SDw2aQcOx2/eKYyeYp\nOP/Q/pTfDCwm/iu76kI6wufj7PdL2/4ovTRZaKv0jnzd5RP364wRCyzS+OQZHHaS\nLbeYrsJmBfKKGdXL9ESh2svL8Z6NVBmfDF/Kmxm6Xgd/BRrgmz/qSH0v3iaMyCpH\n5yro+XDI5AfteZfQg0AZDox+mMoR7wzFcymQpVA1Z5RWoRuPVC8oO9ILYcCrq+6M\nNr4loPU74SFod1O6Y7SZ5A6Cz1JXaeAy0AXpvFXx8mK31mIVx3yjnFa9im4Sqraf\nMLNKAa3vUl765Wt8I1Q9p7FvbV0qki2rEk8Q/D6qnquI06uajRRybcH+qEoUFqRX\npA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=lobo2.lab.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lobo2.lab.sunet.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lobo2.lab.sunet.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://lobo2.lab.sunet.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://lobo2.lab.sunet.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://lobo2.lab.sunet.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://federation.umontpellier.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Boz Franck"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "franck.boz@univ-montp1.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Aurelien MORAT"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "aurelien.morat@univ-montp1.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federation.umontpellier.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-11-26T15:40:57Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.umontpellier.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federation.umontpellier.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://federation.umontpellier.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "umontpellier.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-montp1.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Montpellier University idp"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IDP de l'universite de montpellier"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Montpellier University"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Montpellier"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIVANLpEjQnKlSmtfHEGcM1f/W7i4lpMA0GCSqGSIb3DQEB\nBQUAMCUxIzAhBgNVBAMMGmZlZGVyYXRpb24udW1vbnRwZWxsaWVyLmZyMB4XDTE0\nMTEyNjE0MDA1OVoXDTM0MTEyNjE0MDA1OVowJTEjMCEGA1UEAwwaZmVkZXJhdGlv\nbi51bW9udHBlbGxpZXIuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQCmmImK4S7w7kBZ7+B6u08+SVar2WziXT2HeFII+NcAWeSwMIcu8ZqJeIB6wO9M\nbupXiAmXtRC0iICDKbL1AlDdyL3NrGvwWPNyha5xvDHCxT3lDCWeJpTb8RH/9sFj\nkPHOCE9VMU43GO+5r01Kequm7Nq6uocH7vCxUedZt+wUb7pEJLRR7U8IvC2kQoNX\nkdILYF9njDlEiTl2ypmzh650gtp7lrmUuE/7aOmvwfJ+yThUkOVjcyOB0O1pvmub\nhujVpYLm8QhLY+YQvziw7K5FyAGcsodDoVFbYQX2w9A0k4qvMbhqMCpAW5vIXyH9\nI7DboeEAd1Hx+UddYu5ZsXj/AgMBAAGjezB5MB0GA1UdDgQWBBSmZeTS5ODCHv+N\nlkOHEz7PvbycwDBYBgNVHREEUTBPghpmZWRlcmF0aW9uLnVtb250cGVsbGllci5m\ncoYxaHR0cHM6Ly9mZWRlcmF0aW9uLnVtb250cGVsbGllci5mci9pZHAvc2hpYmJv\nbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAnBA+peFmxiPlU2s9zj3md7Yq2zNbWYBz\nGz5Ur5EvuVarCOx5aigdHrjHtORDVCHOuB6BgHqfDAK15V3qLSZEx4jjMJ4w5xi4\nsLcm4kn+j/wYaIZkTOxyUp57ECNrhwGJT2SbnYKmmlD9mxNnjNGGuLFSxfxcqNCm\nf6yIOQbKNi+Q/JSTc5ma6qtjO4u3darPGaP83/MYulHEjx+Zy4yiAntw0oPk3ZxY\noz6GW83/GNoyFh4u65Ay8Cox65Hk17SVMxHhc/LPv7rII1uLSoLmTTA/aJN9zyEf\n9EnaolCTqrzcOMIMPXkxzbx4oep11GrkLknLljw3wLfQkaBe0fBs2Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Montpellier"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-montp1.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Montpellier"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ubas-test.srv.lu.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "\u00c5hfeldt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "martin.ahfeldt@lu.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ubas-test.srv.lu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ubas-test.srv.lu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ubas-test.srv.lu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ubas-test.srv.lu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIJAOfZjMApPqeXMA0GCSqGSIb3DQEBCwUAMHIxCzAJBgNV\nBAYTAlNFMQ8wDQYDVQQIEwZTd2VkZW4xDTALBgNVBAcTBEx1bmQxEjAQBgNVBAoT\nCUxEQyBkcmlmdDERMA8GA1UECxMIVEVTVC1zc2wxHDAaBgNVBAMTE3ViYXMtdGVz\ndC5zcnYubHUuc2UwHhcNMTUxMDE0MDkwMDAxWhcNMjAxMDEzMDkwMDAxWjByMQsw\nCQYDVQQGEwJTRTEPMA0GA1UECBMGU3dlZGVuMQ0wCwYDVQQHEwRMdW5kMRIwEAYD\nVQQKEwlMREMgZHJpZnQxETAPBgNVBAsTCFRFU1Qtc3NsMRwwGgYDVQQDExN1YmFz\nLXRlc3Quc3J2Lmx1LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\nma6sd5S7fy4QMP1oV3BB8QO92cd/JAIbvgduiOf6JIbwXoamIlpKX8VK0HhXm1Cr\nTrbUBk1cStapjj+bb6DMEmN/YoPcwXDiS7O4Rngm9O2gD4FwFjSxZwOjSfme0FPz\nb9e9XdUd0wcAYn5jOvESB+OdtSDpzGmoOiaobm+5dvnje31bod1GDyxgoWDx201u\nQyVM+10tnRiex5Hrk7WWYnhMEv02PLIx+6cO2ms9a/qqzNfUYt699q5IkfU2yQKI\nXU554jrS3Md0HDGich8TBphtLMzQ8Ot3SVkJza48u9L3Fpk6ANk8lkKM5E7ywaD2\nIS6RKHxEdOaYi+WvyMWMsQIDAQABo1cwVTAJBgNVHRMEAjAAMAsGA1UdDwQEAwIF\n4DA7BgNVHREENDAyghN1YmFzLXRlc3Quc3J2Lmx1LnNlght0MDIyMS11YmFzLWx1\nLXRzdC5zcnYubHUuc2UwDQYJKoZIhvcNAQELBQADggEBAHM/29XBSwCIyROueQ1y\nFmit577cWeazp1+NBL3NRHtesFJdMftMCGncQxGmLrLtM7BTXOo3VIESzKYMl1Xm\n95IX1G1n38VkoVqJvTeVaSC6ICdphoRzoS3RIdZVFZ5h7VYz7zhqwmS5b8sXGvhH\niJQJq7XXtua5AkQnhyg4S2Tvl+OGXXM02d3DYLAfnn9Hqwh2OYK++J1FJUsnRFy9\nMq8mcNGZ3w2+BrFczNJ+C23CGJ2dxQS77hAPIB8fOTPKt8zFbsFRk4TeDwFUlQ1m\nES+MzAaLWpKSnGkIsyHbz5P8oek6Suc5ewoxo/7lMBXDpwS1YSEets0i0s6OHM5C\n5iU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "uBAS och luBAS testmilj\u00f6 / utbildningsplaner och kusrplaner"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "uBAS and luBAS testing"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "uBAS test"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "uBAS test"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "http://shastacollege.instructure.com/saml2",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "http://shastacollege.instructure.com/saml2",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Instructure, Inc"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.instructure.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Instructure, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shastacollege.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shastacollege.test.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shastacollege.beta.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.canvaslms.com/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://canvas.instructure.com/images/canvas/header_canvas_logo@2x.png",
                    "lang": "en",
                    "height": "220",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "220"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.canvaslms.com/policies/privacy-policy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "OEI - Shasta College - Canvas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE8TCCA9mgAwIBAgIJAOBms/PYWcPLMA0GCSqGSIb3DQEBCwUAMIGrMQswCQYD\nVQQGEwJVUzENMAsGA1UECBMEVXRhaDEXMBUGA1UEBxMOU2FsdCBMYWtlIENpdHkx\nGTAXBgNVBAoTEEluc3RydWN0dXJlLCBJbmMxEzARBgNVBAsTCk9wZXJhdGlvbnMx\nIDAeBgNVBAMTF0NhbnZhcyBTQU1MIENlcnRpZmljYXRlMSIwIAYJKoZIhvcNAQkB\nFhNvcHNAaW5zdHJ1Y3R1cmUuY29tMB4XDTE1MDQxNTAxMDAwMFoXDTE3MDQyMjAx\nMDAwMFowgasxCzAJBgNVBAYTAlVTMQ0wCwYDVQQIEwRVdGFoMRcwFQYDVQQHEw5T\nYWx0IExha2UgQ2l0eTEZMBcGA1UEChMQSW5zdHJ1Y3R1cmUsIEluYzETMBEGA1UE\nCxMKT3BlcmF0aW9uczEgMB4GA1UEAxMXQ2FudmFzIFNBTUwgQ2VydGlmaWNhdGUx\nIjAgBgkqhkiG9w0BCQEWE29wc0BpbnN0cnVjdHVyZS5jb20wggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDckDPQGWedlVGC2Z9fn1wNFmN+0IPNi6OSE1nM\nvoTWx2oZlQepaAu4zI5QqOfnV0rW2V1volpoJbu0WelH0DkGzdOEQdWJjAs3nRBf\ny0evxtpg0tK5kIvGsnN6YcD41YmkfWzvwbMf0cEq1Y0wCmymF6XzOUUE4zsi0nhP\nm2Z7WiuongDQdR01UsDN13YcpD/i1JXr3YtkNnJ/a1Kc9OXNycI8M5NVo5QQgdx/\nQ7zAmTk8p9E0ZRthdOQ/PBicWx39mNmBij5KpqCWlHu3NWdgcG8KXSv5atXU8Crd\nTRJ3aGIEN9vBYIHe8MHGCzs1QlRfJmXFMkeUSOTnJJx78rMDAgMBAAGjggEUMIIB\nEDAdBgNVHQ4EFgQUo0WWVlJ1SxZOs11L85ZAuZGyuzEwgeAGA1UdIwSB2DCB1YAU\no0WWVlJ1SxZOs11L85ZAuZGyuzGhgbGkga4wgasxCzAJBgNVBAYTAlVTMQ0wCwYD\nVQQIEwRVdGFoMRcwFQYDVQQHEw5TYWx0IExha2UgQ2l0eTEZMBcGA1UEChMQSW5z\ndHJ1Y3R1cmUsIEluYzETMBEGA1UECxMKT3BlcmF0aW9uczEgMB4GA1UEAxMXQ2Fu\ndmFzIFNBTUwgQ2VydGlmaWNhdGUxIjAgBgkqhkiG9w0BCQEWE29wc0BpbnN0cnVj\ndHVyZS5jb22CCQDgZrPz2FnDyzAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUA\nA4IBAQBV3EmmnzYqYQ5fXNZymG2WaspEW0NeFMhDXa3p3AMIQJbnnU14lR7bqIvf\n/bLW1YE0fw1kSzsw8VrkQp7k1U+kaYA3i5/FQBy2WtqUCVq2GXZA2gs5YD4nvJB/\nF57E//0kEhbATZH9+wJqDkqyIgsrSIlJjiXDth1BppGK8weboPtr9sWV24Ui0+ls\nw16XTsGlnRRO19g+gXKOZp5ApXkDrB+HwZQvZxiCuSgvJlcBzMdxVvWSL+vPtg8Y\nshIKzobIhaQ2MzXHLcxrDhW10YFPwDXh8Tfn5iU9ONsaJivuvVhtDYZD1ZzSoPpm\nq4vYqxxY/6rFJhrCtnlLepSaxlXM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shastacollege.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shastacollege.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shastacollege.beta.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shastacollege.beta.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shastacollege.test.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shastacollege.test.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "OEI - Shasta College - Canvas"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://miunidp.miun.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 771 975 000"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "SystemDrift, IT-avdelningen, Mittuniversitetet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SystemDriftIT@miun.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Mid Sweden University"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 10 142 7888"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "M\u00e5rtensson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:roger.martensson@miun.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Mid Sweden University"
          },
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roger"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 771 976130"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@miun.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Mid Sweden University"
          }
        }
      ],
      "entity_id": "https://miunidp.miun.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oasis:names:tc:SAML:attribute:assurance-certification",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://miunidp.miun.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://miunidp.miun.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://miunidp.miun.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://miunidp.miun.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://miunidp.miun.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "miun.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.miun.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.miun.se/en/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mittuniversitetet PRODTEST"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mid Sweden University PRODTEST"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IDP p\u00e5 Mittuniversitetet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IDP at Mid Sweden University"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.miun.se/imagevault/publishedmedia/x4bl7padufcm1j4td3d7/logo.png",
                    "lang": "sv",
                    "height": "111",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "225"
                  },
                  {
                    "text": "https://www.miun.se/imagevault/publishedmedia/x4bl7padufcm1j4td3d7/logo.png",
                    "lang": "en",
                    "height": "111",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "225"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.miun.se/sv/Helpdesk/Student/MittNets-regler/"
                  }
                ]
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "miun.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:63.176762,14.651352"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:62.394626,17.284259"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:62.630989,17.946473"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUDopqrwr+8ysNjsx8WcAQU0xgFqYwDQYJKoZIhvcNAQEL\nBQAwHjEcMBoGA1UEAwwTbWl1bmlkcHRlc3QubWl1bi5zZTAeFw0xNjAzMTQxMDQ4\nMzRaFw0zNjAzMTQxMDQ4MzRaMB4xHDAaBgNVBAMME21pdW5pZHB0ZXN0Lm1pdW4u\nc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDSfUra2csPm7zfml2+\n+FLWgZ3C3W7V77ogOuOd/5+79XywWdtHD1WrJntmL4eGvytW8vU6/DOo0c4UVKxt\nDKB2LSIy6uwd+OPbnWl6IQbk2ylb0UOIMV1pLMgBmrBoKt2dtpUH0T3Oqg2D7r9r\nCH8nk7rgrT5INIQDCS1NNVWEgRqltMH1Mmn90J2XzoGZrl6ZmEZ8uWURcypuPZcT\nQY9VvbVP8PKz1Bo9Qhh0LjXOumIGCdQoH0sQytePjcroLpL1HSAvX7DDsPNl4/Qh\nsnILrHdK2z601oN1Ngu1rxrqWz0H2j9Z8U+zYjxdGOpvjXPg8iOIZJW0YM36SbcB\nSfKZAgMBAAGjbTBrMB0GA1UdDgQWBBQC5zJpccPPIWSbMiJAkQHQ39PBNTBKBgNV\nHREEQzBBghNtaXVuaWRwdGVzdC5taXVuLnNlhipodHRwczovL21pdW5pZHB0ZXN0\nLm1pdW4uc2UvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBACdM6Gcf\nmHA0Hr1zC4T18vXqj2todlOm/wBoisGcJ8Yvz5YDozE0Ginn1RpjaUab/v10s8BK\nxBwVnyzTupIJMl0pW7XEHzVEWStpn69m+iNFtDuCe8gVvILI0dRt1NVUD/+b3d1U\n/QePhM43hJVGWi7/yyP12INV98P4HdZ91VMxafGzFVCh/cgLjYxwVaAYt0kCzZqE\noAK9ajxQTMEz7h5ebJDfi+eydnDmzUFuFYzjB4CIPs0YLvyr5R1wXOxzZcpPE7c5\nqjqmAlpXZIozlPXNuM5NG2qX5fs+okW0ZvDzp7uGthyxxTchBR8PxTfSnE2ImX2a\nQ2DB2f7ifMpnsvw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAPRwsS0jawwgnaLnIOydT5jeXjVhMA0GCSqGSIb3DQEB\nCwUAMB4xHDAaBgNVBAMME21pdW5pZHB0ZXN0Lm1pdW4uc2UwHhcNMTYwMzE0MTA0\nODMyWhcNMzYwMzE0MTA0ODMyWjAeMRwwGgYDVQQDDBNtaXVuaWRwdGVzdC5taXVu\nLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA4EPO2E98M79WKFHy\nAPjeQALlMgPuAkrVa9aiC84V7q3hgfdbD0wbNJTGA9uj7an2Fz5uNfUWS1Rg/7DT\nuEjrGpsWXn3mlBuH2wOZe9wHqFwVf5NUos/00gLxs6WIjaNv6gxnbnVss0pKURTL\n+bl4mn7XSPpbNosWlHkn4IbnXBi8zTwQ7Us2+klu15YfAPnlkMYgzOl1YkxqB3cM\nzxnejzBjzpG1VJWkLUOEFxlFYUwEsn5aOMpT4DXEq1PSSZfDmtz6tN+WQiV8W1rt\nQYyThOUwvF+L6Z9N960IFfiirCVk30doFfu5P/KmzciFWKcRHH2Jce3R/pC0SVNs\n56Z63QIDAQABo20wazAdBgNVHQ4EFgQUhtV3ZMcE4JWqlNJJVYkqB5inKUEwSgYD\nVR0RBEMwQYITbWl1bmlkcHRlc3QubWl1bi5zZYYqaHR0cHM6Ly9taXVuaWRwdGVz\ndC5taXVuLnNlL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQCKf/Z8\nm1RMKsiP56XEBD/KlZToM23WF+i3xw7IPlo6a+bMT2emxKBCVv3CU6oMe55TMUeu\nRHzNHB3g0oa/xH+APxLbP64FMvDrJAPFDsltRX97C9UyO47rBL983Jcjo20fjCt1\n03xMipYa9aYc6miUSXKSP0zLu8XoyRo8Vlx0+4y1hI1B/vfgw2I850thSfM/TepO\neHLpC5j1cjhz+omgj8KtOu4iwRShXmOTb3/MPKYQ0BezIuI99QfavE3jkdVg4+bb\nsEjpTEgCNeNotsnug8EzSf3jMac7QVsKk/ZUjpMUiH1QWeXQSzpkT+BfEjcXUm23\np8Zy6HNa1RvGgW8P"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUPMQjIIrMt+goB+uHSwi2oO14KAgwDQYJKoZIhvcNAQEL\nBQAwHjEcMBoGA1UEAwwTbWl1bmlkcHRlc3QubWl1bi5zZTAeFw0xNjAzMTQxMDQ4\nMzRaFw0zNjAzMTQxMDQ4MzRaMB4xHDAaBgNVBAMME21pdW5pZHB0ZXN0Lm1pdW4u\nc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCgqMKF+EDtjw74HWSy\nt2SU4fV4734PyV9gsPBJph8VQ32cAB7tqkqhIQbkHJKhJ4XeladH+ifk+BOdje9n\nEwIKIehxdujW832NAlMkEXfo3M2wt8UCBATCoWsxexkFUtNhZQnvtUm7dW0GuDYE\nNaZd0W6JMz0vBl83+JatCHu30kHu6CDgo/D6S9RL4pj3KiN08oR5Rjn5jHdNgMTf\ndNuYn2jsvKiR9EtcXC2KgvtYwqzGpjmcFxthBPBF3lzAza8ES16UVCPxVuH9DSJ5\ngB20wTMzP9xKSWQ/NKjh4AqEZ0hLH4dXGDzA3G3h/IkSgfaB+XalZDC6vzfuXXnv\ndE2HAgMBAAGjbTBrMB0GA1UdDgQWBBREfhKvA2DRE1mKkZfCgjAyiwegWzBKBgNV\nHREEQzBBghNtaXVuaWRwdGVzdC5taXVuLnNlhipodHRwczovL21pdW5pZHB0ZXN0\nLm1pdW4uc2UvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAGl9GoKC\ngm7ywKn8I5eAF+MEUkDPPPt5KMSfIe7SZmI975vceeCDaPOZ8gvKuAHHC3yG6fgf\nFLqNffN26y4k6EYg4XVGq5u8SmEwDktTn4wRJyj4NN9cqg3EZbw7wa10jTVTGEWm\n13Hf0TEi2qAkU3Xb8K7hHDy//BnKHo1FZLcIPMUGrIpaCl32klb5fAwvE+E6QgCB\naFup4A/f+gTnofyIo1gi8TmMs/7v+A5Ty39VdmU15eXvA2TBhGEDFmVAQWnZvSQ2\nYAe2eCFJhzuNutfMyzzH4ZE1da+vfxQX0yLQpKiK4XRIH4Jr1THM/12L+YNmlRPF\n7RI4YGkyabhUuiM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mittuniversitetet PRODTEST"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mid Sweden University PRODTEST"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.miun.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "MIUN"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://bismarck.nyme.hu/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Nemeth Tamas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tamas.nemeth.net@eik.nyme.hu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Nemeth Tamas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tamas.nemeth.net@eik.nyme.hu"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Nemeth Tamas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tamas.nemeth.net@eik.nyme.hu"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bismarck.nyme.hu/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "urn:schac:homeOrganizationType:hu:university"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-edugain"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "nyme"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:geant:niif.hu:eduid.hu:entity-attributes:processing-info",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "hu",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://metadata.eduid.hu/registration_policy_1_0.txt"
              }
            ],
            "registration_instant": "2013-08-01T07:17:19.807Z",
            "registration_authority": "http://eduid.hu",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://bismarck.nyme.hu/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://bismarck.nyme.hu/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.nyme.hu"
                  }
                ],
                "display_name": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Nyugat-magyarorsz\u00e1gi Egyetem"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The University of West Hungary (Sopron), Hungary"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Nyugat-magyarorsz\u00e1gi Egyetem"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The University of West Hungary (Sopron), Hungary"
                  }
                ],
                "logo": [
                  {
                    "text": "https://bismarck.nyme.hu/simplesaml/black_on_white.png",
                    "height": "145",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "143"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.nyme.hu/fileadmin/dokumentumok/rektori/szmszm/adatvedelmi_adatkezelesi_szab_20150128.pdf"
                  }
                ]
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nyme.hu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eik.nyme.hu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "bismarck.nyme.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Nyugat-magyarorsz\u00e1gi Egyetem"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The University of West Hungary (Sopron), Hungary"
          }
        ],
        "organization_url": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nyme.hu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uniwest.hu"
          }
        ],
        "organization_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Nyugat-magyarorsz\u00e1gi Egyetem"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of West Hungary (Sopron), Hungary"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.glasgowkelvin.ac.uk/openathens",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Campbell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:MCampbell@glasgowkelvin.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matt"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McBride"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:amcbride@glasgowkelvin.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.glasgowkelvin.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-09-22T14:18:15Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.glasgowkelvin.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.glasgowkelvin.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "glasgowkelvin.ac.uk"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Glasgow Kelvin College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkCgAwIBAgIIEcxlhYHW7FYwDQYJKoZIhvcNAQEFBQAwQzEfMB0GA1UE\n\t\t\t\t\t\tCgwWR2xhc2dvdyBLZWx2aW4gQ29sbGVnZTEgMB4GA1UEAwwXaWRwLmdsYXNnb3dr\n\t\t\t\t\t\tZWx2aW4uYWMudWswHhcNMTQwODI5MTMyODUyWhcNMjQwODI5MTMyODUyWjBDMR8w\n\t\t\t\t\t\tHQYDVQQKDBZHbGFzZ293IEtlbHZpbiBDb2xsZWdlMSAwHgYDVQQDDBdpZHAuZ2xh\n\t\t\t\t\t\tc2dvd2tlbHZpbi5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAOxm3dLSX+UNx+aVR24NNhE03L/lpOpLPxU+COARq2kuD8AGv6OxUWt0tdDYskJp\n\t\t\t\t\t\tSwMQRQmqP2R32ulYMQBeeD0e+Kale+b9uX/Zkut8PohQZeSkCMpV0lEmkK07ivOB\n\t\t\t\t\t\tMh6FiViWZ0XWAQ/6RfnSC/9L+PJcqpRkAwr0qkGo7k2eaE7ffIhZY7ImKVAiPS7r\n\t\t\t\t\t\tYAgZPCiWHtC8eN6+h9kJJo7FyFacKMO82lid+rHdUq+X3335xHL7tFjOCzk/AcI8\n\t\t\t\t\t\t9DSdgvrL3rB/bMmsko7+tz/DbEfrFwMqwpVuX1Cs7YWl88E7VB+FBJZsTLJH2XDQ\n\t\t\t\t\t\tm9930Nq2iULafPahz+IHhgECAwEAAaNQME4wHQYDVR0OBBYEFGZmAoJCe7wdXY7f\n\t\t\t\t\t\t/pFKFpXXbwZDMB8GA1UdIwQYMBaAFGZmAoJCe7wdXY7f/pFKFpXXbwZDMAwGA1Ud\n\t\t\t\t\t\tEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAEPUdwYfF7ElyNcGzmGgCz0sqZAC\n\t\t\t\t\t\tUaNoersFgCvSzrc2BWmeivgBUy0VVt5tU2YZKTAcIhvh/ZXNbJzoc+YH/KuLJ1hi\n\t\t\t\t\t\t7b/jDBPH7QZZ4uv4U/WkSr4n/1tRpUnLrY505X/hCxpH11MOs2OHd5edwiIDuiUA\n\t\t\t\t\t\t3hDuvyCQYLy386VhX3UZVBtew16Z5KUhPcbtW/k+RhYuH/j2Inq/4W1UpmsNR2Ug\n\t\t\t\t\t\tl2RyOBeMBakzxmb2R6y3nWcxAidG42LV8DLVUbqwoEcIg4Mt5jbZDrlEhPvW4zal\n\t\t\t\t\t\tTWIuR+MKKnSlSNym/jSdIEVMIQ/mmLy8Pmqg/bdX5zgOHNLQEtGgpX0ReOo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkCgAwIBAgIIEcxlhYHW7FYwDQYJKoZIhvcNAQEFBQAwQzEfMB0GA1UE\n\t\t\t\t\t\tCgwWR2xhc2dvdyBLZWx2aW4gQ29sbGVnZTEgMB4GA1UEAwwXaWRwLmdsYXNnb3dr\n\t\t\t\t\t\tZWx2aW4uYWMudWswHhcNMTQwODI5MTMyODUyWhcNMjQwODI5MTMyODUyWjBDMR8w\n\t\t\t\t\t\tHQYDVQQKDBZHbGFzZ293IEtlbHZpbiBDb2xsZWdlMSAwHgYDVQQDDBdpZHAuZ2xh\n\t\t\t\t\t\tc2dvd2tlbHZpbi5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAOxm3dLSX+UNx+aVR24NNhE03L/lpOpLPxU+COARq2kuD8AGv6OxUWt0tdDYskJp\n\t\t\t\t\t\tSwMQRQmqP2R32ulYMQBeeD0e+Kale+b9uX/Zkut8PohQZeSkCMpV0lEmkK07ivOB\n\t\t\t\t\t\tMh6FiViWZ0XWAQ/6RfnSC/9L+PJcqpRkAwr0qkGo7k2eaE7ffIhZY7ImKVAiPS7r\n\t\t\t\t\t\tYAgZPCiWHtC8eN6+h9kJJo7FyFacKMO82lid+rHdUq+X3335xHL7tFjOCzk/AcI8\n\t\t\t\t\t\t9DSdgvrL3rB/bMmsko7+tz/DbEfrFwMqwpVuX1Cs7YWl88E7VB+FBJZsTLJH2XDQ\n\t\t\t\t\t\tm9930Nq2iULafPahz+IHhgECAwEAAaNQME4wHQYDVR0OBBYEFGZmAoJCe7wdXY7f\n\t\t\t\t\t\t/pFKFpXXbwZDMB8GA1UdIwQYMBaAFGZmAoJCe7wdXY7f/pFKFpXXbwZDMAwGA1Ud\n\t\t\t\t\t\tEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAEPUdwYfF7ElyNcGzmGgCz0sqZAC\n\t\t\t\t\t\tUaNoersFgCvSzrc2BWmeivgBUy0VVt5tU2YZKTAcIhvh/ZXNbJzoc+YH/KuLJ1hi\n\t\t\t\t\t\t7b/jDBPH7QZZ4uv4U/WkSr4n/1tRpUnLrY505X/hCxpH11MOs2OHd5edwiIDuiUA\n\t\t\t\t\t\t3hDuvyCQYLy386VhX3UZVBtew16Z5KUhPcbtW/k+RhYuH/j2Inq/4W1UpmsNR2Ug\n\t\t\t\t\t\tl2RyOBeMBakzxmb2R6y3nWcxAidG42LV8DLVUbqwoEcIg4Mt5jbZDrlEhPvW4zal\n\t\t\t\t\t\tTWIuR+MKKnSlSNym/jSdIEVMIQ/mmLy8Pmqg/bdX5zgOHNLQEtGgpX0ReOo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Glasgow Kelvin College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.glasgowkelvin.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Glasgow Kelvin College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibb-prod.eseo.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Duclos Philippe"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "philippe.duclos@eseo.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tessier Fabien"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "fabien.tessier@eseo.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibb-prod.eseo.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-06-11T17:24:23Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibb-prod.eseo.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibb-prod.eseo.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibb-prod.eseo.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eseo.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.eseo.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "\u00c9cole d'ing\u00e9nieurs"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Groupe ESEO"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Groupe ESEO"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAPKv3AMhxdHV3jWXxqMbNKHYz0KVMA0GCSqGSIb3DQEB\nBQUAMB4xHDAaBgNVBAMTE3NoaWJib3VsZXRoLmVzZW8uZnIwHhcNMTQwNTEzMTI0\nNDQ4WhcNMzQwNTEzMTI0NDQ4WjAeMRwwGgYDVQQDExNzaGliYm91bGV0aC5lc2Vv\nLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmCTC2H03ZXvDs4Io\na1d+L6ggwRUqGwP45mlW5l6Nuti5JBqjDLBvP1tPqAeh1V6boPufnkd2ZquVCZDP\n1WFjLKyL015a81gLeWvJMId1yWq4+7s4s1HBFgaftNM6z6Hl/sTt1UL/dFM3DrNH\nZ1fUHe+TWGv8e60KA4DqhjdphtM+Q0dsZNVDGGp5d0zLOPhrikoZE8pqXvbOD7r/\nW9I8jWEX4RIBJkvpeBI5zpGZVRbq5LKNVaccEJW3dx9v1MyI7JQbT90hmUdBYIOl\nb+vQ5fgJCj9RlgK+tEMJsB67w2SvD7YsG3w/DqogoZBeQUgolwPKteAyKGZIh0Y2\n5pyMSQIDAQABo20wazBKBgNVHREEQzBBghNzaGliYm91bGV0aC5lc2VvLmZyhipo\ndHRwczovL3NoaWJib3VsZXRoLmVzZW8uZnIvaWRwL3NoaWJib2xldGgwHQYDVR0O\nBBYEFMR3J/ymlt+tWJbLpfaFrrhqC2qZMA0GCSqGSIb3DQEBBQUAA4IBAQAzJ0MU\njZjJiOzYrQkeSkDw0kl2drKEOW1/54ANucqNSko1MQ2QXbOiL2bcgOXC8jDgOyEX\n+G0QO8YdGio1CCirUVPTWSIsxpRM9nI2FbhpGk+DXe2wgPTYnJPN94kdVJrWEE/Y\nBtBvR1BzklAZ6sLrXQMWerGNHAQIyQ8+SInFpqtbB9yJuWuc9oVaoGYIm3TI2N8S\n/Uo1+w4j8jXAl7tXaUnoZ1oKW36H+0sRVhZ2Ys4eH3Vk6nvf5qHPdgUCNjh6txmf\nom24YGvt8hL3ZCb5y2+jFCIZyCf853CuTiEjLyT7c1KZzUPzvDVqf0gL5n3twqxj\ncE2NlFME1N0tqRVC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Groupe ESEO"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eseo.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Groupe ESEO"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://box-idp.sunet.se/simplesaml/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NOC"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@sunet.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SUNET"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://box-idp.sunet.se/simplesaml/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish University Network (SUNET)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sunet.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SUNET"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://box-idp.sunet.se/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://box-idp.sunet.se/simplesaml/module.php/saml/sp/discoresp.php",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SUNET Box Service Access"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SUNET Box Service Access"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SUNET Box Service Access"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SUNET Box Service Access"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://box-idp.sunet.se/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://box-idp.sunet.se/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://box-idp.sunet.se/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://box-idp.sunet.se/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.kcollege.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mitchell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:garethmitchell@kcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gareth"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mitchell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:garethmitchell@kcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gareth"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.kcollege.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-03-08T17:52:30Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEVDCCAzygAwIBAgIJAIt8JpQ7ds27MA0GCSqGSIb3DQEBBQUAMIGqMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjENMAsGA1UECBMES2VudDESMBAGA1UEBxMJVG9uYnJpZGdlMRIwEAYD\n\t\t\t\t\t\tVQQKEwlLIENvbGxlZ2UxFjAUBgNVBAsTDUlUIERlcGFydG1lbnQxIjAgBgNVBAMT\n\t\t\t\t\t\tGXNoaWJib2xldGgua2NvbGxlZ2UuYWMudWsxKDAmBgkqhkiG9w0BCQEWGWl0c2Vy\n\t\t\t\t\t\tdmljZXNAa2NvbGxlZ2UuYWMudWswHhcNMTQwMjEyMDk1MDA5WhcNMjQwMjEwMDk1\n\t\t\t\t\t\tMDA5WjCBqjELMAkGA1UEBhMCR0IxDTALBgNVBAgTBEtlbnQxEjAQBgNVBAcTCVRv\n\t\t\t\t\t\tbmJyaWRnZTESMBAGA1UEChMJSyBDb2xsZWdlMRYwFAYDVQQLEw1JVCBEZXBhcnRt\n\t\t\t\t\t\tZW50MSIwIAYDVQQDExlzaGliYm9sZXRoLmtjb2xsZWdlLmFjLnVrMSgwJgYJKoZI\n\t\t\t\t\t\thvcNAQkBFhlpdHNlcnZpY2VzQGtjb2xsZWdlLmFjLnVrMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAyUONnw9FNuYKcET6VNifgEdvZOAOZXlyJTOmS+dR\n\t\t\t\t\t\ttEhyW8TBc5gFjyPyc12Odj3qelGj/IwN0UuvN9XSZwVXVfTfxShmAxfA4jGp9/QS\n\t\t\t\t\t\t3GDvDJRaIEpZBXdnnj1/mBtXUc3kz8bATlKK2iOyl+M4YtwxoHzDyFhlsu+h4A2Y\n\t\t\t\t\t\tLOl3ippTtSql++pgoRAITDLuALIgF/BSzWV/wv1l11AzPauPONJTPWH8uBZ8e85H\n\t\t\t\t\t\tkcgm2+psZwP3NYGrgzWmR2OKFZg/4buis+S1LDTX66zuwaMnCwnK7y6jcgQ8piB0\n\t\t\t\t\t\tY5ypSZCq4fOUc7vNiYmA/EJVq5c6//cyfo4OHUxMgOStHwIDAQABo3sweTAJBgNV\n\t\t\t\t\t\tHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZp\n\t\t\t\t\t\tY2F0ZTAdBgNVHQ4EFgQUhvOVaHPTsggHRCxEXm6G8hfJbVswHwYDVR0jBBgwFoAU\n\t\t\t\t\t\thvOVaHPTsggHRCxEXm6G8hfJbVswDQYJKoZIhvcNAQEFBQADggEBALIGgkvNn9fX\n\t\t\t\t\t\tHlxH5CiHKVOSwEHE7MlnkJLOemlMv/n4jjWJyKOQ1XR6nZ7Q9UQl0v5cHZKJMMYq\n\t\t\t\t\t\tchJebSDsho3kb9LkibDEAO6b2b8ZUGMf0F/6hqETy5Qj/w9YFRHqsIHkDMbCZAKd\n\t\t\t\t\t\t8fm5chrfV2op269TzIrs0LLiCqGE7Jak0ZafxxHUofxQb2d31OdT5xga47ReJI1n\n\t\t\t\t\t\tCwTAsqXJlK6Zt6T5x29G94U0l5jgYlIrkbGI5ybdfCmOI7NIk+N6uadQ0CLx4sbH\n\t\t\t\t\t\tTGHu0K6ZOPVhjPVgBOVGFbmVDx9WrGCSliwiYBc8hzurYDhZFH323wiUja7yrCUs\n\t\t\t\t\t\tzGCgMnWgl18="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kcollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.kcollege.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.kcollege.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.kcollege.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.kcollege.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.kcollege.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.kcollege.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.kcollege.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.kcollege.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kcollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEVDCCAzygAwIBAgIJAIt8JpQ7ds27MA0GCSqGSIb3DQEBBQUAMIGqMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjENMAsGA1UECBMES2VudDESMBAGA1UEBxMJVG9uYnJpZGdlMRIwEAYD\n\t\t\t\t\t\tVQQKEwlLIENvbGxlZ2UxFjAUBgNVBAsTDUlUIERlcGFydG1lbnQxIjAgBgNVBAMT\n\t\t\t\t\t\tGXNoaWJib2xldGgua2NvbGxlZ2UuYWMudWsxKDAmBgkqhkiG9w0BCQEWGWl0c2Vy\n\t\t\t\t\t\tdmljZXNAa2NvbGxlZ2UuYWMudWswHhcNMTQwMjEyMDk1MDA5WhcNMjQwMjEwMDk1\n\t\t\t\t\t\tMDA5WjCBqjELMAkGA1UEBhMCR0IxDTALBgNVBAgTBEtlbnQxEjAQBgNVBAcTCVRv\n\t\t\t\t\t\tbmJyaWRnZTESMBAGA1UEChMJSyBDb2xsZWdlMRYwFAYDVQQLEw1JVCBEZXBhcnRt\n\t\t\t\t\t\tZW50MSIwIAYDVQQDExlzaGliYm9sZXRoLmtjb2xsZWdlLmFjLnVrMSgwJgYJKoZI\n\t\t\t\t\t\thvcNAQkBFhlpdHNlcnZpY2VzQGtjb2xsZWdlLmFjLnVrMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAyUONnw9FNuYKcET6VNifgEdvZOAOZXlyJTOmS+dR\n\t\t\t\t\t\ttEhyW8TBc5gFjyPyc12Odj3qelGj/IwN0UuvN9XSZwVXVfTfxShmAxfA4jGp9/QS\n\t\t\t\t\t\t3GDvDJRaIEpZBXdnnj1/mBtXUc3kz8bATlKK2iOyl+M4YtwxoHzDyFhlsu+h4A2Y\n\t\t\t\t\t\tLOl3ippTtSql++pgoRAITDLuALIgF/BSzWV/wv1l11AzPauPONJTPWH8uBZ8e85H\n\t\t\t\t\t\tkcgm2+psZwP3NYGrgzWmR2OKFZg/4buis+S1LDTX66zuwaMnCwnK7y6jcgQ8piB0\n\t\t\t\t\t\tY5ypSZCq4fOUc7vNiYmA/EJVq5c6//cyfo4OHUxMgOStHwIDAQABo3sweTAJBgNV\n\t\t\t\t\t\tHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZp\n\t\t\t\t\t\tY2F0ZTAdBgNVHQ4EFgQUhvOVaHPTsggHRCxEXm6G8hfJbVswHwYDVR0jBBgwFoAU\n\t\t\t\t\t\thvOVaHPTsggHRCxEXm6G8hfJbVswDQYJKoZIhvcNAQEFBQADggEBALIGgkvNn9fX\n\t\t\t\t\t\tHlxH5CiHKVOSwEHE7MlnkJLOemlMv/n4jjWJyKOQ1XR6nZ7Q9UQl0v5cHZKJMMYq\n\t\t\t\t\t\tchJebSDsho3kb9LkibDEAO6b2b8ZUGMf0F/6hqETy5Qj/w9YFRHqsIHkDMbCZAKd\n\t\t\t\t\t\t8fm5chrfV2op269TzIrs0LLiCqGE7Jak0ZafxxHUofxQb2d31OdT5xga47ReJI1n\n\t\t\t\t\t\tCwTAsqXJlK6Zt6T5x29G94U0l5jgYlIrkbGI5ybdfCmOI7NIk+N6uadQ0CLx4sbH\n\t\t\t\t\t\tTGHu0K6ZOPVhjPVgBOVGFbmVDx9WrGCSliwiYBc8hzurYDhZFH323wiUja7yrCUs\n\t\t\t\t\t\tzGCgMnWgl18="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "K College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kcollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "South and West Kent College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:urkund:shibboleth:sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Witasp"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:peter.witasp@prioinfo.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Peter"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Otter"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:samuel@onposition.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Samuel"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:urkund:shibboleth:sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://secure.urkund.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://secure.urkund.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://secure.urkund.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://secure.urkund.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "URKUND"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://secure.urkund.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.urkund.com/se/om-urkund"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.urkund.com/en/about-urkund"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "URKUND is an online plagiarism checker service reserved for teachers"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "URKUND is an online plagiarism checker service reserved for teachers"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://static.urkund.com/documents/URKUND_SP_privacy.pdf"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "URKUND"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "URKUND"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "urkundweb.urkund.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJAL61GoCfz8heMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE3Vya3VuZHdlYi51cmt1bmQuc2UwHhcNMDkwMzAzMTU1NjQyWhcNMTkwMzAx\nMTU1NjQyWjAeMRwwGgYDVQQDExN1cmt1bmR3ZWIudXJrdW5kLnNlMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA3RwMFJu304/B3qtfLT8r2vKBOugNcfyZ\nEDsf4Q4ZHFDFhWOh6VAuywjpixKBm/LYCrRyKqnM2hRVWKIIKpTvlu7TD1Se/G/g\nm6VxdXi02oc+7d6Q18SXmqHjFCaxh73HiEqwarofgRKXrVWupruUv/5//nIXeNWC\nu9GuFWYEug5Vj0lw7SoVZC3B0fsbVjQGHEpl4ybc6aCAleuyndWbaa+HXEmSr/d6\nsVjSu2F1d/OCPoeZ9U3Q5lLzLwpV67oXY1dLzwSLu17KiP6bzyqsopHAaac34rZ1\nIa5m722Sdv55LA2JXX0k/D9QXduyLVnmzEhAvzyiyUKo9hMAhFwjrwIDAQABo0Ew\nPzAeBgNVHREEFzAVghN1cmt1bmR3ZWIudXJrdW5kLnNlMB0GA1UdDgQWBBTWCFlV\niTs20fc8BncRSVYrqXdS8jANBgkqhkiG9w0BAQUFAAOCAQEAQnPM81umUT9cokgv\nd7qjClP5S4ufKMgscVIu5umiV3aOSpDTsCAxvfSp3z5tywF1EQ/6FRrTSVIZiS+e\nwbR9+JEVOnxV3D81Xv4p23zj0p1g2d6gdlpfbOmGiCWqx75QosHqfP6ENFDFCwxl\nCasucZK1gv2h3Sat232poJYdoDcmDKZt7DRIcs88k+85/TG3CnB6LUWjv35NrMGq\nYcF3FDUEnWCpXVoOF3bB84M9zlrggkBlhid47DpJZ54EcMl8qrMQmOJDcw4/1Jc1\nidGXqKfeI6/eA5cV6Kvyy63eSji0hOvD1CKIhufI3w6R1+DU0pSVsv+t7ND9KWBl\ngEln3A=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=urkundweb.urkund.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "urkundweb.urkund.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJAL61GoCfz8heMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE3Vya3VuZHdlYi51cmt1bmQuc2UwHhcNMDkwMzAzMTU1NjQyWhcNMTkwMzAx\nMTU1NjQyWjAeMRwwGgYDVQQDExN1cmt1bmR3ZWIudXJrdW5kLnNlMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA3RwMFJu304/B3qtfLT8r2vKBOugNcfyZ\nEDsf4Q4ZHFDFhWOh6VAuywjpixKBm/LYCrRyKqnM2hRVWKIIKpTvlu7TD1Se/G/g\nm6VxdXi02oc+7d6Q18SXmqHjFCaxh73HiEqwarofgRKXrVWupruUv/5//nIXeNWC\nu9GuFWYEug5Vj0lw7SoVZC3B0fsbVjQGHEpl4ybc6aCAleuyndWbaa+HXEmSr/d6\nsVjSu2F1d/OCPoeZ9U3Q5lLzLwpV67oXY1dLzwSLu17KiP6bzyqsopHAaac34rZ1\nIa5m722Sdv55LA2JXX0k/D9QXduyLVnmzEhAvzyiyUKo9hMAhFwjrwIDAQABo0Ew\nPzAeBgNVHREEFzAVghN1cmt1bmR3ZWIudXJrdW5kLnNlMB0GA1UdDgQWBBTWCFlV\niTs20fc8BncRSVYrqXdS8jANBgkqhkiG9w0BAQUFAAOCAQEAQnPM81umUT9cokgv\nd7qjClP5S4ufKMgscVIu5umiV3aOSpDTsCAxvfSp3z5tywF1EQ/6FRrTSVIZiS+e\nwbR9+JEVOnxV3D81Xv4p23zj0p1g2d6gdlpfbOmGiCWqx75QosHqfP6ENFDFCwxl\nCasucZK1gv2h3Sat232poJYdoDcmDKZt7DRIcs88k+85/TG3CnB6LUWjv35NrMGq\nYcF3FDUEnWCpXVoOF3bB84M9zlrggkBlhid47DpJZ54EcMl8qrMQmOJDcw4/1Jc1\nidGXqKfeI6/eA5cV6Kvyy63eSji0hOvD1CKIhufI3w6R1+DU0pSVsv+t7ND9KWBl\ngEln3A=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=urkundweb.urkund.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://secure.urkund.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://secure.urkund.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://secure.urkund.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://secure.urkund.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://secure.urkund.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://secure.urkund.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://secure.urkund.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://secure.urkund.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://secure.urkund.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://portalservices.miun.se/shibboleth",
    {
      "entity_id": "https://portalservices.miun.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://portalservices.miun.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://portalservices.miun.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://portalservices.miun.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://portalservices.miun.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://portalservices.miun.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "rosalind.miun.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAIIQvcjXtAm5MA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEHJvc2FsaW5kLm1pdW4uc2UwHhcNMTMwNTI5MjIyOTMzWhcNMjMwNTI3MjIy\nOTMzWjAbMRkwFwYDVQQDExByb3NhbGluZC5taXVuLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAnT/D8qoQnoI3I8898z/vg4a/LlQfYv/DkRIAqbxZ\n8JuXcBHCflsTlUas/2pTtNY+FJwRLF4IKLJojaOF5vsg3Xcd7Y8jrC4EMvUfkoVK\n5cTx/uz6Xf4ejmAMDDmYHvWqyIRfERVvSARwTjpRX4Gt94so2n6vdJErP0Rl61Ho\nI3nJwSlcRP5Wn1Y3l/uw1r/ZhUUv6yGgWVWXmV+6qlH3rq3nULNrzohHbuODr6rR\nAUOik1SaiERnx5koy7/CF12MwDdQAYp1+YFL2xT6+vcF3FwhDppL7lkoFrd0ihNI\nX/hdkecVrpnj5ykle7g7xABsJEOTfPiGBOefkR0y2AXtpQIDAQABoz4wPDAbBgNV\nHREEFDASghByb3NhbGluZC5taXVuLnNlMB0GA1UdDgQWBBQ3oI6Zshdu4dz7v2+6\nxa5Rvh8KBTANBgkqhkiG9w0BAQUFAAOCAQEAikkMrClX/tjmENc+SIAgnKjYS8Z8\nmdEJGtRZr47tcc/Qb84gfslLvfa6bJuzzWeVvoXj1+92m8tcM32s45yUiCmmL9Oq\nqJxdaTqatW5za2RdaI2Kr0pIO0z2UUfbYd5i5wyLKsp85VMk3RlKsEnyaq8RaYK8\n6qz4HKXoYiX7gqwlrVRDOZr0vvNhe8vcCYihxnLEv5WolJzM4wqz0CoKKO/ZwrW3\nXEJzWYfbXhiq0WDNbmFY7WWKlfTjKwD3088PGcA8/AdosEB66Xs0K3PTVyJWcB3r\nTeyoCQ24KR1X/NqeCJndNrh9MFFO1D14hF64NWpRKRybaB2lzrgIiIWvlw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=rosalind.miun.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "rosalind.miun.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAIIQvcjXtAm5MA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEHJvc2FsaW5kLm1pdW4uc2UwHhcNMTMwNTI5MjIyOTMzWhcNMjMwNTI3MjIy\nOTMzWjAbMRkwFwYDVQQDExByb3NhbGluZC5taXVuLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAnT/D8qoQnoI3I8898z/vg4a/LlQfYv/DkRIAqbxZ\n8JuXcBHCflsTlUas/2pTtNY+FJwRLF4IKLJojaOF5vsg3Xcd7Y8jrC4EMvUfkoVK\n5cTx/uz6Xf4ejmAMDDmYHvWqyIRfERVvSARwTjpRX4Gt94so2n6vdJErP0Rl61Ho\nI3nJwSlcRP5Wn1Y3l/uw1r/ZhUUv6yGgWVWXmV+6qlH3rq3nULNrzohHbuODr6rR\nAUOik1SaiERnx5koy7/CF12MwDdQAYp1+YFL2xT6+vcF3FwhDppL7lkoFrd0ihNI\nX/hdkecVrpnj5ykle7g7xABsJEOTfPiGBOefkR0y2AXtpQIDAQABoz4wPDAbBgNV\nHREEFDASghByb3NhbGluZC5taXVuLnNlMB0GA1UdDgQWBBQ3oI6Zshdu4dz7v2+6\nxa5Rvh8KBTANBgkqhkiG9w0BAQUFAAOCAQEAikkMrClX/tjmENc+SIAgnKjYS8Z8\nmdEJGtRZr47tcc/Qb84gfslLvfa6bJuzzWeVvoXj1+92m8tcM32s45yUiCmmL9Oq\nqJxdaTqatW5za2RdaI2Kr0pIO0z2UUfbYd5i5wyLKsp85VMk3RlKsEnyaq8RaYK8\n6qz4HKXoYiX7gqwlrVRDOZr0vvNhe8vcCYihxnLEv5WolJzM4wqz0CoKKO/ZwrW3\nXEJzWYfbXhiq0WDNbmFY7WWKlfTjKwD3088PGcA8/AdosEB66Xs0K3PTVyJWcB3r\nTeyoCQ24KR1X/NqeCJndNrh9MFFO1D14hF64NWpRKRybaB2lzrgIiIWvlw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=rosalind.miun.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://portalservices.miun.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://portalservices.miun.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://portalservices.miun.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://portalservices.miun.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://portalservices.miun.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://portalservices.miun.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://portalservices.miun.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://portalservices.miun.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://portalservices.miun.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://portalservices.miun.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp1.utpa.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "zecca@utpa.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Frank Zecca"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jnunez@utpa.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jaime Nunez"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@utpa.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp1.utpa.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.utpa.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.utpa.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUdKkzW01lvdyal9wyJMIhLH5ZWwQwDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNaWRwMS51dHBhLmVkdTAeFw0xMDA3MjEyMTI1MTlaFw0z\nMDA3MjEyMTI1MTlaMBgxFjAUBgNVBAMTDWlkcDEudXRwYS5lZHUwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCNr/xhq+UAztUMJytS7SVqGJx2gaxW0xNU\nOfT5OPFA12tLUPYXnf3WA/fHv8WD3jgPNgGSQPgYX0WZaOYr19o6/+iQtuLCPaXD\nLuDBjY3TmflArRS7uRzUy5nl98QJcIhlssp60sDWhz/uPI8BCnKLvo35KisJ+aLH\nYGB1tzenVmR6kjuZA1VNC3lmsPjTBqAc8yPm7w9jk+ZmHbmW5fDWetnMmxpHzjQf\nUlP55ddm30sxZxAGC9/N253RVKuPy8NvYuVzvCYk86AS2mVmvneJ1S2KT77GCAmr\nx1ags31zP4B/VJIsWQ9znlfAgpcrVVt1jcYFd0EVBiIoBmK6DkFPAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDWlkcDEudXRwYS5lZHWGJGh0dHBzOi8vaWRwMS51dHBhLmVk\ndS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQURat8zqRPL/gEEcB95AU0ZGwRBu0w\nDQYJKoZIhvcNAQEFBQADggEBAIP6l5tAs2w6Otty6UaPb1MghRRx/75GLW7lYmvV\n1W/Yfz6cNuhqwimY3p84NvHbwFnQFFlVIrzImDoYPuLoQwrUAahDZGsdgMZ51apV\nLsI6TJr7WmTxJEGZSQq7iRC6Kf+XyV7/Qa/1wPR0iy90O0/4yNkzlQIoRoIPUK7+\nMMxVRpFaUpwJwIpNA3WID0JTeDaJ2YT9OFLgUeS/N0B2lIp5ClPktl71LJkwpv4C\noie3XK/NlMnqzjcF/dvCwDhsSHE1a6eSOJTHeP8y49js+sV4i4wcl0Inbf+8+EOh\nDzZqtIw6JsdQP1xYSJp98NUDw6qHGVfuUGUNLW1KeKmwsio="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utpa.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp1.utpa.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp1.utpa.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp1.utpa.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp1.utpa.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.utpa.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.utpa.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utpa.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.utpa.edu/dit"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.utpa.edu/policies/privacy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Texas-Pan American"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUdKkzW01lvdyal9wyJMIhLH5ZWwQwDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNaWRwMS51dHBhLmVkdTAeFw0xMDA3MjEyMTI1MTlaFw0z\nMDA3MjEyMTI1MTlaMBgxFjAUBgNVBAMTDWlkcDEudXRwYS5lZHUwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCNr/xhq+UAztUMJytS7SVqGJx2gaxW0xNU\nOfT5OPFA12tLUPYXnf3WA/fHv8WD3jgPNgGSQPgYX0WZaOYr19o6/+iQtuLCPaXD\nLuDBjY3TmflArRS7uRzUy5nl98QJcIhlssp60sDWhz/uPI8BCnKLvo35KisJ+aLH\nYGB1tzenVmR6kjuZA1VNC3lmsPjTBqAc8yPm7w9jk+ZmHbmW5fDWetnMmxpHzjQf\nUlP55ddm30sxZxAGC9/N253RVKuPy8NvYuVzvCYk86AS2mVmvneJ1S2KT77GCAmr\nx1ags31zP4B/VJIsWQ9znlfAgpcrVVt1jcYFd0EVBiIoBmK6DkFPAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDWlkcDEudXRwYS5lZHWGJGh0dHBzOi8vaWRwMS51dHBhLmVk\ndS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQURat8zqRPL/gEEcB95AU0ZGwRBu0w\nDQYJKoZIhvcNAQEFBQADggEBAIP6l5tAs2w6Otty6UaPb1MghRRx/75GLW7lYmvV\n1W/Yfz6cNuhqwimY3p84NvHbwFnQFFlVIrzImDoYPuLoQwrUAahDZGsdgMZ51apV\nLsI6TJr7WmTxJEGZSQq7iRC6Kf+XyV7/Qa/1wPR0iy90O0/4yNkzlQIoRoIPUK7+\nMMxVRpFaUpwJwIpNA3WID0JTeDaJ2YT9OFLgUeS/N0B2lIp5ClPktl71LJkwpv4C\noie3XK/NlMnqzjcF/dvCwDhsSHE1a6eSOJTHeP8y49js+sV4i4wcl0Inbf+8+EOh\nDzZqtIw6JsdQP1xYSJp98NUDw6qHGVfuUGUNLW1KeKmwsio="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Texas-Pan American"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utpa.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Texas-Pan American"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayf.aau.dk",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayf.aau.dk",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2010-12-06T14:25:53Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayf.aau.dk/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aau.dk"
              },
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Aalborg Universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Aalborg University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Aalborg Universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Aalborg University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "aau.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICsDCCAZgCAQcwDQYJKoZIhvcNAQELBQAwHjEcMBoGA1UEAwwTaHR0cHM6Ly93\nYXlmLmFhdS5kazAeFw0xNTAxMDEwMDAwMDBaFw0yNTEyMzEyMzU5NTlaMB4xHDAa\nBgNVBAMME2h0dHBzOi8vd2F5Zi5hYXUuZGswggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQDHiAwKahBTuI4Z+IJ1rgOeEiCCy3bR9QIe3BpCsejFCU5rSzkW\nANqVuc1PDfp0JdIZhrPXsmDJQMmidPCGPIDQKo+bk+af3+EUFS/I/+35sSBX2vf+\nh1DHvZV9jsznmpSVjp7HZ/WoPWBykWBJO0AOVmzB5zlaqkS36J76+wxerwdpuExV\nnYSNd73S+AyT/EZ+tXAO+6lQ8FL/YMlJnUkSaSqLSHFy01D2qBNmYRwBpCS6/dUZ\nyxi0t5j8ghKUD4BHOZVavn65J62cJdXiOcMRyUAIp57GXQrL63KtrjIcXddq+CZy\nZ5t37EdUOIz42joFcy73MFOntynlKEvOw1BJAgMBAAEwDQYJKoZIhvcNAQELBQAD\nggEBAEurW2Zf6aCXWNDIV04ht39P4MlhI8ut1QL0TPoAjUKlTk9ybvxQcN1XkOVQ\nZYXsyhHWjWhmpBpZS7KaAbJzhBUCMpwAdsDOxLsF7+VZo3BPVGnH2lKSHPCDCGex\n++rithjuctIdtKqlK5/82/xb7/eftgZycF+slf3cFosOAAYb3oprtWVEx0KUmEq8\nB2TSJQMdX/r6TW7h69X94MOXA8ad4Ukgo0rnhZhbcUtURQeI51RFtfVGWu1g9ZDd\nx/eM6He+xeVltiNDy7VLsdrvA4KVYDZpR5ZOzDL6pE5u+yb3Wg8rgUOoZUcPVB47\nYNCobCjLM8GtgKPZGSBhP+avu6w="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Aalborg Universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Aalborg University"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aau.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.en.aau.dk"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Aalborg Universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Aalborg University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.uusuvote.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.uusuvote.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-10-17T09:15:38Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Ulster SU Voting"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uusuvote.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.uusuvote.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.uusuvote.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.uusuvote.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.uusuvote.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.uusuvote.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.uusuvote.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.uusuvote.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.uusuvote.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.uusuvote.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.uusuvote.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.uusuvote.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.uusuvote.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.uusuvote.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.uusuvote.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.uusuvote.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.uusuvote.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.arts.ac.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@arts.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UAL Service desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shib-support@arts.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.arts.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID5DCCAswCCQD996epTPDENDANBgkqhkiG9w0BAQUFADCBszELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFzAVBgNVBAgMDkdyZWF0ZXIgTG9uZG9uMQ8wDQYDVQQHDAZMb25kb24xJzAl\n\t\t\t\t\t\tBgNVBAoMHlVuaXZlcnNpdHkgb2YgdGhlIEFydHMsIExvbmRvbjEUMBIGA1UECwwL\n\t\t\t\t\t\tSVQgU2VydmljZXMxFzAVBgNVBAMMDmlkcC5hcnRzLmFjLnVrMSIwIAYJKoZIhvcN\n\t\t\t\t\t\tAQkBFhNzc2xhZG1pbkBhcnRzLmFjLnVrMB4XDTE0MDEwODExMjAzMVoXDTM0MDEy\n\t\t\t\t\t\tMzExMjAzMVowgbMxCzAJBgNVBAYTAkdCMRcwFQYDVQQIDA5HcmVhdGVyIExvbmRv\n\t\t\t\t\t\tbjEPMA0GA1UEBwwGTG9uZG9uMScwJQYDVQQKDB5Vbml2ZXJzaXR5IG9mIHRoZSBB\n\t\t\t\t\t\tcnRzLCBMb25kb24xFDASBgNVBAsMC0lUIFNlcnZpY2VzMRcwFQYDVQQDDA5pZHAu\n\t\t\t\t\t\tYXJ0cy5hYy51azEiMCAGCSqGSIb3DQEJARYTc3NsYWRtaW5AYXJ0cy5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM6O2rZ7nuoylsc2Zd9Mahbc\n\t\t\t\t\t\tyvGGqZMmx+mO414AqbuMn4R0kat5rKpuaq2kj/M18NBJaNti2UzYBvfEx+SPOZDl\n\t\t\t\t\t\tzCFAup8NqJwZXGPP5NGNXeAFQWCzIfDZpcOqrrjDA5/dJtDpIST4kGLaFUUwfmE3\n\t\t\t\t\t\t6Ikpye28h3v4oYPH4bxGkodWsVkU2AMAObbsFu2C5FxRP9jXE42q7AjRyZNOM5jt\n\t\t\t\t\t\tizy1jjFEhdsU1gYJyaN/XEpMZA2x1h+t+DcCEqlp9+BFn24t2krubxfXo6fy/zqH\n\t\t\t\t\t\ttUPPMHElAALmzFZyhz4BMtfxGmuYu5+5nROjz7wh0QANgo5s2chALSVBhN1coMsC\n\t\t\t\t\t\tAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAvL41pZYkDiD0qBQK+ndeXOsBSQbHXLEl\n\t\t\t\t\t\tWwQttoLoo23kRPU+Q1guFwk2pIgKb6SDSSflwrT+SjeCAmNOnBE5+J2fXqynj/CW\n\t\t\t\t\t\tup2U9ejHg5ZEn4GPwLOftqycM/2tOzxjY/6/5NbM+BEZs+T15XqhsBQacPMg2PSJ\n\t\t\t\t\t\ti+e8IPQeKWZlpBRf4NMghdfb7+vfTpDqOFB4kik+VesdEBE/zgGSTdcUNaAB1Hqq\n\t\t\t\t\t\t+QSJKGU5LkUlhzDceN+QA/RuIuTUF0VSi283LNzyyp2q9ya+mv7UYVaGJs7AYuNR\n\t\t\t\t\t\tmUNMMO4EcXmyJkn6gSTesu0OCj76227/ss3Ni3p+nehxcBY9R/olXg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "arts.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.arts.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.arts.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.arts.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.arts.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.arts.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.arts.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.arts.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.arts.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "arts.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID5DCCAswCCQD996epTPDENDANBgkqhkiG9w0BAQUFADCBszELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFzAVBgNVBAgMDkdyZWF0ZXIgTG9uZG9uMQ8wDQYDVQQHDAZMb25kb24xJzAl\n\t\t\t\t\t\tBgNVBAoMHlVuaXZlcnNpdHkgb2YgdGhlIEFydHMsIExvbmRvbjEUMBIGA1UECwwL\n\t\t\t\t\t\tSVQgU2VydmljZXMxFzAVBgNVBAMMDmlkcC5hcnRzLmFjLnVrMSIwIAYJKoZIhvcN\n\t\t\t\t\t\tAQkBFhNzc2xhZG1pbkBhcnRzLmFjLnVrMB4XDTE0MDEwODExMjAzMVoXDTM0MDEy\n\t\t\t\t\t\tMzExMjAzMVowgbMxCzAJBgNVBAYTAkdCMRcwFQYDVQQIDA5HcmVhdGVyIExvbmRv\n\t\t\t\t\t\tbjEPMA0GA1UEBwwGTG9uZG9uMScwJQYDVQQKDB5Vbml2ZXJzaXR5IG9mIHRoZSBB\n\t\t\t\t\t\tcnRzLCBMb25kb24xFDASBgNVBAsMC0lUIFNlcnZpY2VzMRcwFQYDVQQDDA5pZHAu\n\t\t\t\t\t\tYXJ0cy5hYy51azEiMCAGCSqGSIb3DQEJARYTc3NsYWRtaW5AYXJ0cy5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM6O2rZ7nuoylsc2Zd9Mahbc\n\t\t\t\t\t\tyvGGqZMmx+mO414AqbuMn4R0kat5rKpuaq2kj/M18NBJaNti2UzYBvfEx+SPOZDl\n\t\t\t\t\t\tzCFAup8NqJwZXGPP5NGNXeAFQWCzIfDZpcOqrrjDA5/dJtDpIST4kGLaFUUwfmE3\n\t\t\t\t\t\t6Ikpye28h3v4oYPH4bxGkodWsVkU2AMAObbsFu2C5FxRP9jXE42q7AjRyZNOM5jt\n\t\t\t\t\t\tizy1jjFEhdsU1gYJyaN/XEpMZA2x1h+t+DcCEqlp9+BFn24t2krubxfXo6fy/zqH\n\t\t\t\t\t\ttUPPMHElAALmzFZyhz4BMtfxGmuYu5+5nROjz7wh0QANgo5s2chALSVBhN1coMsC\n\t\t\t\t\t\tAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAvL41pZYkDiD0qBQK+ndeXOsBSQbHXLEl\n\t\t\t\t\t\tWwQttoLoo23kRPU+Q1guFwk2pIgKb6SDSSflwrT+SjeCAmNOnBE5+J2fXqynj/CW\n\t\t\t\t\t\tup2U9ejHg5ZEn4GPwLOftqycM/2tOzxjY/6/5NbM+BEZs+T15XqhsBQacPMg2PSJ\n\t\t\t\t\t\ti+e8IPQeKWZlpBRf4NMghdfb7+vfTpDqOFB4kik+VesdEBE/zgGSTdcUNaAB1Hqq\n\t\t\t\t\t\t+QSJKGU5LkUlhzDceN+QA/RuIuTUF0VSi283LNzyyp2q9ya+mv7UYVaGJs7AYuNR\n\t\t\t\t\t\tmUNMMO4EcXmyJkn6gSTesu0OCj76227/ss3Ni3p+nehxcBY9R/olXg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of the Arts London"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.arts.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of the Arts London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.bbaw.de/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Zimmer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:zimmer@bbaw.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kai"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Krauth"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:krauth@bbaw.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dr. Wolf-Hagen"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Zimmer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:zimmer@bbaw.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kai"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.bbaw.de/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-03-13T16:23:00Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://clarin.eu/category/clarin-member"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Berlin-Brandenburgische Akademie der Wissenschaften"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Berlin-Brandenburgische Akademie der Wissenschaften"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bbaw.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bbaw.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e209"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e209"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.bbaw.de/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.bbaw.de/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.bbaw.de/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.bbaw.de/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "BBAW - CLARIN Dienste"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "BBAW - CLARIN services"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Verschiedene Dienste der Berlin-Brandenburgischen Akademie der Wissenschaften (BBAW) im Rahmen der CLARIN-Initiative."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Various services provided by the Berlin-Brandenburg Academy of Sciences and Humanities (BBAW) in the context of the CLARIN initiative."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth.bbaw.de/Shibboleth.sso/DiscoJuice",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.bbaw.de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.bbaw.de"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "BBAW - CLARIN Dienste"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "BBAW - CLARIN services"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Verschiedene Dienste der Berlin-Brandenburgischen Akademie der Wissenschaften (BBAW) im Rahmen der CLARIN-Initiative."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Various services provided by the Berlin-Brandenburg Academy of Sciences and Humanities (BBAW) in the context of the CLARIN initiative."
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth.bbaw.de/bbaw_logo.png",
                    "height": "104",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "234"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://shibboleth.bbaw.de/privacy.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shibboleth.bbaw.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF3TCCBMWgAwIBAgIHGFtty9nuvzANBgkqhkiG9w0BAQsFADCBnDELMAkGA1UE\nBhMCREUxPDA6BgNVBAoTM0Jlcmxpbi1CcmFuZGVuYnVyZ2lzY2hlIEFrYWRlbWll\nIGRlciBXaXNzZW5zY2hhZnRlbjEgMB4GA1UECxMXSW5mb3JtYXRpb25zdGVjaG5v\nbG9naWUxEjAQBgNVBAMTCUJCQVctQ0EgMTEZMBcGCSqGSIb3DQEJARYKY2FAYmJh\ndy5kZTAeFw0xNDEwMTMxNTMxMDdaFw0xOTA3MDkyMzU5MDBaMIGKMQswCQYDVQQG\nEwJERTEPMA0GA1UECBMGQmVybGluMQ8wDQYDVQQHEwZCZXJsaW4xPDA6BgNVBAoT\nM0Jlcmxpbi1CcmFuZGVuYnVyZ2lzY2hlIEFrYWRlbWllIGRlciBXaXNzZW5zY2hh\nZnRlbjEbMBkGA1UEAxMSc2hpYmJvbGV0aC5iYmF3LmRlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAtciZovXzGD+K7C5bwgQl29CGss8jg8NoLco1C+h7\nREVbgOZo9ipf4OUoI8XieicXewor2hTF89Iy5nt/HuTQuKDW8q3edn+C/DNJgu4B\n0gmdZmZ+ubXcOd/1hnjRRLS9wxvgq2Q+mBLZwV8wMMJA/tEkO1xd0yGAysl4tcu2\nBcV/2SM+oI9rdWNuGK2m4lOsouEi0mIvm9v4aJBIfknOXm0cfC7xJB1fV5Q59gBL\n74PYTB99XKjQ3jVTzu3j1lOq9UgwbhYNXOiw2rWT2wY64LFAuNrk2j0tFnIIBLYM\nws2DLo4AXOeDUR6TY5xWfMRg6rHEKYY8s/ggeEj5KG+HNwIDAQABo4ICMjCCAi4w\nTwYDVR0gBEgwRjARBg8rBgEEAYGtIYIsAQEEAwIwEQYPKwYBBAGBrSGCLAIBBAMB\nMA8GDSsGAQQBga0hgiwBAQQwDQYLKwYBBAGBrSGCLB4wCQYDVR0TBAIwADALBgNV\nHQ8EBAMCBeAwHQYDVR0lBBYwFAYIKwYBBQUHAwIGCCsGAQUFBwMBMB0GA1UdDgQW\nBBTr7kmL7423Mx9V5mu8Ukx5vyME0zAfBgNVHSMEGDAWgBSMpo/xPxQ7ArX5J1RM\nqzyh2BuQmDAdBgNVHREEFjAUghJzaGliYm9sZXRoLmJiYXcuZGUweQYDVR0fBHIw\ncDA2oDSgMoYwaHR0cDovL2NkcDEucGNhLmRmbi5kZS9iYmF3LWNhL3B1Yi9jcmwv\nY2FjcmwuY3JsMDagNKAyhjBodHRwOi8vY2RwMi5wY2EuZGZuLmRlL2JiYXctY2Ev\ncHViL2NybC9jYWNybC5jcmwwgckGCCsGAQUFBwEBBIG8MIG5MDMGCCsGAQUFBzAB\nhidodHRwOi8vb2NzcC5wY2EuZGZuLmRlL09DU1AtU2VydmVyL09DU1AwQAYIKwYB\nBQUHMAKGNGh0dHA6Ly9jZHAxLnBjYS5kZm4uZGUvYmJhdy1jYS9wdWIvY2FjZXJ0\nL2NhY2VydC5jcnQwQAYIKwYBBQUHMAKGNGh0dHA6Ly9jZHAyLnBjYS5kZm4uZGUv\nYmJhdy1jYS9wdWIvY2FjZXJ0L2NhY2VydC5jcnQwDQYJKoZIhvcNAQELBQADggEB\nAIcuZcIEBKtbbf/OOTxBfEiZ2iGfu3kLO2QXYR5oqh6D7ZVjrjXfWjyCR6beFosY\nM/2YkWIzRwfI/DAwXhiwXByqyYFcB6ICnqtIenuxgrhgcZcY5nOrV5NJ+kS8ivv8\njLdayhH+CBCA/UpDbyujMdeVjlJWPwaSacD51FIm6Ao3T+DBdXArNSphcGV+y2jD\n5JLMDjRaj/g29jQuJNhTvNajJFfVdNZt8KPEbYvJwwOk9rD9P3BEyAT9At/V6LyY\ngP+LmoAAhHE052Fg3khXrQ8qLV5ubP7DKZtIWA7nGg8v7/9iynjoUJ6yZn8Gx4s4\nWdNzDxmjE9EyFPvbQdfnOkE="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=shibboleth.bbaw.de,O=Berlin-Brandenburgische Akademie der Wissenschaften,L=Berlin,ST=Berlin,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shibboleth.bbaw.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF3TCCBMWgAwIBAgIHGFtty9nuvzANBgkqhkiG9w0BAQsFADCBnDELMAkGA1UE\nBhMCREUxPDA6BgNVBAoTM0Jlcmxpbi1CcmFuZGVuYnVyZ2lzY2hlIEFrYWRlbWll\nIGRlciBXaXNzZW5zY2hhZnRlbjEgMB4GA1UECxMXSW5mb3JtYXRpb25zdGVjaG5v\nbG9naWUxEjAQBgNVBAMTCUJCQVctQ0EgMTEZMBcGCSqGSIb3DQEJARYKY2FAYmJh\ndy5kZTAeFw0xNDEwMTMxNTMxMDdaFw0xOTA3MDkyMzU5MDBaMIGKMQswCQYDVQQG\nEwJERTEPMA0GA1UECBMGQmVybGluMQ8wDQYDVQQHEwZCZXJsaW4xPDA6BgNVBAoT\nM0Jlcmxpbi1CcmFuZGVuYnVyZ2lzY2hlIEFrYWRlbWllIGRlciBXaXNzZW5zY2hh\nZnRlbjEbMBkGA1UEAxMSc2hpYmJvbGV0aC5iYmF3LmRlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAtciZovXzGD+K7C5bwgQl29CGss8jg8NoLco1C+h7\nREVbgOZo9ipf4OUoI8XieicXewor2hTF89Iy5nt/HuTQuKDW8q3edn+C/DNJgu4B\n0gmdZmZ+ubXcOd/1hnjRRLS9wxvgq2Q+mBLZwV8wMMJA/tEkO1xd0yGAysl4tcu2\nBcV/2SM+oI9rdWNuGK2m4lOsouEi0mIvm9v4aJBIfknOXm0cfC7xJB1fV5Q59gBL\n74PYTB99XKjQ3jVTzu3j1lOq9UgwbhYNXOiw2rWT2wY64LFAuNrk2j0tFnIIBLYM\nws2DLo4AXOeDUR6TY5xWfMRg6rHEKYY8s/ggeEj5KG+HNwIDAQABo4ICMjCCAi4w\nTwYDVR0gBEgwRjARBg8rBgEEAYGtIYIsAQEEAwIwEQYPKwYBBAGBrSGCLAIBBAMB\nMA8GDSsGAQQBga0hgiwBAQQwDQYLKwYBBAGBrSGCLB4wCQYDVR0TBAIwADALBgNV\nHQ8EBAMCBeAwHQYDVR0lBBYwFAYIKwYBBQUHAwIGCCsGAQUFBwMBMB0GA1UdDgQW\nBBTr7kmL7423Mx9V5mu8Ukx5vyME0zAfBgNVHSMEGDAWgBSMpo/xPxQ7ArX5J1RM\nqzyh2BuQmDAdBgNVHREEFjAUghJzaGliYm9sZXRoLmJiYXcuZGUweQYDVR0fBHIw\ncDA2oDSgMoYwaHR0cDovL2NkcDEucGNhLmRmbi5kZS9iYmF3LWNhL3B1Yi9jcmwv\nY2FjcmwuY3JsMDagNKAyhjBodHRwOi8vY2RwMi5wY2EuZGZuLmRlL2JiYXctY2Ev\ncHViL2NybC9jYWNybC5jcmwwgckGCCsGAQUFBwEBBIG8MIG5MDMGCCsGAQUFBzAB\nhidodHRwOi8vb2NzcC5wY2EuZGZuLmRlL09DU1AtU2VydmVyL09DU1AwQAYIKwYB\nBQUHMAKGNGh0dHA6Ly9jZHAxLnBjYS5kZm4uZGUvYmJhdy1jYS9wdWIvY2FjZXJ0\nL2NhY2VydC5jcnQwQAYIKwYBBQUHMAKGNGh0dHA6Ly9jZHAyLnBjYS5kZm4uZGUv\nYmJhdy1jYS9wdWIvY2FjZXJ0L2NhY2VydC5jcnQwDQYJKoZIhvcNAQELBQADggEB\nAIcuZcIEBKtbbf/OOTxBfEiZ2iGfu3kLO2QXYR5oqh6D7ZVjrjXfWjyCR6beFosY\nM/2YkWIzRwfI/DAwXhiwXByqyYFcB6ICnqtIenuxgrhgcZcY5nOrV5NJ+kS8ivv8\njLdayhH+CBCA/UpDbyujMdeVjlJWPwaSacD51FIm6Ao3T+DBdXArNSphcGV+y2jD\n5JLMDjRaj/g29jQuJNhTvNajJFfVdNZt8KPEbYvJwwOk9rD9P3BEyAT9At/V6LyY\ngP+LmoAAhHE052Fg3khXrQ8qLV5ubP7DKZtIWA7nGg8v7/9iynjoUJ6yZn8Gx4s4\nWdNzDxmjE9EyFPvbQdfnOkE="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=shibboleth.bbaw.de,O=Berlin-Brandenburgische Akademie der Wissenschaften,L=Berlin,ST=Berlin,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.bbaw.de/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.bbaw.de/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.bbaw.de/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.bbaw.de/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.bbaw.de/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.bbaw.de/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.bbaw.de/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth.bbaw.de/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.bbaw.de/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.bbaw.de/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-p00.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-p00.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;p00"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;p00"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-p00.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-p00.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQTCCAimgAwIBAgIJALxPd7mRqLHWMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2xhZG9rMy1wMDAubGFkb2sudW11LnNlMB4XDTE0MTAwNzE0NDUwN1oXDTI0\nMTAwNDE0NDUwN1owIjEgMB4GA1UEAxMXbGFkb2szLXAwMC5sYWRvay51bXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC5eQWoo0jvq5ezBDlf44cN\nsbWxAK+OkxeRrIgazZz3BgFO7F+RTuEFyWbVCuwjltGqhugKwXWG+Sw6hK1HCJh7\n7EhxlXiiFZjsl0UYIvh4fk2YDSHnFX1gvF/8SvUJ6y3XXfq+NFcm79wbw7JCcHon\nimO50gTfcX+f8vOEmx7T39vdCMJinwZFfgwdSAgKI2u99hF7Fh6MoREL69rWtOn5\nSMKu6aOMz61fxI0+mQw0YPpdix0z8q6qTgfgWa6q1TXo7a5hEvooCXbfvG0EcBt9\nWe59FKDHqOco4q8O7W/+CfTh3chrqvIgd1ySno4PUofrQpZx43U6jPUwIppDlmq3\nAgMBAAGjejB4MFcGA1UdEQRQME6CF2xhZG9rMy1wMDAubGFkb2sudW11LnNlhjNo\ndHRwczovL2xhZG9rMy1wMDAubGFkb2sudW11LnNlL3N0dWRlbnQtZnJvbnRlbmQt\nc3AwHQYDVR0OBBYEFPYqHe1zEaIMRzs3f0sxAtAwo7lwMA0GCSqGSIb3DQEBBQUA\nA4IBAQCvy0qQ/FqDy6C1g5ECxZViC8/VPRBKnlnVXzmUWSjbF7KMTbfsM/LXKs2z\nyqtu4vOZ3HjUyL8ZB0MUhvBRZZKJEU+ybkNRll71Lmi7G7pjF0lppFRNt0DIxQ4t\nB3ZmRqC36gtRXx9Sw3utpX3EPkUDh2ahit3dqXBF2befvQRgXLo6Bdcy0+2t1vzm\noIn5DFz+1jZCpTHuVuRKNJPVuks8RWzBV0QUgeiO9vzg8JMbyDJx0DU3azGuNrBH\nrJDif3ojo11aT4Nrn7xehC+cV0yIqTFPNiAuZ/MWyDUBH5MIw3blavnllojr8+PG\nUEpDZ+oqJxcdV7QpvC9PesO5oSvH"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-p00.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.twigonglow.com/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kemp"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pkemp@twig-world.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Patricia"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Munn"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dmunn@twig-world.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.twigonglow.com/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-11-22T15:15:58Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Twig World Limited: Glow Science"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.twigonglow.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Twig World Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.twigonglow.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.twigonglow.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.twigonglow.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.twigonglow.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.twigonglow.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.twigonglow.com/Shibboleth.sso/shibtest",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.twigonglow.com/Shibboleth.sso/Glow",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.twigonglow.com/Shibboleth.sso/RMUnify",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.twigonglow.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIJAMTlVAXkOmrZMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\n\t\t\t\t\t\tBAMTEnd3dy50d2lnb25nbG93LmNvbTAeFw0xMjExMTMxMTAxNDVaFw0yMjExMTEx\n\t\t\t\t\t\tMTAxNDVaMB0xGzAZBgNVBAMTEnd3dy50d2lnb25nbG93LmNvbTCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBAKZvpD5K0jQvz3y9mkhLylUzqC+bZrGmyuIE\n\t\t\t\t\t\t9LAdDXh/9LpxgxnY+an/FnIQzrKFLyw+4t8H1QSLWyTLK8MA8b6tJjBxznvUv8Qk\n\t\t\t\t\t\tIpBAmBXWSkPQSHgbIoTFivb6iIVJq9h7yLi0JM7GpM4SS/ed+JiYiBM1C89/iaks\n\t\t\t\t\t\ts1kpbN9TYrqN0YBkogTe1NIJMDp13SagmR2WjmnzQKtCH8z3DQDA3MrrP+KIbp5Z\n\t\t\t\t\t\tQm6Nlk+XQv51Mg5b/8qMgBoekB6cTI+HEIXJauJyPfCPL0hysnNUzR57BGG04ol4\n\t\t\t\t\t\tVx/eIKKvzRSwRowSGIxIcIGzUk9lg1PIt7RXPcTHANqppLGZIusCAwEAAaNqMGgw\n\t\t\t\t\t\tRwYDVR0RBEAwPoISd3d3LnR3aWdvbmdsb3cuY29thihodHRwczovL3d3dy50d2ln\n\t\t\t\t\t\tb25nbG93LmNvbS9zaGliYm9sZXRoLXNwMB0GA1UdDgQWBBRHiLe+VeAuCc/Ly0mK\n\t\t\t\t\t\tI5tvs+uuujANBgkqhkiG9w0BAQUFAAOCAQEAJZHQuo5dFz0F77boWcIjUTH9eHtH\n\t\t\t\t\t\tHUYbLsotM1Xin8k0vQIwkqQcIByBHLlM/ScVKku4u8a5maAawSr6IZVvBbpYgYsO\n\t\t\t\t\t\tO0GZpHD45GFBIMQsgd+tTGlHus/t0048J5j3GPqx1NTMGs80DnCXAq9fLKjpil4i\n\t\t\t\t\t\t/mfAfP6CSrguh2rCvVndSrTLIHJfQ+d6Up8h24LYKzhHVQmdqgsSQAWg1yUacFER\n\t\t\t\t\t\tud1Wodm6t+Nrbyh4XA3YbekaxHPRO9bBIjo+sncONDf6JfFL57s4i74LeZVOMeQC\n\t\t\t\t\t\tyFFf/Cs64qzIILqKQWM0wqZq1vOavCR+OhOTdyjjKejhDKb9CWLzXSuOFw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.twigonglow.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.twigonglow.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.twigonglow.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.twigonglow.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.twigonglow.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.twigonglow.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.twigonglow.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.twigonglow.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.twigonglow.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.twigonglow.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sdn-openstack.oit.duke.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rob@duke.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rob Carter"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shilen@duke.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shilen Patel"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sdn-openstack.oit.duke.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Duke University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.duke.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Duke University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sdn-openstack-dev-01.oit.duke.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "http://sdn-openstack-dev-01.oit.duke.edu:5000/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "OpenStack for Research"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKjCCAhKgAwIBAgIJAOJfno4EnLE6MA0GCSqGSIb3DQEBBQUAMCwxKjAoBgNV\nBAMTIXNkbi1vcGVuc3RhY2stZGV2LTAxLm9pdC5kdWtlLmVkdTAeFw0xNjAxMTIx\nODEyMTZaFw0yNjAxMDkxODEyMTZaMCwxKjAoBgNVBAMTIXNkbi1vcGVuc3RhY2st\nZGV2LTAxLm9pdC5kdWtlLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\nggEBAMVe4zmeL0wgsAe9egTdVQk3B6aqbsGc6PQ/twlFzMFDFc3hlC8RLw4YIpnx\n2ScFpuI1DVPqsKsC7l2wsXbBO7THYRGmmEjNjVbuYFXUC7mt8A4lluXzJjROJDBx\ndT6++d48bD81SnoLpU5wrr0JXiYNy3JxeVKshdGt9YutLLmlF91D4jOwxLt2s7op\nXXNBqspAHkZvK+TZIboUPHoycjHrFYW1xqjarwpTEpkfzyKmb12faqr78nWLISID\nUrd90Ysdwl+nPbg93Ce/zmpX1jVHnNb3zKhISYTk85uUgLYF0j6+jz9XDqZVCA7b\nBwlkwOFFG1yHMatuDRk+hlJ66DECAwEAAaNPME0wLAYDVR0RBCUwI4Ihc2RuLW9w\nZW5zdGFjay1kZXYtMDEub2l0LmR1a2UuZWR1MB0GA1UdDgQWBBSSiEcxZhDYi+9c\nSDTGY+oXd35CoDANBgkqhkiG9w0BAQUFAAOCAQEAKMnx2FRBy7I8kIJZy3TIuCEC\nIMqyOyCo7WxVBFcA3nJPurO2SNrvC2nNWG/WKvaga+ggMos5IcDiGwNPOtRiC3MS\nfApVKRbwBCb6vxkwnM3rtLzPVGL+5Hsmsxjk82Xy8m6+JubK0XTP4xkhrIwyqj3O\nCriPKh1LYjUQ7p2mF0qQnw0mFvkCgHgKeqx7llzFMKzxk+xAXDcnunXGRB2xVHDL\nJJ7lo9u+ITPEMRXy4dr9NjWXfHVDRBdIq12HG5OR+KBomJSSLoF4B/+Lw8e5UA4k\nhqZYCJefeTUol0vkdULhuiJHN1eaOWijZo9sbu1cYeHxwVXo1hN00PS4WuJ+hg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sdn-openstack-dev-01.oit.duke.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://sdn-openstack-dev-01.oit.duke.edu:5000/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://sdn-openstack-dev-01.oit.duke.edu:5000/v3/auth/OS-FEDERATION/websso/saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sdn-openstack.oit.duke.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://sdn-openstack.oit.duke.edu:5000/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://sdn-openstack.oit.duke.edu:5000/v3/auth/OS-FEDERATION/websso/saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "OpenStack for Research"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://gw-astronomy.org/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "uwm-help@gravity.phys.uwm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UWM CGCA Help"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "stephenb@uwm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Branson Stephens"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "anders15@uwm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Warren Anderson"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lsc-seccomm@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LIGO Scientific Collaboration Security Committee"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://gw-astronomy.org/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Wisconsin-Milwaukee"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uwm.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Wisconsin-Milwaukee"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://gw-astronomy.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://gw-astronomy.org/registry/pages/public/sp_info"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Gravitational Wave Astronomy Community Registry used to support collaboration across astronomy and astrophysics projects."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://gw-astronomy.org/registry/pages/public/privacy_info"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Gravitational Wave Astronomy Community Registry"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEWDCCA0CgAwIBAgIBPjANBgkqhkiG9w0BAQUFADCBhzETMBEGCgmSJomT8ixk\nARkWA29yZzEUMBIGCgmSJomT8ixkARkWBGxpZ28xDTALBgNVBAoTBExJR08xIDAe\nBgNVBAsTF0NlcnRpZmljYXRlIEF1dGhvcml0aWVzMRUwEwYDVQQLEwxXZWIgU2Vy\ndmljZXMxEjAQBgNVBAMTCUxJR08gQ0EgMTAeFw0xMTA0MjkxNzI0MTJaFw0yMTA0\nMjgxNzI0MTJaMGoxEzARBgoJkiaJk/IsZAEZFgNvcmcxFDASBgoJkiaJk/IsZAEZ\nFgRsaWdvMQ0wCwYDVQQKEwRMSUdPMRUwEwYDVQQLEwxXZWIgU2VydmljZXMxFzAV\nBgNVBAMTDmd1ZXN0LmxpZ28ub3JnMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\nCgKCAQEApxrDaMIRCnagFhhjD4rY47JBOHKjA4IS6EG1MvqG6kMXm73ZdYRhRraQ\nonVmFMUPPlkR5zTlok+qvb+Iy58s6PqguQe0Tz3eEnfRlVqLaXniKNGxkef5pXFY\nhndYXzkfeoclycdYZGwu12ANoG5wjADhYcWEuiyJKprfWXF/msa65rkczuMd5WFw\nlde6hnpZTXa6FaeYb1Hi8Me36pHFCU3DfhARdup7DQ4t3QDEttQY1mn/pnY6vd2o\noa/jmL1iHkJbTDT6+EWhk/3XdrC1tfo1VKQ+B4RebTyzRY8Wsgn3CAyAz9K5nA7w\naYBOYhK26Z6envlE+vXviDI89J/C7QIDAQABo4HqMIHnMAwGA1UdEwEB/wQCMAAw\nDgYDVR0PAQH/BAQDAgSwMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAZ\nBgNVHSAEEjAQMA4GDCsGAQQBgfpGAgECATA5BgNVHR8EMjAwMC6gLKAqhihodHRw\nOi8vY2EubGlnby5vcmcvNTQxNDA0YzMvNTQxNDA0YzMuY3JsMB8GA1UdIwQYMBaA\nFFJu3Xuqb4VcCCLTl5+tfyNWHmrRMDEGA1UdEQQqMCiCDmd1ZXN0LmxpZ28ub3Jn\ngRZzY290dC5rb3JhbmRhQGxpZ28ub3JnMA0GCSqGSIb3DQEBBQUAA4IBAQBXTyxj\nWEiIQ4kG8I9ujY9AssDMi63g9m4AT7uAm6mbNJVRaYkYVy7lnRi227fBjIXr8rku\ngfUhzwRULi9OUuY5eO713iB/urMn3mysch9R6heciYGzccnn5nN3gWrUN3kZ0AWd\nXaIE5G8rZOACTDp7SCVyNH1eZNkk6apK9LJgblo44XppU8gZk1OIzBzeknCuZhGz\n6Lnu58KItVKI+8w7FepUsXIdF6pHRLevhzW7d61QZ5iW8o2qW0TG24RDY4JJE45m\ny6qIv7HErgRcZZrxupRI6NfHLBxJx22n8rBD7gmVoCLXkAftIKQZ8pBKF4c74ErF\nxWUYS9G3JfMMW9UY"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gw-astronomy.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://gw-astronomy.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://gw-astronomy.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://gw-astronomy.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Gravitational Wave Astronomy Community Registry"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Gravitational Wave Astronomy Community Registry used to support collaboration across astronomy and astrophysics projects."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:displayName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:givenName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:mail",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:sn",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "http://adfs.stw.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs.stw.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-07-08T15:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/64b3a9ee71b20e9b46d4a6a5ac5e98ba",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Technologiestichting STW realiseert kennisoverdracht tussen technische wetenschappen en gebruikers. Dat doet zij door excellent technisch-wetenschappelijk onderzoek te financieren en bij elk project onderzoekers en gebruikers letterlijk bij elkaar te bren"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Technology Foundation STW realises knowledge transfer between the technical sciences and users. It does that by funding excellent technical sciences research and for each project literally bringing researchers and users together."
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/stw.png",
                    "height": "194",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "259"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Technologiestichting STW"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Technologiestichting STW"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Technologiestichting STW"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.stw.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Technologiestichting STW"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.shibboleth.net/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:contact@shibboleth.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth.Net Technical Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cantor"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cantor.2@osu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Scott"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Young"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ukfed@iay.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.shibboleth.net/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-01-06T16:22:29Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.net/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.net/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.net/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "shibboleth.net"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "An identity provider hosted and used by the\n\t\t\t\t\tdevelopers of Shibboleth."
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth.net/images/gryphon_64x82.png",
                    "height": "82",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Shibboleth.net"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAKyBWnv1/h1U11C7kHvV33FIrEsJMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB0xGzAZBgNVBAMTEmlkcC5zaGliYm9sZXRoLm5ldDAeFw0xMDEyMjkwMDA5\n\t\t\t\t\t\tMTlaFw0zMDEyMjkwMDA5MTlaMB0xGzAZBgNVBAMTEmlkcC5zaGliYm9sZXRoLm5l\n\t\t\t\t\t\tdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKjWAdpUx/82FUzrRMfA\n\t\t\t\t\t\tM63PkZZYCm3RnT3eiL+DeJcbGdcEJx/o+32vgHXJgJOBt14YdVam5GErIYgk4SGq\n\t\t\t\t\t\t5Z5RYl0PpQn6HQG/9prGnYCu6p5zfb0557o51Eh8TcVehS6Y2ruyCjAF0jgVMwh5\n\t\t\t\t\t\t/0Oh8EE9wG93pSpm70DAiiaTVCb8WoT1aZYtxbBmmuH10bU+wge/NMmaHuVAe599\n\t\t\t\t\t\tpyezFIL4FoI2g+1Q6nG4Yl1Z07I81tTApXKVMWRt/4/M3m2D7PUMOQ9qsxthp2L/\n\t\t\t\t\t\tLovIeNo0bTyeW290T2Y/JRZhKOgeDqkhuu82DPri2Vm5G/unB69KfRB7CF9QWIc3\n\t\t\t\t\t\ty80CAwEAAaNrMGkwSAYDVR0RBEEwP4ISaWRwLnNoaWJib2xldGgubmV0hilodHRw\n\t\t\t\t\t\tczovL2lkcC5zaGliYm9sZXRoLm5ldC9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n\t\t\t\t\t\t3uZ32tKXJBzPCTp2dtHSLV0FvGgwDQYJKoZIhvcNAQEFBQADggEBAAYXYuzp0UTj\n\t\t\t\t\t\t3yLRvUCbEtaw9b80+weOELkVv3WFY3QAG8pIKEblrMMtzrzLFWZwYwwMZDab/HnH\n\t\t\t\t\t\tegmgjZBthrOedEmoJ+OHRmIiS8zdZxVGEadJhTUaeIkO6kwK7Ht3nQePoiXV7TI5\n\t\t\t\t\t\t+A9SpmZGoukC85Za4wGDw4xWGs5t5l6tBuuV+1s0oC6T8ih5n/NyThfpbihSW0d7\n\t\t\t\t\t\tiBfSUickgpoM2BLM3FCnbO8HOsX1rGV4ypG9ZGDDvr2jrzalXXmc05gSlL2qd9ce\n\t\t\t\t\t\tQ1M+9vavusPCqlj2zZf2/HfzhyiFcb/OgA0oTFWW2ynXji6UarIV5QaPoi/XmGmx\n\t\t\t\t\t\tBXD36HfGBXk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Shibboleth.net"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.shibboleth.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "JISC Collections and Janet Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-p12.ladok.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-p12.ladok.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;p12"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;p12"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-p12.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-p12.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQTCCAimgAwIBAgIJAJwfFHHm4QTAMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2xhZG9rMy1wMTIubGFkb2sudW11LnNlMB4XDTE1MDIwOTEwNDE0NloXDTI1\nMDIwNjEwNDE0NlowIjEgMB4GA1UEAxMXbGFkb2szLXAxMi5sYWRvay51bXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC1hH5bfM0hd5d2hD4Na6LP\nGBeBX337nRyUU0tJaLVQj2fZMygo2zV6fE9ht4dIEzUaS0u8C8HhY2ASHMVYYsb4\nE5L1Jx9fosv8L6tqoX+hL8QZQ2w2SCYGHjRaAEkmhdjMSTp9O3n3q5lFG8jA+unf\nSA9CDvL/R//Imq2oqNrf3cgbfifhD5XnOZRc0gj2THlq0E/fpqXK6XYOIc1ZO9dx\nr2tNw1Zu3zY+c1BbQ42gMa43O1L9S9szfQfJZC6cMa3C5DXHCidJ/sFJ5ITLmxur\nR6pteZI9vyHaIPC+zX4Ta5kn50rhqeITajNExyWo1fA5ebVlRlQ5Jl9L5l6scnMR\nAgMBAAGjejB4MFcGA1UdEQRQME6CF2xhZG9rMy1wMTIubGFkb2sudW11LnNlhjNo\ndHRwczovL2xhZG9rMy1wMTIubGFkb2sudW11LnNlL3N0dWRlbnQtZnJvbnRlbmQt\nc3AwHQYDVR0OBBYEFIl6Hqs8E9quQ9zh8x5nn5SzlqF8MA0GCSqGSIb3DQEBBQUA\nA4IBAQCFZ9SxV0u3FYj8PTzaDa6unPRH/0qzZ4LuD87Hmx87n4NL3XFu2e5ocgvf\nlHY3XEr23zWm0u7vZu2M9lD3No/y4wmFPxpv4uSt27EcLPbD8u1LA0q+xzO6/T5j\nNKnxy7NcK+a17PXnsp/XXzOfRtFqkPByitZIbD9KWkuDg6ri2gws1BPc/fHV9V1i\nDWuaLVpBYp5vMqIr5esITLLVNIwk0A68PZy05J87SEr7Gepyg1zyX4AYa52rqkY0\nXQHW0Eym6LKaJ2wLzF/Il9WlgBNOFr7nN2344wyG3cq8Qd1d/zWyms+sauuZxZz7\nuqxBQkCvnX33vrqLW5c3nz5GznAD"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-p12.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ashiok.ufpe.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fabio Chicout"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "fabio.chicout@ufpe.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ashiok.ufpe.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKjCCAxICAQAwDQYJKoZIhvcNAQEFBQAwgdoxMTAvBgNVBAoTKFVGUEUgLSBV\nbml2ZXJzaWRhZGUgRmVkZXJhbCBkZSBQZXJubWJ1Y28xNTAzBgNVBAsULE5USSAt\nIE7DumNsZW8gZGUgVGVjb25vbG9naWEgZGEgSW5mb3JtYcOnw6NvMSIwIAYJKoZI\nhvcNAQkBFhNhbG1pci5waXJlc0B1ZnBlLmJyMQ8wDQYDVQQHEwZSZWNpZmUxEzAR\nBgNVBAgTClBlcm5hbWJ1Y28xCzAJBgNVBAYTAkJSMRcwFQYDVQQDEw5hc2hpb2su\ndWZwZS5icjAeFw0xNTA3MDgxNTE3MDBaFw0xODA3MDcxNTE3MDBaMIHaMTEwLwYD\nVQQKEyhVRlBFIC0gVW5pdmVyc2lkYWRlIEZlZGVyYWwgZGUgUGVybm1idWNvMTUw\nMwYDVQQLFCxOVEkgLSBOw7pjbGVvIGRlIFRlY29ub2xvZ2lhIGRhIEluZm9ybWHD\np8OjbzEiMCAGCSqGSIb3DQEJARYTYWxtaXIucGlyZXNAdWZwZS5icjEPMA0GA1UE\nBxMGUmVjaWZlMRMwEQYDVQQIEwpQZXJuYW1idWNvMQswCQYDVQQGEwJCUjEXMBUG\nA1UEAxMOYXNoaW9rLnVmcGUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQCpJtnXex0EfajEm2mxs7SbI095tfMKoBYKm+oX2Rh0LG9Dqv2tkz8zlrGz\n65MX7J0T83f2XXCtwn8+QeFWIPjZeCrhXqiV+cd/8zT48mat8jjvlPXQUBT9l7CF\nui7Ck3nKgAuyRmLZS0VRWa5Fe7jQVenb0ukfWjlkqA0HA3aG76d/5/Re/JHCuhoX\nJ/B8Hk3r4RnUqAR5v9p+wvVlIfuMgZ2PoMpOEFnLRST/IAYYu6sfNF+/OGYnNOVt\nHaodpJiODntW7N58a7LUvmMDQcuZNk/gEFFa7lpc1lUxZ21/xjzt8hoM5JaKalRp\nWvoGp7ebIAjU5XAAB9D617WrhRaHAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAB7u\nICGu5gqybOHxpZOVMhL7Vc5ZkHKk07gFzlMeDcrm4FEi9NSC+ACSZOw4Y65hzlML\n3Mqvwa27U2Uf9+g8cXKvmjEImZTX+1DpWcgfslS6ZZlXPX751+c+0G5HCMvHQotT\neouE1EENazDBi7+JHPH0dVX5EQwo/TghbjWwZn0XauScEQQSfcb5ncHWV62IlpjP\nHRjJA1oHM/BcHqi1Gld3QuKZ6Mz0AWAjsXlbwvcOUNjtPdgghHZzL/2PZQwErMw3\n3p9yrXX8gzzfzibmLwq3vu7eqXmz40Q1GyzzFVBcHdOTYRKON7g0Gj7rYzPVzw6m\ngJlqm/h9oLN/JBPHKNI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufpe.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ashiok.ufpe.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://ashiok.ufpe.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ashiok.ufpe.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ashiok.ufpe.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://ashiok.ufpe.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ashiok.ufpe.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ashiok.ufpe.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://ashiok.ufpe.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufpe.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufpe.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufpe.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFPE - Universidade Federal de Pernambuco"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFPE - Universidade Federal de Pernambuco"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFPE - Universidade Federal de Pernambuco"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFPE - Universidade Federal de Pernambuco"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKjCCAxICAQAwDQYJKoZIhvcNAQEFBQAwgdoxMTAvBgNVBAoTKFVGUEUgLSBV\nbml2ZXJzaWRhZGUgRmVkZXJhbCBkZSBQZXJubWJ1Y28xNTAzBgNVBAsULE5USSAt\nIE7DumNsZW8gZGUgVGVjb25vbG9naWEgZGEgSW5mb3JtYcOnw6NvMSIwIAYJKoZI\nhvcNAQkBFhNhbG1pci5waXJlc0B1ZnBlLmJyMQ8wDQYDVQQHEwZSZWNpZmUxEzAR\nBgNVBAgTClBlcm5hbWJ1Y28xCzAJBgNVBAYTAkJSMRcwFQYDVQQDEw5hc2hpb2su\ndWZwZS5icjAeFw0xNTA3MDgxNTE3MDBaFw0xODA3MDcxNTE3MDBaMIHaMTEwLwYD\nVQQKEyhVRlBFIC0gVW5pdmVyc2lkYWRlIEZlZGVyYWwgZGUgUGVybm1idWNvMTUw\nMwYDVQQLFCxOVEkgLSBOw7pjbGVvIGRlIFRlY29ub2xvZ2lhIGRhIEluZm9ybWHD\np8OjbzEiMCAGCSqGSIb3DQEJARYTYWxtaXIucGlyZXNAdWZwZS5icjEPMA0GA1UE\nBxMGUmVjaWZlMRMwEQYDVQQIEwpQZXJuYW1idWNvMQswCQYDVQQGEwJCUjEXMBUG\nA1UEAxMOYXNoaW9rLnVmcGUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQCpJtnXex0EfajEm2mxs7SbI095tfMKoBYKm+oX2Rh0LG9Dqv2tkz8zlrGz\n65MX7J0T83f2XXCtwn8+QeFWIPjZeCrhXqiV+cd/8zT48mat8jjvlPXQUBT9l7CF\nui7Ck3nKgAuyRmLZS0VRWa5Fe7jQVenb0ukfWjlkqA0HA3aG76d/5/Re/JHCuhoX\nJ/B8Hk3r4RnUqAR5v9p+wvVlIfuMgZ2PoMpOEFnLRST/IAYYu6sfNF+/OGYnNOVt\nHaodpJiODntW7N58a7LUvmMDQcuZNk/gEFFa7lpc1lUxZ21/xjzt8hoM5JaKalRp\nWvoGp7ebIAjU5XAAB9D617WrhRaHAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAB7u\nICGu5gqybOHxpZOVMhL7Vc5ZkHKk07gFzlMeDcrm4FEi9NSC+ACSZOw4Y65hzlML\n3Mqvwa27U2Uf9+g8cXKvmjEImZTX+1DpWcgfslS6ZZlXPX751+c+0G5HCMvHQotT\neouE1EENazDBi7+JHPH0dVX5EQwo/TghbjWwZn0XauScEQQSfcb5ncHWV62IlpjP\nHRjJA1oHM/BcHqi1Gld3QuKZ6Mz0AWAjsXlbwvcOUNjtPdgghHZzL/2PZQwErMw3\n3p9yrXX8gzzfzibmLwq3vu7eqXmz40Q1GyzzFVBcHdOTYRKON7g0Gj7rYzPVzw6m\ngJlqm/h9oLN/JBPHKNI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFPE - Universidade Federal de Pernambuco"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFPE - Universidade Federal de Pernambuco"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufpe.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufpe.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFPE - Universidade Federal de Pernambuco"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFPE - Universidade Federal de Pernambuco"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://aktivera-test.su.se/Shibboleth.sso",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://aktivera-test.su.se/Shibboleth.sso",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aktivera-test.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aktivera-test.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aktivera-test.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://aktivera-test.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aktivera-test.su.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://aktivera-test.su.se/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://aktivera-test.su.se/Shibboleth.sso/WAYF/wavelan",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "signuptool-test-app1"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAK5pPeHRZOXtMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFHNpZ251cHRvb2wtdGVzdC1hcHAxMB4XDTExMDIyMTE1MjYxNloXDTIxMDIx\nODE1MjYxNlowHzEdMBsGA1UEAxMUc2lnbnVwdG9vbC10ZXN0LWFwcDEwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDY+owzEC+S0BF0nCbN13lR0CHlp7mg\n/7YhK3ESVboh9kUtM4/awXRjvJFMfcuFbaJV2DXCX85hFvBIw0D4u6bjNNPye9oS\nVPAFenaFnHAE75O5C3FYnuB5X3P9HDdBoc5m21CDwLmGek7KwPTxpJtqevNUAO2C\n/EEtdk1xe+2T4+fikdRMP9uvf6xz7/WgGzm1V/olbV3tgph7ye4KEB2F6Z/hsyyn\nJaekNZD3oKOk3DsXfxHKRhD/nUjqXoGoUwkD4HLT1fKdP5VYb+T/SzdxLSaoUoJJ\nfVv2Xs/wlD3Vx3zvV5l3x8EJ4paySeh4RdNsUAylbshYUXN9frk5g/WzAgMBAAGj\nQjBAMB8GA1UdEQQYMBaCFHNpZ251cHRvb2wtdGVzdC1hcHAxMB0GA1UdDgQWBBSt\ncBtmU+scg9g8iK1x07dqKTh+QDANBgkqhkiG9w0BAQUFAAOCAQEAw0NLLpKeYIhn\nrL0edePtkGr3sFNmOyg8k9qkPxgwrozjLg/+AkssNft+rs7nZp87IIhZUiNZxr7w\nqnRPJXoxq56IfsbZpQwAH0QIRc9gl5BjzvdqByGH76Z5dDPFUaTrxnd7XdWybOiZ\nbX4d2LgWklI0aTw7xQEjw0qX/nWW0guZRC/nJfgiHjV7xEJLcoxcyn0+dqo1+XkU\ny60nYKhdp2qnCnRCR8by5ykruSaDJ4c/OCsGh9WIE6HvpDunTTzisfqrdZ22LTLR\nvaJm+7MsfXQvQZz6YUW2MGSYOa6G9v2dS4Dz9v/9JQjn6bBqqSouw3spYPDAbzGp\nu/S7d9rEGQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=signuptool-test-app1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "signuptool-test-app1"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAK5pPeHRZOXtMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFHNpZ251cHRvb2wtdGVzdC1hcHAxMB4XDTExMDIyMTE1MjYxNloXDTIxMDIx\nODE1MjYxNlowHzEdMBsGA1UEAxMUc2lnbnVwdG9vbC10ZXN0LWFwcDEwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDY+owzEC+S0BF0nCbN13lR0CHlp7mg\n/7YhK3ESVboh9kUtM4/awXRjvJFMfcuFbaJV2DXCX85hFvBIw0D4u6bjNNPye9oS\nVPAFenaFnHAE75O5C3FYnuB5X3P9HDdBoc5m21CDwLmGek7KwPTxpJtqevNUAO2C\n/EEtdk1xe+2T4+fikdRMP9uvf6xz7/WgGzm1V/olbV3tgph7ye4KEB2F6Z/hsyyn\nJaekNZD3oKOk3DsXfxHKRhD/nUjqXoGoUwkD4HLT1fKdP5VYb+T/SzdxLSaoUoJJ\nfVv2Xs/wlD3Vx3zvV5l3x8EJ4paySeh4RdNsUAylbshYUXN9frk5g/WzAgMBAAGj\nQjBAMB8GA1UdEQQYMBaCFHNpZ251cHRvb2wtdGVzdC1hcHAxMB0GA1UdDgQWBBSt\ncBtmU+scg9g8iK1x07dqKTh+QDANBgkqhkiG9w0BAQUFAAOCAQEAw0NLLpKeYIhn\nrL0edePtkGr3sFNmOyg8k9qkPxgwrozjLg/+AkssNft+rs7nZp87IIhZUiNZxr7w\nqnRPJXoxq56IfsbZpQwAH0QIRc9gl5BjzvdqByGH76Z5dDPFUaTrxnd7XdWybOiZ\nbX4d2LgWklI0aTw7xQEjw0qX/nWW0guZRC/nJfgiHjV7xEJLcoxcyn0+dqo1+XkU\ny60nYKhdp2qnCnRCR8by5ykruSaDJ4c/OCsGh9WIE6HvpDunTTzisfqrdZ22LTLR\nvaJm+7MsfXQvQZz6YUW2MGSYOa6G9v2dS4Dz9v/9JQjn6bBqqSouw3spYPDAbzGp\nu/S7d9rEGQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=signuptool-test-app1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aktivera-test.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aktivera-test.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aktivera-test.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://aktivera-test.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://aktivera-test.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://aktivera-test.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aktivera-test.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aktivera-test.su.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://aktivera-test.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://aktivera-test.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://halfback.cnaf.infn.it/casshib/app2",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:igi-portal-admin@lists.italiangrid.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://halfback.cnaf.infn.it/casshib/app2",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2012-07-04T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IGI Grid Portal erogato da INFN"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IGI Grid Portal provided by INFN"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.infn.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.infn.it/indexen.php"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Istituto Nazionale di Fisica Nucleare"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Istituto Nazionale di Fisica Nucleare"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://halfback.cnaf.infn.it/casshib/shib/app2/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://halfback.cnaf.infn.it/casshib/shib/app2/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://halfback.cnaf.infn.it/casshib/shib/app2/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://halfback.cnaf.infn.it/casshib/shib/app2/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "IGI Grid Portal provided by INFN"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "IGI is the Italian Grid infrastructure, run for the benefit of the research and education communities in Italy and worldwide"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonOrgDN",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "localityName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://halfback.cnaf.infn.it/casshib/shib/app2/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://wiki.italiangrid.it/IGIPortal"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IGI is the Italian Grid infrastructure, run for the benefit of the research and education communities in Italy and worldwide."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://wiki.italiangrid.it/IGIPortal/Federation-info"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IGI Grid Portal"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://halfback.cnaf.infn.it/casshib/shib/app2/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://halfback.cnaf.infn.it/casshib/shib/app2/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEhzCCA2+gAwIBAgIQYJH5E+/63l61Qiby7wHhYjANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEyMDYyNTAwMDAwMFoXDTE1MDYyNTIzNTk1OVowXTELMAkGA1UE\nBhMCSVQxLjAsBgNVBAoTJUlzdGl0dXRvIE5hemlvbmFsZSBkaSBGaXNpY2EgTnVj\nbGVhcmUxHjAcBgNVBAMTFWhhbGZiYWNrLmNuYWYuaW5mbi5pdDCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAOH0IRtQc7utWIumhJaEwwBdovpOu3eUH3X5\nDK7/OaQYHpo2+E1tnoHdG1JU+QgZocacuw3oJz74tGdknUsvDj9MCdp2lGYLpPW9\np4WMK5+ElpVFjLcKdxndPNME8SF0nOcRoM9aMQhpOSnSLX3Ybeov/MO0dT9iVVmW\nKAau3hSeUZ2renaL/oQp+bK3+EoYImYV/5R1rkpTTf0brmaQg3GBdxADnAdwFBgG\nY93qnKsYQjPsOg7ik7kf0jUSrITGo7rgLHvkElm4ySG01jOOtfw4AoglUppUan2x\nhlHYWrUhdqzNV2uasqHP3t7EA4tITv8IrgJj3k2coinPbB9s1mUCAwEAAaOCAWgw\nggFkMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBTz\nkh/WAe7TMeep782t7Dy4EX8J/DAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIw\nADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwGAYDVR0gBBEwDzANBgsr\nBgEEAbIxAQICHTA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJl\nbmEub3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUH\nMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYG\nCCsGAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAgBgNVHREEGTAX\nghVoYWxmYmFjay5jbmFmLmluZm4uaXQwDQYJKoZIhvcNAQEFBQADggEBAHW8TsHv\nD7EM9iMprOIH+5VeRSh0cYEdttX033scsifCFCArRJvhofIkR/1F23DIWRnc8//4\n7MKSrLoC9PNeIjXa6anC3O9IZNCeBxb9UEcRvPW3Yc1wEe4ATp1aR8EXtH3G2Sef\nEELgyGnKzScgkUSGIbgf9P05XOyok0RuKWTHDvYNHr/GW/NW5optwXz6apDDE2mX\nicFWqRortYglbk+s6VO0hcYN6ORR5UBgOR6VULrT9r6mDQykItMVhBgt4peAeOss\n+6acaFTdJZHMD+Z3KkvA7yfD4IWulPnTaT+o1n7X1V6oAEVHn6SfpuBeP+wXeu+f\nyVxNpwv+OOJLtns="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://halfback.cnaf.infn.it/casshib/shib/app2/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://halfback.cnaf.infn.it/casshib/shib/app2/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://halfback.cnaf.infn.it/casshib/shib/app2/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://halfback.cnaf.infn.it/casshib/shib/app2/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://halfback.cnaf.infn.it/casshib/shib/app2/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://halfback.cnaf.infn.it/casshib/shib/app2/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://halfback.cnaf.infn.it/casshib/shib/app2/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://halfback.cnaf.infn.it/casshib/shib/app2/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://halfback.cnaf.infn.it/casshib/shib/app2/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://halfback.cnaf.infn.it/casshib/shib/app2/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://equinoxjournals.com/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Willis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mwillis@equinoxpub.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Willis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mwillis@equinoxpub.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://equinoxjournals.com/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-04-03T09:28:24Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Equinox Publishing"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.equinoxpub.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Equinox Publishing Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.equinoxpub.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.equinoxpub.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.equinoxpub.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.equinoxpub.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.equinoxpub.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Publishing academic journals, textbooks, anthologies, monographs and reference books in the areas of archaeology, linguistics, cultural history, religious studies, theology, biblical studies, cookery and popular music."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.equinoxpub.com/equinox/images/home_logo.gif",
                    "height": "79",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "363"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Equinox Publishing"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.equinoxpub.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.equinoxpub.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.equinoxpub.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.equinoxpub.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEXDCCA0SgAwIBAgIJAI+ovrSiKZbIMA0GCSqGSIb3DQEBBQUAMIGuMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEYMBYGA1UECBMPU291dGggWW9ya3NoaXJlMRIwEAYDVQQHEwlTaGVm\n\t\t\t\t\t\tZmllbGQxHzAdBgNVBAoTFkVxdWlub3ggUHVibGlzaGluZyBMdGQxCzAJBgNVBAsT\n\t\t\t\t\t\tAklUMRwwGgYDVQQDExNlcXVpbm94am91cm5hbHMuY29tMSUwIwYJKoZIhvcNAQkB\n\t\t\t\t\t\tFhZzdXBwb3J0QGVxdWlub3hwdWIuY29tMB4XDTEyMDQwMzIyMjkzOFoXDTIyMDQw\n\t\t\t\t\t\tMTIyMjkzOFowga4xCzAJBgNVBAYTAkdCMRgwFgYDVQQIEw9Tb3V0aCBZb3Jrc2hp\n\t\t\t\t\t\tcmUxEjAQBgNVBAcTCVNoZWZmaWVsZDEfMB0GA1UEChMWRXF1aW5veCBQdWJsaXNo\n\t\t\t\t\t\taW5nIEx0ZDELMAkGA1UECxMCSVQxHDAaBgNVBAMTE2VxdWlub3hqb3VybmFscy5j\n\t\t\t\t\t\tb20xJTAjBgkqhkiG9w0BCQEWFnN1cHBvcnRAZXF1aW5veHB1Yi5jb20wggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDGZpYDMaxM9v0cDM+JkoNQSMRPwOUo\n\t\t\t\t\t\tiwl45P9jJh1zwJRi++9/uu9e/kQIEJmiZYowkyea2wPDYZVAukOgfkk4m+0VVoV6\n\t\t\t\t\t\tRo/mNO1jBCsVXXQ6DeT8Aq/UCI1N4LlBD9DHPp+neQZvhoQp1V1zouXqMUBTRtW+\n\t\t\t\t\t\t77h2IIidOGlaU6OS7qJLqGLQQCWZD1mxb6Sms+5Sa1xdf9WOUq3inB6gB6GReJdC\n\t\t\t\t\t\ttWInflUNrFS8mvM0lHUQs18SmulMokgb+s8xSJljpcbCMpSWKshHZjWuOmzc15a4\n\t\t\t\t\t\ta3rSgZxZDJMqioQzpGMOyd7FZEIgnBY6KFurNkha7ddISbaSmrWtnytBAgMBAAGj\n\t\t\t\t\t\tezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVk\n\t\t\t\t\t\tIENlcnRpZmljYXRlMB0GA1UdDgQWBBRoLYcAzpJhhw9sBy/6ACALL0qpczAfBgNV\n\t\t\t\t\t\tHSMEGDAWgBRoLYcAzpJhhw9sBy/6ACALL0qpczANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tSqIXjnqGhkkRA5cSJherE2uyt7eDmA7VXbJjGV+KgM4dWf+R+Y81NzYuddknTeGZ\n\t\t\t\t\t\teQTcGy67dYnzDan8ZN+AfS98NgHx4qaTI+rwq5/0Vo+MaG57NiGUt6pkR1LKTbtw\n\t\t\t\t\t\tZf8QgAhLAWH66w4tK+/507XY5GS+Cfkjznnm2hT6pftCg13mMO4YFGzH7LUwPYSR\n\t\t\t\t\t\tUdH7G5kkGwV0FhZaDP0e5SKWfHGjihDcw5RbOLiD5hv7m1Ls7PDKPR+izh+40wf/\n\t\t\t\t\t\td0RO7oiZKGZjtKMvJPh++lYFflUPLH/lmg3nzKYmwTdJFmC4m9NL+9QRn0Ned2D8\n\t\t\t\t\t\tpztQ4C1nPvNFJOO9MeGj6g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.equinoxpub.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.equinoxpub.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.equinoxpub.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.equinoxpub.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.equinoxpub.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.equinoxpub.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://eduspot.ens-cachan.fr/authsaml2/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "eduspot@ens-cachan.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://eduspot.ens-cachan.fr/authsaml2/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-04-12T10:48:28Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/wifi"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/national"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ecole Normale Sup\u00e9rieure de Cachan"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ens-cachan.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ecole Normale Sup\u00e9rieure de Cachan"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://eduspot.ens-cachan.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Acc\u00e8s aux Wifi pour les participants au projet Eduspot via le portail captif Univnautes."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENS de Cachan - Portail Eduspot"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENS de Cachan - Portail Eduspot"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEpDCCA4ygAwIBAgIQeTFgbQWRlGanItIwtJ/w0jANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMjAeFw0xNDEwMTcwMDAwMDBaFw0xNzEwMTYyMzU5NTlaMEMxITAfBgNVBAsT\nGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEeMBwGA1UEAxMVZWR1c3BvdC5lbnMt\nY2FjaGFuLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuNjLcYRU\nVIYvwbFG89dp+n0NMsDR6SrHZ/AMit0airV2ReNm1H+Wcuq0UGQKLsrhytQsL3vK\nlgBCbUi2LbIFlPubTIBx8pNoH8AkBcOyfg1kiN2yJ4z+gaqjoy+gp7zChSKhga3D\nLsIkAfBK2hKiw+t1Cod/LCgbeBdGKnB4gDTZScYf8r3rSIyE1mtDI93VJfsMHkKD\nj3WOmhAnoT1KDXFHI1utdUwyM/u2nGgAjgupEbDTAOfx/N56/yUkR88Q22itXKdS\nEr3v66gp0CJluEPUFTmmCCdklnv12rFR16hrgm/fiZWyj6z9BtRQUW6cC35fDtmq\n9CMXI8aYdpMTEwIDAQABo4IBcTCCAW0wHwYDVR0jBBgwFoAUW9CKHJoyW+C13ZZU\nG+GGKLD9tr0wHQYDVR0OBBYEFHeYAb+69vprObDtE1PM63PWKio0MA4GA1UdDwEB\n/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEF\nBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8E\nMzAxMC+gLaArhilodHRwOi8vY3JsLnVzZXJ0cnVzdC5jb20vVEVSRU5BU1NMQ0Ey\nLmNybDBsBggrBgEFBQcBAQRgMF4wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudXNl\ncnRydXN0LmNvbS9URVJFTkFTU0xDQTIuY3J0MCUGCCsGAQUFBzABhhlodHRwOi8v\nb2NzcC51c2VydHJ1c3QuY29tMCAGA1UdEQQZMBeCFWVkdXNwb3QuZW5zLWNhY2hh\nbi5mcjANBgkqhkiG9w0BAQsFAAOCAQEANOYe63FGB6CrqW/Hl8uRbBrJsYHnzknp\nh6NjKRuvnzeOOOrDVW75T3//6AepZzJ0k1ZzzYIYJ0crBavEEo9L5AvwMPvs7mYw\nRAUTEMhGTm/nYQct1jwbCgNKCDgYuydZUcixtiq3LXz1SglHXGNhg+SLGCGXrHrJ\nJxuaneWu5FgReUB3EDUC0bCrM9nx2cHitLtox3aXU/fhiPXCEkP2HV4DnjLu3fBJ\nS5gBayfEa2U6VDzvwdEk71Pw3PKsdEl7f9N5mp3rpjvr36r5TH5LXhbk0utRGo7u\nyn+WFioypXnVKl7dgWzQsVdGI4NnnsfGgmah+vJMEtRPPnBtjRrV3A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEpDCCA4ygAwIBAgIQeTFgbQWRlGanItIwtJ/w0jANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMjAeFw0xNDEwMTcwMDAwMDBaFw0xNzEwMTYyMzU5NTlaMEMxITAfBgNVBAsT\nGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEeMBwGA1UEAxMVZWR1c3BvdC5lbnMt\nY2FjaGFuLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuNjLcYRU\nVIYvwbFG89dp+n0NMsDR6SrHZ/AMit0airV2ReNm1H+Wcuq0UGQKLsrhytQsL3vK\nlgBCbUi2LbIFlPubTIBx8pNoH8AkBcOyfg1kiN2yJ4z+gaqjoy+gp7zChSKhga3D\nLsIkAfBK2hKiw+t1Cod/LCgbeBdGKnB4gDTZScYf8r3rSIyE1mtDI93VJfsMHkKD\nj3WOmhAnoT1KDXFHI1utdUwyM/u2nGgAjgupEbDTAOfx/N56/yUkR88Q22itXKdS\nEr3v66gp0CJluEPUFTmmCCdklnv12rFR16hrgm/fiZWyj6z9BtRQUW6cC35fDtmq\n9CMXI8aYdpMTEwIDAQABo4IBcTCCAW0wHwYDVR0jBBgwFoAUW9CKHJoyW+C13ZZU\nG+GGKLD9tr0wHQYDVR0OBBYEFHeYAb+69vprObDtE1PM63PWKio0MA4GA1UdDwEB\n/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEF\nBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8E\nMzAxMC+gLaArhilodHRwOi8vY3JsLnVzZXJ0cnVzdC5jb20vVEVSRU5BU1NMQ0Ey\nLmNybDBsBggrBgEFBQcBAQRgMF4wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudXNl\ncnRydXN0LmNvbS9URVJFTkFTU0xDQTIuY3J0MCUGCCsGAQUFBzABhhlodHRwOi8v\nb2NzcC51c2VydHJ1c3QuY29tMCAGA1UdEQQZMBeCFWVkdXNwb3QuZW5zLWNhY2hh\nbi5mcjANBgkqhkiG9w0BAQsFAAOCAQEANOYe63FGB6CrqW/Hl8uRbBrJsYHnzknp\nh6NjKRuvnzeOOOrDVW75T3//6AepZzJ0k1ZzzYIYJ0crBavEEo9L5AvwMPvs7mYw\nRAUTEMhGTm/nYQct1jwbCgNKCDgYuydZUcixtiq3LXz1SglHXGNhg+SLGCGXrHrJ\nJxuaneWu5FgReUB3EDUC0bCrM9nx2cHitLtox3aXU/fhiPXCEkP2HV4DnjLu3fBJ\nS5gBayfEa2U6VDzvwdEk71Pw3PKsdEl7f9N5mp3rpjvr36r5TH5LXhbk0utRGo7u\nyn+WFioypXnVKl7dgWzQsVdGI4NnnsfGgmah+vJMEtRPPnBtjRrV3A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjQCCQCR6CZCuHxqRDANBgkqhkiG9w0BAQUFADBoMQswCQYDVQQGEwJG\nUjErMCkGA1UEChMiRUNPTEUgTk9STUFMRSBTVVBFUklFVVJFIERFIENBQ0hBTjEM\nMAoGA1UECxMDRFNJMR4wHAYDVQQDExVlZHVzcG90LmVucy1jYWNoYW4uZnIwHhcN\nMTQwNDE0MTIzNjI4WhcNMTUwNDE0MTIzNjI4WjBoMQswCQYDVQQGEwJGUjErMCkG\nA1UEChMiRUNPTEUgTk9STUFMRSBTVVBFUklFVVJFIERFIENBQ0hBTjEMMAoGA1UE\nCxMDRFNJMR4wHAYDVQQDExVlZHVzcG90LmVucy1jYWNoYW4uZnIwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDaN/r/9eegiIWfM7W+cBepylzyQKasGNVV\npOGqQtClO+RDnHw1e+VjLofvQkCrkXqO0Yk2+3fFluaVEKefRhz87KkfCwqmmMVv\nN7QPL7wdjefp7z0QQQd500er/lWzNEZ16noFKNAKIVQ7L8nwEID2szf2o7lwiHUM\nI0/WYrcHtglX+KFiKCajf8lMQHQlnLvrODzBvZPuY+hcjyPMet8C77jsQs9KcBa/\nWOZ0XHwpfP6qSedCp1feHWNG/6H/ngPhFH+Yfh8dCYvnf8evL+WKL+b2L22s009K\n6pGpup0ZJaS2UbMblHeOCRf9kfT6peLwcOawPi9M7W68vSBtNd4DAgMBAAEwDQYJ\nKoZIhvcNAQEFBQADggEBAAm4J2729rV0T1ZHR7GhruA+x8Kt0SXeXwvng8Zuaijz\nNSNK9Ej3j9Y/NRYKPTPAm2fGCrbbr89lZ+0680b6ZqicZU2c4juHe0u5/5zN1wmV\nh98Us4F37tUL4aT6fvi+FTJUkeHR3ZV/wGkdbzTLWqKqVQ8POO8Q55DZEjIrFiq3\nLmIbOYK8bfdAZTc2XWVsU1bNQyJMY6Qiu2mA1VTc61b5gUI94RmMpfEP0hl7DBgh\nKIz/GZRjl9UB3x6EEgmPi+ihRwPs/tQORLZpaS9pyqdPzrH3NuP/iVO5Dv/D7Ss9\nU3vIxlLV3X9ESLFrZiZgFRyKOqQOri3RHniJ7Yt9v+k="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://eduspot.ens-cachan.fr/authsaml2/singleSignOnPost",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ENS de Cachan - Portail Eduspot"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Acc\u00e8s aux Wifi pour les participants au projet Eduspot via le portail captif Univnautes."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.uk-plc.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@cloudbuy.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "@UK PLC Customer Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Roberts"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul.roberts@cloudbuy.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.uk-plc.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-01-18T18:08:20Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "@UK PLC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uk-plc.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cloudbuy PLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.uk-plc.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.uk-plc.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.uk-plc.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.uk-plc.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "1",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.uk-plc.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJAIV70zuQ2vBVMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXNwLnVrLXBsYy5uZXQwHhcNMTEwMTE3MTEwNDU5WhcNMjEwMTE0MTEwNDU5\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1zcC51ay1wbGMubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAm69+UMm20EyOMmETcniHi59ED3GW+f1B+qNgCQZpP+PRNnLA\n\t\t\t\t\t\tZ0+lLrrBrAb1oDjUqt3ya45AUVcHxDuEtpQnbIsvSvQztQr/J7Il9rBAHa7MKQVl\n\t\t\t\t\t\t6vWt8VQA8njt/Zy3Zwed6CvbPyB6jBe6KrrHdqfdXBXqxXt5KbcNb4nTKUIe081p\n\t\t\t\t\t\twMkNThERBLbFg48FDsSytT2D+ERsz4Ivg8fW6kTEl7Fvx35lK4rBUQjIBcsWNuFN\n\t\t\t\t\t\thTy29mfVAZOWq0TnrzE84uYioNf5LrZiZSdmPFDarqyl9/T2Lo7OeG+8ZGxpOe8f\n\t\t\t\t\t\tBRVhqpY/xHev7S1hdHTn8f+fM59PiWA8IUN+xwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1zcC51ay1wbGMubmV0MB0GA1UdDgQWBBQm+W+pJIIr4Gh6H9Hl7CXWBYnjYTAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAhN9iAGeAhzrOkYr5wRWcZmJTaD1XCMZsgfB2sF/Z\n\t\t\t\t\t\t+Xu8dlJ2wHw+xubq2PU7aYZRGb3QblGODdowyDzV1/hQ43/psakSBmm14VDqKu7M\n\t\t\t\t\t\t/+ZvM5hCUoGfTgXRaUXPVhDbNLJyoFewg9IEYS1UXQo6GuXoFqOf602Bd9SWpfgM\n\t\t\t\t\t\tWrjGCgrkN7arw85MqyiWoP5lEH9NMw3yyrYqEjV5L15ciszslzRCLsMF2viSpJDH\n\t\t\t\t\t\trmLaDUQp1MFaZc8ulVkIJIc2vvj4AdZ5BS3N8qsPc6+l4E7aunsP/WXxxFqT8VVa\n\t\t\t\t\t\tvkVcbTLRcJHyGdZsf++gt0fT+WmWbQsVC0Y1ILG/LNkfaA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJAIV70zuQ2vBVMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXNwLnVrLXBsYy5uZXQwHhcNMTEwMTE3MTEwNDU5WhcNMjEwMTE0MTEwNDU5\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1zcC51ay1wbGMubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAm69+UMm20EyOMmETcniHi59ED3GW+f1B+qNgCQZpP+PRNnLA\n\t\t\t\t\t\tZ0+lLrrBrAb1oDjUqt3ya45AUVcHxDuEtpQnbIsvSvQztQr/J7Il9rBAHa7MKQVl\n\t\t\t\t\t\t6vWt8VQA8njt/Zy3Zwed6CvbPyB6jBe6KrrHdqfdXBXqxXt5KbcNb4nTKUIe081p\n\t\t\t\t\t\twMkNThERBLbFg48FDsSytT2D+ERsz4Ivg8fW6kTEl7Fvx35lK4rBUQjIBcsWNuFN\n\t\t\t\t\t\thTy29mfVAZOWq0TnrzE84uYioNf5LrZiZSdmPFDarqyl9/T2Lo7OeG+8ZGxpOe8f\n\t\t\t\t\t\tBRVhqpY/xHev7S1hdHTn8f+fM59PiWA8IUN+xwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1zcC51ay1wbGMubmV0MB0GA1UdDgQWBBQm+W+pJIIr4Gh6H9Hl7CXWBYnjYTAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAhN9iAGeAhzrOkYr5wRWcZmJTaD1XCMZsgfB2sF/Z\n\t\t\t\t\t\t+Xu8dlJ2wHw+xubq2PU7aYZRGb3QblGODdowyDzV1/hQ43/psakSBmm14VDqKu7M\n\t\t\t\t\t\t/+ZvM5hCUoGfTgXRaUXPVhDbNLJyoFewg9IEYS1UXQo6GuXoFqOf602Bd9SWpfgM\n\t\t\t\t\t\tWrjGCgrkN7arw85MqyiWoP5lEH9NMw3yyrYqEjV5L15ciszslzRCLsMF2viSpJDH\n\t\t\t\t\t\trmLaDUQp1MFaZc8ulVkIJIc2vvj4AdZ5BS3N8qsPc6+l4E7aunsP/WXxxFqT8VVa\n\t\t\t\t\t\tvkVcbTLRcJHyGdZsf++gt0fT+WmWbQsVC0Y1ILG/LNkfaA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.uk-plc.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.uk-plc.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.uk-plc.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.uk-plc.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.uk-plc.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp.uk-plc.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.uk-plc.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp.uk-plc.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp.uk-plc.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp.uk-plc.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://adfs.hanze.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs.hanze.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-05-12T10:50:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/f5401f60caf9e9a56c1517c24d5c0546",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hanzehogeschool Groningen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hanzehogeschool Groningen"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/hanze.png",
                    "height": "26",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hanzehogeschool Groningen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hanze University Groningen"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hanzehogeschool Groningen"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hanze University Groningen"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hanze.nl"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hanze.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hanzehogeschool Groningen"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hanze University Groningen"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://federation.upf.pf/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dsi@upf.pf"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federation.upf.pf/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-05-31T22:29:12Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.upf.pf/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federation.upf.pf/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://federation.upf.pf/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "upf.pf"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.upf.pf"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Employee, Student"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnels, Etudiants"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of French Polynesia"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Polyn\u00e9sie fran\u00e7aise"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUFC0XwDnBlYK71GiAUaF7vx7MRXIwDQYJKoZIhvcNAQEF\nBQAwHDEaMBgGA1UEAxMRZmVkZXJhdGlvbi51cGYucGYwHhcNMTMwNDE4MDI1NjA5\nWhcNMzMwNDE4MDI1NjA5WjAcMRowGAYDVQQDExFmZWRlcmF0aW9uLnVwZi5wZjCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMKdTj5nsNnLZKNJKeb8m9lf\neGVP3AjbhAJo0Fc0KjE3mFUUOc8ScnvT5ms3tD3fvY4OM57ysI+6fXIfqks+K3fU\np6dbTUUA7EayO/AXEeEZIYmGobqhFbf/+HL+XbaNj6Fu66otgU83ENyz9hWKsd7L\nUoKc/IpYYb5lxRiZObLsD3cZLkQUdaEKmVqBnsl4QBRFgqbbujg9+b9yGc7S6tWt\ntiz0VU9mmDzYz7RvUg3rlxrt/XHTdv9pyNIBfXyWbHwBl20x9RLWantPh5B/gzMg\nNG9Gsxrg2s6jOJkWExAaJui9udv6ZG4Om006MXimSQQJQjefxaFf5tMPkohQuQMC\nAwEAAaNpMGcwRgYDVR0RBD8wPYIRZmVkZXJhdGlvbi51cGYucGaGKGh0dHBzOi8v\nZmVkZXJhdGlvbi51cGYucGYvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFErV+rWb\ndP0OnShtmHsMw4ScsryqMA0GCSqGSIb3DQEBBQUAA4IBAQCQtbM/X3jSinJzQ/iM\nGssEbM/bT5sysN1Y1rsSXCn/Voy27ikk5WN5dbfWZZ1KIYnZtFvJwk3JUUpAXvYS\nTjDkoYhatlfdXSR0ZDJUrtGeo+Rpf8s4Y1UX6EuiywKKU/rxUaGs5m4sG94Xixys\n+/WSNcRFx+Oub984KlUVGNJdFsW4QJhLm0SIlzhn1XmHyF8Zk6111bBBVXVGqO7r\nbA2FN5TC8+oLwbU4vngFuLBu3cNt0xDE5C3760iVBLU++kah8FBjAZQsK0dnXyM3\nJlfc1EsNYvnxkLXlrcZIC5yU8s+4ht45VLUahR9HNHB+sCw9hGlcbV3QigKTlJav\npbip"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Polyn\u00e9sie fran\u00e7aise"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.upf.pf"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Polyn\u00e9sie fran\u00e7aise"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://manage.federations.renam.md",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pocotilenco"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:leaf@renam.md"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Valentin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://manage.federations.renam.md",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://federations.renam.md"
              }
            ],
            "registration_instant": "2015-12-01T08:00:00Z",
            "registration_authority": "http://federations.renam.md/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "ro",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RENAM"
          },
          {
            "lang": "ru",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RENAM"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RENAM"
          }
        ],
        "organization_url": [
          {
            "lang": "ro",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://renam.md"
          },
          {
            "lang": "ru",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://renam.md"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://renam.md"
          }
        ],
        "organization_name": [
          {
            "lang": "ro",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RENAM"
          },
          {
            "lang": "ru",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RENAM"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RENAM"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://manage.federations.renam.md/ssphp/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://manage.federations.renam.md/ssphp/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://manage.federations.renam.md"
                  },
                  {
                    "lang": "ro",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://manage.federations.renam.md"
                  },
                  {
                    "lang": "ru",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://manage.federations.renam.md"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Federation Management Board - used to manage federation entitites and generate metadata"
                  },
                  {
                    "lang": "ro",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Sistem de Management al Federatiei - necesara pentru managementul entitatilor federative si generarea metadatelor"
                  },
                  {
                    "lang": "ru",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "\u041f\u0440\u0438\u043b\u043e\u0436\u0435\u043d\u0438\u0435 \u0434\u043b\u044f \u043c\u0435\u043d\u0435\u0434\u0436\u043c\u0435\u043d\u0442\u0430 \u0424\u0435\u0434\u0435\u0440\u0430\u0446\u0438\u0438 - \u043d\u0435\u043e\u0434\u0445\u043e\u0434\u0438\u043c\u043e \u0434\u043b\u044f \u0443\u043f\u0440\u0430\u0432\u043b\u0435\u043d\u0438\u044f \u0444\u0435\u0434\u0435\u0440\u0430\u0442\u0438\u0432\u043d\u044b\u043c\u0438 \u0441\u0435\u0440\u0432\u0438\u0441\u0430\u043c\u0438 \u0438 \u0433\u0435\u043d\u0435\u0440\u0430\u0446\u0438\u0438 \u043c\u0430\u0442\u0430-\u0434\u0430\u043d\u043d\u044b\u0445"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Federation Management Board"
                  },
                  {
                    "lang": "ro",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sistem de Management al Federatiei"
                  },
                  {
                    "lang": "ru",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u041f\u0440\u0438\u043b\u043e\u0436\u0435\u043d\u0438\u0435 \u0434\u043b\u044f \u043c\u0435\u043d\u0435\u0434\u0436\u043c\u0435\u043d\u0442\u0430 \u0424\u0435\u0434\u0435\u0440\u0430\u0446\u0438\u0438"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE6zCCA9OgAwIBAgICANMwDQYJKoZIhvcNAQELBQAwdDESMBAGCgmSJomT8ixk\nARkTAk1EMRcwFQYKCZImiZPyLGQBGRMHTUQtR3JpZDEOMAwGA1UEChMFUkVOQU0x\nIDAeBgNVBAsTF0NlcnRpZmljYXRpb24gQXV0aG9yaXR5MRMwEQYDVQQDEwpNRC1H\ncmlkIENBMB4XDTE1MTEyNTA4MzEyNFoXDTI1MTEyMjA4MzEyNFowYDESMBAGCgmS\nJomT8ixkARkWAk1EMRowGAYKCZImiZPyLGQBGRYKRmVkZXJhdGlvbjEOMAwGA1UE\nChMFUkVOQU0xHjAcBgNVBAMTFU1hbmFnZVNlcnZpY2VNZXRhU2lnbjCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN0ctV8e4QOli52mhR6sc4MImsPDodie\nhe/uqVoAfhsxumuf6vR5oHvgy4QQGC/zJxEfWbI2hKlCCkH9tRBerYgu90vMMCZe\nd+INTGvskp28hDXki1Luj5DnzcTjuF9M7M8PRfa/nmYp5e33+Kh87UX6Jo9ekWMr\npEKMEgR2UeJt+2vzQGDCYrI2NhDX1u20eZfVBP+gJNkxFSLH+cXICMe2P3z8vy5g\nL22wdJC+ep7XCqPPpRn50qKJF2nT0aopMggY7cCBxo0QAkt9t3qCvwTnHasMU+Ov\n9I0+TLJ2exn8/vBA1nicToanXyZNlYjD1kJHsw0gWh+a+1wHG/kkfe8CAwEAAaOC\nAZkwggGVMB0GA1UdDgQWBBRgFwRz+fla6Dkajz7A+0RDKvolTjAfBgNVHSMEGDAW\ngBQHQ26bo1u5q+z02L86Gw2jKbg1YjA6BggrBgEFBQcBAQQuMCwwKgYIKwYBBQUH\nMAKGHmh0dHA6Ly9jYS5ncmlkLm1kL2ZpbGVzL2NhLmNydDAzBgNVHR8ELDAqMCig\nJqAkhiJodHRwOi8vY2EuZ3JpZC5tZC9maWxlcy9jcmwtdjIuY3JsMCkGA1UdEgQi\nMCCBC2NhQHJlbmFtLm1khhFodHRwOi8vY2EuZ3JpZC5tZDCBtgYDVR0gBIGuMIGr\nMA4GDCsGAQQBgfNaCgEBBDCBmAYKKoZIhvdMBQICATCBiTA2BggrBgEFBQcCARYq\naHR0cDovL2NhLmdyaWQubWQvZmlsZXMvTUQtR3JpZC1DUC1DUFMucGRmME8GCCsG\nAQUFBwICMEMaQUxpbWl0ZWQgTGlhYmlsaXR5LCBzZWUgaHR0cDovL2NhLmdyaWQu\nbWQvZmlsZXMvTUQtR3JpZC1DUC1DUFMucGRmMA0GCSqGSIb3DQEBCwUAA4IBAQC6\nKJuZeroALfPd32ft7vDVrU2olrWlK83Xvgjy6BRbd9ksBxuFUCAYbZxYWhWiNCUG\n2xn7nKLWjs51sSeDqFPVzNsAaU/MGr3TvFcxH1gyaIZQNkXVZcRbi93SdVfmnl9Z\n1R86aJxShVN6wOTAWyMSkzh3VGVGK9IeA57WoDAGuxvDVgxURO+lpkY0QztOMK9m\nDOFfR5TiqEahO0z7zUInQbg7LEgwDazK7BuDbirKdQhncGYCVG1dg3Qq09vJdSS4\nUgVNSVjlMzKBjhjGa9KhyOQZozleonKnk1o/cblzPGClGgcZeqElC6YXDpJzlSqt\nQDG9g0AnMyza3V7kLiDz"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE6zCCA9OgAwIBAgICANMwDQYJKoZIhvcNAQELBQAwdDESMBAGCgmSJomT8ixk\nARkTAk1EMRcwFQYKCZImiZPyLGQBGRMHTUQtR3JpZDEOMAwGA1UEChMFUkVOQU0x\nIDAeBgNVBAsTF0NlcnRpZmljYXRpb24gQXV0aG9yaXR5MRMwEQYDVQQDEwpNRC1H\ncmlkIENBMB4XDTE1MTEyNTA4MzEyNFoXDTI1MTEyMjA4MzEyNFowYDESMBAGCgmS\nJomT8ixkARkWAk1EMRowGAYKCZImiZPyLGQBGRYKRmVkZXJhdGlvbjEOMAwGA1UE\nChMFUkVOQU0xHjAcBgNVBAMTFU1hbmFnZVNlcnZpY2VNZXRhU2lnbjCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN0ctV8e4QOli52mhR6sc4MImsPDodie\nhe/uqVoAfhsxumuf6vR5oHvgy4QQGC/zJxEfWbI2hKlCCkH9tRBerYgu90vMMCZe\nd+INTGvskp28hDXki1Luj5DnzcTjuF9M7M8PRfa/nmYp5e33+Kh87UX6Jo9ekWMr\npEKMEgR2UeJt+2vzQGDCYrI2NhDX1u20eZfVBP+gJNkxFSLH+cXICMe2P3z8vy5g\nL22wdJC+ep7XCqPPpRn50qKJF2nT0aopMggY7cCBxo0QAkt9t3qCvwTnHasMU+Ov\n9I0+TLJ2exn8/vBA1nicToanXyZNlYjD1kJHsw0gWh+a+1wHG/kkfe8CAwEAAaOC\nAZkwggGVMB0GA1UdDgQWBBRgFwRz+fla6Dkajz7A+0RDKvolTjAfBgNVHSMEGDAW\ngBQHQ26bo1u5q+z02L86Gw2jKbg1YjA6BggrBgEFBQcBAQQuMCwwKgYIKwYBBQUH\nMAKGHmh0dHA6Ly9jYS5ncmlkLm1kL2ZpbGVzL2NhLmNydDAzBgNVHR8ELDAqMCig\nJqAkhiJodHRwOi8vY2EuZ3JpZC5tZC9maWxlcy9jcmwtdjIuY3JsMCkGA1UdEgQi\nMCCBC2NhQHJlbmFtLm1khhFodHRwOi8vY2EuZ3JpZC5tZDCBtgYDVR0gBIGuMIGr\nMA4GDCsGAQQBgfNaCgEBBDCBmAYKKoZIhvdMBQICATCBiTA2BggrBgEFBQcCARYq\naHR0cDovL2NhLmdyaWQubWQvZmlsZXMvTUQtR3JpZC1DUC1DUFMucGRmME8GCCsG\nAQUFBwICMEMaQUxpbWl0ZWQgTGlhYmlsaXR5LCBzZWUgaHR0cDovL2NhLmdyaWQu\nbWQvZmlsZXMvTUQtR3JpZC1DUC1DUFMucGRmMA0GCSqGSIb3DQEBCwUAA4IBAQC6\nKJuZeroALfPd32ft7vDVrU2olrWlK83Xvgjy6BRbd9ksBxuFUCAYbZxYWhWiNCUG\n2xn7nKLWjs51sSeDqFPVzNsAaU/MGr3TvFcxH1gyaIZQNkXVZcRbi93SdVfmnl9Z\n1R86aJxShVN6wOTAWyMSkzh3VGVGK9IeA57WoDAGuxvDVgxURO+lpkY0QztOMK9m\nDOFfR5TiqEahO0z7zUInQbg7LEgwDazK7BuDbirKdQhncGYCVG1dg3Qq09vJdSS4\nUgVNSVjlMzKBjhjGa9KhyOQZozleonKnk1o/cblzPGClGgcZeqElC6YXDpJzlSqt\nQDG9g0AnMyza3V7kLiDz"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://manage.federations.renam.md/ssphp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://manage.federations.renam.md/ssphp/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://manage.federations.renam.md/ssphp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://manage.federations.renam.md/ssphp/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Federation Management Board"
                },
                {
                  "lang": "ro",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Sistem de Management al Federatiei"
                },
                {
                  "lang": "ru",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "\u041f\u0440\u0438\u043b\u043e\u0436\u0435\u043d\u0438\u0435 \u0434\u043b\u044f \u043c\u0435\u043d\u0435\u0434\u0436\u043c\u0435\u043d\u0442\u0430 \u0424\u0435\u0434\u0435\u0440\u0430\u0446\u0438\u0438"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Federation Management Board - used to manage federation entitites and generate metadata"
                },
                {
                  "lang": "ro",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Sistem de Management al Federatiei - necesara pentru managementul entitatilor federative si generarea metadatelor"
                },
                {
                  "lang": "ru",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "\u041f\u0440\u0438\u043b\u043e\u0436\u0435\u043d\u0438\u0435 \u0434\u043b\u044f \u043c\u0435\u043d\u0435\u0434\u0436\u043c\u0435\u043d\u0442\u0430 \u0424\u0435\u0434\u0435\u0440\u0430\u0446\u0438\u0438 - \u043d\u0435\u043e\u0434\u0445\u043e\u0434\u0438\u043c\u043e \u0434\u043b\u044f \u0443\u043f\u0440\u0430\u0432\u043b\u0435\u043d\u0438\u044f \u0444\u0435\u0434\u0435\u0440\u0430\u0442\u0438\u0432\u043d\u044b\u043c\u0438 \u0441\u0435\u0440\u0432\u0438\u0441\u0430\u043c\u0438 \u0438 \u0433\u0435\u043d\u0435\u0440\u0430\u0446\u0438\u0438 \u043c\u0430\u0442\u0430-\u0434\u0430\u043d\u043d\u044b\u0445"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "surname",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "uid",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "commonName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "transientId",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.2.3.4.5.6.7.8.9.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:incommon:rock.k12.nc.us",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ksensenich@rock.k12.nc.us"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kacey Sensenich"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "wgoins@rock.k12.nc.us"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Wanda Goins"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:rock.k12.nc.us",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.rock.k12.nc.us:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.rock.k12.nc.us:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPjCCAiagAwIBAgIJAPmR55t2JpqLMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE3NoaWIucm9jay5rMTIubmMudXMwHhcNMTMxMjE4MTcxMzAxWhcNMzQwMTA4\nMTcxMzAxWjAeMRwwGgYDVQQDExNzaGliLnJvY2suazEyLm5jLnVzMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAlBZdzVkY+qjXvyQSQ+OWA6fTFgvtmAZW\nw9KIs5IvL0trjOwMZLjGYWzUpRcirb9EW6XLC5A2ZW/FuVfIHYO70EOczz+7pW4h\n8JTHbhdm3nqC1OWeRv3RpKL0N+MHBVIV+3F85xPpWVqVTzpePA98HRKaJkjLPtcm\nHWYrA1+j6jUXIpdOs4BKuywQCTF62NHovNyV7Q+Dq2x3RmXRNSNCobXgvja1jXnC\nDISVtj52UDsjZC8WONKbQ+Rx7qWlFGYqiCJ77m0+rj7HCDaxIWC5qzRSfY8T1DIn\nNUS8bR50+JhV76cIzgvkq9K1uvlZoXkAMdo1t4G2otTJC8HjnSRvdwIDAQABo38w\nfTAdBgNVHQ4EFgQUruM5s76Piz3hAqGOEkjj+R5zJIowTgYDVR0jBEcwRYAUruM5\ns76Piz3hAqGOEkjj+R5zJIqhIqQgMB4xHDAaBgNVBAMTE3NoaWIucm9jay5rMTIu\nbmMudXOCCQD5keebdiaaizAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IB\nAQBs9xg8DRa/Ph2e+ysJCjFAbo13N0C9tKHEjZlxQsuRVCFVsjBSB6RSMpKJdhlU\nJ7D11R7XhUR/w6dMlz1Wa03FOYbLh4xEACQ2KOhilYXFEF5ucrRbtc/RmfnFf2ag\n+ENPkZ+gwZytp9W7XWQQ9xYVe3jw8nNH5/+D9PKDHaoPCxLMzqFcUL6NNOC6HQ6n\nrUL38YTy5o779bOJWt7b7V3V/u4/Ckc5xIYHTgZWBo9o1GWpgNkszitRBBiQryZf\n8b7euuy4mlqaPv6zyudJOcHupn8GhHdekfNicDem60M4vl96TpHurp9ifSH2NGEb\nj0Gw0iewVqKmJYc2NtrfKI3T"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPjCCAiagAwIBAgIJANtc2N1zb53NMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE3NoaWIucm9jay5rMTIubmMudXMwHhcNMTEwNDA3MTQxMDU3WhcNMTQwNDA2\nMTQxMDU3WjAeMRwwGgYDVQQDExNzaGliLnJvY2suazEyLm5jLnVzMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAlBZdzVkY+qjXvyQSQ+OWA6fTFgvtmAZW\nw9KIs5IvL0trjOwMZLjGYWzUpRcirb9EW6XLC5A2ZW/FuVfIHYO70EOczz+7pW4h\n8JTHbhdm3nqC1OWeRv3RpKL0N+MHBVIV+3F85xPpWVqVTzpePA98HRKaJkjLPtcm\nHWYrA1+j6jUXIpdOs4BKuywQCTF62NHovNyV7Q+Dq2x3RmXRNSNCobXgvja1jXnC\nDISVtj52UDsjZC8WONKbQ+Rx7qWlFGYqiCJ77m0+rj7HCDaxIWC5qzRSfY8T1DIn\nNUS8bR50+JhV76cIzgvkq9K1uvlZoXkAMdo1t4G2otTJC8HjnSRvdwIDAQABo38w\nfTAdBgNVHQ4EFgQUruM5s76Piz3hAqGOEkjj+R5zJIowTgYDVR0jBEcwRYAUruM5\ns76Piz3hAqGOEkjj+R5zJIqhIqQgMB4xHDAaBgNVBAMTE3NoaWIucm9jay5rMTIu\nbmMudXOCCQDbXNjdc2+dzTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IB\nAQBsz6rnvJbbWYSsOW1ZQRa6d4MwOQJyC1MSlVBWgkF78tROYcd4odLNJPWB26Vs\nVJOlu173WyK26NdTPk35aAI0Y6Hl927DTyoa+GQM//JKM9CUXvhBGr9Ly5+fcKYO\nylAMffw3Mgw18H6IejfhvJZgF64Dysp+IZe+8WPhPuzqJwSlkLdS9HXNHyxBHtBl\nagNbI0Gj1/d2JrAMlId3wZu1Z/tbZHndIypnUTW/PToLtkUjlrH8naMXYx3oTuP6\nOzXh12tNCnBxCY6icNDRtdN30nH0uDt11VfENHv5C5mKxr7w2uDTLdBjEL0HPh0m\nr1ynZK4DSpncepmCHNLOHwCG"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rock.k12.nc.us"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.rock.k12.nc.us/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.rock.k12.nc.us/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.rock.k12.nc.us/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.rock.k12.nc.us/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.rock.k12.nc.us:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.rock.k12.nc.us:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rock.k12.nc.us"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rockingham County Schools"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPjCCAiagAwIBAgIJAPmR55t2JpqLMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE3NoaWIucm9jay5rMTIubmMudXMwHhcNMTMxMjE4MTcxMzAxWhcNMzQwMTA4\nMTcxMzAxWjAeMRwwGgYDVQQDExNzaGliLnJvY2suazEyLm5jLnVzMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAlBZdzVkY+qjXvyQSQ+OWA6fTFgvtmAZW\nw9KIs5IvL0trjOwMZLjGYWzUpRcirb9EW6XLC5A2ZW/FuVfIHYO70EOczz+7pW4h\n8JTHbhdm3nqC1OWeRv3RpKL0N+MHBVIV+3F85xPpWVqVTzpePA98HRKaJkjLPtcm\nHWYrA1+j6jUXIpdOs4BKuywQCTF62NHovNyV7Q+Dq2x3RmXRNSNCobXgvja1jXnC\nDISVtj52UDsjZC8WONKbQ+Rx7qWlFGYqiCJ77m0+rj7HCDaxIWC5qzRSfY8T1DIn\nNUS8bR50+JhV76cIzgvkq9K1uvlZoXkAMdo1t4G2otTJC8HjnSRvdwIDAQABo38w\nfTAdBgNVHQ4EFgQUruM5s76Piz3hAqGOEkjj+R5zJIowTgYDVR0jBEcwRYAUruM5\ns76Piz3hAqGOEkjj+R5zJIqhIqQgMB4xHDAaBgNVBAMTE3NoaWIucm9jay5rMTIu\nbmMudXOCCQD5keebdiaaizAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IB\nAQBs9xg8DRa/Ph2e+ysJCjFAbo13N0C9tKHEjZlxQsuRVCFVsjBSB6RSMpKJdhlU\nJ7D11R7XhUR/w6dMlz1Wa03FOYbLh4xEACQ2KOhilYXFEF5ucrRbtc/RmfnFf2ag\n+ENPkZ+gwZytp9W7XWQQ9xYVe3jw8nNH5/+D9PKDHaoPCxLMzqFcUL6NNOC6HQ6n\nrUL38YTy5o779bOJWt7b7V3V/u4/Ckc5xIYHTgZWBo9o1GWpgNkszitRBBiQryZf\n8b7euuy4mlqaPv6zyudJOcHupn8GhHdekfNicDem60M4vl96TpHurp9ifSH2NGEb\nj0Gw0iewVqKmJYc2NtrfKI3T"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPjCCAiagAwIBAgIJANtc2N1zb53NMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE3NoaWIucm9jay5rMTIubmMudXMwHhcNMTEwNDA3MTQxMDU3WhcNMTQwNDA2\nMTQxMDU3WjAeMRwwGgYDVQQDExNzaGliLnJvY2suazEyLm5jLnVzMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAlBZdzVkY+qjXvyQSQ+OWA6fTFgvtmAZW\nw9KIs5IvL0trjOwMZLjGYWzUpRcirb9EW6XLC5A2ZW/FuVfIHYO70EOczz+7pW4h\n8JTHbhdm3nqC1OWeRv3RpKL0N+MHBVIV+3F85xPpWVqVTzpePA98HRKaJkjLPtcm\nHWYrA1+j6jUXIpdOs4BKuywQCTF62NHovNyV7Q+Dq2x3RmXRNSNCobXgvja1jXnC\nDISVtj52UDsjZC8WONKbQ+Rx7qWlFGYqiCJ77m0+rj7HCDaxIWC5qzRSfY8T1DIn\nNUS8bR50+JhV76cIzgvkq9K1uvlZoXkAMdo1t4G2otTJC8HjnSRvdwIDAQABo38w\nfTAdBgNVHQ4EFgQUruM5s76Piz3hAqGOEkjj+R5zJIowTgYDVR0jBEcwRYAUruM5\ns76Piz3hAqGOEkjj+R5zJIqhIqQgMB4xHDAaBgNVBAMTE3NoaWIucm9jay5rMTIu\nbmMudXOCCQDbXNjdc2+dzTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IB\nAQBsz6rnvJbbWYSsOW1ZQRa6d4MwOQJyC1MSlVBWgkF78tROYcd4odLNJPWB26Vs\nVJOlu173WyK26NdTPk35aAI0Y6Hl927DTyoa+GQM//JKM9CUXvhBGr9Ly5+fcKYO\nylAMffw3Mgw18H6IejfhvJZgF64Dysp+IZe+8WPhPuzqJwSlkLdS9HXNHyxBHtBl\nagNbI0Gj1/d2JrAMlId3wZu1Z/tbZHndIypnUTW/PToLtkUjlrH8naMXYx3oTuP6\nOzXh12tNCnBxCY6icNDRtdN30nH0uDt11VfENHv5C5mKxr7w2uDTLdBjEL0HPh0m\nr1ynZK4DSpncepmCHNLOHwCG"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Rockingham County Schools"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rock.k12.nc.us/rockingham/site/default.asp"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Rockingham County Schools"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://capuccino.info.ufrn.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "SINFO"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "redes@info.ufrn.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://capuccino.info.ufrn.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC0jCCAboCAQAwDQYJKoZIhvcNAQEFBQAwLzEMMAoGA1UECxMDQ1BEMQswCQYD\n               VQQGEwJCUjESMBAGA1UEAxMJY2FwdWNjaW5vMB4XDTE0MDYwNTEzMTQ0OVoXDTE5\n               MDYwNDEzMTQ0OVowLzEMMAoGA1UECxMDQ1BEMQswCQYDVQQGEwJCUjESMBAGA1UE\n               AxMJY2FwdWNjaW5vMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1tLx\n               +5Q99cvQ6T4dFLqtoXnaeVtePhdogMKFxJsNwxWL901s+NPJT3f4dkEJ9rMry6g2\n               Wg9U+f96mY5iViRSP09RF6IPyHwU0xUh6gZE2ggvLKKbddkU9I380M3n0SJWRSXe\n               rMZwL1qiVEA+Ysgvh1CS+NWKmTzn1GC3MCUjB4mA8fdZ+Xh+SlCbSEtbTo0nQxqt\n               g2xx+t+jO2YZIawYp+pYEza5gMWTI58csYXijWzWV/SqaUXDN7nEd08UpLVyzKEf\n               rtFsA/U5/v3cqdQ3f9czTABbp6RQuN8sXJ1z/rpID+og2W3o0QmIaJ/GtocyEWtK\n               U8KkFewao0aPe2OITQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQAv43rE0bYSXgqb\n               PUkmyZn/EfLe9dsr6RFGfRWU3eSPIbcaZTf6cXuwWBc3sMURUMjRRNX1DsNpK9Yr\n               pFrHXusucXsnBz/1owJyFSNq2m0NZhSabKJvXS8KgvH237db1OP4hbqbZZ7PcTm/\n               CjCtIiYSn4O/xil76jd7B0vFMcICdWmojoJXJOuVuMGGERXhpI2pFC2X9LVafY1q\n               HiaTJ8XDtqq27T9Q2BYJBQoIjPPBF9wF3L4OCAJUCIs/I2vTaG3oR6gPVRo4AP01\n               XkH1cct5hhIN0719bcHVK1Rp9xpSWZT3DFO0qggrszg/du71sHZOQgW+z0tGH3BK\n               EnZQnP4F"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufrn.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://capuccino.info.ufrn.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://capuccino.info.ufrn.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://capuccino.info.ufrn.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://capuccino.info.ufrn.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://capuccino.info.ufrn.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://capuccino.info.ufrn.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://capuccino.info.ufrn.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://capuccino.info.ufrn.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufrn.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufrn.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufrn.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFRN - Universidade Federal do Rio Grande do Norte"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFRN - Universidade Federal do Rio Grande do Norte"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFRN - Universidade Federal do Rio Grande do Norte"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFRN - Universidade Federal do Rio Grande do Norte"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC0jCCAboCAQAwDQYJKoZIhvcNAQEFBQAwLzEMMAoGA1UECxMDQ1BEMQswCQYD\n               VQQGEwJCUjESMBAGA1UEAxMJY2FwdWNjaW5vMB4XDTE0MDYwNTEzMTQ0OVoXDTE5\n               MDYwNDEzMTQ0OVowLzEMMAoGA1UECxMDQ1BEMQswCQYDVQQGEwJCUjESMBAGA1UE\n               AxMJY2FwdWNjaW5vMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1tLx\n               +5Q99cvQ6T4dFLqtoXnaeVtePhdogMKFxJsNwxWL901s+NPJT3f4dkEJ9rMry6g2\n               Wg9U+f96mY5iViRSP09RF6IPyHwU0xUh6gZE2ggvLKKbddkU9I380M3n0SJWRSXe\n               rMZwL1qiVEA+Ysgvh1CS+NWKmTzn1GC3MCUjB4mA8fdZ+Xh+SlCbSEtbTo0nQxqt\n               g2xx+t+jO2YZIawYp+pYEza5gMWTI58csYXijWzWV/SqaUXDN7nEd08UpLVyzKEf\n               rtFsA/U5/v3cqdQ3f9czTABbp6RQuN8sXJ1z/rpID+og2W3o0QmIaJ/GtocyEWtK\n               U8KkFewao0aPe2OITQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQAv43rE0bYSXgqb\n               PUkmyZn/EfLe9dsr6RFGfRWU3eSPIbcaZTf6cXuwWBc3sMURUMjRRNX1DsNpK9Yr\n               pFrHXusucXsnBz/1owJyFSNq2m0NZhSabKJvXS8KgvH237db1OP4hbqbZZ7PcTm/\n               CjCtIiYSn4O/xil76jd7B0vFMcICdWmojoJXJOuVuMGGERXhpI2pFC2X9LVafY1q\n               HiaTJ8XDtqq27T9Q2BYJBQoIjPPBF9wF3L4OCAJUCIs/I2vTaG3oR6gPVRo4AP01\n               XkH1cct5hhIN0719bcHVK1Rp9xpSWZT3DFO0qggrszg/du71sHZOQgW+z0tGH3BK\n               EnZQnP4F"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFRN - Universidade Federal do Rio Grande do Norte"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFRN - Universidade Federal do Rio Grande do Norte"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufrn.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufrn.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFRN - Universidade Federal do Rio Grande do Norte"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFRN - Universidade Federal do Rio Grande do Norte"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://journals.bmj.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://journals.bmj.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-08-27T11:16:15Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "BMJ Journals"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://journals.bmj.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HighWire Press, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.highwire.org/applications/bmjjournals/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.highwire.org/applications/bmjjournals/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIJAMTRVlqTJ11lMA0GCSqGSIb3DQEBBQUAMIG+MQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBD\n\t\t\t\t\t\taXR5MRcwFQYDVQQKEw5IaWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUx\n\t\t\t\t\t\tIDAeBgNVBAMTF3NoaWJib2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkB\n\t\t\t\t\t\tFiZzaGliYm9sZXRoLWFkbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTAeFw0xNDA0\n\t\t\t\t\t\tMTUxOTQzMDNaFw0yNDA0MTIxOTQzMDNaMIG+MQswCQYDVQQGEwJVUzETMBEGA1UE\n\t\t\t\t\t\tCBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBDaXR5MRcwFQYDVQQKEw5I\n\t\t\t\t\t\taWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUxIDAeBgNVBAMTF3NoaWJi\n\t\t\t\t\t\tb2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkBFiZzaGliYm9sZXRoLWFk\n\t\t\t\t\t\tbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALPB99M9iWjentrddY/rLgzKn1X0j4Ao191iyiowBBt/r/pmn2oz\n\t\t\t\t\t\tfrbONkkTVBB++mNtiufK6jyKnBM5mffPOkXHRo+K1DQec7TvpQ1PmLv/BpBgPrr9\n\t\t\t\t\t\tldViOSUnYJuB0IgJVV8oylgeH2Ay0XRkNPlBUjBA2fUPWVpXcvFe+aD2tLdVR9uO\n\t\t\t\t\t\tXvfTMxAEGqzxTU+OxO6pW2sBXNBmGvZQ0TRyovQh5+pTURY/lm0V/iWvRmRe51WE\n\t\t\t\t\t\tO/nhYyvRuMmNj8EL38o10S9TXuCkVzY00hK5cclaFge7gz/tfjmadVVcbe8xCVxc\n\t\t\t\t\t\tnb1lhmt1kH2XtKvU5hyZMTO+VUfXQvqcQyECAwEAAaN7MHkwCQYDVR0TBAIwADAs\n\t\t\t\t\t\tBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYD\n\t\t\t\t\t\tVR0OBBYEFJpUZq/XaW9/bPvjffkxX0IDvuPiMB8GA1UdIwQYMBaAFJpUZq/XaW9/\n\t\t\t\t\t\tbPvjffkxX0IDvuPiMA0GCSqGSIb3DQEBBQUAA4IBAQCq/FF56ZB1cL3KbniEJP99\n\t\t\t\t\t\tU9wTD6KpOrWxvqNbUSV1cefLf5cYHonOjy6oAJSSBSNuP7U5Q//0tXtkvlJoqGUY\n\t\t\t\t\t\tvqngmeg9wLZ/Fla3tXcDdTj0n1F+NZOx9vBDacIk0Ua4aHXDA4bdytzkV1QyZDRq\n\t\t\t\t\t\tQ8vq7RoQ8E5IF7Cll+kt2dZXQk8o6Qp3w2ppoMRtYdKOQassqn+V1MYcMPgdxZkS\n\t\t\t\t\t\tDrcgzktR/JMb5OmPrp4mSy1OWDGrFvUIigsLBPZV9tw1f7y42lnbmQas3RCS30yr\n\t\t\t\t\t\tCtUPT/PQDkCdBRViGmmMkYwjdaOTiHOJveWtrVXu8vLvO36pqFF4Kft0pgqlfvAE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.highwire.org/applications/bmjjournals/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.highwire.org/applications/bmjjournals/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.highwire.org/applications/bmjjournals/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.highwire.org/applications/bmjjournals/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://fed.p.lodz.pl/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:bok@p.lodz.pl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Biura Obs\u0142ugi Klient\u00f3w Centrum Komputerowego"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://fed.p.lodz.pl/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.pionier.net.pl/en/index.php?page=rps"
              }
            ],
            "registration_instant": "2015-08-03T00:00:00Z",
            "registration_authority": "https://aai.pionier.net.pl",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://fed.p.lodz.pl/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://fed.p.lodz.pl/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://fed.p.lodz.pl/idp/profile/SAML2/POST-SimpleSign/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://fed.p.lodz.pl:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://fed.p.lodz.pl/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://fed.p.lodz.pl/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://fed.p.lodz.pl/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://fed.p.lodz.pl/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://fed.p.lodz.pl:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://fed.p.lodz.pl:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "p.lodz.pl"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Lodz University of Technology"
                  },
                  {
                    "lang": "pl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Politechnika \u0141\u00f3dzka"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lodz University of Technology"
                  },
                  {
                    "lang": "pl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Politechnika \u0141\u00f3dzka"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUf92tx4MSZkG0nD2gvKf1684tQsYwDQYJKoZIhvcNAQEL\nBQAwGDEWMBQGA1UEAwwNZmVkLnAubG9kei5wbDAeFw0xNTAzMTkxMjIzNTJaFw0z\nNTAzMTkxMjIzNTJaMBgxFjAUBgNVBAMMDWZlZC5wLmxvZHoucGwwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQClJEvUpbTZ2twCfK6BPayJ+NOosjc+5yQQ\n82+oQPkK9AUBj3L5nG1d8S0ytNrP023FBEPHqlKrrP1IYFr6//tZMG77pz4iJkAI\nbP3ALXmd0DkDbEk5f0lZRbgicRsNUqG/XZ+YU2vptTM+qjeRN6oC4kTfy2hyT6ZT\nl0QFQudrh8DXXnC//2PcIp2LJOVpi/s0bkx17CsFe1wXKGiE+IRjxREwMPsjhZcL\n0kRyOWvNFgZJdYA7QwbwpX2r4JO9QtPJlj0r5a+AlmqFvXRrYHoZRY/xjiFsE5da\nLhA3/T/qpJTSuOLq/OAKdg7btY3NXyUVEA96YjLM7sB+3pH5f0LvAgMBAAGjYTBf\nMB0GA1UdDgQWBBSMCHpJHpAfliH4Oas5962Zaj4F9jA+BgNVHREENzA1gg1mZWQu\ncC5sb2R6LnBshiRodHRwczovL2ZlZC5wLmxvZHoucGwvaWRwL3NoaWJib2xldGgw\nDQYJKoZIhvcNAQELBQADggEBAFMj2tTRqW2cjCBtUrYQvkrbS9ThyMeskXqBlv8Z\nyuK5649zIrA3A9u/DYHum9bVf+gfvcIPfMTmBdcthMVTJIz4jD0B+Q6UdYO+YLnb\nGIHo5I6+5YcaiHG3vDJ8bwQQ0c3y2BV+xXazoPUHMQAQhw657P3zVVmXQrBL81S8\njrKFuLnw92jEyfvJvanV5hGLq6/sFIlFYMIXjVp60rkn/jYiVRy46GPZXzyuTQfN\nwnHFEgO9IZFWIfExNj8Vs2cWxZd4P6r6D7IXbeEtPz53yfi3t28vATtQKi12JHEC\n16rusRPe4GqH6oWfMN55z6Hl6dBDSFxv0xuqLKZZQOA5sa4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVALBJ54FSifljTYxqdKs9piNvZRmGMA0GCSqGSIb3DQEB\nCwUAMBgxFjAUBgNVBAMMDWZlZC5wLmxvZHoucGwwHhcNMTUwMzE5MTIyMzQ5WhcN\nMzUwMzE5MTIyMzQ5WjAYMRYwFAYDVQQDDA1mZWQucC5sb2R6LnBsMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAht1Z4j3LNunoGUj0Xg1mVFm1pC9G2h/W\nKJx9e6hpsQNeOV164mLeDocnSPZz0sN8yMOdtPKgRp11pqjxY80Y62fbmL4Z5VzR\nS5LSPb4RwK8bDt+Y5VrpEQfahyhKn4FTv0ONx3ayQHhBkeVtwv6m5OcKbohTP4KL\nGa//7AA1yUuSHOMsNs5Jl0+Qw+pnrqq0NdxuJNUVvpzmsy/LECw4yT1TYPtmKIT0\nBRoKFnptuAvUeuzI8X4Sk7nHPmnwkEVTCXm5KlCdRrrRAXOv75rCMnoHwlljGArW\nN8pr5Bi95j2/JTspzdD+Sd4ZJ2KL0RbLB7WJzxwdxdU2brJmzvyAHQIDAQABo2Ew\nXzAdBgNVHQ4EFgQU5pnJ2LRleP5CXaU7Q3p13pllUXQwPgYDVR0RBDcwNYINZmVk\nLnAubG9kei5wbIYkaHR0cHM6Ly9mZWQucC5sb2R6LnBsL2lkcC9zaGliYm9sZXRo\nMA0GCSqGSIb3DQEBCwUAA4IBAQAqca7YchwV5OSyMoKyVAka7UJfaUiL45t4lhjx\nGQK715ftzkPITSuOnt+xrx5JHLWyw47xNIj+W+HckkhnWpeQ4QQrEAO8T63pZrUv\nH+gOYWqKOaYum0D1+CaBen29Unts9Ie9hiqFg5yUy40LG10JYZeGcYMLw4f5b+Sz\nK9z2eS9vbYBf7F2snpz/PG2XWXhh3qgQAvQfgNhlT81IjRyYZQhjFKdw+Oiklp+Z\nJ25Z/5z3Qt2aL7DuQC5/9xfyPmI0K6fHnMIkpE+t9XGXLCvQgVmCzzudXLdaVIwf\nNzpyfHJJG9+8ns6iv60kTPTWKis5/IMSjcdeGmyUvDzEqs8I"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUNXScWBo43xj5lpqlUdGPP9YZL3QwDQYJKoZIhvcNAQEL\nBQAwGDEWMBQGA1UEAwwNZmVkLnAubG9kei5wbDAeFw0xNTAzMTkxMjIzNTBaFw0z\nNTAzMTkxMjIzNTBaMBgxFjAUBgNVBAMMDWZlZC5wLmxvZHoucGwwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQChdv4HP1QY4J29sh1jYKp5J0NAVAOyc1wv\nMBAtrEQYoVT3QETu5380X/ZBVwpOrxUa5andF6XcNxhK3TlTj6XqbOeEboL9yGqc\nHhu5GRFjHfTUmPKsEsuIPT7g8yVuR/kqVq7CvNkbi1hse2ZPDf0WXDmDJeG+DdXc\ntxyuRtG+mn/b5/faxneH7lNgK/Vv/ciM66ezNBtjqB94QtZNmCosuHJmzuEYbwMF\nNEFLBfNeaxdu5GPnHXZJdGRcoKzYIL3f5tEKMXV0OFnE5PekRiWl1rkPgDyLgY41\nwwz5l9J1lere/jSxRTJJxXdg9KVc9CtRyCSKh41Z7jlaAP7Oy3mdAgMBAAGjYTBf\nMB0GA1UdDgQWBBTuGHz++Xnn/VzfXKWxhyTT+h9CXTA+BgNVHREENzA1gg1mZWQu\ncC5sb2R6LnBshiRodHRwczovL2ZlZC5wLmxvZHoucGwvaWRwL3NoaWJib2xldGgw\nDQYJKoZIhvcNAQELBQADggEBAFi7u1NDWSQzg9qV3Jfc6kXX/JoBYw4fD0E4dUSg\ne4Dt2jDy42Psv1lBedpDN9Z/SWCl5C9X5qFRh6aGOTC1Az/j0XNuU4l9lx4DBXyO\n8Go9+znYd2l5bLkekCh2FF/EhCCHikhG0BAzc/m3n/FI+SC+pR3noUkTFChsj/YO\nv+rTqPYf+nXDtjzxOTy7iXJewLd0AaC4cK9BeOED5RyZADtK76zhv9pkUJwK1mWr\nnneqUZTQqcy82KLNUIk6u943LlhuqCXzy/idqKydkbAMxo4ZtL6mLFIBuAgU8Tm7\n4J3XCqnActMT97Zf5r6j4RjYBhiuFU30SvNV857zAr+/noQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lodz University of Technology"
          },
          {
            "lang": "pl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Politechnika \u0141\u00f3dzka"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.p.lodz.pl"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Lodz University of Technology"
          },
          {
            "lang": "pl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Politechnika \u0141\u00f3dzka"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibb.ws.seemis.gov.scot/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:letters@seemis.gov.scot"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SEEMIS Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mountfort"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ian.mountfort@seemis.gov.scot"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibb.ws.seemis.gov.scot/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SEEMIS Group LLP: Glow Services"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.seemis.gov.scot/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SEEMIS Group LLP"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC1jCCAb6gAwIBAgIJANnFj5LehaRsMA0GCSqGSIb3DQEBBQUAMBAxDjAMBgNV\n\t\t\t\t\t\tBAMTBXNoaWJiMB4XDTEwMDkxMzE0MjEyMloXDTIwMDkxMDE0MjEyMlowEDEOMAwG\n\t\t\t\t\t\tA1UEAxMFc2hpYmIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCtSXC9\n\t\t\t\t\t\t5Iq68ruXAxPoscW47pepV3+UBJne3/lJ5VxdI3n3QbmM0GfMrd3jDkS4r2BgnYF1\n\t\t\t\t\t\tveTqa9BCCGKh5Hp6ISDo9dZ4Si/zllypDYhOmcBBbuUr/bjAj7y7hjp9Q18yHBnO\n\t\t\t\t\t\tFmeYQIXfI5Q5gbEaTT3JCON+65nVMH3rifQvoGU9Dbxwo2INR0lmZtLBpPgeq+2i\n\t\t\t\t\t\tGt+FKLOOOey0ydB0eKD2qDASoqQhOKKNTvgxmWGWiXQwswRQNygLyvbnJ+pIf0GG\n\t\t\t\t\t\tYyHCyplLkq99nEeChSx7wSjaiD9J5uUDEICJAZo6V6vqNC+DJu6Ztx4Tq1w39m0A\n\t\t\t\t\t\tQuwgWV4d5XQTLnftAgMBAAGjMzAxMBAGA1UdEQQJMAeCBXNoaWJiMB0GA1UdDgQW\n\t\t\t\t\t\tBBTuy95SjJcKxjwAb2d7iwYOHVJMETANBgkqhkiG9w0BAQUFAAOCAQEAOeOhi+4R\n\t\t\t\t\t\tGhqXhKLiw8yUCOSff4x+dDfjzseeWUeBhVyYeMsAklANvDE7nlKB8gcQv9HgHaLC\n\t\t\t\t\t\tfbo2bGQegAumPYkNBbLbHk5wMM9lcKV+h08ak54ufgY5dxdKN2YYl9EC56egzuJg\n\t\t\t\t\t\thTWoSRbwML5X6CGKuKMLSCiEVJXS8hmZHJl1kxmwXKAqArUhFwhfFMYxBbXnBUSV\n\t\t\t\t\t\tgI3Rbjt43XXJJEt6BhLaLVxqmzndyabdI2u3zx6CdtvFynSPDOA/p8Rifcrfzt20\n\t\t\t\t\t\tl5nkqOEMNUx0VHYCZ/W+pt8AmPMWGRWjL2wcUndgwrdBVqaeT7Dmz7ozeniJbF1n\n\t\t\t\t\t\tmCaszq2WwCToAw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC1jCCAb6gAwIBAgIJANnFj5LehaRsMA0GCSqGSIb3DQEBBQUAMBAxDjAMBgNV\n\t\t\t\t\t\tBAMTBXNoaWJiMB4XDTEwMDkxMzE0MjEyMloXDTIwMDkxMDE0MjEyMlowEDEOMAwG\n\t\t\t\t\t\tA1UEAxMFc2hpYmIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCtSXC9\n\t\t\t\t\t\t5Iq68ruXAxPoscW47pepV3+UBJne3/lJ5VxdI3n3QbmM0GfMrd3jDkS4r2BgnYF1\n\t\t\t\t\t\tveTqa9BCCGKh5Hp6ISDo9dZ4Si/zllypDYhOmcBBbuUr/bjAj7y7hjp9Q18yHBnO\n\t\t\t\t\t\tFmeYQIXfI5Q5gbEaTT3JCON+65nVMH3rifQvoGU9Dbxwo2INR0lmZtLBpPgeq+2i\n\t\t\t\t\t\tGt+FKLOOOey0ydB0eKD2qDASoqQhOKKNTvgxmWGWiXQwswRQNygLyvbnJ+pIf0GG\n\t\t\t\t\t\tYyHCyplLkq99nEeChSx7wSjaiD9J5uUDEICJAZo6V6vqNC+DJu6Ztx4Tq1w39m0A\n\t\t\t\t\t\tQuwgWV4d5XQTLnftAgMBAAGjMzAxMBAGA1UdEQQJMAeCBXNoaWJiMB0GA1UdDgQW\n\t\t\t\t\t\tBBTuy95SjJcKxjwAb2d7iwYOHVJMETANBgkqhkiG9w0BAQUFAAOCAQEAOeOhi+4R\n\t\t\t\t\t\tGhqXhKLiw8yUCOSff4x+dDfjzseeWUeBhVyYeMsAklANvDE7nlKB8gcQv9HgHaLC\n\t\t\t\t\t\tfbo2bGQegAumPYkNBbLbHk5wMM9lcKV+h08ak54ufgY5dxdKN2YYl9EC56egzuJg\n\t\t\t\t\t\thTWoSRbwML5X6CGKuKMLSCiEVJXS8hmZHJl1kxmwXKAqArUhFwhfFMYxBbXnBUSV\n\t\t\t\t\t\tgI3Rbjt43XXJJEt6BhLaLVxqmzndyabdI2u3zx6CdtvFynSPDOA/p8Rifcrfzt20\n\t\t\t\t\t\tl5nkqOEMNUx0VHYCZ/W+pt8AmPMWGRWjL2wcUndgwrdBVqaeT7Dmz7ozeniJbF1n\n\t\t\t\t\t\tmCaszq2WwCToAw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibb.ws.seemis.gov.scot/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibb.ws.seemis.gov.scot/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://meta.swamid.se/shibboleth",
    {
      "entity_id": "https://meta.swamid.se/shibboleth",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish Academic Identity Federation (SWAMID)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.swamid.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SWAMID"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://meta.swamid.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://meta.swamid.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://meta.swamid.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://meta.swamid.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://meta.swamid.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://meta.swamid.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://meta.swamid.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Metadata service at SWAMID"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Metadata service at SWAMID"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "meta.swamid.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJAO86gLrkwwP3MA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDm1ldGEuc3dhbWlkLnNlMB4XDTE0MDMxMzEyMjYzNloXDTI0MDMxMDEyMjYz\nNlowGTEXMBUGA1UEAxMObWV0YS5zd2FtaWQuc2UwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDZVfts97pzO7DCqNPgK3do1xRdwwJ85kbhzb0azMGZHTqh\nBowZu+DgMPPeZ4/YFT8hO1HOoW9oEvV0qFgSrPYclFxTWrzlbHnika1wEBc8ukIX\nmdjdI1yGrk3bh50DTnkljuWbnwYPiWARIzyEL3vT4HP+5z+If5T0eaaL7u6qNZX7\nDKqhPnyF0OKT8am6MnN/VGS1FehKOulnHrkVgOeb43Rf5YbMy/2+UT6noaaJb28/\na4fwMp7uFJ7Nvx5O7AIeAmdy5eg5lqlHslQEIsD5K/KCRk1m2h0uMm5i6hSddjTR\ne7p42tXVBb8UbSUFNdne8jO+IVajxXRlBPw4S/bXAgMBAAGjPDA6MBkGA1UdEQQS\nMBCCDm1ldGEuc3dhbWlkLnNlMB0GA1UdDgQWBBTxCjCev8NEnf0Hqn+16Y9roCLU\nSzANBgkqhkiG9w0BAQUFAAOCAQEAnjDzcj7BU2afxo5h6OtV4a7zhfBMeq3S3gyw\nkLjbk1BRAJ7vWS2juhnVTP78g5sAkjIDbq/7V77mLBBt/7xqbwgOkPh5/i9lWTOV\nLAwqyhW3dEAqDAKQ3oTKPQR9OiHZ3wShNvHU+/7jKeecEShKb9ZUgGZGYYF6VTz7\nVWDuymgW+e7fOSXixyTpB3ED7kg24w4WaM7n59xlA3+Y9E5d+snpf8e7yrqwCZP1\novvypDjeN1LIIK6K1u6a+IpQDdBgkes//gOqD5/RTR3RPSAhZu/46eoCWxX4o8Xx\n4cWL7ZsFtqVIs30fEZPu0cco2tW8iiRcMYolr6q3vi5xtOH1Bg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=meta.swamid.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://meta.swamid.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://meta.swamid.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://meta.swamid.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://meta.swamid.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://meta.swamid.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://meta.swamid.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://meta.swamid.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://meta.swamid.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://meta.swamid.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.dias.ie/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bucas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jfbucas@stp.dias.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jean Francois"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bucas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jfbucas@stp.dias.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jean Francois"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bucas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jfbucas@stp.dias.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jean Francois"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.dias.ie/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.heanet.ie/services/identity-access/edugate#join"
              }
            ],
            "registration_instant": "2013-11-15T00:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.dias.ie/idp/profile/Logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.dias.ie/idp/profile/Logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.dias.ie/idp/profile/Logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://idp.dias.ie/idp/profile/Logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.dias.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.dias.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.dias.ie/idp/profile/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.dias.ie/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.dias.ie/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dias.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.dias.ie"
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/dias_logo.png",
                    "height": "112",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "136"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Dublin Institute for Advanced Studies"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUD82Rv6ZhMvwGESzIOJRkEtryOk4wDQYJKoZIhvcNAQEF\nBQAwFjEUMBIGA1UEAxMLaWRwLmRpYXMuaWUwHhcNMTMxMTE1MTAxODExWhcNMzMx\nMTE1MTAxODExWjAWMRQwEgYDVQQDEwtpZHAuZGlhcy5pZTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAINbJEvXC7qeIqXcCt3l6qrIw7ckk6FIy/rBBbO0\n0HkzFWd6JsOO3QZ8ymRgVeap9N1SycxIuox63M8sa89KwNVXAvNyDfrbvmbqIxzJ\nT5RmHl4ISgrsQubAWJ7eNiqVXiMvQe+e2A7iPpplPJYGqhvG/TB6F/4QDfGO+G9/\ntK+EdCvntS8wEy/s0UrDVOo+upvJnypzNJLcavfZWWwfjzR57Rcx48jTlRjZRe0R\n4/2rWS5yAJ8UhjBksoGD36ZHIpc1GFI5JeSNbGA7V501qhhjK9X09A+/NAlLGIj3\ns2ZJPfNGMPaY6Uc7u6sfEvwUJoz8kUnIV7Ac8HNw/d8Joi8CAwEAAaNdMFswOgYD\nVR0RBDMwMYILaWRwLmRpYXMuaWWGImh0dHBzOi8vaWRwLmRpYXMuaWUvaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFJ8KCzRdsORXHfsuXHNeCrKqR4owMA0GCSqGSIb3\nDQEBBQUAA4IBAQBPyzwZNTdiO9/RRp0f8hBqP0rOsO7mueuDbGvZoCPUEYiBkYiG\nzYB2DHkcfAYQls/vuI7DiuLWQC5COLsoDVgAW59VBrRKTRwpIjktvTM3C2aexomw\nGW7M9XqyiTdArQb3Inyl8Jca4HiniDEorh7OqjGEIakT4cIj8Vfu43b+E0L28otA\nGphiaINCWGdfHDfbsuc6fLoJp4WzSQHxGQEkkHE/XO6zWQLXPNuO9eU3MWwqw+or\nLlHiaoyxj0hM9NnJIllv1huBF7CHL4EadiizxS/nK2mx0vZgJVvQAOG6Kir3lbME\nh8KMdglIpPQmLF1/JtTN3QNn8SZmE7iel3kB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Dublin Institute for Advanced Studies"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dias.ie"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Dublin Institute for Advanced Studies"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.kmc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.kmc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/kmc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/kmc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kmc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Kingston Maurward College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kmc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.mdanderson.org/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idm@mdanderson.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MDACC IdM Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "4info@mdanderson.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MDACC 4Info"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.mdanderson.org/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.mdanderson.org:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.mdanderson.org:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAN9NaOe859o4m2yJ5DUijMku+q4tMA0GCSqGSIb3DQEB\nBQUAMB4xHDAaBgNVBAMTE3NoaWIubWRhbmRlcnNvbi5vcmcwHhcNMDkxMDAxMjI0\nNjAyWhcNMjkxMDAxMjI0NjAyWjAeMRwwGgYDVQQDExNzaGliLm1kYW5kZXJzb24u\nb3JnMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAiKDahIBcn1K0mp5A\nmT2zcPTNaRITSnkgajXbN12Wzwk2CFLJZ6QekzoeyhKGuUNgYXHcPnWJuoclpmXo\neX8C3egYAWorgC2LMjKvBMPCaSmH3ioe9avwOSCpG37Zw4ydWPJod2hy7h5NQedq\n9ath8J9I7U2q/Y5a/khlttR7o/7lGJHBCumAp+VnUEgLzUkAYbXo9gbdwC+GhdI1\nWx+msDZwq8qIgT679SUm6RHUfkHKZD352zCaP+VHxuX4uMUj/ue/2BnN0Z9RnHZ/\nxgDmURoSwokxnbLWodMV0Ny0eDvcpS9eEf5Zx04YFMJ3XpjnOxvvO4WaXt8WPcRT\nCHtEQwIDAQABo20wazBKBgNVHREEQzBBghNzaGliLm1kYW5kZXJzb24ub3Jnhipo\ndHRwczovL3NoaWIubWRhbmRlcnNvbi5vcmcvaWRwL3NoaWJib2xldGgwHQYDVR0O\nBBYEFALOifNwK+8AFuidZ/PXBFI5+j5BMA0GCSqGSIb3DQEBBQUAA4IBAQAzMZSH\n2QsL5RGHaHkM9+2fLesMDjPzd35RnbR1iRkcBi9eFvQah3pH1ITWNWRNsUbs+UUH\nuO44upcOk6VCbZ88rNeS6kE1BgSRNsRNTy/wJth/rsvIoAVek9arZNEMoBCCixGP\n81YR1OzjO2Egmcan0GsYCdPDowRcYEzEtLZGq8S5+0pa8vtEpa6UtakWsfTAZqFP\nt0OioSV7pwA9szQp2fCqvp61B5RP1zeUfWJIcjpKYlRCejwboHTN/S40bjxsXJ32\nc6j5VoHLH/WEfXJ262osyqeyDwVPyJZx7WWPWlYY3GCKYxwhrAZSA7A1u8VHe3wD\nqHwdXzHWzbbPX5x9"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mdanderson.org"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.mdanderson.org/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.mdanderson.org/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.mdanderson.org/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.mdanderson.org/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.mdanderson.org:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.mdanderson.org:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mdanderson.org"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Texas M.D. Anderson Cancer Center"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAN9NaOe859o4m2yJ5DUijMku+q4tMA0GCSqGSIb3DQEB\nBQUAMB4xHDAaBgNVBAMTE3NoaWIubWRhbmRlcnNvbi5vcmcwHhcNMDkxMDAxMjI0\nNjAyWhcNMjkxMDAxMjI0NjAyWjAeMRwwGgYDVQQDExNzaGliLm1kYW5kZXJzb24u\nb3JnMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAiKDahIBcn1K0mp5A\nmT2zcPTNaRITSnkgajXbN12Wzwk2CFLJZ6QekzoeyhKGuUNgYXHcPnWJuoclpmXo\neX8C3egYAWorgC2LMjKvBMPCaSmH3ioe9avwOSCpG37Zw4ydWPJod2hy7h5NQedq\n9ath8J9I7U2q/Y5a/khlttR7o/7lGJHBCumAp+VnUEgLzUkAYbXo9gbdwC+GhdI1\nWx+msDZwq8qIgT679SUm6RHUfkHKZD352zCaP+VHxuX4uMUj/ue/2BnN0Z9RnHZ/\nxgDmURoSwokxnbLWodMV0Ny0eDvcpS9eEf5Zx04YFMJ3XpjnOxvvO4WaXt8WPcRT\nCHtEQwIDAQABo20wazBKBgNVHREEQzBBghNzaGliLm1kYW5kZXJzb24ub3Jnhipo\ndHRwczovL3NoaWIubWRhbmRlcnNvbi5vcmcvaWRwL3NoaWJib2xldGgwHQYDVR0O\nBBYEFALOifNwK+8AFuidZ/PXBFI5+j5BMA0GCSqGSIb3DQEBBQUAA4IBAQAzMZSH\n2QsL5RGHaHkM9+2fLesMDjPzd35RnbR1iRkcBi9eFvQah3pH1ITWNWRNsUbs+UUH\nuO44upcOk6VCbZ88rNeS6kE1BgSRNsRNTy/wJth/rsvIoAVek9arZNEMoBCCixGP\n81YR1OzjO2Egmcan0GsYCdPDowRcYEzEtLZGq8S5+0pa8vtEpa6UtakWsfTAZqFP\nt0OioSV7pwA9szQp2fCqvp61B5RP1zeUfWJIcjpKYlRCejwboHTN/S40bjxsXJ32\nc6j5VoHLH/WEfXJ262osyqeyDwVPyJZx7WWPWlYY3GCKYxwhrAZSA7A1u8VHe3wD\nqHwdXzHWzbbPX5x9"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Texas M.D. Anderson Cancer Center"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mdanderson.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Texas M.D. Anderson Cancer Center"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://test.stir.unidesk.ac.uk/tas/secure/login/verify",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:is.helpline@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-certs@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Apps Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test.stir.unidesk.ac.uk/tas/secure/login/verify",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-05T13:49:49Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Test Unidesk - Stirling"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID2jCCAsKgAwIBAgIJALr8CP8PS5BEMA0GCSqGSIb3DQEBCwUAMFExIDAeBgNV\n\t\t\t\t\t\tBAMTF3Rlc3Quc3Rpci51bmlkZXNrLmFjLnVrMSAwHgYDVQQKExd0ZXN0LnN0aXIu\n\t\t\t\t\t\tdW5pZGVzay5hYy51azELMAkGA1UEBhMCVUswHhcNMTYwNDAxMTIzNzE5WhcNMjYw\n\t\t\t\t\t\tMzMwMTIzNzE5WjBRMSAwHgYDVQQDExd0ZXN0LnN0aXIudW5pZGVzay5hYy51azEg\n\t\t\t\t\t\tMB4GA1UEChMXdGVzdC5zdGlyLnVuaWRlc2suYWMudWsxCzAJBgNVBAYTAlVLMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApgFf2q8W/UjaWOZdNqr9EmOa\n\t\t\t\t\t\tWG0l2hEosA+IAHcKkdBNdMhNGzED45WLadguUY1F+Irnft2DF/52/rukG/XuFkM1\n\t\t\t\t\t\tSybLxZdme3ozG91w+TB86/BPTNOl16P2Q3QQ90FdkqZY/rWPMwIRVA5mjKuf6+1T\n\t\t\t\t\t\t5PL9/XpQC9JFwXmUXNsNsLJryDgm+13wugMPymrgWmFGZN2HYlSv5TF5mIxVQOYC\n\t\t\t\t\t\tSjsGZhu88GmRjMxHN1T6OAn7a4HA7/wlEfnl8SQ5TIWPRjQukN9hg/CpYC2zI17G\n\t\t\t\t\t\t/606x/P4lkJ37/NErZ/u4ueA4ymhyWSbLFX8MsFDymiTghJu/7N1Z9nY/ePklQID\n\t\t\t\t\t\tAQABo4G0MIGxMB0GA1UdDgQWBBRa1jo5LhT5i8tbKUA76iynFS7CnDCBgQYDVR0j\n\t\t\t\t\t\tBHoweIAUWtY6OS4U+YvLWylAO+ospxUuwpyhVaRTMFExIDAeBgNVBAMTF3Rlc3Qu\n\t\t\t\t\t\tc3Rpci51bmlkZXNrLmFjLnVrMSAwHgYDVQQKExd0ZXN0LnN0aXIudW5pZGVzay5h\n\t\t\t\t\t\tYy51azELMAkGA1UEBhMCVUuCCQC6/Aj/D0uQRDAMBgNVHRMEBTADAQH/MA0GCSqG\n\t\t\t\t\t\tSIb3DQEBCwUAA4IBAQAx2Xfd1pfAlPepfSX4KUPbhJaq+Z2695FVOW+KqBC/L6db\n\t\t\t\t\t\tjyUYQtoi1X9yge4FaVNt1GMMUv9XVcvH6O7UTLdXBiSXXW/BbhLzRgnf09Mtta0y\n\t\t\t\t\t\tskCRNaStwWbIrDFRegIk0rFUya3n2oR5B5ZW0ah7C93sxYbVbSMZmVfUpf/oZY79\n\t\t\t\t\t\tUZhImwhWAzMfvKgzPySFAXOmoShseo6hrOTyeWJgVxT4EKtifhyhdTZDkT8XykbX\n\t\t\t\t\t\tCA34rv87jODyi+dYGhbegFiuJoDo/9/weL0BH5N48yW18sSjRkURF5VXGbPMUx96\n\t\t\t\t\t\t8Knhux1hK+cTlx1vIfHtJa81w/f3BtS7gweYmKp4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID2jCCAsKgAwIBAgIJALr8CP8PS5BEMA0GCSqGSIb3DQEBCwUAMFExIDAeBgNV\n\t\t\t\t\t\tBAMTF3Rlc3Quc3Rpci51bmlkZXNrLmFjLnVrMSAwHgYDVQQKExd0ZXN0LnN0aXIu\n\t\t\t\t\t\tdW5pZGVzay5hYy51azELMAkGA1UEBhMCVUswHhcNMTYwNDAxMTIzNzE5WhcNMjYw\n\t\t\t\t\t\tMzMwMTIzNzE5WjBRMSAwHgYDVQQDExd0ZXN0LnN0aXIudW5pZGVzay5hYy51azEg\n\t\t\t\t\t\tMB4GA1UEChMXdGVzdC5zdGlyLnVuaWRlc2suYWMudWsxCzAJBgNVBAYTAlVLMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApgFf2q8W/UjaWOZdNqr9EmOa\n\t\t\t\t\t\tWG0l2hEosA+IAHcKkdBNdMhNGzED45WLadguUY1F+Irnft2DF/52/rukG/XuFkM1\n\t\t\t\t\t\tSybLxZdme3ozG91w+TB86/BPTNOl16P2Q3QQ90FdkqZY/rWPMwIRVA5mjKuf6+1T\n\t\t\t\t\t\t5PL9/XpQC9JFwXmUXNsNsLJryDgm+13wugMPymrgWmFGZN2HYlSv5TF5mIxVQOYC\n\t\t\t\t\t\tSjsGZhu88GmRjMxHN1T6OAn7a4HA7/wlEfnl8SQ5TIWPRjQukN9hg/CpYC2zI17G\n\t\t\t\t\t\t/606x/P4lkJ37/NErZ/u4ueA4ymhyWSbLFX8MsFDymiTghJu/7N1Z9nY/ePklQID\n\t\t\t\t\t\tAQABo4G0MIGxMB0GA1UdDgQWBBRa1jo5LhT5i8tbKUA76iynFS7CnDCBgQYDVR0j\n\t\t\t\t\t\tBHoweIAUWtY6OS4U+YvLWylAO+ospxUuwpyhVaRTMFExIDAeBgNVBAMTF3Rlc3Qu\n\t\t\t\t\t\tc3Rpci51bmlkZXNrLmFjLnVrMSAwHgYDVQQKExd0ZXN0LnN0aXIudW5pZGVzay5h\n\t\t\t\t\t\tYy51azELMAkGA1UEBhMCVUuCCQC6/Aj/D0uQRDAMBgNVHRMEBTADAQH/MA0GCSqG\n\t\t\t\t\t\tSIb3DQEBCwUAA4IBAQAx2Xfd1pfAlPepfSX4KUPbhJaq+Z2695FVOW+KqBC/L6db\n\t\t\t\t\t\tjyUYQtoi1X9yge4FaVNt1GMMUv9XVcvH6O7UTLdXBiSXXW/BbhLzRgnf09Mtta0y\n\t\t\t\t\t\tskCRNaStwWbIrDFRegIk0rFUya3n2oR5B5ZW0ah7C93sxYbVbSMZmVfUpf/oZY79\n\t\t\t\t\t\tUZhImwhWAzMfvKgzPySFAXOmoShseo6hrOTyeWJgVxT4EKtifhyhdTZDkT8XykbX\n\t\t\t\t\t\tCA34rv87jODyi+dYGhbegFiuJoDo/9/weL0BH5N48yW18sSjRkURF5VXGbPMUx96\n\t\t\t\t\t\t8Knhux1hK+cTlx1vIfHtJa81w/f3BtS7gweYmKp4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.stir.unidesk.ac.uk/tas/secure/login/verify",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://connect-beta.sunet.se/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:noc@nordu.net"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "NORDUnet NOC"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://connect-beta.sunet.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://connect-beta.sunet.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://connect-beta.sunet.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect-beta.sunet.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect-beta.sunet.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SUNET E-Meeting Service (beta)"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "SUNET E-Meeting Service (beta)"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://connect-beta.sunet.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://connect-beta.sunet.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://connect-beta.sunet.se/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://connect-beta.sunet.se/Shibboleth.sso/DS/kalmar2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://connect-beta.sunet.se/Shibboleth.sso/DS/nordu.net",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "4"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "connect-beta.sunet.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJAPlfAgYiS2HzMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\nBAMTFWNvbm5lY3QtYmV0YS5zdW5ldC5zZTAeFw0xNDExMjkxMTE4NTVaFw0yNDEx\nMjYxMTE4NTVaMCAxHjAcBgNVBAMTFWNvbm5lY3QtYmV0YS5zdW5ldC5zZTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANMhbRolAnPwqhMMJvS76dzc0tLp\neEjwS5GTMFIZSic54pnHHEnBGgQAZkPmputFdioAV6eZw2qHAGvROcQTRk4jeIXo\naULWXN9fNq+EZa/1SdzdtC3z5WqoyV+DYNWgOh0jI+iCh9mQpCEs8TtImWWZbVFY\nUev5+Cf3wJCi5RMYSU6oBD0/zpHq/+7fDjXCs7Coe7q9o1mQqw08mDCH8/Gb+mgg\nUPjQWL6U7oGWBJ0s4Bclc9WPUQQQVE8C6wt+CvQw6Eg1maV2f28si3ez1ybZv27w\nXgH/pTnib1FmLWBTSETkFOZs4ZRxoKgU838lRUktc58CEGKQhwisaKqfd+ECAwEA\nAaNDMEEwIAYDVR0RBBkwF4IVY29ubmVjdC1iZXRhLnN1bmV0LnNlMB0GA1UdDgQW\nBBS4cKd+yNhVRbYHclbmpNeBJySm6TANBgkqhkiG9w0BAQUFAAOCAQEAHnWZUpzK\nFU+MdGvtwH249x7sQtj7mXSISsX1rnfy6M1Zz7SWtkSeFgijQvpNEDsIfRXtMApS\nzegZMJEAbnVQ9OVXcVD1zgoHdob0qjJ3KXlc/lByeosty1Q6TLI1NtGZzS23COmP\nH/AVOR5U++JOt28OOfoi7mtxOFPxkge3AooWLNFOEOGMSF78BG8NCrT0l59OnAtN\n3sN7PXo740wv8cQLou3/kv+NHOMwdhdiCTvY9JttcRsT55rHbWRpgDbqYTvyEhkD\n3Zul4UGjlp2ilyjkZqr+qOUEAdjC63hNBmNMEtJGi2vhEyi2BN+F1PfoB5mot7A0\n15RMslPZtWnEtQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=connect-beta.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "connect-beta.sunet.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJAPlfAgYiS2HzMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\nBAMTFWNvbm5lY3QtYmV0YS5zdW5ldC5zZTAeFw0xNDExMjkxMTE4NTVaFw0yNDEx\nMjYxMTE4NTVaMCAxHjAcBgNVBAMTFWNvbm5lY3QtYmV0YS5zdW5ldC5zZTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANMhbRolAnPwqhMMJvS76dzc0tLp\neEjwS5GTMFIZSic54pnHHEnBGgQAZkPmputFdioAV6eZw2qHAGvROcQTRk4jeIXo\naULWXN9fNq+EZa/1SdzdtC3z5WqoyV+DYNWgOh0jI+iCh9mQpCEs8TtImWWZbVFY\nUev5+Cf3wJCi5RMYSU6oBD0/zpHq/+7fDjXCs7Coe7q9o1mQqw08mDCH8/Gb+mgg\nUPjQWL6U7oGWBJ0s4Bclc9WPUQQQVE8C6wt+CvQw6Eg1maV2f28si3ez1ybZv27w\nXgH/pTnib1FmLWBTSETkFOZs4ZRxoKgU838lRUktc58CEGKQhwisaKqfd+ECAwEA\nAaNDMEEwIAYDVR0RBBkwF4IVY29ubmVjdC1iZXRhLnN1bmV0LnNlMB0GA1UdDgQW\nBBS4cKd+yNhVRbYHclbmpNeBJySm6TANBgkqhkiG9w0BAQUFAAOCAQEAHnWZUpzK\nFU+MdGvtwH249x7sQtj7mXSISsX1rnfy6M1Zz7SWtkSeFgijQvpNEDsIfRXtMApS\nzegZMJEAbnVQ9OVXcVD1zgoHdob0qjJ3KXlc/lByeosty1Q6TLI1NtGZzS23COmP\nH/AVOR5U++JOt28OOfoi7mtxOFPxkge3AooWLNFOEOGMSF78BG8NCrT0l59OnAtN\n3sN7PXo740wv8cQLou3/kv+NHOMwdhdiCTvY9JttcRsT55rHbWRpgDbqYTvyEhkD\n3Zul4UGjlp2ilyjkZqr+qOUEAdjC63hNBmNMEtJGi2vhEyi2BN+F1PfoB5mot7A0\n15RMslPZtWnEtQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=connect-beta.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://connect-beta.sunet.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://connect-beta.sunet.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect-beta.sunet.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect-beta.sunet.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect-beta.sunet.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://connect-beta.sunet.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect-beta.sunet.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://connect-beta.sunet.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://connect-beta.sunet.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://connect-beta.sunet.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.uniroma3.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Technical Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@uniroma3.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uniroma3.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2009-12-31T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFQTCCBCmgAwIBAgIQBTxw+2vP6xm5lPNGi9q8AzANBgkqhkiG9w0BAQ0FADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMzAeFw0xNjAxMjUwMDAwMDBaFw0xOTAxMjkxMjAwMDBaMHExCzAJBgNVBAYT\nAklUMQ4wDAYDVQQIEwVJdGFseTENMAsGA1UEBxMEUm9tZTEpMCcGA1UECgwgVW5p\ndmVyc2l0w6AgZGVnbGkgU3R1ZGkgUm9tYSBUUkUxGDAWBgNVBAMTD2lkcC51bmly\nb21hMy5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKJYlicKcg0O\nYFbsM608K0gczymf4q0Wwt1xK3NDNVdLNTxLEB1yYDSo5KaXTPREeigN/KEcEI0q\nmx2NkMg2Gp3Rxfo0V+l1/cILd6BygxvI0YLVCYqO2D6Guna5QZxSAzhnTcPoTpte\neWAPtqCeOSlpZ9woztQGQJEF9i5pQN6eVPGvIaB4Dxq24AI64uFwuOarhtDauvk/\nKA9hy6pAbSkXgsabdSHytR/vTvfK4e8WIc5pMa8W7apIWHX9bj2G0ElzYIsB89Zl\ne05QVjCCcJ7jfTjuVMFDc4ef816vLq6vmRjQi57tGieyjH0tTFb0tX39P2fJ90/e\nDCg7v/lCVIECAwEAAaOCAeAwggHcMB8GA1UdIwQYMBaAFGf9iCAUJ5jHCdIlGbvp\nURFjdVBiMB0GA1UdDgQWBBROeTzj9F4M6HIC/gAVKpJOQWKmajAyBgNVHREEKzAp\ngg9pZHAudW5pcm9tYTMuaXSCFnNoaWJib2xldGgudW5pcm9tYTMuaXQwDgYDVR0P\nAQH/BAQDAgWgMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjBrBgNVHR8E\nZDBiMC+gLaArhilodHRwOi8vY3JsMy5kaWdpY2VydC5jb20vVEVSRU5BU1NMQ0Ez\nLmNybDAvoC2gK4YpaHR0cDovL2NybDQuZGlnaWNlcnQuY29tL1RFUkVOQVNTTENB\nMy5jcmwwTAYDVR0gBEUwQzA3BglghkgBhv1sAQEwKjAoBggrBgEFBQcCARYcaHR0\ncHM6Ly93d3cuZGlnaWNlcnQuY29tL0NQUzAIBgZngQwBAgIwbgYIKwYBBQUHAQEE\nYjBgMCQGCCsGAQUFBzABhhhodHRwOi8vb2NzcC5kaWdpY2VydC5jb20wOAYIKwYB\nBQUHMAKGLGh0dHA6Ly9jYWNlcnRzLmRpZ2ljZXJ0LmNvbS9URVJFTkFTU0xDQTMu\nY3J0MAwGA1UdEwEB/wQCMAAwDQYJKoZIhvcNAQENBQADggEBABJgwxpy4mqcAR7C\nql/pvWh1dJ6UqyKlMmuvqf2q1A6XmsSEDD/3SP43+Eoxl/tNMKOTN+UPd8hBjgUH\njeVHzJ3AGAFPuuQ5fR9Ix1kMpgz4TqiqAwfslEFGog0iJbztjwGNcxVvuu3nGqYn\nV0IBzXEahifLGtRI52rgG7nJv/n0PmIcmn/DzEPlwm6DhGsa2e82U/OtbyEEfxZ+\nNDVBxYV/3T+NqEEaACLHePhzY8bUg4WTrToZa/I2/+cKiyXOsbYVr1ZKsOUtcLxL\nVG+4Km92F9fZ4aFwmSvZZKs65ZhSh7Re6fwiExrnQRFAgN8aZx9k++IFyC6cK0/g\n5iHa3Cc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uniroma3.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uniroma3.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uniroma3.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.uniroma3.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uniroma3.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.uniroma3.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uniroma3.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uniroma3.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uniroma3.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uniroma3.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.idem.uniroma3.it/EN"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.idem.uniroma3.it/IT"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Roma TRE members"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti di Roma Tre"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University Roma TRE IdP"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 di Roma Tre IdP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFQTCCBCmgAwIBAgIQBTxw+2vP6xm5lPNGi9q8AzANBgkqhkiG9w0BAQ0FADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMzAeFw0xNjAxMjUwMDAwMDBaFw0xOTAxMjkxMjAwMDBaMHExCzAJBgNVBAYT\nAklUMQ4wDAYDVQQIEwVJdGFseTENMAsGA1UEBxMEUm9tZTEpMCcGA1UECgwgVW5p\ndmVyc2l0w6AgZGVnbGkgU3R1ZGkgUm9tYSBUUkUxGDAWBgNVBAMTD2lkcC51bmly\nb21hMy5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKJYlicKcg0O\nYFbsM608K0gczymf4q0Wwt1xK3NDNVdLNTxLEB1yYDSo5KaXTPREeigN/KEcEI0q\nmx2NkMg2Gp3Rxfo0V+l1/cILd6BygxvI0YLVCYqO2D6Guna5QZxSAzhnTcPoTpte\neWAPtqCeOSlpZ9woztQGQJEF9i5pQN6eVPGvIaB4Dxq24AI64uFwuOarhtDauvk/\nKA9hy6pAbSkXgsabdSHytR/vTvfK4e8WIc5pMa8W7apIWHX9bj2G0ElzYIsB89Zl\ne05QVjCCcJ7jfTjuVMFDc4ef816vLq6vmRjQi57tGieyjH0tTFb0tX39P2fJ90/e\nDCg7v/lCVIECAwEAAaOCAeAwggHcMB8GA1UdIwQYMBaAFGf9iCAUJ5jHCdIlGbvp\nURFjdVBiMB0GA1UdDgQWBBROeTzj9F4M6HIC/gAVKpJOQWKmajAyBgNVHREEKzAp\ngg9pZHAudW5pcm9tYTMuaXSCFnNoaWJib2xldGgudW5pcm9tYTMuaXQwDgYDVR0P\nAQH/BAQDAgWgMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjBrBgNVHR8E\nZDBiMC+gLaArhilodHRwOi8vY3JsMy5kaWdpY2VydC5jb20vVEVSRU5BU1NMQ0Ez\nLmNybDAvoC2gK4YpaHR0cDovL2NybDQuZGlnaWNlcnQuY29tL1RFUkVOQVNTTENB\nMy5jcmwwTAYDVR0gBEUwQzA3BglghkgBhv1sAQEwKjAoBggrBgEFBQcCARYcaHR0\ncHM6Ly93d3cuZGlnaWNlcnQuY29tL0NQUzAIBgZngQwBAgIwbgYIKwYBBQUHAQEE\nYjBgMCQGCCsGAQUFBzABhhhodHRwOi8vb2NzcC5kaWdpY2VydC5jb20wOAYIKwYB\nBQUHMAKGLGh0dHA6Ly9jYWNlcnRzLmRpZ2ljZXJ0LmNvbS9URVJFTkFTU0xDQTMu\nY3J0MAwGA1UdEwEB/wQCMAAwDQYJKoZIhvcNAQENBQADggEBABJgwxpy4mqcAR7C\nql/pvWh1dJ6UqyKlMmuvqf2q1A6XmsSEDD/3SP43+Eoxl/tNMKOTN+UPd8hBjgUH\njeVHzJ3AGAFPuuQ5fR9Ix1kMpgz4TqiqAwfslEFGog0iJbztjwGNcxVvuu3nGqYn\nV0IBzXEahifLGtRI52rgG7nJv/n0PmIcmn/DzEPlwm6DhGsa2e82U/OtbyEEfxZ+\nNDVBxYV/3T+NqEEaACLHePhzY8bUg4WTrToZa/I2/+cKiyXOsbYVr1ZKsOUtcLxL\nVG+4Km92F9fZ4aFwmSvZZKs65ZhSh7Re6fwiExrnQRFAgN8aZx9k++IFyC6cK0/g\n5iHa3Cc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Roma TRE"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 di Roma TRE"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uniroma3.it/en2/"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uniroma3.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Roma TRE"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 di Roma TRE"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.merthyr.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Watkins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:a.watkins@merthyr.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Watkins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:a.watkins@merthyr.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.merthyr.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIURCB/tUHtc3A/ovYJbLippy5MADIwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHDEaMBgGA1UEAxMRaWRwLm1lcnRoeXIuYWMudWswHhcNMTEwNzA1MTExMjMx\n\t\t\t\t\t\tWhcNMzEwNzA1MTExMjMxWjAcMRowGAYDVQQDExFpZHAubWVydGh5ci5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJFAsCItsP8+n3dD74AGDmML\n\t\t\t\t\t\tLHA+qOSCF9QzNbyG6eUUmbbtq2YL03KomYlI0wV21lK9TDcUIVDwionhN+J5gzp/\n\t\t\t\t\t\tj0XQ6/aTWIPeT5Igyw6rpYQJHR0F4hSMkZPHgoEIf+pJ4KsOxcS8v45Hs5G5jobz\n\t\t\t\t\t\tKtksWzWz2saCt4Y0Dkbz1AhZuHeWRYkwx5HT231AdCgEOaCOieYqJizq+LGTNM9r\n\t\t\t\t\t\tiakEZEoQ1iBwzwOEeeWTCLAdq74nLg1IqvldRE9qrzMD383wp8QDcnFrpRG0FpAP\n\t\t\t\t\t\tzYDLciyZ6IehEB/197cVjAFhMBcR0g5LdWZRmchLYCIM5IRVeboxSOLJMzeRKUsC\n\t\t\t\t\t\tAwEAAaNpMGcwRgYDVR0RBD8wPYIRaWRwLm1lcnRoeXIuYWMudWuGKGh0dHBzOi8v\n\t\t\t\t\t\taWRwLm1lcnRoeXIuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFCnF7X1W\n\t\t\t\t\t\tOJhryeXx3KqcXqwmzOMAMA0GCSqGSIb3DQEBBQUAA4IBAQBE9l2CvybnLgrucYfg\n\t\t\t\t\t\tXucF8nJ6iXP2co2/L4YnA9psqMNvHlFGmtqsRGcByS+XlYX1cKGCJ2UHj/0Zti0W\n\t\t\t\t\t\tRkjM0MT2NS/hBUv321UfMxJ6h7e/Xlrv4CTTxRO6kh5/9nXk8lfT6pcYFSGtC9b6\n\t\t\t\t\t\tKHr+IQ726FM2L2VCsoH/3htHDM5L89KhzVg8iQmyxpQBNcj3MgURzr9AtBlWRvK0\n\t\t\t\t\t\taMsJOAqGAm5SC+E7ckFz57KHdVRYNl+PzG2tsQa491vYhpNAxGb4zHc6xITNZ315\n\t\t\t\t\t\t0eUpscAC9+6x+Q53jgbzcKJ0011YisfPRo5mS0bMw1eMC849PJeX2p8MZeGgXuf8\n\t\t\t\t\t\twQ0d"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "merthyr.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.merthyr.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.merthyr.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.merthyr.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.merthyr.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.merthyr.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.merthyr.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.merthyr.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.merthyr.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "merthyr.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIURCB/tUHtc3A/ovYJbLippy5MADIwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHDEaMBgGA1UEAxMRaWRwLm1lcnRoeXIuYWMudWswHhcNMTEwNzA1MTExMjMx\n\t\t\t\t\t\tWhcNMzEwNzA1MTExMjMxWjAcMRowGAYDVQQDExFpZHAubWVydGh5ci5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJFAsCItsP8+n3dD74AGDmML\n\t\t\t\t\t\tLHA+qOSCF9QzNbyG6eUUmbbtq2YL03KomYlI0wV21lK9TDcUIVDwionhN+J5gzp/\n\t\t\t\t\t\tj0XQ6/aTWIPeT5Igyw6rpYQJHR0F4hSMkZPHgoEIf+pJ4KsOxcS8v45Hs5G5jobz\n\t\t\t\t\t\tKtksWzWz2saCt4Y0Dkbz1AhZuHeWRYkwx5HT231AdCgEOaCOieYqJizq+LGTNM9r\n\t\t\t\t\t\tiakEZEoQ1iBwzwOEeeWTCLAdq74nLg1IqvldRE9qrzMD383wp8QDcnFrpRG0FpAP\n\t\t\t\t\t\tzYDLciyZ6IehEB/197cVjAFhMBcR0g5LdWZRmchLYCIM5IRVeboxSOLJMzeRKUsC\n\t\t\t\t\t\tAwEAAaNpMGcwRgYDVR0RBD8wPYIRaWRwLm1lcnRoeXIuYWMudWuGKGh0dHBzOi8v\n\t\t\t\t\t\taWRwLm1lcnRoeXIuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFCnF7X1W\n\t\t\t\t\t\tOJhryeXx3KqcXqwmzOMAMA0GCSqGSIb3DQEBBQUAA4IBAQBE9l2CvybnLgrucYfg\n\t\t\t\t\t\tXucF8nJ6iXP2co2/L4YnA9psqMNvHlFGmtqsRGcByS+XlYX1cKGCJ2UHj/0Zti0W\n\t\t\t\t\t\tRkjM0MT2NS/hBUv321UfMxJ6h7e/Xlrv4CTTxRO6kh5/9nXk8lfT6pcYFSGtC9b6\n\t\t\t\t\t\tKHr+IQ726FM2L2VCsoH/3htHDM5L89KhzVg8iQmyxpQBNcj3MgURzr9AtBlWRvK0\n\t\t\t\t\t\taMsJOAqGAm5SC+E7ckFz57KHdVRYNl+PzG2tsQa491vYhpNAxGb4zHc6xITNZ315\n\t\t\t\t\t\t0eUpscAC9+6x+Q53jgbzcKJ0011YisfPRo5mS0bMw1eMC849PJeX2p8MZeGgXuf8\n\t\t\t\t\t\twQ0d"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Merthyr Tydfil College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.merthyr.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of South Wales"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://lap.clarino.uio.no/simplesaml/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Oepen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lap-developers@ifi.uio.no"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stephan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://lap.clarino.uio.no/simplesaml/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.feide.no/files/feide/metadata-registration-practice-statement.pdf"
              }
            ],
            "registration_instant": "2016-03-11T16:15:49Z",
            "registration_authority": "http://feide.no/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Oslo"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uio.no"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Oslo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lap.clarino.uio.no/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mn.uio.no/ifi/english/research/projects/clarino/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ready-to-Run and State-of-the-Art Language Analysis Tools in the Cloud"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.mn.uio.no/ifi/english/research/projects/clarino/user/privacy/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "LAP: UiO Language Analysis Portal (Production)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lap.clarino.uio.no/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://lap.clarino.uio.no/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lap.clarino.uio.no/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://lap.clarino.uio.no/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "LAP: UiO Language Analysis Portal (Production)"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Ready-to-Run and State-of-the-Art Language Analysis Tools in the Cloud"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.123library.org/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Benjamin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:timbenjamin@123doc.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Benjamin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:timbenjamin@123doc.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.123library.org/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-11-02T10:40:16Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "123 Library"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.123library.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "123Doc Education Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDfDCCAmSgAwIBAgIJAOqpAln6yGDwMA0GCSqGSIb3DQEBBQUAMDIxEzARBgNV\n\t\t\t\t\t\tBAoTCjEyM0xpYnJhcnkxGzAZBgNVBAMTEnd3dy4xMjNsaWJyYXJ5Lm9yZzAeFw0x\n\t\t\t\t\t\tNTAxMDkxNjI0NTVaFw0yNTAxMDYxNjI0NTVaMDIxEzARBgNVBAoTCjEyM0xpYnJh\n\t\t\t\t\t\tcnkxGzAZBgNVBAMTEnd3dy4xMjNsaWJyYXJ5Lm9yZzCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBALNX0cg2tfg5w/8mF6+jaYx5vJYaY2viY90ZPZD4YiVF\n\t\t\t\t\t\tEvr0yHv40gdZoDaPrQpI/z+krN1Hv8zz2aFi2jkSJ6udzVCmzV1fxVSeUtAyW7j/\n\t\t\t\t\t\tdQDuApuBmReKdsBKbUUH0cOehMdPwJM5jUm8BUpUKd1jO5/b3AhNZWQnxeDJVmzy\n\t\t\t\t\t\tCdHGc3BJhe7RBi7hLJTlX/1AbD1dHLMjU/U2813rt+MB+QfPVzuCkajNNA5pY6OJ\n\t\t\t\t\t\tksDx/Q9SGZLgrGvFUE64MH/ffvQ8/jR33aJAQ7v1y463MpVQqxZLlxh/GtSPu9nD\n\t\t\t\t\t\tzqYSl80fTFns7omQ/uOQv1y91SMe42M8qGysv3HaRL0CAwEAAaOBlDCBkTAdBgNV\n\t\t\t\t\t\tHQ4EFgQUrxHW4/Azow1MEfosgbCPRp3DNacwYgYDVR0jBFswWYAUrxHW4/Azow1M\n\t\t\t\t\t\tEfosgbCPRp3DNaehNqQ0MDIxEzARBgNVBAoTCjEyM0xpYnJhcnkxGzAZBgNVBAMT\n\t\t\t\t\t\tEnd3dy4xMjNsaWJyYXJ5Lm9yZ4IJAOqpAln6yGDwMAwGA1UdEwQFMAMBAf8wDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBAATMW4Py6IHcQbxj26vK9mQNlpWAy/Ah2fp5CFhpm2PK\n\t\t\t\t\t\tDsGjjf4Wn4NWQyc2G7bmCPLRYQa2douIBzWpZ1n3S/tnaf2855LHsa/WV8gKuoN4\n\t\t\t\t\t\txFpGWiS8c7KOZvhJuvqP1K9mAMBbCeEocFB+OpzwvpVn0chSzBfs89aVDO7iHXpJ\n\t\t\t\t\t\tYHz4dJsJ76McTVdPTAKila/Hjgq4dt4xRodj45MlgX3SApqQLQnLJPZoF40Ug478\n\t\t\t\t\t\tFZl7Wye00MsuE+Rphr+nsnbjKJquxjSUe1K/Ayb4RfoQz5Z4G9g0skthUkl0IsUr\n\t\t\t\t\t\tOoPW3kslUwruNUj/IpAl13p9ahFKw3C83XJgOQmtZog="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "want_assertions_signed": "false",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://www.123library.org/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.123library.org/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.123library.org/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.123library.org/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://science-gateway.chain-project.eu/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:credentials-admin@ct.infn.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://science-gateway.chain-project.eu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2014-10-10T07:30:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INFN ROMA3"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.roma3.infn.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INFN ROMA3"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://science-gateway.chain-project.eu/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://science-gateway.chain-project.eu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://science-gateway.chain-project.eu/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://science-gateway.chain-project.eu/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://science-gateway.chain-project.eu/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://science-gateway.chain-project.eu/service"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://science-gateway.chain-project.eu/service"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The CHAIN-REDS Science Gateway is a standard-based web 2.0 platform to show the use cases and other demonstrative applications identified by the CHAIN-REDS project (www.chain-project.eu) and execute them on a worldwide e-Infrastructure based on different paradigms (Grid, Cloud and local HPC Cluster Computing)"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Il Sciece Gateway del progetto CHAIN-REDS e' una piattaforma web 2.0 basata su standard avente la finilita'  di mostrare speciali casi d'uso ed appicazioni identificate all'interno del progetto (www.chain-project.eu) ed eseguire queste su una infrastruttura di calcolo distribuita su base mondiale e con differenti paradigmi (grid, cloud, HPC)"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://science-gateway.chain-project.eu/policy"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://science-gateway.chain-project.eu/policy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CHAIN-REDS Science Gateway"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CHAIN-REDS Science Gateway"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://science-gateway.chain-project.eu/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://science-gateway.chain-project.eu/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE8TCCA9mgAwIBAgIRAJkwiwyfpx7usj9S/zvy7rIwDQYJKoZIhvcNAQELBQAw\nZDELMAkGA1UEBhMCTkwxFjAUBgNVBAgTDU5vb3JkLUhvbGxhbmQxEjAQBgNVBAcT\nCUFtc3RlcmRhbTEPMA0GA1UEChMGVEVSRU5BMRgwFgYDVQQDEw9URVJFTkEgU1NM\nIENBIDIwHhcNMTUwNTA3MDAwMDAwWhcNMTgwNTA2MjM1OTU5WjBLMSEwHwYDVQQL\nExhEb21haW4gQ29udHJvbCBWYWxpZGF0ZWQxJjAkBgNVBAMTHXNjaWVuY2UtZ2F0\nZXdheS5yb21hMy5pbmZuLml0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAyzvRvoZbRbXCb5eTXKcL9zK6ZQGX/e4ccq5S+3FWoydzIjkU9LZ79o3hkwHU\ng+OSIJFs9GKYrMvVBgiG3+BY2DGyCmH+XEigqw43pmkC9VTK8bl6J8sOWjFbGC/X\nAq3Z7gcpzA6kjCkGqTszC/Duid/J/rBHoFJXZrWljAnbYFEeYm9v9IgYtOOQzYtU\nGx4qBSMfCgFl4OcpfRre+UPNA0+2srdcX88HxtdRNBODoIsD9o4d8f0LkSVXVwv1\nWzJycCGsUTPOTAExrjQGvK1Ufsfy8I/yRTgTc9SnwTixyQ+nSLjdR3I4EsrPEUUx\n8bAAAhwjctyC6rz9hjIBdjRDVQIDAQABo4IBtTCCAbEwHwYDVR0jBBgwFoAUW9CK\nHJoyW+C13ZZUG+GGKLD9tr0wHQYDVR0OBBYEFBD3hmwITDYUQR2HIerZcvF9dMsX\nMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUF\nBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAEC\nATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnVzZXJ0cnVzdC5jb20vVEVS\nRU5BU1NMQ0EyLmNybDBsBggrBgEFBQcBAQRgMF4wNQYIKwYBBQUHMAKGKWh0dHA6\nLy9jcnQudXNlcnRydXN0LmNvbS9URVJFTkFTU0xDQTIuY3J0MCUGCCsGAQUFBzAB\nhhlodHRwOi8vb2NzcC51c2VydHJ1c3QuY29tMGQGA1UdEQRdMFuCHXNjaWVuY2Ut\nZ2F0ZXdheS5yb21hMy5pbmZuLml0ghhncmlkc3J2LTAzLnJvbWEzLmluZm4uaXSC\nIHNjaWVuY2UtZ2F0ZXdheS5jaGFpbi1wcm9qZWN0LmV1MA0GCSqGSIb3DQEBCwUA\nA4IBAQBRQFOhixQr232gE3iNYIth4OzlMwK3pftdxdsgt3rrOHQBHFv5QBbZL42m\n0KH+EwUtk1fjDtg4FHWqnEC+GgLgNouvSiFCR0Sa/mQPx7aya+j4F0kslz/7yazI\n9bdgXkwuetwmHX1lGtbw3aUKokULJhPUu2yvxPe5fC+YwJYBzeuVn6EOITXdjHRQ\n/1e8otsVnM4pm8JDKkS1ZXWPrQf4XrmYhUDC5vyIaVJNONlWVeUaHxkLf4mP2d2x\nyfCKbqhsoCXGNbLT2AgzayLYMJRckuTX3VNGFDTdbiFiv62Z842eKkLYlpRYxUi/\n+3A6Rx0nC5V7eKNZwLSToOSPSEQA"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://science-gateway.chain-project.eu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://science-gateway.chain-project.eu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://science-gateway.chain-project.eu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://science-gateway.chain-project.eu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://science-gateway.chain-project.eu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://science-gateway.chain-project.eu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CHAIN-REDS Science Gateway"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The CHAIN-REDS Science Gateway is a standard-based web 2.0 platform to show the use cases and other demonstrative applications identified by the CHAIN-REDS project (www.chain-project.eu) and execute them on a worldwide e-Infrastructure based on different paradigms (Grid, Cloud and local HPC Cluster Computing)"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://openathens.keele.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Carter"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:n.carter@keele.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Neil"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bridges"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:n.w.bridges@keele.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Norman"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://openathens.keele.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-06-23T16:46:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://openathens.keele.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://openathens.keele.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "keele.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID5zCCAs+gAwIBAgIJAJYE6X8FdcoOMA0GCSqGSIb3DQEBBQUAMIGJMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEWMBQGA1UECAwNU3RhZmZvcmRzaGlyZTEOMAwGA1UEBwwFS2VlbGUx\n\t\t\t\t\t\tHDAaBgNVBAoME1VuaXZlcnNpdHkgb2YgS2VlbGUxEzARBgNVBAsMCm9wZW5hdGhl\n\t\t\t\t\t\tbnMxHzAdBgNVBAMMFm9wZW5hdGhlbnMua2VlbGUuYWMudWswHhcNMTMxMjE2MTYy\n\t\t\t\t\t\tMTMyWhcNMjMxMjE3MTYyMTMyWjCBiTELMAkGA1UEBhMCR0IxFjAUBgNVBAgMDVN0\n\t\t\t\t\t\tYWZmb3Jkc2hpcmUxDjAMBgNVBAcMBUtlZWxlMRwwGgYDVQQKDBNVbml2ZXJzaXR5\n\t\t\t\t\t\tIG9mIEtlZWxlMRMwEQYDVQQLDApvcGVuYXRoZW5zMR8wHQYDVQQDDBZvcGVuYXRo\n\t\t\t\t\t\tZW5zLmtlZWxlLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\toJKbr6JC7sgMXeXfP7Sj721oLA9jhqan0QnG/5NTm6v/HgkgQnjezp/uBD9OirA+\n\t\t\t\t\t\tpyCmYUhQWLBgiD8JxH5bhhmfTGUD3iLcUeo4yKPJPzyWhHjCru2iPSAbnvl6yzAQ\n\t\t\t\t\t\t7pBZFJktxfO4Dx6iOQsiaCC93z04GPdqL0eNt2NZNNX/X5r3HdYkzonf6DvYTEfR\n\t\t\t\t\t\tk/xkzj35q70jDKwIrIiMUFr+xzUeQUYzVE4gysoYoaIfDvcO3kPKUgTuIZvbDsBm\n\t\t\t\t\t\tQIkjOb3MQcqXL3JXrhv6nwCahJOTvORHxEBzD4LAaowVbtJsfU/FRKQph98FGvdZ\n\t\t\t\t\t\t9Sef14MLaj6OLM/0CTH8vQIDAQABo1AwTjAdBgNVHQ4EFgQUxaJLsEIgT0EQ9l/i\n\t\t\t\t\t\tX0XT8xDk764wHwYDVR0jBBgwFoAUxaJLsEIgT0EQ9l/iX0XT8xDk764wDAYDVR0T\n\t\t\t\t\t\tBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAExw2HRuHuKy63i3dBx7siDE333dA\n\t\t\t\t\t\tWote0EBhijBShMcGmfNl1I1n9clrfHlm/yBuOyZABwysuTsjmNVWnaYOPGX53sxP\n\t\t\t\t\t\tGz2ibT6mPhZKVu0XiMaeoMnW0KO/SBCdYlLP6Z0J9NWU5c5prP9Nwmz+lcDH2qB8\n\t\t\t\t\t\tCIjUT62cW6wo0WKs4QuucTw5zDlZCqT62yWqhb5RAlB0yy0nHDZfi69RXl5y8vhx\n\t\t\t\t\t\thwcXwYvkeiw1BrLJj80Qw1LvBn1M6oqZ6TfYLrX8ub2JdhGudeFY8K2XZS2p0oEu\n\t\t\t\t\t\tdfpSmtW4JDyR0X8mLpFU61SdoVKWIZ+1UOtRO1YbGVbeQntrmy3E5LGStw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Keele University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.keele.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Keele"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.swamid.se/shibboleth",
    {
      "entity_id": "https://sp.swamid.se/shibboleth",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish Academic Identity Federation (SWAMID)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.swamid.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SWAMID"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.swamid.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.swamid.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.swamid.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.swamid.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SWAMID Test SP"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "SWAMID Test SP"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.swamid.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp.swamid.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp.swamid.se/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.swamid.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.swamid.se"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Detta \u00e4r en applikation som l\u00e5ter dig testa federerad inloggning."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is an application for testing federated authentication."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SWAMID Test SP"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SWAMID Test SP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://sp.swamid.se/shibboleth"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "sp.swamid.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAKP67GrfYHgtMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDHNwLnN3YW1pZC5zZTAeFw0wOTA2MTYxMTA3NTRaFw0xOTA2MTQxMTA3NTRa\nMBcxFTATBgNVBAMTDHNwLnN3YW1pZC5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAOVNkKXqQZrXXNCk7nE7JTsqyjuwbshkafxDCI7XN6HSaRcnR+OY\nswVYkSvGXfMr4XQLzAGyIOfYDcHwOqZina11Zf8sOdD5t6mygGKza+LzbGZN9d4y\nSosskTH1NiCVBCTdJVpfwU2+K87DKrT9xtuRf7TMDDKA3gjPtN+/IxT6hw2+oZZi\nUgQgJoGN68WO9C4c/WMfcFf7hgC7fSt4fji9MFNpJoOw9MsuaRgYEVkCaHubLj46\nYa3NbyY48zzAuc4ix8hoLJ9dP+nUCyGKtkY81HprKGtuiu8kYSo+pC20nv1Qr8xP\nFhSU14YvXPUIVOGfX9zsGVLOQKpkb4Z4AkUCAwEAAaNbMFkwOAYDVR0RBDEwL4IM\nc3Auc3dhbWlkLnNlhh9odHRwczovL3NwLnN3YW1pZC5zZS9zaGliYm9sZXRoMB0G\nA1UdDgQWBBTpV1dUBMfW7y2/Rjo17VSql2/AijANBgkqhkiG9w0BAQUFAAOCAQEA\nSsYAA5tq6JjKqI5u2gvZfhM5S6ZKgrvciayGoezdTI6FfvpS3kWtCTZlu+CGDYIW\nVBpMtgQ84HpTrGbr3X1w25mspK+hsXi3K7SKqdfMdc0JynwNPrlL4GgmTuR/fgoo\ntuE0Wnbi7xdxpQ1qd0SFzw4gFWp1wC1+FsGtB9HLksSskgnNxniG9Z9+9WxgU6hD\nfJbH6eFgMDUPe2FpKiJ7LXqgiJWJRuK4zgFyGIZ5OFstLpkT/cXa8qNhtsbp2BPO\njxcbsxoUpA7Qgl/OFu7gzxLkLrl4iRSwk8MTj2bjVBvqvisLJAmuiYDBd9iZvqXB\nIznEEJKY8IltpfdkKGE20g=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=sp.swamid.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://sp.swamid.se/shibboleth"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "sp.swamid.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAKP67GrfYHgtMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDHNwLnN3YW1pZC5zZTAeFw0wOTA2MTYxMTA3NTRaFw0xOTA2MTQxMTA3NTRa\nMBcxFTATBgNVBAMTDHNwLnN3YW1pZC5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAOVNkKXqQZrXXNCk7nE7JTsqyjuwbshkafxDCI7XN6HSaRcnR+OY\nswVYkSvGXfMr4XQLzAGyIOfYDcHwOqZina11Zf8sOdD5t6mygGKza+LzbGZN9d4y\nSosskTH1NiCVBCTdJVpfwU2+K87DKrT9xtuRf7TMDDKA3gjPtN+/IxT6hw2+oZZi\nUgQgJoGN68WO9C4c/WMfcFf7hgC7fSt4fji9MFNpJoOw9MsuaRgYEVkCaHubLj46\nYa3NbyY48zzAuc4ix8hoLJ9dP+nUCyGKtkY81HprKGtuiu8kYSo+pC20nv1Qr8xP\nFhSU14YvXPUIVOGfX9zsGVLOQKpkb4Z4AkUCAwEAAaNbMFkwOAYDVR0RBDEwL4IM\nc3Auc3dhbWlkLnNlhh9odHRwczovL3NwLnN3YW1pZC5zZS9zaGliYm9sZXRoMB0G\nA1UdDgQWBBTpV1dUBMfW7y2/Rjo17VSql2/AijANBgkqhkiG9w0BAQUFAAOCAQEA\nSsYAA5tq6JjKqI5u2gvZfhM5S6ZKgrvciayGoezdTI6FfvpS3kWtCTZlu+CGDYIW\nVBpMtgQ84HpTrGbr3X1w25mspK+hsXi3K7SKqdfMdc0JynwNPrlL4GgmTuR/fgoo\ntuE0Wnbi7xdxpQ1qd0SFzw4gFWp1wC1+FsGtB9HLksSskgnNxniG9Z9+9WxgU6hD\nfJbH6eFgMDUPe2FpKiJ7LXqgiJWJRuK4zgFyGIZ5OFstLpkT/cXa8qNhtsbp2BPO\njxcbsxoUpA7Qgl/OFu7gzxLkLrl4iRSwk8MTj2bjVBvqvisLJAmuiYDBd9iZvqXB\nIznEEJKY8IltpfdkKGE20g=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=sp.swamid.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.swamid.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.swamid.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.swamid.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.swamid.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.swamid.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp.swamid.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.swamid.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp.swamid.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp.swamid.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp.swamid.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://xploreuat.ieee.org/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Caldwell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:d.caldwell@ieee.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Don"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Trivedi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mh.trivedi@ieee.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mehul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://xploreuat.ieee.org/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IEEE Xplore Digital Library Test SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ieee.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Institute of Electrical And Electronics Engineers, Incorporated"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICtjCCAZ6gAwIBAgIEUcCIQjANBgkqhkiG9w0BAQUFADAdMRswGQYDVQQDExJ4cGxvcmV1YXQu\n\t\t\t\t\t\taWVlZS5vcmcwHhcNMTMwNjE4MTYxODEwWhcNMTYwNjE3MTYxODEwWjAdMRswGQYDVQQDExJ4cGxv\n\t\t\t\t\t\tcmV1YXQuaWVlZS5vcmcwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCMJ0TBsTib1e6j\n\t\t\t\t\t\t9YowCopEZ42Qa2Sie35zYvVOPBYQtPaFH8vnCvRZM83gVKxj3G8LCyu7XnHfjm8unR5jUn6tmI4N\n\t\t\t\t\t\tH+G13cIwC12p1dkot2SxPTh7H6rWMdJiQMQJ00INgpeKE3dB3D6GxcuWjwYLsts8lvk8IuhCjuIh\n\t\t\t\t\t\t5FwDrFPD0T1HNIArg3y7iE9mMAPWr6lAFwHkHfGl9fb6Ic6ihxeFyDwOfPlmSZV0ivUq7+rteEQY\n\t\t\t\t\t\tb8h4Rr2pSLkL7ZTcYMrLjXFzca8cOdlaf+oTGWFik7/vGrsCAPSdF4tZnJ1xFl+EqOBJyCsGabYi\n\t\t\t\t\t\tTlVsq0dLwi35ewh0/tgTFMiJAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAH5knWR/f9aq52LG1uQO\n\t\t\t\t\t\tYnqWj7GwU+6MT9UxPZllvUVrb0icSxiAAlQ0+PqmQtL59vOYnP/ndFMKR0cYFKBoLMKIGfuo8/4q\n\t\t\t\t\t\taUyBHHvMbPErbc2518DH4BnD4e6nHY1+2EqispzNkohx2cyHRM/LuvQGjHEFPgV0eadjKT75rPKQ\n\t\t\t\t\t\td10xGdIKPL1f38NkoMsALGAPI5vhXnMD3xihF1VgIk1jFV96FQh6TBY7TwRBeAwv0MsKx9njtST1\n\t\t\t\t\t\tGiru0Nun+Co7b5Wj3MMzLfAIpvVZEZSPKf7x/BO0Wht7QWpVQQ6jxe4k8oRa9Sze4gIRNPVr5p2W\n\t\t\t\t\t\tYbSvqmDBZaFbuvrNaD4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://xploreuat.ieee.org/Shibboleth/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://xploreuat.ieee.org/Shibboleth/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://xploreuat.ieee.org/Shibboleth/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://xploreuat.ieee.org/Shibboleth/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.tools.sunet.se/shibboleth",
    {
      "entity_id": "https://sp.tools.sunet.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://tools.sunet.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://tools.sunet.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://tools.sunet.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://tools.sunet.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://tools.sunet.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "sampo.sunet.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJAI+J1ypxJJViMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDnNhbXBvLnN1bmV0LnNlMB4XDTEwMDMxNjEyNDg0NloXDTIwMDMxMzEyNDg0\nNlowGTEXMBUGA1UEAxMOc2FtcG8uc3VuZXQuc2UwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQC/ptcTBImyhr19TLXOQ3D2TmMvIVPY1o1xcFiqUPdQrsPV\nN/gNBH296AKnnrNvD5q6fCDug6I08VwiBa5FFtzcUAT7bMf0Vgvh4Cnun3PiHnTJ\nAWfdI6yuSXyf3rIiUcJAXQWpNkR1vbl7w18GiU21T7GFjUTcXsr1vsLpdaWG4+/I\nIYpZmK3CtQcI7Rv/uCQLRVWdOzp3Ds/TRmXeF4q7QV17nEnz/02WOaEZsCJurPOg\nsgzgemBXd8VE/vobqYTfn7yUvmgJKcHFpVqwwkIoVyNoVoIKBjiKYbRjuXThdDfp\nEYv5gtevD6szDBRNskTrzbPWpXnA/yne8yaspNgrAgMBAAGjPDA6MBkGA1UdEQQS\nMBCCDnNhbXBvLnN1bmV0LnNlMB0GA1UdDgQWBBT5t2mmKUW7CUXjzz7ewQVxdSMf\nmjANBgkqhkiG9w0BAQUFAAOCAQEALmHceqzrAarhcb7qAc8RfR3sezshQhMd6roh\nL3xFzwkAHeUnw4ZbMkbvnl+R8LUrbJRiLEPFFtNbUqa68TcS3c/B2dDK+qpbu6nC\njBc2tZW8Nz9ZCfxArqLn6WfJGg4Yhgo9OlfJxZbmdc0Ld0tp0d/F2FHYkVc1SbXk\nVWCSzQ48/y05mpXMcbhdp5PJuLOfX1R6VFvu04oWuA1J9NN03IYF5DwqupZIhN7i\n3+2PmYs4x/dZ1/1cYva9JUCwffmjo7sx6LbedNkKYQL/skTlL8CHo9snghUSYJSZ\nXyNIJHaDalIvdnrWnQFVketJt+fje9CgALP1Btsk1g0AyD7tYw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=sampo.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "sampo.sunet.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJAI+J1ypxJJViMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDnNhbXBvLnN1bmV0LnNlMB4XDTEwMDMxNjEyNDg0NloXDTIwMDMxMzEyNDg0\nNlowGTEXMBUGA1UEAxMOc2FtcG8uc3VuZXQuc2UwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQC/ptcTBImyhr19TLXOQ3D2TmMvIVPY1o1xcFiqUPdQrsPV\nN/gNBH296AKnnrNvD5q6fCDug6I08VwiBa5FFtzcUAT7bMf0Vgvh4Cnun3PiHnTJ\nAWfdI6yuSXyf3rIiUcJAXQWpNkR1vbl7w18GiU21T7GFjUTcXsr1vsLpdaWG4+/I\nIYpZmK3CtQcI7Rv/uCQLRVWdOzp3Ds/TRmXeF4q7QV17nEnz/02WOaEZsCJurPOg\nsgzgemBXd8VE/vobqYTfn7yUvmgJKcHFpVqwwkIoVyNoVoIKBjiKYbRjuXThdDfp\nEYv5gtevD6szDBRNskTrzbPWpXnA/yne8yaspNgrAgMBAAGjPDA6MBkGA1UdEQQS\nMBCCDnNhbXBvLnN1bmV0LnNlMB0GA1UdDgQWBBT5t2mmKUW7CUXjzz7ewQVxdSMf\nmjANBgkqhkiG9w0BAQUFAAOCAQEALmHceqzrAarhcb7qAc8RfR3sezshQhMd6roh\nL3xFzwkAHeUnw4ZbMkbvnl+R8LUrbJRiLEPFFtNbUqa68TcS3c/B2dDK+qpbu6nC\njBc2tZW8Nz9ZCfxArqLn6WfJGg4Yhgo9OlfJxZbmdc0Ld0tp0d/F2FHYkVc1SbXk\nVWCSzQ48/y05mpXMcbhdp5PJuLOfX1R6VFvu04oWuA1J9NN03IYF5DwqupZIhN7i\n3+2PmYs4x/dZ1/1cYva9JUCwffmjo7sx6LbedNkKYQL/skTlL8CHo9snghUSYJSZ\nXyNIJHaDalIvdnrWnQFVketJt+fje9CgALP1Btsk1g0AyD7tYw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=sampo.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://tools.sunet.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://tools.sunet.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://tools.sunet.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://tools.sunet.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://tools.sunet.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://tools.sunet.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://tools.sunet.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://tools.sunet.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://tools.sunet.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://tools.sunet.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://myconcern.thinkiteducation.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bennett"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nick.bennett@logicsoftware.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nick"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tucker"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ian.tucker@logicsoftware.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://myconcern.thinkiteducation.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-12-12T09:37:03Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MyConcern ThinkIT Integrated Demo Site"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oneteamlogic.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "One Team Logic Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://myconcern.thinkiteducation.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://myconcern.thinkiteducation.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://myconcern.thinkiteducation.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://myconcern.thinkiteducation.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://myconcern.thinkiteducation.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://myconcern.thinkiteducation.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The MyConcern ThinkIT Integrated Demo Site is used for demonstrating the joined up ThinkIT solution"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "MyConcern ThinkIT Integrated Demo Site"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAKF0PyvuaE7mMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHRoaW5rLW15Yy0wMS5zZXJlbi5sb2NhbDAeFw0xNDEyMDkxMTQwMTJaFw0y\n\t\t\t\t\t\tNDEyMDYxMTQwMTJaMCMxITAfBgNVBAMTGHRoaW5rLW15Yy0wMS5zZXJlbi5sb2Nh\n\t\t\t\t\t\tbDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAP5SUqhHh8zasv2aaTdf\n\t\t\t\t\t\tjkchvuKO0YzniwI3PNBg9NpL+cNiDyzQ/Qk9X625jQBj7rMD+IIR2XVg4SLChTjK\n\t\t\t\t\t\tS/+bkNDmq1eki/4pHQH/91fkOIscLpJvhp7OyGOKzWqors7REAWnJw1EeTurrV0B\n\t\t\t\t\t\tRXpX5wQLBnV8zKfEyBG12Q5nIP7LDg/+YRDV2EKYeLVcYWzgDzdi2xnRwuUigeiF\n\t\t\t\t\t\t00uMF+AWeen+0kjr9YNUnDbaECJ42m+DCjRGNuZ/Ty4hcCMXTlm1PoHQZf8B/CTj\n\t\t\t\t\t\tQQFx1VbMKUwtfLSF52TGH76iu21oIIuyS8AmHPyacEH1hjOkRgsO6odLo98AoBxO\n\t\t\t\t\t\tegkCAwEAAaNGMEQwIwYDVR0RBBwwGoIYdGhpbmstbXljLTAxLnNlcmVuLmxvY2Fs\n\t\t\t\t\t\tMB0GA1UdDgQWBBQ6KbEs1aIG7ZMKVkd2A/hR3MlT/zANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAO9Oe6XOW3B2zdbT8ayBlxGcHiOorP7GcE5nf6WI1h4FpWub11HIm+N3Wn+lI\n\t\t\t\t\t\tKlhihanbVe4My9QTwk67di82CDzjWSqVQe33rUiDyt9vG26XhPDM6znyzaJHD9V+\n\t\t\t\t\t\tCZ0ucm1cXKLna5recIfbZC1ezYWvQqQIaAQQ1rCuvGr8vB8W21dPnEMKORKJTOOd\n\t\t\t\t\t\tzXvof96kNX/JUr7jBRfw+XTgNZKgJGR3U8GlOKO1f6g/A9eLAoqzeb0s+Rtllczv\n\t\t\t\t\t\t2RMdnVWWAjZaLLMOTVmBF8ndB3CUurWfisv2GBVTHsmgKVtbUdHIS6o8NlQdnPk3\n\t\t\t\t\t\t9AfqjY3J5+HrbC8v/CbVhkudJw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://myconcern.thinkiteducation.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://myconcern.thinkiteducation.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://myconcern.thinkiteducation.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://myconcern.thinkiteducation.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://myconcern.thinkiteducation.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://myconcern.thinkiteducation.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://login.stolaf.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "root@stolaf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "St. Olaf Systems Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.stolaf.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.stolaf.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.stolaf.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.stolaf.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.stolaf.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.stolaf.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stolaf.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "St. Olaf College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEBTCCAu2gAwIBAgIJAIpCACOSmm5jMA0GCSqGSIb3DQEBBQUAMIGYMQswCQYD\nVQQGEwJVUzESMBAGA1UECAwJTWlubmVzb3RhMRMwEQYDVQQHDApOb3J0aGZpZWxk\nMRgwFgYDVQQKDA9TdCBPbGFmIENvbGxlZ2UxCzAJBgNVBAsMAklUMRkwFwYDVQQD\nDBBsb2dpbi5zdG9sYWYuZWR1MR4wHAYJKoZIhvcNAQkBFg9yb290QHN0b2xhZi5l\nZHUwHhcNMTIwODA4MTUzODM4WhcNMzIwODA4MTUzODM4WjCBmDELMAkGA1UEBhMC\nVVMxEjAQBgNVBAgMCU1pbm5lc290YTETMBEGA1UEBwwKTm9ydGhmaWVsZDEYMBYG\nA1UECgwPU3QgT2xhZiBDb2xsZWdlMQswCQYDVQQLDAJJVDEZMBcGA1UEAwwQbG9n\naW4uc3RvbGFmLmVkdTEeMBwGCSqGSIb3DQEJARYPcm9vdEBzdG9sYWYuZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAs6mj0mZ9xeLDbuGLO6ugsJWM\n5hN5Smi+MejkIv+Q95SVZP7tROG2kwMhMl8mPdV+xf8+vNG6GPLA58kyr5ShgLdf\nCAGYnoardWVvp9HVB4kcQA8CgizRmhupCKZqNqQOKg+7qejxHA863dWmPr4a62pS\nddoMuhAOl9yZBpnGHusHy8+Cfbdan8NqUXBX33STQVqA3980oUxLxpo+ywF0prV2\nbCy/54dgIScVT66TDuGZAwdmToRE6Yi4FePI4FFRh7ohOajadkmG1Ni/uEbWXYwl\nl6ehDhTkm0lo0uZ8D1LtCe6ydKE6UAE1ACAZfrfyEh6LfnzoiFJCrJoOzTHlrQID\nAQABo1AwTjAdBgNVHQ4EFgQUt/02+LxZnPfKIg3hVKI774yeF9IwHwYDVR0jBBgw\nFoAUt/02+LxZnPfKIg3hVKI774yeF9IwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0B\nAQUFAAOCAQEAAq57xrup7Jtuy0u2GCcTyqF44T6wPPXwMTmy8R1104gT8AQh7VHh\nUqBU4OUHx3ZUaXNkGOVFQUftc9BSBxKBuyK+6m1yLQyY1zV/WI9UG7wjtUBcu2Vn\nPEKSb+LrqVee+0fm1kMLa7BBH2eDOF3L+7A88JhWnLmpXZIPv/iLoqqibZuw+nDU\ncYnf3BffmuLLX119fYL+023+7YDfXolEbyd0nYVeWV2e33xt6RJtmWuO1VbQsPQZ\nGq8AofetoybsRS9b+CrRWiYzUvjZ0zkjDe9PMzvsXcS7xGD8/90X9damUttErlld\nYj2frn/AgpSfFIR4btP5vc0jd8Qy85QoDg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "http://www.stolaf.edu/services/iit/shibboleth/error.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "St. Olaf College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://stolaf.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "St. Olaf College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.prz.edu.pl/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sysadmin@prz.edu.pl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Administrative Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.prz.edu.pl/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.pionier.net.pl/en/index.php?page=rps"
              }
            ],
            "registration_instant": "2016-03-17T00:00:00Z",
            "registration_authority": "https://aai.pionier.net.pl",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.prz.edu.pl/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.prz.edu.pl/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.prz.edu.pl/idp/profile/SAML2/POST-SimpleSign/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.prz.edu.pl:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.prz.edu.pl/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.prz.edu.pl/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.prz.edu.pl/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.prz.edu.pl/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.prz.edu.pl:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.prz.edu.pl:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "prz.edu.pl"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Rzeszow University of Technology Identity Provider"
                  },
                  {
                    "lang": "pl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Dostawca To\u017csamo\u015bci Politechniki Rzeszowskiej"
                  }
                ],
                "logo": [
                  {
                    "text": "https://w.prz.edu.pl/themes/prz/images/logop_prz.png",
                    "lang": "en",
                    "height": "88",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "222"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rzeszow University of Technology"
                  },
                  {
                    "lang": "pl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Politechnika Rzeszowska"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUSxn45JYq8osLNyE19Vpt1mgep1kwDQYJKoZIhvcNAQEL\nBQAwGTEXMBUGA1UEAwwOaWRwLnByei5lZHUucGwwHhcNMTUwNDE0MDczMDM4WhcN\nMzUwNDE0MDczMDM4WjAZMRcwFQYDVQQDDA5pZHAucHJ6LmVkdS5wbDCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ9/JwepuJgIlNBrtzjdnaLe6iJ7YCXH\nO/1InUZSIr3P9R0Jm2/eCJI39RbpS/Ddrd1eseb2RzELS67HZ5+JM6phmQ5GZicY\nY+bb8ftaBJek/jog6nLk+cx1cE7mxi9HP0gK5nosb1fnvFwtOE7qTYjf8mhYR5Zq\nZTKKHgU+kvpsWVBRh3zFCF39/iShOAhmdFRzrzz7wMYMKxG4pb9qqoM30c7Qc6eE\nXTTkgVCayxsoeZaup7Y/j2Z+U24Q1x7F/Jb0rCmmlDzZX0STYDxXV3ETw+QWBPv+\nQfYgx62L6mU3MOEdkWZRoqmth2Gtk3FCqBxD2etTi5TZXAsTlahurpkCAwEAAaNj\nMGEwHQYDVR0OBBYEFEugE4pRaRLf0csd5sExw+gTuaeIMEAGA1UdEQQ5MDeCDmlk\ncC5wcnouZWR1LnBshiVodHRwczovL2lkcC5wcnouZWR1LnBsL2lkcC9zaGliYm9s\nZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQAU2PaN4KI0DZRU1Ti0yEIhC6D+OvGwBw85\nInPAJ2G1LTt7f9lxeL5f/pXbIGcjdlwfdu2yPaXb1loEbztI2ZeA1SD2XCVjxtlk\nfyBH/DdAi/e2JzvdJRllwYFZXyqbjphcdDbQRPMJDwX64IsLgz3qhshKGMSrPT4e\n9xoJYZBjraB+IecjmjVkTFS9M9nDRbd7D3gDsBG4YO065XbcXnDpe/e+vmM8D8rQ\nqRtuTFz7D6/iwuNxyweebhuSDrOesH0kHEue9NVjyLLezHjGSifWTnAjn3KHB3H9\ny+8rrRJX8fOM6kTfnrL40Ir6vu9ZQacVERazVeNuhthXjAEgTdLx"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAPJvJR0LcPazVISXYG6X06yC9ndaMA0GCSqGSIb3DQEB\nCwUAMBkxFzAVBgNVBAMMDmlkcC5wcnouZWR1LnBsMB4XDTE1MDQxNDA3MzAyOVoX\nDTM1MDQxNDA3MzAyOVowGTEXMBUGA1UEAwwOaWRwLnByei5lZHUucGwwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCxul11b+7eT3TYYtGBRbrwDzZ6jsYx\n59PNKBCGxKV3JuAWTATANitah0zsuQVS8FY6hM9WIC1UO/XZtCo0tPf8RJc2xrwK\nyv+ZUuF2lX6dQ6OKKGW0WpitFWWY7VfwNgMz0/gums1v4tFQ9+lk4XMqbHiOJB+p\nUvqZssipI9jIa++cQcpamYLjjV52rLMwzfHl476T789DPYEF+ItN81dsaTiUSMXj\nVTHqp9cbUH/D+vAlFusBkvrzzQL3P/Aayykck2bajMyWO80U9E9wh7hdMU0Bc8i2\nV6naK2EYMatNJjDI7u0XhUuRSsDpWLrNJZ6PEBKaU+95jaJVdUGw7kwjAgMBAAGj\nYzBhMB0GA1UdDgQWBBQ3HnYKwH8P/Xp/oIV1HuDHb1hsFzBABgNVHREEOTA3gg5p\nZHAucHJ6LmVkdS5wbIYlaHR0cHM6Ly9pZHAucHJ6LmVkdS5wbC9pZHAvc2hpYmJv\nbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAmckDWhG2l6ZzhQ3oFSSCBwlejjDF2ySB\nHw/6fNA+2ZCrj9i6Zwa0hMywWagkWz5km0PThN7cVxA+jC4d8odU6cL/+zvLOQjI\nP0T49HtMESp2YGxf4JijLV22mF9oqljBqpbZoNxGNTJ7IOXGXP7NFzVglm8RdvKU\nDdebvnqXiSjSewgIuLCn+CINvW9SybvcatlJ+M2/6t2N07WgnbJN9uixvscnRepm\n0IDe6O9v5abiq2VG7AIViFWC+a9ccNIzuxyOjYfY9iPLnP838xTbuQ0MSN8eBDEZ\nUneQJVy3VT/nkjcAT7M6lhk0XgexjrWz1AoKMtbCkuNNGVkm2K+QmA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUTHsEb6D9StQBPMYXHN1HAZ3bU5YwDQYJKoZIhvcNAQEL\nBQAwGTEXMBUGA1UEAwwOaWRwLnByei5lZHUucGwwHhcNMTUwNDE0MDczMDM3WhcN\nMzUwNDE0MDczMDM3WjAZMRcwFQYDVQQDDA5pZHAucHJ6LmVkdS5wbDCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIcoQVIFyOSxlVChDHohFju8zTLhOlAA\nTXrjj1AIyzgiw9FplT+8lRFeNct6tntLUDmSD9jbuxFCrxlxHB2ovvVuXuAiIieG\n7rPc2y0fBG4UgdbOtFN9UH5Gr7kkxM3mrQ71mXwwNjj/ilUHgkh1y7GfAEiB4WMw\nCbVB2FlxeJBW1kU9ERA1ZTGUwM1Arwg2pMGKZYEmdQYSH91Wv3M/lBMgQUulktJA\nuyyO+7D72qCDZOZaX8CIFv/etCM+Ihg7f8CAw+N6Iwj+HOd5PFii5PWpcqS+jpKO\nxFWbt43UVNKqxV4OERU/2RAnW+PXQ92KgRlo6s93xtS6Rv/LAIT+6o0CAwEAAaNj\nMGEwHQYDVR0OBBYEFDK/6wBsCmjZko2HLmDi6/CMvxCtMEAGA1UdEQQ5MDeCDmlk\ncC5wcnouZWR1LnBshiVodHRwczovL2lkcC5wcnouZWR1LnBsL2lkcC9zaGliYm9s\nZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQBiGT4n6ocJ29HSVKE0dvqrrMS9dxSNxpTP\nNi8/WMDJCzmeStxGzSa0RP6B86Se1p0EnJEVX7mXe6Qtw5Fr3x7Doid1b2uTzfC1\nNoPhmJte28CariucCtJv7SHWNxTi7YtOJnkjbOE99gpffDiOnF51xwyMQ096aYxj\nYRyeJfn5DyUaMdXA1APINzZNCeq47d4DSiV+f587VJ37w3n6/ySYzc2lQYlYvAkT\nVsFx2s8OuccXXNppTDaVgdDGlLpk8LNHyT2IuOacxwOmbuYVqzwipW/k082UbRc+\n3/XMEQRfdUtgr6G7tbTDuzIkfIsuD6LQwCLHrpKhPb9IgBO7VlCu"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "pl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Politechnika Rzeszowska"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Rzeszow University of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "pl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://portal.prz.edu.pl/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://portal.prz.edu.pl/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "pl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Politechnika Rzeszowska"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Rzeszow University of Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://test-dcs.cla.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dev@cloudspringtech.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dev Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dev@cloudspringtech.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dev Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Amyotte"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:phil@cloudspringtech.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Phil"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test-dcs.cla.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-28T08:35:42Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Digital Content Store"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://cla.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Copyright Licensing Agency Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test-dcs.cla.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://test-dcs.cla.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test-dcs.cla.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test-dcs.cla.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test-dcs.cla.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test-dcs.cla.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://test-dcs.cla.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3zCCAcegAwIBAgIJANN7j8TZENUbMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\n\t\t\t\t\t\tBAMTCG5zMzczMTUzMB4XDTE1MDQyNzEzNDMzOVoXDTI1MDQyNDEzNDMzOVowEzER\n\t\t\t\t\t\tMA8GA1UEAxMIbnMzNzMxNTMwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDe0s9fwQ9v4NajnGwDJkesWo7Py4ufH/5qJsYUPcForz10FATKQtlGZZvb1Gzq\n\t\t\t\t\t\t1TaenINx4QqSjUjdyVUN3N25LWCVXW7IKmL+cxJPXx0R8Nng86ZCtYmA1epphESy\n\t\t\t\t\t\tPTXHLDOst7B4LdtxdlfqMaSr7xRo+1tBvY4G3Lqpt2l085R13XSvVfpbevQZSD4p\n\t\t\t\t\t\tnqi9vAiFUM4NDvycm0Yil/dPk4fGWlpMNT01JR50rpFnntJJVfab7I9Qf5cxboBw\n\t\t\t\t\t\t5mOPwqA8w4BI4o1gFqeH/vBXwrbA8zX9Ehgkfn1Rl8Aa0ZSMgoNjhzzwwLvjAuxT\n\t\t\t\t\t\tbWxPlVUwr7soX+RK9JRRgEMbAgMBAAGjNjA0MBMGA1UdEQQMMAqCCG5zMzczMTUz\n\t\t\t\t\t\tMB0GA1UdDgQWBBSp4HYFPmzOFP8q8RG2pBi0PerD3TANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAU9s2EhAdQudGpXpw6Ozw4tmEvg1IKDbUxUNEKkfUMOnlqPIeYvYhk5LN5ttD\n\t\t\t\t\t\tYTBcGaA8tIh5UIlQpNUh2Eb89FgZ2UqNgyx9OGMaiP7nl5ZV8HHckiTcrFKOnG6X\n\t\t\t\t\t\t+nuyOTeIYjgvpldbLZxRMlCt5fSQzqwwYX6SyK6PWsqQTZhvzpwdpbGrUj4mKEcV\n\t\t\t\t\t\tvs9mlOgKFkqvzXLr+I4D8XVYbIxBCeh7X82ooPv4r6d7kzJJo9pRf+qi0RNKJmWZ\n\t\t\t\t\t\tvI2el1erTkBgTf/qHvtskD/N1KTxz9oZV/bTpkype7gRaya8jguEmXqz0fyt9ohB\n\t\t\t\t\t\tkep+2TUr/H4eYqGM0KNkWWD8FA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test-dcs.cla.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://test-dcs.cla.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test-dcs.cla.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://test-dcs.cla.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://test-dcs.cla.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://test-dcs.cla.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibidp.polimi.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gaffuri"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:roberto.gaffuri@polimi.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@polimi.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibidp.polimi.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2009-12-31T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDjTCCAnWgAwIBAgIBATANBgkqhkiG9w0BAQUFADCBiTELMAkGA1UEBhMCSVQx\nCzAJBgNVBAgTAk1JMQ4wDAYDVQQHEwVNaWxhbjEPMA0GA1UEChMGUE9MSU1JMQ4w\nDAYDVQQLEwVBU0lDVDEaMBgGA1UEAxMRc2hpYmlkcC5wb2xpbWkuaXQxIDAeBgkq\nhkiG9w0BCQEWEWhvc3RpbmdAcG9saW1pLml0MB4XDTE0MDIyMDExMDcwMFoXDTI2\nMDIyMDExMDcwMFowgYkxCzAJBgNVBAYTAklUMQswCQYDVQQIEwJNSTEOMAwGA1UE\nBxMFTWlsYW4xDzANBgNVBAoTBlBPTElNSTEOMAwGA1UECxMFQVNJQ1QxGjAYBgNV\nBAMTEXNoaWJpZHAucG9saW1pLml0MSAwHgYJKoZIhvcNAQkBFhFob3N0aW5nQHBv\nbGltaS5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKhtqK271QYD\nCWbYMZSqPdm29Oh3yeOVC+6FyoU9i3DIHaiqRxa1yKlYHLx5oLgtPi8ASDzXPfMo\n6MGVGYLOzCe/Y2efdJyz1Pqguna+8jfDtm1MeNCrjYd/cTp5gr/HGZGz262dSmIM\nWrWloF7Zg3jwsXvJYO0wCHLsKVRul7vdosPX7Jy9pIxTO1ZJMZCa/NASWMqf1i+B\ntYVpJqMQZJ85H9pEnu+6dBJMz6QM67zL9WnncMUz1ANkCkLX6mAFV9sydjTXPKrK\nhBBCZF44HOdiIbeZ+NKBZLeirVNALptmTxMg1bNYR2eeys9pdht7qdrvDcBziy5E\ntVFwmsFxMF8CAwEAATANBgkqhkiG9w0BAQUFAAOCAQEApV/JH6zxNIBuB/8zTbO7\nK/uJsh14u/ihkWxCwGJoZTKSttIwlH2Y0+R8fQW/+ZV/aOT3vzJzxJJ/WL6x9Bku\nmlaYSnZ+zD0fQWWWSGK/ncqELDCE35h2B5/hmJ0wSHZewPTPRhvptIYsEFzr9Gr4\nhja1IylB5u+kXNOgR5XJvoojnI1855S/N1p6Y+JUfJKCTciw/0w8Kqlz5Hs9/GHt\nWRQMqSSzXV/Ti6l+6Mu2wvg0LSH2F9XZjN49ZX1E4LPcB8ChCzmrMf87+9+tru9C\nY00stxLKVpXdX8pXFj3zFusdHk7fSeE4cCUYQvN7+Jyy7uSEM10eED6xOqvPw31n\noA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "polimi.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.polimi.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.polimi.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.polimi.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.polimi.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibidp.polimi.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.polimi.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.polimi.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.polimi.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "polimi.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://aunicalogin.polimi.it/aunicalogin/idem.jsp"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.polimi.it/en/english-version/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Politecnico di Milano users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti del Politecnico di Milano"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Politecnico di Milano"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Politecnico di Milano"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDjTCCAnWgAwIBAgIBATANBgkqhkiG9w0BAQUFADCBiTELMAkGA1UEBhMCSVQx\nCzAJBgNVBAgTAk1JMQ4wDAYDVQQHEwVNaWxhbjEPMA0GA1UEChMGUE9MSU1JMQ4w\nDAYDVQQLEwVBU0lDVDEaMBgGA1UEAxMRc2hpYmlkcC5wb2xpbWkuaXQxIDAeBgkq\nhkiG9w0BCQEWEWhvc3RpbmdAcG9saW1pLml0MB4XDTE0MDIyMDExMDcwMFoXDTI2\nMDIyMDExMDcwMFowgYkxCzAJBgNVBAYTAklUMQswCQYDVQQIEwJNSTEOMAwGA1UE\nBxMFTWlsYW4xDzANBgNVBAoTBlBPTElNSTEOMAwGA1UECxMFQVNJQ1QxGjAYBgNV\nBAMTEXNoaWJpZHAucG9saW1pLml0MSAwHgYJKoZIhvcNAQkBFhFob3N0aW5nQHBv\nbGltaS5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKhtqK271QYD\nCWbYMZSqPdm29Oh3yeOVC+6FyoU9i3DIHaiqRxa1yKlYHLx5oLgtPi8ASDzXPfMo\n6MGVGYLOzCe/Y2efdJyz1Pqguna+8jfDtm1MeNCrjYd/cTp5gr/HGZGz262dSmIM\nWrWloF7Zg3jwsXvJYO0wCHLsKVRul7vdosPX7Jy9pIxTO1ZJMZCa/NASWMqf1i+B\ntYVpJqMQZJ85H9pEnu+6dBJMz6QM67zL9WnncMUz1ANkCkLX6mAFV9sydjTXPKrK\nhBBCZF44HOdiIbeZ+NKBZLeirVNALptmTxMg1bNYR2eeys9pdht7qdrvDcBziy5E\ntVFwmsFxMF8CAwEAATANBgkqhkiG9w0BAQUFAAOCAQEApV/JH6zxNIBuB/8zTbO7\nK/uJsh14u/ihkWxCwGJoZTKSttIwlH2Y0+R8fQW/+ZV/aOT3vzJzxJJ/WL6x9Bku\nmlaYSnZ+zD0fQWWWSGK/ncqELDCE35h2B5/hmJ0wSHZewPTPRhvptIYsEFzr9Gr4\nhja1IylB5u+kXNOgR5XJvoojnI1855S/N1p6Y+JUfJKCTciw/0w8Kqlz5Hs9/GHt\nWRQMqSSzXV/Ti6l+6Mu2wvg0LSH2F9XZjN49ZX1E4LPcB8ChCzmrMf87+9+tru9C\nY00stxLKVpXdX8pXFj3zFusdHk7fSeE4cCUYQvN7+Jyy7uSEM10eED6xOqvPw31n\noA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Politecnico di Milano"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Politecnico di Milano"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://shibidp.polimi.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://shibidp.polimi.it/en"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Politecnico di Milano Identity Provider"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Politecnico di Milano Identity Provider"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp0.abertay.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:isservicedesk@abertay.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Christie"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ISSADTeam@abertay.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp0.abertay.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-07-31T11:05:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUc7OjIBg0Vhfh00MlmEXTDJVaD5kwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHTEbMBkGA1UEAxMSaWRwMS5hYmVydGF5LmFjLnVrMB4XDTE0MDYyNzEwNTQz\n\t\t\t\t\t\tM1oXDTM0MDYyNzEwNTQzM1owHTEbMBkGA1UEAxMSaWRwMS5hYmVydGF5LmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAhy85D7Rk1W5IrIatuD01\n\t\t\t\t\t\tbZaUq5/6fagpzqXeprRh8NafBqASLj9+Rzda5lJfMrFmvV9Q5JcyXKXdvnL9vaQi\n\t\t\t\t\t\to61t2sAwKTHrmOT8nIHCVLJGIx8wclEUQZifdDzQNIj9MiLL40nN6tD0WQIXcO/e\n\t\t\t\t\t\t4nmBA4havm437GGuFOdP7ZkY2Xuex1AufaJq144mqNHhk4rYplbkpVS+M+NLbRLX\n\t\t\t\t\t\tvooF2zl+CxGwHF1pYiKdbb8+Kf+v9uFX5wMGNZMfpymMprLf6m7dBLxVur2g1pcF\n\t\t\t\t\t\tvvzRddBlKCshg6a3zh6RXgRf8ZmfU//HpBCPQdQ1d09gqUt0hJ8Mf89S65+fTB+Y\n\t\t\t\t\t\twQIDAQABo2swaTBIBgNVHREEQTA/ghJpZHAxLmFiZXJ0YXkuYWMudWuGKWh0dHBz\n\t\t\t\t\t\tOi8vaWRwMS5hYmVydGF5LmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRe\n\t\t\t\t\t\tnf9RmkNw8n4n58D1CDsey26VnTANBgkqhkiG9w0BAQUFAAOCAQEAIG2zPbZsoZxE\n\t\t\t\t\t\taj2ZH6TxNRkR+l8N86WXWn0AdITwU1PX2+5w38sSOuNb0FNA1MesY643dZOUM0TK\n\t\t\t\t\t\t/JpPlGT8GPFAq+Pq3XKCMyLnPJd3WXqEzpbjRUsFmn9Pylsc3uQ27+kuYQ+SCPnS\n\t\t\t\t\t\ttcU8ObI0Zcdk/ZfAn0P3R0DjmzypCt7qC/vqQbskGtniDGPlo9uqYTKxKZW5Xj5z\n\t\t\t\t\t\tQaP8CP68+ECeTyyJs2E9IyjwU3r8e1ruNmLgXlIrZvLcyoc5TcnKgmuj+VhDho9s\n\t\t\t\t\t\tDZWQqoz3Cs2kX3tT0BeVdPiHLZ+Vwc8Bi+WWqioz6oGI16NJYTrhWuMCG3rB7lXZ\n\t\t\t\t\t\tkYaFXYT6DQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uad.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.abertay.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.abertay.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp1.abertay.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp1.abertay.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.abertay.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp1.abertay.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp1.abertay.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp1.abertay.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp1.abertay.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.abertay.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.abertay.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uad.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://idp1.abertay.ac.uk/icons/colour-abertay-uni-logo.png",
                    "height": "23",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idp1.abertay.ac.uk/icons/small/shield_16x16.ico",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Abertay University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUc7OjIBg0Vhfh00MlmEXTDJVaD5kwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHTEbMBkGA1UEAxMSaWRwMS5hYmVydGF5LmFjLnVrMB4XDTE0MDYyNzEwNTQz\n\t\t\t\t\t\tM1oXDTM0MDYyNzEwNTQzM1owHTEbMBkGA1UEAxMSaWRwMS5hYmVydGF5LmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAhy85D7Rk1W5IrIatuD01\n\t\t\t\t\t\tbZaUq5/6fagpzqXeprRh8NafBqASLj9+Rzda5lJfMrFmvV9Q5JcyXKXdvnL9vaQi\n\t\t\t\t\t\to61t2sAwKTHrmOT8nIHCVLJGIx8wclEUQZifdDzQNIj9MiLL40nN6tD0WQIXcO/e\n\t\t\t\t\t\t4nmBA4havm437GGuFOdP7ZkY2Xuex1AufaJq144mqNHhk4rYplbkpVS+M+NLbRLX\n\t\t\t\t\t\tvooF2zl+CxGwHF1pYiKdbb8+Kf+v9uFX5wMGNZMfpymMprLf6m7dBLxVur2g1pcF\n\t\t\t\t\t\tvvzRddBlKCshg6a3zh6RXgRf8ZmfU//HpBCPQdQ1d09gqUt0hJ8Mf89S65+fTB+Y\n\t\t\t\t\t\twQIDAQABo2swaTBIBgNVHREEQTA/ghJpZHAxLmFiZXJ0YXkuYWMudWuGKWh0dHBz\n\t\t\t\t\t\tOi8vaWRwMS5hYmVydGF5LmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRe\n\t\t\t\t\t\tnf9RmkNw8n4n58D1CDsey26VnTANBgkqhkiG9w0BAQUFAAOCAQEAIG2zPbZsoZxE\n\t\t\t\t\t\taj2ZH6TxNRkR+l8N86WXWn0AdITwU1PX2+5w38sSOuNb0FNA1MesY643dZOUM0TK\n\t\t\t\t\t\t/JpPlGT8GPFAq+Pq3XKCMyLnPJd3WXqEzpbjRUsFmn9Pylsc3uQ27+kuYQ+SCPnS\n\t\t\t\t\t\ttcU8ObI0Zcdk/ZfAn0P3R0DjmzypCt7qC/vqQbskGtniDGPlo9uqYTKxKZW5Xj5z\n\t\t\t\t\t\tQaP8CP68+ECeTyyJs2E9IyjwU3r8e1ruNmLgXlIrZvLcyoc5TcnKgmuj+VhDho9s\n\t\t\t\t\t\tDZWQqoz3Cs2kX3tT0BeVdPiHLZ+Vwc8Bi+WWqioz6oGI16NJYTrhWuMCG3rB7lXZ\n\t\t\t\t\t\tkYaFXYT6DQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Abertay University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.abertay.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Abertay Dundee"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.test.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.test.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.test.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.test.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.test.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.test.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.test.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.test.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.test.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.test.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.test.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.test.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.test.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.test.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFHDCCAwSgAwIBAgIJAIbDYkZWg5D9MA0GCSqGSIb3DQEBCwUAMBwxGjAYBgNV\nBAMTEXd3dy50ZXN0LmxhZG9rLnNlMB4XDTE2MDIxMDEzMzUzNloXDTI2MDIwNzEz\nMzUzNlowHDEaMBgGA1UEAxMRd3d3LnRlc3QubGFkb2suc2UwggIiMA0GCSqGSIb3\nDQEBAQUAA4ICDwAwggIKAoICAQC+W5Gi4u6RApYh068l1O/jZB1LKHMYfBa7BeR1\nnGjZXTI15BhJJDeaIqiIyZCwmPiki66Ma5frzSERCki1u7rfP38/bddLtvCCpYhP\nxmQhOFWXQ3SXaWQETSZ3mVLnZmUk7rrnANnfKFLst0AGAAZGJ1M2CTT9yLXhzm4v\n/klsaoVjpOmfpmNlMV+wWj35fpm2Ni8XL1aSQnz0Q6/vUtbP+zbRUwMpXFC/8NO/\n+JT5HMOq6fAJpVJvozwOcPQ83ZaZRYYk2dcOPWgEG5Y4ooEnGdLNfiKQ6DyaMEev\nKGfaLdapWntSi4aeQoqDnGU13nbaRAMvOs389phEHQDpq28qGL3Njwgdg+yLGzJj\n9jUlkYkz7CvR+GQLsZqOeudX/3P1EhavPpk1aG7bGhUUhuLI67m0I5u6axXZi7UQ\nHKqOL4zjNvz1YpL4fel/47WcteYHarumJmuBpmvCqJAfjn9hZMqOkCLbY3NW/qai\nTRznyxNiK+bYZ0VfUcDCvsac0+NcU9a42j5fo1a2Y9q/7MMq76TJ3176t+rYWqJi\n199jmKfyffcrriV4HXkYwYywDyWAn+imSuso+PW7SNDxFu7gY7pPgU2Dnov31lq8\nzJVpN3ssOEWaAJcbPcS4Ho/9o2kL6Hpp42yhNn0ZCnTeOQKpariM8BRN/12v9zXD\naoPC6QIDAQABo2EwXzA+BgNVHREENzA1ghF3d3cudGVzdC5sYWRvay5zZYYgaHR0\ncHM6Ly93d3cudGVzdC5sYWRvay5zZS9ndWktc3AwHQYDVR0OBBYEFHtJ6TbmFAeA\n4BaaLUhwxUHgEszoMA0GCSqGSIb3DQEBCwUAA4ICAQCnQhO2mDJe2HGQzC0Hts9r\nCxgSUQSR23e8FbXWFBniYByYPc786HJsoeDI3YvEO00rOSIRX45Mya5Iapbnj4F3\nf/ya6agLSjMk6ce9u+kqIeXii3JvFcV/biDdHSEdVgOEr39YMWP5tyaJhmesZLfy\n1SnJzlW3PrvFdgaKIfVJ2lfukx3OESJ10/CgRllf91eKpfTPB2g8vU0RAUq+odkk\nX7tSbGDpRtOYfym6FXZpdh2ZBft1QJV7E7jMJZ1dWx7gvp7w06JJozaXaiyIPKCl\nEIYvEppBO+Hs7IbDS4kUSKdzF14wof7qpzQQ+yULmOkrfC80MHGXkKaYNB+mzQ2C\nAm+tmUDwu+6JNeNDlrN72AlojvsDObgsCHoQIVsSx2wFYDM2zTvA/MR71KHASEi8\neGdXcOgn3UMS/ehYrnDq0m/bAjsn/AHjGjIqsFQUpzwqG3N2djGtOD2dzcxOOKCL\n31aHDlUTgv1hdCpa5+NiIzRrahJoJrfmli/NBlX5wQbQ0s1UVlbgy5Xw0Ttr4IIy\nLDCJR8LVHDuZcx5GKkrwQE6fWwLJM8JI8JZF0w9j8bsrU3WUfCwfMaCKvwFlYgQQ\nY6TwKaxgtHgm3WFnPMMTXkKWeKq3sp5fajwzptV1MA/uS2aOuboQ7qm6J2aFy0yX\nQOr7nPNnNq2e/M/T2ugEMg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.test.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.test.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.test.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.test.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.test.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.test.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.test.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.test.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.test.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.test.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://filesender.cesnet.cz/saml/sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kopecky - administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "du-support@cesnet.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lubos"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://filesender.cesnet.cz/saml/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2011-11-04T10:27:36Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/sp-group/aa.cesnet.cz"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CESNET"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CESNET"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ces.net/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cesnet.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CESNET"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://filesender.cesnet.cz/simplesaml/module.php/saml/sp/saml2-logout.php/filesender.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://filesender.du1.cesnet.cz/simplesaml/module.php/saml/sp/saml2-logout.php/filesender.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://filesender4elixir.cesnet.cz/simplesaml/module.php/saml/sp/saml2-logout.php/filesender.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://filesender6.cesnet.cz/simplesaml/module.php/saml/sp/saml2-logout.php/filesender.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://filesender.cesnet.cz/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://filesender.cesnet.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CESNETs servis for sending files."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Cesnet\u00ed slu\u017eba pro pos\u00edl\u00e1n\u00ed soubor\u016f."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FileSender"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FileSender"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://filesender.cesnet.cz/simplesaml/module.php/saml/sp/saml2-acs.php/filesender.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://filesender.cesnet.cz/simplesaml/module.php/saml/sp/saml1-acs.php/filesender.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://filesender.cesnet.cz/simplesaml/module.php/saml/sp/saml2-acs.php/filesender.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://filesender.cesnet.cz/simplesaml/module.php/saml/sp/saml1-acs.php/filesender.cesnet.cz/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://filesender.du1.cesnet.cz/simplesaml/module.php/saml/sp/saml2-acs.php/filesender.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://filesender.du1.cesnet.cz/simplesaml/module.php/saml/sp/saml1-acs.php/filesender.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://filesender.du1.cesnet.cz/simplesaml/module.php/saml/sp/saml2-acs.php/filesender.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://filesender.du1.cesnet.cz/simplesaml/module.php/saml/sp/saml1-acs.php/filesender.cesnet.cz/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://filesender4elixir.cesnet.cz/simplesaml/module.php/saml/sp/saml2-acs.php/filesender.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://filesender4elixir.cesnet.cz/simplesaml/module.php/saml/sp/saml1-acs.php/filesender.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://filesender4elixir.cesnet.cz/simplesaml/module.php/saml/sp/saml2-acs.php/filesender.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://filesender4elixir.cesnet.cz/simplesaml/module.php/saml/sp/saml1-acs.php/filesender.cesnet.cz/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://filesender6.cesnet.cz/simplesaml/module.php/saml/sp/saml2-acs.php/filesender.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://filesender6.cesnet.cz/simplesaml/module.php/saml/sp/saml1-acs.php/filesender.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://filesender6.cesnet.cz/simplesaml/module.php/saml/sp/saml2-acs.php/filesender.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://filesender6.cesnet.cz/simplesaml/module.php/saml/sp/saml1-acs.php/filesender.cesnet.cz/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://login.uea.ac.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:web@uea.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UEA Web Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:web@uea.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UEA Web Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.uea.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-03-01T10:16:25Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.uea.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.uea.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uea.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://login.uea.ac.uk/oala/uea-uk-fed-logo.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://login.uea.ac.uk/oala/uea-uk-fed-icon-16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of East Anglia (UEA)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "139.222.0.0/16"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDoDCCAoigAwIBAgIJAIuKNtoJUQjXMA0GCSqGSIb3DQEBBQUAMD4xIjAgBgNV\n\t\t\t\t\t\tBAoTGVVuaXZlcnNpdHkgb2YgRWFzdCBBbmdsaWExGDAWBgNVBAMTD2xvZ2luLnVl\n\t\t\t\t\t\tYS5hYy51azAeFw0xMDExMDkwNzU3NTJaFw0yMDExMDYwNzU3NTJaMD4xIjAgBgNV\n\t\t\t\t\t\tBAoTGVVuaXZlcnNpdHkgb2YgRWFzdCBBbmdsaWExGDAWBgNVBAMTD2xvZ2luLnVl\n\t\t\t\t\t\tYS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM9oeuK7k5dK\n\t\t\t\t\t\tbp97dCPSq7gqVrm3Rq2fyW62SFx1IVwFBtoW1CIQOkDJF8bVkKa2U+dMmwLHvfEP\n\t\t\t\t\t\tqVnXXA59eDJeGRib2ME6o1q90McllqBVWhuBoR08GFEdXhbt1lpUpBNOF+V9lv+y\n\t\t\t\t\t\tf37bDm2ii+iaCaOcaT5sO9g0krqw/mlWsSPUIhAG7TzndSECH4lHdqBEWPlk87gn\n\t\t\t\t\t\t5LeuezjWpgQmdPD6PaB2fuTyQyP+BeNeIK8EiJvCpBzA92EKitTHxTa6ON3LEy0L\n\t\t\t\t\t\tqzJCDWx7rq0R0ch7TmzGw8DLrKIWRHbfH2nMWMFMp7Hf1EhB/Z1+R7nhgIV6HxQi\n\t\t\t\t\t\td+DmuhrLJB8CAwEAAaOBoDCBnTAdBgNVHQ4EFgQUREAlXs64Gbcn4E+0R5mumL5k\n\t\t\t\t\t\t+MwwbgYDVR0jBGcwZYAUREAlXs64Gbcn4E+0R5mumL5k+MyhQqRAMD4xIjAgBgNV\n\t\t\t\t\t\tBAoTGVVuaXZlcnNpdHkgb2YgRWFzdCBBbmdsaWExGDAWBgNVBAMTD2xvZ2luLnVl\n\t\t\t\t\t\tYS5hYy51a4IJAIuKNtoJUQjXMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAKhau/vUIiWf7K2ILlfdK89NKLuvUwndns9sYEcIFAqTMWnGlpXogPzFUqvd\n\t\t\t\t\t\tPTEjYSkffvr5xHPIasBpaouVmqsr245P1aX9qZh4f6K7FLS+hUHdJvaFrGl6oxEe\n\t\t\t\t\t\tWPILAJimme/YZqVCmyyLeYAB+l9Yt81wd+xkaajOrbNalv2f1fxIwQpGp3oosR3b\n\t\t\t\t\t\tWXVQwwCnZX7KrZHmIfiRvY9yYctOsXs1xlbZoR8m0F5Tq3xOZIoHjOoWyl4AARFM\n\t\t\t\t\t\tNpCaUKSy/eK1MvlZph0VK6QY4P7xlZMvEnMQscrf/bEBblQ+dGyfM664mnPAvWgR\n\t\t\t\t\t\tnIhXWvtGhtoIysHU01bNRSH11OA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDoDCCAoigAwIBAgIJAIuKNtoJUQjXMA0GCSqGSIb3DQEBBQUAMD4xIjAgBgNV\n\t\t\t\t\t\tBAoTGVVuaXZlcnNpdHkgb2YgRWFzdCBBbmdsaWExGDAWBgNVBAMTD2xvZ2luLnVl\n\t\t\t\t\t\tYS5hYy51azAeFw0xMDExMDkwNzU3NTJaFw0yMDExMDYwNzU3NTJaMD4xIjAgBgNV\n\t\t\t\t\t\tBAoTGVVuaXZlcnNpdHkgb2YgRWFzdCBBbmdsaWExGDAWBgNVBAMTD2xvZ2luLnVl\n\t\t\t\t\t\tYS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM9oeuK7k5dK\n\t\t\t\t\t\tbp97dCPSq7gqVrm3Rq2fyW62SFx1IVwFBtoW1CIQOkDJF8bVkKa2U+dMmwLHvfEP\n\t\t\t\t\t\tqVnXXA59eDJeGRib2ME6o1q90McllqBVWhuBoR08GFEdXhbt1lpUpBNOF+V9lv+y\n\t\t\t\t\t\tf37bDm2ii+iaCaOcaT5sO9g0krqw/mlWsSPUIhAG7TzndSECH4lHdqBEWPlk87gn\n\t\t\t\t\t\t5LeuezjWpgQmdPD6PaB2fuTyQyP+BeNeIK8EiJvCpBzA92EKitTHxTa6ON3LEy0L\n\t\t\t\t\t\tqzJCDWx7rq0R0ch7TmzGw8DLrKIWRHbfH2nMWMFMp7Hf1EhB/Z1+R7nhgIV6HxQi\n\t\t\t\t\t\td+DmuhrLJB8CAwEAAaOBoDCBnTAdBgNVHQ4EFgQUREAlXs64Gbcn4E+0R5mumL5k\n\t\t\t\t\t\t+MwwbgYDVR0jBGcwZYAUREAlXs64Gbcn4E+0R5mumL5k+MyhQqRAMD4xIjAgBgNV\n\t\t\t\t\t\tBAoTGVVuaXZlcnNpdHkgb2YgRWFzdCBBbmdsaWExGDAWBgNVBAMTD2xvZ2luLnVl\n\t\t\t\t\t\tYS5hYy51a4IJAIuKNtoJUQjXMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAKhau/vUIiWf7K2ILlfdK89NKLuvUwndns9sYEcIFAqTMWnGlpXogPzFUqvd\n\t\t\t\t\t\tPTEjYSkffvr5xHPIasBpaouVmqsr245P1aX9qZh4f6K7FLS+hUHdJvaFrGl6oxEe\n\t\t\t\t\t\tWPILAJimme/YZqVCmyyLeYAB+l9Yt81wd+xkaajOrbNalv2f1fxIwQpGp3oosR3b\n\t\t\t\t\t\tWXVQwwCnZX7KrZHmIfiRvY9yYctOsXs1xlbZoR8m0F5Tq3xOZIoHjOoWyl4AARFM\n\t\t\t\t\t\tNpCaUKSy/eK1MvlZph0VK6QY4P7xlZMvEnMQscrf/bEBblQ+dGyfM664mnPAvWgR\n\t\t\t\t\t\tnIhXWvtGhtoIysHU01bNRSH11OA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of East Anglia (UEA)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uea.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of East Anglia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp1.hogent.be/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Technical Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@hogent.be"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp1.hogent.be/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://federation.belnet.be/files/Belnet-metadata-registration-practice-statement.txt"
              }
            ],
            "registration_instant": "2012-03-27T12:00:00Z",
            "registration_authority": "http://federation.belnet.be/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAKN8lW+W0bwU2Fgdizh1Fc78eC1cMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcDEuaG9nZW50LmJlMB4XDTEzMTAwNzE0MzI1M1oX\nDTMzMTAwNzE0MzI1M1owGTEXMBUGA1UEAxMOaWRwMS5ob2dlbnQuYmUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCpFqqWVjzACwe3pHH4Z+zxtqD0UjIF\nupRkh8638dhdPTsEAS/dIdoG9vI5Bo0o/3Mds/2Vcasih1aEtLpOZA5szGjbQyF3\nBif6ExfNRc07D9o4o1wEzkkOEaNV6edkBJAENNnuFBZVES13FIhvyW673sdFMU26\nq/PTgXt+DVejhpdgkMtqTLaAbD3G4aViVeNIstuJcrIXwZv3YgD4lgU/fXNjjLDE\nHk8DuL+aGVmalg37cnxNtq+i7O6lW3/yrLxExCOiFkdvcQq2lCfwECU41ira4M2o\nYuB0CDsYqK8rk3Btk4VueIDJsnivARPrJiRNSN7z1WhDjNe7M5pkC4E9AgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcDEuaG9nZW50LmJlhiVodHRwczovL2lkcDEuaG9n\nZW50LmJlL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQC4xxZFlWHXKtFqS2uu3pI\n8k+42jANBgkqhkiG9w0BAQUFAAOCAQEAXFNa7quzgSZt+SBCYhjI/5L5EF5ZkZv1\nVSViW5l/vIyFNfMZiXKKsZXZ55WfGePMbrnWh7l0GPlLzgRpFnLuBRS2+VwzWpzA\nH5KAS7a7R0rgvKd7/21l7XrRcBr6z/TNewOb8mpySJTH5M3in2PejUd5+Ae6PsU9\nPY4KiNwdLjzlzJPo/IBFLxiu70X5hTxip+OxTp7bxMleEG7PnlTzQIWMmBehHnDa\nYCtYQpTwBizo6WlwrYOpE/KWQRYL5BB/Q3aW2KeUy87jEpbgU/SojjBrp5y8wRsp\n4rV7/SlPD5jEYnPfqLEiiXz/yXbN2dNfvlO47aV2d/GdWvKDGnijBw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hogent.be"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.hogent.be:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.hogent.be:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp1.hogent.be/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp1.hogent.be/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.hogent.be:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp1.hogent.be/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp1.hogent.be/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp1.hogent.be/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp1.hogent.be/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.hogent.be:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.hogent.be:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hogent.be"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hogeschool Gent"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "75",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "153"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hogent"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "hogent.be"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.032894, 3.703396"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.172.0/26"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:6a8:1c60:d000::/64"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAKN8lW+W0bwU2Fgdizh1Fc78eC1cMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcDEuaG9nZW50LmJlMB4XDTEzMTAwNzE0MzI1M1oX\nDTMzMTAwNzE0MzI1M1owGTEXMBUGA1UEAxMOaWRwMS5ob2dlbnQuYmUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCpFqqWVjzACwe3pHH4Z+zxtqD0UjIF\nupRkh8638dhdPTsEAS/dIdoG9vI5Bo0o/3Mds/2Vcasih1aEtLpOZA5szGjbQyF3\nBif6ExfNRc07D9o4o1wEzkkOEaNV6edkBJAENNnuFBZVES13FIhvyW673sdFMU26\nq/PTgXt+DVejhpdgkMtqTLaAbD3G4aViVeNIstuJcrIXwZv3YgD4lgU/fXNjjLDE\nHk8DuL+aGVmalg37cnxNtq+i7O6lW3/yrLxExCOiFkdvcQq2lCfwECU41ira4M2o\nYuB0CDsYqK8rk3Btk4VueIDJsnivARPrJiRNSN7z1WhDjNe7M5pkC4E9AgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcDEuaG9nZW50LmJlhiVodHRwczovL2lkcDEuaG9n\nZW50LmJlL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQC4xxZFlWHXKtFqS2uu3pI\n8k+42jANBgkqhkiG9w0BAQUFAAOCAQEAXFNa7quzgSZt+SBCYhjI/5L5EF5ZkZv1\nVSViW5l/vIyFNfMZiXKKsZXZ55WfGePMbrnWh7l0GPlLzgRpFnLuBRS2+VwzWpzA\nH5KAS7a7R0rgvKd7/21l7XrRcBr6z/TNewOb8mpySJTH5M3in2PejUd5+Ae6PsU9\nPY4KiNwdLjzlzJPo/IBFLxiu70X5hTxip+OxTp7bxMleEG7PnlTzQIWMmBehHnDa\nYCtYQpTwBizo6WlwrYOpE/KWQRYL5BB/Q3aW2KeUy87jEpbgU/SojjBrp5y8wRsp\n4rV7/SlPD5jEYnPfqLEiiXz/yXbN2dNfvlO47aV2d/GdWvKDGnijBw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hogeschool Gent"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hogent.be"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hogeschool Gent"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.esh.se/idp/shibboleth",
    {
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVALaN98IcoLX3UQ+fKlQVmqP23WvBMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC5lc2guc2UwHhcNMTMwODA3MDkwOTU4WhcNMzMw\nODA3MDkwOTU4WjAVMRMwEQYDVQQDEwppZHAuZXNoLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAn2ZQb1kuPTXtueUtR79lZa5hCV2fMlOlfFJFMyC3\n+6qQR6CGGZ7GvntHtIKpbfFqIeCsWNGXLttNDmGroG6koge0CEKv6z6JVD5tHert\nUVRA7GpDZpZLR7qRYcrbZp1tLrk9gKL3/PaudZhwAKuWiMz5HNyqk9Ojh3YRWJUD\n1O3RX6l2tvc8MjT8JYE2D+TpqqiT5k1WgV7zgCv3QVnazfuANKZ2qjxiKVi3bh1w\nV/3VDJiN9DYhN1NvU412QBZR1AU1XJL36qkKmeTOi8qhhlxh6abl2oEpgyjR0lxn\no1HwkDipkIJJiN/h7CKlUnEHpPidI5tMy/PezW78h2znfwIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAuZXNoLnNlhiFodHRwczovL2lkcC5lc2guc2UvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFDGWVB2qNc/D6uRZt2wqI4/SM3Y6MA0GCSqGSIb3DQEB\nBQUAA4IBAQCMaKhHwEwcXTM7/HO6RbavAsisMab0TsCmuYsrCtYFccdrFNEUs+R5\nqGwHre8J+0cMi0WgSIHXLnbhvjG3JPmBeLkZdSw/rOGtF6w6VSVpT2iGvfjNbsBq\nwFGkaEnsDKzhiBaIOcJyAJoh97PJygz7yriziwxDZrB7b0xnBHVs6u4HNuQjd/NA\ngeGI3bNTbXj3Fgu9lanUQE7DbWETQEnrqI2QH+8tr4vVnhG7jaET+qP/ya+XXPJ1\n+PUaqX2b8yCDIeHr7NkqtYf1nqphQ71OvdKe1R6Pzw9N19ny10FJcZypisRt/ghv\n9SqhISRU1eEjg6GtcLZCkvdVGag/E4qO"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "esh.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.esh.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.esh.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.esh.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.esh.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.esh.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.esh.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.esh.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.esh.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "esh.se"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r Ersta Sk\u00f6ndal University College"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for the Royal Swedish Academy of Sciences"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ersta Sk\u00f6ndal H\u00f6gskola"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ersta Sk\u00f6ndal University College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVALaN98IcoLX3UQ+fKlQVmqP23WvBMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC5lc2guc2UwHhcNMTMwODA3MDkwOTU4WhcNMzMw\nODA3MDkwOTU4WjAVMRMwEQYDVQQDEwppZHAuZXNoLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAn2ZQb1kuPTXtueUtR79lZa5hCV2fMlOlfFJFMyC3\n+6qQR6CGGZ7GvntHtIKpbfFqIeCsWNGXLttNDmGroG6koge0CEKv6z6JVD5tHert\nUVRA7GpDZpZLR7qRYcrbZp1tLrk9gKL3/PaudZhwAKuWiMz5HNyqk9Ojh3YRWJUD\n1O3RX6l2tvc8MjT8JYE2D+TpqqiT5k1WgV7zgCv3QVnazfuANKZ2qjxiKVi3bh1w\nV/3VDJiN9DYhN1NvU412QBZR1AU1XJL36qkKmeTOi8qhhlxh6abl2oEpgyjR0lxn\no1HwkDipkIJJiN/h7CKlUnEHpPidI5tMy/PezW78h2znfwIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAuZXNoLnNlhiFodHRwczovL2lkcC5lc2guc2UvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFDGWVB2qNc/D6uRZt2wqI4/SM3Y6MA0GCSqGSIb3DQEB\nBQUAA4IBAQCMaKhHwEwcXTM7/HO6RbavAsisMab0TsCmuYsrCtYFccdrFNEUs+R5\nqGwHre8J+0cMi0WgSIHXLnbhvjG3JPmBeLkZdSw/rOGtF6w6VSVpT2iGvfjNbsBq\nwFGkaEnsDKzhiBaIOcJyAJoh97PJygz7yriziwxDZrB7b0xnBHVs6u4HNuQjd/NA\ngeGI3bNTbXj3Fgu9lanUQE7DbWETQEnrqI2QH+8tr4vVnhG7jaET+qP/ya+XXPJ1\n+PUaqX2b8yCDIeHr7NkqtYf1nqphQ71OvdKe1R6Pzw9N19ny10FJcZypisRt/ghv\n9SqhISRU1eEjg6GtcLZCkvdVGag/E4qO"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ersta Sk\u00f6ndal H\u00f6gskola"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ersta Sk\u00f6ndal University College"
          }
        ],
        "organization_url": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.esh.se/"
          }
        ],
        "organization_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ersta Sk\u00f6ndal H\u00f6gskola"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "entity_id": "https://idp.esh.se/idp/shibboleth"
    }
  ],
  [
    "https://shibboleth.gmu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "holt@gmu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tracy Holt"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "wallyg@gmu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Wally Grotophorst"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.gmu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.gmu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.gmu.edu/idp/profile/Shibboleth/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.gmu.edu/idp/profile/Shibboleth/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.gmu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.gmu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gmu.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "George Mason University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUepAw2N9+pmX9TWoDp/ZsdB/L1yEwDQYJKoZIhvcNAQEF\nBQAwHTEbMBkGA1UEAxMSc2hpYmJvbGV0aC5nbXUuZWR1MB4XDTEwMDYyNDE0NTMy\nMVoXDTMwMDYyNDE0NTMyMVowHTEbMBkGA1UEAxMSc2hpYmJvbGV0aC5nbXUuZWR1\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAgp2Dn6k3UuILLaGWGcyQ\nenA31AxjXOoCM7zrhPpSJFzUSPHs2mC/fEqUhqmHJnPxGNalPpW9BH6SN1U2/C+e\nrfVL/OcO/x+Var0Pt+GodnlMsf+f7jcyLMzQB+xG+4/iKPoPByyOlThM+dO7/j/w\nQuclJu6f5iUTYyQM5u+DnvGzCmEA7Oq6E6c/FPegTAXCTnhQie9ZOOKjYfc/Y+y/\n1r7JYP4wkyk6ldk/Jt3xlP7eSvREIzMb5cetg1CbX6NmBsrBiSixMUDbOShDf01/\n8X6ebsaDIFCocE44/UAEM7xAQHUB/wHa7lhsVXI4pHUQ4eE5+9cjAq6/KkioOHnZ\naQIDAQABo2swaTBIBgNVHREEQTA/ghJzaGliYm9sZXRoLmdtdS5lZHWGKWh0dHBz\nOi8vc2hpYmJvbGV0aC5nbXUuZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSM\nUsKgJtDJoCxpwHtips8ra+EF+TANBgkqhkiG9w0BAQUFAAOCAQEAcpGmKUvfmyI7\nhbGONBpP3O5hTDeVe5Xiq5CHsfpduhsknht6uEWa8Z4dUg0QfAQKfaHvan4rg9Wl\nCHk4CnbLvB31Bbvz+TGjepNldfGeY2D0O4O2bxSjanFUAo1Kh+dUKSECtTEbwYdC\n2NcU2TQN4y5aEnC0jE8rj8VhvK3ynej8xJbqjVEY4Q6ndcvkUieqphdFOxBzIgk5\nIHEk7lPD0ggHR2Rp8nKE5xbCnL0j6WLTi+MbyMSZKlaNijMJJsybnB7L7dTXOR0z\n07DA0lAnAjYsa5Y/+xYddE7hlz3BkcttcuOgsEuLUtpd2wrWUGmJcOR7GUBTYfm4\ng750I0EPsQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "George Mason University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gmu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "George Mason University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://katalog.svkos.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Zavilov\u00e1"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "zavilova@svkos.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Magda"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://katalog.svkos.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2014-01-08T16:18:12Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/library"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://katalog.svkos.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://katalog.svkos.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUOaQEEERrbashpZa05w//pJQCTE0wDQYJKoZIhvcNAQEL\nBQAwGzEZMBcGA1UEAwwQa2F0YWxvZy5zdmtvcy5jejAeFw0xNTA4MTIyMTE4NTla\nFw0yNTA4MTIyMTE4NTlaMBsxGTAXBgNVBAMMEGthdGFsb2cuc3Zrb3MuY3owggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQClR0WK0cmbSWU8RArh2svrRpft\nS4nHdg41jsbx0uKJWmpjVpxzIO8t1fpvgQEdjSM2mIBBuSeCpBX+O1Hogk8H7d1Y\nh4LLEkGKiBLQNZRxKueDGc1Pc54+iYy6oMcl1fhaoqphSkW9CqJXGb8lGEnfa8+t\n+MO62kESeTV/9L1fHb0exJgqzCrml/Byev7uXdaqRWqRVeXxy6eXlWhlLGwkPXMf\n9CbIyE5DyXHUupoJu8aiNh11JuR1VgZLUoOOS3yHE53HK200pISag+PIqc2g6hAw\nGHOjKJRcUrZSaqKKRvv39TLwqq9gPL3pSUVJ+G7GYc+mBFpclz/g+H/cCt0vAgMB\nAAGjZzBlMB0GA1UdDgQWBBQx4EEeJ3tf34XxGVnEpsE1hXAfTjBEBgNVHREEPTA7\nghBrYXRhbG9nLnN2a29zLmN6hidodHRwczovL2thdGFsb2cuc3Zrb3MuY3ovaWRw\nL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBACPiFGXFPzxPH/eTQKbJT5lP\nyOcSE2rtal8W4QDrkE4hU220t/JjQVsRzKMnvsv/rgY6CzEYcMkPitPjJoJXmLWY\nJZaaTxx0LosXA0MU8wBj6JKTMSDJ/EEkJOQuak+2lxxwv6greAAe/Ye+6x1fqN1h\nJE6TMVker9+t4OjM0aTX5LeBvJs7ZKwbTDsnm9y9I8EPwtPnX96M3cd/D7H5h4mF\nUUObFs5lyLqvErUgn3FwKNMmi2FrTI0J1HQtLx87hfeUvriApTOW/apm+kqWE6P5\niZxetNC82lCt7vGHOz5cXzYN2MEuqqCvAM2dTLO7rRhrSctONV0qrHlg1vZ4Vbw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "svkos.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://katalog.svkos.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://katalog.svkos.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://katalog.svkos.cz/idp/profile/SAML2/POST-SimpleSign/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://katalog.svkos.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://katalog.svkos.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://katalog.svkos.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://katalog.svkos.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://katalog.svkos.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://katalog.svkos.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://katalog.svkos.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "svkos.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.svkos.cz/en/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.svkos.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for patrons and staff of Moravian-Silesian Research Library in Ostrava"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro \u010dten\u00e1\u0159e a zam\u011bstance Moravskoslezsk\u00e9 v\u011bdeck\u00e9 knihovny v Ostrav\u011b"
                  }
                ],
                "logo": [
                  {
                    "text": "https://katalog.svkos.cz/logo/logo_40.png",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "40"
                  },
                  {
                    "text": "https://katalog.svkos.cz/logo/logo_90.png",
                    "height": "90",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "91"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Moravian-Silesian Research Library in Ostrava"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Moravskoslezsk\u00e1 v\u011bdeck\u00e1 knihovna v Ostrav\u011b"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUOaQEEERrbashpZa05w//pJQCTE0wDQYJKoZIhvcNAQEL\nBQAwGzEZMBcGA1UEAwwQa2F0YWxvZy5zdmtvcy5jejAeFw0xNTA4MTIyMTE4NTla\nFw0yNTA4MTIyMTE4NTlaMBsxGTAXBgNVBAMMEGthdGFsb2cuc3Zrb3MuY3owggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQClR0WK0cmbSWU8RArh2svrRpft\nS4nHdg41jsbx0uKJWmpjVpxzIO8t1fpvgQEdjSM2mIBBuSeCpBX+O1Hogk8H7d1Y\nh4LLEkGKiBLQNZRxKueDGc1Pc54+iYy6oMcl1fhaoqphSkW9CqJXGb8lGEnfa8+t\n+MO62kESeTV/9L1fHb0exJgqzCrml/Byev7uXdaqRWqRVeXxy6eXlWhlLGwkPXMf\n9CbIyE5DyXHUupoJu8aiNh11JuR1VgZLUoOOS3yHE53HK200pISag+PIqc2g6hAw\nGHOjKJRcUrZSaqKKRvv39TLwqq9gPL3pSUVJ+G7GYc+mBFpclz/g+H/cCt0vAgMB\nAAGjZzBlMB0GA1UdDgQWBBQx4EEeJ3tf34XxGVnEpsE1hXAfTjBEBgNVHREEPTA7\nghBrYXRhbG9nLnN2a29zLmN6hidodHRwczovL2thdGFsb2cuc3Zrb3MuY3ovaWRw\nL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBACPiFGXFPzxPH/eTQKbJT5lP\nyOcSE2rtal8W4QDrkE4hU220t/JjQVsRzKMnvsv/rgY6CzEYcMkPitPjJoJXmLWY\nJZaaTxx0LosXA0MU8wBj6JKTMSDJ/EEkJOQuak+2lxxwv6greAAe/Ye+6x1fqN1h\nJE6TMVker9+t4OjM0aTX5LeBvJs7ZKwbTDsnm9y9I8EPwtPnX96M3cd/D7H5h4mF\nUUObFs5lyLqvErUgn3FwKNMmi2FrTI0J1HQtLx87hfeUvriApTOW/apm+kqWE6P5\niZxetNC82lCt7vGHOz5cXzYN2MEuqqCvAM2dTLO7rRhrSctONV0qrHlg1vZ4Vbw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Moravskoslezsk\u00e1 v\u011bdeck\u00e1 knihovna v Ostrav\u011b"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Moravian-Silesian Research Library in Ostrava"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.svkos.cz/en/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.svkos.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Moravskoslezsk\u00e1 v\u011bdeck\u00e1 knihovna v Ostrav\u011b"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Moravian-Silesian Research Library in Ostrava"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://edugate.itb.ie/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Curran"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dave.curran@itb.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dave"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "O'Brien"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Eamonn.OBrien@itb.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Eamonn"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://edugate.itb.ie/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2011-03-08T00:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://edugate.itb.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://edugate.itb.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://edugate.itb.ie/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "itb.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.itb.ie"
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/itb.png",
                    "height": "65",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "235"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Technology Blanchardstown"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.40572644015631,-6.378046274185181"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUWE0VPYPdB8l/5af8W6PkkZDYFm4wDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOZWR1Z2F0ZS5pdGIuaWUwHhcNMTEwNjAxMTQ1NjA1WhcN\nMzEwNjAxMTQ1NjA1WjAZMRcwFQYDVQQDEw5lZHVnYXRlLml0Yi5pZTCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJg3AH4MXYhZXU7pdFdV6lhsNB0/Qjqg\neYSiWfLoZydHcJXTJw7Tfk2/8iX/NkLiyX+zouYTuw99HJtb+oZ4WzW3vwD0pupy\neM4eteWkGycQBoW7aE+KAH8Qrsj3xiGSv0A6Yod6wHn7KyCAmxUb7wPOCf/yuj5z\nSvxZwdQWUXRqlirDhJgLsOSedru92hVRXbo8uMvnkdkWbwggBd5UMNGPZsPRBPKN\nP+nw5Ccvw2GWCZkpel4nqoIFu+8GbJVHYOrUliVLgNcv+lL22SlmI4ahqZDHTToC\nAzfRGuYUOtkpHlBp/H3ZQLEQ/61o5HWYB7RAtQNRCMU0u145/2uJ2TcCAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOZWR1Z2F0ZS5pdGIuaWWGJWh0dHBzOi8vZWR1Z2F0ZS5p\ndGIuaWUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFARmPTDY2ovy8VOaLRwUc5al\nPqZNMA0GCSqGSIb3DQEBBQUAA4IBAQAZIThM8v0IQ++IyxuLKCPziFcDdl3Cptbv\n0LHvMWnVhskz5hxqaFBIyCCXtBwsVOMMGX5gNWtUm+7l+toa3AWC6bvjzDTCU64Z\nLW30XFU05arBASH+s1VNeOVnKHunsK1PN6qDH1VrXKkREyfDNWhQDHm1TE8JlBxY\ngbKMqJzGMLYTLc7xwiEn2qRh4Yh9TaoYwBHlPVTKR0Zd+p4N1xh3Bu5hr/V3MeHD\n6H4JYebKv15gO1dpxnngMQsnFs9lUqkcoMvPsJXj81AAO2WQUK4RC8SH+CL+pzqZ\nhj8bmirIgUuG9EBuz/X57eigHOWaytDx61rjjuvtKOWT2LgfwXqY"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Technology Blanchardstown"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.itb.ie"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Technology Blanchardstown"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://oala-dev.leedsbeckett.ac.uk/oala",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ITServiceDesk@leedsbeckett.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Taylor"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:d.v.taylor@leedsbeckett.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://oala-dev.leedsbeckett.ac.uk/oala",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-08-17T09:27:56Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://oala-dev.leedsbeckett.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://oala-dev.leedsbeckett.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "leedsbeckett.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZDCCAkygAwIBAgIICY7brWx6wwgwDQYJKoZIhvcNAQEFBQAwSTEhMB8GA1UE\n\t\t\t\t\t\tCgwYTGVlZHMgQmVja2V0dCBVbml2ZXJzaXR5MSQwIgYDVQQDDBtvYWxhLWRldi5s\n\t\t\t\t\t\tZWVkc2JlY2tldHQuYWMudWswHhcNMTUwNzEzMTcwODU1WhcNMjUwNzEzMTcwODU1\n\t\t\t\t\t\tWjBJMSEwHwYDVQQKDBhMZWVkcyBCZWNrZXR0IFVuaXZlcnNpdHkxJDAiBgNVBAMM\n\t\t\t\t\t\tG29hbGEtZGV2LmxlZWRzYmVja2V0dC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQAD\n\t\t\t\t\t\tggEPADCCAQoCggEBAJRvAT4MDeSjDJcqXiiMM8xYND6dAESfmu8rl5Glf0sCpkbn\n\t\t\t\t\t\t9/cVtSlZBUj12rjSlz5MKjLVB9IlJVP6LDmXi+VhEYt6y5+cnSSPOGz8vcA+FKic\n\t\t\t\t\t\tqyIMCsOqsOps/s/XvUHvMhn1DRrP9ABzJ7FMh07WJZmeAzdWFjwPa9pStLL5c+Tj\n\t\t\t\t\t\tzX6MXtEb0CorkdO3AOfA7W/105xyNdjY1mpGVNYh8ghmUsUbknWv1IV5wvvm14OU\n\t\t\t\t\t\t0FHxVlTOm/Gn9NE9kyZJ/0llfUzjklDwcdbPF97RYQkIPPXAGtSoQG4NKHXdfXOq\n\t\t\t\t\t\tHdZkHrw8uXFAXCACxgm3ySahQaVxxEMumONUNd8CAwEAAaNQME4wHQYDVR0OBBYE\n\t\t\t\t\t\tFAPEW0ahiwDvlwZaB+PIrnPRtdxPMB8GA1UdIwQYMBaAFAPEW0ahiwDvlwZaB+PI\n\t\t\t\t\t\trnPRtdxPMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAHjbalsxsvOh\n\t\t\t\t\t\tl45Neg5IQrMmEZKkMYzCh7cMHVtQbMruF1KJQU70wB/aPh6qaGXdouvH4QqI4zAy\n\t\t\t\t\t\tbN68NsZUbBOv5W8j9rnQ8m6XvCAYBdeYFrASqiS2i378/g8RtCFAIwkgerDyl6SZ\n\t\t\t\t\t\tB7i1VPnDjQ77RigIZNsWgrYiT/nl7+v/67xLj6avdWuf9DadminHKxDsD1iwee3z\n\t\t\t\t\t\tR1ye3k2HIsyY7Hjdip04Lo7aMibXMu7z/1jR5MpFC8uMxd24uNa+lEZspTkuKMgY\n\t\t\t\t\t\t00OrkNXmwj/zp+J7ytw55N5v7ZImISb2jhaZ1r1iP7sH1dqcsjgWgVnajThtvRwN\n\t\t\t\t\t\t11uM54JtSeI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZDCCAkygAwIBAgIICY7brWx6wwgwDQYJKoZIhvcNAQEFBQAwSTEhMB8GA1UE\n\t\t\t\t\t\tCgwYTGVlZHMgQmVja2V0dCBVbml2ZXJzaXR5MSQwIgYDVQQDDBtvYWxhLWRldi5s\n\t\t\t\t\t\tZWVkc2JlY2tldHQuYWMudWswHhcNMTUwNzEzMTcwODU1WhcNMjUwNzEzMTcwODU1\n\t\t\t\t\t\tWjBJMSEwHwYDVQQKDBhMZWVkcyBCZWNrZXR0IFVuaXZlcnNpdHkxJDAiBgNVBAMM\n\t\t\t\t\t\tG29hbGEtZGV2LmxlZWRzYmVja2V0dC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQAD\n\t\t\t\t\t\tggEPADCCAQoCggEBAJRvAT4MDeSjDJcqXiiMM8xYND6dAESfmu8rl5Glf0sCpkbn\n\t\t\t\t\t\t9/cVtSlZBUj12rjSlz5MKjLVB9IlJVP6LDmXi+VhEYt6y5+cnSSPOGz8vcA+FKic\n\t\t\t\t\t\tqyIMCsOqsOps/s/XvUHvMhn1DRrP9ABzJ7FMh07WJZmeAzdWFjwPa9pStLL5c+Tj\n\t\t\t\t\t\tzX6MXtEb0CorkdO3AOfA7W/105xyNdjY1mpGVNYh8ghmUsUbknWv1IV5wvvm14OU\n\t\t\t\t\t\t0FHxVlTOm/Gn9NE9kyZJ/0llfUzjklDwcdbPF97RYQkIPPXAGtSoQG4NKHXdfXOq\n\t\t\t\t\t\tHdZkHrw8uXFAXCACxgm3ySahQaVxxEMumONUNd8CAwEAAaNQME4wHQYDVR0OBBYE\n\t\t\t\t\t\tFAPEW0ahiwDvlwZaB+PIrnPRtdxPMB8GA1UdIwQYMBaAFAPEW0ahiwDvlwZaB+PI\n\t\t\t\t\t\trnPRtdxPMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAHjbalsxsvOh\n\t\t\t\t\t\tl45Neg5IQrMmEZKkMYzCh7cMHVtQbMruF1KJQU70wB/aPh6qaGXdouvH4QqI4zAy\n\t\t\t\t\t\tbN68NsZUbBOv5W8j9rnQ8m6XvCAYBdeYFrASqiS2i378/g8RtCFAIwkgerDyl6SZ\n\t\t\t\t\t\tB7i1VPnDjQ77RigIZNsWgrYiT/nl7+v/67xLj6avdWuf9DadminHKxDsD1iwee3z\n\t\t\t\t\t\tR1ye3k2HIsyY7Hjdip04Lo7aMibXMu7z/1jR5MpFC8uMxd24uNa+lEZspTkuKMgY\n\t\t\t\t\t\t00OrkNXmwj/zp+J7ytw55N5v7ZImISb2jhaZ1r1iP7sH1dqcsjgWgVnajThtvRwN\n\t\t\t\t\t\t11uM54JtSeI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Leeds Beckett University (Development)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.leedsbeckett.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Leeds Beckett University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://rutcathens.rutc.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ball"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jane.ball@rutc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jane"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kayes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tom.kayes@rutc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tom"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://rutcathens.rutc.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://rutcathens.rutc.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://rutcathens.rutc.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rutc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDuzCCAqOgAwIBAgIJAN1WsDggoMVvMA0GCSqGSIb3DQEBBQUAMEcxJTAjBgNV\n\t\t\t\t\t\tBAoTHFJpY2htb25kIHVwb24gVGhhbWVzIENvbGxlZ2UxHjAcBgNVBAMTFXJ1dGNh\n\t\t\t\t\t\tdGhlbnMucnV0Yy5hYy51azAeFw0xMDExMTExMTM0MTZaFw0yMDExMDgxMTM0MTZa\n\t\t\t\t\t\tMEcxJTAjBgNVBAoTHFJpY2htb25kIHVwb24gVGhhbWVzIENvbGxlZ2UxHjAcBgNV\n\t\t\t\t\t\tBAMTFXJ1dGNhdGhlbnMucnV0Yy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALqStCmUSU8IaQxOwt2Ou+wphpG1cqQYzY/17w8G0ftlzo5+mSJf\n\t\t\t\t\t\tAoPIBYSKmqvJtAqPww4TSrePmQihLopDHHlj6FcFywWYMoGf0JDk/piGgNF/Clj6\n\t\t\t\t\t\tmSXdu/VSuanx2uq5V512W+5A9clJqmBPIAZiglMaHcxDgR5cG7K75it3iSAX81wA\n\t\t\t\t\t\tPX9+T0TbvLGvqVSeSqQ2UVy728uLF53I2eSYta24l99yrSnOziNVHCD6+b0l7t1K\n\t\t\t\t\t\tOKrkuOLLSfuwTzxLeMlq67VOgymL1FrNWvWaySrh1NWWKAdND11Vgk7z4+hFbbfL\n\t\t\t\t\t\tersUW6JBGJUGysvTIFlrpnp81ibXAO28mTUCAwEAAaOBqTCBpjAdBgNVHQ4EFgQU\n\t\t\t\t\t\tnUoRxGM/pC8cQmwmpxUhC8V8wikwdwYDVR0jBHAwboAUnUoRxGM/pC8cQmwmpxUh\n\t\t\t\t\t\tC8V8wimhS6RJMEcxJTAjBgNVBAoTHFJpY2htb25kIHVwb24gVGhhbWVzIENvbGxl\n\t\t\t\t\t\tZ2UxHjAcBgNVBAMTFXJ1dGNhdGhlbnMucnV0Yy5hYy51a4IJAN1WsDggoMVvMAwG\n\t\t\t\t\t\tA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAKwWAWDeDlDvy8ROsFlboPkl\n\t\t\t\t\t\tR0Kq4+4fYhf6/1ihswDC/81AsYtT+2+J7ddNt2mQ8ElBJIvPxFGo9nrfh0OAEQqE\n\t\t\t\t\t\t/SFzabz7Co6EZrTjaq6w0Ga4SLGllKtDtHV/OgvNhNk0HdkHP4EHueq4KJl+ZWoS\n\t\t\t\t\t\tk3F+XEpmVs7e8DSGPY2CQO1cKYqFZF/4mqs1dcmXWqK4FLU8xlR4urtwxPybYRd3\n\t\t\t\t\t\tkTNdyaLJMlqWpe/LumRJ323OxgwDDUxgadxQ99CpcsRN8fn3CyiW5vnf3jjMl91r\n\t\t\t\t\t\t/N50CdH4cNvfaDEqHTiucQkIxjF+VsVX3S3Q5xGnLOJex9/Li8kVqnR1hZOkxi0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDuzCCAqOgAwIBAgIJAN1WsDggoMVvMA0GCSqGSIb3DQEBBQUAMEcxJTAjBgNV\n\t\t\t\t\t\tBAoTHFJpY2htb25kIHVwb24gVGhhbWVzIENvbGxlZ2UxHjAcBgNVBAMTFXJ1dGNh\n\t\t\t\t\t\tdGhlbnMucnV0Yy5hYy51azAeFw0xMDExMTExMTM0MTZaFw0yMDExMDgxMTM0MTZa\n\t\t\t\t\t\tMEcxJTAjBgNVBAoTHFJpY2htb25kIHVwb24gVGhhbWVzIENvbGxlZ2UxHjAcBgNV\n\t\t\t\t\t\tBAMTFXJ1dGNhdGhlbnMucnV0Yy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALqStCmUSU8IaQxOwt2Ou+wphpG1cqQYzY/17w8G0ftlzo5+mSJf\n\t\t\t\t\t\tAoPIBYSKmqvJtAqPww4TSrePmQihLopDHHlj6FcFywWYMoGf0JDk/piGgNF/Clj6\n\t\t\t\t\t\tmSXdu/VSuanx2uq5V512W+5A9clJqmBPIAZiglMaHcxDgR5cG7K75it3iSAX81wA\n\t\t\t\t\t\tPX9+T0TbvLGvqVSeSqQ2UVy728uLF53I2eSYta24l99yrSnOziNVHCD6+b0l7t1K\n\t\t\t\t\t\tOKrkuOLLSfuwTzxLeMlq67VOgymL1FrNWvWaySrh1NWWKAdND11Vgk7z4+hFbbfL\n\t\t\t\t\t\tersUW6JBGJUGysvTIFlrpnp81ibXAO28mTUCAwEAAaOBqTCBpjAdBgNVHQ4EFgQU\n\t\t\t\t\t\tnUoRxGM/pC8cQmwmpxUhC8V8wikwdwYDVR0jBHAwboAUnUoRxGM/pC8cQmwmpxUh\n\t\t\t\t\t\tC8V8wimhS6RJMEcxJTAjBgNVBAoTHFJpY2htb25kIHVwb24gVGhhbWVzIENvbGxl\n\t\t\t\t\t\tZ2UxHjAcBgNVBAMTFXJ1dGNhdGhlbnMucnV0Yy5hYy51a4IJAN1WsDggoMVvMAwG\n\t\t\t\t\t\tA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAKwWAWDeDlDvy8ROsFlboPkl\n\t\t\t\t\t\tR0Kq4+4fYhf6/1ihswDC/81AsYtT+2+J7ddNt2mQ8ElBJIvPxFGo9nrfh0OAEQqE\n\t\t\t\t\t\t/SFzabz7Co6EZrTjaq6w0Ga4SLGllKtDtHV/OgvNhNk0HdkHP4EHueq4KJl+ZWoS\n\t\t\t\t\t\tk3F+XEpmVs7e8DSGPY2CQO1cKYqFZF/4mqs1dcmXWqK4FLU8xlR4urtwxPybYRd3\n\t\t\t\t\t\tkTNdyaLJMlqWpe/LumRJ323OxgwDDUxgadxQ99CpcsRN8fn3CyiW5vnf3jjMl91r\n\t\t\t\t\t\t/N50CdH4cNvfaDEqHTiucQkIxjF+VsVX3S3Q5xGnLOJex9/Li8kVqnR1hZOkxi0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Richmond upon Thames College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rutc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Richmond upon Thames College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://utwente.nl/",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://utwente.nl/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2014-09-09T08:40:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/771fcfef97ddd691af69d7a52b7d2457",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Universiteit Twente"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Universiteit Twente"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/utwente.png",
                    "height": "48",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universiteit Twente"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Twente"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universiteit Twente"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utwente.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universiteit Twente"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth3.liv.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pretlove"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:T.Pretlove@liverpool.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pretlove"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:T.Pretlove@liverpool.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth3.liv.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-05-14T11:14:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVANlUxUdyvt878JJZeQqXZAX2ZiW9MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCAxHjAcBgNVBAMTFXNoaWJib2xldGgzLmxpdi5hYy51azAeFw0xNDAzMjEx\n\t\t\t\t\t\tNjMxNDlaFw0zNDAzMjExNjMxNDlaMCAxHjAcBgNVBAMTFXNoaWJib2xldGgzLmxp\n\t\t\t\t\t\tdi5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKtlHz1hrD0F\n\t\t\t\t\t\tf0M6F1zN8ZBoY5qI2wYwfjcRuXVfZlSJVhODsOUWWxUnfdqV7KBA0HcgRCK008g2\n\t\t\t\t\t\th/sjZXH/VU8M0EHhaYHHkyQxSBwEjWhbVcOT9iI1TkZqHNqZtJQIw7rnybskkv/3\n\t\t\t\t\t\t6IiBtGZgkZL3CZjp0kkqsOh19k/cioEsNsd4cKUyvhVEUvqtO1VULemasTnkmUtk\n\t\t\t\t\t\txJegTZXyW2W6TYMlTxeTwJQWe97WNxpCvV/3ounzXnLTUG5Te4i2ptA67JItknmw\n\t\t\t\t\t\tkS1p/a6d9B63gvHch27jFzollXccq4Gb2VSNLq3B8eAo8+Hnny9vLYYlKH1H7H9q\n\t\t\t\t\t\tgAo8OSA2ZbUCAwEAAaNxMG8wTgYDVR0RBEcwRYIVc2hpYmJvbGV0aDMubGl2LmFj\n\t\t\t\t\t\tLnVrhixodHRwczovL3NoaWJib2xldGgzLmxpdi5hYy51ay9pZHAvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQU7Cmjd6WsvyQ90NQeufSKvO/8yVIwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAIhTLBoOX4fvW9dYMfvjD77y8lyo2UFdATt6G6KWlCosBDkOwDTGK4N5g7CU\n\t\t\t\t\t\t/AxoGWBYLtd+KHy5ii5oV781aMLPa3ClDs1UYE/NuwkylvoSO0+agpeH6oF7IJxH\n\t\t\t\t\t\tN7EsSimVuaLi/R2ghs0KLwv6JfFUkhO2G2S5VTS/FZn/B8NgmBo+fLuJ6DLCQwJJ\n\t\t\t\t\t\tvnqXf9DPozHSBUOQAEkZcjKRSl+QTO6SleKLg5ahHNC3kT+dzF2ACKJMC7f4WzAL\n\t\t\t\t\t\trA/YOcNxfwUB/eiEgmw9dDwpUvOuH+NDET/ASLH3mXUA1w7DkzzHTZkMn9k/Up6O\n\t\t\t\t\t\tSX7ypoc/4IGOgkCbLMA/5Z8ZidI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "liv.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib3-test.liv.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib3-test.liv.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib3-test.liv.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib3-test.liv.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib3-test.liv.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib3-test.liv.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib3-test.liv.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib3-test.liv.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib3-test.liv.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib3-test.liv.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib3-test.liv.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "liv.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVANlUxUdyvt878JJZeQqXZAX2ZiW9MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCAxHjAcBgNVBAMTFXNoaWJib2xldGgzLmxpdi5hYy51azAeFw0xNDAzMjEx\n\t\t\t\t\t\tNjMxNDlaFw0zNDAzMjExNjMxNDlaMCAxHjAcBgNVBAMTFXNoaWJib2xldGgzLmxp\n\t\t\t\t\t\tdi5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKtlHz1hrD0F\n\t\t\t\t\t\tf0M6F1zN8ZBoY5qI2wYwfjcRuXVfZlSJVhODsOUWWxUnfdqV7KBA0HcgRCK008g2\n\t\t\t\t\t\th/sjZXH/VU8M0EHhaYHHkyQxSBwEjWhbVcOT9iI1TkZqHNqZtJQIw7rnybskkv/3\n\t\t\t\t\t\t6IiBtGZgkZL3CZjp0kkqsOh19k/cioEsNsd4cKUyvhVEUvqtO1VULemasTnkmUtk\n\t\t\t\t\t\txJegTZXyW2W6TYMlTxeTwJQWe97WNxpCvV/3ounzXnLTUG5Te4i2ptA67JItknmw\n\t\t\t\t\t\tkS1p/a6d9B63gvHch27jFzollXccq4Gb2VSNLq3B8eAo8+Hnny9vLYYlKH1H7H9q\n\t\t\t\t\t\tgAo8OSA2ZbUCAwEAAaNxMG8wTgYDVR0RBEcwRYIVc2hpYmJvbGV0aDMubGl2LmFj\n\t\t\t\t\t\tLnVrhixodHRwczovL3NoaWJib2xldGgzLmxpdi5hYy51ay9pZHAvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQU7Cmjd6WsvyQ90NQeufSKvO/8yVIwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAIhTLBoOX4fvW9dYMfvjD77y8lyo2UFdATt6G6KWlCosBDkOwDTGK4N5g7CU\n\t\t\t\t\t\t/AxoGWBYLtd+KHy5ii5oV781aMLPa3ClDs1UYE/NuwkylvoSO0+agpeH6oF7IJxH\n\t\t\t\t\t\tN7EsSimVuaLi/R2ghs0KLwv6JfFUkhO2G2S5VTS/FZn/B8NgmBo+fLuJ6DLCQwJJ\n\t\t\t\t\t\tvnqXf9DPozHSBUOQAEkZcjKRSl+QTO6SleKLg5ahHNC3kT+dzF2ACKJMC7f4WzAL\n\t\t\t\t\t\trA/YOcNxfwUB/eiEgmw9dDwpUvOuH+NDET/ASLH3mXUA1w7DkzzHTZkMn9k/Up6O\n\t\t\t\t\t\tSX7ypoc/4IGOgkCbLMA/5Z8ZidI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Liverpool - Test"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.liv.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Liverpool"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.sussex.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lewney"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:d.m.lewney@sussex.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dave"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lewney"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:d.m.lewney@sussex.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dave"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.sussex.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAL/cBrEESZ0ZPT7d+5iLH4sqVPESMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBsxGTAXBgNVBAMTEGlkcC5zdXNzZXguYWMudWswHhcNMTMwODAxMTQ0NzE2\n\t\t\t\t\t\tWhcNMzMwODAxMTQ0NzE2WjAbMRkwFwYDVQQDExBpZHAuc3Vzc2V4LmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAofHugvoV3CedXGuTc3l8gbwJ\n\t\t\t\t\t\tMU0hCP2TetJq7VXqKOXfedqQ5wDagYUvHhi+PqzakJhVridhguoywOiQQHSuGRhc\n\t\t\t\t\t\t4YhYo0kZe6w9PU4NGJztKwIoc90pMGfP9F0MlnyFL4UFEtdMVKhMWl0uPJJec3EH\n\t\t\t\t\t\tMnzTAeakGSENoVAasX3m+vaDoldAeIy7agcQ38K/MaVAskiF4QzP2k+uVFfjC91w\n\t\t\t\t\t\trVKDi6xyDGbFiBkgIlkpXhnjkoIyWSdaKKxAR+3V39pMFkrhznptHBk+Nm6lc5Rs\n\t\t\t\t\t\tIsQFxeoWp8YpFDWjatkTJAid6GCVxIMn7iA04fe7WNknFERgTcVe76mFa5895QID\n\t\t\t\t\t\tAQABo2MwYTBABgNVHREEOTA3ghBpZHAuc3Vzc2V4LmFjLnVrhiNodHRwczovL2lk\n\t\t\t\t\t\tcC5zdXNzZXguYWMudWsvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUW2CGoKuq5ytmpRKk\n\t\t\t\t\t\tvK0UKWA0PZIwDQYJKoZIhvcNAQEFBQADggEBABYQwDDUPodVsJLXP1+4RYXzcALB\n\t\t\t\t\t\tGD+URWmXudUbkmvVyPBFlG61W7aritNYPswnsMkeTsWGceygRZDduiDhImMk3psM\n\t\t\t\t\t\ttfjPPZsCNYNPj+E5kXrxj5S4y0wBPCUA5li9avuUwyiv7Cj41x0R/MBsTOzZymM1\n\t\t\t\t\t\tWAdfk2BWiiO76mGt0T5JtkEvyMR2oOguM3rHyQvSprZwixI5iC51Jgz8hi9/g6uB\n\t\t\t\t\t\thXl7a/FvOINuTcakieicxaKoY8SLwlPSohC5MY7JrRYuoGc72ROnYh41NN7DKmcl\n\t\t\t\t\t\t9i3j/XWPg4DPCgnybKfTsjUDXFGJsKprFqXkTm2t9sAytMmdCHUYvCGzbMk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sussex.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sussex.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sussex.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.sussex.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sussex.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.sussex.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sussex.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sussex.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sussex.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Sussex"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.sussex.ac.uk/includes/images/external/logo.jpg",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "147"
                  },
                  {
                    "text": "https://www.sussex.ac.uk/includes/images/external/favicon.gif",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Sussex"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sussex.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAL/cBrEESZ0ZPT7d+5iLH4sqVPESMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBsxGTAXBgNVBAMTEGlkcC5zdXNzZXguYWMudWswHhcNMTMwODAxMTQ0NzE2\n\t\t\t\t\t\tWhcNMzMwODAxMTQ0NzE2WjAbMRkwFwYDVQQDExBpZHAuc3Vzc2V4LmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAofHugvoV3CedXGuTc3l8gbwJ\n\t\t\t\t\t\tMU0hCP2TetJq7VXqKOXfedqQ5wDagYUvHhi+PqzakJhVridhguoywOiQQHSuGRhc\n\t\t\t\t\t\t4YhYo0kZe6w9PU4NGJztKwIoc90pMGfP9F0MlnyFL4UFEtdMVKhMWl0uPJJec3EH\n\t\t\t\t\t\tMnzTAeakGSENoVAasX3m+vaDoldAeIy7agcQ38K/MaVAskiF4QzP2k+uVFfjC91w\n\t\t\t\t\t\trVKDi6xyDGbFiBkgIlkpXhnjkoIyWSdaKKxAR+3V39pMFkrhznptHBk+Nm6lc5Rs\n\t\t\t\t\t\tIsQFxeoWp8YpFDWjatkTJAid6GCVxIMn7iA04fe7WNknFERgTcVe76mFa5895QID\n\t\t\t\t\t\tAQABo2MwYTBABgNVHREEOTA3ghBpZHAuc3Vzc2V4LmFjLnVrhiNodHRwczovL2lk\n\t\t\t\t\t\tcC5zdXNzZXguYWMudWsvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUW2CGoKuq5ytmpRKk\n\t\t\t\t\t\tvK0UKWA0PZIwDQYJKoZIhvcNAQEFBQADggEBABYQwDDUPodVsJLXP1+4RYXzcALB\n\t\t\t\t\t\tGD+URWmXudUbkmvVyPBFlG61W7aritNYPswnsMkeTsWGceygRZDduiDhImMk3psM\n\t\t\t\t\t\ttfjPPZsCNYNPj+E5kXrxj5S4y0wBPCUA5li9avuUwyiv7Cj41x0R/MBsTOzZymM1\n\t\t\t\t\t\tWAdfk2BWiiO76mGt0T5JtkEvyMR2oOguM3rHyQvSprZwixI5iC51Jgz8hi9/g6uB\n\t\t\t\t\t\thXl7a/FvOINuTcakieicxaKoY8SLwlPSohC5MY7JrRYuoGc72ROnYh41NN7DKmcl\n\t\t\t\t\t\t9i3j/XWPg4DPCgnybKfTsjUDXFGJsKprFqXkTm2t9sAytMmdCHUYvCGzbMk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Sussex"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sussex.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Sussex"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://vfuportalportfolio-test.su.se/Shibboleth.sso",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://vfuportalportfolio-test.su.se/Shibboleth.sso",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/WAYF/wavelan",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/WAYF/wavelan",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/WAYF/idp.it.su.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/WAYF/idp-test.it.su.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/SWAMID",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/SWAMID",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SP \u00e4r f\u00f6r ny vfuportalportfolio milj\u00f6 (som ska speglas vfu-test.su.se)."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SP is for new vfuportalportfolio environment (Mirror environment for vfu-test.su.se )"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Test Verksamhetsf\u00f6rlagd utbildning Stockholms universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Test Workplace Situated Education at Stockholm University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "vfuportalportfolio-test-app01"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHjCCAgagAwIBAgIJAIx7KH7z5CJWMA0GCSqGSIb3DQEBBQUAMCgxJjAkBgNV\nBAMTHXZmdXBvcnRhbHBvcnRmb2xpby10ZXN0LWFwcDAxMB4XDTE2MDQxODA5MzA1\nOFoXDTI2MDQxNjA5MzA1OFowKDEmMCQGA1UEAxMddmZ1cG9ydGFscG9ydGZvbGlv\nLXRlc3QtYXBwMDEwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQClgyOH\n4iU73ym+JGI9Gdra3uunqlmvIFVe9SvA7bXaV6g0Ew1vLO8kId+zpxf26PZSPnbV\nXspO03vp8yLa7Xuxb50CtvBCWYyo1d56G/hNl7Eky6VOyGPhYS8iYdZneoLf7hs7\nXxpsR2ML6FrRT1at+kPa/sDA8yOXbuXsbbASOFxtQP1RRFPVoAcC+qWx73WeLrnL\nYr+70Dmme6kvXPKZT9yg/s/IkhOb4frY8Gzv1apnEyxRVSAwf4N9QE07KEZP5QiB\nBYgIAOK1hQl/bggcpJoQgNDAxKd6+Ko+1ZQMKSdrZ7qmpEj+GZqFME2mgjZzASZJ\nWaDcYzc8tr+hzuJdAgMBAAGjSzBJMCgGA1UdEQQhMB+CHXZmdXBvcnRhbHBvcnRm\nb2xpby10ZXN0LWFwcDAxMB0GA1UdDgQWBBSG1ecYic2UxOhGiceG2PEOJkAalDAN\nBgkqhkiG9w0BAQUFAAOCAQEAnDXs8Q5+FeixXwuKhBSqE83s1FUPcobGkDRrtkcA\nKTIRWRtB/G7A7hNL6rrfripKddoKgxqEEz89xfR9LS0jt/RIaC6ansmFplBeBMnD\nHfnEL7a3tPUeMcZTYn+HYcFgDC7tSNfP/awmeuErweVCDSdrnidHYJE8LP0Ai5ZC\nk215wjr2WUf/IV03yroF2sykwMWLiAdpW+WccO/rBuTZsvq4+qugiE07DM8d2jv+\nwPTYRmTfKywcuDCB2/hUqex1uft/RNfE7JwgS1UblSJLxyrdF12RRzxbnCHoel/x\njuv3gekXlDpGuCilsBc8x619HHAJMerrhiJBiVwRhGTxnQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=vfuportalportfolio-test-app01"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vfuportalportfolio-test.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://wiki2.redclara.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "seg@redclara.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Authentication Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "seg@redclara.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Urban"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mark.urban@redclara.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://wiki2.redclara.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "es",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://cofre.reuna.cl/index.php/es/reglas-federacion"
              }
            ],
            "registration_instant": "2014-02-21T00:00:00Z",
            "registration_authority": "http://cofre.reuna.cl",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RedCLARA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.redclara.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RedCLARA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wiki2.redclara.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wiki2.redclara.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://wiki2.redclara.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://wiki2.redclara.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Wiki - RedCLARA"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Wiki - RedCLARA"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://wiki2.redclara.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://wiki2.redclara.net/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://wiki2.redclara.net/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.redclara.net/index.php?lang=en"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.redclara.net/index.php?lang=es"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "RedCLARA's Wiki Service"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Servicio de Wiki de RedCLARA"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Wiki - RedCLARA"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Wiki - RedCLARA"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "*.redclara.net"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "redclara.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFJzCCBA+gAwIBAgIQAycc1VlqLQ1YMhUWYD69ajANBgkqhkiG9w0BAQsFADBN\nMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMRGlnaUNlcnQgSW5jMScwJQYDVQQDEx5E\naWdpQ2VydCBTSEEyIFNlY3VyZSBTZXJ2ZXIgQ0EwHhcNMTQxMTI4MDAwMDAwWhcN\nMTcxMjA2MTIwMDAwWjB1MQswCQYDVQQGEwJVWTETMBEGA1UEBxMKTW9udGV2aWRl\nbzE4MDYGA1UECgwvQ29vcGVyYWNpw7NuIExhdGlub2FtZXJpY2FuYSBkZSBSZWRl\ncyBBdmFuemFkYXMxFzAVBgNVBAMMDioucmVkY2xhcmEubmV0MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEA4ciHwzKgzkUxp9PSRy9gV4WfIAmIjugbR8f9\nRJD9GwoMPTA173v4Rzjbnl8h/3e+iDfdzetHRM+gkOXwPCaGFpBQa2EPnxtFaaH6\nl8xtfHlsl8D2lqRkOE2OjvP8GzgpT3ikMBXoNr4TL7RQqzinwYCCJzLMSflwNbtk\n/a04k3l9FyxJ4mqEFP6aUsPJA0YRLVrYOIyppRzcHbRng/pNPE0R+JhNC3Kx2SbJ\nUvKtjQfvMJCn2T2dn5hg5mFnyMl78pgmRjppgxWEWkti+4eZoLg0OwVEFyGEgmEU\namd6JmRZTDs04BtstymJNXdkTsCP7yk92lpAc9C3NZ3FvrR0eQIDAQABo4IB2TCC\nAdUwHwYDVR0jBBgwFoAUD4BhHIIxYdUvKOeNRji0LOHG2eIwHQYDVR0OBBYEFBFj\nG3+tyY7afXZLfXNuYoGnE0nEMCcGA1UdEQQgMB6CDioucmVkY2xhcmEubmV0ggxy\nZWRjbGFyYS5uZXQwDgYDVR0PAQH/BAQDAgWgMB0GA1UdJQQWMBQGCCsGAQUFBwMB\nBggrBgEFBQcDAjBrBgNVHR8EZDBiMC+gLaArhilodHRwOi8vY3JsMy5kaWdpY2Vy\ndC5jb20vc3NjYS1zaGEyLWczLmNybDAvoC2gK4YpaHR0cDovL2NybDQuZGlnaWNl\ncnQuY29tL3NzY2Etc2hhMi1nMy5jcmwwQgYDVR0gBDswOTA3BglghkgBhv1sAQEw\nKjAoBggrBgEFBQcCARYcaHR0cHM6Ly93d3cuZGlnaWNlcnQuY29tL0NQUzB8Bggr\nBgEFBQcBAQRwMG4wJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmRpZ2ljZXJ0LmNv\nbTBGBggrBgEFBQcwAoY6aHR0cDovL2NhY2VydHMuZGlnaWNlcnQuY29tL0RpZ2lD\nZXJ0U0hBMlNlY3VyZVNlcnZlckNBLmNydDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3\nDQEBCwUAA4IBAQB3WePP9QxLi7OdtCbfR6kqIPDvfVX3aMvJ3/LQW9GhugwkV+ay\n8GyG17Dbm6Y2YSn1vl36lf/Nas4Lxf5jaVKXXoPUfANaDlJkK3E+cMsh1xrs8Uef\nMgiRll8Q28jA1RH+vmA+hzHOhuNqM8xHl2c/9Eq7FmFYoP4A1Lo/N9dEHHlHhSkG\nI6kBgBW/MAPvSLLPWr4v0u+/ynH9v+PEo60skvnrQPH0wFPoyJd/zxOMaomleJEv\nyL8CtS8Jo8/gqJ76zITM2JD1Cd+NBrPLk41I/hcfQ7Eewb/lkKe8/tpNm3e3bXJG\ns5W/0Lq2GRjQh9nrDfVs2IuE1c5zeqToyp98"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=*.redclara.net,O=Cooperaci\\C3\\B3n Latinoamericana de Redes Avanzadas,L=Montevideo,C=UY"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "*.redclara.net"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "redclara.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFJzCCBA+gAwIBAgIQAycc1VlqLQ1YMhUWYD69ajANBgkqhkiG9w0BAQsFADBN\nMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMRGlnaUNlcnQgSW5jMScwJQYDVQQDEx5E\naWdpQ2VydCBTSEEyIFNlY3VyZSBTZXJ2ZXIgQ0EwHhcNMTQxMTI4MDAwMDAwWhcN\nMTcxMjA2MTIwMDAwWjB1MQswCQYDVQQGEwJVWTETMBEGA1UEBxMKTW9udGV2aWRl\nbzE4MDYGA1UECgwvQ29vcGVyYWNpw7NuIExhdGlub2FtZXJpY2FuYSBkZSBSZWRl\ncyBBdmFuemFkYXMxFzAVBgNVBAMMDioucmVkY2xhcmEubmV0MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEA4ciHwzKgzkUxp9PSRy9gV4WfIAmIjugbR8f9\nRJD9GwoMPTA173v4Rzjbnl8h/3e+iDfdzetHRM+gkOXwPCaGFpBQa2EPnxtFaaH6\nl8xtfHlsl8D2lqRkOE2OjvP8GzgpT3ikMBXoNr4TL7RQqzinwYCCJzLMSflwNbtk\n/a04k3l9FyxJ4mqEFP6aUsPJA0YRLVrYOIyppRzcHbRng/pNPE0R+JhNC3Kx2SbJ\nUvKtjQfvMJCn2T2dn5hg5mFnyMl78pgmRjppgxWEWkti+4eZoLg0OwVEFyGEgmEU\namd6JmRZTDs04BtstymJNXdkTsCP7yk92lpAc9C3NZ3FvrR0eQIDAQABo4IB2TCC\nAdUwHwYDVR0jBBgwFoAUD4BhHIIxYdUvKOeNRji0LOHG2eIwHQYDVR0OBBYEFBFj\nG3+tyY7afXZLfXNuYoGnE0nEMCcGA1UdEQQgMB6CDioucmVkY2xhcmEubmV0ggxy\nZWRjbGFyYS5uZXQwDgYDVR0PAQH/BAQDAgWgMB0GA1UdJQQWMBQGCCsGAQUFBwMB\nBggrBgEFBQcDAjBrBgNVHR8EZDBiMC+gLaArhilodHRwOi8vY3JsMy5kaWdpY2Vy\ndC5jb20vc3NjYS1zaGEyLWczLmNybDAvoC2gK4YpaHR0cDovL2NybDQuZGlnaWNl\ncnQuY29tL3NzY2Etc2hhMi1nMy5jcmwwQgYDVR0gBDswOTA3BglghkgBhv1sAQEw\nKjAoBggrBgEFBQcCARYcaHR0cHM6Ly93d3cuZGlnaWNlcnQuY29tL0NQUzB8Bggr\nBgEFBQcBAQRwMG4wJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmRpZ2ljZXJ0LmNv\nbTBGBggrBgEFBQcwAoY6aHR0cDovL2NhY2VydHMuZGlnaWNlcnQuY29tL0RpZ2lD\nZXJ0U0hBMlNlY3VyZVNlcnZlckNBLmNydDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3\nDQEBCwUAA4IBAQB3WePP9QxLi7OdtCbfR6kqIPDvfVX3aMvJ3/LQW9GhugwkV+ay\n8GyG17Dbm6Y2YSn1vl36lf/Nas4Lxf5jaVKXXoPUfANaDlJkK3E+cMsh1xrs8Uef\nMgiRll8Q28jA1RH+vmA+hzHOhuNqM8xHl2c/9Eq7FmFYoP4A1Lo/N9dEHHlHhSkG\nI6kBgBW/MAPvSLLPWr4v0u+/ynH9v+PEo60skvnrQPH0wFPoyJd/zxOMaomleJEv\nyL8CtS8Jo8/gqJ76zITM2JD1Cd+NBrPLk41I/hcfQ7Eewb/lkKe8/tpNm3e3bXJG\ns5W/0Lq2GRjQh9nrDfVs2IuE1c5zeqToyp98"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=*.redclara.net,O=Cooperaci\\C3\\B3n Latinoamericana de Redes Avanzadas,L=Montevideo,C=UY"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wiki2.redclara.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wiki2.redclara.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://wiki2.redclara.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://wiki2.redclara.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://wiki2.redclara.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://wiki2.redclara.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wiki2.redclara.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://wiki2.redclara.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wiki2.redclara.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://wiki2.redclara.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.bridgemaneducation.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chambers"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sean.chambers@bridgemanimages.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sean"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chambers"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sean.chambers@bridgemanimages.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sean"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.bridgemaneducation.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-09-03T16:48:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Bridgeman Art Library Limited: Bridgeman Education"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bridgemaneducation.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Bridgeman Art Library Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.bridgemaneducation.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.bridgemaneducation.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.bridgemaneducation.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.bridgemaneducation.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.bridgemaneducation.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZDCCAkwCCQDwazyRKFeJxDANBgkqhkiG9w0BAQUFADB0MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEPMA0GA1UECBMGTG9uZG9uMQ8wDQYDVQQHEwZMb25kb24xHjAcBgNVBAoTFUJy\n\t\t\t\t\t\taWRnZW1hbiBBcnQgTGlicmFyeTEjMCEGA1UEAxMad3d3LmJyaWRnZW1hbmVkdWNh\n\t\t\t\t\t\tdGlvbi5jb20wHhcNMTAwODIwMTA0NjUyWhcNMzAwNTA3MTA0NjUyWjB0MQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEPMA0GA1UECBMGTG9uZG9uMQ8wDQYDVQQHEwZMb25kb24xHjAcBgNV\n\t\t\t\t\t\tBAoTFUJyaWRnZW1hbiBBcnQgTGlicmFyeTEjMCEGA1UEAxMad3d3LmJyaWRnZW1h\n\t\t\t\t\t\tbmVkdWNhdGlvbi5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDc\n\t\t\t\t\t\tr1Z/EjsTgw8PlvVdpS1KV66O5QA5Kl8XR+wM+VUz1sRm6WaN8bGv96XJkw/1K96g\n\t\t\t\t\t\t+6SssA6bNuqxJ5vRLyDGNFCwfrqh+Peqd2EPAqmkkjZ1wHaYkHHQlt9SO6Yzr8t6\n\t\t\t\t\t\t//l4mHVG3hf+NRW6ULCR8OXDOvvLXiVHEWUhU9R0ihE9gvbyOAsIMOJ3FQW663gv\n\t\t\t\t\t\t8kP7dxLAiK5MZ+M8jVWsQ/4qV1TuEipF7QySz7KJCfYf15b/cjirm/Rq/TPD1v5i\n\t\t\t\t\t\tv6XUqd01TpEZ20UCirqy5j0DUkdB77M9qlJPVon8MPNtUZJAwpUKtMgUscD6N1FB\n\t\t\t\t\t\tDoRT2qLbSTgDNCcYcn69AgMBAAEwDQYJKoZIhvcNAQEFBQADggEBACEJlFGX1o/F\n\t\t\t\t\t\t5G1kKFT+LgX/KuPVI7qBkb5NVzMGvLaQ2Ntz7wTWL6X0w/z9hHGEnXpr0Zc8HNNT\n\t\t\t\t\t\tcOs5pqDaMRLREMuwaQ+H53zgVgoVvgxdfywzZOFpLghvDOlbDqhdQ/4U4DfvaiPD\n\t\t\t\t\t\tOVsrpdM9zbOHZmbvdarfgC181gnT1Adu6xpJcHRXlLpJk10IYGfQfSvJl3AEYCkg\n\t\t\t\t\t\tHiBaJEKUJYBBvjAyPFaMt6jaV3YDgYs1quUwx1a0lAg8DZMXoaKJpJavwhwCpUvC\n\t\t\t\t\t\t7hKuJsm4gzUh4ULwmXRX4dO9qQedCXa3Gcazu8RU+rGVpJmSQcRXph7zzN+OIPM9\n\t\t\t\t\t\tG4rHrVYGfPY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZDCCAkwCCQDwazyRKFeJxDANBgkqhkiG9w0BAQUFADB0MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEPMA0GA1UECBMGTG9uZG9uMQ8wDQYDVQQHEwZMb25kb24xHjAcBgNVBAoTFUJy\n\t\t\t\t\t\taWRnZW1hbiBBcnQgTGlicmFyeTEjMCEGA1UEAxMad3d3LmJyaWRnZW1hbmVkdWNh\n\t\t\t\t\t\tdGlvbi5jb20wHhcNMTAwODIwMTA0NjUyWhcNMzAwNTA3MTA0NjUyWjB0MQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEPMA0GA1UECBMGTG9uZG9uMQ8wDQYDVQQHEwZMb25kb24xHjAcBgNV\n\t\t\t\t\t\tBAoTFUJyaWRnZW1hbiBBcnQgTGlicmFyeTEjMCEGA1UEAxMad3d3LmJyaWRnZW1h\n\t\t\t\t\t\tbmVkdWNhdGlvbi5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDc\n\t\t\t\t\t\tr1Z/EjsTgw8PlvVdpS1KV66O5QA5Kl8XR+wM+VUz1sRm6WaN8bGv96XJkw/1K96g\n\t\t\t\t\t\t+6SssA6bNuqxJ5vRLyDGNFCwfrqh+Peqd2EPAqmkkjZ1wHaYkHHQlt9SO6Yzr8t6\n\t\t\t\t\t\t//l4mHVG3hf+NRW6ULCR8OXDOvvLXiVHEWUhU9R0ihE9gvbyOAsIMOJ3FQW663gv\n\t\t\t\t\t\t8kP7dxLAiK5MZ+M8jVWsQ/4qV1TuEipF7QySz7KJCfYf15b/cjirm/Rq/TPD1v5i\n\t\t\t\t\t\tv6XUqd01TpEZ20UCirqy5j0DUkdB77M9qlJPVon8MPNtUZJAwpUKtMgUscD6N1FB\n\t\t\t\t\t\tDoRT2qLbSTgDNCcYcn69AgMBAAEwDQYJKoZIhvcNAQEFBQADggEBACEJlFGX1o/F\n\t\t\t\t\t\t5G1kKFT+LgX/KuPVI7qBkb5NVzMGvLaQ2Ntz7wTWL6X0w/z9hHGEnXpr0Zc8HNNT\n\t\t\t\t\t\tcOs5pqDaMRLREMuwaQ+H53zgVgoVvgxdfywzZOFpLghvDOlbDqhdQ/4U4DfvaiPD\n\t\t\t\t\t\tOVsrpdM9zbOHZmbvdarfgC181gnT1Adu6xpJcHRXlLpJk10IYGfQfSvJl3AEYCkg\n\t\t\t\t\t\tHiBaJEKUJYBBvjAyPFaMt6jaV3YDgYs1quUwx1a0lAg8DZMXoaKJpJavwhwCpUvC\n\t\t\t\t\t\t7hKuJsm4gzUh4ULwmXRX4dO9qQedCXa3Gcazu8RU+rGVpJmSQcRXph7zzN+OIPM9\n\t\t\t\t\t\tG4rHrVYGfPY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.bridgemaneducation.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.bridgemaneducation.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.bridgemaneducation.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.bridgemaneducation.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.bridgemaneducation.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.bridgemaneducation.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.bridgemaneducation.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.bridgemaneducation.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.bridgemaneducation.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.bridgemaneducation.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://kurser3.math.su.se/shibboleth",
    {
      "entity_id": "https://kurser3.math.su.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://kurser3.math.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://kurser3.math.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://kurser3.math.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://kurser3.math.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "kurser3.math.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEczCCA1ugAwIBAgIRAJmPvLO1zhBHiC8cv0Ac0q8wDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xMDAxMTkwMDAwMDBaFw0xMzAxMTgyMzU5NTlaMEsxCzAJBgNV\nBAYTAlNFMR8wHQYDVQQKExZTdG9ja2hvbG1zIHVuaXZlcnNpdGV0MRswGQYDVQQD\nExJrdXJzZXIzLm1hdGguc3Uuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQDE0IybA6C3iZ+bkaClj4VPM+9ujYTq5UmpcUPr7ZovIHSrch5rRGSPuw3k\nMQ3dZz+1nBVCdtnbud4JwgJf+oKoHyixu5UAy4PosinJlVV+TeYHhDMB3J+O6O/7\nMVWCD7NUxgOXhwEIu1Ln9fbB2fyoH9czTgYUlz8IyBE1c5kbkU6dJ/v+TYFfYC6f\nQNTq/CKzuPPlG3I0b6fyMTF6+9BXnhGoqGzc4fbpDw466FLYbuBhwjYOGw4sHVOw\nNwZpeo1cSIZ+ynJCO4y3nLHx7Ln5yt48fkvDE8fhnDlP19hEKadctKYQzyt1X+WH\nuYPuy2bffW8LsGMNdz6zgV1yq29vAgMBAAGjggFlMIIBYTAfBgNVHSMEGDAWgBQM\nvZNoDPPeq6NJays3V0fqkOO57TAdBgNVHQ4EFgQU9/hl0fzcymppShwXt+2iss1P\nVA4wDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYB\nBQUHAwEGCCsGAQUFBwMCMBgGA1UdIAQRMA8wDQYLKwYBBAGyMQECAh0wOgYDVR0f\nBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xD\nQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRj\ncy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDov\nL29jc3AudGNzLnRlcmVuYS5vcmcwHQYDVR0RBBYwFIISa3Vyc2VyMy5tYXRoLnN1\nLnNlMA0GCSqGSIb3DQEBBQUAA4IBAQAtyWsUSktP5GxVj19xSNmFDyap7z0/igy4\nWCTNXDGmHPIOmZfaavo5UBtZwEUB1puU2ViognByPFW1dnZzNV+nIiCokKg9gEOG\n7gEOVIzGQZTGkX/EQYlyYkhXd+tQ2Mn7v60RxtHTpmLHutNZiuwXPV/T/pq+i6aT\nWkQUjdUtED1LYCNHIy/voAwYOa8zZ5tBq3kXRveZtY3LpdKRIz6aUkHqLKmHBLF4\nImN8nJk/9yn1zCQW8/1DzycFt9IHU/zeCG1Q41L0EU2ZAXWixc/0sVuVxn6LEcIH\ncltjAaJBgU+QoDEuKsQtzVwmR/JfWYaVaMDXCh+QwOgvP3MIq8pA"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=kurser3.math.su.se,O=Stockholms universitet,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "kurser3.math.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEczCCA1ugAwIBAgIRAJmPvLO1zhBHiC8cv0Ac0q8wDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xMDAxMTkwMDAwMDBaFw0xMzAxMTgyMzU5NTlaMEsxCzAJBgNV\nBAYTAlNFMR8wHQYDVQQKExZTdG9ja2hvbG1zIHVuaXZlcnNpdGV0MRswGQYDVQQD\nExJrdXJzZXIzLm1hdGguc3Uuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQDE0IybA6C3iZ+bkaClj4VPM+9ujYTq5UmpcUPr7ZovIHSrch5rRGSPuw3k\nMQ3dZz+1nBVCdtnbud4JwgJf+oKoHyixu5UAy4PosinJlVV+TeYHhDMB3J+O6O/7\nMVWCD7NUxgOXhwEIu1Ln9fbB2fyoH9czTgYUlz8IyBE1c5kbkU6dJ/v+TYFfYC6f\nQNTq/CKzuPPlG3I0b6fyMTF6+9BXnhGoqGzc4fbpDw466FLYbuBhwjYOGw4sHVOw\nNwZpeo1cSIZ+ynJCO4y3nLHx7Ln5yt48fkvDE8fhnDlP19hEKadctKYQzyt1X+WH\nuYPuy2bffW8LsGMNdz6zgV1yq29vAgMBAAGjggFlMIIBYTAfBgNVHSMEGDAWgBQM\nvZNoDPPeq6NJays3V0fqkOO57TAdBgNVHQ4EFgQU9/hl0fzcymppShwXt+2iss1P\nVA4wDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYB\nBQUHAwEGCCsGAQUFBwMCMBgGA1UdIAQRMA8wDQYLKwYBBAGyMQECAh0wOgYDVR0f\nBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xD\nQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRj\ncy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDov\nL29jc3AudGNzLnRlcmVuYS5vcmcwHQYDVR0RBBYwFIISa3Vyc2VyMy5tYXRoLnN1\nLnNlMA0GCSqGSIb3DQEBBQUAA4IBAQAtyWsUSktP5GxVj19xSNmFDyap7z0/igy4\nWCTNXDGmHPIOmZfaavo5UBtZwEUB1puU2ViognByPFW1dnZzNV+nIiCokKg9gEOG\n7gEOVIzGQZTGkX/EQYlyYkhXd+tQ2Mn7v60RxtHTpmLHutNZiuwXPV/T/pq+i6aT\nWkQUjdUtED1LYCNHIy/voAwYOa8zZ5tBq3kXRveZtY3LpdKRIz6aUkHqLKmHBLF4\nImN8nJk/9yn1zCQW8/1DzycFt9IHU/zeCG1Q41L0EU2ZAXWixc/0sVuVxn6LEcIH\ncltjAaJBgU+QoDEuKsQtzVwmR/JfWYaVaMDXCh+QwOgvP3MIq8pA"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=kurser3.math.su.se,O=Stockholms universitet,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://kurser3.math.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://kurser3.math.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://kurser3.math.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://kurser3.math.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://kurser3.math.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://kurser3.math.su.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://kurser3.math.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://kurser3.math.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://kurser3.math.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://kurser3.math.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idem.unina2.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "CSI"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:csi@unina2.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idem.unina2.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2011-06-07T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAMeHVbcMgkiyi7G8YIyVSk6/OsAEMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkZW0udW5pbmEyLml0MB4XDTEwMDkyNDEyNTcxNFoX\nDTMwMDkyNDEyNTcxNFowGTEXMBUGA1UEAxMOaWRlbS51bmluYTIuaXQwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDEJP3ZKXEqVvt+BU4r7yPQG3RNUCTx\nWQ+4k+nPi/UFRpRk5IHLpbO+/mqbkEJ8Z45eF+uSIsU37DGBmEkWB1ig6OrLqKdZ\nY7/9XAxM2bACl8uCQqDZSod8etUQU60bxlxvAhYips6zKV3d7GKcvLbg6DwYCjL9\nrEdiXlbf/XMkx8H0s5JT/WeJN1UZmlfBbwAMj3kXPrxzexGFMj+xg87C/WWA4wPL\nEjIRMRu4URhwqowcaYBXDN6/d7zXoLCC7VzJjV2mPNqJXJD6Cius5aqLcGImmJPF\nOwufXmPu+cpYc7h5NWd6KMjvUEQ3ucniAEucn8S78Iakd3Kcm3VLZX9/AgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkZW0udW5pbmEyLml0hiVodHRwczovL2lkZW0udW5p\nbmEyLml0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRh0OcndkGzMmnRUBpvGQ4s\nF9pzKzANBgkqhkiG9w0BAQUFAAOCAQEAJ7aS6KvM/hgIoSgK0iGogbCpxrLTVz/3\nMzsgbGBceGiv+zLe0kV8Qz4SIQYPg8Yi71vCel/Fn8UPCC9O9PzD/wwqmFxFnCtB\nkO/ERSlXHZ1X2JM/1mEfBQvyYONbf/8EaYQkuhu/niLB3arnftrOoWNFpGfVttgw\n9OCxJa+998vCAZF9Bj++lZ5LxBDMVbKhxj0XSZw+r8KTon6/X/xRmYpOLjqDiYUd\nkGo9S0UZfQNFVe9/H0TZ6CMUeSAFWsycyaAvApoOUbPD7qqTlfacQgB2MEhPSLq7\nQ1xivizsXOeSZk/Q9/DJDN5TzuB1vxSPpGwc5ghEtOnpUr+lMfdesw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unina2.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idem.unina2.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idem.unina2.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idem.unina2.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idem.unina2.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idem.unina2.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idem.unina2.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idem.unina2.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idem.unina2.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unina2.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://idem.unina2.it/info/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://idem.unina2.it/info_en/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Second University of Naples users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti della Seconda Universit\u00e0 degli Studi di Napoli"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://idem.unina2.it/info/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://idem.unina2.it/info_en/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Second University of Naples"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Seconda Universit\u00e0 degli Studi di Napoli"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAMeHVbcMgkiyi7G8YIyVSk6/OsAEMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkZW0udW5pbmEyLml0MB4XDTEwMDkyNDEyNTcxNFoX\nDTMwMDkyNDEyNTcxNFowGTEXMBUGA1UEAxMOaWRlbS51bmluYTIuaXQwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDEJP3ZKXEqVvt+BU4r7yPQG3RNUCTx\nWQ+4k+nPi/UFRpRk5IHLpbO+/mqbkEJ8Z45eF+uSIsU37DGBmEkWB1ig6OrLqKdZ\nY7/9XAxM2bACl8uCQqDZSod8etUQU60bxlxvAhYips6zKV3d7GKcvLbg6DwYCjL9\nrEdiXlbf/XMkx8H0s5JT/WeJN1UZmlfBbwAMj3kXPrxzexGFMj+xg87C/WWA4wPL\nEjIRMRu4URhwqowcaYBXDN6/d7zXoLCC7VzJjV2mPNqJXJD6Cius5aqLcGImmJPF\nOwufXmPu+cpYc7h5NWd6KMjvUEQ3ucniAEucn8S78Iakd3Kcm3VLZX9/AgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkZW0udW5pbmEyLml0hiVodHRwczovL2lkZW0udW5p\nbmEyLml0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRh0OcndkGzMmnRUBpvGQ4s\nF9pzKzANBgkqhkiG9w0BAQUFAAOCAQEAJ7aS6KvM/hgIoSgK0iGogbCpxrLTVz/3\nMzsgbGBceGiv+zLe0kV8Qz4SIQYPg8Yi71vCel/Fn8UPCC9O9PzD/wwqmFxFnCtB\nkO/ERSlXHZ1X2JM/1mEfBQvyYONbf/8EaYQkuhu/niLB3arnftrOoWNFpGfVttgw\n9OCxJa+998vCAZF9Bj++lZ5LxBDMVbKhxj0XSZw+r8KTon6/X/xRmYpOLjqDiYUd\nkGo9S0UZfQNFVe9/H0TZ6CMUeSAFWsycyaAvApoOUbPD7qqTlfacQgB2MEhPSLq7\nQ1xivizsXOeSZk/Q9/DJDN5TzuB1vxSPpGwc5ghEtOnpUr+lMfdesw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Seconda Universit\u00e0 di Napoli"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Second University of Naplesi"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://idem.unina2.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://idem.unina2.it/index.php/international"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Seconda Universit\u00e0 degli Studi di Napoli"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Second University of Naples"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.rguunion.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.rguunion.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-03-03T14:39:06Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Robert Gordon Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rguunion.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.rguunion.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.rguunion.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.rguunion.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.rguunion.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.rguunion.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.rguunion.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.rguunion.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.rguunion.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.rguunion.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.rguunion.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.rguunion.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.rguunion.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://aktivera.su.se/Shibboleth.sso",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://aktivera.su.se/Shibboleth.sso",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aktivera.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aktivera.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aktivera.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://aktivera.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aktivera.su.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://aktivera.su.se/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://aktivera.su.se/Shibboleth.sso/WAYF/wavelan",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "signuptool-prod-app1"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAN4wS9MFVZVYMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFHNpZ251cHRvb2wtcHJvZC1hcHAxMB4XDTExMDIyMjA5MTAzMVoXDTIxMDIx\nOTA5MTAzMVowHzEdMBsGA1UEAxMUc2lnbnVwdG9vbC1wcm9kLWFwcDEwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDsMwbsy/oF6Gt6pioQahFEJEYQb92t\nw7bWz3hgJO5uDM2gW/H2b69nQGjnKiixafh+ggrn8ckHCrFU2DmCK/qDsJ8ogKIY\n8S2pExyZxnIccKy/CIB2elYEW4h2Eg+JeRbWW//0DJyDAdeDOEMk7MNE+1qebj5V\nQKuoHnUmhMOy0vSYheIxsJ4gqQRZ09QI0YcWeVwSuQ/z8m3s5uOyyvmNLVmUT4bC\nflEJiUGtLa+ORmUeK1Vlk4nuJ/excQK6J6DFeyZDSkSBzizmmXIkRZQsFQGCOSBV\nRhauOY1h5Yrr7TMMmYz5WsSBUb7yI413A/QhsMH0G5JDlsBYjWM5JsypAgMBAAGj\nQjBAMB8GA1UdEQQYMBaCFHNpZ251cHRvb2wtcHJvZC1hcHAxMB0GA1UdDgQWBBQe\n1Qig5SZgrvaBOENdpaZQMbN1jDANBgkqhkiG9w0BAQUFAAOCAQEAnkeyJMh3FVYq\nc4yCDWdg60dv5+fXxvRBdfDS3Zaw6jfoWVRKDgPMfIxcMg7mm11cw8os2T+kqEOu\nyYLeriwG21WsXyihMydql7eRYxBLyVWwRQXQVNczMkCsZiE8kcC6i1t2FISxqLon\nuL4fct/0jh2G3zGO+11qOeJkjldKO/iJetq6sMArvNPILW1Qr4UwgjJ6IJsPdDSY\nIBK/w82B1jJWgKJQKyOYrdWxbb3gNAh7zsbHC5sjOMD+tMvjVDuyyoL8vM01yQQ2\nsksVCOjhrCaJpWxMWRyrMNUONHEZhJYI++lAGGQDraWowS+trAnniR+pnrqujoZm\nmqvHC5Aeiw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=signuptool-prod-app1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "signuptool-prod-app1"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAN4wS9MFVZVYMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFHNpZ251cHRvb2wtcHJvZC1hcHAxMB4XDTExMDIyMjA5MTAzMVoXDTIxMDIx\nOTA5MTAzMVowHzEdMBsGA1UEAxMUc2lnbnVwdG9vbC1wcm9kLWFwcDEwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDsMwbsy/oF6Gt6pioQahFEJEYQb92t\nw7bWz3hgJO5uDM2gW/H2b69nQGjnKiixafh+ggrn8ckHCrFU2DmCK/qDsJ8ogKIY\n8S2pExyZxnIccKy/CIB2elYEW4h2Eg+JeRbWW//0DJyDAdeDOEMk7MNE+1qebj5V\nQKuoHnUmhMOy0vSYheIxsJ4gqQRZ09QI0YcWeVwSuQ/z8m3s5uOyyvmNLVmUT4bC\nflEJiUGtLa+ORmUeK1Vlk4nuJ/excQK6J6DFeyZDSkSBzizmmXIkRZQsFQGCOSBV\nRhauOY1h5Yrr7TMMmYz5WsSBUb7yI413A/QhsMH0G5JDlsBYjWM5JsypAgMBAAGj\nQjBAMB8GA1UdEQQYMBaCFHNpZ251cHRvb2wtcHJvZC1hcHAxMB0GA1UdDgQWBBQe\n1Qig5SZgrvaBOENdpaZQMbN1jDANBgkqhkiG9w0BAQUFAAOCAQEAnkeyJMh3FVYq\nc4yCDWdg60dv5+fXxvRBdfDS3Zaw6jfoWVRKDgPMfIxcMg7mm11cw8os2T+kqEOu\nyYLeriwG21WsXyihMydql7eRYxBLyVWwRQXQVNczMkCsZiE8kcC6i1t2FISxqLon\nuL4fct/0jh2G3zGO+11qOeJkjldKO/iJetq6sMArvNPILW1Qr4UwgjJ6IJsPdDSY\nIBK/w82B1jJWgKJQKyOYrdWxbb3gNAh7zsbHC5sjOMD+tMvjVDuyyoL8vM01yQQ2\nsksVCOjhrCaJpWxMWRyrMNUONHEZhJYI++lAGGQDraWowS+trAnniR+pnrqujoZm\nmqvHC5Aeiw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=signuptool-prod-app1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aktivera.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aktivera.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aktivera.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://aktivera.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://aktivera.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://aktivera.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aktivera.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aktivera.su.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://aktivera.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://aktivera.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ugn.cas.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Van\u00ed\u010dek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vanicekp@utia.cas.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ugn.cas.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2016-01-18T11:28:01Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/avcr"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUanMT4HV96dPVlvHmmJ0S4CVXRlQwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOaWRwLnVnbi5jYXMuY3owHhcNMTYwMTEyMTI0ODQ1WhcN\nMzYwMTEyMTI0ODQ1WjAZMRcwFQYDVQQDEw5pZHAudWduLmNhcy5jejCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKXMLIFCj0bmP3exddG/Jqa7XXfrcog4\n0PeZIBoDSTU24SCnokHfe03eSNnTI7GU+ee42T3eGMJ4TAk8tmFSdiXt3zOZNbQf\nNYmBtBMKkgvNn40enM496MHZsx8Un8mtvgN1VLmSRZ73BKYWw1pHZuywlijLBaXY\nXkyn29L92UuYp46PZeg1Hn8yUIxQVIeiOUkApJbwoHEM6POgZVSs+3WndnApq63c\naIOCHKyQi24ThmlcAhH/4CRQzSG7Q6qG42ElyzZLXZo/efPPk6ro338RJptRnVMK\nio1ngQD2zYoD7EJu33urYhhm+b3VigQsmanAXJmvVIP+5Ie4XySxLY0CAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOaWRwLnVnbi5jYXMuY3qGJWh0dHBzOi8vaWRwLnVnbi5j\nYXMuY3ovaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFFkZTWC0aDTGy5oIATShyof5\nIXZDMA0GCSqGSIb3DQEBBQUAA4IBAQCZVotlNBDXcFPwny31mgxLlID8VcqBFyX8\nAP5CZpGLFVxSN8sPjEa4SA589rCM2Q2HHJP52X4o2KEFhO7xTFPteomul0GZUio9\nQjOjbzunCxLm8p0skzSRWN7C5dHPSwptjVF4DGW84WkSCsQel81xva+Ws/ewvNFO\ndqwJGlvrkLWYMKMBzPN+nocOwLOHbxpFLlM1nJo+TQVgvTDdgwvMwujQJQxLC90G\ne/VSttUAOrFWfuz3n6+oOm7dfjcSxQs1OkA74OpOBoYX77P886WQqsOknyd3mz9Q\nH+4Bj5MUAtb4u4czl/MB7Qe52hUlAke+T+5t70GDjSwLnh691Lcv"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ugn.cas.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ugn.cas.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ugn.cas.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ugn.cas.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ugn.cas.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ugn.cas.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ugn.cas.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ugn.cas.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ugn.cas.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ugn.cas.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ugn.cas.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ugn.cas.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ugn.cas.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ugn.cas.cz/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ugn.cas.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider IGN AV CR employees."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance \u00daGN AV \u010cR"
                  }
                ],
                "logo": [
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-ugn-44.png",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "74"
                  },
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-ugn-67.png",
                    "height": "67",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "113"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Geonics of the CAS"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u00dastav geoniky AV \u010cR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUanMT4HV96dPVlvHmmJ0S4CVXRlQwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOaWRwLnVnbi5jYXMuY3owHhcNMTYwMTEyMTI0ODQ1WhcN\nMzYwMTEyMTI0ODQ1WjAZMRcwFQYDVQQDEw5pZHAudWduLmNhcy5jejCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKXMLIFCj0bmP3exddG/Jqa7XXfrcog4\n0PeZIBoDSTU24SCnokHfe03eSNnTI7GU+ee42T3eGMJ4TAk8tmFSdiXt3zOZNbQf\nNYmBtBMKkgvNn40enM496MHZsx8Un8mtvgN1VLmSRZ73BKYWw1pHZuywlijLBaXY\nXkyn29L92UuYp46PZeg1Hn8yUIxQVIeiOUkApJbwoHEM6POgZVSs+3WndnApq63c\naIOCHKyQi24ThmlcAhH/4CRQzSG7Q6qG42ElyzZLXZo/efPPk6ro338RJptRnVMK\nio1ngQD2zYoD7EJu33urYhhm+b3VigQsmanAXJmvVIP+5Ie4XySxLY0CAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOaWRwLnVnbi5jYXMuY3qGJWh0dHBzOi8vaWRwLnVnbi5j\nYXMuY3ovaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFFkZTWC0aDTGy5oIATShyof5\nIXZDMA0GCSqGSIb3DQEBBQUAA4IBAQCZVotlNBDXcFPwny31mgxLlID8VcqBFyX8\nAP5CZpGLFVxSN8sPjEa4SA589rCM2Q2HHJP52X4o2KEFhO7xTFPteomul0GZUio9\nQjOjbzunCxLm8p0skzSRWN7C5dHPSwptjVF4DGW84WkSCsQel81xva+Ws/ewvNFO\ndqwJGlvrkLWYMKMBzPN+nocOwLOHbxpFLlM1nJo+TQVgvTDdgwvMwujQJQxLC90G\ne/VSttUAOrFWfuz3n6+oOm7dfjcSxQs1OkA74OpOBoYX77P886WQqsOknyd3mz9Q\nH+4Bj5MUAtb4u4czl/MB7Qe52hUlAke+T+5t70GDjSwLnh691Lcv"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Geonics of the CAS, v. v. i."
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u00dastav geoniky AV \u010cR, v. v. i."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ugn.cas.cz/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ugn.cas.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Geonics of the CAS"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u00dastav geoniky AV \u010cR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.uom.gr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tsakiridou"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "aspa@uom.gr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Aspa"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@noc.uom.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University of Macedonia NOC"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uom.gr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEYTCCA0mgAwIBAgIQC/tCFL3CTrbZoTlo1VwxfTANBgkqhkiG9w0BAQUFADA2\n                            MQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n                            U1NMIENBMB4XDTEzMDYyNTAwMDAwMFoXDTE2MDYyNDIzNTk1OVowODEhMB8GA1UE\n                            CxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRMwEQYDVQQDEwppZHAudW9tLmdy\n                            MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAyH5v2JCiY11y+JirdXYz\n                            dJZkF64CowAV/V4H/bOv8MMsUs+wMZ9pPyhkLy3N/ljwMKLnlv1LFRla7UiSD8ap\n                            5oho76dSb0lbF7vSbygHn+qu7VZ+jkdxJ7AuOROeV8rw1DF7HdR4DcRV3eTTSYh/\n                            U2hrfSONOFg8gGp4BzZABbNRuyURHga5nBzewcwysGHZ51/bkMhjpbELRNct0aOP\n                            uYDSRL/JBfVVdzy5+NvG2Kn0w+aNF0PPbEUfg0DST4penlBWjw1qovZkg3ngYCva\n                            /BnhFiuPat9OkztTwJuJobRs4tVFsIaFVUCGKR0bn6TGjQK7dHo4bkpPepj5DBK4\n                            HQIDAQABo4IBZzCCAWMwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH6pDjue0w\n                            HQYDVR0OBBYEFBjSV9NjXnP/58dSjdtwTtmSBMZoMA4GA1UdDwEB/wQEAwIFoDAM\n                            BgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNV\n                            HSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAxMC+gLaAr\n                            hilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNybDBtBggr\n                            BgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5v\n                            cmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8vb2NzcC50Y3Mu\n                            dGVyZW5hLm9yZzAVBgNVHREEDjAMggppZHAudW9tLmdyMA0GCSqGSIb3DQEBBQUA\n                            A4IBAQBOGyswia2sol7gb0lITR9Gzzl3xA7yO5cgDF8epjphTcrJnZeg1k9vINwQ\n                            m2DJTS8rOgINEz5T9NJt5v00HylSmgWV6MuGJ0INdPrzZi5tEfJx4d+UenXTmYey\n                            20ISTUUbW4DDswkWUrV1i7v7fNb2lmdMgXfmeqYdm66OqtmICF+an4gvSxyAxJm/\n                            eLBuMGQtAWZ9iFE/KgXrPuAjNqrF9rBoEEgF4nPiu+dyP3eA9NS54RqRBQsrKTBj\n                            +u6JbdZYW2zUWzUzRyyK1eCgXYNIswNFuTQ7ANWxIf/q8kk8SLv7Vdq/P1i+3PVk\n                            sEP9QjFH5i9IJ+q4yVNeiQgEPT2+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uom.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uom.gr:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uom.gr:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.uom.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uom.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.uom.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uom.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uom.gr:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uom.gr:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uom.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEYTCCA0mgAwIBAgIQC/tCFL3CTrbZoTlo1VwxfTANBgkqhkiG9w0BAQUFADA2\n                            MQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n                            U1NMIENBMB4XDTEzMDYyNTAwMDAwMFoXDTE2MDYyNDIzNTk1OVowODEhMB8GA1UE\n                            CxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRMwEQYDVQQDEwppZHAudW9tLmdy\n                            MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAyH5v2JCiY11y+JirdXYz\n                            dJZkF64CowAV/V4H/bOv8MMsUs+wMZ9pPyhkLy3N/ljwMKLnlv1LFRla7UiSD8ap\n                            5oho76dSb0lbF7vSbygHn+qu7VZ+jkdxJ7AuOROeV8rw1DF7HdR4DcRV3eTTSYh/\n                            U2hrfSONOFg8gGp4BzZABbNRuyURHga5nBzewcwysGHZ51/bkMhjpbELRNct0aOP\n                            uYDSRL/JBfVVdzy5+NvG2Kn0w+aNF0PPbEUfg0DST4penlBWjw1qovZkg3ngYCva\n                            /BnhFiuPat9OkztTwJuJobRs4tVFsIaFVUCGKR0bn6TGjQK7dHo4bkpPepj5DBK4\n                            HQIDAQABo4IBZzCCAWMwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH6pDjue0w\n                            HQYDVR0OBBYEFBjSV9NjXnP/58dSjdtwTtmSBMZoMA4GA1UdDwEB/wQEAwIFoDAM\n                            BgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNV\n                            HSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAxMC+gLaAr\n                            hilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNybDBtBggr\n                            BgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5v\n                            cmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8vb2NzcC50Y3Mu\n                            dGVyZW5hLm9yZzAVBgNVHREEDjAMggppZHAudW9tLmdyMA0GCSqGSIb3DQEBBQUA\n                            A4IBAQBOGyswia2sol7gb0lITR9Gzzl3xA7yO5cgDF8epjphTcrJnZeg1k9vINwQ\n                            m2DJTS8rOgINEz5T9NJt5v00HylSmgWV6MuGJ0INdPrzZi5tEfJx4d+UenXTmYey\n                            20ISTUUbW4DDswkWUrV1i7v7fNb2lmdMgXfmeqYdm66OqtmICF+an4gvSxyAxJm/\n                            eLBuMGQtAWZ9iFE/KgXrPuAjNqrF9rBoEEgF4nPiu+dyP3eA9NS54RqRBQsrKTBj\n                            +u6JbdZYW2zUWzUzRyyK1eCgXYNIswNFuTQ7ANWxIf/q8kk8SLv7Vdq/P1i+3PVk\n                            sEP9QjFH5i9IJ+q4yVNeiQgEPT2+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Macedonia"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u03a0\u03b1\u03bd\u03b5\u03c0\u03b9\u03c3\u03c4\u03ae\u03bc\u03b9\u03bf \u039c\u03b1\u03ba\u03b5\u03b4\u03bf\u03bd\u03af\u03b1\u03c2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uom.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uom.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Macedonia"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u03a0\u03b1\u03bd\u03b5\u03c0\u03b9\u03c3\u03c4\u03ae\u03bc\u03b9\u03bf \u039c\u03b1\u03ba\u03b5\u03b4\u03bf\u03bd\u03af\u03b1\u03c2"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.goldsmiths.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@gold.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Services Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Thompson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:g.thompson@gold.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "George"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.goldsmiths.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-07-21T11:02:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF/TCCBOWgAwIBAgIUMqPz7osmzn9Ev8smgoB4KL4/2zgwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwTTELMAkGA1UEBhMCQk0xGTAXBgNVBAoTEFF1b1ZhZGlzIExpbWl0ZWQxIzAh\n\t\t\t\t\t\tBgNVBAMTGlF1b1ZhZGlzIEdsb2JhbCBTU0wgSUNBIEcyMB4XDTE1MDYxODEwMTMy\n\t\t\t\t\t\tNVoXDTE4MDYxODEwMTMyM1owgYcxCzAJBgNVBAYTAkdCMQ8wDQYDVQQIEwZMb25k\n\t\t\t\t\t\tb24xETAPBgNVBAcTCE5FV0NST1NTMRwwGgYDVQQKExNHb2xkc21pdGhzJyBDb2xs\n\t\t\t\t\t\tZWdlMRcwFQYDVQQLEw5JbmZyYXN0cnVjdHVyZTEdMBsGA1UEAxMUaWRwLmdvbGRz\n\t\t\t\t\t\tbWl0aHMuYWMudWswggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCi3wFk\n\t\t\t\t\t\taznZ+SpYvrsnww1uupnCpggywmvM5SCyqMa1YjecRF+ehyhEpTM+lmpOBp5VunM0\n\t\t\t\t\t\t2dx7Hdt10I3C1gNZemlacaihn573tJUSq44K/hw7JPifTKDxxyF9bTh3LgyYIoQC\n\t\t\t\t\t\tJMlKreErgcs+AqJHAo3ta96MIP3bBzT6tYshIwtTdLwE0M6Y5gcrDyTtDws1jmKu\n\t\t\t\t\t\t9Kt5Ht0ZW5iDh+BkfRRvW3+FTwmooL24oJ8ZXBUmGmxOha4nMHUwDDOGR6bpLO7C\n\t\t\t\t\t\tQozFmTWln2kqhxkXcS212JIHEkqb6wa42+szlVfY4USwOuSJHFQgpbApjg5rrr1p\n\t\t\t\t\t\tFGTCcpbLMt+feQ77kHorhIXeG70rXWsFhLGrGl4Z7E17p/mc0qe1CdB/t8WQsDQt\n\t\t\t\t\t\tPl27TIY/rcj5FU/IoVVOq+Z4UoWWkpnj2Kpouu0aqZQbzcAIXj+e2i6npQ1+tpfJ\n\t\t\t\t\t\tg7fDEYxQbzd1CEZkGG8mT6iyctIvA/Ev+aooUEjbe1CdfB5suLu1EphINkTPdtRg\n\t\t\t\t\t\tSqvF+/2u1xKyNEvVr+OHCQDgneu9FwTrrP6JBMzL0DIfbulbH6KC/cAQdc0suA3I\n\t\t\t\t\t\tk2A8DnCy4fp9po8oS9sva2bfICo6ufesl6OeKs/BzQf3JvN1MnzDRPSvcZr/vKnF\n\t\t\t\t\t\t3GggIRT7y280FLbevP4EZ4KM97zGM0lxZF0omQIDAQABo4IBmDCCAZQwcwYIKwYB\n\t\t\t\t\t\tBQUHAQEEZzBlMCoGCCsGAQUFBzABhh5odHRwOi8vb2NzcC5xdW92YWRpc2dsb2Jh\n\t\t\t\t\t\tbC5jb20wNwYIKwYBBQUHMAKGK2h0dHA6Ly90cnVzdC5xdW92YWRpc2dsb2JhbC5j\n\t\t\t\t\t\tb20vcXZzc2xnMi5jcnQwHwYDVR0RBBgwFoIUaWRwLmdvbGRzbWl0aHMuYWMudWsw\n\t\t\t\t\t\tUQYDVR0gBEowSDBGBgwrBgEEAb5YAAJkAQEwNjA0BggrBgEFBQcCARYoaHR0cDov\n\t\t\t\t\t\tL3d3dy5xdW92YWRpc2dsb2JhbC5jb20vcmVwb3NpdG9yeTAOBgNVHQ8BAf8EBAMC\n\t\t\t\t\t\tBaAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMB8GA1UdIwQYMBaAFJEZ\n\t\t\t\t\t\tYq1bF6cw+/DeOSWxvYy5uFEnMDoGA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwu\n\t\t\t\t\t\tcXVvdmFkaXNnbG9iYWwuY29tL3F2c3NsZzIuY3JsMB0GA1UdDgQWBBQudULPA4BU\n\t\t\t\t\t\tR/Wtj7MvpnX1q4RqEjANBgkqhkiG9w0BAQsFAAOCAQEA3jIcYplsH+C8CnQRW7v5\n\t\t\t\t\t\tEmAuEnBu3Q8lLZWG/gsVhoM3oZLtbwzJVVf5bU/mvymGOSbuZUdhG9A3zE3mNDro\n\t\t\t\t\t\tuMpX55yoaQ80OfSkgtFulLS/D1e+0+h8sa5O+mYgTz0G0yfl9mc/YBD1E3yb4xeW\n\t\t\t\t\t\tYACVP2hh69Th2eJ7wELZIY6lxisJQuIxJyTMWLIodOCqm7/+T6rzKcFCjVZqVVsW\n\t\t\t\t\t\tMU979J/yG2UPvY0ZzjlYJCJBYna/oxazCndtgbPw700yM7d/+3rUdhAVfibBmnzy\n\t\t\t\t\t\tXjNUc3WA20A5xtfJa3B4RHmSp1zlvwxvPOU+DC/TPIfe9fz923/qDhMgCKylFbpP\n\t\t\t\t\t\tVA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gold.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.goldsmiths.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.goldsmiths.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.goldsmiths.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.goldsmiths.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.goldsmiths.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.goldsmiths.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.goldsmiths.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.goldsmiths.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gold.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://www.gold.ac.uk/static/images/gold/logo_goldsmiths.gif",
                    "height": "66",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "180"
                  },
                  {
                    "text": "https://www.gold.ac.uk/static/images/g-16x16.gif",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Goldsmiths, University of London"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF/TCCBOWgAwIBAgIUMqPz7osmzn9Ev8smgoB4KL4/2zgwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwTTELMAkGA1UEBhMCQk0xGTAXBgNVBAoTEFF1b1ZhZGlzIExpbWl0ZWQxIzAh\n\t\t\t\t\t\tBgNVBAMTGlF1b1ZhZGlzIEdsb2JhbCBTU0wgSUNBIEcyMB4XDTE1MDYxODEwMTMy\n\t\t\t\t\t\tNVoXDTE4MDYxODEwMTMyM1owgYcxCzAJBgNVBAYTAkdCMQ8wDQYDVQQIEwZMb25k\n\t\t\t\t\t\tb24xETAPBgNVBAcTCE5FV0NST1NTMRwwGgYDVQQKExNHb2xkc21pdGhzJyBDb2xs\n\t\t\t\t\t\tZWdlMRcwFQYDVQQLEw5JbmZyYXN0cnVjdHVyZTEdMBsGA1UEAxMUaWRwLmdvbGRz\n\t\t\t\t\t\tbWl0aHMuYWMudWswggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCi3wFk\n\t\t\t\t\t\taznZ+SpYvrsnww1uupnCpggywmvM5SCyqMa1YjecRF+ehyhEpTM+lmpOBp5VunM0\n\t\t\t\t\t\t2dx7Hdt10I3C1gNZemlacaihn573tJUSq44K/hw7JPifTKDxxyF9bTh3LgyYIoQC\n\t\t\t\t\t\tJMlKreErgcs+AqJHAo3ta96MIP3bBzT6tYshIwtTdLwE0M6Y5gcrDyTtDws1jmKu\n\t\t\t\t\t\t9Kt5Ht0ZW5iDh+BkfRRvW3+FTwmooL24oJ8ZXBUmGmxOha4nMHUwDDOGR6bpLO7C\n\t\t\t\t\t\tQozFmTWln2kqhxkXcS212JIHEkqb6wa42+szlVfY4USwOuSJHFQgpbApjg5rrr1p\n\t\t\t\t\t\tFGTCcpbLMt+feQ77kHorhIXeG70rXWsFhLGrGl4Z7E17p/mc0qe1CdB/t8WQsDQt\n\t\t\t\t\t\tPl27TIY/rcj5FU/IoVVOq+Z4UoWWkpnj2Kpouu0aqZQbzcAIXj+e2i6npQ1+tpfJ\n\t\t\t\t\t\tg7fDEYxQbzd1CEZkGG8mT6iyctIvA/Ev+aooUEjbe1CdfB5suLu1EphINkTPdtRg\n\t\t\t\t\t\tSqvF+/2u1xKyNEvVr+OHCQDgneu9FwTrrP6JBMzL0DIfbulbH6KC/cAQdc0suA3I\n\t\t\t\t\t\tk2A8DnCy4fp9po8oS9sva2bfICo6ufesl6OeKs/BzQf3JvN1MnzDRPSvcZr/vKnF\n\t\t\t\t\t\t3GggIRT7y280FLbevP4EZ4KM97zGM0lxZF0omQIDAQABo4IBmDCCAZQwcwYIKwYB\n\t\t\t\t\t\tBQUHAQEEZzBlMCoGCCsGAQUFBzABhh5odHRwOi8vb2NzcC5xdW92YWRpc2dsb2Jh\n\t\t\t\t\t\tbC5jb20wNwYIKwYBBQUHMAKGK2h0dHA6Ly90cnVzdC5xdW92YWRpc2dsb2JhbC5j\n\t\t\t\t\t\tb20vcXZzc2xnMi5jcnQwHwYDVR0RBBgwFoIUaWRwLmdvbGRzbWl0aHMuYWMudWsw\n\t\t\t\t\t\tUQYDVR0gBEowSDBGBgwrBgEEAb5YAAJkAQEwNjA0BggrBgEFBQcCARYoaHR0cDov\n\t\t\t\t\t\tL3d3dy5xdW92YWRpc2dsb2JhbC5jb20vcmVwb3NpdG9yeTAOBgNVHQ8BAf8EBAMC\n\t\t\t\t\t\tBaAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMB8GA1UdIwQYMBaAFJEZ\n\t\t\t\t\t\tYq1bF6cw+/DeOSWxvYy5uFEnMDoGA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwu\n\t\t\t\t\t\tcXVvdmFkaXNnbG9iYWwuY29tL3F2c3NsZzIuY3JsMB0GA1UdDgQWBBQudULPA4BU\n\t\t\t\t\t\tR/Wtj7MvpnX1q4RqEjANBgkqhkiG9w0BAQsFAAOCAQEA3jIcYplsH+C8CnQRW7v5\n\t\t\t\t\t\tEmAuEnBu3Q8lLZWG/gsVhoM3oZLtbwzJVVf5bU/mvymGOSbuZUdhG9A3zE3mNDro\n\t\t\t\t\t\tuMpX55yoaQ80OfSkgtFulLS/D1e+0+h8sa5O+mYgTz0G0yfl9mc/YBD1E3yb4xeW\n\t\t\t\t\t\tYACVP2hh69Th2eJ7wELZIY6lxisJQuIxJyTMWLIodOCqm7/+T6rzKcFCjVZqVVsW\n\t\t\t\t\t\tMU979J/yG2UPvY0ZzjlYJCJBYna/oxazCndtgbPw700yM7d/+3rUdhAVfibBmnzy\n\t\t\t\t\t\tXjNUc3WA20A5xtfJa3B4RHmSp1zlvwxvPOU+DC/TPIfe9fz923/qDhMgCKylFbpP\n\t\t\t\t\t\tVA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Goldsmiths, University of London"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.goldsmiths.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Goldsmiths' College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ni.sunet.se/saml2/metadata/",
    {
      "entity_id": "https://ni.sunet.se/saml2/metadata/",
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Krogh"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:markus@nordu.net"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "NORDUnet A/S"
          },
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Markus"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish University Network (SUNET)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sunet.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SUNET"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ni.sunet.se/saml2/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Tj\u00e4nst f\u00f6r att dokumentera SUNET n\u00e4tverket"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Service used for documenting the SUNET network"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SUNET Network Inventory"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SUNET Network Inventory"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOTCCAiGgAwIBAgIJAOqFC7U2KpC4MA0GCSqGSIb3DQEBCwUAMDMxCzAJBgNV\nBAYTAlNFMQ4wDAYDVQQKDAVTVU5FVDEUMBIGA1UEAwwLbmkuc3VuZXQuc2UwHhcN\nMTYwMjA5MTQ0MDUzWhcNMjYwMjA2MTQ0MDUzWjAzMQswCQYDVQQGEwJTRTEOMAwG\nA1UECgwFU1VORVQxFDASBgNVBAMMC25pLnN1bmV0LnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAvPF6Z27GVHJAPvx3dodR7YFOnNpqdZFjdWeFki2/\nMtmDOSzlljPutKmV/AV8u3IDv34s3tZtuKM+gF4br0RJtVhO/gH6RoUy2HiXE3Y1\nnNKRu7ddsD6XnFST5g+LvD85lCQrleBqeAxI2QJwhvTRuyfnmyZXyvRT97dcLakG\nNzedscuKCdD+tewnycoityq/OCC+a37nvT23lIPt5cPSBqcDyvyHkp0A1xJNVKOT\n+FcuL0MI0o6YqtUT4g09DQ+bE6dmEojXBn7RCSxNh9QEVsqJOOwrNRC7PxBS95IJ\nFZIubfTL7tbz4EwFum6wkge8vePr8kKzVE6qygNPFE69ewIDAQABo1AwTjAdBgNV\nHQ4EFgQUxw8dTde6b1pwN4NJXvQ+9rqSMBUwHwYDVR0jBBgwFoAUxw8dTde6b1pw\nN4NJXvQ+9rqSMBUwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAQEAiZrf\nMdLBOGIh/gLK8bOQp3fOD4R1dBFjfzNnc9LIrlo14mv01CM0fmyRjfzQ/e3l3qrX\nEkTnrF5w9pRuBm/LR8DNAbByS1gQ7fPDXzRIiSLDaRQGKh7JcObL/+pSeyfP15hV\nSsZ9CioD2fa96JA1DSXjXSDilwdWC35AGlpCcbj5Hl0QAQ2kn0u44gzNiEpywiC4\n/lybDYpTKJCuok2S0DwfOBps58T1yrFcDJAhGnvj7HEGsrW/GDfwcGflkrxlfGr0\naRl22guR2G2MeQtvNn+JuYRmrJbW8xi5mXCQkps2TvQfiVLHAzCIpXUZANpnS582\n2fn7/8dMTID4P7xD+w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOTCCAiGgAwIBAgIJAOqFC7U2KpC4MA0GCSqGSIb3DQEBCwUAMDMxCzAJBgNV\nBAYTAlNFMQ4wDAYDVQQKDAVTVU5FVDEUMBIGA1UEAwwLbmkuc3VuZXQuc2UwHhcN\nMTYwMjA5MTQ0MDUzWhcNMjYwMjA2MTQ0MDUzWjAzMQswCQYDVQQGEwJTRTEOMAwG\nA1UECgwFU1VORVQxFDASBgNVBAMMC25pLnN1bmV0LnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAvPF6Z27GVHJAPvx3dodR7YFOnNpqdZFjdWeFki2/\nMtmDOSzlljPutKmV/AV8u3IDv34s3tZtuKM+gF4br0RJtVhO/gH6RoUy2HiXE3Y1\nnNKRu7ddsD6XnFST5g+LvD85lCQrleBqeAxI2QJwhvTRuyfnmyZXyvRT97dcLakG\nNzedscuKCdD+tewnycoityq/OCC+a37nvT23lIPt5cPSBqcDyvyHkp0A1xJNVKOT\n+FcuL0MI0o6YqtUT4g09DQ+bE6dmEojXBn7RCSxNh9QEVsqJOOwrNRC7PxBS95IJ\nFZIubfTL7tbz4EwFum6wkge8vePr8kKzVE6qygNPFE69ewIDAQABo1AwTjAdBgNV\nHQ4EFgQUxw8dTde6b1pwN4NJXvQ+9rqSMBUwHwYDVR0jBBgwFoAUxw8dTde6b1pw\nN4NJXvQ+9rqSMBUwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAQEAiZrf\nMdLBOGIh/gLK8bOQp3fOD4R1dBFjfzNnc9LIrlo14mv01CM0fmyRjfzQ/e3l3qrX\nEkTnrF5w9pRuBm/LR8DNAbByS1gQ7fPDXzRIiSLDaRQGKh7JcObL/+pSeyfP15hV\nSsZ9CioD2fa96JA1DSXjXSDilwdWC35AGlpCcbj5Hl0QAQ2kn0u44gzNiEpywiC4\n/lybDYpTKJCuok2S0DwfOBps58T1yrFcDJAhGnvj7HEGsrW/GDfwcGflkrxlfGr0\naRl22guR2G2MeQtvNn+JuYRmrJbW8xi5mXCQkps2TvQfiVLHAzCIpXUZANpnS582\n2fn7/8dMTID4P7xD+w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ni.sunet.se/saml2/acs/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SUNET Network Inventory"
                }
              ],
              "requested_attribute": [
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "displayName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://akkatest.its.uu.se/Shibboleth",
    {
      "entity_id": "https://akkatest.its.uu.se/Shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJAPevEDM/eL6HMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDnJhbWEuaXRzLnV1LnNlMB4XDTEyMDUwNDEzMzkxM1oXDTIyMDUwMjEzMzkx\nM1owGTEXMBUGA1UEAxMOcmFtYS5pdHMudXUuc2UwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQC/JIPualV+2/W+KqnkNM0zJbiDe/bjGyZqTdpGGNZ+Fdv5\nYWfdMAazx8Q6nebRroCAhzOFD2IiwmPVnhAIGxoT60oSvkLEuROWlpcVGYBWO2ob\nUCJhuf36fNuM+M0cvyfNsszGY/RN+alDkRO4q+qBot0ZCQtxFXEKPc3XU71saW8G\nB5rlQT9bUzaPxnFg/c3I4YsGsrutjFhd346XlWrdY+Yu+kgCroyKuG4fJdEQj+Dc\nzYtnf8bCrmQkymdlVCrqiyscRgy7RTM4o6O86y8K/XKY75LPyO5eW1PwSQmhZ81M\n5GOyiTTvxigchLjs/RjXvO831wOFzHCTQR9s2r3hAgMBAAGjPDA6MBkGA1UdEQQS\nMBCCDnJhbWEuaXRzLnV1LnNlMB0GA1UdDgQWBBRq768tUOrPoWPR73il6QUeu7as\nZDANBgkqhkiG9w0BAQUFAAOCAQEAAi9lQbbCd7UgMc6r1Ds6uBbz2mKwaGUOLE/d\n8ZM3aeE0QLI83yX5pF1cKNar9XNAGklsDtMc64/7+tmuimH7hzh5wbmXtZROlvAq\nA9sCefzcJtjKSXvg1N613W+03ZrUzmL0V9EtKEfEDKnuTqUzLMP112eBwZavOTmR\nqtKsyINwsUmnjBv5DayfcCzfUFmHyBlhe+hAMacex0k2Iy/jozNN5ciwvR4OlHwI\nblxtYGVB1uGczqhd4Vn/jIHHcW5mx6oamuRXMcuRoAIJxw8aL7s+0Gm6vNNbLIpt\n+9Wlbs4JNpKbUADka9XZmieDYfcL+QjBqY7yhrIUnv/1GrLXTA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://akkatest.its.uu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://akkatest.its.uu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://akkatest.its.uu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://akkatest.its.uu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://aleph20.knihovna-pardubice.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gol\u00e1\u0148"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "r.golan@knihovna-pardubice.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Radek"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://aleph20.knihovna-pardubice.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2015-12-28T11:25:01Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/library"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aleph20.knihovna-pardubice.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aleph20.knihovna-pardubice.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYTCCAkmgAwIBAgIVAPFubL8wjTn8HgExnivs6f17K02iMA0GCSqGSIb3DQEB\nCwUAMCgxJjAkBgNVBAMMHWFsZXBoMjAua25paG92bmEtcGFyZHViaWNlLmN6MB4X\nDTE1MTIwNjIxNTYzOFoXDTM1MTIwNjIxNTYzOFowKDEmMCQGA1UEAwwdYWxlcGgy\nMC5rbmlob3ZuYS1wYXJkdWJpY2UuY3owggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQCP3LzEbLA/IUKwMzWiGSVDBrEkYmB03ZoFLsVBkUwhnUtt4bhsVM9N\nsSlS9KiNtbo5kswwE/XyuUaUfHRKgm2R5/45EtvLkesrXvJCSFztCmwPHuVgKf7c\nh3J2JzkjjQ3wAaEcTvqLuba/dlA8iEm2KJy5CS/9Wd74AhALGh1fOPluxFZyAJ7V\nS/M4HpMUnz6pd/mnaApSLLwJ9ZlAR79VYun4c8ljVYQUYBmtuCRYi6YO9mE9HWZg\nK/w/9Xf8XX5orPl+eVVu21AEV8zHrZrLJz4wWKHAw9sSvUv4gXQt9Gf0yHvcJtjL\n2K0fU7JJt1/LtmQ4nEMz9VNJujFBI9WpAgMBAAGjgYEwfzAdBgNVHQ4EFgQUwB3l\nbeKoKeenIxwuyuHkmyM8BlIwXgYDVR0RBFcwVYIdYWxlcGgyMC5rbmlob3ZuYS1w\nYXJkdWJpY2UuY3qGNGh0dHBzOi8vYWxlcGgyMC5rbmlob3ZuYS1wYXJkdWJpY2Uu\nY3ovaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBACUYE1aqVNsYpY0y\ncUioFT7EOtc8P51t5wAoHTQc4qBuTcvvhHIc8PtJMpiP15Z+zv+SiTZOeZhW5DZx\n04UUqUCD01dOQmoWp60n1UIuyhboSz9Yg431Z3JYYL6sDusqxj56ywMNSXqg1aw4\nG4oRD2tsMa1kEMKWw3RfeDCgtqzmkkJTAfWb+LlmmsHPm43lXIP1EWvVzKpB2N2o\nFwEyjv8X8tol3kKFg1VL4On2sOq5N4G7UdouhCiNYNZoMl/c+VnHDqQBrf/wRdOT\nGcJHBJBXdvinnR+rfxD3hUM7zi/qWkMOgSWRv1IV8dg0ItyPjFPNpKabl3R1XqMV\nKRvMLBs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYDCCAkigAwIBAgIUURP+yFe36mFpN9RgfCXBYv8Op4QwDQYJKoZIhvcNAQEL\nBQAwKDEmMCQGA1UEAwwdYWxlcGgyMC5rbmlob3ZuYS1wYXJkdWJpY2UuY3owHhcN\nMTUxMjA2MjE1NjMyWhcNMzUxMjA2MjE1NjMyWjAoMSYwJAYDVQQDDB1hbGVwaDIw\nLmtuaWhvdm5hLXBhcmR1YmljZS5jejCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBAPtizkYbUHkTYKA5F2ePE9OaQY+2OP6Kq6rqIceLouNvt01Ojr2OWSbs\nQK7VYQjFrhBsoVOxEz3QHj/JhnU0s+5q62zfft7cKgq15YyhGkQjg9miE8QC9dfs\nYzntSnoCnwuu06T/ZHyp0nRYDtCB39QylNO5LyeB9pgvK3uFy61k0ImctG7/RtSr\nexuTemd5kA7CVWNGseRkmrpjzOhNJBpZ1+dMkQxbYlMb7C9MG1xODER1gnZlUFAV\nNSSNqc59Qzy5nKdbxla8VsC5+Qau+bEZL49PgR6+yFbnOxZiXLg8QURDq3qDWkqK\nxqyqxHYjavOyAnOmDJ1VtjikwIkXfycCAwEAAaOBgTB/MB0GA1UdDgQWBBRDvIQ6\n9wmVi/vE38By6+TmyKJkmjBeBgNVHREEVzBVgh1hbGVwaDIwLmtuaWhvdm5hLXBh\ncmR1YmljZS5jeoY0aHR0cHM6Ly9hbGVwaDIwLmtuaWhvdm5hLXBhcmR1YmljZS5j\nei9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAVw31nViqZGCKvmmp\neR4HfuYsBrrPPpFBk/DHn+I26VX8u/cHh8HE/p6xQy2DGxUEaazxMskUtxesawH2\nBYPl+Q0yZexW4fYES+8XWX7ZS7qqzb208ND+wBzAF88FPZPgURpNzlv66Eft6LTb\nbtvWflGq1OQUjlOO+U1o/k+qWMNY6BnvPZ7I8OL24/NySOBRYF6g60qa5k+sq6b4\n2f9VHwi3EddbXUUeXDEOurE3y59/4vpnbXXE26HIDM2u3BDqWN542+9/0znb8V9j\ncrqwW/FJZT95CyCSHjKlHuo7Sp6xH9lZ6LEgurhFZSR9NCm27iPFocc0rWdHUFAh\nxOyYFQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYTCCAkmgAwIBAgIVAIuGPC6pY3ijY02QMm6L8DaPg39RMA0GCSqGSIb3DQEB\nCwUAMCgxJjAkBgNVBAMMHWFsZXBoMjAua25paG92bmEtcGFyZHViaWNlLmN6MB4X\nDTE1MTIwNjIxNTYzM1oXDTM1MTIwNjIxNTYzM1owKDEmMCQGA1UEAwwdYWxlcGgy\nMC5rbmlob3ZuYS1wYXJkdWJpY2UuY3owggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQCOLAnFMXyrFmUWUCKSgf2K0vNA8Fm2eKG/SSkfxR/GxavQul+9lwDf\nRK0zQ2/Fp3Y9uLV+knosd9wix1PaI7WDizhCfwXZXGHeiIFg5KiJ/YgEsjI9D/62\n62qtbUyFOvM++HKnE5uFDJ4XGRlx0ZoSyg+uVzuXnsSF4OXf7hpvA610c9fwa9Gi\n32olR5BkcKctfd71/xPAN10ze1BZKmX7+hmpnIdLj/cugTK7Ttddj5qrithaYpqh\nyPtF1FhB2HNZlpagASMZlY+rfxxjaD8cVInhCN2IhwPhrSLoPiTzmrXDfSsEHUG9\n08LmoBT5f1Kaky99QRzgnnQRlev4oGCzAgMBAAGjgYEwfzAdBgNVHQ4EFgQUf/RC\njJa8TVE7lmYc/hIM8FVn+c4wXgYDVR0RBFcwVYIdYWxlcGgyMC5rbmlob3ZuYS1w\nYXJkdWJpY2UuY3qGNGh0dHBzOi8vYWxlcGgyMC5rbmlob3ZuYS1wYXJkdWJpY2Uu\nY3ovaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAC+TkpIKYSWT3qBq\nGqtjA4N8cORNeH2/YMG0gCc3b0grGXg+tIyV7frVJ0NQRnqTytgN+Hw+Ww1G7rEI\nE9BmvQ+lz9LmmatDuT1G8Qv3OSVQRkrTPqEtcFnec57E2ocVDLvsLl2wEhhZ+HNz\nhukgkhCwXFECRQBdNZ3uBr38IndJgQspIxCGMkm3syhQsZEreFU6Rapsol2nQ9mX\n9Ov1Z565A5CJcJ0C4FjifHbHzIVvYE5xY9VXT/sFv2ZOVYg6KiNkT2QVSioTi8Qs\nFYylo3H84FfcXVVpFDYg4GKqEynsIvH2zDvBugunV0xM/iNq4mjqbRiyDa8Zb5Q9\nVqwqp44="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "knihovna-pardubice.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aleph20.knihovna-pardubice.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aleph20.knihovna-pardubice.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aleph20.knihovna-pardubice.cz/idp/profile/SAML2/POST-SimpleSign/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aleph20.knihovna-pardubice.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aleph20.knihovna-pardubice.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aleph20.knihovna-pardubice.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aleph20.knihovna-pardubice.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aleph20.knihovna-pardubice.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aleph20.knihovna-pardubice.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aleph20.knihovna-pardubice.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "knihovna-pardubice.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://kkpce.cz/en/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://kkpce.cz/cs/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for patrons and staff of the Regional Library in Pardubice"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro \u010dten\u00e1\u0159e a zam\u011bstance Krajsk\u00e9 knihovny v Pardubic\u00edch"
                  }
                ],
                "logo": [
                  {
                    "text": "https://aleph20.knihovna-pardubice.cz/idp/images/logo_40.png",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "41"
                  },
                  {
                    "text": "https://aleph20.knihovna-pardubice.cz/idp/images/logo_90.png",
                    "height": "87",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "90"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Regional Library in Pardubice"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Krajsk\u00e1 knihovna v Pardubic\u00edch"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYTCCAkmgAwIBAgIVAPFubL8wjTn8HgExnivs6f17K02iMA0GCSqGSIb3DQEB\nCwUAMCgxJjAkBgNVBAMMHWFsZXBoMjAua25paG92bmEtcGFyZHViaWNlLmN6MB4X\nDTE1MTIwNjIxNTYzOFoXDTM1MTIwNjIxNTYzOFowKDEmMCQGA1UEAwwdYWxlcGgy\nMC5rbmlob3ZuYS1wYXJkdWJpY2UuY3owggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQCP3LzEbLA/IUKwMzWiGSVDBrEkYmB03ZoFLsVBkUwhnUtt4bhsVM9N\nsSlS9KiNtbo5kswwE/XyuUaUfHRKgm2R5/45EtvLkesrXvJCSFztCmwPHuVgKf7c\nh3J2JzkjjQ3wAaEcTvqLuba/dlA8iEm2KJy5CS/9Wd74AhALGh1fOPluxFZyAJ7V\nS/M4HpMUnz6pd/mnaApSLLwJ9ZlAR79VYun4c8ljVYQUYBmtuCRYi6YO9mE9HWZg\nK/w/9Xf8XX5orPl+eVVu21AEV8zHrZrLJz4wWKHAw9sSvUv4gXQt9Gf0yHvcJtjL\n2K0fU7JJt1/LtmQ4nEMz9VNJujFBI9WpAgMBAAGjgYEwfzAdBgNVHQ4EFgQUwB3l\nbeKoKeenIxwuyuHkmyM8BlIwXgYDVR0RBFcwVYIdYWxlcGgyMC5rbmlob3ZuYS1w\nYXJkdWJpY2UuY3qGNGh0dHBzOi8vYWxlcGgyMC5rbmlob3ZuYS1wYXJkdWJpY2Uu\nY3ovaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBACUYE1aqVNsYpY0y\ncUioFT7EOtc8P51t5wAoHTQc4qBuTcvvhHIc8PtJMpiP15Z+zv+SiTZOeZhW5DZx\n04UUqUCD01dOQmoWp60n1UIuyhboSz9Yg431Z3JYYL6sDusqxj56ywMNSXqg1aw4\nG4oRD2tsMa1kEMKWw3RfeDCgtqzmkkJTAfWb+LlmmsHPm43lXIP1EWvVzKpB2N2o\nFwEyjv8X8tol3kKFg1VL4On2sOq5N4G7UdouhCiNYNZoMl/c+VnHDqQBrf/wRdOT\nGcJHBJBXdvinnR+rfxD3hUM7zi/qWkMOgSWRv1IV8dg0ItyPjFPNpKabl3R1XqMV\nKRvMLBs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYDCCAkigAwIBAgIUURP+yFe36mFpN9RgfCXBYv8Op4QwDQYJKoZIhvcNAQEL\nBQAwKDEmMCQGA1UEAwwdYWxlcGgyMC5rbmlob3ZuYS1wYXJkdWJpY2UuY3owHhcN\nMTUxMjA2MjE1NjMyWhcNMzUxMjA2MjE1NjMyWjAoMSYwJAYDVQQDDB1hbGVwaDIw\nLmtuaWhvdm5hLXBhcmR1YmljZS5jejCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBAPtizkYbUHkTYKA5F2ePE9OaQY+2OP6Kq6rqIceLouNvt01Ojr2OWSbs\nQK7VYQjFrhBsoVOxEz3QHj/JhnU0s+5q62zfft7cKgq15YyhGkQjg9miE8QC9dfs\nYzntSnoCnwuu06T/ZHyp0nRYDtCB39QylNO5LyeB9pgvK3uFy61k0ImctG7/RtSr\nexuTemd5kA7CVWNGseRkmrpjzOhNJBpZ1+dMkQxbYlMb7C9MG1xODER1gnZlUFAV\nNSSNqc59Qzy5nKdbxla8VsC5+Qau+bEZL49PgR6+yFbnOxZiXLg8QURDq3qDWkqK\nxqyqxHYjavOyAnOmDJ1VtjikwIkXfycCAwEAAaOBgTB/MB0GA1UdDgQWBBRDvIQ6\n9wmVi/vE38By6+TmyKJkmjBeBgNVHREEVzBVgh1hbGVwaDIwLmtuaWhvdm5hLXBh\ncmR1YmljZS5jeoY0aHR0cHM6Ly9hbGVwaDIwLmtuaWhvdm5hLXBhcmR1YmljZS5j\nei9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAVw31nViqZGCKvmmp\neR4HfuYsBrrPPpFBk/DHn+I26VX8u/cHh8HE/p6xQy2DGxUEaazxMskUtxesawH2\nBYPl+Q0yZexW4fYES+8XWX7ZS7qqzb208ND+wBzAF88FPZPgURpNzlv66Eft6LTb\nbtvWflGq1OQUjlOO+U1o/k+qWMNY6BnvPZ7I8OL24/NySOBRYF6g60qa5k+sq6b4\n2f9VHwi3EddbXUUeXDEOurE3y59/4vpnbXXE26HIDM2u3BDqWN542+9/0znb8V9j\ncrqwW/FJZT95CyCSHjKlHuo7Sp6xH9lZ6LEgurhFZSR9NCm27iPFocc0rWdHUFAh\nxOyYFQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYTCCAkmgAwIBAgIVAIuGPC6pY3ijY02QMm6L8DaPg39RMA0GCSqGSIb3DQEB\nCwUAMCgxJjAkBgNVBAMMHWFsZXBoMjAua25paG92bmEtcGFyZHViaWNlLmN6MB4X\nDTE1MTIwNjIxNTYzM1oXDTM1MTIwNjIxNTYzM1owKDEmMCQGA1UEAwwdYWxlcGgy\nMC5rbmlob3ZuYS1wYXJkdWJpY2UuY3owggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQCOLAnFMXyrFmUWUCKSgf2K0vNA8Fm2eKG/SSkfxR/GxavQul+9lwDf\nRK0zQ2/Fp3Y9uLV+knosd9wix1PaI7WDizhCfwXZXGHeiIFg5KiJ/YgEsjI9D/62\n62qtbUyFOvM++HKnE5uFDJ4XGRlx0ZoSyg+uVzuXnsSF4OXf7hpvA610c9fwa9Gi\n32olR5BkcKctfd71/xPAN10ze1BZKmX7+hmpnIdLj/cugTK7Ttddj5qrithaYpqh\nyPtF1FhB2HNZlpagASMZlY+rfxxjaD8cVInhCN2IhwPhrSLoPiTzmrXDfSsEHUG9\n08LmoBT5f1Kaky99QRzgnnQRlev4oGCzAgMBAAGjgYEwfzAdBgNVHQ4EFgQUf/RC\njJa8TVE7lmYc/hIM8FVn+c4wXgYDVR0RBFcwVYIdYWxlcGgyMC5rbmlob3ZuYS1w\nYXJkdWJpY2UuY3qGNGh0dHBzOi8vYWxlcGgyMC5rbmlob3ZuYS1wYXJkdWJpY2Uu\nY3ovaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAC+TkpIKYSWT3qBq\nGqtjA4N8cORNeH2/YMG0gCc3b0grGXg+tIyV7frVJ0NQRnqTytgN+Hw+Ww1G7rEI\nE9BmvQ+lz9LmmatDuT1G8Qv3OSVQRkrTPqEtcFnec57E2ocVDLvsLl2wEhhZ+HNz\nhukgkhCwXFECRQBdNZ3uBr38IndJgQspIxCGMkm3syhQsZEreFU6Rapsol2nQ9mX\n9Ov1Z565A5CJcJ0C4FjifHbHzIVvYE5xY9VXT/sFv2ZOVYg6KiNkT2QVSioTi8Qs\nFYylo3H84FfcXVVpFDYg4GKqEynsIvH2zDvBugunV0xM/iNq4mjqbRiyDa8Zb5Q9\nVqwqp44="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Krajsk\u00e1 knihovna v Pardubic\u00edch"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Regional Library in Pardubice"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://kkpce.cz/en/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://kkpce.cz/cs/"
          }
        ],
        "organization_name": [
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Krajsk\u00e1 knihovna v Pardubic\u00edch"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Regional Library in Pardubice"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://test.rpharms.com/entity",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Edwards"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:micah@cbcl.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Micah"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Edwards"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:micah@cbcl.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Micah"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test.rpharms.com/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-03-04T12:21:55Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CBCL Test Site"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cbcl.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Royal Pharmaceutical Society of Great Britain"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Development site for CBCL"
                  }
                ],
                "logo": [
                  {
                    "text": "https://staging.cbcl.co.uk/ukfed/cbcl_logo.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "139"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CBCL Test Site"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDgjCCAmqgAwIBAgIJALwx9tll+qVcMA0GCSqGSIb3DQEBBQUAMDQxFTATBgNV\n\t\t\tBAoTDHN0YWdpbmctY2JjbDEbMBkGA1UEAxMSc3RhZ2luZy5jYmNsLmNvLnVrMB4X\n\t\t\tDTE1MDIyNTEyNTgxNVoXDTI1MDIyMjEyNTgxNVowNDEVMBMGA1UEChMMc3RhZ2lu\n\t\t\tZy1jYmNsMRswGQYDVQQDExJzdGFnaW5nLmNiY2wuY28udWswggEiMA0GCSqGSIb3\n\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQC8udH1d2ZZEL/BDN30QIMSKtmpY7UEwFN/sUeV\n\t\t\tdZ0Gy3g/INtPq7sD652of1/oL2wAFIAy3DDtn8AvxtZPq6YpXwa4YQFO+jdns95F\n\t\t\tsrPIYsNf07WMgiU+9RyPMlRisuQ6aP2vSmYKuCVClNsSqCUg75La9WoeCCwPVWpk\n\t\t\t68PUmU2BnWn28SJh+PS6HCH1I5VNhxEI6HK3EiJn7GfYOYLYSUXT6h5vmiPs//Se\n\t\t\tiIjgPVmp5WYp1C6Nll4W3zRYEHKDsoP17Q4J2xSLs29wV+E5KKtiGCVXlo3mmAKV\n\t\t\tQEsSKZnOU2fctnZIT3XSR3boh2HPEbnRT44xE2f5ETqIg1ZtAgMBAAGjgZYwgZMw\n\t\t\tHQYDVR0OBBYEFAzPDnpVwkT1SW2m+/wIUPwjc7unMGQGA1UdIwRdMFuAFAzPDnpV\n\t\t\twkT1SW2m+/wIUPwjc7unoTikNjA0MRUwEwYDVQQKEwxzdGFnaW5nLWNiY2wxGzAZ\n\t\t\tBgNVBAMTEnN0YWdpbmcuY2JjbC5jby51a4IJALwx9tll+qVcMAwGA1UdEwQFMAMB\n\t\t\tAf8wDQYJKoZIhvcNAQEFBQADggEBACB9SbHspWAUl22utozAqjRJrzQIAZpm3F/f\n\t\t\tTJ5rSauNjMmynolPErFiK6r2vEZTognGfA4xNgwRzj7Pv9T6fYcZSgju6CLnTtKM\n\t\t\tvisn0gZI8/FbtZtcSRvDREeiq3khk8shExS5y2QF/yIPE9p7dsJzofIabcwNOi+L\n\t\t\t3UmF4Wx9nQ/e6QqgVou2j1C4IUkLkTnomdtA0Azgc/IYHLD83q2v6aTucGndVhEe\n\t\t\tlZykRhgMXr+w93jt0q0k8Teq3TwMBZPl1Qqwp/UbbXm4zf3uRhlKqnJaS75Xx7Yq\n\t\t\tDEV9gsXy2u5SnEMxi5z04whSE1/zOY+XRy3xUBbh9doePRw91wE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDgjCCAmqgAwIBAgIJALwx9tll+qVcMA0GCSqGSIb3DQEBBQUAMDQxFTATBgNV\n\t\t\tBAoTDHN0YWdpbmctY2JjbDEbMBkGA1UEAxMSc3RhZ2luZy5jYmNsLmNvLnVrMB4X\n\t\t\tDTE1MDIyNTEyNTgxNVoXDTI1MDIyMjEyNTgxNVowNDEVMBMGA1UEChMMc3RhZ2lu\n\t\t\tZy1jYmNsMRswGQYDVQQDExJzdGFnaW5nLmNiY2wuY28udWswggEiMA0GCSqGSIb3\n\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQC8udH1d2ZZEL/BDN30QIMSKtmpY7UEwFN/sUeV\n\t\t\tdZ0Gy3g/INtPq7sD652of1/oL2wAFIAy3DDtn8AvxtZPq6YpXwa4YQFO+jdns95F\n\t\t\tsrPIYsNf07WMgiU+9RyPMlRisuQ6aP2vSmYKuCVClNsSqCUg75La9WoeCCwPVWpk\n\t\t\t68PUmU2BnWn28SJh+PS6HCH1I5VNhxEI6HK3EiJn7GfYOYLYSUXT6h5vmiPs//Se\n\t\t\tiIjgPVmp5WYp1C6Nll4W3zRYEHKDsoP17Q4J2xSLs29wV+E5KKtiGCVXlo3mmAKV\n\t\t\tQEsSKZnOU2fctnZIT3XSR3boh2HPEbnRT44xE2f5ETqIg1ZtAgMBAAGjgZYwgZMw\n\t\t\tHQYDVR0OBBYEFAzPDnpVwkT1SW2m+/wIUPwjc7unMGQGA1UdIwRdMFuAFAzPDnpV\n\t\t\twkT1SW2m+/wIUPwjc7unoTikNjA0MRUwEwYDVQQKEwxzdGFnaW5nLWNiY2wxGzAZ\n\t\t\tBgNVBAMTEnN0YWdpbmcuY2JjbC5jby51a4IJALwx9tll+qVcMAwGA1UdEwQFMAMB\n\t\t\tAf8wDQYJKoZIhvcNAQEFBQADggEBACB9SbHspWAUl22utozAqjRJrzQIAZpm3F/f\n\t\t\tTJ5rSauNjMmynolPErFiK6r2vEZTognGfA4xNgwRzj7Pv9T6fYcZSgju6CLnTtKM\n\t\t\tvisn0gZI8/FbtZtcSRvDREeiq3khk8shExS5y2QF/yIPE9p7dsJzofIabcwNOi+L\n\t\t\t3UmF4Wx9nQ/e6QqgVou2j1C4IUkLkTnomdtA0Azgc/IYHLD83q2v6aTucGndVhEe\n\t\t\tlZykRhgMXr+w93jt0q0k8Teq3TwMBZPl1Qqwp/UbbXm4zf3uRhlKqnJaS75Xx7Yq\n\t\t\tDEV9gsXy2u5SnEMxi5z04whSE1/zOY+XRy3xUBbh9doePRw91wE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://staging.cbcl.co.uk/ukfed/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://staging.cbcl.co.uk/ukfed/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://admin.safetynet.rmplc.co.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibsupport@ifl.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Support Contact"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibtechcontact@ifl.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Technical Contact"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://admin.safetynet.rmplc.co.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RM Education plc: RM Safetynet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rm.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RM Education plc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://admin.safetynet.rmplc.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://admin.safetynet.rmplc.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://admin.safetynet.rmplc.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://admin.safetynet.rmplc.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://admin.safetynet.rmplc.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://admin.safetynet.rmplc.co.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJAIDKIKpmE2tBMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\n\t\t\t\t\t\tBAMTG2FkbWluLnNhZmV0eW5ldC5ybXBsYy5jby51azAeFw0xMDA0MDgxNjE2MTha\n\t\t\t\t\t\tFw0yMDA0MDUxNjE2MThaMCYxJDAiBgNVBAMTG2FkbWluLnNhZmV0eW5ldC5ybXBs\n\t\t\t\t\t\tYy5jby51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALyO69kuQy4+\n\t\t\t\t\t\tR7W0KgA21wY7EnbY2qr8K1AKfX87jvsfDX5Jg+XwifaI/8f8sIju9jlgg0S2ju+M\n\t\t\t\t\t\tuWQyCYV6cCMp790MEXXaOR0PiAkrallrkYg/+FbP7+flmOrPhj6UWCAc80ZWJ8wx\n\t\t\t\t\t\tU6Un+UpDpmhRrQWjOn0sOW6PvkbZlRrEtW6XJ2PfhOCHHfAJIcB/r4frQFvmGBk1\n\t\t\t\t\t\t6e24W46xEPi2gznxM9MRm/MMBnFHBzHlpgu+QmL+gBI6OQ0Gr1nmZgcTJqEJCahk\n\t\t\t\t\t\tdp51SjegGKmXXWAdV7pGYkoRrwYH6TryXNaHUXQn0zoS+aa1kZIf0dVp0S508go6\n\t\t\t\t\t\taqwe92WWsAcCAwEAAaNJMEcwJgYDVR0RBB8wHYIbYWRtaW4uc2FmZXR5bmV0LnJt\n\t\t\t\t\t\tcGxjLmNvLnVrMB0GA1UdDgQWBBTiUv6qHBxNTHW11t8mP9SXPRvMmjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAhVafLlFnznxyNY5Zls8IiCN2kAqwUN5iBuVx2Q749LcVHlGy\n\t\t\t\t\t\tNtTZVpLWcrZsklTl2mBJuGI5XjqjuEu/UJtaRx0p6oC32Pg2R8/McMcJjLtbwA9X\n\t\t\t\t\t\tpIZsuOfARLq0AFS9ncrgZtVrua9YErJSWSCUkzZgJTu/1Aelc1Dlojdmp22GH4Rn\n\t\t\t\t\t\tFr1hRdDgtzpAwdBpxPdai7Pdaf47QVRSgfDjCuJ2zJopboYAbnk6UAuiLWDuLtcB\n\t\t\t\t\t\to8UiVcMPP/vvRio3IzTVoEKAmb8/EENkXRSR+we7CKNAQhZBvTvC2oWruki4UmMK\n\t\t\t\t\t\taFvLcsb+dVUZ5xAnv9teHQR18B9PVW+1Se6k3A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJAIDKIKpmE2tBMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\n\t\t\t\t\t\tBAMTG2FkbWluLnNhZmV0eW5ldC5ybXBsYy5jby51azAeFw0xMDA0MDgxNjE2MTha\n\t\t\t\t\t\tFw0yMDA0MDUxNjE2MThaMCYxJDAiBgNVBAMTG2FkbWluLnNhZmV0eW5ldC5ybXBs\n\t\t\t\t\t\tYy5jby51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALyO69kuQy4+\n\t\t\t\t\t\tR7W0KgA21wY7EnbY2qr8K1AKfX87jvsfDX5Jg+XwifaI/8f8sIju9jlgg0S2ju+M\n\t\t\t\t\t\tuWQyCYV6cCMp790MEXXaOR0PiAkrallrkYg/+FbP7+flmOrPhj6UWCAc80ZWJ8wx\n\t\t\t\t\t\tU6Un+UpDpmhRrQWjOn0sOW6PvkbZlRrEtW6XJ2PfhOCHHfAJIcB/r4frQFvmGBk1\n\t\t\t\t\t\t6e24W46xEPi2gznxM9MRm/MMBnFHBzHlpgu+QmL+gBI6OQ0Gr1nmZgcTJqEJCahk\n\t\t\t\t\t\tdp51SjegGKmXXWAdV7pGYkoRrwYH6TryXNaHUXQn0zoS+aa1kZIf0dVp0S508go6\n\t\t\t\t\t\taqwe92WWsAcCAwEAAaNJMEcwJgYDVR0RBB8wHYIbYWRtaW4uc2FmZXR5bmV0LnJt\n\t\t\t\t\t\tcGxjLmNvLnVrMB0GA1UdDgQWBBTiUv6qHBxNTHW11t8mP9SXPRvMmjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAhVafLlFnznxyNY5Zls8IiCN2kAqwUN5iBuVx2Q749LcVHlGy\n\t\t\t\t\t\tNtTZVpLWcrZsklTl2mBJuGI5XjqjuEu/UJtaRx0p6oC32Pg2R8/McMcJjLtbwA9X\n\t\t\t\t\t\tpIZsuOfARLq0AFS9ncrgZtVrua9YErJSWSCUkzZgJTu/1Aelc1Dlojdmp22GH4Rn\n\t\t\t\t\t\tFr1hRdDgtzpAwdBpxPdai7Pdaf47QVRSgfDjCuJ2zJopboYAbnk6UAuiLWDuLtcB\n\t\t\t\t\t\to8UiVcMPP/vvRio3IzTVoEKAmb8/EENkXRSR+we7CKNAQhZBvTvC2oWruki4UmMK\n\t\t\t\t\t\taFvLcsb+dVUZ5xAnv9teHQR18B9PVW+1Se6k3A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://admin.safetynet.rmplc.co.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://admin.safetynet.rmplc.co.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://admin.safetynet.rmplc.co.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://admin.safetynet.rmplc.co.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://admin.safetynet.rmplc.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://admin.safetynet.rmplc.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://admin.safetynet.rmplc.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://admin.safetynet.rmplc.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://admin.safetynet.rmplc.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://admin.safetynet.rmplc.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://auth.chaminade.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kyle.johnson@chaminade.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kyle Johnson"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://auth.chaminade.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://auth.chaminade.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.chaminade.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.chaminade.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://auth.chaminade.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://auth.chaminade.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "chaminade.edu"
              },
              {
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.chaminade.edu/incommon/operational_practices.pdf"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Chaminade University of Honolulu"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUF8kq+m9AYp9/mSs2qicSZwERtD4wDQYJKoZIhvcNAQEF\nBQAwHTEbMBkGA1UEAxMSYXV0aC5jaGFtaW5hZGUuZWR1MB4XDTEzMDQwNTIyNTgy\nMloXDTMzMDQwNTIyNTgyMlowHTEbMBkGA1UEAxMSYXV0aC5jaGFtaW5hZGUuZWR1\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAwEL73ATvDk+FNMOdqXPo\nTN96loqWp6Ju9CE5P4sn6rHQnehH/RWSkTQfPcVRhLbwDoUNEgUWyZs4OqEhJKKz\nU22UlSgdVw+2C0QHFgjTwk8z+8LTS2fkNd4lD8AWJgyQTrAgvUhjTr1zNLxKQLJ5\nyVPhAvLBQq4Sd7HSFUG1MlVYhTM3pIM1PGCPTkFCUxaPTYozo5GAcbMQoAx2wXkb\nVwYBcGBvjBnYK4CMfe/FQWnfk8KB25YURThqcyTF0JaM0w4uFDnz7ukt7Oyrkntb\nvSEOFEYFS9rfRoSs9ggVEHL5eUMwHgwGhxm3qn1iWM2yCU0MnXjdYNjeSXMerXgb\nSQIDAQABo2swaTBIBgNVHREEQTA/ghJhdXRoLmNoYW1pbmFkZS5lZHWGKWh0dHBz\nOi8vYXV0aC5jaGFtaW5hZGUuZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQa\nZqIx6w+PzJEFlWinc/8q5DQXzDANBgkqhkiG9w0BAQUFAAOCAQEAPz8G+GKqlLCY\nvB/3471AE0WtK8lybyHBQNUHbf2ZzBPa532jLvNScewLKgd8+F/Omi4y18VluYaW\ngJVjFQFle/8VJQKauWxBiWXzG4HoDmE+6wbHuq1zvLE0LLLu5svWFOrLbK1Fb++n\n9QM7xLQoy1slc9g8z5THorBJlgMFAFmL3TDIog3rSab69Gw+jwzrW5jglj+w8Iy9\nSUoYkOJ2T85hgO8Brj4OTk2+qpkK7TWDFTyUC2T4aBkMqtYG1Y2ir/kFdwAIjhSU\nreLbWrhl3hZhckCnXW5wiAxlY66PkbGk9rWHvZgbKyeLWgGl4apoL9QhBDefCRdx\nnnxOtnKJww=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Chaminade University of Honolulu"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.chaminade.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Chaminade University of Honolulu"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://aai-login.pmodwrc.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41 58 467 51 49"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Senft"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:marco.senft@pmodwrc.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marco"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41 58 467 51 49"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Senft"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:marco.senft@pmodwrc.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marco"
          }
        }
      ],
      "entity_id": "https://aai-login.pmodwrc.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2015-11-03T16:47:17Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVALG9ecvQJDCXzNRP46ZzLxS4GhtYMA0GCSqGSIb3DQEB\nCwUAMB8xHTAbBgNVBAMMFGFhaS1sb2dpbi5wbW9kd3JjLmNoMB4XDTE1MDkwNDA4\nMzM0OVoXDTE4MDkwNDA4MzM0OVowHzEdMBsGA1UEAwwUYWFpLWxvZ2luLnBtb2R3\ncmMuY2gwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCJUqXZfgggAPBq\nlto9/Kp35iKRqQnYuEYBnGWU2R+DyTBVulQMICxKj1eusQkPbx1kJHUYluEvqQAB\nFo7L92XJstToDPrqcPM9K6raiGIQkvMs8XjpimxTc5+BxwXd8j6W8nt7FSJwJMbr\nrJbPJa4d70hE6YLWeUIOlRcCqQIjimYn15bRTT3lyvyqft/aA7PGmcGwXHUUuqSM\neYcdTznmukf7DHXsELMFo8mh4mhgNtv9hOTljWzDm3E1Seltzn8dWt8BCNRhCrux\n9zbvW6O4pwuEpmEAe8Y6oiRzsPmERpYvNuCXCbiFKAM4+4urIR9HBRIYQ+O0d2Hd\nMra1f9JlAgMBAAGjbzBtMB0GA1UdDgQWBBQhIfuXzA9F23uk457x7OAaaw1+VjBM\nBgNVHREERTBDghRhYWktbG9naW4ucG1vZHdyYy5jaIYraHR0cHM6Ly9hYWktbG9n\naW4ucG1vZHdyYy5jaC9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEA\nVQQ2H4Jk7jcPpGTCgjUooodcP3HnbXBJAjN3yQPCQFAaHy508uVn94Bsf6YB9lDL\nYI8+A/YK3gVasS920PO82WXX+6GJfN69zymoLzx/1glG8TlQUChsIdaQ3wYEpY1M\nXe60wppCMMGrAX6Xm6FMJ0eAhCYB198s3rq912Qo45X0IRatt/9/hX8d6papM3ix\nKLnxSFoYmtjuLBu3m3iafGjKLhqrSuUjijQkUpiBhU9L+mHYqsiFhWtN0shDDArV\n/L/p5/Cgit73Y4DxEiduQLsvOY7qMRT/2B8BeOGfsPmFEhgOW4bsqD0PPDSFU/0V\n5ZEAFD7qOs5ewWuoyZkSkw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pmodwrc.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-login.pmodwrc.ch/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai-login.pmodwrc.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai-login.pmodwrc.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pmodwrc.ch"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.pmodwrc.ch/"
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.pmodwrc.ch/"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Physikalisch-Meteorologisches Observatorium Davos / World Radiation Center"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Physikalisch-Meteorologisches Observatorium Davos / World Radiation Center"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "23",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PMOD/WRC - Observatorium Davos"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PMOD/WRC - Observatory Davos"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "pmodwrc.ch"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:46.813268333,9.844476667"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.5.60.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:620:1b0::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVALG9ecvQJDCXzNRP46ZzLxS4GhtYMA0GCSqGSIb3DQEB\nCwUAMB8xHTAbBgNVBAMMFGFhaS1sb2dpbi5wbW9kd3JjLmNoMB4XDTE1MDkwNDA4\nMzM0OVoXDTE4MDkwNDA4MzM0OVowHzEdMBsGA1UEAwwUYWFpLWxvZ2luLnBtb2R3\ncmMuY2gwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCJUqXZfgggAPBq\nlto9/Kp35iKRqQnYuEYBnGWU2R+DyTBVulQMICxKj1eusQkPbx1kJHUYluEvqQAB\nFo7L92XJstToDPrqcPM9K6raiGIQkvMs8XjpimxTc5+BxwXd8j6W8nt7FSJwJMbr\nrJbPJa4d70hE6YLWeUIOlRcCqQIjimYn15bRTT3lyvyqft/aA7PGmcGwXHUUuqSM\neYcdTznmukf7DHXsELMFo8mh4mhgNtv9hOTljWzDm3E1Seltzn8dWt8BCNRhCrux\n9zbvW6O4pwuEpmEAe8Y6oiRzsPmERpYvNuCXCbiFKAM4+4urIR9HBRIYQ+O0d2Hd\nMra1f9JlAgMBAAGjbzBtMB0GA1UdDgQWBBQhIfuXzA9F23uk457x7OAaaw1+VjBM\nBgNVHREERTBDghRhYWktbG9naW4ucG1vZHdyYy5jaIYraHR0cHM6Ly9hYWktbG9n\naW4ucG1vZHdyYy5jaC9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEA\nVQQ2H4Jk7jcPpGTCgjUooodcP3HnbXBJAjN3yQPCQFAaHy508uVn94Bsf6YB9lDL\nYI8+A/YK3gVasS920PO82WXX+6GJfN69zymoLzx/1glG8TlQUChsIdaQ3wYEpY1M\nXe60wppCMMGrAX6Xm6FMJ0eAhCYB198s3rq912Qo45X0IRatt/9/hX8d6papM3ix\nKLnxSFoYmtjuLBu3m3iafGjKLhqrSuUjijQkUpiBhU9L+mHYqsiFhWtN0shDDArV\n/L/p5/Cgit73Y4DxEiduQLsvOY7qMRT/2B8BeOGfsPmFEhgOW4bsqD0PPDSFU/0V\n5ZEAFD7qOs5ewWuoyZkSkw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "error_url": "http://www.pmodwrc.ch/helpdesk/"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PMOD/WRC - Observatorium Davos"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PMOD/WRC - Observatory Davos"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.pmodwrc.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.pmodwrc.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "pmodwrc.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibidp.wnc.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Peake"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:heather.peake@wnc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Heather"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Williams"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:owen.williams@wnc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Owen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibidp.wnc.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-04-04T16:04:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDeDCCAmACCQDV2f231qNoMzANBgkqhkiG9w0BAQUFADB+MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEYMBYGA1UECAwPTm90dGluZ2hhbXNoaXJlMRIwEAYDVQQHDAlNYW5zZmllbGQx\n\t\t\t\t\t\tJTAjBgNVBAoMHFdlc3QgTm90dGluZ2hhbXNoaXJlIENvbGxlZ2UxGjAYBgNVBAMM\n\t\t\t\t\t\tEXNoaWJpZHAud25jLmFjLnVrMB4XDTE0MDIwMzEwMzYzNVoXDTM0MDEyOTEwMzYz\n\t\t\t\t\t\tNVowfjELMAkGA1UEBhMCR0IxGDAWBgNVBAgMD05vdHRpbmdoYW1zaGlyZTESMBAG\n\t\t\t\t\t\tA1UEBwwJTWFuc2ZpZWxkMSUwIwYDVQQKDBxXZXN0IE5vdHRpbmdoYW1zaGlyZSBD\n\t\t\t\t\t\tb2xsZWdlMRowGAYDVQQDDBFzaGliaWRwLnduYy5hYy51azCCASIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEBBQADggEPADCCAQoCggEBANjphOxHqFN24tCPo/ZUfNvzOUTDoyeq5lHSOWlN\n\t\t\t\t\t\taWRtax7z5fbQ+Ajpdgyp6wP7JA5+CktdwVjR5maIGS8Snow5W2/oLKIH6qZN3Dmh\n\t\t\t\t\t\t4RbfL3IPjWNGqcLBZ5cR6B2b71BmEFowJ4RopV0uLd4yud0aVA33AuNHtt5FCbmx\n\t\t\t\t\t\t57UaykuwNUH0AUP0Mmhw0Unlh5C/SmrLRdeQxQpB3qWDNasgFMcvCet7jUP3Tje5\n\t\t\t\t\t\tLysqQdDV0iS5C7sWmAzVfwJ4oF+CgM6IrCobOf+45dEa7v5+ILDQEpYJJa5vYbvu\n\t\t\t\t\t\tzGxTWbH6Wt6QnJOFX3ZHVYMnh7gogu/vposOzgaJhFYu6ekCAwEAATANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAt2WPnd7BzzXgF7yd1qcPpYFcnx1eaFD5PHCqtSUtPM4tqmrT\n\t\t\t\t\t\tICM5ELCpwZYSZbyTm1MikC1um2U9tZIi780kZnjSSMff7YkiSCN3pEjjM8OaJtnO\n\t\t\t\t\t\t7NKT0bRrx5y0UlVI0D/It4AasMZCL4tJf7J74lbi/6WGMMPz3JMKSJlWSaBg9875\n\t\t\t\t\t\t0LiyYQ0LugAJYLzYvGjdzqg08QOZWnMgUB0clI8moXNLUiE8Q4VN12PJqugUuzEi\n\t\t\t\t\t\tt7IWhuOL2qj1e65huFQRUrHdvKsvm9+iydT7JkIMw0tUDO/uTPRl51QNYCP6aiC2\n\t\t\t\t\t\td88+xmq6gSOp+ZyGanKnNUHyRuukGiawzUDS5w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wnc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.wnc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.wnc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.wnc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.wnc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibidp.wnc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.wnc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.wnc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.wnc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wnc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDeDCCAmACCQDV2f231qNoMzANBgkqhkiG9w0BAQUFADB+MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEYMBYGA1UECAwPTm90dGluZ2hhbXNoaXJlMRIwEAYDVQQHDAlNYW5zZmllbGQx\n\t\t\t\t\t\tJTAjBgNVBAoMHFdlc3QgTm90dGluZ2hhbXNoaXJlIENvbGxlZ2UxGjAYBgNVBAMM\n\t\t\t\t\t\tEXNoaWJpZHAud25jLmFjLnVrMB4XDTE0MDIwMzEwMzYzNVoXDTM0MDEyOTEwMzYz\n\t\t\t\t\t\tNVowfjELMAkGA1UEBhMCR0IxGDAWBgNVBAgMD05vdHRpbmdoYW1zaGlyZTESMBAG\n\t\t\t\t\t\tA1UEBwwJTWFuc2ZpZWxkMSUwIwYDVQQKDBxXZXN0IE5vdHRpbmdoYW1zaGlyZSBD\n\t\t\t\t\t\tb2xsZWdlMRowGAYDVQQDDBFzaGliaWRwLnduYy5hYy51azCCASIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEBBQADggEPADCCAQoCggEBANjphOxHqFN24tCPo/ZUfNvzOUTDoyeq5lHSOWlN\n\t\t\t\t\t\taWRtax7z5fbQ+Ajpdgyp6wP7JA5+CktdwVjR5maIGS8Snow5W2/oLKIH6qZN3Dmh\n\t\t\t\t\t\t4RbfL3IPjWNGqcLBZ5cR6B2b71BmEFowJ4RopV0uLd4yud0aVA33AuNHtt5FCbmx\n\t\t\t\t\t\t57UaykuwNUH0AUP0Mmhw0Unlh5C/SmrLRdeQxQpB3qWDNasgFMcvCet7jUP3Tje5\n\t\t\t\t\t\tLysqQdDV0iS5C7sWmAzVfwJ4oF+CgM6IrCobOf+45dEa7v5+ILDQEpYJJa5vYbvu\n\t\t\t\t\t\tzGxTWbH6Wt6QnJOFX3ZHVYMnh7gogu/vposOzgaJhFYu6ekCAwEAATANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAt2WPnd7BzzXgF7yd1qcPpYFcnx1eaFD5PHCqtSUtPM4tqmrT\n\t\t\t\t\t\tICM5ELCpwZYSZbyTm1MikC1um2U9tZIi780kZnjSSMff7YkiSCN3pEjjM8OaJtnO\n\t\t\t\t\t\t7NKT0bRrx5y0UlVI0D/It4AasMZCL4tJf7J74lbi/6WGMMPz3JMKSJlWSaBg9875\n\t\t\t\t\t\t0LiyYQ0LugAJYLzYvGjdzqg08QOZWnMgUB0clI8moXNLUiE8Q4VN12PJqugUuzEi\n\t\t\t\t\t\tt7IWhuOL2qj1e65huFQRUrHdvKsvm9+iydT7JkIMw0tUDO/uTPRl51QNYCP6aiC2\n\t\t\t\t\t\td88+xmq6gSOp+ZyGanKnNUHyRuukGiawzUDS5w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "West Nottinghamshire College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wnc.ac.uk/About-Us/The-College/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "West Nottinghamshire College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:feide.no:services:no.uio.galaxy-test",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Vazov"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "n.a.vazov@usit.uio.no"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nikolay"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:feide.no:services:no.uio.galaxy-test",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.feide.no/files/feide/metadata-registration-practice-statement.pdf"
              }
            ],
            "registration_instant": "2015-10-15T13:47:32Z",
            "registration_authority": "http://feide.no/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute_value": [
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "kalmar"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "norway"
              }
            ],
            "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
            "name": "tags",
            "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Oslo"
          },
          {
            "lang": "no",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universitet i Oslo"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uio.no/english/"
          },
          {
            "lang": "no",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uio.no/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Oslo"
          },
          {
            "lang": "no",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universitetet i Oslo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://galaxy-test.uio.no/user/logout_feide_user",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Galaxy server at UiO"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Galaxy Bioportal UiO test"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICbTCCAdYCCQDXiijSZIJdujANBgkqhkiG9w0BAQUFADB7MQswCQYDVQQGEwJO\nTzENMAsGA1UEBwwET3NsbzENMAsGA1UECgwEVVNJVDELMAkGA1UECwwCVkQxGzAZ\nBgNVBAMMEmdhbGF4eS10ZXN0LnVpby5ubzEkMCIGCSqGSIb3DQEJARYVbi5hLnZh\nem92QHVzaXQudWlvLm5vMB4XDTEzMDExNTEwNTAwM1oXDTI2MDkyNDEwNTAwM1ow\nezELMAkGA1UEBhMCTk8xDTALBgNVBAcMBE9zbG8xDTALBgNVBAoMBFVTSVQxCzAJ\nBgNVBAsMAlZEMRswGQYDVQQDDBJnYWxheHktdGVzdC51aW8ubm8xJDAiBgkqhkiG\n9w0BCQEWFW4uYS52YXpvdkB1c2l0LnVpby5ubzCBnzANBgkqhkiG9w0BAQEFAAOB\njQAwgYkCgYEAxhQJULqEK0BwR7N5r1VYHj1ZiGREBT9msBDDmMvU1p1UqWIUmLRy\nI/1pn775zdl9qjCQ7VTFjp3SkdZiEnjR4wOyFjpQzs/yneu3SAoFF/tRKrFoTgvt\njGOb3VDmKHGr1Ygb6wDMoit9rAXD+gM7sjO6TDU1C4l+E2Dk3lUln4UCAwEAATAN\nBgkqhkiG9w0BAQUFAAOBgQCqryzoZSredMYi1vLz6jg0TD9WdedYqVFdKWsmfxsb\n434A6SMEWkt3ql4s1bH3UD9IjK/+KuviVyka3pj3LW347bFOm2sEwwvVHGlAXbzx\nZFql6Vk1Bc+qGGOsgTK4pM3Xq/etRr0Fjp52YllAQC8DYEbo/UWf0HWGYLPTc4bb\nAg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICbTCCAdYCCQDXiijSZIJdujANBgkqhkiG9w0BAQUFADB7MQswCQYDVQQGEwJO\nTzENMAsGA1UEBwwET3NsbzENMAsGA1UECgwEVVNJVDELMAkGA1UECwwCVkQxGzAZ\nBgNVBAMMEmdhbGF4eS10ZXN0LnVpby5ubzEkMCIGCSqGSIb3DQEJARYVbi5hLnZh\nem92QHVzaXQudWlvLm5vMB4XDTEzMDExNTEwNTAwM1oXDTI2MDkyNDEwNTAwM1ow\nezELMAkGA1UEBhMCTk8xDTALBgNVBAcMBE9zbG8xDTALBgNVBAoMBFVTSVQxCzAJ\nBgNVBAsMAlZEMRswGQYDVQQDDBJnYWxheHktdGVzdC51aW8ubm8xJDAiBgkqhkiG\n9w0BCQEWFW4uYS52YXpvdkB1c2l0LnVpby5ubzCBnzANBgkqhkiG9w0BAQEFAAOB\njQAwgYkCgYEAxhQJULqEK0BwR7N5r1VYHj1ZiGREBT9msBDDmMvU1p1UqWIUmLRy\nI/1pn775zdl9qjCQ7VTFjp3SkdZiEnjR4wOyFjpQzs/yneu3SAoFF/tRKrFoTgvt\njGOb3VDmKHGr1Ygb6wDMoit9rAXD+gM7sjO6TDU1C4l+E2Dk3lUln4UCAwEAATAN\nBgkqhkiG9w0BAQUFAAOBgQCqryzoZSredMYi1vLz6jg0TD9WdedYqVFdKWsmfxsb\n434A6SMEWkt3ql4s1bH3UD9IjK/+KuviVyka3pj3LW347bFOm2sEwwvVHGlAXbzx\nZFql6Vk1Bc+qGGOsgTK4pM3Xq/etRr0Fjp52YllAQC8DYEbo/UWf0HWGYLPTc4bb\nAg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://galaxy-test.uio.no/user/feide_auth",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Galaxy Bioportal UiO test"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Galaxy server at UiO"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "cn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.aws.dev.progressivedigitalmedia.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sfikas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Panagiotis.Sfikas@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Panagiotis"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wafo-Tapa"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Dominique.Wafo-Tapa@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dominique"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hogg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ghogg@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Geoffrey"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Imran"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Assad.Imran@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Assad"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sfikas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Panagiotis.Sfikas@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Panagiotis"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wafo-Tapa"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Dominique.Wafo-Tapa@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dominique"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hogg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ghogg@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Geoffrey"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Imran"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Assad.Imran@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Assad"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.aws.dev.progressivedigitalmedia.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-01-19T09:55:25Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Marketline Advantage"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.progressivemediagroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GlobalData PLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.aws.dev.progressivedigitalmedia.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.aws.dev.progressivedigitalmedia.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.aws.dev.progressivedigitalmedia.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.aws.dev.progressivedigitalmedia.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.aws.dev.progressivedigitalmedia.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.aws.dev.progressivedigitalmedia.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth.aws.dev.progressivedigitalmedia.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.aws.dev.progressivedigitalmedia.com/Shibboleth.sso/UKfederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth.aws.dev.progressivedigitalmedia.com/Shibboleth.sso/UKfederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJAJ0anKvb8NpwMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXBkbS1kZXYtd2ViMDEwHhcNMTYwMTIyMTcxMTQ4WhcNMjYwMTE5MTcxMTQ4\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1wZG0tZGV2LXdlYjAxMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEA7FdrCgGZLid5434KxGyqa6VNLIV6wMy6YSBMkmDU0Zu1NdLH\n\t\t\t\t\t\tcmvQdgCQLalMYROs/gWNtI46zu1K9sLa04CFege3HKdTbNgYKEutm/PefmgpwocY\n\t\t\t\t\t\tVFaXmfjYwBBPnpNcJx4xOFAU/MBvbnbi13uXORBohpG3Ls6Pt1j9Iq29dKf9AwPY\n\t\t\t\t\t\t1wdkFPetgc4g+DagfOaCKLy3gUZM3TJrEwu2M6MgqSRE7azZKNXHH25SGcTFtTSB\n\t\t\t\t\t\toXv93omnYn3VyfbStqkbFjI61MgyE39ubs62qmgVq78HkDTYu5mNrocbVlbrfGke\n\t\t\t\t\t\tGPQ9xSXYvoEHcgpMZB8umh76cIRXtaerJQmLbwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1wZG0tZGV2LXdlYjAxMB0GA1UdDgQWBBRvGfAZty2hHkw+jYQqxVxihYrmTjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAWFzoOr6uoi0PwNcJxKUsr2lbYbJtigUC/IUA5Rnb\n\t\t\t\t\t\tg68H8dO8go/NWKppp88eEBpI8CGF9wssKX8J1XS0LYAaAHf4AZdUpOSS9Tjk3JlX\n\t\t\t\t\t\tYp4tGuyfr9nsbm2q3wBoY3vYEcj1pmqhcAfB+PSR2p9/h29Z0Xm1i2NMMXwjRHSf\n\t\t\t\t\t\tvg71L+mudKv/gxpX6mKct9mcFisyM1JDtPmO1Rhpqophe4D6Hjevy6tRl5xw2kNg\n\t\t\t\t\t\tddwE8o3bWp7Nvl+OuquXBPI2dLrDHL6mYaKW1AJteYgpxSsj4jw4KlugOlrcaYum\n\t\t\t\t\t\tlXL+Gte857dAAqPxxmXJdHnUDpWHAoIl9dSmoPTNpK9Yyw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.aws.dev.progressivedigitalmedia.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.aws.dev.progressivedigitalmedia.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.aws.dev.progressivedigitalmedia.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth.aws.dev.progressivedigitalmedia.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.aws.dev.progressivedigitalmedia.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.aws.dev.progressivedigitalmedia.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.silverchair.com/accp/development/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ShibbolethAdmin@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Laseter"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jlaseter@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Josh"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.silverchair.com/accp/development/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-06-08T08:24:40Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Silverchair Development: American College of Chest Physicians"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://accpdev.silverchair.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Silverchair Science + Communications, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://accpdev.silverchair.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://accpdev.silverchair.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://accpdev.silverchair.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://accpdev.silverchair.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://accpdev.silverchair.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://accpdev.silverchair.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAOnxeyETHXm1MA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\n\t\t\t\t\t\tBAMTD3Npc3dlYjEuc3NjLmludDAeFw0xMjA2MDUxNzU2NDNaFw0yMjA2MDMxNzU2\n\t\t\t\t\t\tNDNaMBoxGDAWBgNVBAMTD3Npc3dlYjEuc3NjLmludDCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBALL55DRPN6W6LC899+Z4S/wvZop4jMfn+8fyeuWrU4HO\n\t\t\t\t\t\tKVLk0zt8oG8KNff1eaU0SUshqbNDrotvDFrF67/CUvxTiju3TBAwCU9+1+ui9hG3\n\t\t\t\t\t\tRrB09ScBsMnODAIDEAPtPYXg5q2FDFRnO1mgT0/Kys4jlIujsYtPhVs+cMQl5mt6\n\t\t\t\t\t\tANH14RiICRPnuQM5xcsXe284Ry40E8vi5/yJcozV3DaRjnE17f9mAEsbWOB7kUDc\n\t\t\t\t\t\t9frQKlNH2x7CIjnku9FvjkqRyoGJKtdVoSP0Yh6RXuDwsjS9cXEodTkC5bwB2SLt\n\t\t\t\t\t\tWD1vMUuwwB7DqPOn21WxHZ+gM86ASHwVQp+rvyVkKQ0CAwEAAaM9MDswGgYDVR0R\n\t\t\t\t\t\tBBMwEYIPc2lzd2ViMS5zc2MuaW50MB0GA1UdDgQWBBTus065XW0fl57GPIa3yPRk\n\t\t\t\t\t\t3Y2igTANBgkqhkiG9w0BAQUFAAOCAQEAr5XZgVon2nogF3UL6P5b9kVURyaUQkK/\n\t\t\t\t\t\t2gITgZPyfSzPbcsaXptatkJY3l2Z3Au/gTbttZwFs6kr+B6q6OuNG4H9zyqxPZS4\n\t\t\t\t\t\tzlC2bag5nJ1CkLd2yRiMGp5o1s0lFLeHmhjtPJfLYOayXad/tMxaC+/dzlkOTgrc\n\t\t\t\t\t\tIYejATqDiN2j2OBZrExvo4VBaMVQK/xhIb8PiQZVPnTabOR0M6A4XKQUziCwvQ2M\n\t\t\t\t\t\taaNBHcUL8keqOTY8ysUEOR6KX85YvoGmqrqiCQqJHRPBQgoOuMgGK5iHg97hFk9g\n\t\t\t\t\t\tG7EPjuEL78uppkzFBJ0XRmOQ4YBUzYxYqxmwYElCO+/9bP+ETGAXBQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://accpdev.silverchair.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://accpdev.silverchair.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://accpdev.silverchair.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://accpdev.silverchair.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://accpdev.silverchair.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://accpdev.silverchair.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://akka-anv.uu.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://akka-anv.uu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://akka-anv.uu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://akka-anv.uu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://akka-anv.uu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://akka-anv.uu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "akka-anv.uu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJAN5oCkisOOXcMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDmFra2EtYW52LnV1LnNlMB4XDTEyMTAxMjA5NTY0NloXDTIyMTAxMDA5NTY0\nNlowGTEXMBUGA1UEAxMOYWtrYS1hbnYudXUuc2UwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQC9RBkxotLN9wNFPDlbM+HXCTFLC2rxdOI1McjZJjJ0MwJQ\nQhju2m8CB0lrTb22nHd7ITqtzhVBKXHY0rmCm7j5tlPCDcQqzgHbk2KR7lGEv5JK\noVXF7NdFRTxl393UX2a0+5aWUVsFrWIlHLK5ve+5HBdDUccWtX3XfR2HDcAvMNJB\nB2FuueVM6pwkNwsyNjDzJlrvtC3QsuLE4KdSjb2GGDg0xvIEgs+/d85JNk+yLhaa\n90zyQaw0L3OA7F8fX6EesiBg9tGirQcZ6cYHRVKuM1D4sO08iwRA0EA8iXnL34+5\nCaa/71lSR1Kzo1cluQKkzfob+9AzztZ3vdKxwNiLAgMBAAGjPDA6MBkGA1UdEQQS\nMBCCDmFra2EtYW52LnV1LnNlMB0GA1UdDgQWBBQFsDy6A2U1Zby9p6ijIsBxv3du\nAzANBgkqhkiG9w0BAQUFAAOCAQEAtOsbz5YiPiR9xoQbIRr9BV3+fIxw07MNI2tU\nouCtCW6wuFPvYARgGGCavPn/Hn2V0LWIo2VRpHizK9DbpFRU0ofvr3nJZKq+H45w\nWXmJLalTYyYnu6rwW7zmkbS30mMQ7J5aBawRNK5opSgbRp0eQt0ynyTgeJgqmACK\ngaUQmP5gD9lXDNdROqMjwANcMdU57NDRGWzASx01r+0LLaUX4NzTPlnOYldRPn0z\nJnhHj8Wsg0csCS86vOCTNXVKXHcRIUL5FaLf+8MrSHrs8WR4CN4AHLuprwthtQyV\n2nacKYU2Ke9STDjLkJSCmx/o8ZLfQPFLSCr1SjyYQzm21MOIZw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=akka-anv.uu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://akka-anv.uu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.puc-campinas.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Carlos Cesar Braga"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cesar@puc-campinas.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.puc-campinas.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEFDCCAvwCAQAwDQYJKoZIhvcNAQEFBQAwgc8xPDA6BgNVBAoTM1BVQ0MgLSBQ\nT05USUZJQ0lBIFVOSVZFUlNJREFERSBDQVRPTElDQSBERSBDQU1QSU5BUzENMAsG\nA1UECxMETlRJQzEqMCgGCSqGSIb3DQEJARYbdGVsZWNvbUBwdWMtY2FtcGluYXMu\nZWR1LmJyMREwDwYDVQQHEwhDQU1QSU5BUzESMBAGA1UECBMJU0FPIFBBVUxPMQsw\nCQYDVQQGEwJCUjEgMB4GA1UEAxMXaWRwLnB1Yy1jYW1waW5hcy5lZHUuYnIwHhcN\nMTQwNjA1MTQyOTE1WhcNMTkwNjA0MTQyOTE1WjCBzzE8MDoGA1UEChMzUFVDQyAt\nIFBPTlRJRklDSUEgVU5JVkVSU0lEQURFIENBVE9MSUNBIERFIENBTVBJTkFTMQ0w\nCwYDVQQLEwROVElDMSowKAYJKoZIhvcNAQkBFht0ZWxlY29tQHB1Yy1jYW1waW5h\ncy5lZHUuYnIxETAPBgNVBAcTCENBTVBJTkFTMRIwEAYDVQQIEwlTQU8gUEFVTE8x\nCzAJBgNVBAYTAkJSMSAwHgYDVQQDExdpZHAucHVjLWNhbXBpbmFzLmVkdS5icjCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALNo4ffCB7RXNl8+27biVdUU\ni8DdBAOm2d1yem94W/Bz29deIgpdXAtm+F9sugoPaHXdgKTqaoz8XOPLOkLH18hk\n5SlN96Qghp9VjW3Spx+kVU+SI1V0kw/L5Q7TBc1yq/bx29MKtIVCdaFdPqk99Xfx\nbSqX+bmXlUPVI6CTKf9cseQEmKop8aHKad8wKL6b6AH9IO2kfXbKIO7U0AEtnX4J\nknqIl4LHhykFA72Bkv9s5zaNVa4J9PykQKOHW3oIqZqYGyZVQOz7rV8wWxvBcHi5\nKdLal6phc3ecGZ5uBzRXhNY9iGgOch7IJihGvUKUT7MhU8EajCY7fxvglesV2rkC\nAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAiUQvx+gr71M1aU8WOW+vn91QDmWfU6yf\nVS/w4sRDpOyagvK59B42w9nMlCjPv9RQ07o0SFSAwELAd/PUIDh7cT7LUmPVqaWZ\nBZQArltphjHtpGOlPjSLIwbbCzToMRCpksnsM3w7Hu+yMI9AR8XCqw36PVKJSkOY\nRAac9Nwp2wbumAbKlymXLN1W7UUpMtp1Af7GhbO/aryiMktlOKUg3K15fOevZqsm\nTwNT0xF7TKbSHFN+g6zksLj0yAXD/ZSvwdV8OwzEtj+jBIfy2iFJz9I7cT/NRmLu\nmyTHlotGeDZJUn6x2TGCGQiNVu09lXCJBGqp4ffJGRACkMxOMqtwYw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.puc-campinas.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.puc-campinas.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.puc-campinas.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.puc-campinas.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.puc-campinas.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.puc-campinas.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.puc-campinas.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.puc-campinas.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.puc-campinas.edu.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.puc-campinas.edu.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "PUCC - Pontificia Universidade Catolica de Campinas"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "PUCC - Pontificia Universidade Catolica de Campinas"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PUCC - Pontificia Universidade Catolica de Campinas"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PUCC - Pontificia Universidade Catolica de Campinas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEFDCCAvwCAQAwDQYJKoZIhvcNAQEFBQAwgc8xPDA6BgNVBAoTM1BVQ0MgLSBQ\nT05USUZJQ0lBIFVOSVZFUlNJREFERSBDQVRPTElDQSBERSBDQU1QSU5BUzENMAsG\nA1UECxMETlRJQzEqMCgGCSqGSIb3DQEJARYbdGVsZWNvbUBwdWMtY2FtcGluYXMu\nZWR1LmJyMREwDwYDVQQHEwhDQU1QSU5BUzESMBAGA1UECBMJU0FPIFBBVUxPMQsw\nCQYDVQQGEwJCUjEgMB4GA1UEAxMXaWRwLnB1Yy1jYW1waW5hcy5lZHUuYnIwHhcN\nMTQwNjA1MTQyOTE1WhcNMTkwNjA0MTQyOTE1WjCBzzE8MDoGA1UEChMzUFVDQyAt\nIFBPTlRJRklDSUEgVU5JVkVSU0lEQURFIENBVE9MSUNBIERFIENBTVBJTkFTMQ0w\nCwYDVQQLEwROVElDMSowKAYJKoZIhvcNAQkBFht0ZWxlY29tQHB1Yy1jYW1waW5h\ncy5lZHUuYnIxETAPBgNVBAcTCENBTVBJTkFTMRIwEAYDVQQIEwlTQU8gUEFVTE8x\nCzAJBgNVBAYTAkJSMSAwHgYDVQQDExdpZHAucHVjLWNhbXBpbmFzLmVkdS5icjCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALNo4ffCB7RXNl8+27biVdUU\ni8DdBAOm2d1yem94W/Bz29deIgpdXAtm+F9sugoPaHXdgKTqaoz8XOPLOkLH18hk\n5SlN96Qghp9VjW3Spx+kVU+SI1V0kw/L5Q7TBc1yq/bx29MKtIVCdaFdPqk99Xfx\nbSqX+bmXlUPVI6CTKf9cseQEmKop8aHKad8wKL6b6AH9IO2kfXbKIO7U0AEtnX4J\nknqIl4LHhykFA72Bkv9s5zaNVa4J9PykQKOHW3oIqZqYGyZVQOz7rV8wWxvBcHi5\nKdLal6phc3ecGZ5uBzRXhNY9iGgOch7IJihGvUKUT7MhU8EajCY7fxvglesV2rkC\nAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAiUQvx+gr71M1aU8WOW+vn91QDmWfU6yf\nVS/w4sRDpOyagvK59B42w9nMlCjPv9RQ07o0SFSAwELAd/PUIDh7cT7LUmPVqaWZ\nBZQArltphjHtpGOlPjSLIwbbCzToMRCpksnsM3w7Hu+yMI9AR8XCqw36PVKJSkOY\nRAac9Nwp2wbumAbKlymXLN1W7UUpMtp1Af7GhbO/aryiMktlOKUg3K15fOevZqsm\nTwNT0xF7TKbSHFN+g6zksLj0yAXD/ZSvwdV8OwzEtj+jBIfy2iFJz9I7cT/NRmLu\nmyTHlotGeDZJUn6x2TGCGQiNVu09lXCJBGqp4ffJGRACkMxOMqtwYw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PUCC - Pontificia Universidade Catolica de Campinas"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PUCC - Pontificia Universidade Catolica de Campinas"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.puc-campinas.edu.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.puc-campinas.edu.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "PUCC - Pontificia Universidade Catolica de Campinas"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "PUCC - Pontificia Universidade Catolica de Campinas"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp-test.ucs.ed.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "shibboleth@ed.ac.uk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "shibboleth@ed.ac.uk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-test.ucs.ed.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-04-30T17:05:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVANRDl0zVDHZ6OYfXOdpdFYUK94KWMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCAxHjAcBgNVBAMTFWlkcC10ZXN0LnVjcy5lZC5hYy51azAeFw0xMTA4MTcw\n\t\t\t\t\t\tODQ4NDRaFw0zMTA4MTcwODQ4NDRaMCAxHjAcBgNVBAMTFWlkcC10ZXN0LnVjcy5l\n\t\t\t\t\t\tZC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKk0/tK2QdQr\n\t\t\t\t\t\tT72QiLa3ntSOTJGlFEGDuwAAnhOXxH6T2+4oqy3QsoUCgI+6f4J8meXYmuCpOIHh\n\t\t\t\t\t\tBrTv32n9SYgXI+KE40BLSym0ToGzWdz+fZAU+IHaX6gixQRjQdYTPPefDCfeLk3U\n\t\t\t\t\t\tKTFpHZCK5tMJYiflwS/X7abnOF/yNypoeB3ZpI13qbHV+I5v8iHz6lxs8V2yutXE\n\t\t\t\t\t\tsrjCB+YKVuB5dyVU5ettupnpDQI7vzl3QzHVTm46NoT0MiGS3FH+Xkr/zDXl6ynr\n\t\t\t\t\t\tFxkg322Re8D3U1XzQTC/rP4WMqx0cc9Im3JaAf7happqm9fDJqeMdxodKqdgAMDI\n\t\t\t\t\t\tdH1R1b4lyfUCAwEAAaNxMG8wTgYDVR0RBEcwRYIVaWRwLXRlc3QudWNzLmVkLmFj\n\t\t\t\t\t\tLnVrhixodHRwczovL2lkcC10ZXN0LnVjcy5lZC5hYy51ay9pZHAvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQUcMIFOHTjJnX/8pzUK1pZ+4jarLQwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAI6diGFybO93xeSV7Ww2N8thw3KZrSKou+SASMkCENS81L2Z2f0c9sAmpWZN\n\t\t\t\t\t\t8Ewi3i7iPcGOvzxD8WQ6sY+roCvgbPJz/CY0NafC1OwJvZwYrv5MBRvWblilkGAr\n\t\t\t\t\t\tjHp3oD7zQUgx7UsBSOFEnpVlY/JmXmhXYSwIZcSA6ShmyQTo+TRbM206gGCu6R4C\n\t\t\t\t\t\tdB+g+QtBW0jl56x/wf7d86zb1KGp4f9/UalrP+7RCkQBqkGqZC714/Ib/GURnDSP\n\t\t\t\t\t\tMJIL1EfWROWJ0aNTNs6IIU35GiQkDotZL4p43FpksZ6KATV6SDVlCF9b5xFvhZpb\n\t\t\t\t\t\tZMO08Pnpl7xrrBG2Gw7MPizq7c4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ed.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-test.ucs.ed.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-test.ucs.ed.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-test.ucs.ed.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-test.ucs.ed.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-test.ucs.ed.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-test.ucs.ed.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-test.ucs.ed.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-test.ucs.ed.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ed.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVANRDl0zVDHZ6OYfXOdpdFYUK94KWMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCAxHjAcBgNVBAMTFWlkcC10ZXN0LnVjcy5lZC5hYy51azAeFw0xMTA4MTcw\n\t\t\t\t\t\tODQ4NDRaFw0zMTA4MTcwODQ4NDRaMCAxHjAcBgNVBAMTFWlkcC10ZXN0LnVjcy5l\n\t\t\t\t\t\tZC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKk0/tK2QdQr\n\t\t\t\t\t\tT72QiLa3ntSOTJGlFEGDuwAAnhOXxH6T2+4oqy3QsoUCgI+6f4J8meXYmuCpOIHh\n\t\t\t\t\t\tBrTv32n9SYgXI+KE40BLSym0ToGzWdz+fZAU+IHaX6gixQRjQdYTPPefDCfeLk3U\n\t\t\t\t\t\tKTFpHZCK5tMJYiflwS/X7abnOF/yNypoeB3ZpI13qbHV+I5v8iHz6lxs8V2yutXE\n\t\t\t\t\t\tsrjCB+YKVuB5dyVU5ettupnpDQI7vzl3QzHVTm46NoT0MiGS3FH+Xkr/zDXl6ynr\n\t\t\t\t\t\tFxkg322Re8D3U1XzQTC/rP4WMqx0cc9Im3JaAf7happqm9fDJqeMdxodKqdgAMDI\n\t\t\t\t\t\tdH1R1b4lyfUCAwEAAaNxMG8wTgYDVR0RBEcwRYIVaWRwLXRlc3QudWNzLmVkLmFj\n\t\t\t\t\t\tLnVrhixodHRwczovL2lkcC10ZXN0LnVjcy5lZC5hYy51ay9pZHAvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQUcMIFOHTjJnX/8pzUK1pZ+4jarLQwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAI6diGFybO93xeSV7Ww2N8thw3KZrSKou+SASMkCENS81L2Z2f0c9sAmpWZN\n\t\t\t\t\t\t8Ewi3i7iPcGOvzxD8WQ6sY+roCvgbPJz/CY0NafC1OwJvZwYrv5MBRvWblilkGAr\n\t\t\t\t\t\tjHp3oD7zQUgx7UsBSOFEnpVlY/JmXmhXYSwIZcSA6ShmyQTo+TRbM206gGCu6R4C\n\t\t\t\t\t\tdB+g+QtBW0jl56x/wf7d86zb1KGp4f9/UalrP+7RCkQBqkGqZC714/Ib/GURnDSP\n\t\t\t\t\t\tMJIL1EfWROWJ0aNTNs6IIU35GiQkDotZL4p43FpksZ6KATV6SDVlCF9b5xFvhZpb\n\t\t\t\t\t\tZMO08Pnpl7xrrBG2Gw7MPizq7c4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Edinburgh: V2 TEST"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.truro-penwith.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Stephens"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:roberts@truro-penwith.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Stephens"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:roberts@truro-penwith.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.truro-penwith.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-07-24T12:37:39Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZTCCAk2gAwIBAgIUVIqVGTLdOThvAs45mIha28LOG0cwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwKTEnMCUGA1UEAxMec2hpYmJvbGV0aC50cnVyby1wZW53aXRoLmFjLnVrMB4X\n\t\t\t\t\t\tDTEzMDcyNTA5MjU1OFoXDTMzMDcyNTA5MjU1OFowKTEnMCUGA1UEAxMec2hpYmJv\n\t\t\t\t\t\tbGV0aC50cnVyby1wZW53aXRoLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\n\t\t\t\t\t\tMIIBCgKCAQEAjNqa9ASmhvPnSc/Sg2TXmSShKIwWmTXV7eNgqQY/yacb2zrsWJes\n\t\t\t\t\t\tFx/hGQ2GADV/+PWyHNT208q0Bb7IsutKLSRCntKKB8FPREaSTRO8QVkEpDAuakpR\n\t\t\t\t\t\tm9B/Q1z0+HGVlGc6ZifDgChxZYYlOxr8CyGk9r5xNu28KnQsjUodwEPW7Xv5tjaH\n\t\t\t\t\t\tUkg9ZI8UpYkxYKt9yQj+KdfV5g0BiUkaKTRIQ+20L5ohFYweuH2DKTOv48td7bMa\n\t\t\t\t\t\tY5MRpabacOhJOs+Pt6AKToGcmM+gEhib0fifhdMg2Qf77dZ3miuI+8sjIZFuttyQ\n\t\t\t\t\t\tSKeWWJgnpka95I0m8hfr/DxzkSPIHzJFbQIDAQABo4GEMIGBMGAGA1UdEQRZMFeC\n\t\t\t\t\t\tHnNoaWJib2xldGgudHJ1cm8tcGVud2l0aC5hYy51a4Y1aHR0cHM6Ly9zaGliYm9s\n\t\t\t\t\t\tZXRoLnRydXJvLXBlbndpdGguYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYE\n\t\t\t\t\t\tFPe307YqPO7BPihGONrKkqFzgZCDMA0GCSqGSIb3DQEBBQUAA4IBAQCL0w8cTddh\n\t\t\t\t\t\tiqoUJu/oGOju7URDWO+YwIjJV+tWEf8lC0nGnPehoaYitXDexoNNZ9yqEJ3XhrTF\n\t\t\t\t\t\tgTNtJfRPnT9RZ0e+dbJu/f68HKLkv798yy14wgv6m20miPvY14OhlTT2mUcUuhz0\n\t\t\t\t\t\tm29Yd8Kg1MIDcH1Me7SVAvJex0uaDn0J74dNJofWxeCRv4+rlMuDQa2NL2sJ6GL0\n\t\t\t\t\t\toZnqLAehosKei0nPPNYFE4aa+L/V6BSDs7hqimBf6oFt4qDqOeGgfAZeuWdqCYDN\n\t\t\t\t\t\tkUAJtuR24UgajKJGGInWVDBNlXJMCNyAVoSevzXTO6Dp+XDyDdOY/Dt8MMSvKPc4\n\t\t\t\t\t\tSZjtHVMDghth"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "truro-penwith.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.truro-penwith.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.truro-penwith.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.truro-penwith.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.truro-penwith.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.truro-penwith.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.truro-penwith.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.truro-penwith.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.truro-penwith.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "truro-penwith.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZTCCAk2gAwIBAgIUVIqVGTLdOThvAs45mIha28LOG0cwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwKTEnMCUGA1UEAxMec2hpYmJvbGV0aC50cnVyby1wZW53aXRoLmFjLnVrMB4X\n\t\t\t\t\t\tDTEzMDcyNTA5MjU1OFoXDTMzMDcyNTA5MjU1OFowKTEnMCUGA1UEAxMec2hpYmJv\n\t\t\t\t\t\tbGV0aC50cnVyby1wZW53aXRoLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\n\t\t\t\t\t\tMIIBCgKCAQEAjNqa9ASmhvPnSc/Sg2TXmSShKIwWmTXV7eNgqQY/yacb2zrsWJes\n\t\t\t\t\t\tFx/hGQ2GADV/+PWyHNT208q0Bb7IsutKLSRCntKKB8FPREaSTRO8QVkEpDAuakpR\n\t\t\t\t\t\tm9B/Q1z0+HGVlGc6ZifDgChxZYYlOxr8CyGk9r5xNu28KnQsjUodwEPW7Xv5tjaH\n\t\t\t\t\t\tUkg9ZI8UpYkxYKt9yQj+KdfV5g0BiUkaKTRIQ+20L5ohFYweuH2DKTOv48td7bMa\n\t\t\t\t\t\tY5MRpabacOhJOs+Pt6AKToGcmM+gEhib0fifhdMg2Qf77dZ3miuI+8sjIZFuttyQ\n\t\t\t\t\t\tSKeWWJgnpka95I0m8hfr/DxzkSPIHzJFbQIDAQABo4GEMIGBMGAGA1UdEQRZMFeC\n\t\t\t\t\t\tHnNoaWJib2xldGgudHJ1cm8tcGVud2l0aC5hYy51a4Y1aHR0cHM6Ly9zaGliYm9s\n\t\t\t\t\t\tZXRoLnRydXJvLXBlbndpdGguYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYE\n\t\t\t\t\t\tFPe307YqPO7BPihGONrKkqFzgZCDMA0GCSqGSIb3DQEBBQUAA4IBAQCL0w8cTddh\n\t\t\t\t\t\tiqoUJu/oGOju7URDWO+YwIjJV+tWEf8lC0nGnPehoaYitXDexoNNZ9yqEJ3XhrTF\n\t\t\t\t\t\tgTNtJfRPnT9RZ0e+dbJu/f68HKLkv798yy14wgv6m20miPvY14OhlTT2mUcUuhz0\n\t\t\t\t\t\tm29Yd8Kg1MIDcH1Me7SVAvJex0uaDn0J74dNJofWxeCRv4+rlMuDQa2NL2sJ6GL0\n\t\t\t\t\t\toZnqLAehosKei0nPPNYFE4aa+L/V6BSDs7hqimBf6oFt4qDqOeGgfAZeuWdqCYDN\n\t\t\t\t\t\tkUAJtuR24UgajKJGGInWVDBNlXJMCNyAVoSevzXTO6Dp+XDyDdOY/Dt8MMSvKPc4\n\t\t\t\t\t\tSZjtHVMDghth"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Truro and Penwith College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.truro-penwith.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Truro and Penwith College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.stratford.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sparkes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nicolasparkes@stratford.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nicola"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Morris"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:richardmorris@stratford.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.stratford.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-09-08T17:41:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUHUDFCEinVS2/oqpWRjzbVISrlKIwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHjEcMBoGA1UEAwwTaWRwLnN0cmF0Zm9yZC5hYy51azAeFw0xNDA4MTkxNDM2\n\t\t\t\t\t\tMzFaFw0zNDA4MTkxNDM2MzFaMB4xHDAaBgNVBAMME2lkcC5zdHJhdGZvcmQuYWMu\n\t\t\t\t\t\tdWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCv6gdMgmB2bhP5Tqbp\n\t\t\t\t\t\t3XC7EkL7NXTsg+bMwg8G7GjNfNsVPv7MO773+zRXrvUYdBvPSQLOcKw9JvpYvrAh\n\t\t\t\t\t\tzOuZLME8rxoTD6ejNRC9IFsOI02eQ87qJ1jCOqFjPjn9N7V1QDKjRfx/6F1XNuZ8\n\t\t\t\t\t\tv8L0hwc4/6moj4mIr7RhxgUt4fj/KHZbaxnGw1ix3GTUpa1UNZvF5HsbXVknogyQ\n\t\t\t\t\t\tSFeWYPEMhUaSmUcD5KLCuovvXU1s5JB79V4+BRJIsxRt+tD6BcM6cQnLux+N3rXQ\n\t\t\t\t\t\tRx4IFUKRWv3KRzXEo6s8LapGk8Pr4/lTgFSjd+oIzOpqZSHgNmnhHvAKl/HG+jsD\n\t\t\t\t\t\tv/KPAgMBAAGjbTBrMB0GA1UdDgQWBBSTmgz2ydW2bFqPFjRPfX/MeU0kcDBKBgNV\n\t\t\t\t\t\tHREEQzBBghNpZHAuc3RyYXRmb3JkLmFjLnVrhipodHRwczovL2lkcC5zdHJhdGZv\n\t\t\t\t\t\tcmQuYWMudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEFBQADggEBABDOMGaU\n\t\t\t\t\t\t4H1UYggkzWnhqlIk1gd/wWWS86W6uzPKmaXfhym7bAZf8Y6aL6n0XrM3zp+zclCR\n\t\t\t\t\t\tM9qG8+Kzg7InCs8WEH3xlCsIi1HAjjfCUN29RsJ9yCnRpV5h2b0pIYEUT02Kw8N2\n\t\t\t\t\t\tkH/FMfEgOmKsUmKmYamCu5lBHU2inYFEJXkiisCoLQjXnws3wpCJLfKMN567rJlu\n\t\t\t\t\t\tOjJYfYtmKTXwc/VqRkUFGQWu5GP9hgGPC0wcWHr6Vspqa8eMZDF4CY5EAD9kTWB7\n\t\t\t\t\t\tFWoWYXavsqXe6P6DUNnqnBUhicJtx+YalauPcXILOZEuGU7fY0qk1fDwRQemMEDJ\n\t\t\t\t\t\tTOavKjmM2o9UJkU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stratford.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.stratford.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.stratford.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.stratford.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.stratford.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.stratford.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.stratford.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.stratford.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.stratford.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stratford.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUHUDFCEinVS2/oqpWRjzbVISrlKIwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHjEcMBoGA1UEAwwTaWRwLnN0cmF0Zm9yZC5hYy51azAeFw0xNDA4MTkxNDM2\n\t\t\t\t\t\tMzFaFw0zNDA4MTkxNDM2MzFaMB4xHDAaBgNVBAMME2lkcC5zdHJhdGZvcmQuYWMu\n\t\t\t\t\t\tdWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCv6gdMgmB2bhP5Tqbp\n\t\t\t\t\t\t3XC7EkL7NXTsg+bMwg8G7GjNfNsVPv7MO773+zRXrvUYdBvPSQLOcKw9JvpYvrAh\n\t\t\t\t\t\tzOuZLME8rxoTD6ejNRC9IFsOI02eQ87qJ1jCOqFjPjn9N7V1QDKjRfx/6F1XNuZ8\n\t\t\t\t\t\tv8L0hwc4/6moj4mIr7RhxgUt4fj/KHZbaxnGw1ix3GTUpa1UNZvF5HsbXVknogyQ\n\t\t\t\t\t\tSFeWYPEMhUaSmUcD5KLCuovvXU1s5JB79V4+BRJIsxRt+tD6BcM6cQnLux+N3rXQ\n\t\t\t\t\t\tRx4IFUKRWv3KRzXEo6s8LapGk8Pr4/lTgFSjd+oIzOpqZSHgNmnhHvAKl/HG+jsD\n\t\t\t\t\t\tv/KPAgMBAAGjbTBrMB0GA1UdDgQWBBSTmgz2ydW2bFqPFjRPfX/MeU0kcDBKBgNV\n\t\t\t\t\t\tHREEQzBBghNpZHAuc3RyYXRmb3JkLmFjLnVrhipodHRwczovL2lkcC5zdHJhdGZv\n\t\t\t\t\t\tcmQuYWMudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEFBQADggEBABDOMGaU\n\t\t\t\t\t\t4H1UYggkzWnhqlIk1gd/wWWS86W6uzPKmaXfhym7bAZf8Y6aL6n0XrM3zp+zclCR\n\t\t\t\t\t\tM9qG8+Kzg7InCs8WEH3xlCsIi1HAjjfCUN29RsJ9yCnRpV5h2b0pIYEUT02Kw8N2\n\t\t\t\t\t\tkH/FMfEgOmKsUmKmYamCu5lBHU2inYFEJXkiisCoLQjXnws3wpCJLfKMN567rJlu\n\t\t\t\t\t\tOjJYfYtmKTXwc/VqRkUFGQWu5GP9hgGPC0wcWHr6Vspqa8eMZDF4CY5EAD9kTWB7\n\t\t\t\t\t\tFWoWYXavsqXe6P6DUNnqnBUhicJtx+YalauPcXILOZEuGU7fY0qk1fDwRQemMEDJ\n\t\t\t\t\t\tTOavKjmM2o9UJkU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Stratford-upon-Avon College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.stratford.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Stratford-upon-Avon College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-10.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-10.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;10"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;10"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-10.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-10.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAMWbtSdAnrAVMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0xMC5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTQ0MzE4WhcNMjQx\nMDA0MTQ0MzE4WjAhMR8wHQYDVQQDExZsYWRvazMtMTAubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnDpADu728OIV57+XopAF7/6A\n0a26Wa8qO0WS4hsIcqPdkIq27kPgsPbm7sh1pKBAQ/BG3wCFSvc3t15ul8NxckCI\nbd4miJxPTP6AIAw3h0WAKGWYmVBKXodhW2PLwkS+bmUva6z2xncWG8/jXsTxPdJK\nilx+SnLgHgCbUOxOdWgc8TZI2sGpC/8S+wrxiY21/mueg4jMzq4tlTz7L+5bJvoH\nom+qi42iUPYWdbqPXgZx79NjAyA0c82lzbMiwG2OCcPrA0DjajyIsm2c3vpddTMK\nE7ErtBkctwPGZDjypQz7pmIrYoA+O3CO5VdUJfmUFr/NEPo1Oh/QnKU40D6i6wID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMTAubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0xMC5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUAkkqvZzOBJ82CEDGCrZQnN1is8EwDQYJKoZIhvcNAQEFBQADggEB\nAEq9QB0UetFzg9pXEXPwlpT6Fc15uF5bRxmRMrqi4Sbv7XUBZzBIxmJYdFqzJd50\nnSBzBJ2qDrtkK2FMRQwWNwo86XGdyiufQMlwzkIE0dKBkzHIi+Zqbwp8yGV4ezR4\ntwW+VeeLOfAYUdGNQy3aB40c2E1uekz+rOxpGyas0Uhjf97HT6r3ydGYK2gpv3kt\nZZUz8BdNuajMBgDmW3z2BHnhALPtNBIxNF+8fhUEfFUfjGRvd20Kj5BybjyX+HP1\n6Dl6Et7Dxr9UooyconthAy8uqv4R9aCr+FkFIR1QWbg2rfnR6FVnJ+D9LL4l0JkG\n7qpp/QqMhIdfb1k6Z+/eZzM="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-10.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://student.grayzone.ladok.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://student.grayzone.ladok.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.grayzone.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.grayzone.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.grayzone.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.grayzone.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.grayzone.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://student.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://student.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://student.grayzone.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok student.grayzone.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok student.grayzone.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://student.grayzone.ladok.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "student.grayzone.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIJAIGkX/wOfnFpMA0GCSqGSIb3DQEBCwUAMCQxIjAgBgNV\nBAMTGXN0dWRlbnQuZ3JheXpvbmUubGFkb2suc2UwHhcNMTYwMzE0MTE0NjUyWhcN\nMjYwMzEyMTE0NjUyWjAkMSIwIAYDVQQDExlzdHVkZW50LmdyYXl6b25lLmxhZG9r\nLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA7EZ6ip4ed9S31sHM\nkn3u3Jt7CzPEhlhY6pIG3N/hIkeUeZns49ga3WCxr7mSsYmMLOkK/WmOmgRr6X7I\nr4zwwGaFxHuyBifOEn8pbBF9+NZU2odYAqjXCwTTgI7Dv7oOEnI83Qvpwsfvu/B/\nZ9cvgpWWmK9IWDlgdrJstC9m3y4LkeTpbWfRnJfvl8nSl9woDoUE0sc9BqKGXJIF\nEUepi55j51lHA66q1HU5G2rcDWXtC1zZ0b7qmsIRD16TMqODgwsOAdZF33LHxp2b\nlLONXk001RzjUi3b4CNVm+PNXzCwibQSwmxJNQdtBPk0acFnSgRZX2c0hBSwvAg+\nqJooXwIDAQABo3EwbzBOBgNVHREERzBFghlzdHVkZW50LmdyYXl6b25lLmxhZG9r\nLnNlhihodHRwczovL3N0dWRlbnQuZ3JheXpvbmUubGFkb2suc2UvZ3VpLXNwMB0G\nA1UdDgQWBBSI2f1Krb20gR6VnpnH61B1vycoBTANBgkqhkiG9w0BAQsFAAOCAQEA\nK/pOvQFHi38hPYPWCZwOxfTGVye9orF5FSajYCyucrQLZhoDdj4e4gll/p33dHd8\nMevGPBcHvab4OetEonqLyTnauaGcummYfbu71SN+3cuyKuMuLuS6r6zjg4urKLTB\n+T/ludsssL8Kh9JcZ9KNrCh6slW64WrvCs2/oZRBq6AK8S+1JxJWq25ooboaVxu+\niL8W9vWi42ftSllQFlfaco3PwqFLyaLhI1Yf4BDQEPwVmliCRiLAOVMsF9Edfxr4\n3f0CFDF8FL3zPA2piWosG7hrENU5gNTWU4NW5J9PL9ElZNvcovBC2CMuz9W5Cciu\nSDtqcg4gkoVpkscIiQGWrw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=student.grayzone.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.grayzone.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.grayzone.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.grayzone.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.grayzone.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.grayzone.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.grayzone.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://student.grayzone.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://student.grayzone.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://student.grayzone.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://subscription.echalk.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@echalk.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "eChalk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@echalk.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "eChalk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://subscription.echalk.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "eChalk: Interactive resources for whole-class teaching"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.echalk.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "eChalk Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://subscription.echalk.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://subscription.echalk.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://subscription.echalk.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://subscription.echalk.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://subscription.echalk.co.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUjCCAjqgAwIBAgIJAIxk1ZoatOwHMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\n\t\t\t\t\t\tBAMTGXN1YnNjcmlwdGlvbi5lY2hhbGsuY28udWswHhcNMDkwODE0MTAyNDMyWhcN\n\t\t\t\t\t\tMTkwODEyMTAyNDMyWjAkMSIwIAYDVQQDExlzdWJzY3JpcHRpb24uZWNoYWxrLmNv\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA284/+4DBsyk67HOJ\n\t\t\t\t\t\tptE1JK2ntKVDgjUzGlqIdLGepXJEpWL6JEoMA0f2V+TI2GzhcXPUa3Refysqj9Yo\n\t\t\t\t\t\tv+3Fo6jc8yMUz6PlMkRaOQH/0v5dTCCZIhaqDzBOI5XFCo/nTONY10oSDT59ypRZ\n\t\t\t\t\t\t/fRWCLHPBRtWYQuKQeFadyFH6Ox4kjfANiykpzHYu+kzOStUsOF4hulZ4p5q4WoB\n\t\t\t\t\t\to/tnmCJuZO+wViVZw2P/KF1R4vFsEUiD7sFoFU/+zOyKoS4eC+cCcMBxXu9CsRaS\n\t\t\t\t\t\tyk+5Ob1wSjDooOdd8pRBsAkuYMxzdv0d+uMznwhiybjlMj8Mk6OFswsHMo4B/moW\n\t\t\t\t\t\tF2s7gQIDAQABo4GGMIGDMB0GA1UdDgQWBBQrvG0acEEnI7JXqoFYdrzLC171EzBU\n\t\t\t\t\t\tBgNVHSMETTBLgBQrvG0acEEnI7JXqoFYdrzLC171E6EopCYwJDEiMCAGA1UEAxMZ\n\t\t\t\t\t\tc3Vic2NyaXB0aW9uLmVjaGFsay5jby51a4IJAIxk1ZoatOwHMAwGA1UdEwQFMAMB\n\t\t\t\t\t\tAf8wDQYJKoZIhvcNAQEFBQADggEBAHGSPPNL5RZ8hIzclnzlF0kgBZqIdY6pMvBk\n\t\t\t\t\t\t+ftUmpI6NRkPsY1TI/k7SPYcAOcS+ujPUzrX7nnoosXRZ+z2WmA2Oyd+HTqnw83r\n\t\t\t\t\t\tGdJflkPCAiKRkmBC7uJGdBP9AR+fTQeBZdbf7DbKQjmpkxjfhPaDM/3Oi69E/jli\n\t\t\t\t\t\t+YM0f4JcfJWcxEPKRGDSpCkR/idaQZkVDc22T7lq7sOMlKVtS0bg02IjvSf9teJp\n\t\t\t\t\t\tyLoqT2I7utT6SVExQtH+R3jpEPqKRR2/ct8B9Yc+MaaWwU2CTYsvDydLgGgp7Ar/\n\t\t\t\t\t\tj4zX/I526fHsI+R5AO9HpeyqGRBhxBBsymL4bb9BZ/Ew43NokdM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUjCCAjqgAwIBAgIJAIxk1ZoatOwHMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\n\t\t\t\t\t\tBAMTGXN1YnNjcmlwdGlvbi5lY2hhbGsuY28udWswHhcNMDkwODE0MTAyNDMyWhcN\n\t\t\t\t\t\tMTkwODEyMTAyNDMyWjAkMSIwIAYDVQQDExlzdWJzY3JpcHRpb24uZWNoYWxrLmNv\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA284/+4DBsyk67HOJ\n\t\t\t\t\t\tptE1JK2ntKVDgjUzGlqIdLGepXJEpWL6JEoMA0f2V+TI2GzhcXPUa3Refysqj9Yo\n\t\t\t\t\t\tv+3Fo6jc8yMUz6PlMkRaOQH/0v5dTCCZIhaqDzBOI5XFCo/nTONY10oSDT59ypRZ\n\t\t\t\t\t\t/fRWCLHPBRtWYQuKQeFadyFH6Ox4kjfANiykpzHYu+kzOStUsOF4hulZ4p5q4WoB\n\t\t\t\t\t\to/tnmCJuZO+wViVZw2P/KF1R4vFsEUiD7sFoFU/+zOyKoS4eC+cCcMBxXu9CsRaS\n\t\t\t\t\t\tyk+5Ob1wSjDooOdd8pRBsAkuYMxzdv0d+uMznwhiybjlMj8Mk6OFswsHMo4B/moW\n\t\t\t\t\t\tF2s7gQIDAQABo4GGMIGDMB0GA1UdDgQWBBQrvG0acEEnI7JXqoFYdrzLC171EzBU\n\t\t\t\t\t\tBgNVHSMETTBLgBQrvG0acEEnI7JXqoFYdrzLC171E6EopCYwJDEiMCAGA1UEAxMZ\n\t\t\t\t\t\tc3Vic2NyaXB0aW9uLmVjaGFsay5jby51a4IJAIxk1ZoatOwHMAwGA1UdEwQFMAMB\n\t\t\t\t\t\tAf8wDQYJKoZIhvcNAQEFBQADggEBAHGSPPNL5RZ8hIzclnzlF0kgBZqIdY6pMvBk\n\t\t\t\t\t\t+ftUmpI6NRkPsY1TI/k7SPYcAOcS+ujPUzrX7nnoosXRZ+z2WmA2Oyd+HTqnw83r\n\t\t\t\t\t\tGdJflkPCAiKRkmBC7uJGdBP9AR+fTQeBZdbf7DbKQjmpkxjfhPaDM/3Oi69E/jli\n\t\t\t\t\t\t+YM0f4JcfJWcxEPKRGDSpCkR/idaQZkVDc22T7lq7sOMlKVtS0bg02IjvSf9teJp\n\t\t\t\t\t\tyLoqT2I7utT6SVExQtH+R3jpEPqKRR2/ct8B9Yc+MaaWwU2CTYsvDydLgGgp7Ar/\n\t\t\t\t\t\tj4zX/I526fHsI+R5AO9HpeyqGRBhxBBsymL4bb9BZ/Ew43NokdM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://subscription.echalk.co.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://subscription.echalk.co.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://subscription.echalk.co.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://subscription.echalk.co.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://subscription.echalk.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://subscription.echalk.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://subscription.echalk.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://subscription.echalk.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://subscription.echalk.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://subscription.echalk.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:feide.no:services:com.itslearning",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@itslearning.com"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "itslearning"
          },
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "itslearning Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:feide.no:services:com.itslearning",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.feide.no/files/feide/metadata-registration-practice-statement.pdf"
              }
            ],
            "registration_instant": "2012-01-30T11:46:56Z",
            "registration_authority": "http://feide.no/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute_value": [
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "kalmar"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "norway"
              }
            ],
            "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
            "name": "tags",
            "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "itslearning"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.itslearning.eu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "itslearning"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.itslearning.com/elogin/logout.aspx",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "itslearning"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "itslearning is a virtual learning environment specifically designed for schools and universities."
                },
                {
                  "lang": "no",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "itslearning er et virtuelt l\u00e6ringsmilj\u00f8, spesielt utformet for skoler og universiteter."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.itslearning.com/elogin/default.aspx",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cerealchemistry.aaccnet.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "SSO-Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "SSO-Tech"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cerealchemistry.aaccnet.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-03-10T10:52:28Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "AACCI Grain Science Online Library"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aaccnet.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://cerealchemistry.aaccnet.org/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cerealchemistry.aaccnet.org/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cerealchemistry.aaccnet.org/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIJAOPdBcTdt8SCMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\n\t\t\t\t\t\tBAMTG2NlcmVhbGNoZW1pc3RyeS5hYWNjbmV0Lm9yZzAeFw0xNDAzMTQwNTAzMTNa\n\t\t\t\t\t\tFw0xNzAzMTMwNTAzMTNaMCYxJDAiBgNVBAMTG2NlcmVhbGNoZW1pc3RyeS5hYWNj\n\t\t\t\t\t\tbmV0Lm9yZzCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOfS4gn3WScE\n\t\t\t\t\t\tYsIzNB26nqXjCcCg+lq+vMJE6zrJLiyxKDsHDJ7eE1QNDHzGj45NVSiEG/h3qWC+\n\t\t\t\t\t\tanvXuMrkRq53OWy3QCdtYPYDeN4kuMZktGkJKllvYF14rKn82xvg9yUB5XoiIOoj\n\t\t\t\t\t\t+JtFqr1FD/udHow2uXwNHVkU2rCjYkAcDdlIp504ZjqDBZgzTcFP3PyJae2WQWzf\n\t\t\t\t\t\t0sHRRbBQJxL2I/gzhBwvyuVhjk3akNkWna83rhDJnP8HdZW+7YBrBbjoGQ3QvNWL\n\t\t\t\t\t\tPbFHHtFF4ACLpCLg5/b9nDyehDIYuVic2LGbAGvwD0reX7dkJG+DDagvEnKm5jC2\n\t\t\t\t\t\trmrgoEvhy2UCAwEAAaN5MHcwVgYDVR0RBE8wTYIbY2VyZWFsY2hlbWlzdHJ5LmFh\n\t\t\t\t\t\tY2NuZXQub3Jnhi5odHRwczovL2NlcmVhbGNoZW1pc3RyeS5hYWNjbmV0Lm9yZy9z\n\t\t\t\t\t\taGliYm9sZXRoMB0GA1UdDgQWBBTxd3A8HN1LUDntyh4JNI44mwmQ8jANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAuKmFpPiWz6WAjz2cvsvRsDV6ulDfEU4owYYoqZEa8bAgz5Am\n\t\t\t\t\t\tMAXMM/Mocoi7c2ZirXtGNPQ5lpW1nr/q7ON1eqsMcoCL/W+jjvm/DXs43K4syLY8\n\t\t\t\t\t\tnnnEYommJabZZtEZGCJOEGNElGm+z27pzBv9bfz0hO12mK/2okBzrrwlkirOyT1A\n\t\t\t\t\t\tE2oojb5Ybl/9JA1GpIHzAJMHJKwlQEYiCP8QxdlrKN+mcRUjnDXDtmP4Xnr7jxLf\n\t\t\t\t\t\tCTx3mMByMIAvKJ9GKCQSPaFgL+kKGge8dj/vCzfEF38LNrUNZ72jDc/ttsuIKUXy\n\t\t\t\t\t\tV17me3Pv3lJyZ4+Xbfrb4DVIDEueohFg6yhk5w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://cerealchemistry.aaccnet.org/page/about_library"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "AACCI Grain Science Online Library is a large, customizable collection of grain science resources."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "AACCI Grain Science Online Library"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://kiidp.ki.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 8 524 86488"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Parisa Farzbod"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:parisa.farzbod@ki.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Karolinska Institutet"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 8 524 86382"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Eric Johansson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:eric.johansson@ki.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Karolinska Institutet"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 8 524 82222"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT-support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it-support@ki.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Karolinska Institutet"
          }
        }
      ],
      "entity_id": "https://kiidp.ki.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAM0PmHWir6jrdlS8z2iCpGvo0CqaMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2tpaWRwLmtpLnNlMB4XDTEwMTEwOTA4MTgwNloXDTMw\nMTEwOTA4MTgwNlowFjEUMBIGA1UEAxMLa2lpZHAua2kuc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCGXvXTTL9jXqeUnjwuEuPctScCyn+hRZQOmWm7\nOrvAHMIi+MKQMeSboowpbj+apvYbaxQFY4PH4287fd4OhYJGAdfNk68E7h+S5Ryq\nBVrJVM9SSGcwGAViCSq5YfuSo/ZtvMCGtQJ8ef1uu4sg4VJ+UzXtSjfRvKNko9Jm\nr3lJ3qDUp3ltm+r9Yk7EQ+tKfJFIg41HiAEeFl9Zztlp6DqbOlwXleUjCVPklCZV\n4emEO9flD+uk3zxp9y9TlcOAtuFNp6EmzH5Xc2LvWOusDZITsuNtL6OfadIixkfb\nIctgW4hgD0GOnDi2chYu4Yq3vets8GsQVkD0BAIXNxhJ1HEjAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2tpaWRwLmtpLnNlhiJodHRwczovL2tpaWRwLmtpLnNlL2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBSDaQ4ABwxargqbAwedMAvPxCvABjANBgkqhkiG\n9w0BAQUFAAOCAQEAhHhPDWxChQt/L74HjwWVQHPQghTRcxJaQcBefWKH2yiERNyd\n/PKXU5G3RIzOS3Y3fYGwOMxH+PidKd48txJ50n/3VDI75g2MJsB+KJjLi2iVVkan\nxTyNLauF4A6ueNbn9V/myyZTa7kiru+iDSOasFSlLMf2leQXQHX3qBkOyBmy5Nu8\neGhJzMVovMnIaDofE1FXMI6yTuF3KG+Uep7moWj+WHY028TupWsiAE4LVs793dAn\ny4PHmY+q902WpZA1xeckJAdpSjS5rLc3fWOEHBNbmhBkOhDr/tarFUyjxi4mKEhm\nuKycjtOvYOwcvABc1u3WpxJ+CdtbbcHrnYCWXg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ki.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://kiidp.ki.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://kiidp.ki.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://kiidp.ki.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://kiidp.ki.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://kiidp.ki.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://kiidp.ki.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://kiidp.ki.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://kiidp.ki.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ki.se"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r Karolinska Institutet."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Karolinska Institutet."
                  }
                ],
                "logo": [
                  {
                    "text": "https://kiidp.ki.se/images/ki_logo_292x146.png",
                    "height": "146",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "292"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Karolinska Institutet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Karolinska Institutet"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "ki.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:59.3475753,18.0279382"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:59.219589,17.940939"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.229.0.0/18"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.237.96.0/19"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.237.128.0/20"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.237.204.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.237.207.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.16.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.140.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "194.14.96.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:06B0:0022::/48"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "136.155.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "159.38.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.63.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.76.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAM0PmHWir6jrdlS8z2iCpGvo0CqaMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2tpaWRwLmtpLnNlMB4XDTEwMTEwOTA4MTgwNloXDTMw\nMTEwOTA4MTgwNlowFjEUMBIGA1UEAxMLa2lpZHAua2kuc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCGXvXTTL9jXqeUnjwuEuPctScCyn+hRZQOmWm7\nOrvAHMIi+MKQMeSboowpbj+apvYbaxQFY4PH4287fd4OhYJGAdfNk68E7h+S5Ryq\nBVrJVM9SSGcwGAViCSq5YfuSo/ZtvMCGtQJ8ef1uu4sg4VJ+UzXtSjfRvKNko9Jm\nr3lJ3qDUp3ltm+r9Yk7EQ+tKfJFIg41HiAEeFl9Zztlp6DqbOlwXleUjCVPklCZV\n4emEO9flD+uk3zxp9y9TlcOAtuFNp6EmzH5Xc2LvWOusDZITsuNtL6OfadIixkfb\nIctgW4hgD0GOnDi2chYu4Yq3vets8GsQVkD0BAIXNxhJ1HEjAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2tpaWRwLmtpLnNlhiJodHRwczovL2tpaWRwLmtpLnNlL2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBSDaQ4ABwxargqbAwedMAvPxCvABjANBgkqhkiG\n9w0BAQUFAAOCAQEAhHhPDWxChQt/L74HjwWVQHPQghTRcxJaQcBefWKH2yiERNyd\n/PKXU5G3RIzOS3Y3fYGwOMxH+PidKd48txJ50n/3VDI75g2MJsB+KJjLi2iVVkan\nxTyNLauF4A6ueNbn9V/myyZTa7kiru+iDSOasFSlLMf2leQXQHX3qBkOyBmy5Nu8\neGhJzMVovMnIaDofE1FXMI6yTuF3KG+Uep7moWj+WHY028TupWsiAE4LVs793dAn\ny4PHmY+q902WpZA1xeckJAdpSjS5rLc3fWOEHBNbmhBkOhDr/tarFUyjxi4mKEhm\nuKycjtOvYOwcvABc1u3WpxJ+CdtbbcHrnYCWXg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Karolinska Institutet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Karolinska Institutet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ki.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "KI"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.mah.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 709 655480"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT Drift"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:drift@mah.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Malm\u00f6 University"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 768 428753"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Robert Faling"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:robert.faling@mah.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Malm\u00f6 University"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 40 6657555"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Servicedesk Malm\u00f6 h\u00f6gskola"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@mah.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Malm\u00f6 University"
          }
        }
      ],
      "entity_id": "https://idp.mah.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.mah.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.mah.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.mah.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.mah.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.mah.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mah.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mah.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mah.se/english"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r Malm\u00f6 h\u00f6gskola"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Malm\u00f6 University"
                  }
                ],
                "logo": [
                  {
                    "text": "https://cdn.mah.se/images/header/en/logo_en.jpg",
                    "height": "195",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "132"
                  },
                  {
                    "text": "https://cdn.mah.se/images/header/sv/logo_sv.jpg",
                    "lang": "sv",
                    "height": "195",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "132"
                  },
                  {
                    "text": "https://cdn.mah.se/images/header/en/logo_en.jpg",
                    "lang": "en",
                    "height": "195",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "132"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Malm\u00f6 h\u00f6gskola"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Malm\u00f6 University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "mah.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:55.608982,12.992469"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.178.224.0/19"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEzCCAfugAwIBAgIUPrvA/P0+Dsrc50jusZnN26yth0cwDQYJKoZIhvcNAQEL\nBQAwFTETMBEGA1UEAwwKaWRwLm1haC5zZTAeFw0xNjAzMjIwODExNTJaFw0zNjAz\nMjIwODExNTJaMBUxEzARBgNVBAMMCmlkcC5tYWguc2UwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQCCYTQPJO3eMFyM1s95c9+L6GqieSDW421ziu+LKsau\nHGw1bYbSN/QFV//WSFu7kVTXOlyHw7oCKOCPAsnAeZwO7ulFjL7XbmsXgUhC7Zce\nA7lHXakjMoLXGTbz07xPRjhjLs31TG6wfQBwec5aot+yfRmuy2ag+DOWCQDvVND5\nPDgdH7MNURiJD0POpaPv/w1PNm55hpqxxAQpXrn6KZuUdLtihWQKsK0UeEEf52Pi\n9dlrVnDArIredcnDA8uQz578Ve/JgmJYlRfhMa2XKGkz8IwGxHk6DWODqrgdbTIn\n/OHT/+TFUFQHU89YEZLfTb/MRSSKnhxcuOguH2KwL9aLAgMBAAGjWzBZMB0GA1Ud\nDgQWBBQGmSCSgZIUbOMnq6TS2JniITm0DTA4BgNVHREEMTAvggppZHAubWFoLnNl\nhiFodHRwczovL2lkcC5tYWguc2UvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEL\nBQADggEBAE6eWPoKTaZh/h1OufvNWObcvnJp9nmCsT6qHTQ3FRJ6VFKh/JSeqYlh\na25i1dxjphMfNR/H9Bpj3eblaVKaKgywojh5X1jOevrvyrJui2Mdzoy/rTfSpe9/\nuScxEK65CIDkBj3xbzrILg/qV1uW1jUJivTvmAC97S3iEevYdDgWKXmhuYemoFfz\nJW+eSiJqXLxZ66LtzYpR006NkwmvGIiNklUXpSohW8Qli6fdQsN1jelLSg22kjKe\nLFzVBYxtNETAVdxLSeIJ8saBNAcs+PrZ/tDjWYwefkJGiOR/Sy1BmbR7H8itKAti\njJU2WIS+eETI7AoMBvxYUdOwhHO9Uyc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEzCCAfugAwIBAgIUZqSagQMfxaTdLMgiEq1DliWEF6swDQYJKoZIhvcNAQEL\nBQAwFTETMBEGA1UEAwwKaWRwLm1haC5zZTAeFw0xNjAzMjIwODExNTBaFw0zNjAz\nMjIwODExNTBaMBUxEzARBgNVBAMMCmlkcC5tYWguc2UwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQCg9MH6aHw3FTJimmv0pYtzdcN4Z1y00cGlbuFykg+G\n2lZWhp1nPTHmcX10NBs6zMDhw8tU/aoP0w0HbFYb8ybvVwQIJ70o5bYSZvUlaxjs\nWPjeGev3atiS2po1YbB0l0cjmZGc4WTXljoi11u8KbJKRd5oNzS+/bP9H3BA9MGU\nZrw+9+1j53IEjlWSYOEpDfpcWimiKxTBauVWV+rTduC5XJqPIzlcOm248jojOP+c\noot/aD67tw3EkPtMXAwA6gF3QaDf24YkSTTzkqGTgyykOZBWpykmLDm6VswEvVwb\n1TjdI6GTOJftTiqceySv+fyjypE+i8z7c2puHa8w25FVAgMBAAGjWzBZMB0GA1Ud\nDgQWBBS0AHl1i/xnxDcIta2EkFeRqpWZ1DA4BgNVHREEMTAvggppZHAubWFoLnNl\nhiFodHRwczovL2lkcC5tYWguc2UvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEL\nBQADggEBACysMW88jYNzQNZK3BmPa2G3+U8wShjS6A4O9iVvFn20vKV0MZ2y13Lt\nPKbiLEK+Fp8ueRt6AHEdNRVMfq+YdzyuG9EDGqKKt1NEbfcG/JS2oWwTa/n9gzCc\nUE3r/3QIhBMi1ydR5a93F6bL8kQHm110COBSxA/y9n5rel6ybwhgQUGPWlfpV1CL\n74tDsem3BPOxFrznliM4yO31HORttr+idQU40p1J5QAFQkZHqnvW328vftAs3zCl\nt27XR73hJaFRoXZHtdbTkG386Q4u/nrLj5WSydSVRDkWUt0Cib52ft10Kz6bQtxg\n2l1TKCgfNmMiI8LLDq42FYLivsEaFAs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAM5xFJJcWySFKJeIz/WavrXmbuhNMA0GCSqGSIb3DQEB\nCwUAMBUxEzARBgNVBAMMCmlkcC5tYWguc2UwHhcNMTYwMzIyMDgxMTUwWhcNMzYw\nMzIyMDgxMTUwWjAVMRMwEQYDVQQDDAppZHAubWFoLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAmC0oViw/6krOFwoIf7M2PaGGvBmZnpNT4Jz8nI+f\nDyFGPC8cTUEnHPgLthCHS1aNzmkmlZ9jpK8eL2VBntEUbAYSK+6G9ual+jYjk/fH\nPpuR3e3J1a/JGEV+LgJziw+4j3O41aTcwt5l0ZBVtdON7pRTeTLfnEYJeoGlPJU7\nGk9v/+BTo5peTtR2UZiOpgEs0OeNfiOt1RdaUndkQHbDc6aDdMgRwsbwQtLASvfr\nPDSWraERg1NFyK+BAUmIeEdq48um6KPIVkLMIPawgMV+uDYY9/E5GVm5V6+/CqiY\nePkChMR6u5JaUQ70D0odk6i9SaGZUcwWJfoE9eTiwMo0yQIDAQABo1swWTAdBgNV\nHQ4EFgQUqqLsvn6tmlN7zYJ7Ea9h8psUF24wOAYDVR0RBDEwL4IKaWRwLm1haC5z\nZYYhaHR0cHM6Ly9pZHAubWFoLnNlL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\nCwUAA4IBAQA5rgvE5wFj20LbPOe7omwVROuTVUdpGbZ4XNWp6RDWx937xcJvJMFY\nmLBKhE3VtxyRDj+hwqnGgmeyEyYXBTPX7NNsibwOE0WcCcn4bshR6Gd5NvyQQ8w0\nYbc+s9dLigZVWsOrMdednugV0mnqQ/qWwQYn7DBDHInReks2o+DtWyFhYeoSalch\neMaU8y4Mq8Swi7X4ErzBD+DKFQe0q5aCaXIiwD+H4XJzOYkUxZSpAPW62lOgJAku\nSb3rBCm5iyTFace5tFk069wtFHASk2Xy8atTMLx0nbFkq5eE/DVRsYj+C7QZOLTf\n7UutZmHR05RiErkouLWVildFWPkfDUIO"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Malm\u00f6 h\u00f6gskola"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Malm\u00f6 University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mah.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "MAH"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dadotsweb1.essex.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Noble"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Susan.Noble@jisc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Susan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Syrotiuk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nicholas.syrotiuk@jisc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nick"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dadotsweb1.essex.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-05T08:03:12Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UK Data Service Dotstat Production server (Version 7)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jisc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Essex"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dadotsweb1.essex.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dadotsweb1.essex.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dadotsweb1.essex.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dadotsweb1.essex.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dadotsweb1.essex.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dadotsweb1.essex.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJAKjnriY74DziMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\n\t\t\t\t\t\tBAMTFmRhZG90c3dlYjEuZXNzZXguYWMudWswHhcNMTUwNDIyMTIyMDE0WhcNMjUw\n\t\t\t\t\t\tNDE5MTIyMDE0WjAhMR8wHQYDVQQDExZkYWRvdHN3ZWIxLmVzc2V4LmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArT2aS9/q46teLSQZLyEMYOGM\n\t\t\t\t\t\twY3VyQmkBJ/xePd5WxEGX1IzWAw1d7glV6XBuSE4rprc84Hz2dVEDlCb2NZheIIt\n\t\t\t\t\t\tGAfoWurKIyyi+v6m7LLSp9VGAUi7hXqi6eoceop1ei2foO+kmhYOlXGt8nKXgdML\n\t\t\t\t\t\tjM3X90ab03q91/Xb3usia/WFrC61Ta9Z4/L0lJCtl3EyuWm0CLRBQH291nyLkqNE\n\t\t\t\t\t\tq3pKrt3fVmbzgz+K+FXppyt38vdIG0bm+wMqSXdBNUMtTfiIG6p90UM8CIOqJtZY\n\t\t\t\t\t\tfkhX5kLWkEJGZjt1swPXuEfQivTKpIbIUdqG1frEJQ8Ws2fAmo8D7PGiecRjuQID\n\t\t\t\t\t\tAQABo0QwQjAhBgNVHREEGjAYghZkYWRvdHN3ZWIxLmVzc2V4LmFjLnVrMB0GA1Ud\n\t\t\t\t\t\tDgQWBBTtm1Vzg3dzOyODStZMXAilmgJ6VjANBgkqhkiG9w0BAQUFAAOCAQEAW1uC\n\t\t\t\t\t\t7aDFUnDcYYcZXj1+LUg57401KOCb3adqJy43uR4nlIuOmDqkCW0qrVUg//ZHjIdc\n\t\t\t\t\t\tsi8mv/5enPXxGGxU3ti5YL9+iMVgrZcqplzGyVdZsjRo1Y4ERJDIxXzSlvve8wER\n\t\t\t\t\t\tQh5E61YNmSJEGIIR1sguf3vlou0MvNuKLsiY1EPU7UAVWW+Yc8TIdWwvkNb12eTJ\n\t\t\t\t\t\tm3V1TGhOB6QOgpJsxc5vQ7xt/eq6p6LOimQMWVBNyZdoX/BQbwVu9gz97UMG3OvS\n\t\t\t\t\t\tFv4lbhZmxO3Xc/7QkrH/8raZc7dddIhbTU3YMdOzTZnGFJaGmGWLRLvHzn8XICx9\n\t\t\t\t\t\tdX8Y3VJ0YyQXEt/44A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dadotsweb1.essex.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dadotsweb1.essex.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dadotsweb1.essex.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dadotsweb1.essex.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dadotsweb1.essex.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dadotsweb1.essex.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.itep.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Erick Marllon"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "erick@itep.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.itep.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0DCCArgCAQAwDQYJKoZIhvcNAQEFBQAwga0xLjAsBgNVBAoTJUluc3RpdHV0\nbyBkZSBUZWNub2xvZ2lhIGRlIFBlcm5hbWJ1Y28xDTALBgNVBAsTBFVUSUMxIzAh\nBgkqhkiG9w0BCQEWFHBsYW50YW8tdXRpY0BpdGVwLmJyMQ8wDQYDVQQHEwZSZWNp\nZmUxEzARBgNVBAgTClBlcm5hbWJ1Y28xCzAJBgNVBAYTAkJSMRQwEgYDVQQDEwtp\nZHAuaXRlcC5icjAeFw0xNTAxMzAxNDE2MjFaFw0xODAxMjkxNDE2MjFaMIGtMS4w\nLAYDVQQKEyVJbnN0aXR1dG8gZGUgVGVjbm9sb2dpYSBkZSBQZXJuYW1idWNvMQ0w\nCwYDVQQLEwRVVElDMSMwIQYJKoZIhvcNAQkBFhRwbGFudGFvLXV0aWNAaXRlcC5i\ncjEPMA0GA1UEBxMGUmVjaWZlMRMwEQYDVQQIEwpQZXJuYW1idWNvMQswCQYDVQQG\nEwJCUjEUMBIGA1UEAxMLaWRwLml0ZXAuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQD5QoDb/jNA1TiFRbbXcsZhhLj0XbKR2Z2u9PgA+ahtnvCDDvc+\n7oHCYs9t0P/UDIP7t8k1eLgKGb/1Zuw56HK1Ans3MWWr89XqxWo8LZVqlHcVTFL5\neGtcH5Ew83jBGoaMPkKAPN68DvYVot8AiMrN7m4ZzTrKaW8F+gpyPqX9NdJ1NF3o\n6g6G2187weaHaEcRqBfJ0+9jK61RD+ufcQypZkOi120d/nHWG4gL/MWlYc2GsnHW\nXuAo6G55HNG7N/ihDyNwGGg2P81HLyQ352lom6fdtH9/wPjXHFvhDf9AiD6RK43D\nQ5HKK1jrmGpmgjCnnnU2i/VixR8gR9dutfWFAgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBAB9RY1YQJqlaJb3mpPdv0tSiG84jvKEcpKT/aNInCJ+E4w823GW5cNYhZDlk\nZkTeHadbJSLuJrP3T7EGB7Xyvc5h/qMmLhCG3HxGnCgD6qC1xl2EdeMeOGFJy2na\n7HgEF/Z8VVN5q7Bv/dLrtT0R8ASf8pidmTunbJY4wQxdKOJR8tMS7u0kjbjv0rcM\ng15xNx4qO4znwZXq6b/YtHgXSPXH0YXDbDL1V6hzH02OhwnVQvTuqs1U/isTt7un\nialGuHDf5vCXiTpYL0bb2cI6+5lxtDWkinby7/DJ3w2lExZI1YDmEtOzS+zPpVUu\nDw6i1eVLb8QLB2R+pfcTZ4PrmFo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "itep.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.itep.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.itep.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.itep.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.itep.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.itep.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.itep.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.itep.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.itep.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "itep.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.itep.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.itep.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ITEP - Instituto de Tecnologia de Pernambuco"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ITEP - Instituto de Tecnologia de Pernambuco"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ITEP - Instituto de Tecnologia de Pernambuco"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ITEP - Instituto de Tecnologia de Pernambuco"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0DCCArgCAQAwDQYJKoZIhvcNAQEFBQAwga0xLjAsBgNVBAoTJUluc3RpdHV0\nbyBkZSBUZWNub2xvZ2lhIGRlIFBlcm5hbWJ1Y28xDTALBgNVBAsTBFVUSUMxIzAh\nBgkqhkiG9w0BCQEWFHBsYW50YW8tdXRpY0BpdGVwLmJyMQ8wDQYDVQQHEwZSZWNp\nZmUxEzARBgNVBAgTClBlcm5hbWJ1Y28xCzAJBgNVBAYTAkJSMRQwEgYDVQQDEwtp\nZHAuaXRlcC5icjAeFw0xNTAxMzAxNDE2MjFaFw0xODAxMjkxNDE2MjFaMIGtMS4w\nLAYDVQQKEyVJbnN0aXR1dG8gZGUgVGVjbm9sb2dpYSBkZSBQZXJuYW1idWNvMQ0w\nCwYDVQQLEwRVVElDMSMwIQYJKoZIhvcNAQkBFhRwbGFudGFvLXV0aWNAaXRlcC5i\ncjEPMA0GA1UEBxMGUmVjaWZlMRMwEQYDVQQIEwpQZXJuYW1idWNvMQswCQYDVQQG\nEwJCUjEUMBIGA1UEAxMLaWRwLml0ZXAuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQD5QoDb/jNA1TiFRbbXcsZhhLj0XbKR2Z2u9PgA+ahtnvCDDvc+\n7oHCYs9t0P/UDIP7t8k1eLgKGb/1Zuw56HK1Ans3MWWr89XqxWo8LZVqlHcVTFL5\neGtcH5Ew83jBGoaMPkKAPN68DvYVot8AiMrN7m4ZzTrKaW8F+gpyPqX9NdJ1NF3o\n6g6G2187weaHaEcRqBfJ0+9jK61RD+ufcQypZkOi120d/nHWG4gL/MWlYc2GsnHW\nXuAo6G55HNG7N/ihDyNwGGg2P81HLyQ352lom6fdtH9/wPjXHFvhDf9AiD6RK43D\nQ5HKK1jrmGpmgjCnnnU2i/VixR8gR9dutfWFAgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBAB9RY1YQJqlaJb3mpPdv0tSiG84jvKEcpKT/aNInCJ+E4w823GW5cNYhZDlk\nZkTeHadbJSLuJrP3T7EGB7Xyvc5h/qMmLhCG3HxGnCgD6qC1xl2EdeMeOGFJy2na\n7HgEF/Z8VVN5q7Bv/dLrtT0R8ASf8pidmTunbJY4wQxdKOJR8tMS7u0kjbjv0rcM\ng15xNx4qO4znwZXq6b/YtHgXSPXH0YXDbDL1V6hzH02OhwnVQvTuqs1U/isTt7un\nialGuHDf5vCXiTpYL0bb2cI6+5lxtDWkinby7/DJ3w2lExZI1YDmEtOzS+zPpVUu\nDw6i1eVLb8QLB2R+pfcTZ4PrmFo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ITEP - Instituto de Tecnologia de Pernambuco"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ITEP - Instituto de Tecnologia de Pernambuco"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.itep.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.itep.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ITEP - Instituto de Tecnologia de Pernambuco"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ITEP - Instituto de Tecnologia de Pernambuco"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.silverchair.com/aclands/staging/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:technicaloperations@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:technicaloperations@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Operations"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.silverchair.com/aclands/staging/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-06T13:15:33Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Silverchair Staging: Wolters Kluwer Acland\u2019s Video Atlas Of Human Anatomy"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://aclandanatomy.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Silverchair Science + Communications, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aclandanatomyrc.silverchair.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aclandanatomyrc.silverchair.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aclandanatomyrc.silverchair.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://aclandanatomyrc.silverchair.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aclandanatomyrc.silverchair.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://aclandanatomyrc.silverchair.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDXTCCAkWgAwIBAgIJAP0kjtCO5LCSMA0GCSqGSIb3DQEBBQUAMCoxKDAmBgNV\n\t\t\t\t\t\tBAMTH2FjbGFuZGFuYXRvbXlyYy5zaWx2ZXJjaGFpci5jb20wHhcNMTUwNTA1MTI1\n\t\t\t\t\t\tOTQyWhcNMjAwNTAzMTI1OTQyWjAqMSgwJgYDVQQDEx9hY2xhbmRhbmF0b215cmMu\n\t\t\t\t\t\tc2lsdmVyY2hhaXIuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\t4KlybwJfF5/BPhQtkuJVGsgsUtGccJRx+CBb7xh7g/yOk6BprnfPrWkE9bd40WvX\n\t\t\t\t\t\tSBy8gNLmFeGHRdl52rpxYfD2xFXgMv1kg1E/pArvO/ulWUVO75s4aHDsh2ZyW0yA\n\t\t\t\t\t\txEnsKYbpPVwD+dcg/ilZ2PQ+D2Q0vCOXgukbwX0dNw3Dt0uBCMRlJsdkMn82kUHH\n\t\t\t\t\t\tZXE1aSw0i4EGgR1JOnFXmcelGhCwN+BK7WodUIJtN22OLPiSjwOEITEhd+cYLPov\n\t\t\t\t\t\tEhRu5hYGp87ouJscd6SaiNKThJUjzx09MoetxkXB3Oo0zgeJPuE8VFEF/MRZemnb\n\t\t\t\t\t\tjCNQRXCfUCVYAhVZS12d8wIDAQABo4GFMIGCMGEGA1UdEQRaMFiCH2FjbGFuZGFu\n\t\t\t\t\t\tYXRvbXlyYy5zaWx2ZXJjaGFpci5jb22GNWh0dHBzOi8vc3Auc2lsdmVyY2hhaXIu\n\t\t\t\t\t\tY29tL2FjbGFuZHMvc3RhZ2luZy9zaGliYm9sZXRoMB0GA1UdDgQWBBS3GtGfzTPW\n\t\t\t\t\t\tuObt+vb/xORB5huW0DANBgkqhkiG9w0BAQUFAAOCAQEAUB6buU3Bti3wCLmypcFQ\n\t\t\t\t\t\tCCFXNfQSRWCdhD9OE4RDMlT0H2EibiXCN8ST9gxy7OdMk4SPI+fCjfxKW6EMptBs\n\t\t\t\t\t\t98EkLD1NW4wtUFDek9ify6OrmUS0zuEIeCYQ6PK1o9Gjltzu7yIxyexkDrR4vZXC\n\t\t\t\t\t\tKgaCrxImOhmNTNRPcq3KUa8brOeuLqGLGSfZ24eyd7swYYMpwbsaVYTHxIdonSqI\n\t\t\t\t\t\txlMcKiDeqZxfndOrwJUbTPJDLTl3OhjWCnYBZsjkP3wVzs47XSki/yIUotWZlmZS\n\t\t\t\t\t\t4kzhd/HkufOmKXEgGTXk4n+7KETjJzDaIQVWRiOBZgWGVtBRqglkhiNRg/gTkARJ\n\t\t\t\t\t\tWw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aclandanatomyrc.silverchair.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aclandanatomyrc.silverchair.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://aclandanatomyrc.silverchair.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://aclandanatomyrc.silverchair.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://aclandanatomyrc.silverchair.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://aclandanatomyrc.silverchair.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.sfsu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "supakitk@sfsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Supakit Kiatrungrit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jfung@sfsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Joellen Fung"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "systems@sfsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "supakitk@sfsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Supakit Kiatrungrit"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.sfsu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sfsu.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sfsu.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUaVXwsxeZ7HtpgzDRqkb/SXmxNCUwDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMaWRwLnNmc3UuZWR1MB4XDTEwMDExMjE3NTg0OVoXDTMw\nMDExMjE3NTg0OVowFzEVMBMGA1UEAxMMaWRwLnNmc3UuZWR1MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnM2TW44FPEMlaZShdBub38iLLGtpvvtTZVvC\ntLo6xRQx0YCPYIQua2hxjf5lYFMe2KlwehxuCfujsTbegBX8TNg86NaN2s5iTFk7\nQ7BKY0o1UGEHhmELKZx/BVSH1AB0qwk1ZF9jGyynTITRwRGsr1yLvFM3aTH1tB4s\niMpTTp7U4HfWcfCsAepxVJw8o8Nvgujgi6E8Mh4emTz+PdNmx0cgpiu7EpvruUEk\nELlHifyFRhCCBUeOtxgsJXvXgqIYxLlxcz7aGnsylTCgX8fN2WABkJte90Cv06EU\nmkCnB4x8pKLxSfVkLDRDImpqPwnTjmizD6neSRQ5ano4qdAm9wIDAQABo18wXTA8\nBgNVHREENTAzggxpZHAuc2ZzdS5lZHWGI2h0dHBzOi8vaWRwLnNmc3UuZWR1L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBT7bbal9a/eJjoYsQd6Stdkk9D6uTANBgkq\nhkiG9w0BAQUFAAOCAQEAB2UmDPQkEVR8YPNCUZS2+XjA5Pw7vdswtZpqLbN4x2RG\nAFnaUFs4Qw5/9RScVOdfuSKjbB32LSJzOTLUc2LA2zUhAcieprD9wBcW2gIVnpPC\nPQxMSI7vD7YuF6erW/qFh+gZwBod/PPmP30wy4uDAcWfW09f79wWv67v8ePXS/PA\nWw8M8pNXffLcYo8NAdTY1ZddhYsqcAduFzL4Q0u/+QpV4K2qpMOK57sJ/4GuI0i4\nTF+IPVqP9ibO/PX7scYZDBm8wGCQ3G3UwADAQxJlSTJzyP7PthgH3ublYb3IbrY6\nOQKTDUHTSx//VpESlGrhleDG/BalOfbtxZka2UF05A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sfsu.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.sfsu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sfsu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sfsu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.sfsu.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sfsu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sfsu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sfsu.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "San Francisco State University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUaVXwsxeZ7HtpgzDRqkb/SXmxNCUwDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMaWRwLnNmc3UuZWR1MB4XDTEwMDExMjE3NTg0OVoXDTMw\nMDExMjE3NTg0OVowFzEVMBMGA1UEAxMMaWRwLnNmc3UuZWR1MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnM2TW44FPEMlaZShdBub38iLLGtpvvtTZVvC\ntLo6xRQx0YCPYIQua2hxjf5lYFMe2KlwehxuCfujsTbegBX8TNg86NaN2s5iTFk7\nQ7BKY0o1UGEHhmELKZx/BVSH1AB0qwk1ZF9jGyynTITRwRGsr1yLvFM3aTH1tB4s\niMpTTp7U4HfWcfCsAepxVJw8o8Nvgujgi6E8Mh4emTz+PdNmx0cgpiu7EpvruUEk\nELlHifyFRhCCBUeOtxgsJXvXgqIYxLlxcz7aGnsylTCgX8fN2WABkJte90Cv06EU\nmkCnB4x8pKLxSfVkLDRDImpqPwnTjmizD6neSRQ5ano4qdAm9wIDAQABo18wXTA8\nBgNVHREENTAzggxpZHAuc2ZzdS5lZHWGI2h0dHBzOi8vaWRwLnNmc3UuZWR1L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBT7bbal9a/eJjoYsQd6Stdkk9D6uTANBgkq\nhkiG9w0BAQUFAAOCAQEAB2UmDPQkEVR8YPNCUZS2+XjA5Pw7vdswtZpqLbN4x2RG\nAFnaUFs4Qw5/9RScVOdfuSKjbB32LSJzOTLUc2LA2zUhAcieprD9wBcW2gIVnpPC\nPQxMSI7vD7YuF6erW/qFh+gZwBod/PPmP30wy4uDAcWfW09f79wWv67v8ePXS/PA\nWw8M8pNXffLcYo8NAdTY1ZddhYsqcAduFzL4Q0u/+QpV4K2qpMOK57sJ/4GuI0i4\nTF+IPVqP9ibO/PX7scYZDBm8wGCQ3G3UwADAQxJlSTJzyP7PthgH3ublYb3IbrY6\nOQKTDUHTSx//VpESlGrhleDG/BalOfbtxZka2UF05A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "San Francisco State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sfsu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "San Francisco State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.unifi.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@unifi.it.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.unifi.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2011-06-23T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAPWvhnhnIM07MA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE3NoaWJib2xldGgudW5pZmkuaXQwHhcNMTEwNTA5MTI0MTMyWhcNMzEwNTA5\nMTI0MTMyWjAeMRwwGgYDVQQDExNzaGliYm9sZXRoLnVuaWZpLml0MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAlTYplVQaIDgOLjhY6W0ysUneVOsAhdD3\nnKOLZC6NO1CFlFB8gINO2i+SkTVkhQ2jFAjq9XXb9WBsqx2Ta4skroyM1I039R6z\nHVFAmtib4Ea8spGXhg87OnxiPaXijJ81d6ka3At+g0VQYJ5w7jC/cuRaT4sk3scc\neiQlViLn1kdcUYyXQo54gtwBjEoNvlPfF/S9ljdyo/yU7/oz4SQrDuYThqV+xXCM\n4ZTRt0gWcEAdd+d3mpfohNrEuGptbVoD6gpBkG9ytl/UVnKpkd32JDWLxeDDNOQz\nH+PWA1KbjR2aM//87u7rq9WBgjufjwYzTT4nulbzl/Mur+eyUFF80QIDAQABo20w\nazBKBgNVHREEQzBBghNzaGliYm9sZXRoLnVuaWZpLml0hipodHRwczovL3NoaWJi\nb2xldGgudW5pZmkuaXQvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFHnEVLfzRW+Y\no/M/MOvtO3S+knB3MA0GCSqGSIb3DQEBBQUAA4IBAQCM8asqBBYAnVvJXtFEfuyM\nqNAqiwomAQ1YPTPj4tD0w9EK9aMqJN4OCo/3Dy4fuHx4F9xAtWApP8cRvUswCURu\nsaq1eUJ4Oay+ck1AxKl93EueGJxk46ZLUjizspod/N5U342IYKAIMTV2EZxKaLGD\n0yF4A47fZKHJSY+L0MaonVdOleDN1dsICwYbCo5xvhaV+QlW+10orfGhe+JqMm9T\nr8mC7l26BgX42zsxXS6O5cGQpu9YBa9fiL5wqhxet2xvHBI0mOekpH0+PGRvwe18\nOFmZKVHYQGnUEfIKGWoFZSeZhO9UJsWJNdRxSkDf9m71otdlbfFSJ8BqkOm3AElL"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unifi.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.unifi.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.unifi.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.unifi.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.unifi.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.unifi.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.unifi.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.unifi.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.unifi.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unifi.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://shibboleth.unifi.it/info/index.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://shibboleth.unifi.it/info/index.html"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for University of Florence users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider per gli utenti dell'Universit\u00e0 di Firenze"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.siaf.unifi.it/CMpro-v-p-606.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.siaf.unifi.it/CMpro-v-p-606.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Florence"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 di Firenze"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAPWvhnhnIM07MA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE3NoaWJib2xldGgudW5pZmkuaXQwHhcNMTEwNTA5MTI0MTMyWhcNMzEwNTA5\nMTI0MTMyWjAeMRwwGgYDVQQDExNzaGliYm9sZXRoLnVuaWZpLml0MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAlTYplVQaIDgOLjhY6W0ysUneVOsAhdD3\nnKOLZC6NO1CFlFB8gINO2i+SkTVkhQ2jFAjq9XXb9WBsqx2Ta4skroyM1I039R6z\nHVFAmtib4Ea8spGXhg87OnxiPaXijJ81d6ka3At+g0VQYJ5w7jC/cuRaT4sk3scc\neiQlViLn1kdcUYyXQo54gtwBjEoNvlPfF/S9ljdyo/yU7/oz4SQrDuYThqV+xXCM\n4ZTRt0gWcEAdd+d3mpfohNrEuGptbVoD6gpBkG9ytl/UVnKpkd32JDWLxeDDNOQz\nH+PWA1KbjR2aM//87u7rq9WBgjufjwYzTT4nulbzl/Mur+eyUFF80QIDAQABo20w\nazBKBgNVHREEQzBBghNzaGliYm9sZXRoLnVuaWZpLml0hipodHRwczovL3NoaWJi\nb2xldGgudW5pZmkuaXQvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFHnEVLfzRW+Y\no/M/MOvtO3S+knB3MA0GCSqGSIb3DQEBBQUAA4IBAQCM8asqBBYAnVvJXtFEfuyM\nqNAqiwomAQ1YPTPj4tD0w9EK9aMqJN4OCo/3Dy4fuHx4F9xAtWApP8cRvUswCURu\nsaq1eUJ4Oay+ck1AxKl93EueGJxk46ZLUjizspod/N5U342IYKAIMTV2EZxKaLGD\n0yF4A47fZKHJSY+L0MaonVdOleDN1dsICwYbCo5xvhaV+QlW+10orfGhe+JqMm9T\nr8mC7l26BgX42zsxXS6O5cGQpu9YBa9fiL5wqhxet2xvHBI0mOekpH0+PGRvwe18\nOFmZKVHYQGnUEfIKGWoFZSeZhO9UJsWJNdRxSkDf9m71otdlbfFSJ8BqkOm3AElL"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Florence"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 di Firenze"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unifi.it"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unifi.it"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Studies of Florence"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli Studi di Firenze"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.enac.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Didier MAGRE"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "didier.magre@enac.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Alexandre COHEN"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "alexandre.cohen@enac.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.enac.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-06-25T17:15:45Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.enac.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.enac.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.enac.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "enac.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.enac.fr/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Students, Researchers and Staff"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Apprenants,Chercheurs et Personnels"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENAC - Ecole Nationale de l'Aviation Civile"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENAC - Ecole Nationale de l'Aviation Civile"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVALjMEvpFsfHdqv4aYoi82tdjMJg9MA0GCSqGSIb3DQEB\nBQUAMCAxHjAcBgNVBAMMFWlkcC5yZWNoZXJjaGUuZW5hYy5mcjAeFw0xNDExMTcx\nNzMxMDNaFw0zNDExMTcxNzMxMDNaMCAxHjAcBgNVBAMMFWlkcC5yZWNoZXJjaGUu\nZW5hYy5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIDNPO0L9Xkl\nDb1GUrFEoY56R+3WyTCWXYgD8K3Q5+8Am9DCltbnlx/hqbV1osKZIlJPvo189VH6\nQuEPhjTqTYPlPGvA04OYwDtKPBNKGSL4iapsovMh5vgHcV4qi2n9eMABOVRo80NC\nC+U+HkZNuYiNeFhZ+iGdfAFS9sgoRNSsLGDLXJC07nSLznf1BuOT2ipHuaz5No98\nHD+tfE3rZAlWT0Iq+NNGdpG+eERLM0KwmrCJ6WpKY7EPDxw1Wrc7DN7llBIys4HI\nIMwHoCIkJqElofAuCMnnFeZWJZ4O5mS+ucNQga0V29CHYUVZuhLWLfBV01VLQ9Ho\ns+Z7Duht01sCAwEAAaNxMG8wHQYDVR0OBBYEFKIVSiPZ5+jJqGUvMhVVhO/uAh+b\nME4GA1UdEQRHMEWCFWlkcC5yZWNoZXJjaGUuZW5hYy5mcoYsaHR0cHM6Ly9pZHAu\ncmVjaGVyY2hlLmVuYWMuZnIvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEFBQAD\nggEBAEtxX5sqTKoZ6pP1UnihbwYHTfAMpLeqkXUCDl5JI7gPmUE9JYocAFKmbD/Z\nnscHzNQA2G1D+g2YhAOEpNk7VcgQnsgsldbyYCPE9gqU8pt5CfObmrLIY4an1OxJ\nUcpnjVs8OH0blae/KOrMkc4353Klwo3YFxrkqyRFsNGpYOdDJUEDd6X5NF47wvS0\neR5z1/IoEPIVcVuR/xWmpK95gcJ/DFgFrebwCE+FjS89pBjH5bHMS/QNzKef0tqY\ngd7OPw24Ut2oiKcpjkQjV8SBxAY/i5GnwUrt9E1J5p4IHiETJ0q9s9GVUTA2S1/U\n/e8nBK9EJdoDnEi1985qGA1FYp4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ENAC - Ecole Nationale de l'Aviation Civile"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.enac.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ENAC - Ecole Nationale de l'Aviation Civile"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp-test.nordu.net/simplesaml/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NOC"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@sunet.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SUNET"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-test.nordu.net/simplesaml/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-test.nordu.net/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-test.nordu.net/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://idp-test.nordu.net/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://idp-test.nordu.net/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://idp-test.nordu.net/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:profiles:holder-of-key:SSO:browser",
              "location": "https://idp-test.nordu.net/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-03.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-03.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;03"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;03"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-03.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-03.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAIhCSM/gXPV2MA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wMy5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTIxMzE4WhcNMjQx\nMDA0MTIxMzE4WjAhMR8wHQYDVQQDExZsYWRvazMtMDMubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtQOsQBm/doFi/rO80GvjNJGY\n/hrRllUtBkIgExc/oqEkKEXRH/yp23e5P8aS/u+Z+Ap0e0RCLqQwAi5yVCx4IIp9\nwEu/trbuR75QF9XIGO0cTy0PrcOyZsAjCk42QmdsUWWq/3jv9G+f+Riny0A0yy3y\n5k//tCZPVBQ+6WIhxbSk+yJM5cec4g2exA7M8fWG/i9Wb/7sWEjN0Kz5GTgPLO81\nE4/Ji7oJh4zesuDyFlfCn9wHx7ex7gzmP1H5uTkgfy5GGTZakzVi5dc9oQICY3xA\nDqx95pPNugXlfmZzV6M9aWmPnLvRO17LX9uOD5hDHsqhnqppOVcNf/YEbYxH+QID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMDMubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0wMy5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUbJhrFVcaM2PS/pjQJjhusF3gYRowDQYJKoZIhvcNAQEFBQADggEB\nAJh7UZv2qYzT1FCI0wGEnqPfkxTYFLvjq1zSp1u4WAlvVXPkN/KMbqIgzzTSW3S2\nzyImr52uqUp0IWjbg+iAk5e8n4+08gJMwWcpidfs9U0avIu9YoMz+qjQ5CyMe6xR\n1w1DWjbXQnB75XAtrOYCm7RH9sx0RvpfFnzUT92z2I+68Jl4499eeBzSprJuRjYP\nmiF1AohiHs3zkZAlP4BQWc1utAp/fv5ls2pnepCAJvePieJPalI19r3bd1cLU+A7\ndwvGpzDdwMxXKv+cQUdRnCE3IhzFb8X57J7pQApgGPnzt0H9uwgFPIEE8mOaQM4U\nIlstWICQczAoX1y5Ow2IOEo="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-03.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://birk.wayf.dk/birk.php/sso.hrs.dk/adfs/services/trust",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://birk.wayf.dk/birk.php/sso.hrs.dk/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2012-05-16T22:43:37Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/sso.hrs.dk/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://birk.wayf.dk/birk.php/sso.hrs.dk/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hrs.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hotel- og Restaurantskolen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Copenhagen Hospitality College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "hrs.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC1DCCAbwCAQcwDQYJKoZIhvcNAQELBQAwMDEuMCwGA1UEAwwlaHR0cDovL3Nz\nby5ocnMuZGsvYWRmcy9zZXJ2aWNlcy90cnVzdDAeFw0xNTAxMDEwMDAwMDBaFw0y\nNTEyMzEyMzU5NTlaMDAxLjAsBgNVBAMMJWh0dHA6Ly9zc28uaHJzLmRrL2FkZnMv\nc2VydmljZXMvdHJ1c3QwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDH\niAwKahBTuI4Z+IJ1rgOeEiCCy3bR9QIe3BpCsejFCU5rSzkWANqVuc1PDfp0JdIZ\nhrPXsmDJQMmidPCGPIDQKo+bk+af3+EUFS/I/+35sSBX2vf+h1DHvZV9jsznmpSV\njp7HZ/WoPWBykWBJO0AOVmzB5zlaqkS36J76+wxerwdpuExVnYSNd73S+AyT/EZ+\ntXAO+6lQ8FL/YMlJnUkSaSqLSHFy01D2qBNmYRwBpCS6/dUZyxi0t5j8ghKUD4BH\nOZVavn65J62cJdXiOcMRyUAIp57GXQrL63KtrjIcXddq+CZyZ5t37EdUOIz42joF\ncy73MFOntynlKEvOw1BJAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAKEeFZyhJPo7\nYHgXgmb2ZmJOv6W37gxrAuuWVbyhcOzYSAtqA8zv3EkwuK5rGJpbdwVeNot+YJ9B\nTdqVLOLMSc6/JxdHtezW+M8nMEwMOLWkkyNA5/RC7w0XBvCfpPByuV8Mke60GtFn\nVOigg/8wKAyFIsEpzSPv7VMF4/SA/tYTkrGJtw9pYu0A54JWb4s0m5C87Y+16MHV\nFaA1fbcQnYioyAz0FRkxfvmMRiNPINA1jOrC7h/iRq0nGxHEnOMRNKT2h9upRgul\nH8vDIZSNJeoj/SitEpgjanw5oNXtqn16gZcB2v/fPs2qDbs636amU6ELoV0gpQjv\n247KqYnMNlQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hotel- og Restaurantskolen"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Copenhagen Hospitality College"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hrs.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://hrs.dk/english.aspx"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hotel- og Restaurantskolen"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Copenhagen Hospitality College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://hood.accessiblelearning.com/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rob.armas@dsaim.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert Armas"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "haris.gunadi@dsaim.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Haris Gunadi"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://hood.accessiblelearning.com/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Accessible Information Management, LLC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://accessiblelearning.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Accessible Information Management, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://hood.accessiblelearning.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.accessiblelearning.com"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Accessible Information Management, LLC"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "AIM LLC provides software and support, systems implementation and integration, strategic consulting, and technology management services to help colleges and universities build, unify, and manage their disability services accommodations. Enterprise solutions for administration and recordkeeping. Portal solutions to enhance Web-based experiences and support community building Technology management services to better manage technology resources and provide metrics on demand. Bringing together people, processes, and technology, AIM LLC works with colleges and universities to help them strengthen performance and services through improved data accuracy and integrity, increased accountability, and enhanced educational experiences."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.accessiblelearning.com/Shibboleth/logo.png",
                    "lang": "en",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.accessiblelearning.com/Policies.aspx"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFUzCCBDugAwIBAgIJAO7LODGH3QVDMA0GCSqGSIb3DQEBCwUAMIG0MQswCQYD\nVQQGEwJVUzEQMA4GA1UECBMHQXJpem9uYTETMBEGA1UEBxMKU2NvdHRzZGFsZTEa\nMBgGA1UEChMRR29EYWRkeS5jb20sIEluYy4xLTArBgNVBAsTJGh0dHA6Ly9jZXJ0\ncy5nb2RhZGR5LmNvbS9yZXBvc2l0b3J5LzEzMDEGA1UEAxMqR28gRGFkZHkgU2Vj\ndXJlIENlcnRpZmljYXRlIEF1dGhvcml0eSAtIEcyMB4XDTE1MDkwOTA2MDc0M1oX\nDTE4MDkwOTA2MDc0M1owSTEhMB8GA1UECxMYRG9tYWluIENvbnRyb2wgVmFsaWRh\ndGVkMSQwIgYDVQQDExtob29kLmFjY2Vzc2libGVsZWFybmluZy5jb20wggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCzIaJgVm1EK8sWJ5N9pONd2NrZFSmC\nd+lvZdXQXz0xt7ehWwOl/Ox5jDaEhHWwY1Jo5jLB6VjgHZDVNW7rqSRLL65mG9xs\nqhfi6t0Fv5Q2JxOyqaUA33UrB2P0MXnDz4mdCUhZC/XWdhGFEMOa4CJXGMfvKAKC\nNUHirFsKK4HfKD11c994gF6JU0wHSp3fppHeiutd0yi4sj9XqUgsSR11EnKT9Qm8\nxK0mjNYus+q8+CYk0+N37BMhtQAPEUoc+DGk6VVjiK1LGJUNMI0WAwi0oFzuPacE\nbCZUabtOMDDAGo9/mLy0Mr+x76nNwKBAEpP6Bn1wCz032xLLc5+IxPHvAgMBAAGj\nggHQMIIBzDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEF\nBQcDAjAOBgNVHQ8BAf8EBAMCBaAwNwYDVR0fBDAwLjAsoCqgKIYmaHR0cDovL2Ny\nbC5nb2RhZGR5LmNvbS9nZGlnMnMxLTEyMC5jcmwwUwYDVR0gBEwwSjBIBgtghkgB\nhv1tAQcXATA5MDcGCCsGAQUFBwIBFitodHRwOi8vY2VydGlmaWNhdGVzLmdvZGFk\nZHkuY29tL3JlcG9zaXRvcnkvMHYGCCsGAQUFBwEBBGowaDAkBggrBgEFBQcwAYYY\naHR0cDovL29jc3AuZ29kYWRkeS5jb20vMEAGCCsGAQUFBzAChjRodHRwOi8vY2Vy\ndGlmaWNhdGVzLmdvZGFkZHkuY29tL3JlcG9zaXRvcnkvZ2RpZzIuY3J0MB8GA1Ud\nIwQYMBaAFEDCvSeOzDSDMKIz1/tss/C0LIDOMEcGA1UdEQRAMD6CG2hvb2QuYWNj\nZXNzaWJsZWxlYXJuaW5nLmNvbYIfd3d3Lmhvb2QuYWNjZXNzaWJsZWxlYXJuaW5n\nLmNvbTAdBgNVHQ4EFgQUi2Ix81N3GaP1/83cbJpM+XkTA3EwDQYJKoZIhvcNAQEL\nBQADggEBAKneHJZzy9yasYo78TmozfHawnsMc6ibxqfybKkjg+3FqQFptAbmOM0s\n7bfkXaH8xiztpMWz/CKa4viVKXrP7tG2sJN53ZpImJNoSFygmuQPSJJkvg+2Gy9h\ncxxIOzWOZ30xP6ee19tpu9nRRRkzxBjBbJ7easLFbYK8LLz6y4oXROjopRmOgo95\nGqkj5bjzyMgj8MTpTtA6BRJAUtslFW8vubeGdUva7cBV0YuZ+p3TX2D+SvE/v6Gq\nRcirgtTkER95xUT+lJ+0VLVOYxYG7/vHDpTFK4/uP7C/vD+NHAp3xHWzO26mCETe\nknTYMKwSgln2Tp5R4/PMslPvgZnilQc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hood.accessiblelearning.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://hood.accessiblelearning.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hood.accessiblelearning.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://hood.accessiblelearning.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://hood.accessiblelearning.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://hood.accessiblelearning.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Accessible Information Management, LLC"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "AIM LLC provides software and support, systems implementation and integration, strategic consulting, and technology management services to help colleges and universities build, unify, and manage their disability services accommodations. Enterprise solutions for administration and recordkeeping. Portal solutions to enhance Web-based experiences and support community building Technology management services to better manage technology resources and provide metrics on demand. Bringing together people, processes, and technology, AIM LLC works with colleges and universities to help them strengthen performance and services through improved data accuracy and integrity, increased accountability, and enhanced educational experiences."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "cn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "o",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://coventry.ac.uk/idp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Walton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:g.walton@coventry.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gary"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Walton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:g.walton@coventry.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gary"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://coventry.ac.uk/idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAL0mMgDu5top1RP1uWsDIPodHtSIMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB4xHDAaBgNVBAMTE2lkcDIuY292ZW50cnkuYWMudWswHhcNMTMwNzEyMDkz\n\t\t\t\t\t\tNjIyWhcNMzMwNzEyMDkzNjIyWjAeMRwwGgYDVQQDExNpZHAyLmNvdmVudHJ5LmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAn6tyDBeIOr1TNvvs\n\t\t\t\t\t\ttzM3LABsvXKstxllmo4TKiRIdLHML9GeDmQeK5J+Ayly6uD+W++45pUrma0Yv9pM\n\t\t\t\t\t\t6AGXJZsSRd+JNhBrv3IV2CWGWKAZIsd/nDLO6yPDAFNsyBrCLicibY8mH/o/uXYj\n\t\t\t\t\t\tYUHkC/VB4Sjb5uzM1u+q4Vx93hYCwrZu6L6Wtr5jHdMepZ813c95wP+8+pVydY5x\n\t\t\t\t\t\ttqWjB3iTXsl+AC7Y3bqVK0FgqidVhifjBO+p8aZfxm/Ycen1LJuS7JYCCDSn/UL5\n\t\t\t\t\t\tSXo5qvEzXuKLwicugewrqXJwpzMkZif+ppl54yDwtG5pVHQT2+KwmDyXQiZAv1ji\n\t\t\t\t\t\tDikFcwIDAQABo20wazBKBgNVHREEQzBBghNpZHAyLmNvdmVudHJ5LmFjLnVrhipo\n\t\t\t\t\t\tdHRwczovL2lkcDIuY292ZW50cnkuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0O\n\t\t\t\t\t\tBBYEFBv/ZE7Ke43/cMfhyAuTRI5/hE2kMA0GCSqGSIb3DQEBBQUAA4IBAQCIZQeM\n\t\t\t\t\t\tD88/cHeyRWLIUoxBb8Pdb9HwEG51qmg7b+/dwkjomtO5uanQYdO78ar7zmnMAnNJ\n\t\t\t\t\t\tQFV9WSrp4armb7XqUSrol4OR85F+TCCGJrkRHMHbl1GKECD1iyS1Pgd0DXbP+eqz\n\t\t\t\t\t\tKaY8aNKN0PCKurzn4tTUAVXZ5vsup8GEps+/uhCHZbAAnH9ilcATposzClVpGvgl\n\t\t\t\t\t\tLFYNPVs92nXyrx4PC7rfxNEr+AEIeGdjXpbVexdcgy1q9pvRX+dp/Q9jPtg1Gq1r\n\t\t\t\t\t\tJDUzK95tyg7HYNkAgvc9sjxOxjHjJfhVob237ouSKvJHmKjF/DfNotgfYNCwqdYH\n\t\t\t\t\t\tPpU40zSkez1KZrd9"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "coventry.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.coventry.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.coventry.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp2.coventry.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.coventry.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp2.coventry.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2.coventry.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.coventry.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.coventry.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "coventry.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAL0mMgDu5top1RP1uWsDIPodHtSIMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB4xHDAaBgNVBAMTE2lkcDIuY292ZW50cnkuYWMudWswHhcNMTMwNzEyMDkz\n\t\t\t\t\t\tNjIyWhcNMzMwNzEyMDkzNjIyWjAeMRwwGgYDVQQDExNpZHAyLmNvdmVudHJ5LmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAn6tyDBeIOr1TNvvs\n\t\t\t\t\t\ttzM3LABsvXKstxllmo4TKiRIdLHML9GeDmQeK5J+Ayly6uD+W++45pUrma0Yv9pM\n\t\t\t\t\t\t6AGXJZsSRd+JNhBrv3IV2CWGWKAZIsd/nDLO6yPDAFNsyBrCLicibY8mH/o/uXYj\n\t\t\t\t\t\tYUHkC/VB4Sjb5uzM1u+q4Vx93hYCwrZu6L6Wtr5jHdMepZ813c95wP+8+pVydY5x\n\t\t\t\t\t\ttqWjB3iTXsl+AC7Y3bqVK0FgqidVhifjBO+p8aZfxm/Ycen1LJuS7JYCCDSn/UL5\n\t\t\t\t\t\tSXo5qvEzXuKLwicugewrqXJwpzMkZif+ppl54yDwtG5pVHQT2+KwmDyXQiZAv1ji\n\t\t\t\t\t\tDikFcwIDAQABo20wazBKBgNVHREEQzBBghNpZHAyLmNvdmVudHJ5LmFjLnVrhipo\n\t\t\t\t\t\tdHRwczovL2lkcDIuY292ZW50cnkuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0O\n\t\t\t\t\t\tBBYEFBv/ZE7Ke43/cMfhyAuTRI5/hE2kMA0GCSqGSIb3DQEBBQUAA4IBAQCIZQeM\n\t\t\t\t\t\tD88/cHeyRWLIUoxBb8Pdb9HwEG51qmg7b+/dwkjomtO5uanQYdO78ar7zmnMAnNJ\n\t\t\t\t\t\tQFV9WSrp4armb7XqUSrol4OR85F+TCCGJrkRHMHbl1GKECD1iyS1Pgd0DXbP+eqz\n\t\t\t\t\t\tKaY8aNKN0PCKurzn4tTUAVXZ5vsup8GEps+/uhCHZbAAnH9ilcATposzClVpGvgl\n\t\t\t\t\t\tLFYNPVs92nXyrx4PC7rfxNEr+AEIeGdjXpbVexdcgy1q9pvRX+dp/Q9jPtg1Gq1r\n\t\t\t\t\t\tJDUzK95tyg7HYNkAgvc9sjxOxjHjJfhVob237ouSKvJHmKjF/DfNotgfYNCwqdYH\n\t\t\t\t\t\tPpU40zSkez1KZrd9"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Coventry University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.coventry.ac.uk/cu/its/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Coventry University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://capuccino.iff.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Andre de Azevedo Cunha"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "acunha@iff.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://capuccino.iff.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIExTCCA62gAwIBAgIBADANBgkqhkiG9w0BAQUFADCBojELMAkGA1UEBhMCQlIx\nFzAVBgNVBAgTDlJpbyBkZSBKYW5laXJvMR4wHAYDVQQHExVDYW1wb3MgZG9zIEdv\neXRhY2F6ZXMxDDAKBgNVBAoTA0lGRjENMAsGA1UECxMEREdUSTEdMBsGA1UEAxMU\nY2FwdWNjaW5vLmlmZi5lZHUuYnIxHjAcBgkqhkiG9w0BCQEWD2RndGlAaWZmLmVk\ndS5icjAeFw0xNDA1MDYxODI1MjlaFw0xNzA1MDUxODI1MjlaMIGiMQswCQYDVQQG\nEwJCUjEXMBUGA1UECBMOUmlvIGRlIEphbmVpcm8xHjAcBgNVBAcTFUNhbXBvcyBk\nb3MgR295dGFjYXplczEMMAoGA1UEChMDSUZGMQ0wCwYDVQQLEwRER1RJMR0wGwYD\nVQQDExRjYXB1Y2Npbm8uaWZmLmVkdS5icjEeMBwGCSqGSIb3DQEJARYPZGd0aUBp\nZmYuZWR1LmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA80pYCh/E\naudRt7/Kf2qHUJkoKEfQNUa4FKh/ysAT6E5FqvzomTo3uTSqCJiLEuz8MOKnuJm5\n/ly7CVJxwZ2X0JNol8dcP1o7sPpJHToICVBaPUuw1a+fmoMaXxuLiDp88ROwcW3S\nPyp9s2QT3p18KkwmBUrCqrVAXA4GjMtUU5LWSpWVS9F05EAJGt6P5BUroFodEZbf\nCRd7lNBCOjTRUCaybY+/gPqPQmKw46FS9m00jy5WWe/zlsm+G0ibHRN51jCf5iMK\n0fsfLSC3xOHeXvJiBadb/Aiv8GPAdh41maXz/JvO6LMnTubrLGgw2rNUHTQgXmPj\noaJdj0DUuYhXyQIDAQABo4IBAjCB/zAdBgNVHQ4EFgQUOHBSiatQxvVy78q6INXo\ni8IPZcYwgc8GA1UdIwSBxzCBxIAUOHBSiatQxvVy78q6INXoi8IPZcahgaikgaUw\ngaIxCzAJBgNVBAYTAkJSMRcwFQYDVQQIEw5SaW8gZGUgSmFuZWlybzEeMBwGA1UE\nBxMVQ2FtcG9zIGRvcyBHb3l0YWNhemVzMQwwCgYDVQQKEwNJRkYxDTALBgNVBAsT\nBERHVEkxHTAbBgNVBAMTFGNhcHVjY2luby5pZmYuZWR1LmJyMR4wHAYJKoZIhvcN\nAQkBFg9kZ3RpQGlmZi5lZHUuYnKCAQAwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0B\nAQUFAAOCAQEAidU39xZ6oiq7cuPC91caVg4grC5SoZ7MAYHuQ5MNbgQgF1bQBJ1E\ntGnpBVyJTf1nwYltymxwGov4FAo0qFiqxoDOat3pkgV9CxQSBI59fC9WNb7iS+DY\nX30fDa0t4i9bGTjjpCbuU7Sp5+MHcTJVXyA13dDRWaB+TaQn/NLjz+ilBe9/Tp1N\nQKwp2MNTYTRBCoVqIIrFhLQu2nb9AAMriuJ57gVEo8tdtgRLf5K2vjoipFCUc+R9\nuWZR1Bn1QFTSbPtu9lvgvdTlm8z0HwuDYFE5gbEvWllAHtzwNzz1NMz/S6hBw8W9\npd0Oo1Kztbb+S9VqyAL+jGb+Hha5Kefw8g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://capuccino.iff.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://capuccino.iff.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://capuccino.iff.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://capuccino.iff.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://capuccino.iff.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://capuccino.iff.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://capuccino.iff.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://capuccino.iff.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.iff.edu.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.iff.edu.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFF - Instituto Federal Fluminense"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFF - Instituto Federal Fluminense"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFF - Instituto Federal Fluminense"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFF - Instituto Federal Fluminense"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIExTCCA62gAwIBAgIBADANBgkqhkiG9w0BAQUFADCBojELMAkGA1UEBhMCQlIx\nFzAVBgNVBAgTDlJpbyBkZSBKYW5laXJvMR4wHAYDVQQHExVDYW1wb3MgZG9zIEdv\neXRhY2F6ZXMxDDAKBgNVBAoTA0lGRjENMAsGA1UECxMEREdUSTEdMBsGA1UEAxMU\nY2FwdWNjaW5vLmlmZi5lZHUuYnIxHjAcBgkqhkiG9w0BCQEWD2RndGlAaWZmLmVk\ndS5icjAeFw0xNDA1MDYxODI1MjlaFw0xNzA1MDUxODI1MjlaMIGiMQswCQYDVQQG\nEwJCUjEXMBUGA1UECBMOUmlvIGRlIEphbmVpcm8xHjAcBgNVBAcTFUNhbXBvcyBk\nb3MgR295dGFjYXplczEMMAoGA1UEChMDSUZGMQ0wCwYDVQQLEwRER1RJMR0wGwYD\nVQQDExRjYXB1Y2Npbm8uaWZmLmVkdS5icjEeMBwGCSqGSIb3DQEJARYPZGd0aUBp\nZmYuZWR1LmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA80pYCh/E\naudRt7/Kf2qHUJkoKEfQNUa4FKh/ysAT6E5FqvzomTo3uTSqCJiLEuz8MOKnuJm5\n/ly7CVJxwZ2X0JNol8dcP1o7sPpJHToICVBaPUuw1a+fmoMaXxuLiDp88ROwcW3S\nPyp9s2QT3p18KkwmBUrCqrVAXA4GjMtUU5LWSpWVS9F05EAJGt6P5BUroFodEZbf\nCRd7lNBCOjTRUCaybY+/gPqPQmKw46FS9m00jy5WWe/zlsm+G0ibHRN51jCf5iMK\n0fsfLSC3xOHeXvJiBadb/Aiv8GPAdh41maXz/JvO6LMnTubrLGgw2rNUHTQgXmPj\noaJdj0DUuYhXyQIDAQABo4IBAjCB/zAdBgNVHQ4EFgQUOHBSiatQxvVy78q6INXo\ni8IPZcYwgc8GA1UdIwSBxzCBxIAUOHBSiatQxvVy78q6INXoi8IPZcahgaikgaUw\ngaIxCzAJBgNVBAYTAkJSMRcwFQYDVQQIEw5SaW8gZGUgSmFuZWlybzEeMBwGA1UE\nBxMVQ2FtcG9zIGRvcyBHb3l0YWNhemVzMQwwCgYDVQQKEwNJRkYxDTALBgNVBAsT\nBERHVEkxHTAbBgNVBAMTFGNhcHVjY2luby5pZmYuZWR1LmJyMR4wHAYJKoZIhvcN\nAQkBFg9kZ3RpQGlmZi5lZHUuYnKCAQAwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0B\nAQUFAAOCAQEAidU39xZ6oiq7cuPC91caVg4grC5SoZ7MAYHuQ5MNbgQgF1bQBJ1E\ntGnpBVyJTf1nwYltymxwGov4FAo0qFiqxoDOat3pkgV9CxQSBI59fC9WNb7iS+DY\nX30fDa0t4i9bGTjjpCbuU7Sp5+MHcTJVXyA13dDRWaB+TaQn/NLjz+ilBe9/Tp1N\nQKwp2MNTYTRBCoVqIIrFhLQu2nb9AAMriuJ57gVEo8tdtgRLf5K2vjoipFCUc+R9\nuWZR1Bn1QFTSbPtu9lvgvdTlm8z0HwuDYFE5gbEvWllAHtzwNzz1NMz/S6hBw8W9\npd0Oo1Kztbb+S9VqyAL+jGb+Hha5Kefw8g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFF - Instituto Federal Fluminense"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFF - Instituto Federal Fluminense"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iff.edu.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iff.edu.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFF - Instituto Federal Fluminense"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFF - Instituto Federal Fluminense"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibidp.amherst.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rlansaldo@amherst.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rob Ansaldo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jwmanly@amherst.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Manly"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibidp.amherst.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.amherst.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.amherst.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAKMvGP/vH0uzAwPfsNR+8twMxr8nMA0GCSqGSIb3DQEB\nBQUAMB4xHDAaBgNVBAMTE3NoaWJpZHAuYW1oZXJzdC5lZHUwHhcNMTAwMzI5MTc0\nMDIzWhcNMzAwMzI5MTc0MDIzWjAeMRwwGgYDVQQDExNzaGliaWRwLmFtaGVyc3Qu\nZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkNJ1nVz/FM/CchMM\nNfgW4ROHyNf3K15dT4LB1x+GVivrpYuvOHAY4eyhwoBfkm0t5NM19EHpsdFIVePO\nCm80WYFwCpR1lCPcN/3/JelfCTKKcjKJM6RCHUiM7e0JUlTTV/f0PEdiDrNn01wM\n9kknwkAxkXCyN4TNKT/KTMhYNwxhCqTa4QVDThJMQWXJkIbOA7pJbgmVmCfdcJub\n4E8C9gtgPTWnQPXtXxRtfH2YYd8fRwPIIx6ASW9VThOSk+FNmcbEGLpxFSRjnfMO\n+SPdVahROAhP6IAgASEBzjgp9qb4deqLjIpk1hIQhHkoKZELlUq5lezaraxOemJI\nKFoG4wIDAQABo20wazBKBgNVHREEQzBBghNzaGliaWRwLmFtaGVyc3QuZWR1hipo\ndHRwczovL3NoaWJpZHAuYW1oZXJzdC5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0O\nBBYEFMj2O62lcU/Ny7iWyJ/vDyYkzMJOMA0GCSqGSIb3DQEBBQUAA4IBAQAkppMI\ntdfWe60+4ipCZ+aT/Fg30auva3YgKZsWEsTRcJ8cMLcst27AvswP16DtKp+eksN1\nPgq+CEj6ahY1O4Rtic8hKwBsyHlMY47VdjZK2lvWBA3Dh81636jmOePQVRFqIAfQ\nEpKiUdqXNpwy61ODSFRJ/XEyod2tN+J2f5Rq2Cej6VWSNZ5FatuemjZMlxEXNi5s\ngl7fU1fEoCtBURaLf/tkzMKykipuzzSpZVS3uq8slt2jVsQlddIXR60pkGyQgr6/\nIs8EDBRpRFjVojjmYbLxcdbgEVA3CteakwkNe5Gb4gJuhFiq6nGhxFOron13TF69\nfuOjmWpbYZwDGqld"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "amherst.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.amherst.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.amherst.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.amherst.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibidp.amherst.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.amherst.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.amherst.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "amherst.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Amherst College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAKMvGP/vH0uzAwPfsNR+8twMxr8nMA0GCSqGSIb3DQEB\nBQUAMB4xHDAaBgNVBAMTE3NoaWJpZHAuYW1oZXJzdC5lZHUwHhcNMTAwMzI5MTc0\nMDIzWhcNMzAwMzI5MTc0MDIzWjAeMRwwGgYDVQQDExNzaGliaWRwLmFtaGVyc3Qu\nZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkNJ1nVz/FM/CchMM\nNfgW4ROHyNf3K15dT4LB1x+GVivrpYuvOHAY4eyhwoBfkm0t5NM19EHpsdFIVePO\nCm80WYFwCpR1lCPcN/3/JelfCTKKcjKJM6RCHUiM7e0JUlTTV/f0PEdiDrNn01wM\n9kknwkAxkXCyN4TNKT/KTMhYNwxhCqTa4QVDThJMQWXJkIbOA7pJbgmVmCfdcJub\n4E8C9gtgPTWnQPXtXxRtfH2YYd8fRwPIIx6ASW9VThOSk+FNmcbEGLpxFSRjnfMO\n+SPdVahROAhP6IAgASEBzjgp9qb4deqLjIpk1hIQhHkoKZELlUq5lezaraxOemJI\nKFoG4wIDAQABo20wazBKBgNVHREEQzBBghNzaGliaWRwLmFtaGVyc3QuZWR1hipo\ndHRwczovL3NoaWJpZHAuYW1oZXJzdC5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0O\nBBYEFMj2O62lcU/Ny7iWyJ/vDyYkzMJOMA0GCSqGSIb3DQEBBQUAA4IBAQAkppMI\ntdfWe60+4ipCZ+aT/Fg30auva3YgKZsWEsTRcJ8cMLcst27AvswP16DtKp+eksN1\nPgq+CEj6ahY1O4Rtic8hKwBsyHlMY47VdjZK2lvWBA3Dh81636jmOePQVRFqIAfQ\nEpKiUdqXNpwy61ODSFRJ/XEyod2tN+J2f5Rq2Cej6VWSNZ5FatuemjZMlxEXNi5s\ngl7fU1fEoCtBURaLf/tkzMKykipuzzSpZVS3uq8slt2jVsQlddIXR60pkGyQgr6/\nIs8EDBRpRFjVojjmYbLxcdbgEVA3CteakwkNe5Gb4gJuhFiq6nGhxFOron13TF69\nfuOjmWpbYZwDGqld"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Amherst College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.amherst.edu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Amherst College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.lawtel.com/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bukka"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:prashanthi.bukka@thomsonreuters.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Prashanthi"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Paruchuri"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:r.paruchuri@thomsonreuters.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roy"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.lawtel.com/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-06-08T12:33:56Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Thomson Reuters (Professional) UK Limited: Lawtel"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.lawtel.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Thomson Reuters (Professional) UK Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZDCCAkygAwIBAgIJAIQlCctZBRSMMA0GCSqGSIb3DQEBBQUAMCoxDzANBgNV\n\t\t\t\t\t\tBAoTBkxhd3RlbDEXMBUGA1UEAxMOd3d3Lmxhd3RlbC5jb20wHhcNMTIwNTIxMTUz\n\t\t\t\t\t\tMzE1WhcNMjIwNTE5MTUzMzE1WjAqMQ8wDQYDVQQKEwZMYXd0ZWwxFzAVBgNVBAMT\n\t\t\t\t\t\tDnd3dy5sYXd0ZWwuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\t1aHAf0QUNyTTU43/uAAgmTXyljMIEkiAbTYDdOKL/783B9Jancwz5Wcwr1uCqFRB\n\t\t\t\t\t\t9dyeElckxc1vUpdx6Nj81cX6MbhDsCGpnw2sHeWi5pFJ1J6uOL3DR4wtE758XJep\n\t\t\t\t\t\txhdMZpZXJ1F7kA/aJPS+3u1XfgAj5Wop1Lj0o9EtsEm97/VViMN39OsMAWVYsYlJ\n\t\t\t\t\t\tUdMvP6oxXADr2jQEPXyD/vr3Z0yzBwUKnx/xW95h4G8mmwAKOkPNwgHjO/qYzCSy\n\t\t\t\t\t\tcLNCL/1B21R05ZogulZGJlNrMHTuhFzT3t6zDpABQA9QAm9CWQQ3RT7shl0Qtflu\n\t\t\t\t\t\tfi5UV1TOka/oetMJEwxNeQIDAQABo4GMMIGJMB0GA1UdDgQWBBSfkHk8bDqllx8D\n\t\t\t\t\t\tlARoOx4aWRVruzBaBgNVHSMEUzBRgBSfkHk8bDqllx8DlARoOx4aWRVru6EupCww\n\t\t\t\t\t\tKjEPMA0GA1UEChMGTGF3dGVsMRcwFQYDVQQDEw53d3cubGF3dGVsLmNvbYIJAIQl\n\t\t\t\t\t\tCctZBRSMMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAI5u8pzk5pFL\n\t\t\t\t\t\t8GE7AJO8xu43xmPoXZJQI8jtXZ67xA0zDl/YKi7lyAtITABLi0no05j/B6bs30ah\n\t\t\t\t\t\tZJWIhpo1heA1Aqsvg8cc+wsMGA0G0BWRm581pdooU37lf8E6jHrHEcYnMREOLR4n\n\t\t\t\t\t\ttB+Q5JBgE7gNXnrPtKuREyXFpMVuIJaed9L2XRn0dqq8BdMH7L8INOXW2wr+Yb86\n\t\t\t\t\t\t9N5cUMdyvc/CgmvgBL859khThBVONs9kQaQqY0GANNEKnBXKOiWZsW3bcIGq8idV\n\t\t\t\t\t\taZx1wevL8m5ioTXRA6hAmwUnnPZO/o7qIiQhuMFyvjHLVG6nHS3DO+c352LSRku4\n\t\t\t\t\t\tSY88POEuhcQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZDCCAkygAwIBAgIJAIQlCctZBRSMMA0GCSqGSIb3DQEBBQUAMCoxDzANBgNV\n\t\t\t\t\t\tBAoTBkxhd3RlbDEXMBUGA1UEAxMOd3d3Lmxhd3RlbC5jb20wHhcNMTIwNTIxMTUz\n\t\t\t\t\t\tMzE1WhcNMjIwNTE5MTUzMzE1WjAqMQ8wDQYDVQQKEwZMYXd0ZWwxFzAVBgNVBAMT\n\t\t\t\t\t\tDnd3dy5sYXd0ZWwuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\t1aHAf0QUNyTTU43/uAAgmTXyljMIEkiAbTYDdOKL/783B9Jancwz5Wcwr1uCqFRB\n\t\t\t\t\t\t9dyeElckxc1vUpdx6Nj81cX6MbhDsCGpnw2sHeWi5pFJ1J6uOL3DR4wtE758XJep\n\t\t\t\t\t\txhdMZpZXJ1F7kA/aJPS+3u1XfgAj5Wop1Lj0o9EtsEm97/VViMN39OsMAWVYsYlJ\n\t\t\t\t\t\tUdMvP6oxXADr2jQEPXyD/vr3Z0yzBwUKnx/xW95h4G8mmwAKOkPNwgHjO/qYzCSy\n\t\t\t\t\t\tcLNCL/1B21R05ZogulZGJlNrMHTuhFzT3t6zDpABQA9QAm9CWQQ3RT7shl0Qtflu\n\t\t\t\t\t\tfi5UV1TOka/oetMJEwxNeQIDAQABo4GMMIGJMB0GA1UdDgQWBBSfkHk8bDqllx8D\n\t\t\t\t\t\tlARoOx4aWRVruzBaBgNVHSMEUzBRgBSfkHk8bDqllx8DlARoOx4aWRVru6EupCww\n\t\t\t\t\t\tKjEPMA0GA1UEChMGTGF3dGVsMRcwFQYDVQQDEw53d3cubGF3dGVsLmNvbYIJAIQl\n\t\t\t\t\t\tCctZBRSMMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAI5u8pzk5pFL\n\t\t\t\t\t\t8GE7AJO8xu43xmPoXZJQI8jtXZ67xA0zDl/YKi7lyAtITABLi0no05j/B6bs30ah\n\t\t\t\t\t\tZJWIhpo1heA1Aqsvg8cc+wsMGA0G0BWRm581pdooU37lf8E6jHrHEcYnMREOLR4n\n\t\t\t\t\t\ttB+Q5JBgE7gNXnrPtKuREyXFpMVuIJaed9L2XRn0dqq8BdMH7L8INOXW2wr+Yb86\n\t\t\t\t\t\t9N5cUMdyvc/CgmvgBL859khThBVONs9kQaQqY0GANNEKnBXKOiWZsW3bcIGq8idV\n\t\t\t\t\t\taZx1wevL8m5ioTXRA6hAmwUnnPZO/o7qIiQhuMFyvjHLVG6nHS3DO+c352LSRku4\n\t\t\t\t\t\tSY88POEuhcQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "want_assertions_signed": "false",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://www.lawtel.com/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.lawtel.com/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.lawtel.com/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.lawtel.com/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://kilwtest.it.ki.se/shibboleth",
    {
      "entity_id": "https://kilwtest.it.ki.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://kilwtest.it.ki.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://kilwtest.it.ki.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://kilwtest.it.ki.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://kilwtest.it.ki.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://kilwtest.it.ki.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://kilwtest.it.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://kilwtest.it.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://kilwtest.it.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://kilwtest.it.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "kiladoktest01.it.ki.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJAMJ9LjHSUsvoMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmtpbGFkb2t0ZXN0MDEuaXQua2kuc2UwHhcNMTEwNTI2MTMyNTMzWhcNMjEw\nNTIzMTMyNTMzWjAhMR8wHQYDVQQDExZraWxhZG9rdGVzdDAxLml0LmtpLnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqOUmjHK3EDwdhiUDbm9oW/u8\nn/ksrSapvbz+TTMQ70a01QHdcU1d48Dq2rjOVUpiZvV+SVjrSsSaqoTW6X0jUwgO\nnzQZayVMGia9x5Y0zphksK0RIXrcZhN34zamHyg+ioVqumZWVfaXbfkDUphfJ25E\n+HzioYe9pzr+dWeS0bTMQ6kcgI+KZqVfpKYeNn/6c5zgfYFUy8lp7pYr5yRr7HKM\nxbezT7PTdMIXwqI291G4VaTed/jDFOtYInMI3nGcg1U75TjMxbJIjDl24hWMxb3t\nWP1vAQvQDhTYuAPaQZq/FPCYWBbbKmHUG2RcquSWYullHwvWgRnzXi04/8luwQID\nAQABo0QwQjAhBgNVHREEGjAYghZraWxhZG9rdGVzdDAxLml0LmtpLnNlMB0GA1Ud\nDgQWBBTm4IeB4clBD5Xy65Su9mR25oz94DANBgkqhkiG9w0BAQUFAAOCAQEApjAT\nZMzYK0b21AfhOC4ELmXzRIG7tjEqpG1S2KGjTML3OPQ3iqY0+6NH5ihcG7L5U+Ot\nS3HswID9RV4fRkvB2HJ1cBDSH8DbCCi6LyYydJPfJloYJ/AdrumlJQDVJRNyYD6T\n53on7zeJaKv3n9eJrhqdnoEy0ofJtTAydbEx+F3AT3tW+jjpo5biuyuOa6W0wv0J\nDICtfX5UbSz96NxJbSCjoD23hMXqMOcUT3Pllk1MuPeK18rxZWy8qwxVk+E/haLr\nOaQPhM+ucEz0I/gHI37mAyzAz8w9PSTjwN+GKKngB+8IcdOQcUVRIhhTtu+ukBjR\ne01/KT+BtiGpAdoAUA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=kiladoktest01.it.ki.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://kilwtest.it.ki.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://kilwtest.it.ki.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://kilwtest.it.ki.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://kilwtest.it.ki.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://kilwtest.it.ki.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://kilwtest.it.ki.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://filesender.du1.cesnet.cz/saml/sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kopecky - administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "du-support@cesnet.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lubos"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://filesender.du1.cesnet.cz/saml/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2014-09-01T17:40:43Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CESNET"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CESNET"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ces.net/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cesnet.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CESNET"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://filesender.du1.cesnet.cz/simplesaml/module.php/saml/sp/saml2-logout.php/filesender.du1.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://filesender.du1.cesnet.cz/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://filesender.du1.cesnet.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CESNETs servis for sending files."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Cesnet\u00ed slu\u017eba pro pos\u00edl\u00e1n\u00ed soubor\u016f."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FileSender"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FileSender"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://filesender.du1.cesnet.cz/simplesaml/module.php/saml/sp/saml2-acs.php/filesender.du1.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://filesender.du1.cesnet.cz/simplesaml/module.php/saml/sp/saml1-acs.php/filesender.du1.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://filesender.du1.cesnet.cz/simplesaml/module.php/saml/sp/saml2-acs.php/filesender.du1.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://filesender.du1.cesnet.cz/simplesaml/module.php/saml/sp/saml1-acs.php/filesender.du1.cesnet.cz/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:profiles:holder-of-key:SSO:browser",
              "location": "https://filesender.du1.cesnet.cz/simplesaml/module.php/saml/sp/saml2-acs.php/filesender.du1.cesnet.cz",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://uraccess.net/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:onsite@ur.se"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Nilsson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Michael.Nilsson@ur.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://uraccess.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uraccess.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://uraccess.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uraccess.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uraccess.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uraccess.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://uraccess.net/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://uraccess.net/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UR access inneh\u00e5ller ca 18000 TV- och radioprogram fr\u00e5n Utbildningsradion."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UR access - Mediebiblioteket f\u00f6r h\u00f6gskolor och universitet."
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://uraccess.net/shibboleth"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "uraccess.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAP6pqK7LD1xfMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDHVyYWNjZXNzLm5ldDAeFw0xNTEyMDgxMzQyMDVaFw0yNTEyMDUxMzQyMDVa\nMBcxFTATBgNVBAMTDHVyYWNjZXNzLm5ldDCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAPL5dGUPusdwnwRW2S/M+fVgjAxGl9W41JLeHGrd3FRDiLxo47MX\nOLYI8qdzhts3z+G83htGlJI0Iowj6PKQx3xWPmCmFaA8y1Wpx2Y8FT7eJ277F5KL\nKIDoqgL78yubSwyl3sNgjNq0KJ+PHU1WirSwmiJV0dQfX5hc4Ca1UTkQ9H0T9QQL\nXpLF/tqpxJGGbceShZHi1W34pQqhYQaIxl+QhREAybQSMa0cnfXIoTOdgf/6eKCo\n5JoFWtXJMesgDji5R+2wXmbaKCVH5KDcd3pRqb0dKsdGfzaXdqbtTVwj0LezC+4v\nnV7WOn7+zb9GCIBvg1VBrSlOWHrIoqZM7dUCAwEAAaNbMFkwOAYDVR0RBDEwL4IM\ndXJhY2Nlc3MubmV0hh9odHRwczovL3VyYWNjZXNzLm5ldC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBT3qHcAVqfrG19CM9/c1Jlf6/Tf6DANBgkqhkiG9w0BAQUFAAOCAQEA\nXdxT+SX0jtLPiAptvIDrrmc7eG20M/seqsPiIDmuJFeuw7k7vyG2rL6yEGpKVTyX\nBTM2wp9H6vC35z+R3O3c7GMP37LcJMHSwcCgQPWboIp/nxEGEGFwHPB0dUN5qvLR\nOQyxsrnkpOih7FXNtpHItLDGS8JDac4TRWE4x1b1r/B0t50TsXe3Pa6t/H/sGugT\nWA1u0ZsP4QtQfCFyJlIisLruEDEydRdT1UNUcbo6TsRW33G5rzAH9X6+D19LnFRg\nW/UOQjERpXGqmGI72CVn9Q8PXeKyVvIl7zaSzz9GLjJpQLdjkSWHW+qMH+7kbn4S\nRXmDTYIhHnjv+Sc7dzCbIA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=uraccess.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uraccess.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://uraccess.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uraccess.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uraccess.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uraccess.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uraccess.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://uraccess.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://uraccess.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://uraccess.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://instantanatomy.co.uk/shib",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Whitaker"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@instantanatomy.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Whitaker"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@instantanatomy.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://instantanatomy.co.uk/shib",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-09-17T08:48:25Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Instant Anatomy"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://instantanatomy.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Andrew Whitaker trading as Instant Anatomy"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://instantanatomy.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://instantanatomy.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://instantanatomy.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://instantanatomy.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://instantanatomy.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://instantanatomy.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://instantanatomy.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "logo": [
                  {
                    "text": "https://www.instantanatomy.co.uk/images/title.jpg",
                    "height": "62",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "450"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Instant Anatomy"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJAOU2/77+QBVIMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\n\t\t\t\t\t\tBAMTG2Rhcndpbi5pbnN0YW50YW5hdG9teS5jby51azAeFw0xMjA4MTcwMTQ5MzFa\n\t\t\t\t\t\tFw0yMjA4MTUwMTQ5MzFaMCYxJDAiBgNVBAMTG2Rhcndpbi5pbnN0YW50YW5hdG9t\n\t\t\t\t\t\teS5jby51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL5l4CVTvTSr\n\t\t\t\t\t\twY4T+jbnjlcqK7uLjuUnblB1tp+UClVHk31XDiJGDC/G8uUmL275wVRKcvC5Uj5m\n\t\t\t\t\t\t1+SK5wNJ+4DkDLFhpho7adK/UZLW6EMvpgUg5nSq5qeJErkDdmexwUgWMX9v4YYr\n\t\t\t\t\t\tCDxN9qQ3Mf869ORLNUwwwMN+sPT6p8ppiYpdjR1lLkmFRNWPiWztxA2gbHWueC6H\n\t\t\t\t\t\tNBDxEH3NitETaKo2KV0R2S/7yLa9f0yffK5M8n26WFoTE/OPKhiN/lyT+8ZRQe3E\n\t\t\t\t\t\tO6MEPQudNhQuR0/7vvd1giIvQr9ARy4tpROL3VQ1VFLeVaoHQgPi8XDkRrUGoGnf\n\t\t\t\t\t\tcoCiPWctp30CAwEAAaNJMEcwJgYDVR0RBB8wHYIbZGFyd2luLmluc3RhbnRhbmF0\n\t\t\t\t\t\tb215LmNvLnVrMB0GA1UdDgQWBBRCrm+NptHsROj8vWQkA1ifzUbsPzANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAkKx3nfhfX4Am9Isc0yEXdtJznme1IxfFXHauCupdnZnZU2yd\n\t\t\t\t\t\tsOqqZaeiEf1E3KU+PcL9m8/syQ9O8RfiTdkrXPwRsrGll6Rpg0s6QHYLpiWRkeu+\n\t\t\t\t\t\tMXgBUGS7F+HdMah4vBYlB1xK2q5wlzKhFiXWqWuHqpHOlYVgRvVyJhqzwT9QVhgF\n\t\t\t\t\t\tzvqMQdvEtFw0qF7qwDlxkzDp8qWfa7bNnehynDwVxB6jAdgXbSbu5sqBlTB0naJE\n\t\t\t\t\t\t1L8iCT+oVfbn8m7vBIwAey/qzie5Av0Q2XHH0cAwff2AQUrlyTcPbkpfna8jnaaK\n\t\t\t\t\t\t5mOU0vif+aQQFPvwVH2BegxgQF+M+0NVs02wMQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://instantanatomy.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://instantanatomy.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://instantanatomy.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://instantanatomy.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://instantanatomy.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://instantanatomy.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Instant Anatomy"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib1.coastal.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mrichter@coastal.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike Richter"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib1.coastal.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib1.coastal.edu/idp/profile/Logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib1.coastal.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib1.coastal.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "coastal.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Coastal Carolina University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAPmtKMkTjP6RBo5vqaqeBo9Cwh65MA0GCSqGSIb3DQEB\nCwUAMBwxGjAYBgNVBAMMEXNoaWIxLmNvYXN0YWwuZWR1MB4XDTE1MTIyMTE5NDAw\nOFoXDTM1MTIyMTE5NDAwOFowHDEaMBgGA1UEAwwRc2hpYjEuY29hc3RhbC5lZHUw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCFJu1ciBx39t6+Ez8mE8ZE\ntvQvdcBbckSyGgPoBGhdS34gswsnUoJtNp6W1++Pqo3bGuhk+iysP7HewRSyKDX9\nJTo7ZDuMKxTOwfBH/GllBP/Uar/f0QVFjMIjAXVzN0N71vEaFz52344FRcU3Fi6F\nz4CuaiKuQlQ9Qsq60rdP6hNLHNav2rFCclVuLLN129w/1v9oDZfTIQeLOgGF2KSF\nP/l7TzX89pb2vSTTfhVMI2JqwEerMVmtx7Z8zI8U1t799PHdLkBatK/7vIQYeElV\nBm3MNITWFr9CZX6q4FYQhxWOTYzaxnOQe5Aqh9KfZsQ5xv1vR3JIqvVaPEBPVfcz\nAgMBAAGjaTBnMB0GA1UdDgQWBBS6y0a1WXOva6WsTyLrd035hpR9cTBGBgNVHREE\nPzA9ghFzaGliMS5jb2FzdGFsLmVkdYYoaHR0cHM6Ly9zaGliMS5jb2FzdGFsLmVk\ndS9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAATVOzwx2FSYs9n0j\nwjvrcvbI9AzPf0tLrlb/zGwsqO5ngChQGml+tl7vAML1Dnw0xi7c6BSty7f9W72y\nIk3uUiDkw0vm2b8LFJyBDyn5uC6QDXVWVmzLfFyn2pwOV+hcKiClQYVdLVBxjzOT\nBN++tfOCsM+vDod0FgGniMInlmkUNn9fQgeWO4EHW7SSF6B92cmxyjQbxWpYiJIj\nkF50bURYh9pl1w+m1JehzSeR0rPuFhx5uMXuD34tyO0ofwmlKJB+MCnhpZh9VXsU\nVySeXmS5PG0tCJeyQU0flRjY0Yvpy7VmPYBCiFjhKJ8/k5wHRO1fA7Dw052XeDZP\nT9t6jQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Coastal Carolina University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.coastal.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Coastal Carolina University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://edulidp01.hants.gov.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Reynolds"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Andy.Reynolds@hants.gov.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andy"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wigley"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:David.Wigley@hants.gov.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://edulidp01.hants.gov.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVAItvDndSZma37nVve6iWg0pw8KVmMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCExHzAdBgNVBAMTFmVkdWxpZHAwMS5oYW50cy5nb3YudWswHhcNMTEwNjAz\n\t\t\t\t\t\tMDgwNzIzWhcNMzEwNjAzMDgwNzIzWjAhMR8wHQYDVQQDExZlZHVsaWRwMDEuaGFu\n\t\t\t\t\t\tdHMuZ292LnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArR3KsSDW\n\t\t\t\t\t\tb06i0KYMDPvX86rGjYAdZ8Fk7KEb+Chx71umaIEZMZ+C0nXWNq5xO0+6XVDe0f2I\n\t\t\t\t\t\tz5WVzoQjIlEnx84C+zxGFLHyB/1JXKslo3EZQjAcl37AROndH0ONdKgvmRS5ZM4u\n\t\t\t\t\t\tEVo0NlWG1p2P7pz+kMfFb+mT+Bi+bcyO5UtyMZbvXD6iVax1kb1m1+r1BgHLvDP0\n\t\t\t\t\t\trFJCK2mzyuSJuiMxwu9WTc3jMqltnmGwWe1AyLQCaSvch1Xg3PerBFO0rPWEDWdz\n\t\t\t\t\t\tj9We9SXGXoVlVMdx5ttrUOYQIo/p0sbqNSKslB4MaWaFZ7SwR+DdKagtAxW2catQ\n\t\t\t\t\t\tLelvYpERLNeXNQIDAQABo3MwcTBQBgNVHREESTBHghZlZHVsaWRwMDEuaGFudHMu\n\t\t\t\t\t\tZ292LnVrhi1odHRwczovL2VkdWxpZHAwMS5oYW50cy5nb3YudWsvaWRwL3NoaWJi\n\t\t\t\t\t\tb2xldGgwHQYDVR0OBBYEFFHhnpqMIOC7wc8J37OSqa7W/LJZMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQBnwvEGRoWUVFjl3zntI4LUY7/PVNe0JSklGtE44sBSl5AwWSROkt3U\n\t\t\t\t\t\tQ5gv2d/Cjp7Y1adDF9fF1KjrjCsv188xGXqv96C+qcED9nV9/mE25GfMAWBAn+94\n\t\t\t\t\t\tyTsvBdA7JsVHRPBWhXzkLZkA0/9nGmn2dQx7dwTnVaDW58SgOml+WO0j5bn4hk9b\n\t\t\t\t\t\tuxD/Qa526RvMoHEBk1cmy15UVfCvZXRewVPeKDSHy5x13rnIK7rejXRzEaWNyQDi\n\t\t\t\t\t\tiTIi5utX40Mu6owRgH2ITRxgHg+TkWgZ09jsvvP+mPH0OwySBmEP1KShjREYY8xc\n\t\t\t\t\t\tKVCAwfy+2kJgcyZ1eZjwKeZlIzZRW6C+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hants.gov.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://edulidp01.hants.gov.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://edulidp01.hants.gov.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://edulidp01.hants.gov.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://edulidp01.hants.gov.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://edulidp01.hants.gov.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://edulidp01.hants.gov.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://edulidp01.hants.gov.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://edulidp01.hants.gov.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hants.gov.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVAItvDndSZma37nVve6iWg0pw8KVmMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCExHzAdBgNVBAMTFmVkdWxpZHAwMS5oYW50cy5nb3YudWswHhcNMTEwNjAz\n\t\t\t\t\t\tMDgwNzIzWhcNMzEwNjAzMDgwNzIzWjAhMR8wHQYDVQQDExZlZHVsaWRwMDEuaGFu\n\t\t\t\t\t\tdHMuZ292LnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArR3KsSDW\n\t\t\t\t\t\tb06i0KYMDPvX86rGjYAdZ8Fk7KEb+Chx71umaIEZMZ+C0nXWNq5xO0+6XVDe0f2I\n\t\t\t\t\t\tz5WVzoQjIlEnx84C+zxGFLHyB/1JXKslo3EZQjAcl37AROndH0ONdKgvmRS5ZM4u\n\t\t\t\t\t\tEVo0NlWG1p2P7pz+kMfFb+mT+Bi+bcyO5UtyMZbvXD6iVax1kb1m1+r1BgHLvDP0\n\t\t\t\t\t\trFJCK2mzyuSJuiMxwu9WTc3jMqltnmGwWe1AyLQCaSvch1Xg3PerBFO0rPWEDWdz\n\t\t\t\t\t\tj9We9SXGXoVlVMdx5ttrUOYQIo/p0sbqNSKslB4MaWaFZ7SwR+DdKagtAxW2catQ\n\t\t\t\t\t\tLelvYpERLNeXNQIDAQABo3MwcTBQBgNVHREESTBHghZlZHVsaWRwMDEuaGFudHMu\n\t\t\t\t\t\tZ292LnVrhi1odHRwczovL2VkdWxpZHAwMS5oYW50cy5nb3YudWsvaWRwL3NoaWJi\n\t\t\t\t\t\tb2xldGgwHQYDVR0OBBYEFFHhnpqMIOC7wc8J37OSqa7W/LJZMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQBnwvEGRoWUVFjl3zntI4LUY7/PVNe0JSklGtE44sBSl5AwWSROkt3U\n\t\t\t\t\t\tQ5gv2d/Cjp7Y1adDF9fF1KjrjCsv188xGXqv96C+qcED9nV9/mE25GfMAWBAn+94\n\t\t\t\t\t\tyTsvBdA7JsVHRPBWhXzkLZkA0/9nGmn2dQx7dwTnVaDW58SgOml+WO0j5bn4hk9b\n\t\t\t\t\t\tuxD/Qa526RvMoHEBk1cmy15UVfCvZXRewVPeKDSHy5x13rnIK7rejXRzEaWNyQDi\n\t\t\t\t\t\tiTIi5utX40Mu6owRgH2ITRxgHg+TkWgZ09jsvvP+mPH0OwySBmEP1KShjREYY8xc\n\t\t\t\t\t\tKVCAwfy+2kJgcyZ1eZjwKeZlIzZRW6C+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hampshire County Council"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hants.gov.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hampshire County Council"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://umshibp.olemiss.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "daksh@olemiss.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Daksh Chauhan"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "daksh@olemiss.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Daksh Chauhan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://umshibp.olemiss.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://umshibp.olemiss.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://umshibp.olemiss.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://umshibp.olemiss.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://umshibp.olemiss.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://umshibp.olemiss.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "olemiss.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://en.wikipedia.org/wiki/University_of_Mississippi"
                  }
                ],
                "logo": [
                  {
                    "text": "https://secure1.olemiss.edu/irj/go/km/docs/documents/UMImages/UMLogo.png",
                    "lang": "en",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "400"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Mississippi"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAJ02en1t5aWOCxE4dPI/WEGJxW7gMA0GCSqGSIb3DQEB\nBQUAMB4xHDAaBgNVBAMTE3Vtc2hpYnAub2xlbWlzcy5lZHUwHhcNMTIwNzE3MTQy\nMDQyWhcNMzIwNzE3MTQyMDQyWjAeMRwwGgYDVQQDExN1bXNoaWJwLm9sZW1pc3Mu\nZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAv04ygC3gn9pyefto\nMYGjHlyX2T2NNlOSDX3uGYyzAGeHngFrvEPxZD6wN/IO8nCRlGOm+JkKeqqg1OpQ\nVjpXthFqN1sxZwNtAxokfRSEaHFChl5t0ciCuxic4grnHvOQtJulonO/qwbXPMhm\nRkKKbRtYTRcn92uxoUcPH6MgriDUIgfSwDR01VRA03s3Y++Hs2Qyy1oqC1hHYvuL\npXCp+6DoIdGsyksaZtskYrq4a9mSRXZ8q1Re/Ma7LB7lHTkOO0qD9xALLm7eLj71\nBpgFTlno2IHgZSZ/IaUsU0zUb6RXDanO+SKCkX6wwvq+WttrVxZ5Qyh+xQg2EZSg\ntttj/QIDAQABo20wazBKBgNVHREEQzBBghN1bXNoaWJwLm9sZW1pc3MuZWR1hipo\ndHRwczovL3Vtc2hpYnAub2xlbWlzcy5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0O\nBBYEFG6CZ99+tMD6Z1RRYWY9+WEEYsOCMA0GCSqGSIb3DQEBBQUAA4IBAQC6Clv4\n+OLHTrPh4g6RbiZP7Q6uDyHwTdyPcpxB6g5YiQqMzfCqmlg1JO9LXcGnhO0ngjPw\nGS5fUCqUzQw14yXBD6Bq3IAK022afq6DkZkKpsvAv7s4EBFFhYSbg8iJfdheEQMb\nGV6aahGWm1VZToICFALOqFrkI9PteT7Mkksnc7kPXKifdYDMhajhP6ap/ANBQd0X\nkXK+zix7sCJdKO5v6bbmXuGSFT+KRQnHWEC/mDgfU/CwVtVcalFMLAamSa/Y8yzm\n7c2UaQVnu2J/dRQROe7fBs4XdIjF7/kaLlO0fQaNqrQ7PBJLgNbmGGn1vgVPrD47\nnjcg/y96NdqwknJF"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Mississippi"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.olemiss.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Mississippi"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://urn.nbi.ku.dk/saml/sp/wayf",
    {
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2015-01-30T09:31:59Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute_value": [
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "kalmar"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "denmark"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "iceland"
              }
            ],
            "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
            "name": "tags",
            "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "webauth-admin@nbi.ku.dk"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "NBI IT"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://urn.nbi.ku.dk/saml/sp/wayf",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.nbi.ku.dk/wayf/sp/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Form\u00e5let er at give adgang til NBI-tjenester."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The purpose is to provide access to NBI web services."
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NBI's Applikationsserver"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NBI Application Server"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.nbi.ku.dk/wayf/sp/postResponse",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Form\u00e5let er at give adgang til NBI-tjenester."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The purpose is to provide access to NBI web services."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "NBI's Applikationsserver"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "NBI Application Server"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAssurance",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.11",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cloudstandards.cesnet.cz/sp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Trestik"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Vladimir.Trestik@cesnet.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Vladimir"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cloudstandards.cesnet.cz/sp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2015-01-29T11:27:01Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/sp-group/aa.cesnet.cz"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CESNET"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CESNET"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ces.net/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cesnet.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CESNET, z. s. p. o."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cloudstandards.cesnet.cz/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cloudstandards.cesnet.cz/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cloudstandards.cesnet.cz/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cloudstandards.cesnet.cz/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cloudstandards.cesnet.cz/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://cloudstandards.cesnet.cz/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://cloudstandards.cesnet.cz/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://cloudstandards.cesnet.cz/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://cloudstandards.cesnet.cz/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://cloudstandards.cesnet.cz/Shibboleth.sso/DSEG",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://cloudstandards.cesnet.cz/Shibboleth.sso/DSEG",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "staff-sp"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICojCCAYoCCQDl+ffNPW8XLTANBgkqhkiG9w0BAQUFADATMREwDwYDVQQDEwhz\ndGFmZi1zcDAeFw0xMTA1MzExNTEyMDFaFw0yMTA2MDExNTEyMDFaMBMxETAPBgNV\nBAMTCHN0YWZmLXNwMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArw2P\nfWdRZqiAvzuhmPl/ZNOTsN3Pvp/bsAWtEMfZDNcd7KAbeBuVsiprbX16tdiJYTgD\n0VqxCnzfYqt3FVHi4zKN4nUJEYG2q78Nz+iMdsbF8w4KzljL7VMv1hR3K9C2dPBj\nfeZ0mupBlxpk6VcVoHmcVWVP5pN7bTK1uGak0Qx15aJoT6WvhmKwIUB/aAlTn+bQ\nj901evtXa02r/dUHEADEA8ZmhWyxmr8yN8Nol/orwqODKcP269mO8XfTegIZeVYQ\nqj/4S+AhDkXxapJcZXFdlh9elIsQYICRxvEA51Dy8guFoVNNAqpoLj89Fer1R/P3\nxz38pBg6pUW11iVWvwIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQAGfoWQpL9YnlGk\nyeKreOtzpaPNL6UeHPaw/fpTP5RJFlJtxvHmVwDMsRtx+jWpEXaxtCdIrYil8FJL\n68M26xrXtHWSiTovlqMkLZZw4Xwjd2jAeuYVrS84z3c3PCDylafQNddkLJoP3k+y\nv7MEHao5A1SEqRi7CJoeEjTQYV95fsjccLgrjQZWlyC9JauC0+TTbLt3VeASOqaW\nEG3oNAFsAT2ZTYrBpcc1SilLhSV9AtkoYk+g5Ek72S4mCdAb5PColu5krxYZ7gz6\nN02qjxZaJg7RvbagR5qJHKKMuXhYoh87YBC5eheBYdTc4LVIsz74sF6xrcgytZRL\nJcBgGx9A"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=staff-sp"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cloudstandards.cesnet.cz/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cloudstandards.cesnet.cz/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cloudstandards.cesnet.cz/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://cloudstandards.cesnet.cz/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://cloudstandards.cesnet.cz/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://cloudstandards.cesnet.cz/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://adfs-mali.icer.niaid.nih.gov/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-support@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Technical Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-support@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-support@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Technical Support"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-admin@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Administrative Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://adfs-mali.icer.niaid.nih.gov/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "National Institutes of Health"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nih.gov/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National Institutes of Health"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://adfs.icermali.org/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://adfs.icermali.org/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://scienceforum.sc/adfs-mali.html"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Requests and obtains identity assertions on behalf of Windows-based web applications at the NIAID ICER in Mali"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://scienceforum.sc/privacy.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NIAID ICER-Mali Federation Gateway"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFeTCCA2GgAwIBAgIJAPzWRexOtTLQMA0GCSqGSIb3DQEBDQUAMFMxJTAjBgNV\nBAMMHGFkZnMtbWFsaS5pY2VyLm5pYWlkLm5paC5nb3YxKjAoBgkqhkiG9w0BCQEW\nG2ljZXItdnJvLWFkbWluQGxpc3QubmloLmdvdjAeFw0xNjAxMDgxODI3NDFaFw0y\nNjAxMDUxODI3NDFaMFMxJTAjBgNVBAMMHGFkZnMtbWFsaS5pY2VyLm5pYWlkLm5p\naC5nb3YxKjAoBgkqhkiG9w0BCQEWG2ljZXItdnJvLWFkbWluQGxpc3QubmloLmdv\ndjCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIBAMxKRAjTHlBoSXZ/QiqE\nRy04mlmUBNOqiOTeJxe1SqB3N+ZSjqZEW1lDz0WUlMTJRbQ6eU2YBlxnXjuTi2/E\ngRepZygO44yVktX6e08WYpei2xZwm0r0AejVXi5Ef/aQR48ouATBaUhENPlbQn+U\n66Et46SKmPv6tq9ihGWIl26Z8ef2AkREqKrkLV/1jPNt7tj/Nff21VmFYh7Cv0Ey\nOzQ+5mrN6TSn9k94sT8SOT2NkHaOQCprxX+MOXX8AIUMsT0R4FVck4Z6+HwyPfb4\nWhMPqt50/zJgA+3GZtwcNfSUa2l1JBYJulOO5FCCNRfzZZVul7bRBD9mb6SyCOJx\naNg7jR0qsBzp6W6OuDWaPu3cKitP4T18oyMJOl/Xt7+oGwbcxAXOmLBSIlQJfRME\n41/0nl1sDf+bxyZXFTcK2+VNsI+r7pGBFefWEC3sT9fgynVvenX0Lv/2gjtEVQfi\nzIk1eZ9Yc6UVSYG4d3Zilx049k7KjzHi1EAEA/0MOjnP22I1YRWn9vRM4B5VO9qq\nLTqPmIMyP/wRmMjiuARo9HWkQD9x8UOsboCkt7gaJgVVVs96gRXDiSyOPePmPArT\nRnlIJSUxzLep+CHIIAlOa073tu+fviDfsUODx1sEJv509xF+aFDnJkin+lHu8wqD\nNc0AzjrNNRNpLPnpGYcZhsTzAgMBAAGjUDBOMB0GA1UdDgQWBBSZiFDKzbdEhAwU\n4wiyQY7kyaKtvjAfBgNVHSMEGDAWgBSZiFDKzbdEhAwU4wiyQY7kyaKtvjAMBgNV\nHRMEBTADAQH/MA0GCSqGSIb3DQEBDQUAA4ICAQBlSXO918v9KmyE8DeEviQ9gdF/\npmvgO/277aANz/pKY8ELmArDV7zHvURO+igM8PzuTh1kAOorRU7TppxSkJw30KYO\nNs4kTe8gfQAbzf/bahoVhlWcFjGbbDipDcj6CmB1VWmCXx+2H9UqLX4EaqSSiu8n\naOoZijeqS5alFsTdmVrBdz8qsQBzmNJJEogLg+aLCUrg/RFV3r82ZElHstTk20G8\nhGD5qMpN/8OeVRn4YtkyPntQCtlDQHc7LFaCfEgwMFwA+9tscUHEzlMxU0tQcekw\niVAinzW2WWj5UAZVOa81YvTjCJ9XMt+u/7y20v4V7oKj98eM1CFdGCRCqxFF+t/S\nlSRk4PPd8QxfF/7dmhZGLjurPgeGNnCvfO8tZooBKEGU6pc1UZ3XmDkGK+ugSgp+\nGlpl/YflcSRcq//ELLT9GECjhKaDjOfdy34bgYSuIHY/yzTo9R6Bqt9P55nR0+x2\n4iBJ+PODTqEr2SXe/Ai8uOWPufLL9Nqv04csRy9dRrkN8WUwD1wPYKKsnR+7PiHp\nLkMSWluMA+gLMRDnDHwpuu/QJQEeIsTPi+fDCZ+/PHddIZck2iIt2n67X27mzPAQ\nOpD2hjTr3LyoXZ7UWa16wO7x8G4Y2UJXPgG3n6q81tAAZiK1pxf/tzXghNBZXoTn\nEG/9OZqJXrOF9vasDA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://adfs.icermali.org/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://adfs.icermali.org/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "NIAID ICER-Mali Federation Gateway"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Requests and obtains identity assertions on behalf of Windows-based web applications at the NIAID ICER in Mali"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.csus.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idm@csus.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brennan Pike"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.csus.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.csus.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.csus.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFiTCCBHGgAwIBAgICAp8wDQYJKoZIhvcNAQEFBQAwVjELMAkGA1UEBhMCVVMx\nHDAaBgNVBAoTE0luQ29tbW9uIEZlZGVyYXRpb24xKTAnBgNVBAMTIEluQ29tbW9u\nIENlcnRpZmljYXRpb24gQXV0aG9yaXR5MB4XDTA5MTAxMzE3NTkwOFoXDTExMTAx\nNDE3NTkwOFowFzEVMBMGA1UEAxMMaWRwLmNzdXMuZWR1MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAsK3s8yjwINisx1tBv8/BaXvdawmKEnpOzAkz5G8H\ncca8nP1Rlp+tSXFTcnm8fdMj10TO1XLNbF6xOYtFXZ2pZykRz6tBeM4cxNUPLafP\nYQTCkKRZ7OXXqhacnZ7X2nUl+6JZYZpNAAjAl5pX0jznXCltQzHUx0DCE4z0CTny\nmVQ+6Q9Ou2w4giJEVEtgFvtUZFccxBM7ifV376GeRQKz83OMwWcvQZNvbHthbxc/\n1+Xhv4XgJhYMqXHYNG5Fkg4rX/dAsQHff4Ncdh+cCjGSzCQvxvKZNENFIwPPV2Cw\n1LXJEGy5R8dnG5KTZ9pmoF6whN7+70GUBxUJ3ENsiBqvvQIDAQABo4ICnjCCApow\nDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUH\nAwEGCCsGAQUFBwMCMB0GA1UdDgQWBBQA+XJi1NGtvakAmNAlHsMDqC2G7jB+BgNV\nHSMEdzB1gBSTLchhGK1j45tls53djZO658pjRaFapFgwVjELMAkGA1UEBhMCVVMx\nHDAaBgNVBAoTE0luQ29tbW9uIEZlZGVyYXRpb24xKTAnBgNVBAMTIEluQ29tbW9u\nIENlcnRpZmljYXRpb24gQXV0aG9yaXR5ggEAMIGyBggrBgEFBQcBAQSBpTCBojBP\nBggrBgEFBQcwAoZDaHR0cDovL2luY29tbW9uY2ExLmluY29tbW9uZmVkZXJhdGlv\nbi5vcmcvYnJpZGdlL2NlcnRzL2NhLWNlcnRzLnA3YjBPBggrBgEFBQcwAoZDaHR0\ncDovL2luY29tbW9uY2EyLmluY29tbW9uZmVkZXJhdGlvbi5vcmcvYnJpZGdlL2Nl\ncnRzL2NhLWNlcnRzLnA3YjCBjQYDVR0fBIGFMIGCMD+gPaA7hjlodHRwOi8vaW5j\nb21tb25jcmwxLmluY29tbW9uZmVkZXJhdGlvbi5vcmcvY3JsL2VlY3Jscy5jcmww\nP6A9oDuGOWh0dHA6Ly9pbmNvbW1vbmNybDIuaW5jb21tb25mZWRlcmF0aW9uLm9y\nZy9jcmwvZWVjcmxzLmNybDBeBgNVHSAEVzBVMFMGCysGAQQBriMBBAEBMEQwQgYI\nKwYBBQUHAgEWNmh0dHA6Ly9pbmNvbW1vbmNhLmluY29tbW9uZmVkZXJhdGlvbi5v\ncmcvcHJhY3RpY2VzLnBkZjAXBgNVHREEEDAOggxpZHAuY3N1cy5lZHUwDQYJKoZI\nhvcNAQEFBQADggEBAFglriksNFsyek2Q8Cmtkr98MAVA7Hw9IcNkoZ8d886nPcud\nATOziI1uHF/eavbd0n7voFgk3zOTnNTPpGKdiFvhqCx4PvsRm4UFuKcrU1Pl1OoY\nKivxKK2xGYlmJDEqbLu+k8Puta1AGfMNJq54xdv8bTKJMkxlR8ATJA7DlJd2YYy1\n0KLNf6rTBgNvL4EndNGD7sUHXyGsNea7ERSdYhP1VbC703V6dn6Qinhm2qwthgm3\nehMZ8k1NjYWDUUWO3GzrWr0L7ay9XgMSr6/5A3L2IVBaaPbhC2/XAVAl+YLpqaDw\nZGqHp4D/LP3T5x1Tr5iE1zNrNAVeaetMeqA2PGI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKTCCAhGgAwIBAgIJAIrcLAZd2tlUMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDGlkcC5jc3VzLmVkdTAeFw0xMTEwMTExNTU1MzBaFw0yMTEwMDgxNTU1MzBa\nMBcxFTATBgNVBAMTDGlkcC5jc3VzLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAM62rDQa6qRVEXoqEm+kWeFInc5oACzU5pJqkKxEmKizZ8P/Y8aB\n/w2vWzFoWWefNPb/zrg6wijOb6FAbTJe/zBexa+JibUg1uk4BlfOmebWvCIoOhRx\nU7GfR5czHcsiGyzIiwGCchBOIIAsUYtVdT1VNzybetbaKSTTEe/N2+otM76EBGl0\nN95X5LdUxRYydteqIl8hmLrCP06WjGjIukIjQcMgNomRckFedyGHgywYU30Mo9Tm\nCYz/pbiQDQbJPgFjDmbOd4iYsyzdJpE8pbsaEJZ1XcNgxe5Y9BOoexLp0+/Bvebm\nuanwRiy+/THhIqQ38mMKaNjRbzyNJgDl3KsCAwEAAaN4MHYwHQYDVR0OBBYEFPYi\nUhafxN4O1ADU9mFoKPAep57OMEcGA1UdIwRAMD6AFPYiUhafxN4O1ADU9mFoKPAe\np57OoRukGTAXMRUwEwYDVQQDEwxpZHAuY3N1cy5lZHWCCQCK3CwGXdrZVDAMBgNV\nHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAgV3TIJrLbxLn7Df0pWdX3ODHq\n3xLyeurA/QtVE9Xp+x98wi6HfTljnSYRlL3PrQdSpELh7D0T18BUgzBhGATQ7g5m\nH8nxcCMsKC75SYnQSBspuosDBSrcpfV8wfHpcEOiqUIYPg/9kzbu79YzQr/2W61N\nfIctPqr43IlDuZqDDWbbCOPti49oTcMGDeVHJPfR6o2kGeM8qo+uQlHpU030mjtR\nLgbeue9s2vlzQoPbAW2ZIjMtxkSztb4dXEiDz6jBf788NVKCfeKrL52TMF1kT/NM\nA4DxizdeC1TEfLUgq0gDwe8XIYYldlIDI2XAwlm69GmSAVWtw91I4TbeJGJT"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csus.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.csus.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.csus.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.csus.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.csus.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.csus.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.csus.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csus.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "California State University, Sacramento"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFiTCCBHGgAwIBAgICAp8wDQYJKoZIhvcNAQEFBQAwVjELMAkGA1UEBhMCVVMx\nHDAaBgNVBAoTE0luQ29tbW9uIEZlZGVyYXRpb24xKTAnBgNVBAMTIEluQ29tbW9u\nIENlcnRpZmljYXRpb24gQXV0aG9yaXR5MB4XDTA5MTAxMzE3NTkwOFoXDTExMTAx\nNDE3NTkwOFowFzEVMBMGA1UEAxMMaWRwLmNzdXMuZWR1MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAsK3s8yjwINisx1tBv8/BaXvdawmKEnpOzAkz5G8H\ncca8nP1Rlp+tSXFTcnm8fdMj10TO1XLNbF6xOYtFXZ2pZykRz6tBeM4cxNUPLafP\nYQTCkKRZ7OXXqhacnZ7X2nUl+6JZYZpNAAjAl5pX0jznXCltQzHUx0DCE4z0CTny\nmVQ+6Q9Ou2w4giJEVEtgFvtUZFccxBM7ifV376GeRQKz83OMwWcvQZNvbHthbxc/\n1+Xhv4XgJhYMqXHYNG5Fkg4rX/dAsQHff4Ncdh+cCjGSzCQvxvKZNENFIwPPV2Cw\n1LXJEGy5R8dnG5KTZ9pmoF6whN7+70GUBxUJ3ENsiBqvvQIDAQABo4ICnjCCApow\nDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUH\nAwEGCCsGAQUFBwMCMB0GA1UdDgQWBBQA+XJi1NGtvakAmNAlHsMDqC2G7jB+BgNV\nHSMEdzB1gBSTLchhGK1j45tls53djZO658pjRaFapFgwVjELMAkGA1UEBhMCVVMx\nHDAaBgNVBAoTE0luQ29tbW9uIEZlZGVyYXRpb24xKTAnBgNVBAMTIEluQ29tbW9u\nIENlcnRpZmljYXRpb24gQXV0aG9yaXR5ggEAMIGyBggrBgEFBQcBAQSBpTCBojBP\nBggrBgEFBQcwAoZDaHR0cDovL2luY29tbW9uY2ExLmluY29tbW9uZmVkZXJhdGlv\nbi5vcmcvYnJpZGdlL2NlcnRzL2NhLWNlcnRzLnA3YjBPBggrBgEFBQcwAoZDaHR0\ncDovL2luY29tbW9uY2EyLmluY29tbW9uZmVkZXJhdGlvbi5vcmcvYnJpZGdlL2Nl\ncnRzL2NhLWNlcnRzLnA3YjCBjQYDVR0fBIGFMIGCMD+gPaA7hjlodHRwOi8vaW5j\nb21tb25jcmwxLmluY29tbW9uZmVkZXJhdGlvbi5vcmcvY3JsL2VlY3Jscy5jcmww\nP6A9oDuGOWh0dHA6Ly9pbmNvbW1vbmNybDIuaW5jb21tb25mZWRlcmF0aW9uLm9y\nZy9jcmwvZWVjcmxzLmNybDBeBgNVHSAEVzBVMFMGCysGAQQBriMBBAEBMEQwQgYI\nKwYBBQUHAgEWNmh0dHA6Ly9pbmNvbW1vbmNhLmluY29tbW9uZmVkZXJhdGlvbi5v\ncmcvcHJhY3RpY2VzLnBkZjAXBgNVHREEEDAOggxpZHAuY3N1cy5lZHUwDQYJKoZI\nhvcNAQEFBQADggEBAFglriksNFsyek2Q8Cmtkr98MAVA7Hw9IcNkoZ8d886nPcud\nATOziI1uHF/eavbd0n7voFgk3zOTnNTPpGKdiFvhqCx4PvsRm4UFuKcrU1Pl1OoY\nKivxKK2xGYlmJDEqbLu+k8Puta1AGfMNJq54xdv8bTKJMkxlR8ATJA7DlJd2YYy1\n0KLNf6rTBgNvL4EndNGD7sUHXyGsNea7ERSdYhP1VbC703V6dn6Qinhm2qwthgm3\nehMZ8k1NjYWDUUWO3GzrWr0L7ay9XgMSr6/5A3L2IVBaaPbhC2/XAVAl+YLpqaDw\nZGqHp4D/LP3T5x1Tr5iE1zNrNAVeaetMeqA2PGI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKTCCAhGgAwIBAgIJAIrcLAZd2tlUMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDGlkcC5jc3VzLmVkdTAeFw0xMTEwMTExNTU1MzBaFw0yMTEwMDgxNTU1MzBa\nMBcxFTATBgNVBAMTDGlkcC5jc3VzLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAM62rDQa6qRVEXoqEm+kWeFInc5oACzU5pJqkKxEmKizZ8P/Y8aB\n/w2vWzFoWWefNPb/zrg6wijOb6FAbTJe/zBexa+JibUg1uk4BlfOmebWvCIoOhRx\nU7GfR5czHcsiGyzIiwGCchBOIIAsUYtVdT1VNzybetbaKSTTEe/N2+otM76EBGl0\nN95X5LdUxRYydteqIl8hmLrCP06WjGjIukIjQcMgNomRckFedyGHgywYU30Mo9Tm\nCYz/pbiQDQbJPgFjDmbOd4iYsyzdJpE8pbsaEJZ1XcNgxe5Y9BOoexLp0+/Bvebm\nuanwRiy+/THhIqQ38mMKaNjRbzyNJgDl3KsCAwEAAaN4MHYwHQYDVR0OBBYEFPYi\nUhafxN4O1ADU9mFoKPAep57OMEcGA1UdIwRAMD6AFPYiUhafxN4O1ADU9mFoKPAe\np57OoRukGTAXMRUwEwYDVQQDEwxpZHAuY3N1cy5lZHWCCQCK3CwGXdrZVDAMBgNV\nHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAgV3TIJrLbxLn7Df0pWdX3ODHq\n3xLyeurA/QtVE9Xp+x98wi6HfTljnSYRlL3PrQdSpELh7D0T18BUgzBhGATQ7g5m\nH8nxcCMsKC75SYnQSBspuosDBSrcpfV8wfHpcEOiqUIYPg/9kzbu79YzQr/2W61N\nfIctPqr43IlDuZqDDWbbCOPti49oTcMGDeVHJPfR6o2kGeM8qo+uQlHpU030mjtR\nLgbeue9s2vlzQoPbAW2ZIjMtxkSztb4dXEiDz6jBf788NVKCfeKrL52TMF1kT/NM\nA4DxizdeC1TEfLUgq0gDwe8XIYYldlIDI2XAwlm69GmSAVWtw91I4TbeJGJT"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idp.csus.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California State University, Sacramento"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csus.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California State University, Sacramento"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://laketahoecc.instructure.com/saml2",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "http://laketahoecc.instructure.com/saml2",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Instructure, Inc"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.instructure.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Instructure, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://laketahoecc.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://laketahoecc.test.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://laketahoecc.beta.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.canvaslms.com/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://canvas.instructure.com/images/canvas/header_canvas_logo@2x.png",
                    "lang": "en",
                    "height": "220",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "220"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.canvaslms.com/policies/privacy-policy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "OEI - Lake Tahoe Community College - Canvas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE8TCCA9mgAwIBAgIJAOBms/PYWcPLMA0GCSqGSIb3DQEBCwUAMIGrMQswCQYD\nVQQGEwJVUzENMAsGA1UECBMEVXRhaDEXMBUGA1UEBxMOU2FsdCBMYWtlIENpdHkx\nGTAXBgNVBAoTEEluc3RydWN0dXJlLCBJbmMxEzARBgNVBAsTCk9wZXJhdGlvbnMx\nIDAeBgNVBAMTF0NhbnZhcyBTQU1MIENlcnRpZmljYXRlMSIwIAYJKoZIhvcNAQkB\nFhNvcHNAaW5zdHJ1Y3R1cmUuY29tMB4XDTE1MDQxNTAxMDAwMFoXDTE3MDQyMjAx\nMDAwMFowgasxCzAJBgNVBAYTAlVTMQ0wCwYDVQQIEwRVdGFoMRcwFQYDVQQHEw5T\nYWx0IExha2UgQ2l0eTEZMBcGA1UEChMQSW5zdHJ1Y3R1cmUsIEluYzETMBEGA1UE\nCxMKT3BlcmF0aW9uczEgMB4GA1UEAxMXQ2FudmFzIFNBTUwgQ2VydGlmaWNhdGUx\nIjAgBgkqhkiG9w0BCQEWE29wc0BpbnN0cnVjdHVyZS5jb20wggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDckDPQGWedlVGC2Z9fn1wNFmN+0IPNi6OSE1nM\nvoTWx2oZlQepaAu4zI5QqOfnV0rW2V1volpoJbu0WelH0DkGzdOEQdWJjAs3nRBf\ny0evxtpg0tK5kIvGsnN6YcD41YmkfWzvwbMf0cEq1Y0wCmymF6XzOUUE4zsi0nhP\nm2Z7WiuongDQdR01UsDN13YcpD/i1JXr3YtkNnJ/a1Kc9OXNycI8M5NVo5QQgdx/\nQ7zAmTk8p9E0ZRthdOQ/PBicWx39mNmBij5KpqCWlHu3NWdgcG8KXSv5atXU8Crd\nTRJ3aGIEN9vBYIHe8MHGCzs1QlRfJmXFMkeUSOTnJJx78rMDAgMBAAGjggEUMIIB\nEDAdBgNVHQ4EFgQUo0WWVlJ1SxZOs11L85ZAuZGyuzEwgeAGA1UdIwSB2DCB1YAU\no0WWVlJ1SxZOs11L85ZAuZGyuzGhgbGkga4wgasxCzAJBgNVBAYTAlVTMQ0wCwYD\nVQQIEwRVdGFoMRcwFQYDVQQHEw5TYWx0IExha2UgQ2l0eTEZMBcGA1UEChMQSW5z\ndHJ1Y3R1cmUsIEluYzETMBEGA1UECxMKT3BlcmF0aW9uczEgMB4GA1UEAxMXQ2Fu\ndmFzIFNBTUwgQ2VydGlmaWNhdGUxIjAgBgkqhkiG9w0BCQEWE29wc0BpbnN0cnVj\ndHVyZS5jb22CCQDgZrPz2FnDyzAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUA\nA4IBAQBV3EmmnzYqYQ5fXNZymG2WaspEW0NeFMhDXa3p3AMIQJbnnU14lR7bqIvf\n/bLW1YE0fw1kSzsw8VrkQp7k1U+kaYA3i5/FQBy2WtqUCVq2GXZA2gs5YD4nvJB/\nF57E//0kEhbATZH9+wJqDkqyIgsrSIlJjiXDth1BppGK8weboPtr9sWV24Ui0+ls\nw16XTsGlnRRO19g+gXKOZp5ApXkDrB+HwZQvZxiCuSgvJlcBzMdxVvWSL+vPtg8Y\nshIKzobIhaQ2MzXHLcxrDhW10YFPwDXh8Tfn5iU9ONsaJivuvVhtDYZD1ZzSoPpm\nq4vYqxxY/6rFJhrCtnlLepSaxlXM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://laketahoecc.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://laketahoecc.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://laketahoecc.beta.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://laketahoecc.beta.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://laketahoecc.test.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://laketahoecc.test.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "OEI - Lake Tahoe Community College - Canvas"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.rac.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Brooks"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:peter.brooks@rau.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Peter"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Griffin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.griffin@rau.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.rac.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-11-30T15:44:04Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.rac.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.rac.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rac.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIIYso0tsUAlx0wDQYJKoZIhvcNAQEFBQAwPTEjMCEGA1UE\n\t\t\t\t\t\tCgwaUm95YWwgQWdyaWN1bHR1cmFsIENvbGxlZ2UxFjAUBgNVBAMMDWlkcC5yYWMu\n\t\t\t\t\t\tYWMudWswHhcNMTIwNzE4MTEyMDI1WhcNMjIwNzE4MTEyMDI1WjA9MSMwIQYDVQQK\n\t\t\t\t\t\tDBpSb3lhbCBBZ3JpY3VsdHVyYWwgQ29sbGVnZTEWMBQGA1UEAwwNaWRwLnJhYy5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIgWwNErQdrW7Jge\n\t\t\t\t\t\twRcdxffYA3ownBclhJdzCmx6k6SgtSd4LawXlvF/zYU3uq6VT87odI+lFYMGzIhg\n\t\t\t\t\t\tjpYzpEcYOz+fe6BCo21Ghq6BeMCJwGdkB4gZq+mgz/GYXhjAX+zlw8Ryl0JcaUfS\n\t\t\t\t\t\tuPcCcccjVSV0ZOIuVc+IQHJWsyWyAz7QbVjQN0C+rCK76JMbprU/B88fE6ZX+j8/\n\t\t\t\t\t\t9Epqs8YEEDBCxjO7pKcgtGmcVTlmWASmaO4+vndg1uCxb+Twc+ve3OqVF5VQdRQa\n\t\t\t\t\t\tt4pSgxywFY4qHT2vS9zojmpclPi8CKwASpHVKpYic4vjMggoVXc9Uz1lQmV+8ncn\n\t\t\t\t\t\te/1o5+0CAwEAAaNQME4wHQYDVR0OBBYEFD+j5I3TjaVsz/fztmw/pnq6FQIRMB8G\n\t\t\t\t\t\tA1UdIwQYMBaAFD+j5I3TjaVsz/fztmw/pnq6FQIRMAwGA1UdEwQFMAMBAf8wDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBAEw7zYoB5vOTdMWiSaSBKUr91UP8lCH8veVNCVDRwujq\n\t\t\t\t\t\tpjli3+bwqiWcvXQdObzW5r/EGLRDM2d3u3GsmIoWP/JAxwfaaURSz0tGPr+NOhXI\n\t\t\t\t\t\t55l2WOX6QfQWOpeQHQs+EJCDg0S2X6jsuILLAZWG4EP+94Fgqbpe2qb5n7aYLAHW\n\t\t\t\t\t\t9VupAZuqO3LgWjA7qXF0xe8D9E86yGAoqICTQy5IOT0Pbe9Us9QL3CHmTMvCwvpf\n\t\t\t\t\t\td0oNG8oZer9agEzQh2gGenDzVmHWTp/n6j+dSjq0TfNXkd3skkcaXv/KXgpzuv3L\n\t\t\t\t\t\tWZWU2kY5guo5wEXb3L9cxzFAZ+OaHFp31a/I2e0kHS0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIIYso0tsUAlx0wDQYJKoZIhvcNAQEFBQAwPTEjMCEGA1UE\n\t\t\t\t\t\tCgwaUm95YWwgQWdyaWN1bHR1cmFsIENvbGxlZ2UxFjAUBgNVBAMMDWlkcC5yYWMu\n\t\t\t\t\t\tYWMudWswHhcNMTIwNzE4MTEyMDI1WhcNMjIwNzE4MTEyMDI1WjA9MSMwIQYDVQQK\n\t\t\t\t\t\tDBpSb3lhbCBBZ3JpY3VsdHVyYWwgQ29sbGVnZTEWMBQGA1UEAwwNaWRwLnJhYy5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIgWwNErQdrW7Jge\n\t\t\t\t\t\twRcdxffYA3ownBclhJdzCmx6k6SgtSd4LawXlvF/zYU3uq6VT87odI+lFYMGzIhg\n\t\t\t\t\t\tjpYzpEcYOz+fe6BCo21Ghq6BeMCJwGdkB4gZq+mgz/GYXhjAX+zlw8Ryl0JcaUfS\n\t\t\t\t\t\tuPcCcccjVSV0ZOIuVc+IQHJWsyWyAz7QbVjQN0C+rCK76JMbprU/B88fE6ZX+j8/\n\t\t\t\t\t\t9Epqs8YEEDBCxjO7pKcgtGmcVTlmWASmaO4+vndg1uCxb+Twc+ve3OqVF5VQdRQa\n\t\t\t\t\t\tt4pSgxywFY4qHT2vS9zojmpclPi8CKwASpHVKpYic4vjMggoVXc9Uz1lQmV+8ncn\n\t\t\t\t\t\te/1o5+0CAwEAAaNQME4wHQYDVR0OBBYEFD+j5I3TjaVsz/fztmw/pnq6FQIRMB8G\n\t\t\t\t\t\tA1UdIwQYMBaAFD+j5I3TjaVsz/fztmw/pnq6FQIRMAwGA1UdEwQFMAMBAf8wDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBAEw7zYoB5vOTdMWiSaSBKUr91UP8lCH8veVNCVDRwujq\n\t\t\t\t\t\tpjli3+bwqiWcvXQdObzW5r/EGLRDM2d3u3GsmIoWP/JAxwfaaURSz0tGPr+NOhXI\n\t\t\t\t\t\t55l2WOX6QfQWOpeQHQs+EJCDg0S2X6jsuILLAZWG4EP+94Fgqbpe2qb5n7aYLAHW\n\t\t\t\t\t\t9VupAZuqO3LgWjA7qXF0xe8D9E86yGAoqICTQy5IOT0Pbe9Us9QL3CHmTMvCwvpf\n\t\t\t\t\t\td0oNG8oZer9agEzQh2gGenDzVmHWTp/n6j+dSjq0TfNXkd3skkcaXv/KXgpzuv3L\n\t\t\t\t\t\tWZWU2kY5guo5wEXb3L9cxzFAZ+OaHFp31a/I2e0kHS0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Royal Agricultural University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rac.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Royal Agricultural University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.qmsu.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.qmsu.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Membership Solutions: Queen Mary SU"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qmsu.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.qmsu.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.qmsu.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.qmsu.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.qmsu.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.qmsu.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.qmsu.org/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.qmsu.org/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.qmsu.org/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.qmsu.org/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.qmsu.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.qmsu.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.qmsu.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.qmsu.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.qmsu.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.qmsu.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://connectis-sso.staging.federatenow.net/broker/sso/tpd",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:technicalsupport@connectis.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:technicalsupport@connectis.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://connectis-sso.staging.federatenow.net/broker/sso/tpd",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-06-04T10:34:37Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Connectis Staging"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.connectis.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Connected Information Systems B.V."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "authn_requests_signed": "true",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEETCCAvmgAwIBAgIEXjilzjANBgkqhkiG9w0BAQsFADCBuDELMAkGA1UEBhMC\n\t\t\t\t\t\tTkwxEzARBgNVBAgTClNvbWUtU3RhdGUxEjAQBgNVBAcTCVJvdHRlcmRhbTErMCkG\n\t\t\t\t\t\tA1UEChMiQ29ubmVjdGVkIEluZm9ybWF0aW9uIFN5c3RlbXMgQi5WLjErMCkGA1UE\n\t\t\t\t\t\tCxMiQ29ubmVjdGVkIEluZm9ybWF0aW9uIFN5c3RlbXMgQi5WLjEmMCQGA1UEAxMd\n\t\t\t\t\t\tY29ubmVjdGlzLXNzbyBzdGFnaW5nIHNpZ25pbmcwHhcNMTQwNjA0MDkyMTUwWhcN\n\t\t\t\t\t\tMjQwNDEyMDkyMTUwWjCBuDELMAkGA1UEBhMCTkwxEzARBgNVBAgTClNvbWUtU3Rh\n\t\t\t\t\t\tdGUxEjAQBgNVBAcTCVJvdHRlcmRhbTErMCkGA1UEChMiQ29ubmVjdGVkIEluZm9y\n\t\t\t\t\t\tbWF0aW9uIFN5c3RlbXMgQi5WLjErMCkGA1UECxMiQ29ubmVjdGVkIEluZm9ybWF0\n\t\t\t\t\t\taW9uIFN5c3RlbXMgQi5WLjEmMCQGA1UEAxMdY29ubmVjdGlzLXNzbyBzdGFnaW5n\n\t\t\t\t\t\tIHNpZ25pbmcwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCFL8GudeE6\n\t\t\t\t\t\t+ZrNf9A29gp0GWT1ZzlMho1D7CkxqlWa6dLHlHHq/9yVimTJ+gBW98lM5Xtox9pB\n\t\t\t\t\t\tSl4NEhJYxnbzqxQQZHrYe2ePndaOA+I3Qt18s9Flii3CfKgivO8Gk7PIsJiUtmpa\n\t\t\t\t\t\tVQs7VW3exfe9hct+u9+WNuyHvHaEnuf5m2NU3Ik5xyG19etoBhGqhhTeCWr/jXX+\n\t\t\t\t\t\tr3dJSoCiRKCrw1vtd4H0AYkOu3vsvlGyzv468wj8ya7pSWKhUhYTWIaBI5lf6LYP\n\t\t\t\t\t\tI3Ic7CixQJMYnjk3HjHUzBkWF4Br/7/REk94FRsCLbBy97DV/reOcGqSSazVMxnu\n\t\t\t\t\t\tD4oW5vrbvcdfAgMBAAGjITAfMB0GA1UdDgQWBBS6TwUKWGxZJD3DZcMnO5rfH6UB\n\t\t\t\t\t\t/DANBgkqhkiG9w0BAQsFAAOCAQEAbS/JqZ8HtJ1gVgsTLIGHqIarEov1U3sbijbY\n\t\t\t\t\t\t5cmCMAT0KwBP0/0FrF3eSDoxBiAUhPyeYRLmgLDY2OMUoXctpsRQEKdSz2uygZgT\n\t\t\t\t\t\tHUCbwj9m7Wbg7iPGXcoEJhQgJxBh+afOICDNfcOO/mT4LPhy9JY/fg6fqeCfNyeL\n\t\t\t\t\t\tXbBPIFCJ6tnkwseBBdFN+bOpRLSQjhicQNd91+7E9D99NFw1AkZpj+pNq8cwFpOK\n\t\t\t\t\t\t0LLFELmeT1gDlRAv5yjz4PyIUONaHGA35eIvyDcE3TV003+x3PNwqGrMwzsXvR6q\n\t\t\t\t\t\tdo7Z7JztljIHExhgDP6V7Ze4Y2nyrEqVhFWOdAwOH/PTaxIsgQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://connectis-sso.staging.federatenow.net/broker/acs/tpd",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "2",
              "location": "https://connectis-sso.staging.federatenow.net/broker/acs/tpd",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "false"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.teikoz.gr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@grnet.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Technological Educational Institute of Western Macedonia"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "800-11-47638"
            }
          ]
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@grnet.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Technological Educational Institute of Western Macedonia"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "800-11-47638"
            }
          ]
        }
      ],
      "entity_id": "https://idp.teikoz.gr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEvjCCA6agAwIBAgIQSZIpUYIhvsE2nmtnqM1U4zANBgkqhkiG9w0BAQUFADA2\n                            MQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n                            U1NMIENBMB4XDTEwMDkwNzAwMDAwMFoXDTEzMDkwNjIzNTk1OVowgYoxCzAJBgNV\n                            BAYTAkdSMQ8wDQYDVQQIEwZLb3phbmkxDzANBgNVBAcTBktvemFuaTFBMD8GA1UE\n                            ChM4VGVjaG5vbG9naWNhbCBFZHVjYXRpb25hbCBJbnN0aXR1dGUgb2YgV2VzdGVy\n                            biBNYWNlZG9uaWExFjAUBgNVBAMTDWlkcC50ZWlrb3ouZ3IwggEiMA0GCSqGSIb3\n                            DQEBAQUAA4IBDwAwggEKAoIBAQD+qeR1bQidtysnFQPYWjlW+UYDzJ/V2m60cbvv\n                            w+YHf5GRbeGYyEwcc6UITLufPOXMQh8jqQBRvaTZHDx5HeZJ4+p02Rkvy31p4LVP\n                            UV15wwyz+OBpkChlcvaJn97mdp3YGgUMjGfuK4wYUZO6xRbljRwkR6InGkYjvlCV\n                            iUlrRkJdS+bIr6UVAYz1bDRNiwWZuyQU5f0rEmSvFH84lddPt9SmmKK7FQ2mnk45\n                            T2gVd09m2eYKdp0Ud0VIMCjb4bMXXD4ljpNV4adMGNRjq7uih6KPla++7o5EGDOm\n                            PDyS2060CUWtHp8/nHiaqRNn8zEIihw5sVeGrI/koPRl0D8RAgMBAAGjggFxMIIB\n                            bTAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3V0fqkOO57TAdBgNVHQ4EFgQUK0Bh\n                            Sb2qDZw1mNHJVoLaeNzsnDQwDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAw\n                            HQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMBgGA1UdIAQRMA8wDQYLKwYB\n                            BAGyMQECAh0wOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5h\n                            Lm9yZy9URVJFTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAC\n                            hilodHRwOi8vY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggr\n                            BgEFBQcwAYYaaHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwKQYDVR0RBCIwIIIN\n                            aWRwLnRlaWtvei5ncoIPbG9naW4udGVpa296LmdyMA0GCSqGSIb3DQEBBQUAA4IB\n                            AQBl209LrprvBgZr47DE7hD4datAQBdlAhOKvQvS5Xb0QQSsmEVxVeiXGF4E+F71\n                            nGPkgY5qKKwp2H1HN3Y+8DBWJlD7hqTYzN8KVIAafQ2UURbYta0BkxqhVn5mkmI9\n                            m/XrdQqldL69Bkc90HF3luAPkhH1kMA8iaZTctUb5oUBSLJ/MV8PqIdo0R5uZgoc\n                            12Bl3bfVt6iremcGfbh2h8gp0XYGrjVnI66oD5pAyXN+MwEMDJU/VsMXE7BGz8L5\n                            Jw1tFiMPZxGygx7LwN5NP6z2d85J19w8mB87I0HA4C2dk9NeR02KWkHEQkiX6nQs\n                            MxqUW2tYH/WvrKHC2snqJzMW"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "teikoz.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.teikoz.gr:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.teikoz.gr:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.teikoz.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.teikoz.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.teikoz.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.teikoz.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.teikoz.gr:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.teikoz.gr:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "teikoz.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEvjCCA6agAwIBAgIQSZIpUYIhvsE2nmtnqM1U4zANBgkqhkiG9w0BAQUFADA2\n                            MQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n                            U1NMIENBMB4XDTEwMDkwNzAwMDAwMFoXDTEzMDkwNjIzNTk1OVowgYoxCzAJBgNV\n                            BAYTAkdSMQ8wDQYDVQQIEwZLb3phbmkxDzANBgNVBAcTBktvemFuaTFBMD8GA1UE\n                            ChM4VGVjaG5vbG9naWNhbCBFZHVjYXRpb25hbCBJbnN0aXR1dGUgb2YgV2VzdGVy\n                            biBNYWNlZG9uaWExFjAUBgNVBAMTDWlkcC50ZWlrb3ouZ3IwggEiMA0GCSqGSIb3\n                            DQEBAQUAA4IBDwAwggEKAoIBAQD+qeR1bQidtysnFQPYWjlW+UYDzJ/V2m60cbvv\n                            w+YHf5GRbeGYyEwcc6UITLufPOXMQh8jqQBRvaTZHDx5HeZJ4+p02Rkvy31p4LVP\n                            UV15wwyz+OBpkChlcvaJn97mdp3YGgUMjGfuK4wYUZO6xRbljRwkR6InGkYjvlCV\n                            iUlrRkJdS+bIr6UVAYz1bDRNiwWZuyQU5f0rEmSvFH84lddPt9SmmKK7FQ2mnk45\n                            T2gVd09m2eYKdp0Ud0VIMCjb4bMXXD4ljpNV4adMGNRjq7uih6KPla++7o5EGDOm\n                            PDyS2060CUWtHp8/nHiaqRNn8zEIihw5sVeGrI/koPRl0D8RAgMBAAGjggFxMIIB\n                            bTAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3V0fqkOO57TAdBgNVHQ4EFgQUK0Bh\n                            Sb2qDZw1mNHJVoLaeNzsnDQwDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAw\n                            HQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMBgGA1UdIAQRMA8wDQYLKwYB\n                            BAGyMQECAh0wOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5h\n                            Lm9yZy9URVJFTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAC\n                            hilodHRwOi8vY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggr\n                            BgEFBQcwAYYaaHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwKQYDVR0RBCIwIIIN\n                            aWRwLnRlaWtvei5ncoIPbG9naW4udGVpa296LmdyMA0GCSqGSIb3DQEBBQUAA4IB\n                            AQBl209LrprvBgZr47DE7hD4datAQBdlAhOKvQvS5Xb0QQSsmEVxVeiXGF4E+F71\n                            nGPkgY5qKKwp2H1HN3Y+8DBWJlD7hqTYzN8KVIAafQ2UURbYta0BkxqhVn5mkmI9\n                            m/XrdQqldL69Bkc90HF3luAPkhH1kMA8iaZTctUb5oUBSLJ/MV8PqIdo0R5uZgoc\n                            12Bl3bfVt6iremcGfbh2h8gp0XYGrjVnI66oD5pAyXN+MwEMDJU/VsMXE7BGz8L5\n                            Jw1tFiMPZxGygx7LwN5NP6z2d85J19w8mB87I0HA4C2dk9NeR02KWkHEQkiX6nQs\n                            MxqUW2tYH/WvrKHC2snqJzMW"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Technological Educational Institute of Western Macedonia"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03b9\u03ba\u03cc \u0395\u03ba\u03c0\u03b1\u03b9\u03b4\u03b5\u03c5\u03c4\u03b9\u03ba\u03cc \u038a\u03b4\u03c1\u03c5\u03bc\u03b1 \u0394\u03c5\u03c4\u03b9\u03ba\u03ae\u03c2 \u039c\u03b1\u03ba\u03b5\u03b4\u03bf\u03bd\u03af\u03b1\u03c2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.teikoz.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.teikoz.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Technological Educational Institute of Western Macedonia"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03b9\u03ba\u03cc \u0395\u03ba\u03c0\u03b1\u03b9\u03b4\u03b5\u03c5\u03c4\u03b9\u03ba\u03cc \u038a\u03b4\u03c1\u03c5\u03bc\u03b1 \u0394\u03c5\u03c4\u03b9\u03ba\u03ae\u03c2 \u039c\u03b1\u03ba\u03b5\u03b4\u03bf\u03bd\u03af\u03b1\u03c2"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://jidp.jlab.org/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "wise@jlab.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marty Wise"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "wise@jlab.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marty Wise"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@jlab.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "JLab IT Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "secops@jlab.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "JLab Cyber Security Operations"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://jidp.jlab.org/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://jidp.jlab.org/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jidp.jlab.org/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://jidp.jlab.org/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://jidp.jlab.org:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jidp.jlab.org:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "jlab.org"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://jidp.jlab.org/info.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Thomas Jefferson National Accelerator Facility"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Jeffrsson Lab Federation / Single Sign-On server."
                  }
                ],
                "logo": [
                  {
                    "text": "https://jidp.jlab.org/images/jlab-logo-2015.png",
                    "lang": "en",
                    "height": "89",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "314"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://jidp.jlab.org/notices/PrivacyAndSecurityNotice.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJALnZSc3W8jbPMA0GCSqGSIb3DQEBCwUAMBgxFjAUBgNV\nBAMMDWppZHAuamxhYi5vcmcwHhcNMTUxMDA2MTAxNjA4WhcNMjUxMDAzMTAxNjA4\nWjAYMRYwFAYDVQQDDA1qaWRwLmpsYWIub3JnMIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAq0QcBcQ0TE+q/ldmWYn002CTW2tTJyy8ZhGifuOsnUSpuGmv\nC2Fn0uiaOsmS5fWIY7ODJbDCi4lbQaG/rcjVM/ZQV4LhKLzuiZaH/RPtEZaQkfbM\ncWYAWqU2dawgnMe+hrAgnpci7e27HqFqRPnuug/NIl6YO7sdbTVkxCIgmLsvtayw\n9Phnh/hqapuhbQAg574QXndo1Rf1T9EEhXItpXVQi0qpXJpL8sbfy2KHemxME5wf\n3JKpSF6eaBUwZ+AjwOvP45UPHcS+PO9OkdYWCSwlr+ng1c9irdd2y945s5E/2Jrz\n6yMpN3lrXpB4m4S/Okj7x/wr2pDJgl4YsY61WQIDAQABo1AwTjAdBgNVHQ4EFgQU\nHkkTLqtEStiUx6pTaq/7Wm1YRaQwHwYDVR0jBBgwFoAUHkkTLqtEStiUx6pTaq/7\nWm1YRaQwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAQEAWqcKe9R2eOrW\nA72CXwx1zNDRMZ7SA/HAc3jLi6bYFY9RP/XvtFLnPx+k7VyGyTWmo3D6HDDVffdL\njgXg2k8PzZSND120m6FO4pCn3wHoE6bDXSWupvZ3MDQx548nD74cPV/PZHXM2CoK\n+YKuysd/yw70fs5F9NXc6KCRM3oWMDSyBF6bYpdANW6mXYYpUM1rGH3UAOr4DqgR\nzQ22wyEgR+wadv1F8mNMuy36OX2p1J+uAGcf5H369ILzrHnx+pLgfLwcI+g9ykGU\n1i9hmm8hl7nCznl7VjdmpM+K+o/3PLkJDUFDlh0rIdUkjd8/2RjU1xYipNlaRZv8\n5WBcTMLk6w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://jidp.jlab.org/error-main.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Thomas Jefferson National Accelerator Facility"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://education.jlab.org/index.php"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Thomas Jefferson National Accelerator Facility"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://learn.eduopen.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Minerva"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cea@unimore.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tommaso"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://learn.eduopen.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2016-03-31T10:18:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "eduOpen MOOC Italia erogato da Universit\u00e0 di Modena e Reggio Emilia"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "eduOpen MOOC Italy provided by University of Modena e Reggio Emilia"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unimore.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.international.unimore.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 di Modena e Reggio Emilia"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Modena e Reggio Emilia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://learn.eduopen.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://learn.eduopen.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://learn.eduopen.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://learn.eduopen.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://learn.eduopen.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://learn.eduopen.org/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://learn.eduopen.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://learn.eduopen.org/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://learn.eduopen.org/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://learn.eduopen.org/eduopen/information-en.php"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://learn.eduopen.org/eduopen/information-it.php"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "eduOpen MOOC Italia"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "eduOpen MOOC Italy"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Portal for providing demonstration courses for EDUOPEN Network in a federated environment"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Portale per l'erogazione dei corsi dimostrativi per la rete EDUOPEN in un ambiente federato"
                  }
                ],
                "logo": [
                  {
                    "text": "https://learn.eduopen.org/theme/eduopen/pix/eduopen60english.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://learn.eduopen.org/theme/eduopen/pix/eduopen60italian.png",
                    "lang": "it",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://learn.eduopen.org/theme/eduopen/pix/eduopen16english.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://learn.eduopen.org/theme/eduopen/pix/eduopen16italian.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://learn.eduopen.org/eduopen/privacy-en.php"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://learn.eduopen.org/eduopen/privacy-it.php"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIJAJgJgkpaC7xFMA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\nBAMTEWxlYXJuLmVkdW9wZW4ub3JnMB4XDTE2MDMxNTA5MTI0NFoXDTI2MDMxMzA5\nMTI0NFowHDEaMBgGA1UEAxMRbGVhcm4uZWR1b3Blbi5vcmcwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDWw77X6r/2lsnNRbja4oFFEXtJoS4amc1Z4JXs\n6al58tSH8rleeqzdgymkX2n+fKU/+BoNAv/C5v4JN1+O+wCDx6hZ3huyAqZ25lSx\njJfgzXSMj2TqL3s7whjwoZ2MEys33zdiJoJ2O9TvcyRYy5xV2fZJplF0z5LfpoRF\nLsjqBf1E40ls/QgwfnLH5mzI++zOG9hvvp20ikhg5X8nGjk9qkvN2uU0oIcwnXn5\nCGmLnmDd/7PAUbHYY3S6bS07hKPfJ9fgSQ1cvZ2yOeITEXfBMNU4+TB9gwbP7gcN\n3RptBRgJ6b5ErcvVFPK83ua5oEpBIqxIF61qyfbuXDIFsZFJAgMBAAGjZTBjMEIG\nA1UdEQQ7MDmCEWxlYXJuLmVkdW9wZW4ub3JnhiRodHRwczovL2xlYXJuLmVkdW9w\nZW4ub3JnL3NoaWJib2xldGgwHQYDVR0OBBYEFAPGNguResZVYhI46QFoBZmbIXo7\nMA0GCSqGSIb3DQEBBQUAA4IBAQAZsFD4WSHCQmF6M/5eU9WL9jFyNdzTm+pievFs\n1zxtyoB211byfA3Vy6/1UPLbgiGAPC7cortKE1hxAken4W0drnLMVNuHpTT/GBwr\n5J6pCVhqU4E6YGkmdXFlVWbaEF+9NwbdZoIKPxUvBkylImXV0o8XDQUpQ4LU6szg\nVhL18Lwuxw7CbX/sxPNDvJXrbWvrAEOpwcz9feVDBdj5J4r0Nwbutm4ahk1xTXzm\nR8kwgs6koOxQduST9dwIjI3L1VaD5t32aeQgZGxqV6yDVW+wMmEKHO2mLTTjhI46\nw44pEUtbE0j6vHrF7T229AWQzYX/b5F8Mg3OV+WVYW0AP84V"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://learn.eduopen.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://learn.eduopen.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://learn.eduopen.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://learn.eduopen.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "eduOpen MOOC Italia"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "eduOpen MOOC Italy"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Portal for providing demonstration courses for EDUOPEN Network in a federated environment"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Portale per l'erogazione dei corsi dimostrativi per la rete EDUOPEN in un ambiente federato"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://core.uwap.org/simplesaml/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "\u00c5kre Solberg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "andreas.solberg@uninett.no"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andreas"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://core.uwap.org/simplesaml/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.feide.no/files/feide/metadata-registration-practice-statement.pdf"
              }
            ],
            "registration_instant": "2013-10-17T11:25:00Z",
            "registration_authority": "http://feide.no/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNINETT"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://uninett.no/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNINETT"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://core.uwap.org/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The service platform of UNINETT for next generation collaboration tools for higher education."
                  },
                  {
                    "lang": "no",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNINETTs tjenesteplattform for neste generasjons samarbeidsverkt\u00f8y for h\u00f8yere utdanning."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UWAP"
                  },
                  {
                    "lang": "no",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UWAP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://core.uwap.org/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://core.uwap.org/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://core.uwap.org/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://core.uwap.org/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "UWAP"
                },
                {
                  "lang": "no",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "UWAP"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The service platform of UNINETT for next generation collaboration tools for higher education."
                },
                {
                  "lang": "no",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "UNINETTs tjenesteplattform for neste generasjons samarbeidsverkt\u00f8y for h\u00f8yere utdanning."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cafe.ufop.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Daniel Magalhaes Bicalho"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "daniel.bicalho@nti.ufop.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.ufop.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID4jCCAsoCAQAwDQYJKoZIhvcNAQEFBQAwgbYxKzApBgNVBAoTIlVuaXZlcnNp\nZGFkZSBGZWRlcmFsIGRlIE91cm8gUHJldG8xDDAKBgNVBAsTA05USTEpMCcGCSqG\nSIb3DQEJARYaZGFuaWVsLmJpY2FsaG9AbnRpLnVmb3AuYnIxEzARBgNVBAcTCk91\ncm8gUHJldG8xFTATBgNVBAgTDE1pbmFzIEdlcmFpczELMAkGA1UEBhMCQlIxFTAT\nBgNVBAMTDGNhZmUudWZvcC5icjAeFw0xNTEyMDcxNjM1NDRaFw0xODEyMDYxNjM1\nNDRaMIG2MSswKQYDVQQKEyJVbml2ZXJzaWRhZGUgRmVkZXJhbCBkZSBPdXJvIFBy\nZXRvMQwwCgYDVQQLEwNOVEkxKTAnBgkqhkiG9w0BCQEWGmRhbmllbC5iaWNhbGhv\nQG50aS51Zm9wLmJyMRMwEQYDVQQHEwpPdXJvIFByZXRvMRUwEwYDVQQIEwxNaW5h\ncyBHZXJhaXMxCzAJBgNVBAYTAkJSMRUwEwYDVQQDEwxjYWZlLnVmb3AuYnIwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDA0fRsDeNvadrIp0Z/l1ez5QPz\nI/ssUFSqEEd0LRHUtpjlcIjv8+ue8mdB0DTLDgwyHNK5/2JCjvHtAFLvm2aitTxF\nOI3FcEs0yE6D4vUETqG+FBWeQMryWihZw6fZMZYxsKU0Krzsv3uOS76QMPlNJIfK\nb4WuwYyHg8fY1n22s5HbVgFU3I+uVFba1yRCxbkOlJiHmyJT8jn31nSXG89q+Aw4\nC24kwspEcMlQI9o3gmWV3BOB9LUA097u83RRHIYj7Let3HFmWnRhobl//+NxOdsG\nJnProi+xH8e1cP7muJGwekvdoFbWmunRehlFw4vA2LYUb+WNLESCRl65WCQ9AgMB\nAAEwDQYJKoZIhvcNAQEFBQADggEBAHY5ix9yFTNC8JuwgmOZ4zGLAQCWMjQ9SbDN\nvrEH6lpvOo9efFH2zAzxvu8SkmcrYL0yexsvoG/snfnVzNNOTM4GNFWyIwIRWnJB\nYeNnDQcYMEKbLHSjEBDrX2AyvF7IequyK5mbsy4ic1Nrt25iOVfkPCPjMAtOISVb\nIqQ+iNiydXlAGvol6Umg+gThSodbJy6wPe2TVSAiPax9qDdTVfoRBlreH56SYkBS\nkqzE4C2rmTrRyFSx4aPeDFFfxTLb+6pzzGViG4LKjmUnuwBMDf0xUeEzSXtKJt8b\nd1Z09RkELvyaUolyxwbKw1xAZusdas/XqeYVNmpV9JKLyafDkrA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufop.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.ufop.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.ufop.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.ufop.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.ufop.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.ufop.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.ufop.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.ufop.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.ufop.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufop.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufop.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufop.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFOP - Universidade Federal de Ouro Preto"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFOP - Universidade Federal de Ouro Preto"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFOP - Universidade Federal de Ouro Preto"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFOP - Universidade Federal de Ouro Preto"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID4jCCAsoCAQAwDQYJKoZIhvcNAQEFBQAwgbYxKzApBgNVBAoTIlVuaXZlcnNp\nZGFkZSBGZWRlcmFsIGRlIE91cm8gUHJldG8xDDAKBgNVBAsTA05USTEpMCcGCSqG\nSIb3DQEJARYaZGFuaWVsLmJpY2FsaG9AbnRpLnVmb3AuYnIxEzARBgNVBAcTCk91\ncm8gUHJldG8xFTATBgNVBAgTDE1pbmFzIEdlcmFpczELMAkGA1UEBhMCQlIxFTAT\nBgNVBAMTDGNhZmUudWZvcC5icjAeFw0xNTEyMDcxNjM1NDRaFw0xODEyMDYxNjM1\nNDRaMIG2MSswKQYDVQQKEyJVbml2ZXJzaWRhZGUgRmVkZXJhbCBkZSBPdXJvIFBy\nZXRvMQwwCgYDVQQLEwNOVEkxKTAnBgkqhkiG9w0BCQEWGmRhbmllbC5iaWNhbGhv\nQG50aS51Zm9wLmJyMRMwEQYDVQQHEwpPdXJvIFByZXRvMRUwEwYDVQQIEwxNaW5h\ncyBHZXJhaXMxCzAJBgNVBAYTAkJSMRUwEwYDVQQDEwxjYWZlLnVmb3AuYnIwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDA0fRsDeNvadrIp0Z/l1ez5QPz\nI/ssUFSqEEd0LRHUtpjlcIjv8+ue8mdB0DTLDgwyHNK5/2JCjvHtAFLvm2aitTxF\nOI3FcEs0yE6D4vUETqG+FBWeQMryWihZw6fZMZYxsKU0Krzsv3uOS76QMPlNJIfK\nb4WuwYyHg8fY1n22s5HbVgFU3I+uVFba1yRCxbkOlJiHmyJT8jn31nSXG89q+Aw4\nC24kwspEcMlQI9o3gmWV3BOB9LUA097u83RRHIYj7Let3HFmWnRhobl//+NxOdsG\nJnProi+xH8e1cP7muJGwekvdoFbWmunRehlFw4vA2LYUb+WNLESCRl65WCQ9AgMB\nAAEwDQYJKoZIhvcNAQEFBQADggEBAHY5ix9yFTNC8JuwgmOZ4zGLAQCWMjQ9SbDN\nvrEH6lpvOo9efFH2zAzxvu8SkmcrYL0yexsvoG/snfnVzNNOTM4GNFWyIwIRWnJB\nYeNnDQcYMEKbLHSjEBDrX2AyvF7IequyK5mbsy4ic1Nrt25iOVfkPCPjMAtOISVb\nIqQ+iNiydXlAGvol6Umg+gThSodbJy6wPe2TVSAiPax9qDdTVfoRBlreH56SYkBS\nkqzE4C2rmTrRyFSx4aPeDFFfxTLb+6pzzGViG4LKjmUnuwBMDf0xUeEzSXtKJt8b\nd1Z09RkELvyaUolyxwbKw1xAZusdas/XqeYVNmpV9JKLyafDkrA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFOP - Universidade Federal de Ouro Preto"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFOP - Universidade Federal de Ouro Preto"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufop.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufop.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFOP - Universidade Federal de Ouro Preto"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFOP - Universidade Federal de Ouro Preto"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://test.stir.unidesk.ac.uk/tas/public/login/verify",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:is.helpline@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-certs@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Apps Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test.stir.unidesk.ac.uk/tas/public/login/verify",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-05T13:47:56Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Test Unidesk - Stirling"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID2jCCAsKgAwIBAgIJANyOrK6P4z4IMA0GCSqGSIb3DQEBCwUAMFExIDAeBgNV\n\t\t\t\t\t\tBAMTF3Rlc3Quc3Rpci51bmlkZXNrLmFjLnVrMSAwHgYDVQQKExd0ZXN0LnN0aXIu\n\t\t\t\t\t\tdW5pZGVzay5hYy51azELMAkGA1UEBhMCVUswHhcNMTYwNDAxMTIzNzE4WhcNMjYw\n\t\t\t\t\t\tMzMwMTIzNzE4WjBRMSAwHgYDVQQDExd0ZXN0LnN0aXIudW5pZGVzay5hYy51azEg\n\t\t\t\t\t\tMB4GA1UEChMXdGVzdC5zdGlyLnVuaWRlc2suYWMudWsxCzAJBgNVBAYTAlVLMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0/TrlARELCO2seaUN5x9qwXm\n\t\t\t\t\t\toMpDksEGPHgRa40wqvHnF/1ebwuJ/a0L2XW7OLt1Lg4J5N1B/VxJ76qt4c9rqY0k\n\t\t\t\t\t\tfKAcbwLjUDXLG4R61/ixw1U5g8TkxGWs/b1QZzYN1mXGqYZXQEehau4jrsLlj5u+\n\t\t\t\t\t\t2llO5Io0AkRSOYjZCjd1lWaqj4nVYJD8EVIugxnzJZ6Er3sys+izkhwUXueJSieJ\n\t\t\t\t\t\tTOPurN9fHt/qiwg8OY+v8rUfHM6c6tGQHrYEThad+fzhfS8mATMs0Ghw85vGYiqn\n\t\t\t\t\t\tVBece+oe4iTxmZyFXr3Syd+Nwb8WBlH0DDrj9SVC2HLttXsHTRexKOAeXjTzNwID\n\t\t\t\t\t\tAQABo4G0MIGxMB0GA1UdDgQWBBQ5yaFQUQPTK5YABLJFqvVyQyTx/DCBgQYDVR0j\n\t\t\t\t\t\tBHoweIAUOcmhUFED0yuWAASyRar1ckMk8fyhVaRTMFExIDAeBgNVBAMTF3Rlc3Qu\n\t\t\t\t\t\tc3Rpci51bmlkZXNrLmFjLnVrMSAwHgYDVQQKExd0ZXN0LnN0aXIudW5pZGVzay5h\n\t\t\t\t\t\tYy51azELMAkGA1UEBhMCVUuCCQDcjqyuj+M+CDAMBgNVHRMEBTADAQH/MA0GCSqG\n\t\t\t\t\t\tSIb3DQEBCwUAA4IBAQBGPthismR3ASkL4uXomIVPyWLvAEwfuOInJXcAWFTUzuXM\n\t\t\t\t\t\tNsnEqPjIY+oq9sC9ALo0Ne7X0MhXaBie+P/+tZMRq6EoYT0moDMIsFC/MZaEiRUa\n\t\t\t\t\t\t6mhwksA4PVEwhYEqL2C0HtpkIB5eJ7cqnQCQIlsSxQYUVP/J01rW/WX5CDnaVG+l\n\t\t\t\t\t\tsINoMQr42MaRYjduErB1j0WvpN+p+g98NS9vSPCcFTFTK28syLDlgDPwlPYTAfV7\n\t\t\t\t\t\t/z1ISaVQYVdUyh+sUrWuY2lHH3u9OtoE7FZrA2YUkD+fV3MzlIrRX/Ku8/iq+bqe\n\t\t\t\t\t\tlRHGvV+PFtz4Y8zu1o61fq5+Fm2S0oHYtgDRVudH"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID2jCCAsKgAwIBAgIJANyOrK6P4z4IMA0GCSqGSIb3DQEBCwUAMFExIDAeBgNV\n\t\t\t\t\t\tBAMTF3Rlc3Quc3Rpci51bmlkZXNrLmFjLnVrMSAwHgYDVQQKExd0ZXN0LnN0aXIu\n\t\t\t\t\t\tdW5pZGVzay5hYy51azELMAkGA1UEBhMCVUswHhcNMTYwNDAxMTIzNzE4WhcNMjYw\n\t\t\t\t\t\tMzMwMTIzNzE4WjBRMSAwHgYDVQQDExd0ZXN0LnN0aXIudW5pZGVzay5hYy51azEg\n\t\t\t\t\t\tMB4GA1UEChMXdGVzdC5zdGlyLnVuaWRlc2suYWMudWsxCzAJBgNVBAYTAlVLMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0/TrlARELCO2seaUN5x9qwXm\n\t\t\t\t\t\toMpDksEGPHgRa40wqvHnF/1ebwuJ/a0L2XW7OLt1Lg4J5N1B/VxJ76qt4c9rqY0k\n\t\t\t\t\t\tfKAcbwLjUDXLG4R61/ixw1U5g8TkxGWs/b1QZzYN1mXGqYZXQEehau4jrsLlj5u+\n\t\t\t\t\t\t2llO5Io0AkRSOYjZCjd1lWaqj4nVYJD8EVIugxnzJZ6Er3sys+izkhwUXueJSieJ\n\t\t\t\t\t\tTOPurN9fHt/qiwg8OY+v8rUfHM6c6tGQHrYEThad+fzhfS8mATMs0Ghw85vGYiqn\n\t\t\t\t\t\tVBece+oe4iTxmZyFXr3Syd+Nwb8WBlH0DDrj9SVC2HLttXsHTRexKOAeXjTzNwID\n\t\t\t\t\t\tAQABo4G0MIGxMB0GA1UdDgQWBBQ5yaFQUQPTK5YABLJFqvVyQyTx/DCBgQYDVR0j\n\t\t\t\t\t\tBHoweIAUOcmhUFED0yuWAASyRar1ckMk8fyhVaRTMFExIDAeBgNVBAMTF3Rlc3Qu\n\t\t\t\t\t\tc3Rpci51bmlkZXNrLmFjLnVrMSAwHgYDVQQKExd0ZXN0LnN0aXIudW5pZGVzay5h\n\t\t\t\t\t\tYy51azELMAkGA1UEBhMCVUuCCQDcjqyuj+M+CDAMBgNVHRMEBTADAQH/MA0GCSqG\n\t\t\t\t\t\tSIb3DQEBCwUAA4IBAQBGPthismR3ASkL4uXomIVPyWLvAEwfuOInJXcAWFTUzuXM\n\t\t\t\t\t\tNsnEqPjIY+oq9sC9ALo0Ne7X0MhXaBie+P/+tZMRq6EoYT0moDMIsFC/MZaEiRUa\n\t\t\t\t\t\t6mhwksA4PVEwhYEqL2C0HtpkIB5eJ7cqnQCQIlsSxQYUVP/J01rW/WX5CDnaVG+l\n\t\t\t\t\t\tsINoMQr42MaRYjduErB1j0WvpN+p+g98NS9vSPCcFTFTK28syLDlgDPwlPYTAfV7\n\t\t\t\t\t\t/z1ISaVQYVdUyh+sUrWuY2lHH3u9OtoE7FZrA2YUkD+fV3MzlIrRX/Ku8/iq+bqe\n\t\t\t\t\t\tlRHGvV+PFtz4Y8zu1o61fq5+Fm2S0oHYtgDRVudH"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.stir.unidesk.ac.uk/tas/public/login/verify",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://keelesu.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://keelesu.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-12-19T10:52:06Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Keele SU"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://keelesu.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://keelesu.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://keelesu.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://keelesu.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://keelesu.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://keelesu.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://keelesu.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://keelesu.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://keelesu.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://keelesu.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://keelesu.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://keelesu.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://keelesu.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://keelesu.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://keelesu.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://keelesu.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://keelesu.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.hca.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.hca.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/hca.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/hca.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hca.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hereford College of Arts"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hca.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://drupal-pilot-web-02.it.ox.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sysdev@oucs.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Systems Development and Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sysdev@oucs.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Systems Development and Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://drupal-pilot-web-02.it.ox.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-10-12T09:43:31Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Oxford Drupal Pilot development"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.it.ox.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Oxford"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://drupal-pilot-web-02.it.ox.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://drupal-pilot-web-02.it.ox.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://drupal-pilot-web-02.it.ox.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://drupal-pilot-web-02.it.ox.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://drupal-pilot-council-dev.it.ox.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://drupal-pilot-council-dev.it.ox.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://drupal-pilot-council-dev.it.ox.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://drupal-pilot-council-dev.it.ox.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://drupal-pilot-web-02.it.ox.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://drupal-pilot-council-dev.it.ox.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWTCCAkGgAwIBAgIJAPOKjeXKIpPPMA0GCSqGSIb3DQEBBQUAMCoxKDAmBgNV\n\t\t\t\t\t\tBAMTH2RydXBhbC1waWxvdC13ZWItMDIuaXQub3guYWMudWswHhcNMTUxMDAxMTM1\n\t\t\t\t\t\tMzIzWhcNMjUwOTI4MTM1MzIzWjAqMSgwJgYDVQQDEx9kcnVwYWwtcGlsb3Qtd2Vi\n\t\t\t\t\t\tLTAyLml0Lm94LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tsQMf3qRXSHmQ0ye8gI0aveqbk6rIRXpcaxYFJ/ebcaec04TkFMq0LjBzE3Yj8UyS\n\t\t\t\t\t\tgk+tWTOIUrUlzREiMdfU4Qro2xERenlvttJAZnRGngjDfPXgHoQsg5lTjm/tRaHY\n\t\t\t\t\t\tLWnflxzA3XdPhd/t1D7J2DpBLL7p6ok+Y4PgwDOkZrc3eEpx7PcdLBn54f1RcbYC\n\t\t\t\t\t\tUz/jPHWJ0D6g+lg9HBjC9SjfnJv3lkUmXFV5DE05chK2uNHEjz8ZSbWYCrVPMcUx\n\t\t\t\t\t\tfBlpIGSTvstMjoz92DjbtTUP5H1+rR3yb2cBc0IiU0V+NfL8fMb79G5CXP6HAUL6\n\t\t\t\t\t\tXWo4vEh2x791KMLXC6wS8QIDAQABo4GBMH8wXgYDVR0RBFcwVYIfZHJ1cGFsLXBp\n\t\t\t\t\t\tbG90LXdlYi0wMi5pdC5veC5hYy51a4YyaHR0cHM6Ly9kcnVwYWwtcGlsb3Qtd2Vi\n\t\t\t\t\t\tLTAyLml0Lm94LmFjLnVrL3NoaWJib2xldGgwHQYDVR0OBBYEFLvwkmrVvmir9YsG\n\t\t\t\t\t\trI2ee4f0f4ILMA0GCSqGSIb3DQEBBQUAA4IBAQBAUPYBXkLeNnmjnVhbtG5T0zqe\n\t\t\t\t\t\t/8Vx9C+Y+9vPygR6pEtHNh2x5dJMB5gWny7Ks071rgs0/s2MdWoe72nC1NB4kieE\n\t\t\t\t\t\tmNvNGPSmSJxIYXA6ZVczIvajAl2qB9j4Q/lIJt2PmGBQmeOu7m9YzqCvSDfKMpgk\n\t\t\t\t\t\tKQ6y0BigQ6Tpa7tSFRzMwwK56dN2VoKAHPxclfExoIWsK2d8wPO/PiiVv99NxrDl\n\t\t\t\t\t\twICWl+HpC/pPJHVP2NMJPI7FLsO+Pzc8a2yTKl3QQWpV5HqK2P+/jhMzRcq7Bm80\n\t\t\t\t\t\t5DMxXDen4Zx9PRnX+LSqVDBXL2Sy3nsIbayFHVpLKYCdwFGpUco+zke0ik1i"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://drupal-pilot-web-02.it.ox.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://drupal-pilot-web-02.it.ox.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://drupal-pilot-web-02.it.ox.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://drupal-pilot-web-02.it.ox.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://drupal-pilot-council-dev.it.ox.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://drupal-pilot-council-dev.it.ox.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://drupal-pilot-council-dev.it.ox.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://drupal-pilot-council-dev.it.ox.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://drupal-pilot-web-02.it.ox.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://drupal-pilot-web-02.it.ox.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://drupal-pilot-web-02.it.ox.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://drupal-pilot-web-02.it.ox.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://drupal-pilot-web-02.it.ox.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://drupal-pilot-web-02.it.ox.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://drupal-pilot-council-dev.it.ox.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://drupal-pilot-council-dev.it.ox.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://drupal-pilot-council-dev.it.ox.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://drupal-pilot-council-dev.it.ox.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://drupal-pilot-council-dev.it.ox.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://drupal-pilot-council-dev.it.ox.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.oldham.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Catterall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:stuart.catterall@oldham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stuart"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hough"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:robert.hough@oldham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Catterall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:stuart.catterall@oldham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stuart"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hough"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:robert.hough@oldham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.oldham.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-07-31T13:45:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIRAMcHtIGAOBG7Xl/x6OlCvx8wDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzExMjAwMDAwMDBaFw0xNjExMTkyMzU5NTlaMEUxITAfBgNV\n\t\t\t\t\t\tBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEgMB4GA1UEAxMXc2hpYmJvbGV0\n\t\t\t\t\t\taC5vbGRoYW0uYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDp\n\t\t\t\t\t\tck8rlkYXQ99QaIZpn1ik2kBd7wvCnJ6QifQFXckEGEMSZzGG0/mWchho5XXOb+Sm\n\t\t\t\t\t\t6jOAIEI+m/pSzss1iz3tPAKJIujtV0D7NwiEwFaUOrOQ+oeRAQtdNS8GBbKPGMgH\n\t\t\t\t\t\tlsX6zIydvH/59ZeYT11FsKErwVb4n1apu2BbGuwK9M40vJ8eRwxS3y7kK64NdE9/\n\t\t\t\t\t\tXBsxC6+iswe9UBTMYi3h5Pny4ihsJtZrMgC+ctyZFv4N3GVTXA1gK7QaGaUjhg+M\n\t\t\t\t\t\tZ3CSDfpc6UzQ++hxvve8LO6w3nJ0M/uyyq9kZ5ZvxVcx8Dv+mFSWXdf9QC5A0amJ\n\t\t\t\t\t\tWXbZTlWDz3tHCvCC2FwxAgMBAAGjggF0MIIBcDAfBgNVHSMEGDAWgBQMvZNoDPPe\n\t\t\t\t\t\tq6NJays3V0fqkOO57TAdBgNVHQ4EFgQUxy1jShUzSc9Rh9vCP8y/c9yzUk0wDgYD\n\t\t\t\t\t\tVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEG\n\t\t\t\t\t\tCCsGAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoG\n\t\t\t\t\t\tA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5B\n\t\t\t\t\t\tU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2Ny\n\t\t\t\t\t\tdC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0\n\t\t\t\t\t\tdHA6Ly9vY3NwLnRjcy50ZXJlbmEub3JnMCIGA1UdEQQbMBmCF3NoaWJib2xldGgu\n\t\t\t\t\t\tb2xkaGFtLmFjLnVrMA0GCSqGSIb3DQEBBQUAA4IBAQB0Fwd2Jh3G5xkA8gbEi1HV\n\t\t\t\t\t\t2lvMgUxoo/8e4ZwmQpPT7zS/No3XGcpxw07+6Zx8X6FKm5MnqcLsehvJ5Vvpty6T\n\t\t\t\t\t\tjur/5oD0I4L+Vuj/fQxSuG7AlGMC/0geHY65BAuxVOrKhKEU3bBdSIg8aWZwjzLS\n\t\t\t\t\t\tCSyVju5jBTncT/ebRNdOVn9WQ6it8wQBHnLRw/s6liYD81K8OJL+WUUPetyDokGJ\n\t\t\t\t\t\tuRqaKvbYt5qYseXcbOrwBvyERQ3j+j+g4tLRWo/k1QJxilBbXtqo22L4e8AjOMN7\n\t\t\t\t\t\tSvdjM8XejBUGw++3ZzPbg/v0meOi2EidA5m5mHbAvLV248hMsLUCJxA9qYJ5DebU"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oldham.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.oldham.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.oldham.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.oldham.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.oldham.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.oldham.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.oldham.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.oldham.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.oldham.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oldham.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIRAMcHtIGAOBG7Xl/x6OlCvx8wDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzExMjAwMDAwMDBaFw0xNjExMTkyMzU5NTlaMEUxITAfBgNV\n\t\t\t\t\t\tBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEgMB4GA1UEAxMXc2hpYmJvbGV0\n\t\t\t\t\t\taC5vbGRoYW0uYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDp\n\t\t\t\t\t\tck8rlkYXQ99QaIZpn1ik2kBd7wvCnJ6QifQFXckEGEMSZzGG0/mWchho5XXOb+Sm\n\t\t\t\t\t\t6jOAIEI+m/pSzss1iz3tPAKJIujtV0D7NwiEwFaUOrOQ+oeRAQtdNS8GBbKPGMgH\n\t\t\t\t\t\tlsX6zIydvH/59ZeYT11FsKErwVb4n1apu2BbGuwK9M40vJ8eRwxS3y7kK64NdE9/\n\t\t\t\t\t\tXBsxC6+iswe9UBTMYi3h5Pny4ihsJtZrMgC+ctyZFv4N3GVTXA1gK7QaGaUjhg+M\n\t\t\t\t\t\tZ3CSDfpc6UzQ++hxvve8LO6w3nJ0M/uyyq9kZ5ZvxVcx8Dv+mFSWXdf9QC5A0amJ\n\t\t\t\t\t\tWXbZTlWDz3tHCvCC2FwxAgMBAAGjggF0MIIBcDAfBgNVHSMEGDAWgBQMvZNoDPPe\n\t\t\t\t\t\tq6NJays3V0fqkOO57TAdBgNVHQ4EFgQUxy1jShUzSc9Rh9vCP8y/c9yzUk0wDgYD\n\t\t\t\t\t\tVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEG\n\t\t\t\t\t\tCCsGAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoG\n\t\t\t\t\t\tA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5B\n\t\t\t\t\t\tU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2Ny\n\t\t\t\t\t\tdC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0\n\t\t\t\t\t\tdHA6Ly9vY3NwLnRjcy50ZXJlbmEub3JnMCIGA1UdEQQbMBmCF3NoaWJib2xldGgu\n\t\t\t\t\t\tb2xkaGFtLmFjLnVrMA0GCSqGSIb3DQEBBQUAA4IBAQB0Fwd2Jh3G5xkA8gbEi1HV\n\t\t\t\t\t\t2lvMgUxoo/8e4ZwmQpPT7zS/No3XGcpxw07+6Zx8X6FKm5MnqcLsehvJ5Vvpty6T\n\t\t\t\t\t\tjur/5oD0I4L+Vuj/fQxSuG7AlGMC/0geHY65BAuxVOrKhKEU3bBdSIg8aWZwjzLS\n\t\t\t\t\t\tCSyVju5jBTncT/ebRNdOVn9WQ6it8wQBHnLRw/s6liYD81K8OJL+WUUPetyDokGJ\n\t\t\t\t\t\tuRqaKvbYt5qYseXcbOrwBvyERQ3j+j+g4tLRWo/k1QJxilBbXtqo22L4e8AjOMN7\n\t\t\t\t\t\tSvdjM8XejBUGw++3ZzPbg/v0meOi2EidA5m5mHbAvLV248hMsLUCJxA9qYJ5DebU"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Oldham College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oldham.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Oldham College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-01.ladok.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-01.ladok.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-01.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-01.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-01.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-01.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-01.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-01.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-01.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;01"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;01"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-01.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-01.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAPEBgpwK1hxNMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wMS5sYWRvay51bXUuc2UwHhcNMTQxMDA2MDc1MTMxWhcNMjQx\nMDAzMDc1MTMxWjAhMR8wHQYDVQQDExZsYWRvazMtMDEubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0FInxZg2fEgXhvHMGxn0wAah\nTMCX0XTYmg5rs/fhJ2T0RAxuRCUmvf2ETW/F7makbonO75IDHghExLEUGkxcGK4v\n0uqaPM7/9C799QICJ5cmyrE7tCXOJPO9GAe28Qv88WJm/6DSwngnUryB2r7HlE0f\nUVrMQopRYLqD33eXBFQ732X9nqt9i/R5OK6O/kOE9nmyaBoQdmjZNLYxnobbDNrH\nPrcCje8NFVIxXjOzX8vssEpo8f0DtpOj34F15BSvrr8t5F28UdaTx0Hb7c9B3hW8\nKxAJxs0QHPCI/mgMpBxZBq+9uBLzTxiXvjUjw31EuQI6SJAkyyLBlqHgIUo6EQID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMDEubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0wMS5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUahPApJv5/xIpL/gbnN8MUfFhhUowDQYJKoZIhvcNAQEFBQADggEB\nAETmm90R56msmOBioztlxMk6TOQbPYVi4NOnqTOokD/X960brBKntkGpXSnNGd7K\ntmK5F2ThcZJZ7FuOev53zJv2lzroBv9t0D8S49I3g4JlEM9TgoS8/hi/bFuC3PCC\nONwj91gF9J6rzYTum9XhUOChqEg5JJskYHNHs9vmVfhmkHLh3RbGweXm3Da7zrph\nb+mNrM4Y+K+m3IlSj4NBvEIGlu8rf3rl1Iad2HcIevkCgiiCD8V+rumLzXSUTpKe\nZEqci1h+aWvVDHxYNmDsZbFWOYg+t+Wfcu9uZxHADXvamSFdFAQJqplrSgXsWKNG\nFgjs4zg7hkT8XjhWJeHVZjI="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-01.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-01.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-01.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-01.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-01.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-01.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-01.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-01.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-01.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-01.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.fnal.gov/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "terlyga@fnal.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga Terlyga"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lilstrom@fnal.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Al Lilianstrom"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "maltunay@fnal.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mine Altunay"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "artlee@fnal.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Art Lee"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://idp.fnal.gov/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://pingprod.fnal.gov:9031/idp/attrsvc.ssaml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDtDCCApygAwIBAgIGAU5qDxk/MA0GCSqGSIb3DQEBCwUAMIGaMQswCQYDVQQGEwJVUzELMAkG\nA1UECBMCSUwxEDAOBgNVBAcTB0JhdGF2aWExLjAsBgNVBAoTJUZlcm1pIE5hdGlvbmFsIEFjY2Vs\nZXJhdG9yIExhYm9yYXRvcnkxIDAeBgNVBAsTF0F1dGhlbnRpY2F0aW9uIFNlcnZpY2VzMRowGAYD\nVQQDExFwaW5ncHJvZC5mbmFsLmdvdjAeFw0xNTA3MDcxOTQ3MzFaFw0xODA3MDYxOTQ3MzFaMIGa\nMQswCQYDVQQGEwJVUzELMAkGA1UECBMCSUwxEDAOBgNVBAcTB0JhdGF2aWExLjAsBgNVBAoTJUZl\ncm1pIE5hdGlvbmFsIEFjY2VsZXJhdG9yIExhYm9yYXRvcnkxIDAeBgNVBAsTF0F1dGhlbnRpY2F0\naW9uIFNlcnZpY2VzMRowGAYDVQQDExFwaW5ncHJvZC5mbmFsLmdvdjCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAJd08n1npTMlLcBxZ8x/Wq99VdL0+EcipNjlJtwi9A8pXs4b42eokzpH\nWBOLWW7CF8KVkkeJsZHI9F/ik8u3V6r2BiPOEp9vjRgqE+BAt2zlRor+H/nqv5PyZ/L6/yLY4p8H\nAwdzjXa+CeWMlW8sClwNBR28yqt0a+lUyxApWNR2kyMU98EteGnAzEHdu6kCX6rDc1VoDlLbGajm\nTrPMypPcU3+PgDmVcRNLId3Htlq9IU82zgn9qMVDV6n8p85Yh+RzJDwETIqB8Us8697MDribOa0o\n3t4QOSJKFfbP3o8y/E+GEqWOGxsprJuI+EMb+zFVq1VdkhMi5fG6AKAXKzECAwEAATANBgkqhkiG\n9w0BAQsFAAOCAQEAaWUX/S/J4FoNHaN0jW2la9XpjEmIH0zzHCKkv794CtkJwihfKrXH/5ntu3z6\nWTtRUQRiv3JtTsRyNBDJeY1EJGlxnAoeGk1shSc9wbqXXm/XbhUTiZa9/NOG9jlq/7EWaaCaTRa7\n1eDB/QOMVwGm0RWW7j9r42hg/l9Sm+LtfCdkvTqZAQIz5UMD7LvWAvyv7EGv9t3NH6USbzrADsax\nvmLXS1toaIkjZd90Pvl5MkNQ7k7YXYaOJThjpXOBDyNdPGanCcaJQItGS6EG3dbKRdOqLxhYym42\n63F3WI6GgeS6dTHvrYMBaR6B5dDX7xa2rdsSp8pkSE3xk3OwvbJePw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fnal.gov"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pingprod.fnal.gov:9031/idp/SSO.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://pingprod.fnal.gov:9031/idp/SSO.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ecp-test.fnal.gov/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ecp-prod.fnal.gov/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ecp-prod.fnal.gov/idp-krb/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ecp-test.fnal.gov/idp-krb/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://pingprod.fnal.gov:9031/idp/ARS.ssaml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fnal.gov"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.fnal.gov/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Fermi National Accelerator Laboratory"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Fermilab's Production IdP Server"
                  }
                ],
                "logo": [
                  {
                    "text": "https://pingprod.fnal.gov:9031/files/flogo.png",
                    "lang": "en",
                    "height": "90",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "597"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.fnal.gov/pub/disclaim.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDtDCCApygAwIBAgIGAU5qDxk/MA0GCSqGSIb3DQEBCwUAMIGaMQswCQYDVQQGEwJVUzELMAkG\nA1UECBMCSUwxEDAOBgNVBAcTB0JhdGF2aWExLjAsBgNVBAoTJUZlcm1pIE5hdGlvbmFsIEFjY2Vs\nZXJhdG9yIExhYm9yYXRvcnkxIDAeBgNVBAsTF0F1dGhlbnRpY2F0aW9uIFNlcnZpY2VzMRowGAYD\nVQQDExFwaW5ncHJvZC5mbmFsLmdvdjAeFw0xNTA3MDcxOTQ3MzFaFw0xODA3MDYxOTQ3MzFaMIGa\nMQswCQYDVQQGEwJVUzELMAkGA1UECBMCSUwxEDAOBgNVBAcTB0JhdGF2aWExLjAsBgNVBAoTJUZl\ncm1pIE5hdGlvbmFsIEFjY2VsZXJhdG9yIExhYm9yYXRvcnkxIDAeBgNVBAsTF0F1dGhlbnRpY2F0\naW9uIFNlcnZpY2VzMRowGAYDVQQDExFwaW5ncHJvZC5mbmFsLmdvdjCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAJd08n1npTMlLcBxZ8x/Wq99VdL0+EcipNjlJtwi9A8pXs4b42eokzpH\nWBOLWW7CF8KVkkeJsZHI9F/ik8u3V6r2BiPOEp9vjRgqE+BAt2zlRor+H/nqv5PyZ/L6/yLY4p8H\nAwdzjXa+CeWMlW8sClwNBR28yqt0a+lUyxApWNR2kyMU98EteGnAzEHdu6kCX6rDc1VoDlLbGajm\nTrPMypPcU3+PgDmVcRNLId3Htlq9IU82zgn9qMVDV6n8p85Yh+RzJDwETIqB8Us8697MDribOa0o\n3t4QOSJKFfbP3o8y/E+GEqWOGxsprJuI+EMb+zFVq1VdkhMi5fG6AKAXKzECAwEAATANBgkqhkiG\n9w0BAQsFAAOCAQEAaWUX/S/J4FoNHaN0jW2la9XpjEmIH0zzHCKkv794CtkJwihfKrXH/5ntu3z6\nWTtRUQRiv3JtTsRyNBDJeY1EJGlxnAoeGk1shSc9wbqXXm/XbhUTiZa9/NOG9jlq/7EWaaCaTRa7\n1eDB/QOMVwGm0RWW7j9r42hg/l9Sm+LtfCdkvTqZAQIz5UMD7LvWAvyv7EGv9t3NH6USbzrADsax\nvmLXS1toaIkjZd90Pvl5MkNQ7k7YXYaOJThjpXOBDyNdPGanCcaJQItGS6EG3dbKRdOqLxhYym42\n63F3WI6GgeS6dTHvrYMBaR6B5dDX7xa2rdsSp8pkSE3xk3OwvbJePw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://pingprod.fnal.gov:9031/files/error.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Fermi National Accelerator Laboratory"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fnal.gov/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Fermi National Accelerator Laboratory"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sid.swarthmore.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shib-admin@swarthmore.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "stauffer@swarthmore.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Glenn Stauffer"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mclemen2@swarthmore.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael Clemente"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jrotunno@swarthmore.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jason Rotunno"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@swarthmore.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Swarthmore Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sid.swarthmore.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sid.swarthmore.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sid.swarthmore.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sid.swarthmore.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAO7xcYpBnwYIVTLfF6pF14NXi0KmMA0GCSqGSIb3DQEB\nBQUAMB0xGzAZBgNVBAMTEnNpZC5zd2FydGhtb3JlLmVkdTAeFw0xNDAyMTAyMDEw\nMThaFw0zNDAyMTAyMDEwMThaMB0xGzAZBgNVBAMTEnNpZC5zd2FydGhtb3JlLmVk\ndTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKFxkzJbUP/JjWW42xxm\nD5TOzoB5iQDgXTkSaN54Oe7oSDFzPb2KwavU6VJcnoT7uRARElQ+aYvKsVHlMWH9\nM8XS7V5i7VPVg0UnGSHa311O+ur2oqi4HInZJ54mldyY8XywWl3rYu4xLLUAl5+t\nLXlnus1UmWdxBqiyaGQlYy0YVkPBG2M6lvBsLUOdG2r7hha4yvqrnPgbAAADIz/v\naOSq+lB4g9ApDoPPB4ucwq8p3bGKmtiuJCdGDlpsahIYsm/2ifGnkVfyU3pCAdfr\naO+pAU4z8tS53d2gRTrBXH0R8C8jBeaF/qXCN52Kl+oYP76Z68Jt3XL/CUg7DwWj\nB0ECAwEAAaNrMGkwSAYDVR0RBEEwP4ISc2lkLnN3YXJ0aG1vcmUuZWR1hilodHRw\nczovL3NpZC5zd2FydGhtb3JlLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\nT6SCMFLKsSwfvX3fgI77E4c3xz8wDQYJKoZIhvcNAQEFBQADggEBACje/CpQzRRc\njrrNnirMbg3ERMwkLTtP6Ou2lrp8thPk5L+pIwsmdHJFpxtlQbqDSALRu16N68LF\nEfmx8GeTEKl60MIhVfCmf1glaE4D02gKL3P8M5USPNYcFuLjjpHacEwK26ASxNbe\n+N2ClItzuz2GP4KVgLgjPOkugeQNZT3DrKmsRMHBoqbkrIOM02c6YuhcnuHXNKV8\nG+CNVVb2DBJTvVkhO3f17lY/dklyI2gdwVllRNFBAnmy1Df9aWkDyKjUOJ/8q/fF\nCE6FGmpQsHtUKkKdVS5iUqYG7e6khmfvWCCsU25yjK9G05ktEvFcD/3FCsyGG3hs\nBaXUFreM06I="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "swarthmore.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Swarthmore College"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Swarthmore College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swarthmore College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.swarthmore.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Swarthmore College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dev1.redclara.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "seg@redclara.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Authentication Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "seg@redclara.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Urban"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mark.urban@redclara.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dev1.redclara.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "es",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://cofre.reuna.cl/index.php/es/reglas-federacion"
              }
            ],
            "registration_instant": "2014-02-21T00:00:00Z",
            "registration_authority": "http://cofre.reuna.cl",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RedCLARA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.redclara.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RedCLARA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev1.redclara.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev1.redclara.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev1.redclara.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev1.redclara.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Communities - RedCLARA"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Communities - RedCLARA"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev1.redclara.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.redclara.net/index.php?lang=en"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.redclara.net/index.php?lang=es"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "RedCLARA's Communities Service"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Servicio de Comunidades de RedCLARA"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Communities - RedCLARA"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Comunidades - RedCLARA"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dev1.redclara.net/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dev1.redclara.net/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "*.redclara.net"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "redclara.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFJzCCBA+gAwIBAgIQAycc1VlqLQ1YMhUWYD69ajANBgkqhkiG9w0BAQsFADBN\nMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMRGlnaUNlcnQgSW5jMScwJQYDVQQDEx5E\naWdpQ2VydCBTSEEyIFNlY3VyZSBTZXJ2ZXIgQ0EwHhcNMTQxMTI4MDAwMDAwWhcN\nMTcxMjA2MTIwMDAwWjB1MQswCQYDVQQGEwJVWTETMBEGA1UEBxMKTW9udGV2aWRl\nbzE4MDYGA1UECgwvQ29vcGVyYWNpw7NuIExhdGlub2FtZXJpY2FuYSBkZSBSZWRl\ncyBBdmFuemFkYXMxFzAVBgNVBAMMDioucmVkY2xhcmEubmV0MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEA4ciHwzKgzkUxp9PSRy9gV4WfIAmIjugbR8f9\nRJD9GwoMPTA173v4Rzjbnl8h/3e+iDfdzetHRM+gkOXwPCaGFpBQa2EPnxtFaaH6\nl8xtfHlsl8D2lqRkOE2OjvP8GzgpT3ikMBXoNr4TL7RQqzinwYCCJzLMSflwNbtk\n/a04k3l9FyxJ4mqEFP6aUsPJA0YRLVrYOIyppRzcHbRng/pNPE0R+JhNC3Kx2SbJ\nUvKtjQfvMJCn2T2dn5hg5mFnyMl78pgmRjppgxWEWkti+4eZoLg0OwVEFyGEgmEU\namd6JmRZTDs04BtstymJNXdkTsCP7yk92lpAc9C3NZ3FvrR0eQIDAQABo4IB2TCC\nAdUwHwYDVR0jBBgwFoAUD4BhHIIxYdUvKOeNRji0LOHG2eIwHQYDVR0OBBYEFBFj\nG3+tyY7afXZLfXNuYoGnE0nEMCcGA1UdEQQgMB6CDioucmVkY2xhcmEubmV0ggxy\nZWRjbGFyYS5uZXQwDgYDVR0PAQH/BAQDAgWgMB0GA1UdJQQWMBQGCCsGAQUFBwMB\nBggrBgEFBQcDAjBrBgNVHR8EZDBiMC+gLaArhilodHRwOi8vY3JsMy5kaWdpY2Vy\ndC5jb20vc3NjYS1zaGEyLWczLmNybDAvoC2gK4YpaHR0cDovL2NybDQuZGlnaWNl\ncnQuY29tL3NzY2Etc2hhMi1nMy5jcmwwQgYDVR0gBDswOTA3BglghkgBhv1sAQEw\nKjAoBggrBgEFBQcCARYcaHR0cHM6Ly93d3cuZGlnaWNlcnQuY29tL0NQUzB8Bggr\nBgEFBQcBAQRwMG4wJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmRpZ2ljZXJ0LmNv\nbTBGBggrBgEFBQcwAoY6aHR0cDovL2NhY2VydHMuZGlnaWNlcnQuY29tL0RpZ2lD\nZXJ0U0hBMlNlY3VyZVNlcnZlckNBLmNydDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3\nDQEBCwUAA4IBAQB3WePP9QxLi7OdtCbfR6kqIPDvfVX3aMvJ3/LQW9GhugwkV+ay\n8GyG17Dbm6Y2YSn1vl36lf/Nas4Lxf5jaVKXXoPUfANaDlJkK3E+cMsh1xrs8Uef\nMgiRll8Q28jA1RH+vmA+hzHOhuNqM8xHl2c/9Eq7FmFYoP4A1Lo/N9dEHHlHhSkG\nI6kBgBW/MAPvSLLPWr4v0u+/ynH9v+PEo60skvnrQPH0wFPoyJd/zxOMaomleJEv\nyL8CtS8Jo8/gqJ76zITM2JD1Cd+NBrPLk41I/hcfQ7Eewb/lkKe8/tpNm3e3bXJG\ns5W/0Lq2GRjQh9nrDfVs2IuE1c5zeqToyp98"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=*.redclara.net,O=Cooperaci\\C3\\B3n Latinoamericana de Redes Avanzadas,L=Montevideo,C=UY"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "*.redclara.net"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "redclara.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFJzCCBA+gAwIBAgIQAycc1VlqLQ1YMhUWYD69ajANBgkqhkiG9w0BAQsFADBN\nMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMRGlnaUNlcnQgSW5jMScwJQYDVQQDEx5E\naWdpQ2VydCBTSEEyIFNlY3VyZSBTZXJ2ZXIgQ0EwHhcNMTQxMTI4MDAwMDAwWhcN\nMTcxMjA2MTIwMDAwWjB1MQswCQYDVQQGEwJVWTETMBEGA1UEBxMKTW9udGV2aWRl\nbzE4MDYGA1UECgwvQ29vcGVyYWNpw7NuIExhdGlub2FtZXJpY2FuYSBkZSBSZWRl\ncyBBdmFuemFkYXMxFzAVBgNVBAMMDioucmVkY2xhcmEubmV0MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEA4ciHwzKgzkUxp9PSRy9gV4WfIAmIjugbR8f9\nRJD9GwoMPTA173v4Rzjbnl8h/3e+iDfdzetHRM+gkOXwPCaGFpBQa2EPnxtFaaH6\nl8xtfHlsl8D2lqRkOE2OjvP8GzgpT3ikMBXoNr4TL7RQqzinwYCCJzLMSflwNbtk\n/a04k3l9FyxJ4mqEFP6aUsPJA0YRLVrYOIyppRzcHbRng/pNPE0R+JhNC3Kx2SbJ\nUvKtjQfvMJCn2T2dn5hg5mFnyMl78pgmRjppgxWEWkti+4eZoLg0OwVEFyGEgmEU\namd6JmRZTDs04BtstymJNXdkTsCP7yk92lpAc9C3NZ3FvrR0eQIDAQABo4IB2TCC\nAdUwHwYDVR0jBBgwFoAUD4BhHIIxYdUvKOeNRji0LOHG2eIwHQYDVR0OBBYEFBFj\nG3+tyY7afXZLfXNuYoGnE0nEMCcGA1UdEQQgMB6CDioucmVkY2xhcmEubmV0ggxy\nZWRjbGFyYS5uZXQwDgYDVR0PAQH/BAQDAgWgMB0GA1UdJQQWMBQGCCsGAQUFBwMB\nBggrBgEFBQcDAjBrBgNVHR8EZDBiMC+gLaArhilodHRwOi8vY3JsMy5kaWdpY2Vy\ndC5jb20vc3NjYS1zaGEyLWczLmNybDAvoC2gK4YpaHR0cDovL2NybDQuZGlnaWNl\ncnQuY29tL3NzY2Etc2hhMi1nMy5jcmwwQgYDVR0gBDswOTA3BglghkgBhv1sAQEw\nKjAoBggrBgEFBQcCARYcaHR0cHM6Ly93d3cuZGlnaWNlcnQuY29tL0NQUzB8Bggr\nBgEFBQcBAQRwMG4wJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmRpZ2ljZXJ0LmNv\nbTBGBggrBgEFBQcwAoY6aHR0cDovL2NhY2VydHMuZGlnaWNlcnQuY29tL0RpZ2lD\nZXJ0U0hBMlNlY3VyZVNlcnZlckNBLmNydDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3\nDQEBCwUAA4IBAQB3WePP9QxLi7OdtCbfR6kqIPDvfVX3aMvJ3/LQW9GhugwkV+ay\n8GyG17Dbm6Y2YSn1vl36lf/Nas4Lxf5jaVKXXoPUfANaDlJkK3E+cMsh1xrs8Uef\nMgiRll8Q28jA1RH+vmA+hzHOhuNqM8xHl2c/9Eq7FmFYoP4A1Lo/N9dEHHlHhSkG\nI6kBgBW/MAPvSLLPWr4v0u+/ynH9v+PEo60skvnrQPH0wFPoyJd/zxOMaomleJEv\nyL8CtS8Jo8/gqJ76zITM2JD1Cd+NBrPLk41I/hcfQ7Eewb/lkKe8/tpNm3e3bXJG\ns5W/0Lq2GRjQh9nrDfVs2IuE1c5zeqToyp98"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=*.redclara.net,O=Cooperaci\\C3\\B3n Latinoamericana de Redes Avanzadas,L=Montevideo,C=UY"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev1.redclara.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev1.redclara.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev1.redclara.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev1.redclara.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev1.redclara.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dev1.redclara.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev1.redclara.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dev1.redclara.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dev1.redclara.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dev1.redclara.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.univ-evry.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "assistance-reseau@univ-evry.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.univ-evry.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2011-01-21T11:14:33Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.univ-evry.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.univ-evry.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.univ-evry.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-evry.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-evry.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 d'Evry Val d'Essonne"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 d'Evry Val d'Essonne"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRzCCAi+gAwIBAgIUAq2mpKTxqh6qstX6eHwrmooVbmMwDQYJKoZIhvcNAQEF\nBQAwIjEgMB4GA1UEAxMXc2hpYmJvbGV0aC51bml2LWV2cnkuZnIwHhcNMTAwOTI0\nMTA0OTA0WhcNMzAwOTI0MTA0OTA0WjAiMSAwHgYDVQQDExdzaGliYm9sZXRoLnVu\naXYtZXZyeS5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJp52EEk\nt5jLp2Fdl+FW8WxlusVfSKNpnmDCk08OeoWrF+6oxlfGzRxK87iUGawBhHx9Q3Iv\npDyxfCBr6Cl8uLD1B881s1HF79T5iNeNS42MwGCjYxDmnDK1Jc1DcNDP8e5wfvBL\n2fT8WSjajtOOy+KXFltTsIcoenaCLcPb3l3EBpxmQQdgLwWb886kExL6oeYXxtXs\nDlTo6jzVCtFRxw9JMx7DaaxlPGHLBkGuUjYV6HJ1lX9N9lKzLt5C8QP+zlvaNj4l\nl4NWnvoxZ6b6tmB8A3yOv6YJNZmJEztCWr5szNuLIHV1Ps//jinag738uxQVsH2b\ngYAkC5aLCdheVnMCAwEAAaN1MHMwUgYDVR0RBEswSYIXc2hpYmJvbGV0aC51bml2\nLWV2cnkuZnKGLmh0dHBzOi8vc2hpYmJvbGV0aC51bml2LWV2cnkuZnIvaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFEWCfI5AXn3/RakH6dnpRYDa2t9VMA0GCSqGSIb3\nDQEBBQUAA4IBAQBLNO5vu0/3c4pxRULtvx6c/OUQQQcjiPraIvVQVrnEb24aGKs7\npIHGnk3VnyPaieODwif5KDUqQc3fkG0tXIUVshI4aRzopVL4qFDfwi7KbpDS6nUC\ncRyZSJ4Xp6SYPhadkK49sLSe9lf5tdcn8Kr6EpAL3uvQx45HdtzV9CI1KS8nI/ZE\n+pvpXfptS9ZSrvsEz2SP9KjeEzSWiBTfCmGkKVxTPTiq/Qrg9Ceeoep8sj39Dh6Z\n2Y95aiTAmI2kjFbS4s2bZHjk/0TsYmOB8H6X+Ily18J3+xTfqvBw3c/inBzx1NT+\n21YW2cnfO+jzg5ZJqmB5D1PP001cJMAoHwV3"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 d'Evry Val d'Essonne"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-evry.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 d'Evry Val d'Essonne"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.bucks.ac.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@bucks.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "University IT Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Facey"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Oliver.Facey@bucks.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Oliver"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.bucks.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVANqu+NZEXr9JDN0KL+SXOAzT26P1MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBsxGTAXBgNVBAMTEGlkcDIuYnVja3MuYWMudWswHhcNMTAwMjIyMTEyNDQ3\n\t\t\t\t\t\tWhcNMzAwMjIyMTEyNDQ3WjAbMRkwFwYDVQQDExBpZHAyLmJ1Y2tzLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAm+/eL9vGVVAi8+UjXdF14DBe\n\t\t\t\t\t\tn8iaPlI97zOPvd0mXE9eTf9/3ZwpERG1RdlYStTyKzKJn9wSEOg09F9xjoCLjwLC\n\t\t\t\t\t\t8FYxUYstC+nMxSkvWVOc2KuSCxZ8k2rMYd8oIBa4S+Z8T1LZVlPLG3BUh/PPeITB\n\t\t\t\t\t\tqBU6mkAw463N4vcN0d5uTN4lmvb4pndeUwQNSFUgn8gdNo053iY0Rz96YkyqnZBT\n\t\t\t\t\t\tY0oJCi6xBdVZMGlaA7M85RZXF31gH3e1/XOKXTqG5/k4Wxz8Axsd+T3l2rF/Rf6u\n\t\t\t\t\t\tzDZNgDqpLUv173+NsV3OUy4pb0HL+T4lQbpzJAMwfpaoFNuW5EIYSFObRCApGQID\n\t\t\t\t\t\tAQABo2cwZTBEBgNVHREEPTA7ghBpZHAyLmJ1Y2tzLmFjLnVrhidodHRwczovL2lk\n\t\t\t\t\t\tcDIuYnVja3MuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFFMyfmRe4iDP\n\t\t\t\t\t\t7zdjl7Q2Xaj4kD2hMA0GCSqGSIb3DQEBBQUAA4IBAQBeiHBWZO3Uo8VRvtRi+XgE\n\t\t\t\t\t\tpw5kQCWc9N3z1jrDu6ue5jV6FiK+cimpyBtjRi83UA1mmyE3gnMBn3pUDmcyBAEr\n\t\t\t\t\t\th5Pft+/Yeqw4D7Z9u6zl3QxCSxXy5nz3kUQ2rfX7EaZaypH8vs1blmf/mYf8+WJ7\n\t\t\t\t\t\tNg/p0UgFFHR4w1GBms9bBV8oomirzKNBc1BhynaQ5QL8ebYIFAN+M5qf4p2w2ZHb\n\t\t\t\t\t\tZYZ8rzVKUn7pgsboBcZrcDJu5U80WKeE9UeCeb2NiySJozPNDyIxH5AAzfXTT+jd\n\t\t\t\t\t\tbiSMmVvAhGXgJqfaAeAqGEUayk8ttUtYCXDV3T+XkcJr8P8Iiwq5hejvWSb+cKwr"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bucks.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.bucks.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.bucks.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp2.bucks.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.bucks.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp2.bucks.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2.bucks.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.bucks.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.bucks.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bucks.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVANqu+NZEXr9JDN0KL+SXOAzT26P1MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBsxGTAXBgNVBAMTEGlkcDIuYnVja3MuYWMudWswHhcNMTAwMjIyMTEyNDQ3\n\t\t\t\t\t\tWhcNMzAwMjIyMTEyNDQ3WjAbMRkwFwYDVQQDExBpZHAyLmJ1Y2tzLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAm+/eL9vGVVAi8+UjXdF14DBe\n\t\t\t\t\t\tn8iaPlI97zOPvd0mXE9eTf9/3ZwpERG1RdlYStTyKzKJn9wSEOg09F9xjoCLjwLC\n\t\t\t\t\t\t8FYxUYstC+nMxSkvWVOc2KuSCxZ8k2rMYd8oIBa4S+Z8T1LZVlPLG3BUh/PPeITB\n\t\t\t\t\t\tqBU6mkAw463N4vcN0d5uTN4lmvb4pndeUwQNSFUgn8gdNo053iY0Rz96YkyqnZBT\n\t\t\t\t\t\tY0oJCi6xBdVZMGlaA7M85RZXF31gH3e1/XOKXTqG5/k4Wxz8Axsd+T3l2rF/Rf6u\n\t\t\t\t\t\tzDZNgDqpLUv173+NsV3OUy4pb0HL+T4lQbpzJAMwfpaoFNuW5EIYSFObRCApGQID\n\t\t\t\t\t\tAQABo2cwZTBEBgNVHREEPTA7ghBpZHAyLmJ1Y2tzLmFjLnVrhidodHRwczovL2lk\n\t\t\t\t\t\tcDIuYnVja3MuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFFMyfmRe4iDP\n\t\t\t\t\t\t7zdjl7Q2Xaj4kD2hMA0GCSqGSIb3DQEBBQUAA4IBAQBeiHBWZO3Uo8VRvtRi+XgE\n\t\t\t\t\t\tpw5kQCWc9N3z1jrDu6ue5jV6FiK+cimpyBtjRi83UA1mmyE3gnMBn3pUDmcyBAEr\n\t\t\t\t\t\th5Pft+/Yeqw4D7Z9u6zl3QxCSxXy5nz3kUQ2rfX7EaZaypH8vs1blmf/mYf8+WJ7\n\t\t\t\t\t\tNg/p0UgFFHR4w1GBms9bBV8oomirzKNBc1BhynaQ5QL8ebYIFAN+M5qf4p2w2ZHb\n\t\t\t\t\t\tZYZ8rzVKUn7pgsboBcZrcDJu5U80WKeE9UeCeb2NiySJozPNDyIxH5AAzfXTT+jd\n\t\t\t\t\t\tbiSMmVvAhGXgJqfaAeAqGEUayk8ttUtYCXDV3T+XkcJr8P8Iiwq5hejvWSb+cKwr"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Buckinghamshire New University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bucks.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Buckinghamshire New University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://wiki.shibboleth.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:contact@shibboleth.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth.Net Technical Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cantor"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cantor.2@osu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Scott"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Young"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ukfed@iay.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://wiki.shibboleth.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-01-06T16:23:40Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Shibboleth Federated Wiki"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.shibboleth.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "JISC Collections and Janet Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wiki.shibboleth.net/confluence/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wiki.shibboleth.net/confluence/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://wiki.shibboleth.net/confluence/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://wiki.shibboleth.net/confluence/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://wiki.shibboleth.net/confluence/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://wiki.shibboleth.net/confluence/Shibboleth.sso/EDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://wiki.shibboleth.net/confluence/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://wiki.shibboleth.net/confluence/Shibboleth.sso/EDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://wiki.shibboleth.net/confluence/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The wiki hosting the documentation for Shibboleth.\n\t\t\t\t\tUnauthenticated users may view the existing documentation. Authenticated users\n\t\t\t\t\tmay create new documentation pages and edit existing ones."
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth.net/images/gryphon_64x82.png",
                    "height": "82",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Shibboleth.net Wiki"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQjCCAiqgAwIBAgIJAMI1r/DZzTEJMA0GCSqGSIb3DQEBBQUAME8xEzARBgoJ\n\t\t\t\t\t\tkiaJk/IsZAEZFgNuZXQxGjAYBgoJkiaJk/IsZAEZFgpzaGliYm9sZXRoMRwwGgYD\n\t\t\t\t\t\tVQQDExN3aWtpLnNoaWJib2xldGgubmV0MB4XDTEzMTEyNTE0NTcyOFoXDTM3MDMw\n\t\t\t\t\t\tNDE0NTcyOFowTzETMBEGCgmSJomT8ixkARkWA25ldDEaMBgGCgmSJomT8ixkARkW\n\t\t\t\t\t\tCnNoaWJib2xldGgxHDAaBgNVBAMTE3dpa2kuc2hpYmJvbGV0aC5uZXQwggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC1viMiWhYa8cmxJ6rQ8yORYMD6Gx5n\n\t\t\t\t\t\tr/r9wQko+Tbjl/qGS0LaTfPQCokvwrD06506MPHainaMqbjlO4gDjq2LpU9/iy0s\n\t\t\t\t\t\tiLuY7UHgDqNNZOELBTQOMwLAFcuEA10FCWjJRglT+6w3xEFeU+dZkBXV1VvKBvsZ\n\t\t\t\t\t\tSiuQw437CcV3ueEF4+ZB0l9uyq8o3wzKRZ9DnpyFL7SUJiHJPuqqXZuyQnjLrbVZ\n\t\t\t\t\t\tKjjumGnY3LJTUo1xoUEuhqj5RMfspn2oc5YnIYka5YrCBmYKJV3QtCFbLA/cz8nF\n\t\t\t\t\t\tm+lOvYGz8nl3wHNkZIVRoetVw/Mhf7lzex0rh3XBdS6vVcT75uH0X1OPAgMBAAGj\n\t\t\t\t\t\tITAfMB0GA1UdDgQWBBQe1XwZavrgAhRXrfhv1gGUwSkc7DANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEADCGhWJ+oZ8ltcjJ7D66rMg1HOZT6GFCVeZ7MfhY/KFrvsnITNbTA+SgZ\n\t\t\t\t\t\ttCJt/BLlZXxpzmix19bD9bNwqEMo7WSqBy77X7SS97ZXti6y6vwAz8h78vzQopOd\n\t\t\t\t\t\trnn8XXyWxtrtRRCK4RMpZGrVm3sfBPW68j9hiPHZqewE4nLavjCki/I9rCMe5dJE\n\t\t\t\t\t\t3+ZRf4Ip/9hYqM+a5Chcvbo2zJEOtw+EUQqNTZ51j33H/2qF9UoSpt74UFh+Jd5y\n\t\t\t\t\t\tL2GoFSt/gCld78j/7cU3ObGQEme+hVVZ8/uGa/cCYvFt75vNBdnlj4icZ6fgFe9R\n\t\t\t\t\t\t9h5hlBTGD3PULSFmCdkgxtwIyd855Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://wiki.shibboleth.net/confluence/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://wiki.shibboleth.net/confluence/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wiki.shibboleth.net/confluence/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://wiki.shibboleth.net/confluence/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wiki.shibboleth.net/confluence/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://wiki.shibboleth.net/confluence/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Shibboleth.net Wiki"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The wiki hosting the documentation for Shibboleth.\n\t\t\t\tUnauthenticated user may view the existing documentation. Authenticated users\n\t\t\t\tmay create new documentation pages and edit existing ones."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:mail",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:displayName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:cn",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://afbi-shib.ads.qub.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:eresources@qub.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "E-Resouces Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Goodall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.goodall@qub.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://afbi-shib.ads.qub.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-04-08T14:20:53Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAOO+228Co5G8VjtIFdZLgr8NcmkNMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCIxIDAeBgNVBAMTF2FmYmktc2hpYi5hZHMucXViLmFjLnVrMB4XDTEzMDMy\n\t\t\t\t\t\tNTEyMjIwN1oXDTMzMDMyNTEyMjIwN1owIjEgMB4GA1UEAxMXYWZiaS1zaGliLmFk\n\t\t\t\t\t\tcy5xdWIuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC25Mj6\n\t\t\t\t\t\tJDVixh+B5wf/GQ/FwqAoA5WDat5YscMWNpFNq5ZvXX3IT3kEzsWzK25KwXtUElGJ\n\t\t\t\t\t\tTPz7+VVL/+HxRCSqgLvDeOMq4yD9AQjlB2uVuYMP9aTlFLrCUoi+JR0hjpE8Q5v6\n\t\t\t\t\t\t0F2OldmMujRVNaJEmTjcuMWGitFk5pG1jTfGSZDXUFn3CFrr3e+xWRat6USHioD2\n\t\t\t\t\t\tq7jLg5cmFE8JqViVRunGoYrJMC1W77RQ+R529HNt9K/F7ft7C4M+rkYteoAlx7yz\n\t\t\t\t\t\tuPVaR0FsAK9xpr5q9y0aq2pKkaPUgEbeAjXTBuJNFIDnloCzAxWjLDXW/IB/LQco\n\t\t\t\t\t\t6ha1LpRMU8vfGER7AgMBAAGjdTBzMFIGA1UdEQRLMEmCF2FmYmktc2hpYi5hZHMu\n\t\t\t\t\t\tcXViLmFjLnVrhi5odHRwczovL2FmYmktc2hpYi5hZHMucXViLmFjLnVrL2lkcC9z\n\t\t\t\t\t\taGliYm9sZXRoMB0GA1UdDgQWBBR+s3QwBH9KnP1UtNj2hV45cz/8lTANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAtdu9lrEo9NY77txEQh1y0NzjP/fZVR+PkTEMWx2vbqxZfvhm\n\t\t\t\t\t\twlnUukYbcRCcdxVpCxAsQpyaXHEDfdSsSjLFmEJ7R1fzWymOkh/xKUOT6svwm5pI\n\t\t\t\t\t\tPLE1K5tN+cBVo0RsRr6++HRjtHLsot2okTPMf/zMoUBK6pEkrOEdFpQFbvNLe0hG\n\t\t\t\t\t\tpgJIhPjBjj1lP3cVVS0lPsqZQvxftz8E6sQpUzR9Sy2iNplzFne8WCjEN+YKoVnj\n\t\t\t\t\t\t6tgvslECEk1hDFH4JV4HTpuVHJFF/1uXVgKht2p1cUavGWBCNINZQpoxYS/IyUa+\n\t\t\t\t\t\tDR5nSDGrbwRnkSsU2KYlDMvbuxf5eLC1ZwSeqw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "afbi.qub.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://afbi-shib.ads.qub.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://afbi-shib.ads.qub.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://afbi-shib.ads.qub.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://afbi-shib.ads.qub.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://afbi-shib.ads.qub.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://afbi-shib.ads.qub.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://afbi-shib.ads.qub.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://afbi-shib.ads.qub.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "afbi.qub.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAOO+228Co5G8VjtIFdZLgr8NcmkNMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCIxIDAeBgNVBAMTF2FmYmktc2hpYi5hZHMucXViLmFjLnVrMB4XDTEzMDMy\n\t\t\t\t\t\tNTEyMjIwN1oXDTMzMDMyNTEyMjIwN1owIjEgMB4GA1UEAxMXYWZiaS1zaGliLmFk\n\t\t\t\t\t\tcy5xdWIuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC25Mj6\n\t\t\t\t\t\tJDVixh+B5wf/GQ/FwqAoA5WDat5YscMWNpFNq5ZvXX3IT3kEzsWzK25KwXtUElGJ\n\t\t\t\t\t\tTPz7+VVL/+HxRCSqgLvDeOMq4yD9AQjlB2uVuYMP9aTlFLrCUoi+JR0hjpE8Q5v6\n\t\t\t\t\t\t0F2OldmMujRVNaJEmTjcuMWGitFk5pG1jTfGSZDXUFn3CFrr3e+xWRat6USHioD2\n\t\t\t\t\t\tq7jLg5cmFE8JqViVRunGoYrJMC1W77RQ+R529HNt9K/F7ft7C4M+rkYteoAlx7yz\n\t\t\t\t\t\tuPVaR0FsAK9xpr5q9y0aq2pKkaPUgEbeAjXTBuJNFIDnloCzAxWjLDXW/IB/LQco\n\t\t\t\t\t\t6ha1LpRMU8vfGER7AgMBAAGjdTBzMFIGA1UdEQRLMEmCF2FmYmktc2hpYi5hZHMu\n\t\t\t\t\t\tcXViLmFjLnVrhi5odHRwczovL2FmYmktc2hpYi5hZHMucXViLmFjLnVrL2lkcC9z\n\t\t\t\t\t\taGliYm9sZXRoMB0GA1UdDgQWBBR+s3QwBH9KnP1UtNj2hV45cz/8lTANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAtdu9lrEo9NY77txEQh1y0NzjP/fZVR+PkTEMWx2vbqxZfvhm\n\t\t\t\t\t\twlnUukYbcRCcdxVpCxAsQpyaXHEDfdSsSjLFmEJ7R1fzWymOkh/xKUOT6svwm5pI\n\t\t\t\t\t\tPLE1K5tN+cBVo0RsRr6++HRjtHLsot2okTPMf/zMoUBK6pEkrOEdFpQFbvNLe0hG\n\t\t\t\t\t\tpgJIhPjBjj1lP3cVVS0lPsqZQvxftz8E6sQpUzR9Sy2iNplzFne8WCjEN+YKoVnj\n\t\t\t\t\t\t6tgvslECEk1hDFH4JV4HTpuVHJFF/1uXVgKht2p1cUavGWBCNINZQpoxYS/IyUa+\n\t\t\t\t\t\tDR5nSDGrbwRnkSsU2KYlDMvbuxf5eLC1ZwSeqw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "AFBI: Agri-Food Biosciences Institute"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.afbini.gov.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Queen's University of Belfast"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.nordbiomed.net/saml/sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Urpalainen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:henri.urpalainen@mediamaisteri.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Henri"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Urpalainen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:henri.urpalainen@mediamaisteri.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Henri"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.nordbiomed.net/saml/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.csc.fi/english/institutions/haka/instructions/join/eduGAINRegistrationStatement/"
              }
            ],
            "registration_authority": "http://www.csc.fi/haka",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mediamaisteri"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mediamaisteri"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mediamaisteri"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mediamaisteri.com"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mediamaisteri.com"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mediamaisteri.com"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Mediamaisteri"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Mediamaisteri"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Mediamaisteri"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.nordbiomed.net/nordbiosaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Moodle webkurser om biomedicin f\u00f6r studenter p\u00e5 Nordbiomed programmet."
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Biol\u00e4\u00e4ketieteen Moodle verkkokursseja Nordbiomed ohjelman opiskelijoille"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Biomedicine online courses for Nordbiomed students in Moodle"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.mcampus.fi/Moodle_rekisteriseloste_EN.pdf"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.mcampus.fi/rekisteriseloste_mmg.pdf"
                  }
                ],
                "display_name": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Nordbiomed.net Moodle"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Nordbiomed.net Moodle"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Nordbiomed.net Moodle"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE/TCCA+WgAwIBAgIQTEIjMmXuufcFuvtWfJihPTANBgkqhkiG9w0BAQsFADBf\nMQswCQYDVQQGEwJGUjEOMAwGA1UECBMFUGFyaXMxDjAMBgNVBAcTBVBhcmlzMQ4w\nDAYDVQQKEwVHYW5kaTEgMB4GA1UEAxMXR2FuZGkgU3RhbmRhcmQgU1NMIENBIDIw\nHhcNMTUwNzE3MDAwMDAwWhcNMTYwODA4MjM1OTU5WjBdMSEwHwYDVQQLExhEb21h\naW4gQ29udHJvbCBWYWxpZGF0ZWQxGzAZBgNVBAsTEkdhbmRpIFN0YW5kYXJkIFNT\nTDEbMBkGA1UEAxMSd3d3Lm5vcmRiaW9tZWQubmV0MIIBIjANBgkqhkiG9w0BAQEF\nAAOCAQ8AMIIBCgKCAQEAls+xz8egoxxjFCKfIDzdVZHScL48GtfWfBAZafwuIJho\ndTmsbv9N5kbIm1uLh0GH+IuhEoJruOteMTe1m745IE9AoCluQPWzIfVaUjlc74YW\nQwJLHgaw6ZrzCA0ohP5SLHCOPJDv+1xAzlAumHmnsOw4mX7ea10Plot3SqMcO6rI\nzepln15pqPmmuo57X1jkpQREAKW59DqU5h2RecI56mdIgya3doPQxU3+C9dOMdDT\nz9tnp22IgGRnT1gkF8Ydi4QYFK0KDgLXoLWyuZt0V8N/OAjIGI0eEOjzdPup26k3\nWOvq70FzGpduv4FVPVu+fJjG7ifF0UZUh45yAQO2yQIDAQABo4IBtTCCAbEwHwYD\nVR0jBBgwFoAUs5Cn2MmvTs1hPJ98rV1/Qf1pMOowHQYDVR0OBBYEFCvesVl+fDPe\nJpcyFyNxkZ1Pew81MA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1Ud\nJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjBLBgNVHSAERDBCMDYGCysGAQQBsjEB\nAgIaMCcwJQYIKwYBBQUHAgEWGWh0dHBzOi8vY3BzLnVzZXJ0cnVzdC5jb20wCAYG\nZ4EMAQIBMEEGA1UdHwQ6MDgwNqA0oDKGMGh0dHA6Ly9jcmwudXNlcnRydXN0LmNv\nbS9HYW5kaVN0YW5kYXJkU1NMQ0EyLmNybDBzBggrBgEFBQcBAQRnMGUwPAYIKwYB\nBQUHMAKGMGh0dHA6Ly9jcnQudXNlcnRydXN0LmNvbS9HYW5kaVN0YW5kYXJkU1NM\nQ0EyLmNydDAlBggrBgEFBQcwAYYZaHR0cDovL29jc3AudXNlcnRydXN0LmNvbTAt\nBgNVHREEJjAkghJ3d3cubm9yZGJpb21lZC5uZXSCDm5vcmRiaW9tZWQubmV0MA0G\nCSqGSIb3DQEBCwUAA4IBAQCODf9haiwN3O9XzB9V4MBPPcB0661YbNJo2N6rguEk\nv9JbToStcACbQ3V0xb2yulk/rgw50U7Qd8nJ7FJg60UfXJsPJbhY82JBK2cXBsUR\naoxFqzTcOzeHsZzkHWCetMuJ3C2U7zJ7zlM5d00CKq4KUMPw4aIWa1ZVZzY6w7fk\nygsKkxkMt53Bgz+kboZ2Za7f8+mI1WSwOXGZ7JZvA1silbYaWqAOP/Q2p0YTonc/\ncb9svLVNv1dY7g+DHfHECFu9SLjl/htYmWWoUtL/59m+nPGPmDL6I/rjdzGtVGXi\nPbMcpBprCNt05806/04coPb2RbK0VDV5DG00Z/kNoGxR"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://www.nordbiomed.net/nordbiosaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "NordBioMed.net asiantuntijat kehittavat aktiivisesti kursseja biolaaketieteen alalle, taatakseen opetuksen laadun. Kursseja on mukana kehittamassa Karolinska Institutet, seka Ita-suomen, Turun , Bergenin ja Koopenhaminan yliopistot."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Nordic programmes of biomedicine have worked together in order to develop the field's teaching and quality management. This NordBioMed.net, comprising Karolinska Institutet and the Universities of Eastern Finland, Turku, Bergen and Copenhagen, is actively"
                },
                {
                  "lang": "sv",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Nordiska program for biomedicin har arbetat tillsammans for att utveckla  undervisning och kvalitetsstyrning. NordBioMed.net som  bestar av Karolinska Institutet, universiteten i ostra Finland, Abo,  Bergen och Kopenhamn, har aktivt utvecklat gemens"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Nordbiomed.net Moodle"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Nordbiomed.net Moodle"
                },
                {
                  "lang": "sv",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Nordbiomed.net Moodle"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cma-shibboleth.csum.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ITchange@csum.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Walter Abarca"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cma-shibboleth.csum.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cma-shibboleth.csum.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cma-shibboleth.csum.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cma-shibboleth.csum.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cma-shibboleth.csum.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cma-shibboleth.csum.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csum.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "California Maritime Academy"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIJANGfo3/EFOaFMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2NtYS1zaGliYm9sZXRoLmNzdW0uZWR1MB4XDTEwMDUwNzIyMTMzOVoXDTEz\nMDUwNjIyMTMzOVowIjEgMB4GA1UEAxMXY21hLXNoaWJib2xldGguY3N1bS5lZHUw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDgkG1bWSQW5CqTAcVhu4qi\nukj7tA5Fy71+hPMjlcPut/HVGzFbC50yykZlrBETKZHs/uQvhFTNf/pyMbpgLNNg\n9HLDFh9XRDrff5cod3hLbP9YMUJWRwTEotHPGSIzpEnJEQ49FR5GljJZk42HVqry\n/N17pgseO6Ye54aGrGUgmmulhb1w15yQ+IF6NH1mMmN1UfqL9HDQRe0ict+rT0cs\nQ3T/vWtFnEMYivWDKbUMkmFDbADdxRAHyk1XmY2s6evaq9zq43ZN6Nrx4Z+w8ogF\nZuOxAA3uqUFwzb0RYnkQJagn14taxYsqdG3s938v8moUoEJQH30WAqhjRnwqGRAt\nAgMBAAGjgYQwgYEwHQYDVR0OBBYEFM7EOttJXwWxNIfeiwsYeQR0YQrCMFIGA1Ud\nIwRLMEmAFM7EOttJXwWxNIfeiwsYeQR0YQrCoSakJDAiMSAwHgYDVQQDExdjbWEt\nc2hpYmJvbGV0aC5jc3VtLmVkdYIJANGfo3/EFOaFMAwGA1UdEwQFMAMBAf8wDQYJ\nKoZIhvcNAQEFBQADggEBAETxTbMfKsLKSuqv3vWZYB38XgGQOBZqOCgk5KHnWe9V\n2PggyG73lnr1s4yQHPxot6uK2sP6eYLjaIx/dPTJTivoXJAkECjnTWTWxnJVzh+k\ncZn4KdKgZlqTzIgBzPRpTl5kgBJf/wI38ecaAoWpDBTwrlrETJmE9v0mYnrhdX0u\nfDftIxBbFSfRQ2Qk+jYIHEPSYTGef56YLZkHrA5ohZ5G6rHpFMhIfbea843NZ3ZN\n3hevks7qbycgvP92CH/zLffB39C1ajsstCrmdjbU1m6/MXBYzz4lY9CtI0PIPvgd\neKdMuCgiKOUaEFR8gBOgGbpc3cDVXi0J1zwnq4+eKy4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California Maritime Academy"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csum.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California Maritime Academy"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://lumii-idp.lanet.lv",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ITserviss"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itserviss@lu.lv"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://lumii-idp.lanet.lv",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://laife.lanet.lv/wiki/Latvian-Academic-Identity-Federation-Policy.pdf"
              }
            ],
            "registration_instant": "2013-10-10T10:10:10Z",
            "registration_authority": "http://laife.lanet.lv/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lumii-idp.lanet.lv/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lumii-idp.lanet.lv/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lumii.lv"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:56.950974,24.116292"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "logo": [
                  {
                    "text": "https://lumii-idp.lanet.lv/icons/lumii-logo.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Mathematics and Computer Science, University of Latvia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Mathematics and Computer Science, University of Latvia"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lumii.lv/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LAIFE - LUMII"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib-pprd.middleware.vt.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "serac@vt.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marvin Addison"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib-pprd.middleware.vt.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login-pprd.middleware.vt.edu:10443/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login-pprd.middleware.vt.edu:10443/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEMTCCAxmgAwIBAgIJAKnt8KUieXQOMA0GCSqGSIb3DQEBBQUAMIGuMQswCQYD\nVQQGEwJVUzERMA8GA1UECAwIVmlyZ2luaWExEzARBgNVBAcMCkJsYWNrc2J1cmcx\nPDA6BgNVBAoMM1ZpcmdpbmlhIFBvbHl0ZWNobmljIEluc3RpdHV0ZSBhbmQgU3Rh\ndGUgVW5pdmVyc2l0eTETMBEGA1UECwwKTWlkZGxld2FyZTEkMCIGA1UEAwwbc2hp\nYi1wcHJkLm1pZGRsZXdhcmUudnQuZWR1MB4XDTE1MDMzMTE3NTQyOFoXDTIwMDMz\nMDE3NTQyOFowga4xCzAJBgNVBAYTAlVTMREwDwYDVQQIDAhWaXJnaW5pYTETMBEG\nA1UEBwwKQmxhY2tzYnVyZzE8MDoGA1UECgwzVmlyZ2luaWEgUG9seXRlY2huaWMg\nSW5zdGl0dXRlIGFuZCBTdGF0ZSBVbml2ZXJzaXR5MRMwEQYDVQQLDApNaWRkbGV3\nYXJlMSQwIgYDVQQDDBtzaGliLXBwcmQubWlkZGxld2FyZS52dC5lZHUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCgNWawKGtmrmACiOttv7A0QQAsr1Mi\nLiPqHX1WWYRo352T9pv+IWf8lP7Ye4LXrX7MnXXm2XOB7xzEv8E0DUWXbQf+7jit\nYlKLBmqYTzh+Z2K5JC39kVyCi/wDsi5M9rYTIjAyijr/v7fy1YGnsoqZG9qe2bm4\neoU3QsLea0AlpMZdbdt49x32NSoll6xHcz2O6iPKe17o37ook3fRaWe2B3yDPaX6\ndLr7EuVsn0ei1Npqqyj9u//eA8JlCNh08g7/gIj6z+28Vfa3ZlOfrjBStF6d7qp5\nMy3+bFX7Ldp9+bS6aTmGrFmEP5ryawRzxIKLY57b4Uk7s0XSFeuNJ0pjAgMBAAGj\nUDBOMB0GA1UdDgQWBBS2W871EVgk+1Y0nsJwK/bTP3F1ZjAfBgNVHSMEGDAWgBS2\nW871EVgk+1Y0nsJwK/bTP3F1ZjAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUA\nA4IBAQBYeNJx24OezaEE232V/nsfu5ryx5pBonnljXUSf7C7UfiMC63YXJyLYnCo\n/9yJyBeCnkkp1M6x7sgWIkeY2yNxbuajDX+UM5xMKNmq4sNQAPXutdAJ1yV9JcYd\nnb1O7454gzgaH2i7dNOKMCZPNgKsQ3INEIz3OPD9eBnMj4+chDTGHb5nYeb1CMFE\nwHLf5kXcL0BSav4X7toyyqjvlvqZMEz4PB6A16q005R+4GN1xgAjvjKjFlLDFhEh\ncOOlMaw85rDIC2DeqD8SFdnjGvNsP+Y6F9xWta9yDgA0J8r5PeOlPYEvhKYlWlb3\nc7h6iKRJ/Px5kmp/5GQqsrZ/c+1x"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vt.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login-pprd.middleware.vt.edu/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login-pprd.middleware.vt.edu/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login-pprd.middleware.vt.edu:10443/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login-pprd.middleware.vt.edu/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login-pprd.middleware.vt.edu/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login-pprd.middleware.vt.edu/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login-pprd.middleware.vt.edu/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login-pprd.middleware.vt.edu:10443/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login-pprd.middleware.vt.edu:10443/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vt.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TEST Virginia Tech IdP"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "zTEST_VTIdP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEMTCCAxmgAwIBAgIJAKdWq5o75wFhMA0GCSqGSIb3DQEBBQUAMIGuMQswCQYD\nVQQGEwJVUzERMA8GA1UECAwIVmlyZ2luaWExEzARBgNVBAcMCkJsYWNrc2J1cmcx\nPDA6BgNVBAoMM1ZpcmdpbmlhIFBvbHl0ZWNobmljIEluc3RpdHV0ZSBhbmQgU3Rh\ndGUgVW5pdmVyc2l0eTETMBEGA1UECwwKTWlkZGxld2FyZTEkMCIGA1UEAwwbc2hp\nYi1wcHJkLm1pZGRsZXdhcmUudnQuZWR1MB4XDTE1MDMzMTE3NTQ1MVoXDTIwMDMz\nMDE3NTQ1MVowga4xCzAJBgNVBAYTAlVTMREwDwYDVQQIDAhWaXJnaW5pYTETMBEG\nA1UEBwwKQmxhY2tzYnVyZzE8MDoGA1UECgwzVmlyZ2luaWEgUG9seXRlY2huaWMg\nSW5zdGl0dXRlIGFuZCBTdGF0ZSBVbml2ZXJzaXR5MRMwEQYDVQQLDApNaWRkbGV3\nYXJlMSQwIgYDVQQDDBtzaGliLXBwcmQubWlkZGxld2FyZS52dC5lZHUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC115mM3qIxxFAoGkwjGvpmQGqi3NhN\nst418It0iG4BVZR8UrruBsGBbH69G3ggDTKGRgJNA5HDcdZZMuWXqiNOQfWNTweA\npezxK941Ax1+tV5h0vbsx0JOGtMVabGYFcty/DNb9yu5XOLEc8aGQAxSusuU5WOp\n1XS0b7TXJBQfjPywXGcOpcVl2+GedDmjEeVKmxjfoW/HklLZjn1gCrxsJOzIwnOx\narbbc08ki97c5/Tu0BEvPeqSecOjRX2zlA3YHnPKvfj5lMRoD77az4RC4H8rNdE/\nIAqQVYt90OeTVShMad4uR/c42me45Rx+LQSFKL+dShXxIYXCYuF35y7bAgMBAAGj\nUDBOMB0GA1UdDgQWBBRHBJo36Os/RfOmR7yWQDsxgiQF4jAfBgNVHSMEGDAWgBRH\nBJo36Os/RfOmR7yWQDsxgiQF4jAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUA\nA4IBAQBToc/vEzySf7dFQjLqWJpmGxZgFo5xoVP66XF0qPIqAMKR1LLToetmLA0l\nNeuY5HzcpcuD5ILAHc7IZB+5RFSam1yQIj8L9u/KZTr+sdgyNm2KDHGhEmTTUB63\nJsAPDsCX8Uri2bGOk1JTnaNf/zTQxD4xD5tc/dsOUubw27xLX46LuN4w6GSvbQ+D\nRGfMNHwWfa0PXRqOMktEB4KRMimTVu7FfRX/NI8Qt1cMl0Ur/EKapBVy58SChwsS\nekCkx5H2+ar5TQpn8MoyloboaroHeHtFlQxhUY6fJWjcvZke6hY0W9MMubaovizq\nAzGwzzUtK3/d7PxUuTm7H1vsPcEs"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://login-pprd.middleware.vt.edu/support.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "zTEST_VTIdP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vt.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Virginia Polytechnic Institute and State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ws3.bmc.uu.se/shibboleth",
    {
      "entity_id": "https://ws3.bmc.uu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ws3.bmc.uu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ws3.bmc.uu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ws3.bmc.uu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ws3.bmc.uu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ws3.bmc.uu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ws3.bmc.uu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ws3.bmc.uu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ws3.bmc.uu.se/Shibboleth.sso/WAYF/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ws3.bmc.uu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ws3.bmc.uu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ws3.bmc.uu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJAJd2CtAiLVt5MA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDXdzMy5ibWMudXUuc2UwHhcNMTExMDIwMTExNjU2WhcNMjExMDE3MTExNjU2\nWjAYMRYwFAYDVQQDEw13czMuYm1jLnV1LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAqx7+HJExRK1e+/qomq6aSQwaEGtS+IDK32Fv74FiYp8L4U5I\n8eUAlm3FIHB7Oy48C+io2k8Dz75Xa8LfHA0Cr26kXdHWkr3mQe1P359sgKroWavR\ncYJZ95CUhhr0+V+imHRzWrMldkOUA/eDCNc4M0z+yFFZUG40qRk/UfZe2fw/DVCC\n/0yrUFmxWZm2Ucu0YU0nVS6uH1Hc/FViqYqYp3b9mAOH+ikxkrxz3QWgO8mgmFsq\nslgEefRqXoQGCTNiHMi3Qmy/eGTtosCDFGBmd+TgSAySGU7x4S3V5+4ITVcJA8Bg\nL4PcQzFVlGygsPmfplm//vt/13nqoaiZWgtK2wIDAQABozswOTAYBgNVHREEETAP\ngg13czMuYm1jLnV1LnNlMB0GA1UdDgQWBBQdGkaJLeARtbXFF9QMtMoypLlhgzAN\nBgkqhkiG9w0BAQUFAAOCAQEADuz7Porc0f074NZ/hJ6VyaUYkxAa4/pHqGtCFvi2\nqEf8DmJ7YyWqOoDx5hJMZ2yBkZi2vfIyJBNLJw5O6/puTDfhUNRKTPncAE6hIHQi\nbCluAlR5AJZF8nMzyB+7bTG6XyCWz2No/KZrUcRFh/VEVolrVQwZPQZyKUv/cYNh\nFExo68rNtRrKYOcY5sQk7h+9T/Jgl7NAUddzCcaqS1BDi1LpS82F1kjmUm3DQv13\npjMCd1M+kVHVj+YL5bwEF3ixEf4TUOLwD4GR+7iA4KYwQAwjQ9s2GEYVfcwoOh+N\nqQWpNmDn3kYrd5oTakoGUxe5200RC/e241+n+hwJtUsJ9A=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ws3.bmc.uu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ws3.bmc.uu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ws3.bmc.uu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ws3.bmc.uu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ws3.bmc.uu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ws3.bmc.uu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ws3.bmc.uu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://retrieverstories-dev.umbc.edu/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "collier@umbc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "B. Collier Jones"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "erude1@umbc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ed Rude"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "will3@umbc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Billy Schneider"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://retrieverstories-dev.umbc.edu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Maryland Baltimore County"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.umbc.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Maryland Baltimore County"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://retrieverstories-dev.umbc.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://retrieverstories-dev.umbc.edu"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Retriever Stories (development)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHjCCAgagAwIBAgIJAI0RUT0r/oX8MA0GCSqGSIb3DQEBBQUAMCgxJjAkBgNV\nBAMTHWphYmJhLXd3dy1wcm9kMS5jb3JlLnVtYmMuZWR1MB4XDTExMTAxMDIwMzYx\nMFoXDTIxMTAwNzIwMzYxMFowKDEmMCQGA1UEAxMdamFiYmEtd3d3LXByb2QxLmNv\ncmUudW1iYy5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC2IDFJ\nAGo41UtzNssD22c7fX0B+pRbMR51qpQL041yLnzcOJ+bke+R6OmX34pIWA0vagKM\nqu9iY+3GyEUxGHiuTNhDBvFKYcnO6qAEsgSroUrBCDbZo9Ntpli3ktf4zA5l11Wi\nzcMBt4HAbuXOlqD2LfE3jiPyUtOhgr2ODUoqBBIoYk3RjqxnWJ5kg5uroNjtWHOQ\nTpAM+lzm/aZEei9MO+iOu68kUR9Cf0QZQEAlxvUNWR/CPN2CF00FcfobN6r1rzkd\nQ7vNCXROs232WCL0RjqVl57NLg5ED02gelGzNWSl1MRN3tRxzWGyW0F5GLKwG888\ncT9LsXNEa+efkHYnAgMBAAGjSzBJMCgGA1UdEQQhMB+CHWphYmJhLXd3dy1wcm9k\nMS5jb3JlLnVtYmMuZWR1MB0GA1UdDgQWBBQh7CUvbTSbYcrvs/SftNs70q6XSDAN\nBgkqhkiG9w0BAQUFAAOCAQEASdHFzNxj+9RstGDYQxNTcBXzthJ0RZgwm2WgwRj4\npeDj19tKH7k/txzj2BaaVfusTxBBqdlWZElQuv5302MPH8zDP/lhtI2j4xsuOxHL\nWk6K8OzkjihskQeZnF6xaNlajtnab7BbrkFYmS4UCbiIOduJCmKQzbE0AFDZUN1j\nOXVVS7Im4xemrgUPAUArzcGEMhAuGc4fZgiJJ93Vtw/MzpcqXW3woU4s+yuY3Dcn\nwJC08P8O53sa3+tLYDHiJdjRo5cOXwbFhex/GrHIMAnN2s7lFw55P04VmLuo/7pB\nao6Rbsibw3/fICNNEUjDp113Ypd6MW4ncJ0OJhknmmrRRg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://retrieverstories-dev.umbc.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://retrieverstories-dev.umbc.edu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://retrieverstories-dev.umbc.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://retrieverstories-dev.umbc.edu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Retriever Stories (development)"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://tcs-personal-portal.terena.org/simplesamlphp/module.php/saml/sp/metadata.php/default-sp",
    {
      "entity_id": "https://tcs-personal-portal.terena.org/simplesamlphp/module.php/saml/sp/metadata.php/default-sp",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "TERENA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.terena.org/tcs"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "TERENA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://tcs-personal-portal.terena.org/simplesamlphp/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://tcs-personal-portal.terena.org/simplesamlphp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://tcs-personal-portal.terena.org/simplesamlphp/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://tcs-personal-portal.terena.org/simplesamlphp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://tcs-personal-portal.terena.org/simplesamlphp/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sso.kgv.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Coleman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mpc@kgv.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martyn"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Coleman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mpc@kgv.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martyn"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.kgv.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-06-14T15:39:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE4TCCA8mgAwIBAgIRAOgdNtecQeRkdUUz80ab59kwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzA1MTAwMDAwMDBaFw0xNjA1MDkyMzU5NTlaMIGzMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEQMA4GA1UEERMHUFI4IDZMUjETMBEGA1UECBMKTWVyc2V5c2lkZTES\n\t\t\t\t\t\tMBAGA1UEBxMJU09VVEhQT1JUMR0wGwYDVQQJExRTY2FyaXNicmljayBOZXcgUm9h\n\t\t\t\t\t\tZDEeMBwGA1UEChMVS2luZyBHZW9yZ2UgViBDb2xsZWdlMRIwEAYDVQQLEwlJVFN1\n\t\t\t\t\t\tcHBvcnQxFjAUBgNVBAMTDXNzby5rZ3YuYWMudWswggEiMA0GCSqGSIb3DQEBAQUA\n\t\t\t\t\t\tA4IBDwAwggEKAoIBAQDueymCOvHFvXJkoXtlKiOrfDC88zyRVVg4BpTnMzf7BSP2\n\t\t\t\t\t\tQHFcuJGXEDb6963Wufka5eBoD0YV3HMxkj/UJnlQIRWAJnVfcU5coMyjH8CgF9Bf\n\t\t\t\t\t\t9U5EZ28pXQWNuguvMqKtNLND8YIiDOcqO8e3trmwDv7PLnovSwCfTP09WJmqEJra\n\t\t\t\t\t\tyDhU8NdRYsNofVk9uLL8LePvttrIxi1o7oALtM4wxLbwhu/oMtikJ9hVdWLGovMa\n\t\t\t\t\t\tTUX5U5VP0Nyvw3/WYXcr/aqdSrTbszupI1A+/Vg5M42uFQYd/Fr2UW+AwPTHEz+F\n\t\t\t\t\t\toTWcGlg2D5R0hVo0JSnVeleyODk4LgdP3pGCgAKLAgMBAAGjggFqMIIBZjAfBgNV\n\t\t\t\t\t\tHSMEGDAWgBQMvZNoDPPeq6NJays3V0fqkOO57TAdBgNVHQ4EFgQUSx1khQvIHbbS\n\t\t\t\t\t\tAYJosmXfN/R6SMQwDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0l\n\t\t\t\t\t\tBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQEC\n\t\t\t\t\t\tAh0wCAYGZ4EMAQICMDoGA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRl\n\t\t\t\t\t\tcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEF\n\t\t\t\t\t\tBQcwAoYpaHR0cDovL2NydC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQw\n\t\t\t\t\t\tJgYIKwYBBQUHMAGGGmh0dHA6Ly9vY3NwLnRjcy50ZXJlbmEub3JnMBgGA1UdEQQR\n\t\t\t\t\t\tMA+CDXNzby5rZ3YuYWMudWswDQYJKoZIhvcNAQEFBQADggEBAAYbYA7nIj0rI03i\n\t\t\t\t\t\tJTm/m2hkxCPFfsCMB+6diphJEMffubScT/M6/MRcDDfkc1xT6m5AxDaHsDlgAkcO\n\t\t\t\t\t\tslEpTMOQnKm/dO3fAWv2Nx6AHTeStlzyiHTrUUEPcxcxRaadBz2TV+43lexjnibz\n\t\t\t\t\t\tgqnbz0Qc4sMqE3hXaRUixGrou1bk/8TGpJaUcGWdo+UnAXtkelzuPRAGLXZEcOon\n\t\t\t\t\t\t0FK89Xj6N+RUwAlA6Fuu/fXevoMdtHQ6b3EW2NZ7HcC5T3Du6XBYTv/CBSXX8FwP\n\t\t\t\t\t\t84TLS0UyU2VwGJ9b2iXEnX2uQ4p6hN6x/WdmGwrqxGmxmbcD7WLAvo7WnmdPThB8\n\t\t\t\t\t\tgtXXhng="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kgv.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.kgv.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.kgv.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso.kgv.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.kgv.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sso.kgv.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.kgv.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.kgv.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.kgv.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kgv.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE4TCCA8mgAwIBAgIRAOgdNtecQeRkdUUz80ab59kwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzA1MTAwMDAwMDBaFw0xNjA1MDkyMzU5NTlaMIGzMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEQMA4GA1UEERMHUFI4IDZMUjETMBEGA1UECBMKTWVyc2V5c2lkZTES\n\t\t\t\t\t\tMBAGA1UEBxMJU09VVEhQT1JUMR0wGwYDVQQJExRTY2FyaXNicmljayBOZXcgUm9h\n\t\t\t\t\t\tZDEeMBwGA1UEChMVS2luZyBHZW9yZ2UgViBDb2xsZWdlMRIwEAYDVQQLEwlJVFN1\n\t\t\t\t\t\tcHBvcnQxFjAUBgNVBAMTDXNzby5rZ3YuYWMudWswggEiMA0GCSqGSIb3DQEBAQUA\n\t\t\t\t\t\tA4IBDwAwggEKAoIBAQDueymCOvHFvXJkoXtlKiOrfDC88zyRVVg4BpTnMzf7BSP2\n\t\t\t\t\t\tQHFcuJGXEDb6963Wufka5eBoD0YV3HMxkj/UJnlQIRWAJnVfcU5coMyjH8CgF9Bf\n\t\t\t\t\t\t9U5EZ28pXQWNuguvMqKtNLND8YIiDOcqO8e3trmwDv7PLnovSwCfTP09WJmqEJra\n\t\t\t\t\t\tyDhU8NdRYsNofVk9uLL8LePvttrIxi1o7oALtM4wxLbwhu/oMtikJ9hVdWLGovMa\n\t\t\t\t\t\tTUX5U5VP0Nyvw3/WYXcr/aqdSrTbszupI1A+/Vg5M42uFQYd/Fr2UW+AwPTHEz+F\n\t\t\t\t\t\toTWcGlg2D5R0hVo0JSnVeleyODk4LgdP3pGCgAKLAgMBAAGjggFqMIIBZjAfBgNV\n\t\t\t\t\t\tHSMEGDAWgBQMvZNoDPPeq6NJays3V0fqkOO57TAdBgNVHQ4EFgQUSx1khQvIHbbS\n\t\t\t\t\t\tAYJosmXfN/R6SMQwDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0l\n\t\t\t\t\t\tBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQEC\n\t\t\t\t\t\tAh0wCAYGZ4EMAQICMDoGA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRl\n\t\t\t\t\t\tcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEF\n\t\t\t\t\t\tBQcwAoYpaHR0cDovL2NydC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQw\n\t\t\t\t\t\tJgYIKwYBBQUHMAGGGmh0dHA6Ly9vY3NwLnRjcy50ZXJlbmEub3JnMBgGA1UdEQQR\n\t\t\t\t\t\tMA+CDXNzby5rZ3YuYWMudWswDQYJKoZIhvcNAQEFBQADggEBAAYbYA7nIj0rI03i\n\t\t\t\t\t\tJTm/m2hkxCPFfsCMB+6diphJEMffubScT/M6/MRcDDfkc1xT6m5AxDaHsDlgAkcO\n\t\t\t\t\t\tslEpTMOQnKm/dO3fAWv2Nx6AHTeStlzyiHTrUUEPcxcxRaadBz2TV+43lexjnibz\n\t\t\t\t\t\tgqnbz0Qc4sMqE3hXaRUixGrou1bk/8TGpJaUcGWdo+UnAXtkelzuPRAGLXZEcOon\n\t\t\t\t\t\t0FK89Xj6N+RUwAlA6Fuu/fXevoMdtHQ6b3EW2NZ7HcC5T3Du6XBYTv/CBSXX8FwP\n\t\t\t\t\t\t84TLS0UyU2VwGJ9b2iXEnX2uQ4p6hN6x/WdmGwrqxGmxmbcD7WLAvo7WnmdPThB8\n\t\t\t\t\t\tgtXXhng="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "King George V College, Southport"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kgv.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "King George V College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dldev.acm.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ali"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ali@acm.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Asad"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Greenberg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:greenberg@acm.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dldev.acm.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-02-15T14:02:40Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Association For Computing Machinery: ACM Digital Library"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.acm.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Association for Computing Machinery, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dldev.acm.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dldev.acm.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dldev.acm.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dldev.acm.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dldev.acm.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dldev.acm.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dldev.acm.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAI+sbsQ8QmviMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEGFjbXdlYjEwLmFjbS5vcmcwHhcNMTMwNTMwMTk1NzI5WhcNMjMwNTI4MTk1\n\t\t\t\t\t\tNzI5WjAbMRkwFwYDVQQDExBhY213ZWIxMC5hY20ub3JnMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAxJG8see4mAOsTX6VGC6W7gTjIxZp007VCSvwYkH5\n\t\t\t\t\t\tI1Q2R4Hkl0DBWwwXlYklsZE07ycxDCEjGaqvxpON8/8V67IvlmvDdlpTmt8OQDmp\n\t\t\t\t\t\th8NpUR/FnOHuwdR8RDyQkQaCCLwFdeUBfAwvjZVpmAV/AgtPRd6nxb4PZW4XizAL\n\t\t\t\t\t\trmwWnPz3hxos5lyDKyzzwJJcqcTGSwD/qvYIk5miPfJgG0lhFTMJuukzpfdHv5Z0\n\t\t\t\t\t\tBofyhshiiVE+soJ3ebPTcE1f2BBG+zLMuQT5ory36adzgnuvOjZC0f0RU53KYYf3\n\t\t\t\t\t\tfCuC+/GUXzFBItOhSUatko38aib0QeQt4oD9yHsZA3ERQwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghBhY213ZWIxMC5hY20ub3JnMB0GA1UdDgQWBBSINwJG8YRgFRwXUSje\n\t\t\t\t\t\t6ydcAruXGjANBgkqhkiG9w0BAQUFAAOCAQEAiXKVkyxo8XBOs/Zs68wBX4bQqwmD\n\t\t\t\t\t\toz8qNKyDGRzoM86MrtoAX+GNcn1qs2xyAnQPM2YIdimUjxerdZv3YypCAwMrqwZk\n\t\t\t\t\t\tUGFCQndqZs05IiQV6BxjJFXTCOV0dwQy5iJMM1cWtYS8DDN25J2WF6CsmNDXESpf\n\t\t\t\t\t\tStYEnGYryPbfXB5QP5lJhafq67na/W5XlgOSdypgYLd+okt2KZxJrxGEGJ/Hvxdd\n\t\t\t\t\t\tlpyyFlpO4zleVRFXhb2QFfX+bskV1H8L8NSPj+vhrAC8AQC/uotzzqoSx17Ka4ih\n\t\t\t\t\t\tGmYriqXUnK+P3S5FP9oikKzKFzhgx+4xcNEroRKNHCVN3ZL2P/ORdCE0dQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dldev.acm.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dldev.acm.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dldev.acm.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dldev.acm.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dldev.acm.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dldev.acm.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-08.ladok.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-08.ladok.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;08"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;08"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-08.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-08.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAO5uNSsUisnLMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wOC5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTQ0MjU5WhcNMjQx\nMDA0MTQ0MjU5WjAhMR8wHQYDVQQDExZsYWRvazMtMDgubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA17Ttikn7C8StJRcTZVkLKwpn\nB1bnBxXkW4Nmf/m1+Nt+nO+q/5Mn19h5+ALZqexBNue95/ikK3BnNTddwZE3RzkV\nJ2LPTV6fseinRwvhxZDsyeDxyrYPs5cBYVRbYP++XmD0dN31Pfg3WkoPtPEUQ3y+\niEbgwMv1LYK9hgSRrvA/2rlpbsFg3zI9lHwoum97sFIZxv1GFNhRws/D4MpOX65L\nz5vxAFQquVNQ52rGXwN7P3RDP/1IjqnsBuHUk+nChmrpe8NGjhfVNa/FdZd+iaNR\nGrh80AGencDGOKcbwwyLlkQ6oDEsWAoxmLnaVrZjR2dId9XmOgswcy+xp3mKKQID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMDgubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0wOC5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUVPs+VHLQttdwq2k20jXjwE1QNaYwDQYJKoZIhvcNAQEFBQADggEB\nAIW42icVY8jhfhkbT7KEJcN3Ar+BxA7asqf9k2rddH/ivNJcUTx67VLf0hf7Znla\n3/OLPbqW0xBZzONpzqpEXVTB1H1ZIagfd9Z/5+I6tc2m5JLpFCG7aKj274rGxwpz\nolj/ZuLwEZp3zJBoWA9MMCiDGWAgzTS3H9Ys/QTUOVJR+B7HZ6FGTpcsT7IZUpuN\n7hR0zx92QePBX5nZv4p93vUOsj/SdwwgnyoT/c7mT5aUjvX6PtpqyK8sOMKwqrR3\nVmqhSIq31DIL5TJwnV8k1SJ95uWyflne1xoqht0IcL3QONAggkL14fVXx+nUSDVQ\n+IxJFSoCr7+UBhCVQpc1k5o="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-08.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.crous-grenoble.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Benoit LION"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "benoit.lion@crous-grenoble.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "S\u00e9bastien LEYRELOUP"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sebastien.leyreloup@crous-grenoble.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.crous-grenoble.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2011-12-08T22:14:26Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.crous-grenoble.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.crous-grenoble.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.crous-grenoble.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "crous-grenoble.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.crous-grenoble.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Grenoble - Personnels"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Grenoble - Personnels"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEdzCCA1+gAwIBAgIQJXNY9IPVDDkw5l9yCMhrQTANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDkxNTAwMDAwMFoXDTE3MDkxNDIzNTk1OVowQzEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMR4wHAYDVQQDExVpZHAuY3JvdXMt\nZ3Jlbm9ibGUuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDHPm9t\nJjz1cm0wZpVpxnN8vANWsur6N3iue42UeYbyXWTvHRSmO+QZMTYMULmTLf5zhp1r\nzF56kyPMfO7PMtJ5E1xlz22L+mlg7Rd3FQH3JZxlpZPDDVqXAL4mxZH/kPfrHr98\nkkp9tMbuGVC0CKyE6pVVw8HQrp2ZMNLVsHnwta0dMRDxUzOjpY3STs7BQxqO0rhy\nn53wd3jb74oIj5oTi1AW/r2lvu5d2IXTSWjlOxgpAg+Pay+rwT98yv0Ox0G6XdXQ\n8IhPrWdL421/VKIu5xqfDtSKgJeq2JNlamqx0crk7MlBRyUEXGMlOL0CPqzAiPfp\nTBn3LYg95jrVJ5ofAgMBAAGjggFyMIIBbjAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJ\nays3V0fqkOO57TAdBgNVHQ4EFgQUiAemAdbi7dUgmxf4rUhJVqdgFAIwDgYDVR0P\nAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsG\nAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1Ud\nHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NM\nQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50\nY3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6\nLy9vY3NwLnRjcy50ZXJlbmEub3JnMCAGA1UdEQQZMBeCFWlkcC5jcm91cy1ncmVu\nb2JsZS5mcjANBgkqhkiG9w0BAQUFAAOCAQEATZ2G4Kb8XApp47+o/4/GFetVkiZc\nL113ZiOXH4Q/ZD9sfAqh/6G5kvAYDdCLCL5UxmOcOkXH/wkXyoeP82yyFF5GeGzp\nmwKoOpr34+0ux4ctI1T1UZNPz5Bv4AUAEBbru6ZpCsEmw5KwFpSGOjPnlPspkJBT\nr3RAsxa5qG2yMzJRa0PiywpXd8q82JfFk2cHL9P4au0u5p9H9Hin+Cpvmn0StV51\niEsqhPuQmD3oc87nHEra79A3QGjMSN1zaSbcadRvXZhHdZaez/C9h8yyPKkR9wM2\nrp/TCvQsQDOOiVfOsrZjqiF1nBI3Z/KLRoV9yz3wmtdG59CY0Pf+XM0plg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS Grenoble - Personnels"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.crous-grenoble.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS Grenoble - Personnels"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sutest.dsv.su.se/shibboleth",
    {
      "entity_id": "https://sutest.dsv.su.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sutest.dsv.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sutest.dsv.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sutest.dsv.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sutest.dsv.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sutest.dsv.su.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sutest.dsv.su.se/Shibboleth.sso/DS/DSV",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sutest.dsv.su.se/Shibboleth.sso/DS/SU",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sutest.dsv.su.se/Shibboleth.sso/DS/SWAMID",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "sutest.dsv.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJANFaQko5QEDsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEHN1dGVzdC5kc3Yuc3Uuc2UwHhcNMTEwNjE0MTUxMDI5WhcNMjEwNjExMTUx\nMDI5WjAbMRkwFwYDVQQDExBzdXRlc3QuZHN2LnN1LnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA9dKcFUqB+h9m4Ce2+30IxJWbSuCup9EQIWDD15Ni\nu7LgB5v1lmPJvz3dNAO8oLGZc2GZ1MGC4LMTjOsOxyVBI3kK+sstXZ5HCcEXHGnN\ndawOEwMpAge81J/SU4py7fxb028I7CxBnyVTD0nQeaXYl8TwA9/Wi0fqdQrOpNY4\nHmd2izAT3+lPSWplNYQRdiZpDmpJ5Kpe0fqvwYk7IZ0yAePBVlmNMUO7Um6ONjM8\nRiD/F0Kvl2TycXa3fHZWP5QhF8Ovkg2l+bpbr78Nvj/oqY3jGAXnCnK2qoYmb6/N\n82kJ+53n55a/2YWS71Co2L6GcdXK9RD6J6GIO5F99VLFHwIDAQABoz4wPDAbBgNV\nHREEFDASghBzdXRlc3QuZHN2LnN1LnNlMB0GA1UdDgQWBBQsUNUB8MuUgg3w4rVX\nHCQfNaFJbDANBgkqhkiG9w0BAQUFAAOCAQEATmRML430Yi9BjDHVyEpYY3mEZkYT\nLhoFdN1yC8E37VG7ilUh/rI/BSvCrxt8KSZQ+5OusLq+4jVrNsESXD7PHDFAmQZ9\n5DMGnlZnYHbi9s2Eck8Na/c/jxza0gxaXG0IGmgYkVvcbHZ4HVNM1XOrn/EbtayE\nTRrcLGU0e+HjsbcULaB40DPyKJTPJrp+77H7560BQZXylxoDpTNuiKE7lvygoSbu\nHvZVD47jmfXvB9EmZnrzECl2gYKn3BJSbXFcvFnd8346qDw0p8mOxmiFu+5GRO7d\nIpamop1r0dxsmADb5Z3TF29YvB5OuZFPPwLKKg1tX9Nw+9199lffGUhEPg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=sutest.dsv.su.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "sutest.dsv.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJANFaQko5QEDsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEHN1dGVzdC5kc3Yuc3Uuc2UwHhcNMTEwNjE0MTUxMDI5WhcNMjEwNjExMTUx\nMDI5WjAbMRkwFwYDVQQDExBzdXRlc3QuZHN2LnN1LnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA9dKcFUqB+h9m4Ce2+30IxJWbSuCup9EQIWDD15Ni\nu7LgB5v1lmPJvz3dNAO8oLGZc2GZ1MGC4LMTjOsOxyVBI3kK+sstXZ5HCcEXHGnN\ndawOEwMpAge81J/SU4py7fxb028I7CxBnyVTD0nQeaXYl8TwA9/Wi0fqdQrOpNY4\nHmd2izAT3+lPSWplNYQRdiZpDmpJ5Kpe0fqvwYk7IZ0yAePBVlmNMUO7Um6ONjM8\nRiD/F0Kvl2TycXa3fHZWP5QhF8Ovkg2l+bpbr78Nvj/oqY3jGAXnCnK2qoYmb6/N\n82kJ+53n55a/2YWS71Co2L6GcdXK9RD6J6GIO5F99VLFHwIDAQABoz4wPDAbBgNV\nHREEFDASghBzdXRlc3QuZHN2LnN1LnNlMB0GA1UdDgQWBBQsUNUB8MuUgg3w4rVX\nHCQfNaFJbDANBgkqhkiG9w0BAQUFAAOCAQEATmRML430Yi9BjDHVyEpYY3mEZkYT\nLhoFdN1yC8E37VG7ilUh/rI/BSvCrxt8KSZQ+5OusLq+4jVrNsESXD7PHDFAmQZ9\n5DMGnlZnYHbi9s2Eck8Na/c/jxza0gxaXG0IGmgYkVvcbHZ4HVNM1XOrn/EbtayE\nTRrcLGU0e+HjsbcULaB40DPyKJTPJrp+77H7560BQZXylxoDpTNuiKE7lvygoSbu\nHvZVD47jmfXvB9EmZnrzECl2gYKn3BJSbXFcvFnd8346qDw0p8mOxmiFu+5GRO7d\nIpamop1r0dxsmADb5Z3TF29YvB5OuZFPPwLKKg1tX9Nw+9199lffGUhEPg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=sutest.dsv.su.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sutest.dsv.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sutest.dsv.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sutest.dsv.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sutest.dsv.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sutest.dsv.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sutest.dsv.su.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sutest.dsv.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sutest.dsv.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sutest.dsv.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sutest.dsv.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp1.ioe.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lau"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:y.lau@ioe.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Yu-king"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lau"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:y.lau@ioe.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Yu-king"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp1.ioe.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-03-20T14:43:42Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUMNyG7wrtkwxFGRAstVzy1ROpxGgwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGTEXMBUGA1UEAxMOaWRwMi5pb2UuYWMudWswHhcNMTIwMjA4MTUzMjM3WhcN\n\t\t\t\t\t\tMzIwMjA4MTUzMjM3WjAZMRcwFQYDVQQDEw5pZHAyLmlvZS5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN37KVPn30CW2BIleDIha2CleSXGY0a6\n\t\t\t\t\t\t1OA/eOLI+lsBvug487BAw/Rcf9Y7ooF3D8JIOxixwX1USXFyNCl0sf7/718UVpe0\n\t\t\t\t\t\tGxtcPYw/NwhtyVpQH+OqE/vh56pKw1o3WPnrFSHmj6/vSg0Pj1R0OFdvn+hoV+JC\n\t\t\t\t\t\t5POvdSBVkhS8KrRqse9Cr/CdYSmoQ55J1YCgiWngimPtes1zY4s2omZS9kEIi2Px\n\t\t\t\t\t\tShhgne1ZG3zR/4b6OXoEOr8K0LfAaPqsKYhwOzXXez6mYKak0rImeVqTdpk0Slyh\n\t\t\t\t\t\tNNYx7OsA++h2CmAgPOnevOjFNy7sbJ1GT1dAeRE3O+uDcURIgdZokf8CAwEAAaNj\n\t\t\t\t\t\tMGEwQAYDVR0RBDkwN4IOaWRwMi5pb2UuYWMudWuGJWh0dHBzOi8vaWRwMi5pb2Uu\n\t\t\t\t\t\tYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFOLtRIRYnBMYIo5SxgAJChkg\n\t\t\t\t\t\tZhbtMA0GCSqGSIb3DQEBBQUAA4IBAQCze9F7kn4uxmMTTyIel3fByZZNSmFj/blC\n\t\t\t\t\t\tUIOvCuuKWes5c7gMXCWP0INVj1ndi02zhdFxu6SoCDESy0kpGsYupcWNXMdUuNSA\n\t\t\t\t\t\tWnqbU+OfQ8byNGcnFf0p8TuHwANOaPWCK3Irthu2JXvm9mBe35Ghzf1uNOKkKP2i\n\t\t\t\t\t\tskDYHKQbL5LBKXJoDqtQeFtZSUHR1pwrcN8o25QPQzfRpgWhqA9pp9DscbLhzgSu\n\t\t\t\t\t\tnireWPUNaiihBLtqAQGIGauhQ1iznkN4BAolAnxC6encTbpdeF6zb+v22vm0JXfd\n\t\t\t\t\t\tw9lCORwIgQvhUPvXxS9oiA3XIwEAkid4j/wOQLE9plZLQx5+z78n"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ioe.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.ioe.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.ioe.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp2.ioe.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.ioe.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp2.ioe.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2.ioe.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.ioe.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.ioe.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ioe.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUMNyG7wrtkwxFGRAstVzy1ROpxGgwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGTEXMBUGA1UEAxMOaWRwMi5pb2UuYWMudWswHhcNMTIwMjA4MTUzMjM3WhcN\n\t\t\t\t\t\tMzIwMjA4MTUzMjM3WjAZMRcwFQYDVQQDEw5pZHAyLmlvZS5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN37KVPn30CW2BIleDIha2CleSXGY0a6\n\t\t\t\t\t\t1OA/eOLI+lsBvug487BAw/Rcf9Y7ooF3D8JIOxixwX1USXFyNCl0sf7/718UVpe0\n\t\t\t\t\t\tGxtcPYw/NwhtyVpQH+OqE/vh56pKw1o3WPnrFSHmj6/vSg0Pj1R0OFdvn+hoV+JC\n\t\t\t\t\t\t5POvdSBVkhS8KrRqse9Cr/CdYSmoQ55J1YCgiWngimPtes1zY4s2omZS9kEIi2Px\n\t\t\t\t\t\tShhgne1ZG3zR/4b6OXoEOr8K0LfAaPqsKYhwOzXXez6mYKak0rImeVqTdpk0Slyh\n\t\t\t\t\t\tNNYx7OsA++h2CmAgPOnevOjFNy7sbJ1GT1dAeRE3O+uDcURIgdZokf8CAwEAAaNj\n\t\t\t\t\t\tMGEwQAYDVR0RBDkwN4IOaWRwMi5pb2UuYWMudWuGJWh0dHBzOi8vaWRwMi5pb2Uu\n\t\t\t\t\t\tYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFOLtRIRYnBMYIo5SxgAJChkg\n\t\t\t\t\t\tZhbtMA0GCSqGSIb3DQEBBQUAA4IBAQCze9F7kn4uxmMTTyIel3fByZZNSmFj/blC\n\t\t\t\t\t\tUIOvCuuKWes5c7gMXCWP0INVj1ndi02zhdFxu6SoCDESy0kpGsYupcWNXMdUuNSA\n\t\t\t\t\t\tWnqbU+OfQ8byNGcnFf0p8TuHwANOaPWCK3Irthu2JXvm9mBe35Ghzf1uNOKkKP2i\n\t\t\t\t\t\tskDYHKQbL5LBKXJoDqtQeFtZSUHR1pwrcN8o25QPQzfRpgWhqA9pp9DscbLhzgSu\n\t\t\t\t\t\tnireWPUNaiihBLtqAQGIGauhQ1iznkN4BAolAnxC6encTbpdeF6zb+v22vm0JXfd\n\t\t\t\t\t\tw9lCORwIgQvhUPvXxS9oiA3XIwEAkid4j/wOQLE9plZLQx5+z78n"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Education, University of London"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ioe.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University College London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://hls.uwe.ac.uk/athens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lib.it@uwe.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Library IT Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lib.it@uwe.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Library IT Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://hls.uwe.ac.uk/athens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-11-15T16:34:27Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of the West of England (UWE) - HLS SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uwe.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of the West of England, Bristol"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkCgAwIBAgIJAIF9qCDnlp/PMA0GCSqGSIb3DQEBBQUAMCYxDDAKBgNV\n\t\t\t\t\t\tBAoTA1VXRTEWMBQGA1UEAxMNaGxzLnV3ZS5hYy51azAeFw0xMzExMTIxMTAxNTJa\n\t\t\t\t\t\tFw0yMzExMTAxMTAxNTJaMCYxDDAKBgNVBAoTA1VXRTEWMBQGA1UEAxMNaGxzLnV3\n\t\t\t\t\t\tZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKeL+4hyrrRQ\n\t\t\t\t\t\t44APl//eH/UQDbjO/tyPSpmOi50u6u/qfoYr4bc5qCSlToN3im30Gxq8YJ58mHVx\n\t\t\t\t\t\tdto7txqz4D0CFUMZBmRCcarLrMXEXUfebzPNkFV0LL6Ae12G9MfqWLCGJDQrJraX\n\t\t\t\t\t\tgT4xQYcMZlzHBTFfsGMF6LaOic/l3wyXVq3qeEwo2hmcEHTnW3wEf1+cY8dwL7Ms\n\t\t\t\t\t\t8hBsGGl8lKYOvUCv28rhBsHjffkf3DtJNlaE/0CeU1K0qRFiVusta7FuEG3K8B1p\n\t\t\t\t\t\to1B6sEuXPRbgjzHLeIWySE8GLJlb6iErpjLsym93acFQXYgBPdku78TUEQMiX4+k\n\t\t\t\t\t\tCnHLSb+E+Z8CAwEAAaOBiDCBhTAdBgNVHQ4EFgQU3PcvI9B6dkUu9jAFhjLjjnPN\n\t\t\t\t\t\tb2AwVgYDVR0jBE8wTYAU3PcvI9B6dkUu9jAFhjLjjnPNb2ChKqQoMCYxDDAKBgNV\n\t\t\t\t\t\tBAoTA1VXRTEWMBQGA1UEAxMNaGxzLnV3ZS5hYy51a4IJAIF9qCDnlp/PMAwGA1Ud\n\t\t\t\t\t\tEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAJmty3rQooOzSXU6q/IsS6+/DIpo\n\t\t\t\t\t\t2YUrHeuWtiS9yZKVFu+UkjXBs6pub/R7K70119ju/6XzkYYuF7uCjht6m3VaX5pK\n\t\t\t\t\t\t0v5p1+TTSxad18iyWBdZCSEbhnyhw39hg1BBrzxPHjgGANTxiw3KY90+4kDvfQM+\n\t\t\t\t\t\tB8jDb19FkDP2s385z0fqejBp+5LeEtY518lIdmQgT8cnqrW2z+2oLc0FdLL072Vo\n\t\t\t\t\t\twBMgfMJKeD0m1I9uREqMO1eg5feDEqfn+rrk88x8e/Pkz2njekPMadJNd9HE/tQi\n\t\t\t\t\t\tWiII6YDODMbcjfRCAJxuFOADibLPnWl0Zx22X2AZKgQEgqBY4ch6WKCaTZQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkCgAwIBAgIJAIF9qCDnlp/PMA0GCSqGSIb3DQEBBQUAMCYxDDAKBgNV\n\t\t\t\t\t\tBAoTA1VXRTEWMBQGA1UEAxMNaGxzLnV3ZS5hYy51azAeFw0xMzExMTIxMTAxNTJa\n\t\t\t\t\t\tFw0yMzExMTAxMTAxNTJaMCYxDDAKBgNVBAoTA1VXRTEWMBQGA1UEAxMNaGxzLnV3\n\t\t\t\t\t\tZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKeL+4hyrrRQ\n\t\t\t\t\t\t44APl//eH/UQDbjO/tyPSpmOi50u6u/qfoYr4bc5qCSlToN3im30Gxq8YJ58mHVx\n\t\t\t\t\t\tdto7txqz4D0CFUMZBmRCcarLrMXEXUfebzPNkFV0LL6Ae12G9MfqWLCGJDQrJraX\n\t\t\t\t\t\tgT4xQYcMZlzHBTFfsGMF6LaOic/l3wyXVq3qeEwo2hmcEHTnW3wEf1+cY8dwL7Ms\n\t\t\t\t\t\t8hBsGGl8lKYOvUCv28rhBsHjffkf3DtJNlaE/0CeU1K0qRFiVusta7FuEG3K8B1p\n\t\t\t\t\t\to1B6sEuXPRbgjzHLeIWySE8GLJlb6iErpjLsym93acFQXYgBPdku78TUEQMiX4+k\n\t\t\t\t\t\tCnHLSb+E+Z8CAwEAAaOBiDCBhTAdBgNVHQ4EFgQU3PcvI9B6dkUu9jAFhjLjjnPN\n\t\t\t\t\t\tb2AwVgYDVR0jBE8wTYAU3PcvI9B6dkUu9jAFhjLjjnPNb2ChKqQoMCYxDDAKBgNV\n\t\t\t\t\t\tBAoTA1VXRTEWMBQGA1UEAxMNaGxzLnV3ZS5hYy51a4IJAIF9qCDnlp/PMAwGA1Ud\n\t\t\t\t\t\tEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAJmty3rQooOzSXU6q/IsS6+/DIpo\n\t\t\t\t\t\t2YUrHeuWtiS9yZKVFu+UkjXBs6pub/R7K70119ju/6XzkYYuF7uCjht6m3VaX5pK\n\t\t\t\t\t\t0v5p1+TTSxad18iyWBdZCSEbhnyhw39hg1BBrzxPHjgGANTxiw3KY90+4kDvfQM+\n\t\t\t\t\t\tB8jDb19FkDP2s385z0fqejBp+5LeEtY518lIdmQgT8cnqrW2z+2oLc0FdLL072Vo\n\t\t\t\t\t\twBMgfMJKeD0m1I9uREqMO1eg5feDEqfn+rrk88x8e/Pkz2njekPMadJNd9HE/tQi\n\t\t\t\t\t\tWiII6YDODMbcjfRCAJxuFOADibLPnWl0Zx22X2AZKgQEgqBY4ch6WKCaTZQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "want_assertions_signed": "false",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://hls.uwe.ac.uk/athens/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://hls.uwe.ac.uk/athens/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hls.uwe.ac.uk/athens/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hls.uwe.ac.uk/athens/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://idp.si.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mcavoyj@si.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeffrey McAvoy"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "wungw@si.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Weber Wung"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "AvetaA@si.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex Aveta"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "JamwalJ@si.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jas Jamwal"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.si.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.si.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.si.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.si.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.si.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEzCCAfugAwIBAgIURicbi+W5DJNnSH6V80PzY0w8bqowDQYJKoZIhvcNAQEF\nBQAwFTETMBEGA1UEAxMKaWRwLnNpLmVkdTAeFw0xMTA4MTYxMzE4NDRaFw0zMTA4\nMTYxMzE4NDRaMBUxEzARBgNVBAMTCmlkcC5zaS5lZHUwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQCsLSjr8Hs24ca3oKpOoRUVpnbgx1ixdBcVGXywde+Z\n24zgm9rvRDucxCwQH1LYSCGXSfDChVmutdPZkAsSdt/j6eUp3VvRLIy8zA2lb/+Z\n4rIzRX/+07+Ti65FjgZ7rE4SiNQua0fsvkTtZuvJqJcfS7itrGQnzJ9vSq42Rbrp\nKjXUZHTWxSi2FEcfdiQqifo8rmV/uvCaTma4n4WzMxQOuN9Jfpz2FvobSZuW/dcd\nkCfsvoNBYW4zBQ/6bKMINlcWxVWVhrQe2ycZzp0q/E/8wr1SPfKiKWjaRylmA3Td\n8sGfDuIegpc8C+m8yYbs4AUQ38FGP9lCSHoEAgfBX503AgMBAAGjWzBZMDgGA1Ud\nEQQxMC+CCmlkcC5zaS5lZHWGIWh0dHBzOi8vaWRwLnNpLmVkdS9pZHAvc2hpYmJv\nbGV0aDAdBgNVHQ4EFgQUH7eODleiY1FnkHhARn6bhlXc5yswDQYJKoZIhvcNAQEF\nBQADggEBABTIKmvq4Pu9qZiRYRSpCX2WcLbHqbZ651mdIXcmz3QB9xIeyWDCWRzp\nlH+Zg2Zt4SBareU5m1UTnJxzyQRAFqopbxFqxhwDtd7Q/s23TH8C0XEvOu4RYOMG\nuMpOhcoMM2RulU/8MY4ga7wmOUkNcDpmorurVUT44puSi3jxUegUSwsVhHIJeIBL\nvcfm468S++LCzuKnkKiOYXSxaQlAjZDD5zOH8CBADP/A/CEzdf3mPBCMx/Hhtcsk\nBOetPLICbnq+Qh8VieTSm1b2EcS/c2NqtwbBv0RSsjN/LwIMmyTyUTagP360Nhvb\nRfYItwvvswQ2wtebkQpbdpNcuE7Ng8g="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "si.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Smithsonian Institution"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Smithsonian Institution"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.si.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Smithsonian Institution"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.justis.com",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@justis.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ganapathi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ravi.ganapathi@justis.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ravi"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.justis.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Justis Publishing"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.justispublishing.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Justis Publishing Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Justis Publishing"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonTargetedID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEADCCAuigAwIBAgIJAOUEkaPJ2Bd5MA0GCSqGSIb3DQEBBQUAMIGAMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEPMA0GA1UECAwGTG9uZG9uMQ8wDQYDVQQHDAZMb25kb24xHjAcBgNV\n\t\t\t\t\t\tBAoMFUp1c3RpcyBQdWJsaXNoaW5nIEx0ZDEUMBIGA1UECwwLRGV2ZWxvcG1lbnQx\n\t\t\t\t\t\tGTAXBgNVBAMMEGxvZ2luLmp1c3Rpcy5jb20wHhcNMTEwNzE4MTQ1MTMzWhcNMjEw\n\t\t\t\t\t\tNzE1MTQ1MTMzWjCBgDELMAkGA1UEBhMCR0IxDzANBgNVBAgMBkxvbmRvbjEPMA0G\n\t\t\t\t\t\tA1UEBwwGTG9uZG9uMR4wHAYDVQQKDBVKdXN0aXMgUHVibGlzaGluZyBMdGQxFDAS\n\t\t\t\t\t\tBgNVBAsMC0RldmVsb3BtZW50MRkwFwYDVQQDDBBsb2dpbi5qdXN0aXMuY29tMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA3w8g9C9ESGQ0H2JeatthhPcG\n\t\t\t\t\t\tEv3dywh7L27cbXmFL5yB8trjZRo6BfREpv4FRSgWlboRh62N/CQLHP6eF3gngSjR\n\t\t\t\t\t\taO3ERVm8KNKHmXXrhn4jP4EZYIFjXkO3MYYML4zdzgLWi2s9xbjN+ehQz/Hnvr9d\n\t\t\t\t\t\tw0n9pSMhWTyW4R0Hprgdf/KhssKKTIILXFgbzGrMTvATtCUbWhbY0eKOlrzVwgxZ\n\t\t\t\t\t\tTtt+1twitnAtG7L88X78NcwE49rKbMRFLcnLmXFF0nb71d2srGBwMDHJ4SagIRcR\n\t\t\t\t\t\tZZH/pjICbkuB0JzFUjnYYv7OGnHyxbSU6irjXB4Ci433KxArlBKtLS4w5agHKQID\n\t\t\t\t\t\tAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVy\n\t\t\t\t\t\tYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQU2ZuXN7VAgmrTrBEbRUT6AI3pPmsw\n\t\t\t\t\t\tHwYDVR0jBBgwFoAU2ZuXN7VAgmrTrBEbRUT6AI3pPmswDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAIyTpXAbDuMXIX49higmZ25epvKjkmgBcmMZnGayDUKwUD8PkzXt8g0BzywD\n\t\t\t\t\t\tseFZvib6KXOGSV2vxvKnhvwMacmpwFEXX90xyBdCt+DuLlpL6BmT9LdAANsdQHuC\n\t\t\t\t\t\tqOiB5SbfVRjDmDwXwLFaWMzu9UN+JP763GBPpMTkk+riHTNyC/n8FO5UWYUwuTyU\n\t\t\t\t\t\t/bY2QdSNZKtnrbGDlwWELTISsdCOz0ki4XRd0/WquIqcjfVTW+zGiQQuSIAWDx9Q\n\t\t\t\t\t\tNIvd6OcCOBRPMOvpQ4W5ZAMlO7++IzhzP7s2kHgb6yXBWvzJQx8aK8C1aE2eBBJK\n\t\t\t\t\t\t+Y+kE//yTUdY4YMzolvRCyf44z8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.justis.com/shibboleth/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.justis.com/shibboleth/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://signin.justis.com/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://signin.justis.com/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://signin.justis.com/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://signin.justis.com/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://signin.justis.com/shibboleth/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://signin.justis.com/shibboleth/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.justis.com/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.justis.com/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.justis.com/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.justis.com/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.we-learn.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Leach"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:leach.s@welearn365.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sam"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Leach"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:leach.s@welearn365.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sam"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.we-learn.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-03-12T16:34:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEmzCCA4OgAwIBAgIRALIgeKCSmCSkkGB68w8tkDgwDQYJKoZIhvcNAQELBQAw\n\t\t\t\t\t\tZDELMAkGA1UEBhMCTkwxFjAUBgNVBAgTDU5vb3JkLUhvbGxhbmQxEjAQBgNVBAcT\n\t\t\t\t\t\tCUFtc3RlcmRhbTEPMA0GA1UEChMGVEVSRU5BMRgwFgYDVQQDEw9URVJFTkEgU1NM\n\t\t\t\t\t\tIENBIDIwHhcNMTUwNDI0MDAwMDAwWhcNMTgwNDIzMjM1OTU5WjA+MSEwHwYDVQQL\n\t\t\t\t\t\tExhEb21haW4gQ29udHJvbCBWYWxpZGF0ZWQxGTAXBgNVBAMTEGlkcC53ZS1sZWFy\n\t\t\t\t\t\tbi5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCTaeY2M76584Kc\n\t\t\t\t\t\t5EAHUHOoPtNRe7OBh6HnDIkznaEuimIg/fYsEtIzUWYa12dtHCTiMGSw2mwfspcm\n\t\t\t\t\t\tfPQ+2+BxtpU9UsuPCgELVvDP66ilEKncIZqoR2DyE3KkXCBxFhoeQuW3aB6tJs8J\n\t\t\t\t\t\tSmm6WqbgtHoeMJ3BLihRJEN7Rv/LTh4YdznGR+jMlarsNjKRNDxNLtE5lLC+KC6H\n\t\t\t\t\t\tzT4vG1DfMXKSpFabPpoQGNFDTpN6g1T0SvlrPoVdzTr9nudNp1Tvx/A2qdrKhPu8\n\t\t\t\t\t\tOai9fv0BEhr/TypfhGpgLTv81WNFhCurKt6pdwg3/vMWNNrrCCVzWqBnAJ1DMmgY\n\t\t\t\t\t\tsobdNRw7AgMBAAGjggFsMIIBaDAfBgNVHSMEGDAWgBRb0IocmjJb4LXdllQb4YYo\n\t\t\t\t\t\tsP22vTAdBgNVHQ4EFgQUKq1u1QgwyxHQzgUGESXLq75oumMwDgYDVR0PAQH/BAQD\n\t\t\t\t\t\tAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMC\n\t\t\t\t\t\tMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1UdHwQzMDEw\n\t\t\t\t\t\tL6AtoCuGKWh0dHA6Ly9jcmwudXNlcnRydXN0LmNvbS9URVJFTkFTU0xDQTIuY3Js\n\t\t\t\t\t\tMGwGCCsGAQUFBwEBBGAwXjA1BggrBgEFBQcwAoYpaHR0cDovL2NydC51c2VydHJ1\n\t\t\t\t\t\tc3QuY29tL1RFUkVOQVNTTENBMi5jcnQwJQYIKwYBBQUHMAGGGWh0dHA6Ly9vY3Nw\n\t\t\t\t\t\tLnVzZXJ0cnVzdC5jb20wGwYDVR0RBBQwEoIQaWRwLndlLWxlYXJuLmNvbTANBgkq\n\t\t\t\t\t\thkiG9w0BAQsFAAOCAQEAL8acYPWalG9ngwLOpkjaQApU2E+Pi6CAoYqO3M0W8oRS\n\t\t\t\t\t\teysjGaswZ4g+9VZwyRI0N1iptjxK9JMCZZibN0w1Cnfg7iqcENywtKvK+cEW+/hL\n\t\t\t\t\t\t41bw1jfeRcPHFQCSlod7b5JZ0bSbb0qMN54NsuTjitwd6vFVSFU8sRSvG/eNkbnp\n\t\t\t\t\t\t7wa8IX7Hr/ZGTiR8Zrjb0EX/aAUPRz6YX5W0AxW9zYIgZ8ygmO0ri1uhspHh6sPF\n\t\t\t\t\t\to1cIOol/iyvTszEztbv5fqSUVrFre+EhFqZmstbD6oWJG29X5lnrgnokiRzlH307\n\t\t\t\t\t\tjFH1UhDrKPT2FKWjapS+ttqC6T3U8f2u0f/tvxC+hQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "we-learn.com"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.we-learn.com:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.we-learn.com:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.we-learn.com/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.we-learn.com/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.we-learn.com/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.we-learn.com/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.we-learn.com:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.we-learn.com:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "we-learn.com"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEmzCCA4OgAwIBAgIRALIgeKCSmCSkkGB68w8tkDgwDQYJKoZIhvcNAQELBQAw\n\t\t\t\t\t\tZDELMAkGA1UEBhMCTkwxFjAUBgNVBAgTDU5vb3JkLUhvbGxhbmQxEjAQBgNVBAcT\n\t\t\t\t\t\tCUFtc3RlcmRhbTEPMA0GA1UEChMGVEVSRU5BMRgwFgYDVQQDEw9URVJFTkEgU1NM\n\t\t\t\t\t\tIENBIDIwHhcNMTUwNDI0MDAwMDAwWhcNMTgwNDIzMjM1OTU5WjA+MSEwHwYDVQQL\n\t\t\t\t\t\tExhEb21haW4gQ29udHJvbCBWYWxpZGF0ZWQxGTAXBgNVBAMTEGlkcC53ZS1sZWFy\n\t\t\t\t\t\tbi5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCTaeY2M76584Kc\n\t\t\t\t\t\t5EAHUHOoPtNRe7OBh6HnDIkznaEuimIg/fYsEtIzUWYa12dtHCTiMGSw2mwfspcm\n\t\t\t\t\t\tfPQ+2+BxtpU9UsuPCgELVvDP66ilEKncIZqoR2DyE3KkXCBxFhoeQuW3aB6tJs8J\n\t\t\t\t\t\tSmm6WqbgtHoeMJ3BLihRJEN7Rv/LTh4YdznGR+jMlarsNjKRNDxNLtE5lLC+KC6H\n\t\t\t\t\t\tzT4vG1DfMXKSpFabPpoQGNFDTpN6g1T0SvlrPoVdzTr9nudNp1Tvx/A2qdrKhPu8\n\t\t\t\t\t\tOai9fv0BEhr/TypfhGpgLTv81WNFhCurKt6pdwg3/vMWNNrrCCVzWqBnAJ1DMmgY\n\t\t\t\t\t\tsobdNRw7AgMBAAGjggFsMIIBaDAfBgNVHSMEGDAWgBRb0IocmjJb4LXdllQb4YYo\n\t\t\t\t\t\tsP22vTAdBgNVHQ4EFgQUKq1u1QgwyxHQzgUGESXLq75oumMwDgYDVR0PAQH/BAQD\n\t\t\t\t\t\tAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMC\n\t\t\t\t\t\tMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1UdHwQzMDEw\n\t\t\t\t\t\tL6AtoCuGKWh0dHA6Ly9jcmwudXNlcnRydXN0LmNvbS9URVJFTkFTU0xDQTIuY3Js\n\t\t\t\t\t\tMGwGCCsGAQUFBwEBBGAwXjA1BggrBgEFBQcwAoYpaHR0cDovL2NydC51c2VydHJ1\n\t\t\t\t\t\tc3QuY29tL1RFUkVOQVNTTENBMi5jcnQwJQYIKwYBBQUHMAGGGWh0dHA6Ly9vY3Nw\n\t\t\t\t\t\tLnVzZXJ0cnVzdC5jb20wGwYDVR0RBBQwEoIQaWRwLndlLWxlYXJuLmNvbTANBgkq\n\t\t\t\t\t\thkiG9w0BAQsFAAOCAQEAL8acYPWalG9ngwLOpkjaQApU2E+Pi6CAoYqO3M0W8oRS\n\t\t\t\t\t\teysjGaswZ4g+9VZwyRI0N1iptjxK9JMCZZibN0w1Cnfg7iqcENywtKvK+cEW+/hL\n\t\t\t\t\t\t41bw1jfeRcPHFQCSlod7b5JZ0bSbb0qMN54NsuTjitwd6vFVSFU8sRSvG/eNkbnp\n\t\t\t\t\t\t7wa8IX7Hr/ZGTiR8Zrjb0EX/aAUPRz6YX5W0AxW9zYIgZ8ygmO0ri1uhspHh6sPF\n\t\t\t\t\t\to1cIOol/iyvTszEztbv5fqSUVrFre+EhFqZmstbD6oWJG29X5lnrgnokiRzlH307\n\t\t\t\t\t\tjFH1UhDrKPT2FKWjapS+ttqC6T3U8f2u0f/tvxC+hQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Warwickshire e-Learning Community"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.warwickshire.gov.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Warwickshire County Council"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://play.miun.se",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "saml_admin@kaltura.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://play.miun.se",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mittuniversitetet (PROD)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://play.miun.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Mittuniversitetet (PROD)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://play.miun.se/user/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service is for presentation of videos from Mid Sweden University"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Denna tj\u00e4nst anv\u00e4nds f\u00f6r presentationer av video fr\u00e5n Mittuniversitetet"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.miun.se/imagevault/publishedmedia/x4bl7padufcm1j4td3d7/logo.png",
                    "height": "111",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "225"
                  },
                  {
                    "text": "https://www.miun.se/imagevault/publishedmedia/x4bl7padufcm1j4td3d7/logo.png",
                    "lang": "sv",
                    "height": "111",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "225"
                  },
                  {
                    "text": "https://www.miun.se/imagevault/publishedmedia/x4bl7padufcm1j4td3d7/logo.png",
                    "lang": "en",
                    "height": "111",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "225"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mid Sweden University Play"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mittuniversitetet Play"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.miun.se/user/authenticate",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://samltest.swamid.se/re_nren_sfs/sp.xml",
    {
      "entity_id": "https://samltest.swamid.se/re_nren_sfs/sp.xml",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish Academic Identity Federation (SWAMID)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.swamid.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SWAMID"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://samltest.swamid.se/disco",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFcTCCBFmgAwIBAgIQIu7k1beHBKgWb27d90Ad9jANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQwODAwMDAwMFoXDTE3MDQwNzIzNTk1OVowQDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRswGQYDVQQDExJzYW1sdGVzdC5z\nd2FtaWQuc2UwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCcJfNqCJmM\nCWZ9+h9MAT9WbT/e+eRpGE9H8eucnnq4weTeFbT+2Ma15hY8hI6gP4GsDIZsaxTu\nDGgIYXctfnl9MTz+9rlANOo8Wjuz6CJ2trJ6BdhPvkoITuSqmIWkFbmP7/0NGkoG\n167CGp/Eq5yZnUOdiKXquH2S5OCw3mB4HGpjUk7T13cN0jOOPiK2cQhUTuUUMaVO\nei0QblIfK/+9fusfYOjd5uzNg1QZ9FvvbB/wTw4Z11eGcZWKpAprIrbx6iw119eL\nU7dvJhgA96VJmesDQejf96Xtpn7bCbxdyBqw2AtooamyrVjnAeQ8NDXW7td9MUuM\n4/yhN9H+fHTVJNs8dCX5FKayw5YoxF8eTMjRk0ObICMrLl8M/EiOG9Eqfc3TPGTF\ndn81sOGc3WzifRyG5fXUx/Xw9vXVkRAkVO6T4n6OUQxn2be9hwXR7yFw9tTplPIl\ndabhc7iWU7NgEBcBI3RWCcRNv0OVsXIMDeGZ64SOm4mpKbXMVebsnSLXxV69T1l4\nM8EegMpraRWHrbtF27FkKZPZgCbNaQbfW4vtJoN9rN07Flz8GLr200WXAepXT14L\ndGwXqjx6Cu2oilkl2OoNWQbRg3dvn1j6XqnRLbio4bvuiCYYEPpjuWcHOs/GwMnz\npml7EL51yz9PTwNZTQXsLH/xKlzWf1BuBQIDAQABo4IBbzCCAWswHwYDVR0jBBgw\nFoAUDL2TaAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFG40O0IHvLK2kXS6s4hN\nCq0DTtPLMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQG\nCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgG\nBmeBDAECATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEu\nb3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKG\nKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsG\nAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJz\nYW1sdGVzdC5zd2FtaWQuc2UwDQYJKoZIhvcNAQEFBQADggEBAHnWOLDwhrYWfd7q\n2fwTaiRP/x/tVPocNgi/wgwo6oZzC1Ru/HPjfUmnj11zkOOHeF8cf2BT2diRptPi\nqDc+7HN8GrM87+Deqvjj4pw7j4hwMpcfNd2AzqW4nPmw4LgiRehITtUtMxL9mkDh\neN0pgldD544xQRUdxYmD9nUWiIaTmuxNqusKkqUTD/kO41i+BxIeaWiXsw6IC7o6\nkPPUQHr1h2na805Kjoy5ML8K2EO+kcvFqfo42gtwa7mN38hKB+jbKF5VqqmoSb4m\nln/3lobOqcV8rrFKjvnjC6iNTbdpQ65o8CoOcfzhWmb/7RxkZ4a9fyzxVS8fMAi6\nu3Qzm3Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFcTCCBFmgAwIBAgIQIu7k1beHBKgWb27d90Ad9jANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQwODAwMDAwMFoXDTE3MDQwNzIzNTk1OVowQDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRswGQYDVQQDExJzYW1sdGVzdC5z\nd2FtaWQuc2UwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCcJfNqCJmM\nCWZ9+h9MAT9WbT/e+eRpGE9H8eucnnq4weTeFbT+2Ma15hY8hI6gP4GsDIZsaxTu\nDGgIYXctfnl9MTz+9rlANOo8Wjuz6CJ2trJ6BdhPvkoITuSqmIWkFbmP7/0NGkoG\n167CGp/Eq5yZnUOdiKXquH2S5OCw3mB4HGpjUk7T13cN0jOOPiK2cQhUTuUUMaVO\nei0QblIfK/+9fusfYOjd5uzNg1QZ9FvvbB/wTw4Z11eGcZWKpAprIrbx6iw119eL\nU7dvJhgA96VJmesDQejf96Xtpn7bCbxdyBqw2AtooamyrVjnAeQ8NDXW7td9MUuM\n4/yhN9H+fHTVJNs8dCX5FKayw5YoxF8eTMjRk0ObICMrLl8M/EiOG9Eqfc3TPGTF\ndn81sOGc3WzifRyG5fXUx/Xw9vXVkRAkVO6T4n6OUQxn2be9hwXR7yFw9tTplPIl\ndabhc7iWU7NgEBcBI3RWCcRNv0OVsXIMDeGZ64SOm4mpKbXMVebsnSLXxV69T1l4\nM8EegMpraRWHrbtF27FkKZPZgCbNaQbfW4vtJoN9rN07Flz8GLr200WXAepXT14L\ndGwXqjx6Cu2oilkl2OoNWQbRg3dvn1j6XqnRLbio4bvuiCYYEPpjuWcHOs/GwMnz\npml7EL51yz9PTwNZTQXsLH/xKlzWf1BuBQIDAQABo4IBbzCCAWswHwYDVR0jBBgw\nFoAUDL2TaAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFG40O0IHvLK2kXS6s4hN\nCq0DTtPLMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQG\nCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgG\nBmeBDAECATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEu\nb3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKG\nKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsG\nAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJz\nYW1sdGVzdC5zd2FtaWQuc2UwDQYJKoZIhvcNAQEFBQADggEBAHnWOLDwhrYWfd7q\n2fwTaiRP/x/tVPocNgi/wgwo6oZzC1Ru/HPjfUmnj11zkOOHeF8cf2BT2diRptPi\nqDc+7HN8GrM87+Deqvjj4pw7j4hwMpcfNd2AzqW4nPmw4LgiRehITtUtMxL9mkDh\neN0pgldD544xQRUdxYmD9nUWiIaTmuxNqusKkqUTD/kO41i+BxIeaWiXsw6IC7o6\nkPPUQHr1h2na805Kjoy5ML8K2EO+kcvFqfo42gtwa7mN38hKB+jbKF5VqqmoSb4m\nln/3lobOqcV8rrFKjvnjC6iNTbdpQ65o8CoOcfzhWmb/7RxkZ4a9fyzxVS8fMAi6\nu3Qzm3Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://samltest.swamid.se/acs/re_nren_sfs/redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://samltest.swamid.se/acs/re_nren_sfs/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://stipendier.uu.se/stipendium",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "http://stipendier.uu.se/stipendium",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://stipendier.uu.se:443/stipendium/saml/SingleLogout/alias/defaultAlias",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://stipendier.uu.se:443/stipendium/saml/SingleLogout/alias/defaultAlias",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://stipendier.uu.se/stipendium/stipac/login?lang=en"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://stipendier.uu.se/stipendium/stipac/login"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "System f\u00f6r att s\u00f6ka och hantera stipendium vid Uppsala universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Scholarship management system at Uppsala university"
                  }
                ],
                "logo": [
                  {
                    "text": "https://stipendier.uu.se/stipendium/img/UU-logga_125x125.png",
                    "height": "125",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "125"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Scholarship"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Stipendiehantering"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYzCCAkugAwIBAgIEXsncWDANBgkqhkiG9w0BAQsFADBiMQswCQYDVQQGEwJzZTEQMA4GA1UE\n\t\t\t\t\t\tCBMHU3ZlcmlnZTEQMA4GA1UEBxMHVXBwc2FsYTELMAkGA1UEChMCVVUxCzAJBgNVBAsTAklUMRUw\n\t\t\t\t\t\tEwYDVQQDEwxUb21teSBTdGVudmkwHhcNMTQwMTIxMTIzMzIxWhcNMTcxMDEyMTIzMzIxWjBiMQsw\n\t\t\t\t\t\tCQYDVQQGEwJzZTEQMA4GA1UECBMHU3ZlcmlnZTEQMA4GA1UEBxMHVXBwc2FsYTELMAkGA1UEChMC\n\t\t\t\t\t\tVVUxCzAJBgNVBAsTAklUMRUwEwYDVQQDEwxUb21teSBTdGVudmkwggEiMA0GCSqGSIb3DQEBAQUA\n\t\t\t\t\t\tA4IBDwAwggEKAoIBAQCYm9zOwWOyPzD3W2ophyDRR2YKEuWdP1ZzQAUf7nwBRa0sf62UODcvavGJ\n\t\t\t\t\t\tFK+yVjdtDayls5KPyIfHiW0vJAjWPrhCRE/Nk4pCyPhEbVhBtSA/JfXUEtB9Otf79G8PmxCJGfUN\n\t\t\t\t\t\tTeaFIl1PhEjQtQGS9IHe/N0P/Gxn9hJL+452ePbScB0hpC2/Z61GV2GDmz8l8g2FS4BXC/OxpqkR\n\t\t\t\t\t\tTfWqVvO7h8UJrrPfntqLTEHpD9Ex0LAy9RBXAj/4eUt8obzr84IJLITF875icjXyRcq0510gtGAr\n\t\t\t\t\t\tLytJxy/5KQ/Y2rUVfVBSg3m4C5BRiTAKjNncx+JFhq665tyiLtOTITxPAgMBAAGjITAfMB0GA1Ud\n\t\t\t\t\t\tDgQWBBTFo53xd9YijvyHlNUZ6Gt1YLLjQTANBgkqhkiG9w0BAQsFAAOCAQEAEFmcm96wM5/SwNCj\n\t\t\t\t\t\ti5uX3XFkQ2IDqeVmAAOmY/3cRh/kXxSM1OR1rifCl4kQlHHxV/9+r1EwiJ+LIhhnBHwJLM2TVFKD\n\t\t\t\t\t\tDRm5Lq9ghRzjiKponRltsGQzdZx5b5dAsG+J3J0TWJCp+HXoO6FNbIs0WAPm2nGkICyUi+ZBmdM1\n\t\t\t\t\t\tNHqA2JtG95d1VrNeZMmou7CdUBqRIWSlQPcGhawq4tKrs/6C79JLwfDhIPidJ3V0gkVSjm1FSNC5\n\t\t\t\t\t\tDJLTyRKIJB8d1r0/RpePenawO79D5eJlDeUTpu0LcPMyCKPGVT0tFaU/TyF6Jn8CJ2ZIlybtdXtp\n\t\t\t\t\t\tlQDSN7w4inBTDBIKvjWfVg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://stipendier.uu.se:443/stipendium/saml/SSO/alias/defaultAlias",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://stipendier.uu.se:443/stipendium/saml/SSO/alias/defaultAlias",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://stipendier.uu.se:443/stipendium/saml/SSO/alias/defaultAlias",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:profiles:holder-of-key:SSO:browser",
              "extension_attributes": {
                "{urn:oasis:names:tc:SAML:2.0:profiles:holder-of-key:SSO:browser}ProtocolBinding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact"
              },
              "location": "https://stipendier.uu.se:443/stipendium/saml/HoKSSO/alias/defaultAlias",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:profiles:holder-of-key:SSO:browser",
              "extension_attributes": {
                "{urn:oasis:names:tc:SAML:2.0:profiles:holder-of-key:SSO:browser}ProtocolBinding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST"
              },
              "location": "https://stipendier.uu.se:443/stipendium/saml/HoKSSO/alias/defaultAlias",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://openathens.warc.com/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Denham"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:andrew.denham@warc.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Denham"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:andrew.denham@warc.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://openathens.warc.com/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-28T09:05:09Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Warc.com"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.warc.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "WARC Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The largest single source of intelligence for marketing, advertising, media and research communities"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.warc.com/images/WarcSiteContent/WARCAthens.gif",
                    "height": "128",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "237"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Warc.com"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDeTCCAmGgAwIBAgIJALAX8VOBhTIkMA0GCSqGSIb3DQEBBQUAMDExETAPBgNV\n\t\t\tBAoTCFdhcmMgTHRkMRwwGgYDVQQDExNvcGVuYXRoZW5zLndhcmMuY29tMB4XDTE1\n\t\t\tMDUyMzEwNTAxN1oXDTI1MDUyMDEwNTAxN1owMTERMA8GA1UEChMIV2FyYyBMdGQx\n\t\t\tHDAaBgNVBAMTE29wZW5hdGhlbnMud2FyYy5jb20wggEiMA0GCSqGSIb3DQEBAQUA\n\t\t\tA4IBDwAwggEKAoIBAQDS2LJWqjg+ht8ZbflL0GnfC4gok1NF1n0XgRfvjJUzX+KB\n\t\t\tu7c9stOlsygoyZtgPE4uzbkO1TxKB0zx4BtUviLSddy5d2C4QkBQptrNm20FqkwU\n\t\t\tuxEo5fenquFRy7gaPCoyV65O0yjGd91raN0Ds88tjVaKaaf1PNkhTXUXEFPSlc0k\n\t\t\tS0aAFjx4IH7hfEP3M0jUP4FzbvnIG3c5yPwza/Y3C0Pki0dfs9rwywxBst9TdfXZ\n\t\t\to+E7fKpMUxGH+VvhPxsj6a6Qxpc+aVLKejvdg8s/iVyOWakeCtkDxfO0l1/DzWJd\n\t\t\tgEetR65EkG204AycfzM+rGKb6j/gj5BfXONIoIkXAgMBAAGjgZMwgZAwHQYDVR0O\n\t\t\tBBYEFE2bamIeuJQPBRGJSRwuVF3LKIFnMGEGA1UdIwRaMFiAFE2bamIeuJQPBRGJ\n\t\t\tSRwuVF3LKIFnoTWkMzAxMREwDwYDVQQKEwhXYXJjIEx0ZDEcMBoGA1UEAxMTb3Bl\n\t\t\tbmF0aGVucy53YXJjLmNvbYIJALAX8VOBhTIkMAwGA1UdEwQFMAMBAf8wDQYJKoZI\n\t\t\thvcNAQEFBQADggEBABAHDhIjgQPg1Rng8yzqwAXkv9O9d4uMokdosYi/Q5MqPTzj\n\t\t\tyAfa1PfhAQzaroG8RgnoSDzbEXDwNbWXuN/i2i9spticshmliuMB70zgfo7cNF5R\n\t\t\tDJNZLvZZpdj/a89Km2e8K7I6tMSBAeNXtrcFKTsJF0WoXJC+Ps8xlRYrtR60WavC\n\t\t\taEP2TUJ7VVEBlauPN+o/oldF+gxycwFPOn9PvFrr0Xsv5lEyFvNVN/QHUj6yTxbR\n\t\t\t0bupxzSmUCOeItj/V0hOlgT1SEnSviMB3rSQJU6luZ13VkPjL0N5h6C8RXnegngJ\n\t\t\tG7IhNFU840UuC06AYA5AB6KHGl3ijvAla11Fk6E="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDeTCCAmGgAwIBAgIJALAX8VOBhTIkMA0GCSqGSIb3DQEBBQUAMDExETAPBgNV\n\t\t\tBAoTCFdhcmMgTHRkMRwwGgYDVQQDExNvcGVuYXRoZW5zLndhcmMuY29tMB4XDTE1\n\t\t\tMDUyMzEwNTAxN1oXDTI1MDUyMDEwNTAxN1owMTERMA8GA1UEChMIV2FyYyBMdGQx\n\t\t\tHDAaBgNVBAMTE29wZW5hdGhlbnMud2FyYy5jb20wggEiMA0GCSqGSIb3DQEBAQUA\n\t\t\tA4IBDwAwggEKAoIBAQDS2LJWqjg+ht8ZbflL0GnfC4gok1NF1n0XgRfvjJUzX+KB\n\t\t\tu7c9stOlsygoyZtgPE4uzbkO1TxKB0zx4BtUviLSddy5d2C4QkBQptrNm20FqkwU\n\t\t\tuxEo5fenquFRy7gaPCoyV65O0yjGd91raN0Ds88tjVaKaaf1PNkhTXUXEFPSlc0k\n\t\t\tS0aAFjx4IH7hfEP3M0jUP4FzbvnIG3c5yPwza/Y3C0Pki0dfs9rwywxBst9TdfXZ\n\t\t\to+E7fKpMUxGH+VvhPxsj6a6Qxpc+aVLKejvdg8s/iVyOWakeCtkDxfO0l1/DzWJd\n\t\t\tgEetR65EkG204AycfzM+rGKb6j/gj5BfXONIoIkXAgMBAAGjgZMwgZAwHQYDVR0O\n\t\t\tBBYEFE2bamIeuJQPBRGJSRwuVF3LKIFnMGEGA1UdIwRaMFiAFE2bamIeuJQPBRGJ\n\t\t\tSRwuVF3LKIFnoTWkMzAxMREwDwYDVQQKEwhXYXJjIEx0ZDEcMBoGA1UEAxMTb3Bl\n\t\t\tbmF0aGVucy53YXJjLmNvbYIJALAX8VOBhTIkMAwGA1UdEwQFMAMBAf8wDQYJKoZI\n\t\t\thvcNAQEFBQADggEBABAHDhIjgQPg1Rng8yzqwAXkv9O9d4uMokdosYi/Q5MqPTzj\n\t\t\tyAfa1PfhAQzaroG8RgnoSDzbEXDwNbWXuN/i2i9spticshmliuMB70zgfo7cNF5R\n\t\t\tDJNZLvZZpdj/a89Km2e8K7I6tMSBAeNXtrcFKTsJF0WoXJC+Ps8xlRYrtR60WavC\n\t\t\taEP2TUJ7VVEBlauPN+o/oldF+gxycwFPOn9PvFrr0Xsv5lEyFvNVN/QHUj6yTxbR\n\t\t\t0bupxzSmUCOeItj/V0hOlgT1SEnSviMB3rSQJU6luZ13VkPjL0N5h6C8RXnegngJ\n\t\t\tG7IhNFU840UuC06AYA5AB6KHGl3ijvAla11Fk6E="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://openathens.warc.com/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://openathens.warc.com/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Warc.com"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The largest single source of intelligence for marketing, advertising, media and research communities"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.southdowns.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ward"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:adam.ward@migliori.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Allison"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:spallison@southdowns.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Allison"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:spallison@southdowns.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mcqueen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nmcqueen@southdowns.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Neil"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.southdowns.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-10-13T13:31:27Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.southdowns.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.southdowns.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.southdowns.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.southdowns.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.southdowns.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.southdowns.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "southdowns.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUYHmDs/az55KjV5rkUaoUYXIIy5owDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAwwUaWRwLnNvdXRoZG93bnMuYWMudWswHhcNMTUwOTAyMTMx\n\t\t\t\t\t\tMTIzWhcNMzUwOTAyMTMxMTIzWjAfMR0wGwYDVQQDDBRpZHAuc291dGhkb3ducy5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJD2qQHKuCscG5oq\n\t\t\t\t\t\taOy3Fk3iOe6VlPoPYZfYzhIAZmNR5ZBkU4Ivn7nmV8GcrD1Swh8Y5vdC/IeUPefA\n\t\t\t\t\t\teexh0zp0sjEmK36ozU8z7dcvflkr9P4tCBzD8zDyYq26W0FCM7iDl7RTwWGga+k3\n\t\t\t\t\t\tYVPuDV7c7hL7yA3d+MR1SFtFK1MH6/0tvadbek+m/Qk+GkD8mPjH+jK1O9tUNXz2\n\t\t\t\t\t\tcf46+FyorWljKa1zy4jQI+J2adR2lPbNf0msKOQIlXEtpodYfCFEs2O5xFZWKuHS\n\t\t\t\t\t\tt2z9yrYU8APNFD+hjH1sfup8aIXcDVWlvJ928/y5KFi3M6uk/0jVmTwuATeSst4l\n\t\t\t\t\t\tKWNTS00CAwEAAaNvMG0wHQYDVR0OBBYEFPh/uaK4fAtwKtAOrt+RDl7ZghQgMEwG\n\t\t\t\t\t\tA1UdEQRFMEOCFGlkcC5zb3V0aGRvd25zLmFjLnVrhitodHRwczovL2lkcC5zb3V0\n\t\t\t\t\t\taGRvd25zLmFjLnVrL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQCA\n\t\t\t\t\t\tdpBM3g3j7BgrhWzrMN22MStrlD4k19CS0axy4gIhdkfnyM3KJ0gofW8OxVVDYrnJ\n\t\t\t\t\t\tK7723AtHhcuyXxCOFqfO151phc+6p9YLC2GkxUmatndDCsTnEXkF3/CDQZs/PzcS\n\t\t\t\t\t\tNGwhfIh7t3Htdj6kAHsWirJKjBST+TJ458UrAIPr3QvbnUZqoUH/J245LuzmAPpj\n\t\t\t\t\t\tCf/SgnqzGpDvH+LlNRYGtz6gg3iCy3+CL0NONVGPoNAbmqFs6/f1zKiJ+spWNFqF\n\t\t\t\t\t\tHqIoomwHimq/YI3YLG1lctf7bmH/fyvG/pZkVBA8FVr3Ex8HKiiRep67LUeei/uw\n\t\t\t\t\t\tsgqZQgD6qpDN/0gCtjl6"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAMFezK1HZGgJj+eQYT5V8m5r7asnMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMB8xHTAbBgNVBAMMFGlkcC5zb3V0aGRvd25zLmFjLnVrMB4XDTE1MDkwMjEz\n\t\t\t\t\t\tMTEyMloXDTM1MDkwMjEzMTEyMlowHzEdMBsGA1UEAwwUaWRwLnNvdXRoZG93bnMu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCP9UwG634cR5mg\n\t\t\t\t\t\txsLoemlVj6EEBrJLaUhvp0nn/HgiuqMwptBFaFk1qMHsVspY3Prbd+pv40af5r8+\n\t\t\t\t\t\tpkzQWedbqwI96/J39qqk7/k37z+YflUM/t9iRhQR7NuxDnLr9JyWb5/qLY39SJ8G\n\t\t\t\t\t\tgEvf5Seu4A15Yqn12CAOcFY/OW58p5tzPg5uUhcGV3TyvOAMgubWmdilCTz27ktR\n\t\t\t\t\t\tPchfZJ2CAfOCSGom3j15K65dzDtj7yARIhSW1SGGkXtaPmBuM22Xlh7IIYHTYRVS\n\t\t\t\t\t\t5YT1heEV6kKvbMpE6Yrn5LXid5enO1lwQkfD6C4juvIZkoNipWhcI22KpLfC3MRM\n\t\t\t\t\t\tA6bB1O2dAgMBAAGjbzBtMB0GA1UdDgQWBBTlWgwMVgaFSkCJJ8Bgs25O7/1uljBM\n\t\t\t\t\t\tBgNVHREERTBDghRpZHAuc291dGhkb3ducy5hYy51a4YraHR0cHM6Ly9pZHAuc291\n\t\t\t\t\t\tdGhkb3ducy5hYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEA\n\t\t\t\t\t\tQB0ChtEoGxbnbeuyALNd6XoTaATMDUq87IXWiX0vJhu+ZNB23AEMFrH3kNQJw++l\n\t\t\t\t\t\txwiYi3xzq4Dc6W/0s0d2S20TFoMXrkewqMmj1fqODX92iN/KbwMWdl9zFxar8Qvv\n\t\t\t\t\t\tDRRV6e+Hvc3ZHlIWekv5RRE0R798yg37kQPFEc40NaiQadOx0twWDZIiY9mRhlXz\n\t\t\t\t\t\toNtXMYVjozF3Eg6QvJxuhrji5m7CnbT+j7yVxaOnJveRb2BShp7luHy8RbFW3Noj\n\t\t\t\t\t\tsbbLV0dPkIADL7SSkQIOD1fBgIVeYQf60AF1FQwWi0rXxZNvZevsji8k+gjZ7YCK\n\t\t\t\t\t\twibNrb/diFicd5nzUvOpQQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUfNUZc3yh6hhcTZJFXiiWY/Nf9IMwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAwwUaWRwLnNvdXRoZG93bnMuYWMudWswHhcNMTUwOTAyMTMx\n\t\t\t\t\t\tMTIzWhcNMzUwOTAyMTMxMTIzWjAfMR0wGwYDVQQDDBRpZHAuc291dGhkb3ducy5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK19/5+rAkwXqY+x\n\t\t\t\t\t\tMIrlRAzMtFYBMc9Xm6VZ683oVtzxh79oBrzordKVo05mvVk3aTci7wcypyZE5f14\n\t\t\t\t\t\txGK9dVEtFU+h0VgnmjuuSNxlX0SNi+bTc1UV2yEcMg+PpeAjzrr30Z4cao8+eCo7\n\t\t\t\t\t\tgjBEqMxNN4bM5hugVl45BmsVAL/0EggVde6cei6ReJ+rn1DzAQhuQWpY3ifXhl+y\n\t\t\t\t\t\tIL+t0qBmfV35bt1rYSSENR5uXYQsfwFv5euXD4h2OXXUp4ZLWh8/xHfdsLsA4+LP\n\t\t\t\t\t\twCpL/xEwOWBGmf/fId6D3rFQAVjZZT8N1GbsN8ttJQ/QRu1+UaZt0CAUEZkvO1FX\n\t\t\t\t\t\tXeehx/ECAwEAAaNvMG0wHQYDVR0OBBYEFORpT+vDj6KPgxh99vtPQ6pzPbwqMEwG\n\t\t\t\t\t\tA1UdEQRFMEOCFGlkcC5zb3V0aGRvd25zLmFjLnVrhitodHRwczovL2lkcC5zb3V0\n\t\t\t\t\t\taGRvd25zLmFjLnVrL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQAZ\n\t\t\t\t\t\tJvxI37cM9qB7mOZ4wO8EHCOpkH23rAjaWT9SpswvOT4KlYzbiQ8l1Y9Fo/qozxjl\n\t\t\t\t\t\tq23B+tT1S5awryrUJlFs0nWrXcbYLFsBv6v9jNEWCHjByoXkpxR08NrqSNAsRrDT\n\t\t\t\t\t\txFwcXNb85gHPgyCYysXm3lEAn3pUCNZv9mReE5fiIJE1OBswzpoR5DsehwLMcwX0\n\t\t\t\t\t\tv+ptmvLy2QxF10v791+/GnHAzXThcvDLGCVkqcQdhDzF8+bcqSxyvWWKUoL91R1O\n\t\t\t\t\t\tHyQKxKQl7wh7guZ9VrDhYt+LZvhNMy2yXVeyBDEJ/EbVTDGC9oCqS/g2JDDTaIVm\n\t\t\t\t\t\t1U1lZKF34YlBgsYQnovH"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "South Downs College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.southdowns.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "South Downs College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.ups-tlse.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "federidmaster@univ-tlse3.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.ups-tlse.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-07-17T08:21:29Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.ups-tlse.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.ups-tlse.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.ups-tlse.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-tlse3.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-tlse3.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Students and staff from Universit\u00e9 de Toulouse 3 - Paul Sabatier"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnels et \u00e9tudiants Universit\u00e9 de Toulouse 3 - Paul Sabatier"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Toulouse 3 - Paul Sabatier"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Toulouse 3 - Paul Sabatier"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUdyy5eL0UrTjscSSpJnKojdThIJcwDQYJKoZIhvcNAQEF\nBQAwITEfMB0GA1UEAxMWc2hpYmJvbGV0aC51cHMtdGxzZS5mcjAeFw0wOTA1MTkw\nNzIzMTNaFw0yOTA1MTkwNzIzMTNaMCExHzAdBgNVBAMTFnNoaWJib2xldGgudXBz\nLXRsc2UuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCDSYueWm19\nK3YtiKE5xRc4CKFGp/aYCA+JIcqXXK7+ky65enp2ObjeYDf2MOcHyiRCNW122y5p\nEk4UXqWk+tagZ2WOGTszb2Rw7WCWIM7Z+bCfwjtTplv3DEFgj+gCAo6nIBbTSLmt\nsCjT95ZxCXxADhXzfjnrrOls7ySgGLQc5yd/lvnlF5l+EDM8uXqoQtfpxuAhFTUE\naXJwSqvV4uEX7eyTJQuYcXerMP0BxURRTKayufMqAs6cIxck8DS28b5x0nnt3zTL\nJcVsc19rxk7AQT5eSGMQLmdq+FQh6hFX0AMo06/7Qd0z1cTWSXNN8LXD+tTDsHAj\nvPvpa1SpFyjdAgMBAAGjczBxMFAGA1UdEQRJMEeCFnNoaWJib2xldGgudXBzLXRs\nc2UuZnKGLWh0dHBzOi8vc2hpYmJvbGV0aC51cHMtdGxzZS5mci9pZHAvc2hpYmJv\nbGV0aDAdBgNVHQ4EFgQUnJKnH/FGOsBSsn6uVbMZZ0wO/IYwDQYJKoZIhvcNAQEF\nBQADggEBABgI82Q35fXOPU4JxpA1zRehoH8Y70OZmtDy+OxfoYZ8HHBO1ZXtlFJ6\nrSQtUHvPKR8VUZy8/Z4D5/FncTTLf/LOhisWHk/BOXJNV3KfOE8aVcQAZd2BzQtf\n396ZSsY0HBdgsEGBoWxuZcUeiaI4wzomtE4OfXRngBccgd6580JerqmON7fLytQK\nm12tRjMzKjY4oPO8ILrjLxIiigbNF5fYfMsWVQFMBHW6wVlBDpuxKmeZTu/TwuqB\n8RPESGgN651QtWiUBwk7Na2WAVQvgcmEwr0BZ+vYq8mymtwQiaXGGY1y51ANm3Lf\nqveDyh76C64hnLr9Jvlv1+E5QP2YPgo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Toulouse 3 - Paul Sabatier"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-tlse3.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Toulouse 3 - Paul Sabatier"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:dartmouth.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Sean.R.McNamara@dartmouth.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sean McNamara"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@dartmouth.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dartmouth Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@dartmouth.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dartmouth Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Jonathan.Crossett@dartmouth.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jonathan Crossett"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:dartmouth.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.dartmouth.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.dartmouth.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.dartmouth.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.dartmouth.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dartmouth.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Dartmouth College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDfjCCAmYCCQD5v/lLik8sFjANBgkqhkiG9w0BAQUFADCBgDELMAkGA1UEBhMC\nVVMxFjAUBgNVBAgTDU5ldyBIYW1wc2hpcmUxEDAOBgNVBAcTB0hhbm92ZXIxGjAY\nBgNVBAoTEURhcnRtb3V0aCBDb2xsZWdlMQ0wCwYDVQQLEwRQS0NTMRwwGgYDVQQD\nExNsb2dpbi5kYXJ0bW91dGguZWR1MB4XDTEzMDgwNzE5NTQ1M1oXDTIzMDgwNTE5\nNTQ1M1owgYAxCzAJBgNVBAYTAlVTMRYwFAYDVQQIEw1OZXcgSGFtcHNoaXJlMRAw\nDgYDVQQHEwdIYW5vdmVyMRowGAYDVQQKExFEYXJ0bW91dGggQ29sbGVnZTENMAsG\nA1UECxMEUEtDUzEcMBoGA1UEAxMTbG9naW4uZGFydG1vdXRoLmVkdTCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBALOih99QFOaxBOq2e2MKw0G1p0lpD1xr\nAgAWKc1WGLKOyjPb3ru6tAz9RFJNKQYRS2VeL6BlTRn4nMpaUPGAZk8byhCQE/h+\nVS9w019U5nmeMopWV7o/UviV0sNBhpkobrCF0spiwNtN+twqHcZKB3LHn7Z4lOnN\npl8CXwQnnBn9xArnSGD9fb62rY6v4d1cAHen9f7sVosLyl3pYATAOe3VWU1Td4W9\nMfWFVb2IXZwDVF4cuFesDehGV6P15MOCYuBoHtPycS66hNFmQIS0Yyo6RSJhU64/\nzSWtwpTDPK++jdIrmr0voi+qyLXf41JGGoAsiVZIPgq/Q/NtzYn8apsCAwEAATAN\nBgkqhkiG9w0BAQUFAAOCAQEAfpVY3snVpp/WT5dZN5cRMowLbJCvvDYO8BEd+r6U\nFRDgTn8WG1NUL45e6yHPRaLF1Mj4g24j8jHEIypy4KJN+DXFJml7FehKl8CY7tJ7\nl1NLX/hNiBXHq5jN+ppWKvnlZLHU1Xs5CEUFIaF+b+FHtBfllCMZPOQUSv0RTJy8\ni3q0skAI/2nPGfA76XiIw88sfuT5bpqqpBfiVKIl/Fi7IV2Mvt8vraULJX/tkot7\nSzxwr2BKS9O9++4J7vv3tfqtPAwKNcyLYAKLnvjWrvVRcZGMarMWKNQsSdWYgdu6\nYCFCMPMXjTEu05ACdSRLThQAnSO5Ml+byI7hpfl0E69FVw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "http://login.dartmouth.edu/shibboleth/error.shtml"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Dartmouth College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dartmouth.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Dartmouth College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.szie.hu/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cseh Vendel"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cseh.vendel@ih.szie.hu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cseh Vendel"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cseh.vendel@ih.szie.hu"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cseh Vendel"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cseh.vendel@ih.szie.hu"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.szie.hu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "urn:schac:homeOrganizationType:hu:university"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-test"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-edugain"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "szie"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-idps"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:geant:niif.hu:eduid.hu:entity-attributes:processing-info",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "hu",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://metadata.eduid.hu/registration_policy_1_0.txt"
              }
            ],
            "registration_instant": "2013-08-01T07:17:19.807Z",
            "registration_authority": "http://eduid.hu",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.szie.hu/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.szie.hu/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.59387252831956,19.361040115356445"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "information_url": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://ifo.szie.hu"
                  }
                ],
                "display_name": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Szent Istv\u00e1n Egyetem"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Szent Istv\u00e1n Egyetem SSO szolg\u00e1ltat\u00e1s"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.szie.hu/szie-logo.png",
                    "height": "78",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "111"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://ifo.szie.hu"
                  }
                ]
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "szie.hu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.szie.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Szent Istv\u00e1n Egyetem"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Szent Istv\u00e1n University"
          }
        ],
        "organization_url": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.szie.hu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.szie.hu"
          }
        ],
        "organization_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Szent Istv\u00e1n Egyetem"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Szent Istv\u00e1n University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://cafe.pucminas.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jose Teixeira Horta Junior"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@pucminas.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.pucminas.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7DCCAdQCAQAwDQYJKoZIhvcNAQEFBQAwPDESMBAGA1UECxMJUFVDIE1pbmFz\nMQswCQYDVQQGEwJCUjEZMBcGA1UEAxMQY2FmZS5wdWNtaW5hcy5icjAeFw0xNDA4\nMDExNzI5MzVaFw0xNzA3MzExNzI5MzVaMDwxEjAQBgNVBAsTCVBVQyBNaW5hczEL\nMAkGA1UEBhMCQlIxGTAXBgNVBAMTEGNhZmUucHVjbWluYXMuYnIwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCwbRSZhSFejHJ757yOpWBXE63J1mukrT3E\n1LaOkUfCDgJgNSOpQDxvT3FgBv9LCRRY+X+z+vRAoT6ab7C+WS8Nuk4UzddO2sqJ\nVedwmDew2yvdaUCPSQ6VZwSca53rsWPYo1gbsz1p+RZMpHe/qoixw3Q2aAsNpx8w\ncBrdR0NUoA1Ud4sRyEd7585VIj7X3dkY/ae+QtbJx+dadjWw+EX4Ry3Ep8dvImMm\nfgOVOuunnKXLop5tRCeIJl6Oi6jQhYtOZld/FXTWufkcO0H+KLmA/gfoWaGN8scy\nXEhXQRMii8brZ/S2IXYCsQvBBgqvgsbT7a2u4C6iP7R8E7fiQeoPAgMBAAEwDQYJ\nKoZIhvcNAQEFBQADggEBAGCmcvJ2ABwJPHZmxZxs/g51NPBgVuIthLckq7GPOv+i\nWwqVIwVoca9PqdUEc2AdG5J7ceQwU2COrq9DLumJAdsJuh/AvnjeF1XBUDGKXR3a\nSD624LId5gwTm4SZzyozjFoZG/WRzbEp3QXoZ0UgzzEFSZsd0K3Mu83qhyJRkNzG\nXhYRvX8ydDIygfAtw6+kMa4v+4Ak5usVOP2BD17H11TEU/Dw3I3LAk0aLwici1/o\nUUBMSFKVKhgKv5eBJYcujVACXvdM8XAxAnIwocuj/0uOVh0BwpEp4xqSTYtV7v/l\nABmiz2DXLugHeiOCiOTKAhg8YLcH/wknW7uULQGn+O0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pucminas.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.pucminas.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.pucminas.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.pucminas.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.pucminas.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.pucminas.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.pucminas.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.pucminas.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.pucminas.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pucminas.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.pucminas.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.pucminas.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "PUCMINAS - Pontificia Universidade Catolica de Minas Gerais"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "PUCMINAS - Pontificia Universidade Catolica de Minas Gerais"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PUCMINAS - Pontificia Universidade Catolica de Minas Gerais"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PUCMINAS - Pontificia Universidade Catolica de Minas Gerais"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7DCCAdQCAQAwDQYJKoZIhvcNAQEFBQAwPDESMBAGA1UECxMJUFVDIE1pbmFz\nMQswCQYDVQQGEwJCUjEZMBcGA1UEAxMQY2FmZS5wdWNtaW5hcy5icjAeFw0xNDA4\nMDExNzI5MzVaFw0xNzA3MzExNzI5MzVaMDwxEjAQBgNVBAsTCVBVQyBNaW5hczEL\nMAkGA1UEBhMCQlIxGTAXBgNVBAMTEGNhZmUucHVjbWluYXMuYnIwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCwbRSZhSFejHJ757yOpWBXE63J1mukrT3E\n1LaOkUfCDgJgNSOpQDxvT3FgBv9LCRRY+X+z+vRAoT6ab7C+WS8Nuk4UzddO2sqJ\nVedwmDew2yvdaUCPSQ6VZwSca53rsWPYo1gbsz1p+RZMpHe/qoixw3Q2aAsNpx8w\ncBrdR0NUoA1Ud4sRyEd7585VIj7X3dkY/ae+QtbJx+dadjWw+EX4Ry3Ep8dvImMm\nfgOVOuunnKXLop5tRCeIJl6Oi6jQhYtOZld/FXTWufkcO0H+KLmA/gfoWaGN8scy\nXEhXQRMii8brZ/S2IXYCsQvBBgqvgsbT7a2u4C6iP7R8E7fiQeoPAgMBAAEwDQYJ\nKoZIhvcNAQEFBQADggEBAGCmcvJ2ABwJPHZmxZxs/g51NPBgVuIthLckq7GPOv+i\nWwqVIwVoca9PqdUEc2AdG5J7ceQwU2COrq9DLumJAdsJuh/AvnjeF1XBUDGKXR3a\nSD624LId5gwTm4SZzyozjFoZG/WRzbEp3QXoZ0UgzzEFSZsd0K3Mu83qhyJRkNzG\nXhYRvX8ydDIygfAtw6+kMa4v+4Ak5usVOP2BD17H11TEU/Dw3I3LAk0aLwici1/o\nUUBMSFKVKhgKv5eBJYcujVACXvdM8XAxAnIwocuj/0uOVh0BwpEp4xqSTYtV7v/l\nABmiz2DXLugHeiOCiOTKAhg8YLcH/wknW7uULQGn+O0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PUCMINAS - Pontificia Universidade Catolica de Minas Gerais"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PUCMINAS - Pontificia Universidade Catolica de Minas Gerais"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.pucminas.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.pucminas.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "PUCMINAS - Pontificia Universidade Catolica de Minas Gerais"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "PUCMINAS - Pontificia Universidade Catolica de Minas Gerais"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.silverchair.com/acp/development/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ShibbolethAdmin@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Laseter"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jlaseter@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Josh"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.silverchair.com/acp/development/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-04-12T08:30:27Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Silverchair Dev: Annals of Internal Medicine"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://annals.acpdev.silverchair.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Silverchair Science + Communications, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://annals.acpdev.silverchair.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://annals.acpdev.silverchair.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://annals.acpdev.silverchair.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://annals.acpdev.silverchair.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://annals.acpdev.silverchair.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://annals.acpdev.silverchair.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJANkdfBndUGSUMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\n\t\t\t\t\t\tBAMTD3Npc3dlYjEuc3NjLmludDAeFw0xMjAzMTQyMDU5NTlaFw0yMjAzMTIyMDU5\n\t\t\t\t\t\tNTlaMBoxGDAWBgNVBAMTD3Npc3dlYjEuc3NjLmludDCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBALDS5+UqQIJ2fAumOUsihM5wVe2HSLiGUnX4bLxaKFCY\n\t\t\t\t\t\taO393EIDcGk0kcGwgD7zyJC+q/iCdIUn32vWY160wit+pIQFBHfSU8AMrV0QwPOy\n\t\t\t\t\t\tayVgO5EK3LY0hXceSQqaqRYt2wZF0EDIABCESQjyUU/9uTvpWjuBtSpeicRBUwkB\n\t\t\t\t\t\tOfOBo4LbuyYgd9hcYNWwIymoZqrZkEEkrFdT9CKPi8hWP7VAJvwxhBs1cJe6EOUv\n\t\t\t\t\t\t73uUw5UMHQBVrJOpv/YxyIxPNBHG/kZYESWo5Yir6GMrTSK4D5UWurBA05wfbhAh\n\t\t\t\t\t\tk8mq2LtrvGGZjKhHvRVYvSXD4uQEOrwpq53J//M5MzECAwEAAaM9MDswGgYDVR0R\n\t\t\t\t\t\tBBMwEYIPc2lzd2ViMS5zc2MuaW50MB0GA1UdDgQWBBQNKdSTkEGS8KPfjVSaZe3V\n\t\t\t\t\t\tN7DQRDANBgkqhkiG9w0BAQUFAAOCAQEAAqtYH86Hpr8AXcEcPCb3Rq2e+b8aa3yA\n\t\t\t\t\t\tmEnbgu6Qk4A1GDx/GC0RTpj2s/tdOPj7BNY22eAgbspo9UcC0YOVKc1Gtnaurogq\n\t\t\t\t\t\tRTE0t3GtSyzRjV2pH/9fefP61ttsyM63ec1K75xXGHaAJEdMPoIWR2ysP0C5whCA\n\t\t\t\t\t\tiJdGkrh2wQvBJF8yd8KS1zSVg1Bk8tKbasqqg8sBe5O2OElzKKdOmWebrQH7h5Jg\n\t\t\t\t\t\twoa/kecYOrfOwsG37V5+oZYDCKSQqRN9YNHWYWe9EFTudAhXQ5OddG6dfUCRHSjR\n\t\t\t\t\t\t82RnLXadMaIx/FmmRgg6I5P2NcEmdxVgDi6yQQ/FY1h0DaoFbBSC9A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://annals.acpdev.silverchair.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://annals.acpdev.silverchair.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://annals.acpdev.silverchair.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://annals.acpdev.silverchair.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://annals.acpdev.silverchair.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://annals.acpdev.silverchair.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-demo-03.its.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-demo-03.its.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-03.its.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-03.its.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-03.its.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-03.its.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-03.its.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-demo-03.its.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-demo-03.its.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;demo-03"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;demo-03"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-demo-03.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-demo-03.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIJAOgVT0mSkmI0MA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\nBAMTG2xhZG9rMy1kZW1vLTAzLmxhZG9rLnVtdS5zZTAeFw0xNDEwMDcxNDQ2NTVa\nFw0yNDEwMDQxNDQ2NTVaMCYxJDAiBgNVBAMTG2xhZG9rMy1kZW1vLTAzLmxhZG9r\nLnVtdS5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALrCNs3pcU6i\ns/gLwcSclyG1xVnkFeFWD6rsmV6dHCFPq5u19YWTEGl/X3WmyZqSAb0ejPMxpy8V\nPJCoY8C+OkFmdwQurOoKfbdbnxjUaKeeP2WzffnpvfuL0LuvtMd1UdRnfNlRQ9el\n68NoY7YWlEJu4B1w1WPY5KhEc48yWdNj8AgcklbjP/TKycKDe+1g4GAp+WU+Gcxd\n681GUeAWWXKIqUVJBLCREETpytRTRMKUdE9VV1CPrl4PdGrndSxOAHgfy18KO/mr\npsivMsJfat8giGmr6ybNBjDxx7jMndqahaK+/o6n5xxAI07Kx9QGcdXmewX0cE4n\nOxf9oyixteMCAwEAAaOBgzCBgDBfBgNVHREEWDBWghtsYWRvazMtZGVtby0wMy5s\nYWRvay51bXUuc2WGN2h0dHBzOi8vbGFkb2szLWRlbW8tMDMubGFkb2sudW11LnNl\nL3N0dWRlbnQtZnJvbnRlbmQtc3AwHQYDVR0OBBYEFMz0MnV1lmCpi0zSus3h+Hqr\nrk+SMA0GCSqGSIb3DQEBBQUAA4IBAQA4EwmVC3KoTVliA3AZcCE1lJpyL/qGi+zr\n5YnPebi4Sf+hTxUS6diFGT2Eh0FSvN6omQ2Zryu0CALKXb6t1ieV+dymNy/3+T6I\n75fmCt2Mcju+YdQPiy2glRnTVsy+NL3s5RfujOK2Y/6JkC1T1bhkY8q37vXy9l0m\nVCquud3+5bD/wfYkSrbL4HjwliXohlAGXy5BtfNK6wg6bHSTuHO/T+yjAAF15kFn\nrTIw0vdVAMr/ssruViMKF91ztRL1ABMxhvn2OqUPW3kE7pJDw5+lDjH6NDeYcph1\n9sW2iFgVmATh19bE+JPlWOV7LHo5tDD0wnoy6hUKxXyEa09wUUlh"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-demo-03.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-03.its.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-03.its.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-03.its.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-03.its.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-03.its.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-03.its.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-demo-03.its.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-demo-03.its.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-demo-03.its.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://du-idp.lanet.lv",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ITserviss"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itserviss@lu.lv"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://du-idp.lanet.lv",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://laife.lanet.lv/wiki/Latvian-Academic-Identity-Federation-Policy.pdf"
              }
            ],
            "registration_instant": "2013-10-10T10:10:10Z",
            "registration_authority": "http://laife.lanet.lv/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://du-idp.lanet.lv/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://du-idp.lanet.lv/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:56.950974,24.116292"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Daugavpils University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Daugavpils University - DU IDP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://laife.lanet.lv/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LAIFE - DU"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.hamilton.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dsmallen@hamilton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David Smallen"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dswartz@hamilton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David Swartz"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.hamilton.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.hamilton.edu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.hamilton.edu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.hamilton.edu:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.hamilton.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.hamilton.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.hamilton.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.hamilton.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.hamilton.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hamilton.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://my.hamilton.edu/images/wordmark.jpg",
                    "lang": "en",
                    "height": "49",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "212"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hamilton College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKTCCAxGgAwIBAgIJAO0MvS2Wg11NMA0GCSqGSIb3DQEBBQUAMIGqMQswCQYD\nVQQGEwJVUzERMA8GA1UECAwITmV3IFlvcmsxEDAOBgNVBAcMB0NsaW50b24xGTAX\nBgNVBAoMEEhhbWlsdG9uIENvbGxlZ2UxGTAXBgNVBAsMEE5ldHdvcmsgU2Vydmlj\nZXMxIDAeBgNVBAMMF3NoaWJib2xldGguaGFtaWx0b24uZWR1MR4wHAYJKoZIhvcN\nAQkBFg9uc0BoYW1pbHRvbi5lZHUwHhcNMTMwMjA0MTk0MDA4WhcNMjMwMjAyMTk0\nMDA4WjCBqjELMAkGA1UEBhMCVVMxETAPBgNVBAgMCE5ldyBZb3JrMRAwDgYDVQQH\nDAdDbGludG9uMRkwFwYDVQQKDBBIYW1pbHRvbiBDb2xsZWdlMRkwFwYDVQQLDBBO\nZXR3b3JrIFNlcnZpY2VzMSAwHgYDVQQDDBdzaGliYm9sZXRoLmhhbWlsdG9uLmVk\ndTEeMBwGCSqGSIb3DQEJARYPbnNAaGFtaWx0b24uZWR1MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAoqYh/6u7bh2Ivh2HCNfV4SC1qRzfkAixYoiQQ0gz\nlg5ijczeMFdrMWhrf34eJWxmEiXk/jhDaTrUise7SdyU5muP1AoEcOlffChan6jI\nlHToO+c1/N4agwHWEvQjQCilUQPAmeq+rI4ciLMLplbbC+r+OlQzMO7rmZPrzgr5\nF6kJiAfeWIsUiALOjIXN17kxv+EU9etkyack6xsCxP9LK7AEImOZUy2KN8nmOFnO\nACWkIBNK++PqICQQimNgp0f3Orlbg9O7W0bxfyho6PmJJrXqe38hPcGDXGoI98qQ\n22vP2ukEqJarGNhpSn1HGbh/LlLFaTlA44pzIlutfV4JjwIDAQABo1AwTjAdBgNV\nHQ4EFgQU/FKHPlyRVc07sbzvNQjnz1oVNwwwHwYDVR0jBBgwFoAU/FKHPlyRVc07\nsbzvNQjnz1oVNwwwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAbj6z\nfxx/rYaP02TF1SSpo1IhHSwOF+iYi/z9/knQSdPQ5xTPddux824+HaT78b3lz1sD\n/MO9QaP+iZ430ClMC+L/FF80+tLtmUHxbx9lrQh5UDFF9PVH3wfraYb2mHnZtEVT\no//C2g0LE5dj2srng76WBeKFm19rqDXY9Lxz0wvYlsgcmHPAjq09P+aU+03qzHmj\nACgQ8OKvEkmgwC8wlILRke7h2kTgGQ2RXC/MAum5X1058aO+MCUoJR2FKdrs90Il\nM9tbUfHRaiJJwVKXJJpy9PfIGa7+daGyDEv1TXEx+8uqI2Gwr870NJKTtGp/uxP0\nb2vzKnRygo55b/VJxw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://my.hamilton.edu/its/rc/federated-id-error"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hamilton College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hamilton.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hamilton College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.opensciencedatacloud.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@opensciencedatacloud.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Powell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rpowell1@uchicago.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ray"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.opensciencedatacloud.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-11-26T12:55:32Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Open Science Data Cloud Console"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.opensciencedatacloud.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Center for Computational Science Research, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.opensciencedatacloud.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.opensciencedatacloud.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.opensciencedatacloud.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.opensciencedatacloud.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Open Science Data Cloud Console"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.opensciencedatacloud.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The OSDC provides cloud computing and storage services for the scientific research community."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.opensciencedatacloud.org/misc/logo_sm.png",
                    "height": "35",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "205"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Open Science Data Cloud Console"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.opensciencedatacloud.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.opensciencedatacloud.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF7zCCA9cCCQCicdy6qcU4ZDANBgkqhkiG9w0BAQUFADCBoTELMAkGA1UEBhMC\n\t\t\t\t\t\tVVMxCzAJBgNVBAgMAklMMRAwDgYDVQQHDAdDaGljYWdvMSAwHgYDVQQKDBdPcGVu\n\t\t\t\t\t\tIFNjaWVuY2UgRGF0YSBDbG91ZDEqMCgGA1UECwwhTGFib3JhdG9yeSBmb3IgQWR2\n\t\t\t\t\t\tYW5jZWQgQ29tcHV0aW5nMSUwIwYDVQQDDBxjYS5vcGVuc2NpZW5jZWRhdGFjbG91\n\t\t\t\t\t\tZC5vcmcgMB4XDTE1MDkyMTIxMDgyM1oXDTIzMTIwODIxMDgyM1owgdAxCzAJBgNV\n\t\t\t\t\t\tBAYTAlVTMQswCQYDVQQIDAJJTDEQMA4GA1UEBwwHQ2hpY2FnbzEqMCgGA1UECgwh\n\t\t\t\t\t\tQ2VudGVyIGZvciBEYXRhIEludGVuc2l2ZSBTY2llbmNlMSAwHgYDVQQLDBdPcGVu\n\t\t\t\t\t\tIFNjaWVuY2UgRGF0YSBDbG91ZDElMCMGA1UEAwwcd3d3Lm9wZW5zY2llbmNlZGF0\n\t\t\t\t\t\tYWNsb3VkLm9yZzEtMCsGCSqGSIb3DQEJARYeYWRtaW5Ab3BlbnNjaWVuY2VkYXRh\n\t\t\t\t\t\tY2xvdWQub3JnMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEA0tTPUHme\n\t\t\t\t\t\tOLd4lMcKVeE212pW4ZS6zUpmnSUuGQx1cFilVUIAa7mvHwxQP3WeIwRHjy69AWRR\n\t\t\t\t\t\tthNPHQf0So00uFYRqUSN1OXgi9MNi/NJF5GLiKhpOmYzRI8wyF7WFmlhV4KYISvX\n\t\t\t\t\t\tALDLdduuDCQ31Fc9MZAL0iJ9oWqSmv+ZBYuClIPdyccAfoKX+vWQf1naSfU7xfgz\n\t\t\t\t\t\tw2h5/GEVnMQcKWVEGzLNAYnnLMcZMfGjH324OAq4cMoZCQ1MZVg9p3y3URfWfWmU\n\t\t\t\t\t\tMUgB2UC8lK84Hb+FzIDD0EM/gZHa0eJhNipNHun/59ZlzqMHXf4ygF/P4s2xCDId\n\t\t\t\t\t\t6/6Irv5rtpr1dv+RA0evv+7FXDaPwDvx1Vn1DpE2PjEh3o8mO16zwIir7St9Xyh6\n\t\t\t\t\t\tPRdcBFlxaNuHPRv7zG3n9V5Fdj3aH2WgKdesZ1qTQ68L18xR9qrtJeTIrxZjuiTr\n\t\t\t\t\t\tbgR0YPFRA5lNACwYE14KNCeXbRqiMWOOPygQaY2Jgn6WFbLvyzguYTJmWkGR3RzY\n\t\t\t\t\t\tN15cFGgwc9uH5EYl+amtb5M5z+3Vk0HynBMzY5JAzuN7LX6D8dLJHk5cHuOK+9Sy\n\t\t\t\t\t\tk56LSa6+2jXI59XMXxcMad5zx9RAZEeKii+LfPyZkd0RH+voZx5IG11sxHhoNEBf\n\t\t\t\t\t\tfNJRtnM7LhGuFjzm2Epw7nwa+wgjbspUUnkCAwEAATANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAgEAZP/VuAyNTjAF1o5fKGwuUy90WHB0WXlp0SiTfrrK66C0fc2koZjzY089a7GF\n\t\t\t\t\t\tSZAqPM/pTQThTsAHpietOnTcetigoUDja+Jw5247iXfEUrRCwK04urIudpU9bCnF\n\t\t\t\t\t\tBS7QSPz4ZRNjQv9LwkGvOU9TkOw9/hfnIIx4aDXGUH7I9wJ9aX7fnuTz94fRLV6u\n\t\t\t\t\t\tzsFRSC/zNC842bHcAs9sZDXldF+nbwJQNdRXKB/uRI4FcBQLGV8k5u+i6c7/MSd3\n\t\t\t\t\t\tkAfdTghk9GMMD1ck9eOX7EYbTnLVWNmiFGOFM6JPCIrLcraQo7b2qhw/uSEAuPAA\n\t\t\t\t\t\t79IoyWuYLSichK/fGWtUCjzinosculG/jteXsA+CEmcqYNyC4WXayIocFPjBQV+/\n\t\t\t\t\t\tp7nJMRNbDB0XiAMGCaGGH/sFmuuwgz21pP6rwwV++XdPthLijx0IJRa13pnt3HEo\n\t\t\t\t\t\tPZtme1tQD9F12h71hYcqyft6Yx2z/WjRL4eC+Pi5TsoKfmzeVoryhIw48+5tmTea\n\t\t\t\t\t\t2DXQ0kYoJCDg5MQ96rv9Pq0OZe9j94oWe91PDuGt9VB4eTlbBt2WiMe+7XDXpOJ2\n\t\t\t\t\t\t8FqqDNY7Ln1LMtV3f5mKjt+lEUkjOr9rcRbFnPx7eLTRRI3C58jBFUxQYcG6zbSo\n\t\t\t\t\t\tiYBbqea72Trn3z2jrytiIM2RYNoL7aS2eqfyIwEr9Q6cuDA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.opensciencedatacloud.org/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.opensciencedatacloud.org/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.opensciencedatacloud.org/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.opensciencedatacloud.org/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.opensciencedatacloud.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.opensciencedatacloud.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.opensciencedatacloud.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.opensciencedatacloud.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.opensciencedatacloud.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.opensciencedatacloud.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sonny.furman.edu/idp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "randy.dill@furman.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Randy Dill"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "clayton.burton@furman.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Clayton Burton"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "service.center@furman.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Service Center"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sonny.furman.edu/idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sonny.furman.edu/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sonny.furman.edu/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIVAI1H0QkWz5jLIhTXfA7tHGhkNvo5MA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEHNvbm55LmZ1cm1hbi5lZHUwHhcNMTIwMzIxMTYyNDQ1\nWhcNMzIwMzIxMTYyNDQ1WjAbMRkwFwYDVQQDExBzb25ueS5mdXJtYW4uZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsbvr70tE2cpMZ7095I5tEPYV\nfoyJL9RWpwwnDMEMFH2fT74Tl8s1WRXe6xwEaAMT+5dx0qcZbgQC27mF0l2+zmMx\n6GvUeLC6CIgDLJtRumTtsRV9E8UsvRswRJnYtYT9eE2CAkUvbjkJZEGSRfZG2o0P\nl8S1munBzQFBD+fFEZYFl4FBxDxpRtkUxM2ylJ0NbqF+mQUCFYhCD+XbCw4IAkwb\nTBHd3cQ/6EMIfdzvVcCBMB3l8Fm2X/CGDlVcLB5boILGYEDX7HPxDLy6DJ0K4I3B\n7T8pxyK8jE6eyWl1S1tUXoi40CQJAbQzy7E2DtL0cZx9Ry1ql6bbIgSXpHiQBQID\nAQABoz4wPDAbBgNVHREEFDASghBzb25ueS5mdXJtYW4uZWR1MB0GA1UdDgQWBBRU\nMLOp0m88ZTOTShxkqeb0GrEL1DANBgkqhkiG9w0BAQUFAAOCAQEAEeOSGj3CBLqs\nWcdXSvyYK9geRTiML+uVZldoHn0yotZcexIgAA+Kwi59TUeRigsC2AAq+rXnJSY3\nJD/wJjdPhWD31bp0C7UFqv5VWiDxMXLPgVNrEZRHvWEwBusUEHkmD95eQoBNAEuB\nyABPQE3LJxQ1tyOFRVYjxNbh9P7fR8bqEtLSPOZyiElyc+eV1Y6sQF6edXY1hyuK\n+0B+9FngV0Wq63/lVLFeuazD+3tI/WugahzvVXleoG49TsFMyjgpFERkcFj9SC6A\n6t98O1ZdhVRiz7VlYeAspGvww4oDGKQUZiKTL7VWvPhIlDNv5kcakfZSRcN/QCf9\ncmzZA1pJew=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "furman.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sonny.furman.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sonny.furman.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sonny.furman.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sonny.furman.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sonny.furman.edu/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sonny.furman.edu/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "furman.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://furman.edu/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Furman University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIVAI1H0QkWz5jLIhTXfA7tHGhkNvo5MA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEHNvbm55LmZ1cm1hbi5lZHUwHhcNMTIwMzIxMTYyNDQ1\nWhcNMzIwMzIxMTYyNDQ1WjAbMRkwFwYDVQQDExBzb25ueS5mdXJtYW4uZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsbvr70tE2cpMZ7095I5tEPYV\nfoyJL9RWpwwnDMEMFH2fT74Tl8s1WRXe6xwEaAMT+5dx0qcZbgQC27mF0l2+zmMx\n6GvUeLC6CIgDLJtRumTtsRV9E8UsvRswRJnYtYT9eE2CAkUvbjkJZEGSRfZG2o0P\nl8S1munBzQFBD+fFEZYFl4FBxDxpRtkUxM2ylJ0NbqF+mQUCFYhCD+XbCw4IAkwb\nTBHd3cQ/6EMIfdzvVcCBMB3l8Fm2X/CGDlVcLB5boILGYEDX7HPxDLy6DJ0K4I3B\n7T8pxyK8jE6eyWl1S1tUXoi40CQJAbQzy7E2DtL0cZx9Ry1ql6bbIgSXpHiQBQID\nAQABoz4wPDAbBgNVHREEFDASghBzb25ueS5mdXJtYW4uZWR1MB0GA1UdDgQWBBRU\nMLOp0m88ZTOTShxkqeb0GrEL1DANBgkqhkiG9w0BAQUFAAOCAQEAEeOSGj3CBLqs\nWcdXSvyYK9geRTiML+uVZldoHn0yotZcexIgAA+Kwi59TUeRigsC2AAq+rXnJSY3\nJD/wJjdPhWD31bp0C7UFqv5VWiDxMXLPgVNrEZRHvWEwBusUEHkmD95eQoBNAEuB\nyABPQE3LJxQ1tyOFRVYjxNbh9P7fR8bqEtLSPOZyiElyc+eV1Y6sQF6edXY1hyuK\n+0B+9FngV0Wq63/lVLFeuazD+3tI/WugahzvVXleoG49TsFMyjgpFERkcFj9SC6A\n6t98O1ZdhVRiz7VlYeAspGvww4oDGKQUZiKTL7VWvPhIlDNv5kcakfZSRcN/QCf9\ncmzZA1pJew=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://sonny.furman.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Furman University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www2.furman.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Furman University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.cambro.umu.se/shibboleth",
    {
      "entity_id": "https://www.cambro.umu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cambro.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.cambro.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cambro.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.cambro.umu.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.cambro.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIjCCAgoCCQDgHEJYdgx+WTANBgkqhkiG9w0BAQUFADBTMQswCQYDVQQGEwJT\nRTENMAsGA1UEBwwEVW1lYTEZMBcGA1UECgwQVW1lYSB1bml2ZXJzaXRldDEaMBgG\nA1UEAwwRd3d3LmNhbWJyby51bXUuc2UwHhcNMTQwNzE0MDUyNjMwWhcNMjQwNzEx\nMDUyNjMwWjBTMQswCQYDVQQGEwJTRTENMAsGA1UEBwwEVW1lYTEZMBcGA1UECgwQ\nVW1lYSB1bml2ZXJzaXRldDEaMBgGA1UEAwwRd3d3LmNhbWJyby51bXUuc2UwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCYjCHkQSRiZaVEFUUk9NSwNl/Y\nKrSFmnz5Aepobjl0mG0yt2nD1lrNRhXxljeJqQzr+u98xqIOpe/Or3OUV6lVb5QH\ntmA/DLJEZDI8DUh3xIrBlsplFFhPw/IPCJikg7TwYo4HJQaT0otZbYDnHMMUSjsk\nRO3C0oxdmZHOWspKoq+gMDaIsIwpG+WZafPqoIYR5TvNCnK5Hj5IEHODfc1gGEjC\niWQ+fdjuHEmPNWmk76jBMQVzPS5HV8pDaDLZdaPqqH5az2SEhWME7Ob1LdzMgRyN\nLTpafoMfboDUut2INkqIl+nJ3kEd30K0UkiZII4NvWtfung6JvljRQb0DHKbAgMB\nAAEwDQYJKoZIhvcNAQEFBQADggEBAIYiRKI4MHTQsxRbbpaMO87V/pGb81ktPfNA\nx9jOsA5yX5dXXH6HbuE9hMeutY/pZFVXVo4j2ASn9Q98lw0JDfy2eFkQzzjgo9wl\n+br9YoAVjnslhuerjI4rZXSMkqfdYcvih4DxXPyAoRQPqIz8hXMi2VcXYsENAN1l\nc35rOFVBZdTp7hR88g9aqdaZBOc/4bDpvWgjkBvral6TCwKkR2z46kkaOi4M51F8\niWocN/BkAiDgRNAj8gKk0QD7flbthIlI3nW2+a+cYBC1oNEZO+ku56tcx1k428VQ\npq8I9dSLC3ziUGK02/9US8m/ZrZ3ywi6spUEqLBcQRFds2gl6bA="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.cambro.umu.se,O=Umea universitet,L=Umea,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.cambro.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIjCCAgoCCQDgHEJYdgx+WTANBgkqhkiG9w0BAQUFADBTMQswCQYDVQQGEwJT\nRTENMAsGA1UEBwwEVW1lYTEZMBcGA1UECgwQVW1lYSB1bml2ZXJzaXRldDEaMBgG\nA1UEAwwRd3d3LmNhbWJyby51bXUuc2UwHhcNMTQwNzE0MDUyNjMwWhcNMjQwNzEx\nMDUyNjMwWjBTMQswCQYDVQQGEwJTRTENMAsGA1UEBwwEVW1lYTEZMBcGA1UECgwQ\nVW1lYSB1bml2ZXJzaXRldDEaMBgGA1UEAwwRd3d3LmNhbWJyby51bXUuc2UwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCYjCHkQSRiZaVEFUUk9NSwNl/Y\nKrSFmnz5Aepobjl0mG0yt2nD1lrNRhXxljeJqQzr+u98xqIOpe/Or3OUV6lVb5QH\ntmA/DLJEZDI8DUh3xIrBlsplFFhPw/IPCJikg7TwYo4HJQaT0otZbYDnHMMUSjsk\nRO3C0oxdmZHOWspKoq+gMDaIsIwpG+WZafPqoIYR5TvNCnK5Hj5IEHODfc1gGEjC\niWQ+fdjuHEmPNWmk76jBMQVzPS5HV8pDaDLZdaPqqH5az2SEhWME7Ob1LdzMgRyN\nLTpafoMfboDUut2INkqIl+nJ3kEd30K0UkiZII4NvWtfung6JvljRQb0DHKbAgMB\nAAEwDQYJKoZIhvcNAQEFBQADggEBAIYiRKI4MHTQsxRbbpaMO87V/pGb81ktPfNA\nx9jOsA5yX5dXXH6HbuE9hMeutY/pZFVXVo4j2ASn9Q98lw0JDfy2eFkQzzjgo9wl\n+br9YoAVjnslhuerjI4rZXSMkqfdYcvih4DxXPyAoRQPqIz8hXMi2VcXYsENAN1l\nc35rOFVBZdTp7hR88g9aqdaZBOc/4bDpvWgjkBvral6TCwKkR2z46kkaOi4M51F8\niWocN/BkAiDgRNAj8gKk0QD7flbthIlI3nW2+a+cYBC1oNEZO+ku56tcx1k428VQ\npq8I9dSLC3ziUGK02/9US8m/ZrZ3ywi6spUEqLBcQRFds2gl6bA="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.cambro.umu.se,O=Umea universitet,L=Umea,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cambro.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.cambro.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cambro.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cambro.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.cambro.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.cambro.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://signon.hh.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 35 167383"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Magnus Mor\u00e9n"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:magnus.moren@hh.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Halmstad University"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 35 167383"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Magnus Mor\u00e9n"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:magnus.moren@hh.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Halmstad University"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+35 167800"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk H\u00f6gskloan i Halmstad"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@hh.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Halmstad University"
          }
        }
      ],
      "entity_id": "https://signon.hh.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVANvNFOWJZe9T3CpX7Sk5ZKgztjMgMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDHNpZ25vbi5oaC5zZTAeFw0wOTA5MTYwODM0MjZaFw0y\nOTA5MTYwODM0MjZaMBcxFTATBgNVBAMTDHNpZ25vbi5oaC5zZTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAIdi7+4jvkJyhmR/IHjVKV0TOJ1TBw5x8FXo\nVVDkZdixmiT/YVp6kfRsKL6yWlNKEm7X6kcrJ+xKUNYUi9n8p1uloS6tBhfG37pC\nXt7fi7imSi882T4fUYzCR3cVAbe8k6L8UKIdWdNVGIkvXzgeBZh/qHCnvyjtF1Bd\n4mEUHh55KieKVmKCYD7TE4T14tE4xSBf7L9Dna4U9aM7Ne+xeHSW/rGGALtfZhIr\nDOZLZSBCIAzBhzwuDb2h7xYBrCBF7QEWInI8tkQPa/g/sS/5xH+nTGO0RAWY9EWu\n2V2HN3hp3/nX8smCSIKRyxWzLJ29htCrsljTLSvFVOstCU0NI/8CAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMc2lnbm9uLmhoLnNlhiNodHRwczovL3NpZ25vbi5oaC5zZS9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUQJ23SW9pFtWUbgw5WcI2qK7YSZAwDQYJ\nKoZIhvcNAQEFBQADggEBAIAl6LBd5IzC+1MxH293vgBeVnIJvRNAp0vn4BqyHgX0\n3i4lqzw/g8hj+va7kOfr1VidYoS3ur5YYnoVC7muILBy8uNeXGaRNeh7xRJHb+HF\n7eEjWvDrj2RQtaED3+1INj2bl5gR4vEt5VkWh6TVU40x4ea0V97Vm4ZO416b9L6I\n06Hp/H4L2oHEJUMdOfxhlipIXZeAxZ2lSHmGspfNRCybLAs/raVGBvq1/RSpRS+X\nvAXrKY9loLQYkufnJ3GlXmbn3eFOyxmA11Q9xTukB8qno9QI2KMxUH8N2cG0vYXB\nCXwK7XzaaZnKkk8K3Hgodpmh+2CIkt0nGwYXAFyb6RE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hh.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://signon.hh.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://signon.hh.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://signon.hh.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://signon.hh.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://signon.hh.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://signon.hh.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://signon.hh.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://signon.hh.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hh.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.hh.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.hh.se"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "H\u00f6gskolan i Halmstad"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Halmstad University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r H\u00f6gskolan i Halmstad"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Halmstad University"
                  }
                ],
                "logo": [
                  {
                    "text": "https://signon.hh.se/hh-logo-en-350x116.png",
                    "height": "116",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  },
                  {
                    "text": "https://signon.hh.se/hh-logo-sv-350x116.png",
                    "lang": "sv",
                    "height": "116",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  },
                  {
                    "text": "https://signon.hh.se/hh-logo-en-350x116.png",
                    "lang": "en",
                    "height": "116",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://signon.hh.se/idp_privacy_statement.html"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://signon.hh.se/idp_privacy_statement_en.html"
                  }
                ]
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "hh.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:56.6647,12.8779"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "194.47.0.0/20"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVANvNFOWJZe9T3CpX7Sk5ZKgztjMgMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDHNpZ25vbi5oaC5zZTAeFw0wOTA5MTYwODM0MjZaFw0y\nOTA5MTYwODM0MjZaMBcxFTATBgNVBAMTDHNpZ25vbi5oaC5zZTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAIdi7+4jvkJyhmR/IHjVKV0TOJ1TBw5x8FXo\nVVDkZdixmiT/YVp6kfRsKL6yWlNKEm7X6kcrJ+xKUNYUi9n8p1uloS6tBhfG37pC\nXt7fi7imSi882T4fUYzCR3cVAbe8k6L8UKIdWdNVGIkvXzgeBZh/qHCnvyjtF1Bd\n4mEUHh55KieKVmKCYD7TE4T14tE4xSBf7L9Dna4U9aM7Ne+xeHSW/rGGALtfZhIr\nDOZLZSBCIAzBhzwuDb2h7xYBrCBF7QEWInI8tkQPa/g/sS/5xH+nTGO0RAWY9EWu\n2V2HN3hp3/nX8smCSIKRyxWzLJ29htCrsljTLSvFVOstCU0NI/8CAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMc2lnbm9uLmhoLnNlhiNodHRwczovL3NpZ25vbi5oaC5zZS9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUQJ23SW9pFtWUbgw5WcI2qK7YSZAwDQYJ\nKoZIhvcNAQEFBQADggEBAIAl6LBd5IzC+1MxH293vgBeVnIJvRNAp0vn4BqyHgX0\n3i4lqzw/g8hj+va7kOfr1VidYoS3ur5YYnoVC7muILBy8uNeXGaRNeh7xRJHb+HF\n7eEjWvDrj2RQtaED3+1INj2bl5gR4vEt5VkWh6TVU40x4ea0V97Vm4ZO416b9L6I\n06Hp/H4L2oHEJUMdOfxhlipIXZeAxZ2lSHmGspfNRCybLAs/raVGBvq1/RSpRS+X\nvAXrKY9loLQYkufnJ3GlXmbn3eFOyxmA11Q9xTukB8qno9QI2KMxUH8N2cG0vYXB\nCXwK7XzaaZnKkk8K3Hgodpmh+2CIkt0nGwYXAFyb6RE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "H\u00f6gskolan i Halmstad"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Halmstad University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hh.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HH"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.univ-savoie.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "admin@univ-savoie.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.univ-savoie.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-09-18T11:18:18Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.univ-savoie.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.univ-savoie.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.univ-savoie.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-savoie.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-savoie.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 Savoie Mont Blanc"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 Savoie Mont Blanc"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIExDCCA6ygAwIBAgIJAJbxent7hKLoMA0GCSqGSIb3DQEBCwUAMIGcMQswCQYD\nVQQGEwJGUjEPMA0GA1UECBMGU2F2b2llMSUwIwYDVQQKExxVbml2ZXJzaXRlIFNh\ndm9pZSBNb250IEJsYW5jMQwwCgYDVQQLEwNkc2kxIjAgBgNVBAMTGXNoaWJib2xl\ndGgudW5pdi1zYXZvaWUuZnIxIzAhBgkqhkiG9w0BCQEWFGFkbWluQHVuaXYtc2F2\nb2llLmZyMB4XDTE2MDIxMDE1NTMwNloXDTI2MDIwNzE1NTMwNlowgZwxCzAJBgNV\nBAYTAkZSMQ8wDQYDVQQIEwZTYXZvaWUxJTAjBgNVBAoTHFVuaXZlcnNpdGUgU2F2\nb2llIE1vbnQgQmxhbmMxDDAKBgNVBAsTA2RzaTEiMCAGA1UEAxMZc2hpYmJvbGV0\naC51bml2LXNhdm9pZS5mcjEjMCEGCSqGSIb3DQEJARYUYWRtaW5AdW5pdi1zYXZv\naWUuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC4KlcQxN5T9TCY\nG9HJc93oBGyp/IPPUhHNwbVuGaR9KAgWPlnIO35975SlA6Qqaa61K3nQduRf1iii\nAdqY1ydteTdz1tfj4TSRjisQpuL4aLl+nRjIlmeLQtnGuQODwWLnmtEt9sXhFv+e\nhRGtFz9tx0IMOhjwRcMO0+Ww9uMJgmq3CNk20Y4T4LCa5IhySMTJcKr29N190LrF\nPzqTNPj63BQkW024kaSbJ2Y+iZltki6LkBR1ImW72+BzT1y67Bm9CXfoZQwYG7SM\noeWSwOGb1udoT0D5VVjcHtn7Rm6A70clfSiGdYejCu8hRpR39LKu0Ho7jpeJeV61\nij7mWIPVAgMBAAGjggEFMIIBATAdBgNVHQ4EFgQUleairMIFuBdMbW1POt5FaZwt\n1HMwgdEGA1UdIwSByTCBxoAUleairMIFuBdMbW1POt5FaZwt1HOhgaKkgZ8wgZwx\nCzAJBgNVBAYTAkZSMQ8wDQYDVQQIEwZTYXZvaWUxJTAjBgNVBAoTHFVuaXZlcnNp\ndGUgU2F2b2llIE1vbnQgQmxhbmMxDDAKBgNVBAsTA2RzaTEiMCAGA1UEAxMZc2hp\nYmJvbGV0aC51bml2LXNhdm9pZS5mcjEjMCEGCSqGSIb3DQEJARYUYWRtaW5AdW5p\ndi1zYXZvaWUuZnKCCQCW8Xp7e4Si6DAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEB\nCwUAA4IBAQAtaBrE87iXhJVQ38JOgy29ruhkxsAQGJfxAmhPIhXvUFGm7gBtYkHG\nAHxGAOfXlgsvF6ekC7z4rGwJdiH97ptJhGZIBe0pSdhzaX1FOGOADb5stDXIMaVI\nqpW9O8oLPaOUvQyZ7RNbuJZiCLjd7KtfJAy63nnmPTlaO1KseEcEZrST5uuWbltU\nsa0Kdh5BaG+SZGojEU7rdaPHLivYBl01AqHUH8GGh8lEpW927qT5DbHB8PQ0ADLb\nEjy9Isdv3XKc4EQXb0tXfL4ot92kqqykLaoMAePFpC84lOl7ImeTh/ZCKXIbIcHX\nTZ4u3TcwVEXeqvbuZPUec7hFrEtrVbcA"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIErTCCA5WgAwIBAgIRALPbdkEOx6FPwPjzvFKn2PswDQYJKoZIhvcNAQELBQAw\nZDELMAkGA1UEBhMCTkwxFjAUBgNVBAgTDU5vb3JkLUhvbGxhbmQxEjAQBgNVBAcT\nCUFtc3RlcmRhbTEPMA0GA1UEChMGVEVSRU5BMRgwFgYDVQQDEw9URVJFTkEgU1NM\nIENBIDIwHhcNMTUwNjAxMDAwMDAwWhcNMTgwNjA2MjM1OTU5WjBHMSEwHwYDVQQL\nExhEb21haW4gQ29udHJvbCBWYWxpZGF0ZWQxIjAgBgNVBAMTGXNoaWJib2xldGgu\ndW5pdi1zYXZvaWUuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDc\nn+cQ/mdGc3AY6bv830qQsonjGaGyWQ51vQUZFZHp29Icwb6ALXtlvZAo8Qq8r3xD\nTA6FxG3s+oLvVjMhkKxID4LC/8yqtMPq7DNj++1SX+7gLDhIPf05/bwnMN3tfgqY\ntrOTeNOjClEmCyuPRFZVMqU4jdSS/NGwPHTEG1hKn43dzRMR/eSaA6b4rrOqGETC\nTVnWOTvBy+nF61HwV5ZSwRaqcwby3fk6GmysrNEWqOH0QCxKoOWMbD6mWlP2C3Xl\nmy783dWTlBZLYLj3uHnacY876T4gW13PA+uI0RrI6PrBu/u7PirnhD3en4PRgZW2\nsQ+BUQ4l6yGrcDo5wFmHAgMBAAGjggF1MIIBcTAfBgNVHSMEGDAWgBRb0IocmjJb\n4LXdllQb4YYosP22vTAdBgNVHQ4EFgQU5SwCQHTC34s3Ji4uOI26ObhwSoAwDgYD\nVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEG\nCCsGAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoG\nA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudXNlcnRydXN0LmNvbS9URVJFTkFT\nU0xDQTIuY3JsMGwGCCsGAQUFBwEBBGAwXjA1BggrBgEFBQcwAoYpaHR0cDovL2Ny\ndC51c2VydHJ1c3QuY29tL1RFUkVOQVNTTENBMi5jcnQwJQYIKwYBBQUHMAGGGWh0\ndHA6Ly9vY3NwLnVzZXJ0cnVzdC5jb20wJAYDVR0RBB0wG4IZc2hpYmJvbGV0aC51\nbml2LXNhdm9pZS5mcjANBgkqhkiG9w0BAQsFAAOCAQEAcLqMd/xRnFts0Ww92RCE\nbKKcHlzHKXwhhS3nod2dvcw/fVTdqUno7ixuyFuRyEjj0+MkDNB7+avIwBpzFg8x\nJob5B3yADerKwycwZvK9x7IeKF9k4XpQr6NYQEwzefCf824URQoe9gfKqpsikcJE\n2SbtIZkdk9iPRsllEYtX8wBrpRojuxd8KTnrs9H+avbiMEMGNab6abXo/LlzV24r\nspTSQxjPfGyDRqxfdI72tc0ES0O0S1NyCI9BovBjTz0sNXqHajpaOKfOmdSjasI4\nvKSy/VQ/I5RdC1gSqP+zBpdnBCrc2PHmKeDo1ofCxa0kR8omQn+Y994RoV1PdKkv\n7w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 Savoie Mont Blanc"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-savoie.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 Savoie Mont Blanc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://elixir.mf.uni-lj.si/20140918",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "\u0160uput"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dusan.suput@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Du\u0161an"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:elixir@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sen\u010dar"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:damijan.sencar@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Damijan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hudomalj"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:emil.hudomalj@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Emil"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lesko\u0161ek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:brane.leskosek@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Branimir"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pesko"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jure.pesko@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jure"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://elixir.mf.uni-lj.si/20140918",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_general.pdf"
              },
              {
                "lang": "sl",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_splosni_pogoji.pdf"
              }
            ],
            "registration_instant": "2014-11-26T10:11:10Z",
            "registration_authority": "http://aai.arnes.si",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Univerza v Ljubljani Medicinska fakulteta"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Univerza v Ljubljani Medicinska fakulteta"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://elixir.mf-uni-lj.si"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://elixir.mf-uni-lj.si"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Univerza v Ljubljani Medicinska fakulteta"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Univerza v Ljubljani Medicinska fakulteta"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://elixir.mf-uni-lj.si"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://elixir.mf-uni-lj.si"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ELIXIR eLearning platform"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ELIXIR eLearning platform"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "93",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "150"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ELIXIR eLearning platform"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ELIXIR eLearning platform"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "elixir.mf.uni-lj.si"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=elixir.mf.uni-lj.si"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ELIXIR eLearning platform"
                },
                {
                  "lang": "sl",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ELIXIR eLearning platform"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "ELIXIR eLearning platform"
                },
                {
                  "lang": "sl",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "ELIXIR eLearning platform"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "rfc822Mailbox",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-demo-05.its.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-demo-05.its.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;demo-05"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;demo-05"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-demo-05.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-demo-05.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIJAJbNz2Ut6PxqMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\nBAMTG2xhZG9rMy1kZW1vLTA1LmxhZG9rLnVtdS5zZTAeFw0xNDEwMDcxNDQ3MTRa\nFw0yNDEwMDQxNDQ3MTRaMCYxJDAiBgNVBAMTG2xhZG9rMy1kZW1vLTA1LmxhZG9r\nLnVtdS5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJbIXoy1e4DO\nhBNnvCRv/k7Av6fxBYikDOzLQKJbtibVP9POw4fECon7c3GRiyB7lBUSPrWLkVM5\ntad4QzjFCzK+t+Wv2VBnDb22+jTPM1epyfEg619hbhujr54iFRCoZkbbDA5yQg7/\nxQsjUZT9jMZoFfKOb8AwwOtd6yUhpQmFxRyMUDgRYqOFBqu65V0zSiYuAr93e5IS\nFUDkwvDjuQP8AOf4bfvZLFepkYPELSLN9mw0+FMyWQd9LnyvKPqG32r95CpIp2ks\nf6V8uXiiLE+ZGB2WzyF4pNhyUH2nNVWIhdsOV6x4/td8oae0rAxLOcNJO2zmU44S\ngqY8LjrEc+cCAwEAAaOBgzCBgDBfBgNVHREEWDBWghtsYWRvazMtZGVtby0wNS5s\nYWRvay51bXUuc2WGN2h0dHBzOi8vbGFkb2szLWRlbW8tMDUubGFkb2sudW11LnNl\nL3N0dWRlbnQtZnJvbnRlbmQtc3AwHQYDVR0OBBYEFAzHqhqAykN2wf7NNTovucpa\nHy8TMA0GCSqGSIb3DQEBBQUAA4IBAQAFAyn+Snc7l6KHh2kDtnpUOCfKbNtx9ALu\ngnh6ltcDDZHoxq0jQNIbQNGqzdot8esoPYntY8IWSsUjZS7SxFw5x5l+/JGIrBP6\nj+zHauVcWgXgChfR2OL+CwFh979lXZniUsjVHXBhE8LxWs3IXpOmCAxY0f2txi6S\nC7InYFK8vlTWsgGvZY4gV7RjTwP8K5OkBrg/rtd3DQa67kQRmu8kAXaJboPabTUv\nETztMh0s9VwEVBPMUKyTETLvUVEnKijUC3XFHn6QB7dKc4K0MEseDwHklMHD+a4+\nXVpEXBWCzSEzde1b1UN1OpTum2X30RmEij8IrqvSnV9rX8RXu9zA"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-demo-05.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://egiswamid.egi.kth.se/shibboleth",
    {
      "entity_id": "https://egiswamid.egi.kth.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://egiswamid.egi.kth.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://egiswamid.egi.kth.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://egiswamid.egi.kth.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://egiswamid.egi.kth.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://egiswamid.egi.kth.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://egiswamid.egi.kth.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://egiswamid.egi.kth.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://egiswamid.egi.kth.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://egiswamid.egi.kth.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "egiswamid.egi.kth.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAOKn91RkenjIMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFGVnaXN3YW1pZC5lZ2kua3RoLnNlMB4XDTEzMDMwNTExNDU0NFoXDTIzMDMw\nMzExNDU0NFowHzEdMBsGA1UEAxMUZWdpc3dhbWlkLmVnaS5rdGguc2UwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDa3DK9UMbKQsvIuJuWLUT3nKRpKUfv\nP0hG4Y9YIjNTXuZWjAVt//FHHVyVVFiyOVjdS7ccgKBdlaQAgxz9TlVXWGkImFDr\n3FB2MBKAXZsqdK8goFzb6QKJJyIS7PRLWQgWWrZkUfESf2HZFbOZK4Q5XxdPu8VY\nDZMU/bwOPwGnO2D8NuJhiMUNSvsw652D0fft5iqoMu68T+RqkvHjt6etgOIRjOUe\nx0FEWmNjOEUXfmR8KEILSgE4LLn4MgBLjwS9f4AklfNaJzubq2CoDDKr5+QqObKa\ns4xt7xB5zaI8n2pWFi1Lik453ZjbyGNNrmIMVoKq8YqfbYbScT+dbGPFAgMBAAGj\nQjBAMB8GA1UdEQQYMBaCFGVnaXN3YW1pZC5lZ2kua3RoLnNlMB0GA1UdDgQWBBSe\nYTmnl+7QvxX3lojqwxfovXBD7TANBgkqhkiG9w0BAQUFAAOCAQEAvjYyfsLqwLUA\nl1jw+FSIRQj1ync3bzU0Pw1i79RjYvSMip+TTScKqMlvfCowOaux0zrD9L9Zezbu\n38fVIa/77VZYFRNkt8uzaB5guMvO1O0XJbuCHl7/J9cdsRnhxFFMrGSQEAFKjXS4\nKhnBVBTB618v+Z3Yr3D4A+2ph5GhQreKEyWrEfKUCNLvI2s9IgF3NlnItHT0Z0VL\nPTw0p2GJzoMLwXYaiWVvGMDnJI9hSxIs+cJCtUUb19wCt3p2cILcFRfkHZR7aO1/\n/es1MnuKqzg9hCb7lpizP/bzSTUxfcVYd7rYACatWWZmXTB2INi4BbF8sFrdUYL9\nVESdo2ebFA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=egiswamid.egi.kth.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://egiswamid.egi.kth.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://egiswamid.egi.kth.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://egiswamid.egi.kth.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://egiswamid.egi.kth.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://egiswamid.egi.kth.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://egiswamid.egi.kth.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.highwire.org/entity/dupjnls",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.highwire.org/entity/dupjnls",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-07-21T13:03:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Stanford University: Duke University Press Journals"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://dukejournals.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HighWire Press, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.highwire.org/applications/dupjnls/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.highwire.org/applications/dupjnls/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIJAMTRVlqTJ11lMA0GCSqGSIb3DQEBBQUAMIG+MQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBD\n\t\t\t\t\t\taXR5MRcwFQYDVQQKEw5IaWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUx\n\t\t\t\t\t\tIDAeBgNVBAMTF3NoaWJib2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkB\n\t\t\t\t\t\tFiZzaGliYm9sZXRoLWFkbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTAeFw0xNDA0\n\t\t\t\t\t\tMTUxOTQzMDNaFw0yNDA0MTIxOTQzMDNaMIG+MQswCQYDVQQGEwJVUzETMBEGA1UE\n\t\t\t\t\t\tCBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBDaXR5MRcwFQYDVQQKEw5I\n\t\t\t\t\t\taWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUxIDAeBgNVBAMTF3NoaWJi\n\t\t\t\t\t\tb2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkBFiZzaGliYm9sZXRoLWFk\n\t\t\t\t\t\tbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALPB99M9iWjentrddY/rLgzKn1X0j4Ao191iyiowBBt/r/pmn2oz\n\t\t\t\t\t\tfrbONkkTVBB++mNtiufK6jyKnBM5mffPOkXHRo+K1DQec7TvpQ1PmLv/BpBgPrr9\n\t\t\t\t\t\tldViOSUnYJuB0IgJVV8oylgeH2Ay0XRkNPlBUjBA2fUPWVpXcvFe+aD2tLdVR9uO\n\t\t\t\t\t\tXvfTMxAEGqzxTU+OxO6pW2sBXNBmGvZQ0TRyovQh5+pTURY/lm0V/iWvRmRe51WE\n\t\t\t\t\t\tO/nhYyvRuMmNj8EL38o10S9TXuCkVzY00hK5cclaFge7gz/tfjmadVVcbe8xCVxc\n\t\t\t\t\t\tnb1lhmt1kH2XtKvU5hyZMTO+VUfXQvqcQyECAwEAAaN7MHkwCQYDVR0TBAIwADAs\n\t\t\t\t\t\tBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYD\n\t\t\t\t\t\tVR0OBBYEFJpUZq/XaW9/bPvjffkxX0IDvuPiMB8GA1UdIwQYMBaAFJpUZq/XaW9/\n\t\t\t\t\t\tbPvjffkxX0IDvuPiMA0GCSqGSIb3DQEBBQUAA4IBAQCq/FF56ZB1cL3KbniEJP99\n\t\t\t\t\t\tU9wTD6KpOrWxvqNbUSV1cefLf5cYHonOjy6oAJSSBSNuP7U5Q//0tXtkvlJoqGUY\n\t\t\t\t\t\tvqngmeg9wLZ/Fla3tXcDdTj0n1F+NZOx9vBDacIk0Ua4aHXDA4bdytzkV1QyZDRq\n\t\t\t\t\t\tQ8vq7RoQ8E5IF7Cll+kt2dZXQk8o6Qp3w2ppoMRtYdKOQassqn+V1MYcMPgdxZkS\n\t\t\t\t\t\tDrcgzktR/JMb5OmPrp4mSy1OWDGrFvUIigsLBPZV9tw1f7y42lnbmQas3RCS30yr\n\t\t\t\t\t\tCtUPT/PQDkCdBRViGmmMkYwjdaOTiHOJveWtrVXu8vLvO36pqFF4Kft0pgqlfvAE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.highwire.org/applications/dupjnls/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.highwire.org/applications/dupjnls/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.highwire.org/applications/dupjnls/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.highwire.org/applications/dupjnls/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://su.avedas.com/shibboleth",
    {
      "entity_id": "https://su.avedas.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://su.avedas.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://su.avedas.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://su.avedas.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://su.avedas.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "su.avedas.com"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICxTCCAi4CCQDSBWv2PjXpZTANBgkqhkiG9w0BAQUFADCBpjELMAkGA1UEBhMC\nREUxDjAMBgNVBAgTBUJhZGVuMRIwEAYDVQQHEwlLYXJsc3J1aGUxEjAQBgNVBAoT\nCUF2ZWRhcyBBRzEdMBsGA1UECxMUU29mdHdhcmUgZGV2ZWxvcG1lbnQxFjAUBgNV\nBAMTDXN1LmF2ZWRhcy5jb20xKDAmBgkqhkiG9w0BCQEWGWIuZ292aW5kYXJhamFu\nQGF2ZWRhcy5jb20wHhcNMTAxMTIyMTQyMzI0WhcNMTMxMDI2MTQyMzI0WjCBpjEL\nMAkGA1UEBhMCREUxDjAMBgNVBAgTBUJhZGVuMRIwEAYDVQQHEwlLYXJsc3J1aGUx\nEjAQBgNVBAoTCUF2ZWRhcyBBRzEdMBsGA1UECxMUU29mdHdhcmUgZGV2ZWxvcG1l\nbnQxFjAUBgNVBAMTDXN1LmF2ZWRhcy5jb20xKDAmBgkqhkiG9w0BCQEWGWIuZ292\naW5kYXJhamFuQGF2ZWRhcy5jb20wgZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGB\nALoE79SI0tNjl3nMoIXc3R+BlrwdcjBWNDPCU7c5NfQ8d5Mkf9JP9T5mgeAhCqPt\nJ/t7kGeEbjySFGWl0BKo0z+BLJm2QLW5o5foQpnOOugXeC5TCw9Yt0+E01eMAVXY\n/yMdyHCJZAv1ZKis0YBOcX1tX/qNlHZtpWab4DwU82JfAgMBAAEwDQYJKoZIhvcN\nAQEFBQADgYEAqhr9F1/MhPQDlya+zlOQMziWnncW2MMqnTNwXnXhncrGE1O2l2HI\nlqJxZNCc13cfFv4IUL0cVlc/2mM5YnAMP1B5dDm0S2psJ+1ofWntqUTF19+jHz7S\n4nG4Jd5WAE9x6Oq0iF37ZyRYG5VW5y+EwjlObbyyT3ZVI1VG81F1DGI="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=b.govindarajan@avedas.com,CN=su.avedas.com,OU=Software development,O=Avedas AG,L=Karlsruhe,ST=Baden,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "su.avedas.com"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICxTCCAi4CCQDSBWv2PjXpZTANBgkqhkiG9w0BAQUFADCBpjELMAkGA1UEBhMC\nREUxDjAMBgNVBAgTBUJhZGVuMRIwEAYDVQQHEwlLYXJsc3J1aGUxEjAQBgNVBAoT\nCUF2ZWRhcyBBRzEdMBsGA1UECxMUU29mdHdhcmUgZGV2ZWxvcG1lbnQxFjAUBgNV\nBAMTDXN1LmF2ZWRhcy5jb20xKDAmBgkqhkiG9w0BCQEWGWIuZ292aW5kYXJhamFu\nQGF2ZWRhcy5jb20wHhcNMTAxMTIyMTQyMzI0WhcNMTMxMDI2MTQyMzI0WjCBpjEL\nMAkGA1UEBhMCREUxDjAMBgNVBAgTBUJhZGVuMRIwEAYDVQQHEwlLYXJsc3J1aGUx\nEjAQBgNVBAoTCUF2ZWRhcyBBRzEdMBsGA1UECxMUU29mdHdhcmUgZGV2ZWxvcG1l\nbnQxFjAUBgNVBAMTDXN1LmF2ZWRhcy5jb20xKDAmBgkqhkiG9w0BCQEWGWIuZ292\naW5kYXJhamFuQGF2ZWRhcy5jb20wgZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGB\nALoE79SI0tNjl3nMoIXc3R+BlrwdcjBWNDPCU7c5NfQ8d5Mkf9JP9T5mgeAhCqPt\nJ/t7kGeEbjySFGWl0BKo0z+BLJm2QLW5o5foQpnOOugXeC5TCw9Yt0+E01eMAVXY\n/yMdyHCJZAv1ZKis0YBOcX1tX/qNlHZtpWab4DwU82JfAgMBAAEwDQYJKoZIhvcN\nAQEFBQADgYEAqhr9F1/MhPQDlya+zlOQMziWnncW2MMqnTNwXnXhncrGE1O2l2HI\nlqJxZNCc13cfFv4IUL0cVlc/2mM5YnAMP1B5dDm0S2psJ+1ofWntqUTF19+jHz7S\n4nG4Jd5WAE9x6Oq0iF37ZyRYG5VW5y+EwjlObbyyT3ZVI1VG81F1DGI="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=b.govindarajan@avedas.com,CN=su.avedas.com,OU=Software development,O=Avedas AG,L=Karlsruhe,ST=Baden,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://su.avedas.com/Shibboleth.sso/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://su.avedas.com/Shibboleth.sso/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://su.avedas.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://su.avedas.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://su.avedas.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://su.avedas.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://su.avedas.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://su.avedas.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://su.avedas.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://su.avedas.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://skmms-idp.lanet.lv",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ITserviss"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itserviss@lu.lv"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://skmms-idp.lanet.lv",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://laife.lanet.lv/wiki/Latvian-Academic-Identity-Federation-Policy.pdf"
              }
            ],
            "registration_instant": "2013-10-10T10:10:10Z",
            "registration_authority": "http://laife.lanet.lv/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://skmms-idp.lanet.lv/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://skmms-idp.lanet.lv/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:56.950974,24.116292"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Riga Red Cross Medical College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Riga Red Cross Medical College - RCMC IDP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://laife.lanet.lv/"
          },
          {
            "lang": "lv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rcmc.lv/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LAIFE - RCMC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ra-idp.lanet.lv",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ITserviss"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itserviss@lu.lv"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ra-idp.lanet.lv",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://laife.lanet.lv/wiki/Latvian-Academic-Identity-Federation-Policy.pdf"
              }
            ],
            "registration_instant": "2013-10-10T10:10:10Z",
            "registration_authority": "http://laife.lanet.lv/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ra-idp.lanet.lv/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ra-idp.lanet.lv/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:56.950974,24.116292"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rezekne Higher Education Institution"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Rezekne Higher Education Institution - RA IDP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://laife.lanet.lv/"
          },
          {
            "lang": "lv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ru.lv/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LAIFE - RA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.silverchair.com/wk/development/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ShibbolethAdmin@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hirst"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:khirst@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kevin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.silverchair.com/wk/development/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-05-13T13:24:22Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Silverchair Dev: Wolters Kluwer Health Library"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://healthlibrary.dev.ssc.int/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Silverchair Science + Communications, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://healthlibrary.dev.ssc.int/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://healthlibrary.dev.ssc.int/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://healthlibrary.dev.ssc.int/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://healthlibrary.dev.ssc.int/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://healthlibrary.dev.ssc.int/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://healthlibrary.dev.ssc.int/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIJAM4mt4HjZTAdMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\n\t\t\t\t\t\tBAMTGWhlYWx0aGxpYnJhcnkuZGV2LnNzYy5pbnQwHhcNMTQwNTA4MjA1NjM0WhcN\n\t\t\t\t\t\tMTkwNTA3MjA1NjM0WjAkMSIwIAYDVQQDExloZWFsdGhsaWJyYXJ5LmRldi5zc2Mu\n\t\t\t\t\t\taW50MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnH2SvahuxzYrG2vg\n\t\t\t\t\t\tYlVQRtgofqTbunyCsaZPZaTAh4/jZBL/vTzXJmNzS+E6w4H9+TJSjh4aqJrKJ/PZ\n\t\t\t\t\t\tg39AAYwcFzAmUHn1FJVuG95LXmzMLYDCNlm8eJg9b+KZRUOQHauH9bmUZJGUYfby\n\t\t\t\t\t\tQqxDJ20tw4RcnixvH+LO2IvIgh8GObI5kTjuwHrC3JkdYTgd8FKRHVC1MfsQItRh\n\t\t\t\t\t\tbejY9cvU6sG27psysGDdxWlbS1NGfCE5zEQoKtCJJEJc7lcg+8tiuH4WvQ3NQY2C\n\t\t\t\t\t\tD4y8p99ymSF2TJFFUlwVePNRNhESod6v/xKxN31xafJKlRg/ij4/WF6Krxow9Oig\n\t\t\t\t\t\tvKGS8QIDAQABo30wezBaBgNVHREEUzBRghloZWFsdGhsaWJyYXJ5LmRldi5zc2Mu\n\t\t\t\t\t\taW50hjRodHRwczovL3NwLnNpbHZlcmNoYWlyLmNvbS93ay9kZXZlbG9wbWVudC9z\n\t\t\t\t\t\taGliYm9sZXRoMB0GA1UdDgQWBBRJ/uKkXqFZ+BTyqIUHrwtgEX7rhDANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEARvDVj3Ruyhy4E+dA87E98wayBUA/AryDbRSRlUsev4Jv2Ke0\n\t\t\t\t\t\tu5rd11kOlH1XdKy6u+PG2x40OfBMAsOwVySBuEAXaQtQuWaudunqd6VWZWWT408L\n\t\t\t\t\t\t23yBKeIGxdF3U0JRScDofsw42DYmunAVo9+s+DxG7tlUZH8KCUP0Gdl9MhybBeJ8\n\t\t\t\t\t\t/DSTUyulPtQt0FMtAkI40yL4fBYO5tyeA2vI/KLlGZ2QtZL/9JHaMS2fXyfmfZOP\n\t\t\t\t\t\tlIjfB2fGvFOB3MTZBGQPcDQmaOo5L4CPPyV/K/EogvjK5sQ34yO5Lm44G1QWWAXl\n\t\t\t\t\t\tIGpJC/ak3Nz/isC5vMl7v2NAxF12Htfk8DQOtg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://healthlibrary.dev.ssc.int/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://healthlibrary.dev.ssc.int/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://healthlibrary.dev.ssc.int/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://healthlibrary.dev.ssc.int/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://healthlibrary.dev.ssc.int/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://healthlibrary.dev.ssc.int/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:incommon:nau.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "christopher.michels@nau.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Christopher Michels"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Summer.steddom@nau.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Summer Steddom"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Mathew.Eis@nau.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mathew Eis"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:nau.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.nau.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.nau.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEWTCCA0GgAwIBAgIJAJPypRDQcZpwMA0GCSqGSIb3DQEBBQUAMIHCMQswCQYD\nVQQGEwJVUzEQMA4GA1UECAwHQXJpem9uYTESMBAGA1UEBwwJRmxhZ3N0YWZmMSQw\nIgYDVQQKDBtOb3J0aGVybiBBcml6b25hIFVuaXZlcnNpdHkxKDAmBgNVBAsMH0lu\nZm9ybWF0aW9uIFRlY2hub2xvZ3kgU2VydmljZXMxGzAZBgNVBAMMEnNoaWJib2xl\ndGgubmF1LmVkdTEgMB4GCSqGSIb3DQEJARYRZGlyZWN0b3J5QG5hdS5lZHUwHhcN\nMTEwMzMxMTgwMTE4WhcNMzEwMzMxMTgwMTE4WjCBwjELMAkGA1UEBhMCVVMxEDAO\nBgNVBAgMB0FyaXpvbmExEjAQBgNVBAcMCUZsYWdzdGFmZjEkMCIGA1UECgwbTm9y\ndGhlcm4gQXJpem9uYSBVbml2ZXJzaXR5MSgwJgYDVQQLDB9JbmZvcm1hdGlvbiBU\nZWNobm9sb2d5IFNlcnZpY2VzMRswGQYDVQQDDBJzaGliYm9sZXRoLm5hdS5lZHUx\nIDAeBgkqhkiG9w0BCQEWEWRpcmVjdG9yeUBuYXUuZWR1MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAqV9ordy6tJx2VgI4hUafJyif2hnWO8Afci7PD0+o\nYnZ6l4h8G/Greg9tGcwmoccVmTFYFUdujacQo3vdQOQV7hFi0bkX1tWo/6ygArrn\nRmigRB21y4Nf19JNYzxF4aZgxi3XVIBeZl3Ospjrj8K8uqNBGesycpUR6kO6HU+G\nIZ/2cPmcjRaiRf0BqztIq8Kes/4NImk5weKDrOlJ+MN08ZCkO5rPs6aSyy4rSYwU\nAscprs8u9eGe3Z7YQijosOnD+cC/pULNgTeKj/mveOWrKBpEobS5q0GH8VF1DIxY\nUK9m+a9PnRmGVcxVtE42bFuAt/LcO8WqUQy67Dz2tMihjwIDAQABo1AwTjAdBgNV\nHQ4EFgQUk1j+/cA4VDnCt2uZqRWbOAodbzgwHwYDVR0jBBgwFoAUk1j+/cA4VDnC\nt2uZqRWbOAodbzgwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAUxjd\nPVkZ7UihWY9i1Ig0Inw/u/2oiG1W3Ee7+wa9aecCR1kAlUnKTjq0EwLJ7wXPtXw1\ny4wken1ppgSVFsaFm+LcsP2fzda7qr6JNCU2NxtLKsA0ZdP48hCknz+OoaVaPBnI\ndwliFh/kektdknGal5jbyXZccRssfnGhW2eL1MXDzEY/YSKa95T2LTDq3ek9Wgyf\n4SO18ccwVPhck1+KazXd7RCzvK12igEbNGBJg8cFGga2qxoyR7gSLDXarm4jlRCX\nc0MKBkAQOLaPFkY0E3sM7Hk/tWmbFyp584N4XZYHU2hcnWfuUBY1571m0ysP3n2y\nSjgw6oOYg18rdX4w3w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nau.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.nau.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.nau.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.nau.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.nau.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.nau.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nau.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Northern Arizona University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEWTCCA0GgAwIBAgIJAJPypRDQcZpwMA0GCSqGSIb3DQEBBQUAMIHCMQswCQYD\nVQQGEwJVUzEQMA4GA1UECAwHQXJpem9uYTESMBAGA1UEBwwJRmxhZ3N0YWZmMSQw\nIgYDVQQKDBtOb3J0aGVybiBBcml6b25hIFVuaXZlcnNpdHkxKDAmBgNVBAsMH0lu\nZm9ybWF0aW9uIFRlY2hub2xvZ3kgU2VydmljZXMxGzAZBgNVBAMMEnNoaWJib2xl\ndGgubmF1LmVkdTEgMB4GCSqGSIb3DQEJARYRZGlyZWN0b3J5QG5hdS5lZHUwHhcN\nMTEwMzMxMTgwMTE4WhcNMzEwMzMxMTgwMTE4WjCBwjELMAkGA1UEBhMCVVMxEDAO\nBgNVBAgMB0FyaXpvbmExEjAQBgNVBAcMCUZsYWdzdGFmZjEkMCIGA1UECgwbTm9y\ndGhlcm4gQXJpem9uYSBVbml2ZXJzaXR5MSgwJgYDVQQLDB9JbmZvcm1hdGlvbiBU\nZWNobm9sb2d5IFNlcnZpY2VzMRswGQYDVQQDDBJzaGliYm9sZXRoLm5hdS5lZHUx\nIDAeBgkqhkiG9w0BCQEWEWRpcmVjdG9yeUBuYXUuZWR1MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAqV9ordy6tJx2VgI4hUafJyif2hnWO8Afci7PD0+o\nYnZ6l4h8G/Greg9tGcwmoccVmTFYFUdujacQo3vdQOQV7hFi0bkX1tWo/6ygArrn\nRmigRB21y4Nf19JNYzxF4aZgxi3XVIBeZl3Ospjrj8K8uqNBGesycpUR6kO6HU+G\nIZ/2cPmcjRaiRf0BqztIq8Kes/4NImk5weKDrOlJ+MN08ZCkO5rPs6aSyy4rSYwU\nAscprs8u9eGe3Z7YQijosOnD+cC/pULNgTeKj/mveOWrKBpEobS5q0GH8VF1DIxY\nUK9m+a9PnRmGVcxVtE42bFuAt/LcO8WqUQy67Dz2tMihjwIDAQABo1AwTjAdBgNV\nHQ4EFgQUk1j+/cA4VDnCt2uZqRWbOAodbzgwHwYDVR0jBBgwFoAUk1j+/cA4VDnC\nt2uZqRWbOAodbzgwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAUxjd\nPVkZ7UihWY9i1Ig0Inw/u/2oiG1W3Ee7+wa9aecCR1kAlUnKTjq0EwLJ7wXPtXw1\ny4wken1ppgSVFsaFm+LcsP2fzda7qr6JNCU2NxtLKsA0ZdP48hCknz+OoaVaPBnI\ndwliFh/kektdknGal5jbyXZccRssfnGhW2eL1MXDzEY/YSKa95T2LTDq3ek9Wgyf\n4SO18ccwVPhck1+KazXd7RCzvK12igEbNGBJg8cFGga2qxoyR7gSLDXarm4jlRCX\nc0MKBkAQOLaPFkY0E3sM7Hk/tWmbFyp584N4XZYHU2hcnWfuUBY1571m0ysP3n2y\nSjgw6oOYg18rdX4w3w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Northern Arizona University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://home.nau.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Northern Arizona University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://filesender.internet2.edu/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "techsupport@internet2.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TSG"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "techsupport@internet2.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TSG"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "techsupport@internet2.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TSG"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://filesender.internet2.edu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Internet2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.internet2.edu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Internet2"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://filesender.internet2.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.internet2.edu/filesender/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service allows any researcher at an institution who is a research and education member of InCommon, is willing to release EPPN and e-mail attributes, and operates an IdP to temporarily store a file of up to 1TB in size and notify recipients of its availability and how to retrieve it.  It is designed to provide a solution to the e-mail large file attachement restriction in most mail systems."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.internet2.edu/filesender/privacy.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Internet2 FileSender"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEAzCCAuugAwIBAgIBADANBgkqhkiG9w0BAQUFADCBxDELMAkGA1UEBhMCVVMx\nETAPBgNVBAgTCE1pY2hpZ2FuMRIwEAYDVQQHEwlBbm4gQXJib3IxQTA/BgNVBAoT\nOFVuaXZlcnNpdHkgQ29ycG9yYXRpb24gZm9yIEFkdmFuY2VkIEludGVybmV0IERl\ndmVsb3BtZW50MSEwHwYDVQQDExhmaWxlc2VuZGVyLmludGVybmV0Mi5lZHUxKDAm\nBgkqhkiG9w0BCQEWGXRlY2hzdXBwb3J0QGludGVybmV0Mi5lZHUwHhcNMTIwNTMw\nMTEyOTI5WhcNMjIwNTI4MTEyOTI5WjCBxDELMAkGA1UEBhMCVVMxETAPBgNVBAgT\nCE1pY2hpZ2FuMRIwEAYDVQQHEwlBbm4gQXJib3IxQTA/BgNVBAoTOFVuaXZlcnNp\ndHkgQ29ycG9yYXRpb24gZm9yIEFkdmFuY2VkIEludGVybmV0IERldmVsb3BtZW50\nMSEwHwYDVQQDExhmaWxlc2VuZGVyLmludGVybmV0Mi5lZHUxKDAmBgkqhkiG9w0B\nCQEWGXRlY2hzdXBwb3J0QGludGVybmV0Mi5lZHUwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDJB0GAiWyeyrR5PgW3rnNspNceX1w3M1HL8jY4ZABYUTQz\nhfHhzhrXxxHwM8Ei8yUczK9hSnHtnURP7GulLfj/4cJZT7lwE/rJopJLPCpS2rXh\nJsAhhpjJVV80FF+wVofDMGZwu/gWR2DKcee6Spok7f2pJJLBbmX5DtenMoR6n7Tp\naVpEtD+wgxrauh/7zzyUJtUbahflUoGxX0Il7LLetOYGgT4u65Du4f/t0fkBxmrl\nvZaNQDDwiJC9g2vZZ5poukx61okmvvkJHs2IsFGbIPrO6lE0v9kDZ93MawTuXuz1\nvldyvULlZ08p7rNIFWI6qqcdtlROgU0iKCcIOUXXAgMBAAEwDQYJKoZIhvcNAQEF\nBQADggEBAKfZknSamtnmWlj0WogmIDn68RoEu8VdU8ny8G0+tErvGGUI9l/y68+h\nX6XyGHPmKUzNMs++wO6e2NjnT+cNNiYgNoSNom+t3I4IxfIE6AGvzqFlhwZrgqAg\nTFow06r0ratzBhfcRlNldAJ30SIFSn/5TyjyR/fAQ8S228saq7hMA8NyzrUY0rqT\nTTiYKzVJRFUVeY1tyDhvMC6PfF5sZLe8hG/rOWVG+h8U5a7FcKkGElxxDDCNsehy\nIGjK2QnyLyqzPNnHwosEzEZDf2yLb6Ee2PIApSqKtO9Syl5QMCiG1dJpb2my00IF\nLXYiHXLNNHaUlb4KEmLyRIb/SCUFu/g="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://filesender.internet2.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://filesender.internet2.edu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://filesender.internet2.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://filesender.internet2.edu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://filesender.internet2.edu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://filesender.internet2.edu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Internet2 FileSender"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This service allows any researcher at an institution who is a research and education member of InCommon, is willing to release EPPN and e-mail attributes, and operates an IdP to temporarily store a file of up to 1TB in size and notify recipients of its availability and how to retrieve it.  It is designed to provide a solution to the e-mail large file attachement restriction in most mail systems."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://expert.testa.antagning.se/ecs-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://expert.testa.antagning.se/ecs-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://expert.testa.antagning.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://expert.testa.antagning.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://expert.testa.antagning.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://expert.testa.antagning.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://expert.testa.antagning.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://expert.testa.antagning.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.testa.antagning.se/ecs-sp/ecs-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.testa.antagning.se/ecs-sp"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIJAN9+3w1NvcgcMA0GCSqGSIb3DQEBBQUAMCgxJjAkBgNV\nBAMTHXd3dy50ZXN0YS5hbnRhZ25pbmcuc2UvZWNzLXNwMB4XDTExMTEwMzEzMTQ1\nNVoXDTIxMTAzMTEzMTQ1NVowKDEmMCQGA1UEAxMdd3d3LnRlc3RhLmFudGFnbmlu\nZy5zZS9lY3Mtc3AwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDF7h+p\nlY+XKnA9Fpo9hWxEadSxDIrehClAuix4Sq9jqaOXJSnFLsoKkuXUPOeifRKliN1M\n1OAUBzSkmLsU9pmQLGPePhsibeZ2QzRmvvRwtRnFQz/v6XqBa9aBuANeiXlSbiGD\nNQcf2DhU2Ecf172x4HxAhUzTXpgRBTJMaY2AIQHLiW+qjNWd5aBrDeLzSO1M4+AW\n2Dxb1q+UHFwQCRapZiAetaRFiAYj7+riHXv+QimWr07BIYuzxxGjYp6UxZtC081f\nA+59xZlhvELu/NILFCOxK0AV5ekjo1CWE4M3gLG8ElXksPHw9h92IbFA+XxII4yl\nbo2BRjrjxeq6hOFBAgMBAAGjeTB3MFYGA1UdEQRPME2CHXd3dy50ZXN0YS5hbnRh\nZ25pbmcuc2UvZWNzLXNwhixodHRwczovL3d3dy50ZXN0YS5hbnRhZ25pbmcuc2Uv\nZWNzLXNwL2Vjcy1zcDAdBgNVHQ4EFgQUYydACh1g3sJY0QqJpPm6Aes14AgwDQYJ\nKoZIhvcNAQEFBQADggEBABgXRYqiJggINk9GwoDrmHDFFJsZkolVggcxGXajm21J\nL7lmQ/egl0wMh4b94XWt6LhSH14C/EVQ7biakVwtqNvSoNEpLNcHb2CXKlD3zI+N\nJz+BWFQmKIob2Mz4Jq7zvz6FRRM4I8OPJgL2n9DxkjtvPdQxKEU8J8CQbm18O+T9\nBJxep5toe7CwjX6G7w8/nvyAJhbF2Y8JEbhdE87k6lOY9w3gfePPsCFZaxHIsxJ1\nl4ZGva1/3LErE+yBLMlq0btsJ3xN1WH0GndIDbKBEUybliI0YthExktB854JHFXG\nKpzNWnJjueWGyd3A1bNfLKm5zayFB1wNyPe5uKnSX5Q="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.testa.antagning.se/ecs-sp"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://expert.testa.antagning.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://expert.testa.antagning.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://expert.testa.antagning.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://expert.testa.antagning.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://expert.testa.antagning.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://expert.testa.antagning.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://expert.testa.antagning.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://expert.testa.antagning.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://expert.testa.antagning.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://expert.testa.antagning.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://zetoc.mimas.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:zetoc@mimas.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Zetoc Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mimas-shib-tech@listserv.manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mimas Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://zetoc.mimas.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-03-07T14:00:37Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Zetoc"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mimas.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Manchester"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://zetoc.jisc.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://zetoc.jisc.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://zetoc.jisc.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://zetoc.jisc.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://zetoc.jisc.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://zetoc.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://zetoc.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The monitoring and search service for global research publications"
                  }
                ],
                "logo": [
                  {
                    "text": "https://zetoc.mimas.ac.uk/images/zetoc/z-logo-black.png",
                    "height": "112",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Zetoc"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKDCCAxCgAwIBAgIJAODl1JSkgO8pMA0GCSqGSIb3DQEBBQUAMIGKMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjETMBEGA1UECBMKTWFuY2hlc3RlcjETMBEGA1UEBxMKTWFuY2hlc3Rl\n\t\t\t\t\t\tcjElMCMGA1UEChMcVGhlIFVuaXZlcnNpdHkgb2YgTWFuY2hlc3RlcjEOMAwGA1UE\n\t\t\t\t\t\tCxMFTWltYXMxGjAYBgNVBAMTEXpldG9jLm1pbWFzLmFjLnVrMB4XDTEzMDUzMDE1\n\t\t\t\t\t\tMzE0OVoXDTIzMDUyODE1MzE0OVowgYoxCzAJBgNVBAYTAkdCMRMwEQYDVQQIEwpN\n\t\t\t\t\t\tYW5jaGVzdGVyMRMwEQYDVQQHEwpNYW5jaGVzdGVyMSUwIwYDVQQKExxUaGUgVW5p\n\t\t\t\t\t\tdmVyc2l0eSBvZiBNYW5jaGVzdGVyMQ4wDAYDVQQLEwVNaW1hczEaMBgGA1UEAxMR\n\t\t\t\t\t\temV0b2MubWltYXMuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCjrE063k8TK8+loGlnrm+DMGxnoUUE1Q1dBljnc6krZnlwQVN4FoYMmcRBeJ++\n\t\t\t\t\t\tgvlWb9OepFILRWrMZyeKbsVGS7P+i1YKP6qPtU6dGYwxiSCmnMyZJJ1zbYbmKVyY\n\t\t\t\t\t\tLSfJLqROoGGpBbvQWFhvXxVFLvhXIATtW4xXp0m0nIi57Km1NIz8qoCqbJ2aWMzQ\n\t\t\t\t\t\tt6rDAHx60NmMEl6umlz/CE+XnfVQP9TSCkwEMsO7FLuXwhsMapIgYGpAV4SMLBjz\n\t\t\t\t\t\tnYEUpuur9EEVd0MnlD8Nq+nqr8Nt5VQc6RYlFFcszLsTNaXJCxdtcH7PeKhMaY+C\n\t\t\t\t\t\tK8xQPxLnHBSpW3d/HhAyeWaFAgMBAAGjgY4wgYswCQYDVR0TBAIwADALBgNVHQ8E\n\t\t\t\t\t\tBAMCBLAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMBwGA1UdEQQVMBOC\n\t\t\t\t\t\tEXpldG9jLm1pbWFzLmFjLnVrMDQGA1UdEgQtMCuBKW1pbWFzLXNoaWItdGVjaEBs\n\t\t\t\t\t\taXN0c2Vydi5tYW5jaGVzdGVyLmFjLnVrMA0GCSqGSIb3DQEBBQUAA4IBAQBD2LxB\n\t\t\t\t\t\tNOJMU4rrC/TqxFJI7WCvR1z3RORHHhyxV6QSnvU+yTx348XwTrfW9y67QAQtm772\n\t\t\t\t\t\t4DuF/gVoQE3lVt5sGIr96szEsIHasz16+Q3leVlV8IHwb7LZS8q3g/i/CnKZ4kBO\n\t\t\t\t\t\tdfjaDQiMvmvpzrWAQKW2W7/0U2cNq1eYCr4gP/xdQiEKmKbqEBo8p21F4+sGCxHx\n\t\t\t\t\t\t9mtElQ0wBqV3xGSLzoh0hGDR7a94kskUA0ilTZC2bHsHf2jH65kZs+oc7Po+eqpj\n\t\t\t\t\t\thwLrdq22270F8hgo4EPDPAgngmgL4YHNU5vXfO8C2qbdJwF6Ie4wI5U/SeiARYiO\n\t\t\t\t\t\tHzhFwIeEOToreweN"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://zetoc.jisc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://zetoc.jisc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://zetoc.jisc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://zetoc.jisc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://zetoc.jisc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://zetoc.jisc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.wheredoyoustand.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Thorpe"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@wheredoyoustand.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Thorpe"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@wheredoyoustand.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.wheredoyoustand.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-05-31T08:53:05Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Where Do You Stand?"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.wheredoyoustand.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "D2.Digital By Design Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.wheredoyoustand.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.wheredoyoustand.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.wheredoyoustand.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.wheredoyoustand.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.wheredoyoustand.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.wheredoyoustand.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "logo": [
                  {
                    "text": "https://www.wheredoyoustand.org.uk/content/images/where-do-you-stand-logo-170x72.png",
                    "height": "72",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "170"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Where Do You Stand?"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFTCCAf2gAwIBAgIJAJk9Zq3V7q4aMA0GCSqGSIb3DQEBBQUAMCUxIzAhBgNV\n\t\t\t\t\t\tBAMTGnd3dy53aGVyZWRveW91c3RhbmQub3JnLnVrMB4XDTEzMDUzMDE1MjI0NloX\n\t\t\t\t\t\tDTIzMDUyODE1MjI0NlowJTEjMCEGA1UEAxMad3d3LndoZXJlZG95b3VzdGFuZC5v\n\t\t\t\t\t\tcmcudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDBIOP3wjI3TysI\n\t\t\t\t\t\tt2rRpeIE71BV2jCDMXG/1MaiyVOvXOGKvRCIpRD/fbiOo7F/4ItDevi8JG7OgMCA\n\t\t\t\t\t\ta9vetz10IFyAynsgNYDL/QioF+ioryGsfnpMxOdy12FCx+LcoL3/AoPbRcyQWyp9\n\t\t\t\t\t\tZTQe2tx6TrIO0lMoHzVXWtkGg0JbfaySXebbRuczjql1ymTp7PwGWdcU9qayfKlC\n\t\t\t\t\t\tS92wsvPNs+wYzmKNKqq88fdS27ZgAq3KkOxhXJiUSKuTKDQ2S/9PibTHF8xVuOa6\n\t\t\t\t\t\t60YT8FHoBJgy8cKjAZysZuFuaVvMfALvAx4XqW7bcrvH2w0yCRX/c2n3FpCoFxuE\n\t\t\t\t\t\tKcbBVQcrAgMBAAGjSDBGMCUGA1UdEQQeMByCGnd3dy53aGVyZWRveW91c3RhbmQu\n\t\t\t\t\t\tb3JnLnVrMB0GA1UdDgQWBBSTEMJNGHiMrWb3/4bTPaygblO/YTANBgkqhkiG9w0B\n\t\t\t\t\t\tAQUFAAOCAQEAaPA+M2xtKHcfs9j5Mlt3Ypm1sWXEHhW/z7zfYmL1mOs3L/QM18Fg\n\t\t\t\t\t\tqo8GsPj2b3Ezzl4ntzjXOWsE/pbcJY3HsZg+U/ocBGIWfNqqWJw0BlfxfvzC9JD1\n\t\t\t\t\t\ttWc4qrLnbfG/tPUU7R1LTIj3lJoSn4LEhRxpQwu/H1wY3gnBNPQHu9uvphlL8KUs\n\t\t\t\t\t\t2VTl/SfeSDXiMGTBu0R11Q/iN01D1FJpmJsTYEYAVvDAOVdbGWzUynXzxg5Tq58b\n\t\t\t\t\t\tTH2p/tyQly+tSTrRgtVTArS4AD1LlEJ0+iQIKwGZK7K1CjCwuJp1G6Oi2u/svbtj\n\t\t\t\t\t\tIFsCv2VSURU413gGBeXs5Ngi1QsibTfnfw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.wheredoyoustand.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.wheredoyoustand.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.wheredoyoustand.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.wheredoyoustand.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.wheredoyoustand.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.wheredoyoustand.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.camosun.ca/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Stephen Campbell, Camosun College Information Technology Services"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:campbells@camosun.bc.ca"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.camosun.ca/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2015-07-24T20:22:29Z",
            "registration_authority": "http://www.canarie.ca",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAPhUQO35onbVePkXGdKrAkBJk0uiMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMMDmlkcC5jYW1vc3VuLmNhMB4XDTE1MDYxOTE5MDkwOVoX\nDTM1MDYxOTE5MDkwOVowGTEXMBUGA1UEAwwOaWRwLmNhbW9zdW4uY2EwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCCHBmK+VJdfG5ksaVqQfNbmMxJCU6k\ns7xLXLbFtV0/cHdYLyHIDc6NYceBjW7aeLon2shOywHinogpLJHZM2VhOFnYSXNT\nAMIqrMPnr6DlDKfX1I1Fn2E1BQcUFDXflzbXAtK+hkQEdDNAByvdtp+XvPa8ke0h\nsq0k5gbF/3jA1stUOMCIh5mIwRrPZGavWe9HpNazX6roCYPypIS9EO9KSargefkY\ngAQ5JpZKYmtIr59n7bSILdEsJIsXAvCcSsaGixicbJtQ+Gexvf61QndsXeu5hZn7\nwG5/oalIEoUFxYdq2vquFTidhLeHhkvO0k9oVmxWH+a4uL/N1HCTt/MHAgMBAAGj\nYzBhMB0GA1UdDgQWBBSHc3+KmnnEmJ5GHGDU9S2wPHOQHDBABgNVHREEOTA3gg5p\nZHAuY2Ftb3N1bi5jYYYlaHR0cHM6Ly9pZHAuY2Ftb3N1bi5jYS9pZHAvc2hpYmJv\nbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEASv2BCHVX/ZO47qRm8Yu0Qvg0yyPnHMWp\nAFzAwJiRH7sWOlcYOUof8Kff7j1w0HgrF4yx+umnMK5761jNUEY3qxGS4YUQWLA9\niI4CZ7cBEbo/Li69ms3vBQjiwoW5XCMu8EfGqtowAv6pnhGNoV87PAR3q/1UdsoQ\npw5z4m/INOggN7LnZTx8B5+slUFaspox2RU0MWAUdn9AZ0E4DWtxpyrJQMacKUu5\nkNRHgdvfQkrNQk/qOpdDh10wJSP50jy+tZaVw/rjqwnzkU/KoaNakopLHOqLRuXB\nfMDTRYP77TLlpD+uApJmxedJ67j4aOhQ2v7iOZewpThU3Wpzndpo9Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "camosun.ca"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.camosun.ca:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.camosun.ca:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.camosun.ca/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.camosun.ca/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.camosun.ca:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.camosun.ca/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.camosun.ca/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.camosun.ca/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.camosun.ca/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.camosun.ca:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.camosun.ca:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "camosun.ca"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.camosun.ca"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Camosun College"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Camosun College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAPhUQO35onbVePkXGdKrAkBJk0uiMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMMDmlkcC5jYW1vc3VuLmNhMB4XDTE1MDYxOTE5MDkwOVoX\nDTM1MDYxOTE5MDkwOVowGTEXMBUGA1UEAwwOaWRwLmNhbW9zdW4uY2EwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCCHBmK+VJdfG5ksaVqQfNbmMxJCU6k\ns7xLXLbFtV0/cHdYLyHIDc6NYceBjW7aeLon2shOywHinogpLJHZM2VhOFnYSXNT\nAMIqrMPnr6DlDKfX1I1Fn2E1BQcUFDXflzbXAtK+hkQEdDNAByvdtp+XvPa8ke0h\nsq0k5gbF/3jA1stUOMCIh5mIwRrPZGavWe9HpNazX6roCYPypIS9EO9KSargefkY\ngAQ5JpZKYmtIr59n7bSILdEsJIsXAvCcSsaGixicbJtQ+Gexvf61QndsXeu5hZn7\nwG5/oalIEoUFxYdq2vquFTidhLeHhkvO0k9oVmxWH+a4uL/N1HCTt/MHAgMBAAGj\nYzBhMB0GA1UdDgQWBBSHc3+KmnnEmJ5GHGDU9S2wPHOQHDBABgNVHREEOTA3gg5p\nZHAuY2Ftb3N1bi5jYYYlaHR0cHM6Ly9pZHAuY2Ftb3N1bi5jYS9pZHAvc2hpYmJv\nbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEASv2BCHVX/ZO47qRm8Yu0Qvg0yyPnHMWp\nAFzAwJiRH7sWOlcYOUof8Kff7j1w0HgrF4yx+umnMK5761jNUEY3qxGS4YUQWLA9\niI4CZ7cBEbo/Li69ms3vBQjiwoW5XCMu8EfGqtowAv6pnhGNoV87PAR3q/1UdsoQ\npw5z4m/INOggN7LnZTx8B5+slUFaspox2RU0MWAUdn9AZ0E4DWtxpyrJQMacKUu5\nkNRHgdvfQkrNQk/qOpdDh10wJSP50jy+tZaVw/rjqwnzkU/KoaNakopLHOqLRuXB\nfMDTRYP77TLlpD+uApJmxedJ67j4aOhQ2v7iOZewpThU3Wpzndpo9Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Camosun College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.camosun.ca"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Camosun College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://test.napier.unidesk.ac.uk/tas/public/login/verify",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:is.helpline@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-certs@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Apps Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test.napier.unidesk.ac.uk/tas/public/login/verify",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-05T09:17:46Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Test Unidesk - Napier"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID5jCCAs6gAwIBAgIJAKmmxe2VazNBMA0GCSqGSIb3DQEBCwUAMFUxIjAgBgNV\n\t\t\t\t\t\tBAMTGXRlc3QubmFwaWVyLnVuaWRlc2suYWMudWsxIjAgBgNVBAoTGXRlc3QubmFw\n\t\t\t\t\t\taWVyLnVuaWRlc2suYWMudWsxCzAJBgNVBAYTAlVLMB4XDTE2MDMyNTE0NDUyNVoX\n\t\t\t\t\t\tDTI2MDMyMzE0NDUyNVowVTEiMCAGA1UEAxMZdGVzdC5uYXBpZXIudW5pZGVzay5h\n\t\t\t\t\t\tYy51azEiMCAGA1UEChMZdGVzdC5uYXBpZXIudW5pZGVzay5hYy51azELMAkGA1UE\n\t\t\t\t\t\tBhMCVUswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC155YdrjNo8XNz\n\t\t\t\t\t\tHvpvZVos38MRNXfRErCpRzvJRUi8HGJqFWRTLOA1MMpxjL/P2Nw/n4W9PcN3OLW6\n\t\t\t\t\t\t5WOeXVtB+wI/V1ptG9T+7NSnfdg4a+zLnS612tx7zYs4ylup1m0px7RgADgmvnnp\n\t\t\t\t\t\tSSD/LO9ZlVuV1llrYM1EMt0xJCXFnlYqaMgqTpJ9bQdRhn+UakEchNS31lYWvnGY\n\t\t\t\t\t\txj+uUYO0ukYhf1RJMJqCCXwpMaUBloimwkF/COs6InnrjMO7yQSLHSDw6C1+0jla\n\t\t\t\t\t\tQ7tjYfGfgWfMzWIDvAZiWXOxq54NgHI4xBstLTM5ynaRa7glGZ46rXNmtadkpFUu\n\t\t\t\t\t\ttEN9XFfJAgMBAAGjgbgwgbUwHQYDVR0OBBYEFIOsVsQYekIKAIZkcAQ1JgQd9GaJ\n\t\t\t\t\t\tMIGFBgNVHSMEfjB8gBSDrFbEGHpCCgCGZHAENSYEHfRmiaFZpFcwVTEiMCAGA1UE\n\t\t\t\t\t\tAxMZdGVzdC5uYXBpZXIudW5pZGVzay5hYy51azEiMCAGA1UEChMZdGVzdC5uYXBp\n\t\t\t\t\t\tZXIudW5pZGVzay5hYy51azELMAkGA1UEBhMCVUuCCQCppsXtlWszQTAMBgNVHRME\n\t\t\t\t\t\tBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQCcOV5eUITv5zxMeUZYFRWh7Vb1eEOK\n\t\t\t\t\t\tTMao1dR5BrrTzmzindDU8z1WYGeGhbz7IOt6qx4lx2bCu5/lcCqN6j2TJ/Zc60Q0\n\t\t\t\t\t\t0RPDa+ozlyu8EOwD6YuQhIoa813RUBPcV3ILyxsn8/H03HuSk+rDSziDrp0dL17q\n\t\t\t\t\t\tqRAZ7DDiNXxVjsOOAKfwATlpBbK7WLP2VG0iMynU4W8YxDNyhQr1hD8aQug14bKI\n\t\t\t\t\t\tFkzIoHsq1aZYLTSSbRmEm4SOd0nhG0N+DRElzuwzE4NJIYAH3wZEg8V6CvLPjLPm\n\t\t\t\t\t\tyaZCgX4d+/NdqDiRw8ysu9XHE+tUXPC9XpWhRKbUV4qCmYsvtMzFYrrs"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID5jCCAs6gAwIBAgIJAKmmxe2VazNBMA0GCSqGSIb3DQEBCwUAMFUxIjAgBgNV\n\t\t\t\t\t\tBAMTGXRlc3QubmFwaWVyLnVuaWRlc2suYWMudWsxIjAgBgNVBAoTGXRlc3QubmFw\n\t\t\t\t\t\taWVyLnVuaWRlc2suYWMudWsxCzAJBgNVBAYTAlVLMB4XDTE2MDMyNTE0NDUyNVoX\n\t\t\t\t\t\tDTI2MDMyMzE0NDUyNVowVTEiMCAGA1UEAxMZdGVzdC5uYXBpZXIudW5pZGVzay5h\n\t\t\t\t\t\tYy51azEiMCAGA1UEChMZdGVzdC5uYXBpZXIudW5pZGVzay5hYy51azELMAkGA1UE\n\t\t\t\t\t\tBhMCVUswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC155YdrjNo8XNz\n\t\t\t\t\t\tHvpvZVos38MRNXfRErCpRzvJRUi8HGJqFWRTLOA1MMpxjL/P2Nw/n4W9PcN3OLW6\n\t\t\t\t\t\t5WOeXVtB+wI/V1ptG9T+7NSnfdg4a+zLnS612tx7zYs4ylup1m0px7RgADgmvnnp\n\t\t\t\t\t\tSSD/LO9ZlVuV1llrYM1EMt0xJCXFnlYqaMgqTpJ9bQdRhn+UakEchNS31lYWvnGY\n\t\t\t\t\t\txj+uUYO0ukYhf1RJMJqCCXwpMaUBloimwkF/COs6InnrjMO7yQSLHSDw6C1+0jla\n\t\t\t\t\t\tQ7tjYfGfgWfMzWIDvAZiWXOxq54NgHI4xBstLTM5ynaRa7glGZ46rXNmtadkpFUu\n\t\t\t\t\t\ttEN9XFfJAgMBAAGjgbgwgbUwHQYDVR0OBBYEFIOsVsQYekIKAIZkcAQ1JgQd9GaJ\n\t\t\t\t\t\tMIGFBgNVHSMEfjB8gBSDrFbEGHpCCgCGZHAENSYEHfRmiaFZpFcwVTEiMCAGA1UE\n\t\t\t\t\t\tAxMZdGVzdC5uYXBpZXIudW5pZGVzay5hYy51azEiMCAGA1UEChMZdGVzdC5uYXBp\n\t\t\t\t\t\tZXIudW5pZGVzay5hYy51azELMAkGA1UEBhMCVUuCCQCppsXtlWszQTAMBgNVHRME\n\t\t\t\t\t\tBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQCcOV5eUITv5zxMeUZYFRWh7Vb1eEOK\n\t\t\t\t\t\tTMao1dR5BrrTzmzindDU8z1WYGeGhbz7IOt6qx4lx2bCu5/lcCqN6j2TJ/Zc60Q0\n\t\t\t\t\t\t0RPDa+ozlyu8EOwD6YuQhIoa813RUBPcV3ILyxsn8/H03HuSk+rDSziDrp0dL17q\n\t\t\t\t\t\tqRAZ7DDiNXxVjsOOAKfwATlpBbK7WLP2VG0iMynU4W8YxDNyhQr1hD8aQug14bKI\n\t\t\t\t\t\tFkzIoHsq1aZYLTSSbRmEm4SOd0nhG0N+DRElzuwzE4NJIYAH3wZEg8V6CvLPjLPm\n\t\t\t\t\t\tyaZCgX4d+/NdqDiRw8ysu9XHE+tUXPC9XpWhRKbUV4qCmYsvtMzFYrrs"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.napier.unidesk.ac.uk/tas/public/login/verify",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://shib.ou.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "david-horton@ouhsc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David Horton"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "bighorse@ou.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Aaron Bighourse"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pat-amburn@ouhsc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pat Amburn"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.ou.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.ou.edu:9443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.ou.edu:9443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAigCCQDc5lzkFlIc/jANBgkqhkiG9w0BAQUFADBiMRQwEgYDVQQDEwtz\naGliLm91LmVkdTEfMB0GA1UEChMWVW5pdmVyc2l0eSBvZiBPa2xhaG9tYTELMAkG\nA1UEBhMCVVMxCzAJBgNVBAgTAk9LMQ8wDQYDVQQHEwZOb3JtYW4wHhcNMTExMjA5\nMTMwMzM3WhcNMTIxMjA4MTMwMzM3WjBiMRQwEgYDVQQDEwtzaGliLm91LmVkdTEf\nMB0GA1UEChMWVW5pdmVyc2l0eSBvZiBPa2xhaG9tYTELMAkGA1UEBhMCVVMxCzAJ\nBgNVBAgTAk9LMQ8wDQYDVQQHEwZOb3JtYW4wggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQDWSD/N2sPHJ2Sg//K+mVAi6Oep5tXdxsmVIC6jegFaQVHSYpL8\nGPULb89CyxekyjMIkNfXOnh9Ycfw+PgOVIspVejmdFyM9O9Lp7XYgG4xi9RwL406\nsbIbVUx74HPGAbp/z6XQqus4TemAeJlfzvlRsmwQkiC4IU2iUc0vM8X2OnXGcQ1M\n1nf/lRDYjxFeeSFFKv/SSZQgApXiORb8BgOxJTP2huppWiq+JAX5dSLArlZPfZTE\nA81ULTd0D9HFsViThTb426UHR1CvuUbfb+saA65WWk9s1jLFD5omksXGP0qkglPV\n+rrc+MbQltnM3arxyFSEfm2nvNqdVStbt+M7AgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBAJJsqc/AA4p+CPPKnQnQoU0uIUt6V9IBuk6z3JjXPjy5gFYtLJ7RBslMui8x\nwhi6eTdUdHpASv7T7WKBBKFSA/NeiZ3TCpYMmdQsPdznzsVS/wsD+pU4PALCfqd6\njJ9ntDEDOezYSTxAdbU8KmPxb5VZr7QseHAtf5OwZQI5131bVjkIjcM8pH4Sx2gk\ngyHNLf2byp1u1gSTRBbC8m1bESeQRTphQtsM+o3m6JUR3k9bV2tfgXLV8zaFWWuM\naQgoBThl3ubE6tZmNvkC76OAzv+E+bRNfLV9lm+5Y66Ar9rSQHKur9xGm59GtmI/\nGhy0tfpx50Ku5N+Baf2OZmHjuv4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ou.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.ou.edu:443/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.ou.edu:443/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.ou.edu:443/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.ou.edu:443/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.ou.edu:9443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.ou.edu:9443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ou.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Oklahoma"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAigCCQDc5lzkFlIc/jANBgkqhkiG9w0BAQUFADBiMRQwEgYDVQQDEwtz\naGliLm91LmVkdTEfMB0GA1UEChMWVW5pdmVyc2l0eSBvZiBPa2xhaG9tYTELMAkG\nA1UEBhMCVVMxCzAJBgNVBAgTAk9LMQ8wDQYDVQQHEwZOb3JtYW4wHhcNMTExMjA5\nMTMwMzM3WhcNMTIxMjA4MTMwMzM3WjBiMRQwEgYDVQQDEwtzaGliLm91LmVkdTEf\nMB0GA1UEChMWVW5pdmVyc2l0eSBvZiBPa2xhaG9tYTELMAkGA1UEBhMCVVMxCzAJ\nBgNVBAgTAk9LMQ8wDQYDVQQHEwZOb3JtYW4wggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQDWSD/N2sPHJ2Sg//K+mVAi6Oep5tXdxsmVIC6jegFaQVHSYpL8\nGPULb89CyxekyjMIkNfXOnh9Ycfw+PgOVIspVejmdFyM9O9Lp7XYgG4xi9RwL406\nsbIbVUx74HPGAbp/z6XQqus4TemAeJlfzvlRsmwQkiC4IU2iUc0vM8X2OnXGcQ1M\n1nf/lRDYjxFeeSFFKv/SSZQgApXiORb8BgOxJTP2huppWiq+JAX5dSLArlZPfZTE\nA81ULTd0D9HFsViThTb426UHR1CvuUbfb+saA65WWk9s1jLFD5omksXGP0qkglPV\n+rrc+MbQltnM3arxyFSEfm2nvNqdVStbt+M7AgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBAJJsqc/AA4p+CPPKnQnQoU0uIUt6V9IBuk6z3JjXPjy5gFYtLJ7RBslMui8x\nwhi6eTdUdHpASv7T7WKBBKFSA/NeiZ3TCpYMmdQsPdznzsVS/wsD+pU4PALCfqd6\njJ9ntDEDOezYSTxAdbU8KmPxb5VZr7QseHAtf5OwZQI5131bVjkIjcM8pH4Sx2gk\ngyHNLf2byp1u1gSTRBbC8m1bESeQRTphQtsM+o3m6JUR3k9bV2tfgXLV8zaFWWuM\naQgoBThl3ubE6tZmNvkC76OAzv+E+bRNfLV9lm+5Y66Ar9rSQHKur9xGm59GtmI/\nGhy0tfpx50Ku5N+Baf2OZmHjuv4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Oklahoma"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ou.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Oklahoma"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/adfs.smk.dk/adfs/services/trust",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/adfs.smk.dk/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2015-07-15T16:08:06Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/adfs.smk.dk/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://birk.wayf.dk/birk.php/adfs.smk.dk/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "smk.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Statens Museum for Kunst \u2013 SMK"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Statens Museum for Kunst \u2013 SMK"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "smk.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC2DCCAcACAQcwDQYJKoZIhvcNAQELBQAwMjEwMC4GA1UEAwwnaHR0cHM6Ly9h\nZGZzLnNtay5kay9hZGZzL3NlcnZpY2VzL3RydXN0MB4XDTE1MDEwMTAwMDAwMFoX\nDTI1MTIzMTIzNTk1OVowMjEwMC4GA1UEAwwnaHR0cHM6Ly9hZGZzLnNtay5kay9h\nZGZzL3NlcnZpY2VzL3RydXN0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAx4gMCmoQU7iOGfiCda4DnhIggst20fUCHtwaQrHoxQlOa0s5FgDalbnNTw36\ndCXSGYaz17JgyUDJonTwhjyA0CqPm5Pmn9/hFBUvyP/t+bEgV9r3/odQx72VfY7M\n55qUlY6ex2f1qD1gcpFgSTtADlZswec5WqpEt+ie+vsMXq8HabhMVZ2EjXe90vgM\nk/xGfrVwDvupUPBS/2DJSZ1JEmkqi0hxctNQ9qgTZmEcAaQkuv3VGcsYtLeY/IIS\nlA+ARzmVWr5+uSetnCXV4jnDEclACKeexl0Ky+tyra4yHF3Xavgmcmebd+xHVDiM\n+No6BXMu9zBTp7cp5ShLzsNQSQIDAQABMA0GCSqGSIb3DQEBCwUAA4IBAQBzgpSB\nJQ9ntqiPmIo3mRCsdCauarGzVELvUMgZduJ8DXYfr4440MJKElv/r5pfb5aHMmdT\nEz3IHhozzLLROtIdIEgNUxhvE2dB7hMLbyci8gOhD3K/mQ8Vn/nnHuPEU+XsbusZ\nolYvjanl30EyTvXaCTBrapK48xNLfcxJmdptKuLJOMrazs2KDYsvlgK6cD3D/l/1\nxJB1XMdCMPifzqJ1//pBtemKTk9/MwW89AA+QSKgMVHlbGg5xb2uxwbX4Wvr528T\nVtKg/2JGMXXsiFb2fDLv9Nv3gx1eJh8eMW2PO5yFqJCO7JjW/lnpXAv/HiDkzR/M\niaCTH9LM7/F3Hd+I"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Statens Museum for Kunst \u2013 SMK"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Statens Museum for Kunst \u2013 SMK"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.smk.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.smk.dk/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Statens Museum for Kunst \u2013 SMK"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Statens Museum for Kunst \u2013 SMK"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://gw.ct.infn.it/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fargetta"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:marco.fargetta@ct.infn.it"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:credentials-admin@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marco"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rotondo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:riccardo.rotondo@ct.infn.it"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:credentials-admin@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Riccardo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Platania"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:giuseppe.platania@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Giuseppe"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rocca"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:carlo.rocca@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Carlo"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barbera"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:roberto.barbera@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roberto"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://gw.ct.infn.it/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2012-05-03T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Science Gateway to IGI provided by INFN Catania"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Science Gateway to IGI erogato da INFN Catania"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ct.infn.it/en/home"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ct.infn.it/it/home"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INFN - the National Institute of Nuclear Physics. Catania division"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INFN - Istituto Nazionale di Fisica Nucleare. Sezione di Catania"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://gw.ct.infn.it/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://gw.ct.infn.it/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gw.ct.infn.it/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://gw.ct.infn.it/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://gw.ct.infn.it/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service provides access to several Grid applications and use case to the Italian Grid community"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Questo servizio fornisce accesso ad un insieme di applicazioni ed use case su Grid alla comunit\u00e0 italiana di Gri"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INFN Science Gateway to IGI"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INFN Science Gateway to IGI"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://gw.ct.infn.it/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://gw.ct.infn.it/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFhDCCBGygAwIBAgIRAOyXU1f6GS689kEaSDAhQPYwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDA1MTkwMDAwMDBaFw0xNzA1MTgyMzU5NTlaMEAxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEbMBkGA1UEAxMSbGlmZXJheS5j\ndC5pbmZuLml0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApizyvtMI\nuoSnnz/fvk7lcXwoDUk11NVAlg5w4zh01YKNvy5SzBu0eRIzRos/ALs4CwmxrmCv\n3JQPA4xxItxVd8x9Q+YElQteEcX+mWXXW5LI5XE3xhPzkdFeQrhkinAK2JreSn6E\nTQk8YO1rOxW3qCpKeYZ2VQF3grAU/JRWbvLF+r2j4zE27n+RzBxnYeZ9rtJ/67gU\n7t1S39DRDTyKit7dJIYl50n9g3atWGALb56QoVnlR+RPRxVI9EFd2hEXfrxWXGdt\nF2v6YIMSAAM5l2/SlEmhQSSkmQ4zXcmPrzC6pte9NWoPOTsQnCnocwMJ16aXsnQy\nBxaoywMtq8NsdwIDAQABo4ICgTCCAn0wHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsr\nN1dH6pDjue0wHQYDVR0OBBYEFCy5dq76F94vaAuznAys6UmGxySTMA4GA1UdDwEB\n/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEF\nBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8E\nMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENB\nLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNz\nLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8v\nb2NzcC50Y3MudGVyZW5hLm9yZzCCAS0GA1UdEQSCASQwggEgghJsaWZlcmF5LmN0\nLmluZm4uaXSCGWFwcGxpY2F0aW9ucy5ldS1kZWNpZGUuZXWCGWFwcGxpY2F0aW9u\ncy5ldW1lZGdyaWQuZXWCEGdpbGRhLmN0LmluZm4uaXSCFGdpc2VsYS1ndy5jdC5p\nbmZuLml0gg1ndy5jdC5pbmZuLml0ghNnd2VhdGhlci5jdC5pbmZuLml0ghBnd2xp\nYi5jdC5pbmZuLml0gh9pbmRpY2F0ZS1ndy5jb25zb3J6aW8tY29tZXRhLml0ghFy\naWNldmkuY3QuaW5mbi5pdIIUdmlyYWxncmlkLmN0LmluZm4uaXSCFHd3dy5jaGFp\nbi1wcm9qZWN0LmV1ghZ3d3cuc3BlY2lhbC1wcm9qZWN0Lml0MA0GCSqGSIb3DQEB\nBQUAA4IBAQCEZIHNNQPD5WkGSlUhCN/BRSharmQ6dT0NiwjQNmRODCpVqBgwVZY0\nVUlAobHaF186QXeiNYge8ZYSpYY2VhBa4znL7IjFODE3FsaJNseKgsyNFqKR8xNO\nnsOCM//SN9N79hwH8yAxLhGyxbnInpOhE6rEkbhtowTjqhDq26cGGlH8JTTPuYvY\nJhgPGGkxo1286x1nuN4ELKvwZ7RF+YTH/WPOIBMNi+ee+vxrIhWbU6iy97f7k4PA\n2e35ZQ6gutnmX2v/ybFWh0ruO4zszYKiMo+zGyLvYmIpV/+Mjs26KbqqrBOS1jjN\nW3MiH8HMxzzYHExNCvzrAgN1TfB+SCiB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gw.ct.infn.it/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://gw.ct.infn.it/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://gw.ct.infn.it/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://gw.ct.infn.it/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://gw.ct.infn.it/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://gw.ct.infn.it/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Science Gateway to IGI"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This service provides access to several Grid applications and use case to the Italian Grid community"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://supr.snic.se",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://supr.snic.se",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://supr.snic.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://supr.snic.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://supr.snic.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://supr.snic.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://supr.snic.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://supr.snic.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://supr.snic.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SNIC User and Project Repository (SUPR)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SNIC User and Project Repository (SUPR)"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SUPR"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SUPR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "messer.c3se.chalmers.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAJ5kq+e+PrCNMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF21lc3Nlci5jM3NlLmNoYWxtZXJzLnNlMB4XDTE0MTExMzEwMTQwNVoXDTI0\nMTExMDEwMTQwNVowIjEgMB4GA1UEAxMXbWVzc2VyLmMzc2UuY2hhbG1lcnMuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCerDdofc8oW+/HTymS5b3e\nmP6PtgKgqOIfFFAZEgyevWuK5tgKattfc/3SFZgkV6Mtd1itIQHZ4+apbtH9fV2u\nocapBjN46GHx5hf5Dy9vq+UcUtpbtAWM6mHL6q5y5lAb2DlmVbnRaVZuwIDiP1y8\nLHaIV5ZBI689px+Ch/BqMONfBFh+qZqTeaZm2MvP5/ndIqz8Ylzu9ew4f+9xRntN\nGFRRygaSH4CaP8ymhgd4P0ldY7DWYvU12GRZMisREH97NxfDhRGpZhcOjQANZDxX\nhTZuSNw4jSe6lUFJ059vb2T3ea2BkWtgEBwXCwT6HUrO+KbIzGNfA4IMtTKvqi7J\nAgMBAAGjRTBDMCIGA1UdEQQbMBmCF21lc3Nlci5jM3NlLmNoYWxtZXJzLnNlMB0G\nA1UdDgQWBBRiuvyLJNhRdxc009bfL6t4d1M6hDANBgkqhkiG9w0BAQUFAAOCAQEA\nFnyDmtBQhFIuOms1F8JslP3HaKtzAdQ5jjhzMH/W0UZIsnKaT+dU1+qOKbjS5GiY\nsdBZDa4dAqweL85Ycl+TF/03rYz0qC+YOq9YDd2QNAM7IdOiBGxCX5zaoha5elgR\nYY/jrujN0MpCgdXdZTbRxbKakQ5CUxBGaSoLE5Z46sAeqXlZrh+zxLtzADdMV2tc\nMoJW1wvwyQA08K1nGonNmkFGrFEiqQ6+JuM0KPnR3Rq/Z4BOl4VoTAYaRT6EyPEx\npGuv7RK02oChLjhdGhzSuVXSbt1DthnmATOjO4kWAS3aPmOZC3jQunXmWb0NjO/l\nm9Ea0VNPPWBYZkyQ68fOqw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=messer.c3se.chalmers.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://supr.snic.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://supr.snic.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://supr.snic.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://supr.snic.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://supr.snic.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://supr.snic.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://supr.snic.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://supr.snic.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://supr.snic.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://portal.medicinskaforeningen.se/saml/simplesamlwww/module.php/saml/sp/metadata.php/AgeraMedlem",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "S\u00f6lve"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "johan@montania.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Johan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://portal.medicinskaforeningen.se/saml/simplesamlwww/module.php/saml/sp/metadata.php/AgeraMedlem",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://portal.medicinskaforeningen.se/saml/simplesamlwww/module.php/saml/sp/saml2-logout.php/AgeraMedlem",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Medlemsportalen f\u00f6r Medicinska F\u00f6reningen i Stockholm"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Member Portal for Medical Students' Association in Stockholm"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Medlemsportalen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Member Portal"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://portal.medicinskaforeningen.se/saml/simplesamlwww/module.php/saml/sp/saml2-acs.php/AgeraMedlem",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://portal.medicinskaforeningen.se/saml/simplesamlwww/module.php/saml/sp/saml1-acs.php/AgeraMedlem",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://portal.medicinskaforeningen.se/saml/simplesamlwww/module.php/saml/sp/saml2-acs.php/AgeraMedlem",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://portal.medicinskaforeningen.se/saml/simplesamlwww/module.php/saml/sp/saml1-acs.php/AgeraMedlem/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:profiles:holder-of-key:SSO:browser",
              "location": "https://portal.medicinskaforeningen.se/saml/simplesamlwww/module.php/saml/sp/saml2-acs.php/AgeraMedlem",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.vib.be/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Minnaert"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jasper.minnaert@vib.be"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jasper"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.vib.be/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://federation.belnet.be/files/Belnet-metadata-registration-practice-statement.txt"
              }
            ],
            "registration_instant": "2012-03-27T12:00:00Z",
            "registration_authority": "http://federation.belnet.be/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAJDe4t8YsctH2JGBPfdMqwdkUTh3MA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC52aWIuYmUwHhcNMTMwOTEwMTI0NzU5WhcNMzMw\nOTEwMTI0NzU5WjAVMRMwEQYDVQQDEwppZHAudmliLmJlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAjX9kGhK6nYxWvuNeuNdGuU2xyEsUyTEE7a3+vWG1\n//IcBPi6b0KXBYOKysqTekzYsoNiSxi9sup5Yx6lgS+nqHoM+ULqyKH5t78HctvB\ng5R4WGNQ5QW01uw3eLZ5OaCnyb/XXwYhUdZJraaFL/R5sSzkwHRkJ5XN1kUjj3M9\nIIr9Kquc6/gbvZj0P4dRHB8WTkboKoC71yF0lJQtiawK5mmH6kmnnR6hNe7+PPY3\nSSysNjOWscyBKXvLQiyC3/5a7ILzWTo9xAwoDvl87JnlgrZaNTbcVpugDufOI496\nFIq7kMHqMJVxcBht64HXHQ+jdiAL1Fga/zmd2nNbi+1a3QIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAudmliLmJlhiFodHRwczovL2lkcC52aWIuYmUvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFCvlrzRYM0OZ/HvA0ZUxTRM3tRUPMA0GCSqGSIb3DQEB\nBQUAA4IBAQAhQdI6woZQyn6p9LAr9IEjc+6CvYLq/SRLK651E/D1j1C3NznmPf3T\nWc8cMRy5g6EGmuIUk7BIo55eAIH95AgXNbvC2/OEkmwDtMV1nDV/rP3XWp0WzOhL\nSkG9fvuA/Mm6v6UtLW6HDRu6GzZPNPegDdSbJ01xpuOaF+O011U2ThaXZFHv+3fw\n81HKd3ZJ1cImeP4gijREmG7Go+Vq2ROM8/+3f/VhYSOgJU9g6ylkxKLKcxAeyg5J\n0BNkUbCgjbqiU1mg5oV7QYFyYKhOO0vJPFfv5DeLIfCdKFo7Hw/HzI3Y+Afjy0+L\nVJxJ/lqmkwOe7YkIk4wBzp6DTlfsek98"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vib.be"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.vib.be:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.vib.be:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.vib.be/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.vib.be/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.vib.be/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.vib.be/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.vib.be:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.vib.be:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "belnet.be"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Vlaams Instituut voor Biotechnologie"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/jpg;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/jpg;base64, ",
                    "height": "128",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "128"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "VIB"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "vib.be"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.018402,3.691419"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.191.128.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAJDe4t8YsctH2JGBPfdMqwdkUTh3MA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC52aWIuYmUwHhcNMTMwOTEwMTI0NzU5WhcNMzMw\nOTEwMTI0NzU5WjAVMRMwEQYDVQQDEwppZHAudmliLmJlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAjX9kGhK6nYxWvuNeuNdGuU2xyEsUyTEE7a3+vWG1\n//IcBPi6b0KXBYOKysqTekzYsoNiSxi9sup5Yx6lgS+nqHoM+ULqyKH5t78HctvB\ng5R4WGNQ5QW01uw3eLZ5OaCnyb/XXwYhUdZJraaFL/R5sSzkwHRkJ5XN1kUjj3M9\nIIr9Kquc6/gbvZj0P4dRHB8WTkboKoC71yF0lJQtiawK5mmH6kmnnR6hNe7+PPY3\nSSysNjOWscyBKXvLQiyC3/5a7ILzWTo9xAwoDvl87JnlgrZaNTbcVpugDufOI496\nFIq7kMHqMJVxcBht64HXHQ+jdiAL1Fga/zmd2nNbi+1a3QIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAudmliLmJlhiFodHRwczovL2lkcC52aWIuYmUvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFCvlrzRYM0OZ/HvA0ZUxTRM3tRUPMA0GCSqGSIb3DQEB\nBQUAA4IBAQAhQdI6woZQyn6p9LAr9IEjc+6CvYLq/SRLK651E/D1j1C3NznmPf3T\nWc8cMRy5g6EGmuIUk7BIo55eAIH95AgXNbvC2/OEkmwDtMV1nDV/rP3XWp0WzOhL\nSkG9fvuA/Mm6v6UtLW6HDRu6GzZPNPegDdSbJ01xpuOaF+O011U2ThaXZFHv+3fw\n81HKd3ZJ1cImeP4gijREmG7Go+Vq2ROM8/+3f/VhYSOgJU9g6ylkxKLKcxAeyg5J\n0BNkUbCgjbqiU1mg5oV7QYFyYKhOO0vJPFfv5DeLIfCdKFo7Hw/HzI3Y+Afjy0+L\nVJxJ/lqmkwOe7YkIk4wBzp6DTlfsek98"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "VIB - Vlaams Instituut voor Biotechnologie"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vib.be"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "VIB"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://oasp.beta.athensams.net/OaspMetadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://oasp.beta.athensams.net/OaspMetadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://oasp-beta.athensams.net/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://oasp-beta.athensams.net/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEtTCCA52gAwIBAgIBADANBgkqhkiG9w0BAQUFADCBnTELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgTCFNvbWVyc2V0MQ0wCwYDVQQHEwRCYXRoMRAwDgYDVQQKEwdFZHVz\n\t\t\t\t\t\tZXJ2MQ8wDQYDVQQLEwZBdGhlbnMxIDAeBgNVBAMTF29hc3AuYmV0YS5hdGhlbnNh\n\t\t\t\t\t\tbXMubmV0MScwJQYJKoZIhvcNAQkBFhhhdGhlbnNkc3BAZWR1c2Vydi5vcmcudWsw\n\t\t\t\t\t\tHhcNMDgwMjE1MDk1ODM1WhcNMTgwMjEyMDk1ODM1WjCBnTELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgTCFNvbWVyc2V0MQ0wCwYDVQQHEwRCYXRoMRAwDgYDVQQKEwdFZHVz\n\t\t\t\t\t\tZXJ2MQ8wDQYDVQQLEwZBdGhlbnMxIDAeBgNVBAMTF29hc3AuYmV0YS5hdGhlbnNh\n\t\t\t\t\t\tbXMubmV0MScwJQYJKoZIhvcNAQkBFhhhdGhlbnNkc3BAZWR1c2Vydi5vcmcudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDLYAfycv0j9S88QfU4GCGU\n\t\t\t\t\t\tMd16DqYLQpEDBvRPLuAjKypBoIZwnKbhh+p6GlafYsXk/oNpG5EZ4Wn/tYd8CM2w\n\t\t\t\t\t\t2bpoifmGAiXKvWoh87vgotkZnrvStGj/Aw7eUM8nsfduMbiw6vCO7BQAfwGzkUL7\n\t\t\t\t\t\t7obaMLA9Zbz5afGAvzq9k58+D6u9ox/DzAdN4iqbrFgvnxiN2uvusIkIeMoxUREd\n\t\t\t\t\t\tqiFFoXlk97Sj7yeKggkA25AtOUO2LnI8Le7FT3dP2jlCB9onlIa0ZR0Fm/RjFu4t\n\t\t\t\t\t\tzxB+jwvZ3VTqmxIzzCYxi6wK+xOaJPVwLvSGTwyquNUJSrMAOef43rIMCVAQDmKr\n\t\t\t\t\t\tAgMBAAGjgf0wgfowHQYDVR0OBBYEFH7zEIp6CNN5LLMic1imrULmiSBgMIHKBgNV\n\t\t\t\t\t\tHSMEgcIwgb+AFH7zEIp6CNN5LLMic1imrULmiSBgoYGjpIGgMIGdMQswCQYDVQQG\n\t\t\t\t\t\tEwJHQjERMA8GA1UECBMIU29tZXJzZXQxDTALBgNVBAcTBEJhdGgxEDAOBgNVBAoT\n\t\t\t\t\t\tB0VkdXNlcnYxDzANBgNVBAsTBkF0aGVuczEgMB4GA1UEAxMXb2FzcC5iZXRhLmF0\n\t\t\t\t\t\taGVuc2Ftcy5uZXQxJzAlBgkqhkiG9w0BCQEWGGF0aGVuc2RzcEBlZHVzZXJ2Lm9y\n\t\t\t\t\t\tZy51a4IBADAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBoIKKJtwn/\n\t\t\t\t\t\tMUxqYHeOpCjgHxOFssQpALuuasCpx7Ojb/a1fkV2523hI09zDTy2m7s3C9szPhwx\n\t\t\t\t\t\tZv1LUshbMsZon2bYXZwDdFa8tkzOYlZpKhguv6r/5LFZI2s09uDaVrFl6cVxFAUz\n\t\t\t\t\t\tFQiY8XQHME4m+hxqf8RMGMid+33QtIIlEAD4/OnvquHXBxiO8ESMxebV4mNLkn34\n\t\t\t\t\t\tKEfS16BFBP3scX62GBHqg+dAZVJHHjbIdIQsPcFa/3UElFMxur1gOKclzjHa8GX3\n\t\t\t\t\t\t0YGxOwt3hjmCenx6jVu/4RF5tN8GLvq5dcU1o0M6b8bDf70Htq2WS+4RIAsO+NHd\n\t\t\t\t\t\t7HIXRm4dVYw+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "openathens.net"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Eduserv Beta"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.athensams.net/dsp/openathens_sp"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEtTCCA52gAwIBAgIBADANBgkqhkiG9w0BAQUFADCBnTELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgTCFNvbWVyc2V0MQ0wCwYDVQQHEwRCYXRoMRAwDgYDVQQKEwdFZHVz\n\t\t\t\t\t\tZXJ2MQ8wDQYDVQQLEwZBdGhlbnMxIDAeBgNVBAMTF29hc3AuYmV0YS5hdGhlbnNh\n\t\t\t\t\t\tbXMubmV0MScwJQYJKoZIhvcNAQkBFhhhdGhlbnNkc3BAZWR1c2Vydi5vcmcudWsw\n\t\t\t\t\t\tHhcNMDgwMjE1MDk1ODM1WhcNMTgwMjEyMDk1ODM1WjCBnTELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgTCFNvbWVyc2V0MQ0wCwYDVQQHEwRCYXRoMRAwDgYDVQQKEwdFZHVz\n\t\t\t\t\t\tZXJ2MQ8wDQYDVQQLEwZBdGhlbnMxIDAeBgNVBAMTF29hc3AuYmV0YS5hdGhlbnNh\n\t\t\t\t\t\tbXMubmV0MScwJQYJKoZIhvcNAQkBFhhhdGhlbnNkc3BAZWR1c2Vydi5vcmcudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDLYAfycv0j9S88QfU4GCGU\n\t\t\t\t\t\tMd16DqYLQpEDBvRPLuAjKypBoIZwnKbhh+p6GlafYsXk/oNpG5EZ4Wn/tYd8CM2w\n\t\t\t\t\t\t2bpoifmGAiXKvWoh87vgotkZnrvStGj/Aw7eUM8nsfduMbiw6vCO7BQAfwGzkUL7\n\t\t\t\t\t\t7obaMLA9Zbz5afGAvzq9k58+D6u9ox/DzAdN4iqbrFgvnxiN2uvusIkIeMoxUREd\n\t\t\t\t\t\tqiFFoXlk97Sj7yeKggkA25AtOUO2LnI8Le7FT3dP2jlCB9onlIa0ZR0Fm/RjFu4t\n\t\t\t\t\t\tzxB+jwvZ3VTqmxIzzCYxi6wK+xOaJPVwLvSGTwyquNUJSrMAOef43rIMCVAQDmKr\n\t\t\t\t\t\tAgMBAAGjgf0wgfowHQYDVR0OBBYEFH7zEIp6CNN5LLMic1imrULmiSBgMIHKBgNV\n\t\t\t\t\t\tHSMEgcIwgb+AFH7zEIp6CNN5LLMic1imrULmiSBgoYGjpIGgMIGdMQswCQYDVQQG\n\t\t\t\t\t\tEwJHQjERMA8GA1UECBMIU29tZXJzZXQxDTALBgNVBAcTBEJhdGgxEDAOBgNVBAoT\n\t\t\t\t\t\tB0VkdXNlcnYxDzANBgNVBAsTBkF0aGVuczEgMB4GA1UEAxMXb2FzcC5iZXRhLmF0\n\t\t\t\t\t\taGVuc2Ftcy5uZXQxJzAlBgkqhkiG9w0BCQEWGGF0aGVuc2RzcEBlZHVzZXJ2Lm9y\n\t\t\t\t\t\tZy51a4IBADAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBoIKKJtwn/\n\t\t\t\t\t\tMUxqYHeOpCjgHxOFssQpALuuasCpx7Ojb/a1fkV2523hI09zDTy2m7s3C9szPhwx\n\t\t\t\t\t\tZv1LUshbMsZon2bYXZwDdFa8tkzOYlZpKhguv6r/5LFZI2s09uDaVrFl6cVxFAUz\n\t\t\t\t\t\tFQiY8XQHME4m+hxqf8RMGMid+33QtIIlEAD4/OnvquHXBxiO8ESMxebV4mNLkn34\n\t\t\t\t\t\tKEfS16BFBP3scX62GBHqg+dAZVJHHjbIdIQsPcFa/3UElFMxur1gOKclzjHa8GX3\n\t\t\t\t\t\t0YGxOwt3hjmCenx6jVu/4RF5tN8GLvq5dcU1o0M6b8bDf70Htq2WS+4RIAsO+NHd\n\t\t\t\t\t\t7HIXRm4dVYw+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEtTCCA52gAwIBAgIBADANBgkqhkiG9w0BAQUFADCBnTELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgTCFNvbWVyc2V0MQ0wCwYDVQQHEwRCYXRoMRAwDgYDVQQKEwdFZHVz\n\t\t\t\t\t\tZXJ2MQ8wDQYDVQQLEwZBdGhlbnMxIDAeBgNVBAMTF29hc3AuYmV0YS5hdGhlbnNh\n\t\t\t\t\t\tbXMubmV0MScwJQYJKoZIhvcNAQkBFhhhdGhlbnNkc3BAZWR1c2Vydi5vcmcudWsw\n\t\t\t\t\t\tHhcNMDgwMjE1MDk1ODM1WhcNMTgwMjEyMDk1ODM1WjCBnTELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgTCFNvbWVyc2V0MQ0wCwYDVQQHEwRCYXRoMRAwDgYDVQQKEwdFZHVz\n\t\t\t\t\t\tZXJ2MQ8wDQYDVQQLEwZBdGhlbnMxIDAeBgNVBAMTF29hc3AuYmV0YS5hdGhlbnNh\n\t\t\t\t\t\tbXMubmV0MScwJQYJKoZIhvcNAQkBFhhhdGhlbnNkc3BAZWR1c2Vydi5vcmcudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDLYAfycv0j9S88QfU4GCGU\n\t\t\t\t\t\tMd16DqYLQpEDBvRPLuAjKypBoIZwnKbhh+p6GlafYsXk/oNpG5EZ4Wn/tYd8CM2w\n\t\t\t\t\t\t2bpoifmGAiXKvWoh87vgotkZnrvStGj/Aw7eUM8nsfduMbiw6vCO7BQAfwGzkUL7\n\t\t\t\t\t\t7obaMLA9Zbz5afGAvzq9k58+D6u9ox/DzAdN4iqbrFgvnxiN2uvusIkIeMoxUREd\n\t\t\t\t\t\tqiFFoXlk97Sj7yeKggkA25AtOUO2LnI8Le7FT3dP2jlCB9onlIa0ZR0Fm/RjFu4t\n\t\t\t\t\t\tzxB+jwvZ3VTqmxIzzCYxi6wK+xOaJPVwLvSGTwyquNUJSrMAOef43rIMCVAQDmKr\n\t\t\t\t\t\tAgMBAAGjgf0wgfowHQYDVR0OBBYEFH7zEIp6CNN5LLMic1imrULmiSBgMIHKBgNV\n\t\t\t\t\t\tHSMEgcIwgb+AFH7zEIp6CNN5LLMic1imrULmiSBgoYGjpIGgMIGdMQswCQYDVQQG\n\t\t\t\t\t\tEwJHQjERMA8GA1UECBMIU29tZXJzZXQxDTALBgNVBAcTBEJhdGgxEDAOBgNVBAoT\n\t\t\t\t\t\tB0VkdXNlcnYxDzANBgNVBAsTBkF0aGVuczEgMB4GA1UEAxMXb2FzcC5iZXRhLmF0\n\t\t\t\t\t\taGVuc2Ftcy5uZXQxJzAlBgkqhkiG9w0BCQEWGGF0aGVuc2RzcEBlZHVzZXJ2Lm9y\n\t\t\t\t\t\tZy51a4IBADAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBoIKKJtwn/\n\t\t\t\t\t\tMUxqYHeOpCjgHxOFssQpALuuasCpx7Ojb/a1fkV2523hI09zDTy2m7s3C9szPhwx\n\t\t\t\t\t\tZv1LUshbMsZon2bYXZwDdFa8tkzOYlZpKhguv6r/5LFZI2s09uDaVrFl6cVxFAUz\n\t\t\t\t\t\tFQiY8XQHME4m+hxqf8RMGMid+33QtIIlEAD4/OnvquHXBxiO8ESMxebV4mNLkn34\n\t\t\t\t\t\tKEfS16BFBP3scX62GBHqg+dAZVJHHjbIdIQsPcFa/3UElFMxur1gOKclzjHa8GX3\n\t\t\t\t\t\t0YGxOwt3hjmCenx6jVu/4RF5tN8GLvq5dcU1o0M6b8bDf70Htq2WS+4RIAsO+NHd\n\t\t\t\t\t\t7HIXRm4dVYw+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://oasp-beta.athensams.net/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://oasp-beta.athensams.net/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://oasp-beta.athensams.net/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://oasp-beta.athensams.net/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://oasp-beta.athensams.net:5070/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://oasp-beta.athensams.net:5070/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://oasp-beta.athensams.net:5070/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://oasp-beta.athensams.net:5070/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://oasp-beta.athensams.net/oa/auth/rcv",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://oasp-beta.athensams.net/oa/auth/rcv",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://oasp-beta.athensams.net/oa/auth/rcv",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://oasp-beta.athensams.net/oa/auth/rcv",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://oasp-beta.athensams.net:5070/oa/auth/rcv",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://oasp-beta.athensams.net:5070/oa/auth/rcv",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://oasp-beta.athensams.net:5070/oa/auth/rcv",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://oasp-beta.athensams.net:5070/oa/auth/rcv",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://oasp-beta.athensams.net/authrev.aspx",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://oasp-beta.athensams.net/authrev.aspx",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "18"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.calderdale.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Haworth"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:michaelh@calderdale.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Haworth"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:michaelh@calderdale.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.calderdale.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-04-07T17:36:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZDCCAkwCCQDCBJgSsIDDIjANBgkqhkiG9w0BAQUFADB0MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEXMBUGA1UECBMOV2VzdCBZb3Jrc2hpcmUxEDAOBgNVBAcTB0hhbGlmYXgxGzAZ\n\t\t\t\t\t\tBgNVBAoTEkNhbGRlcmRhbGUgQ29sbGVnZTEdMBsGA1UEAxMUaWRwLmNhbGRlcmRh\n\t\t\t\t\t\tbGUuYWMudWswHhcNMTMwODIwMDk0OTE1WhcNMzMwODE1MDk0OTE1WjB0MQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEXMBUGA1UECBMOV2VzdCBZb3Jrc2hpcmUxEDAOBgNVBAcTB0hhbGlm\n\t\t\t\t\t\tYXgxGzAZBgNVBAoTEkNhbGRlcmRhbGUgQ29sbGVnZTEdMBsGA1UEAxMUaWRwLmNh\n\t\t\t\t\t\tbGRlcmRhbGUuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDl\n\t\t\t\t\t\td9r2GlhawshfKg2mLNnNM/cDXMuNmFyO5WqggGq/KYHz0IBPyiyta6i+br5eXBKO\n\t\t\t\t\t\t1AqN50NOCd/+R8Sn6od72hEt8Rqw/mNeBpeunugR6osrfXU2jLJC3s1arRzeq9Su\n\t\t\t\t\t\ttiJIfcH5W+D/DNU8HohGu0S1O850RDNczxgv3XRtgpIZ7+StR/i7K/87CnfqPa7N\n\t\t\t\t\t\tZ5HnroRkOvnJvWVQqxeWq4uyg1SvmduZM3M5q9GHPIWNNOGD2tweqedebRfuKGS0\n\t\t\t\t\t\tzFli/TuNt71KRfbe69XRJJ8+qonpZQnBXAB9Yoy54Cdfx5xVEPM8cDIym18PPFBt\n\t\t\t\t\t\tz8XvtHII5NLdfyVeXR8TAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBALpqSF1/M+T+\n\t\t\t\t\t\ttgTfWN+2Okc+AH9CyDweJWpzlrOGNyp7A5ZlACnxtDacwOweI2smD2dw40kePPYG\n\t\t\t\t\t\tEDXNI38vkdzVLOOEVdJYXNIl48Y2bXuqP+vpzu6LCP7YtuaooutLN5o+XEuGyvkn\n\t\t\t\t\t\tteHT5ghzinJTZSYxJbm3KoXntug1voV18Z6naYJiazdhs2e5EvrnjFkwNgzjKXqx\n\t\t\t\t\t\tlDLBTzo4/aBLVsUmfJ1ulvsIeUja2lHL7jZ68ENOjtH3ttQgoCcsd26iKqyaTzrI\n\t\t\t\t\t\tDmObHsLnFUzF6kTwb/GOVLcTnRMIt6geVfLn+Fvd8TEvRL/9tpnU1QjnvfalQrec\n\t\t\t\t\t\tuF5jkFFaZrc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "calderdale.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.calderdale.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.calderdale.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.calderdale.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.calderdale.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.calderdale.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.calderdale.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.calderdale.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.calderdale.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "calderdale.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZDCCAkwCCQDCBJgSsIDDIjANBgkqhkiG9w0BAQUFADB0MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEXMBUGA1UECBMOV2VzdCBZb3Jrc2hpcmUxEDAOBgNVBAcTB0hhbGlmYXgxGzAZ\n\t\t\t\t\t\tBgNVBAoTEkNhbGRlcmRhbGUgQ29sbGVnZTEdMBsGA1UEAxMUaWRwLmNhbGRlcmRh\n\t\t\t\t\t\tbGUuYWMudWswHhcNMTMwODIwMDk0OTE1WhcNMzMwODE1MDk0OTE1WjB0MQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEXMBUGA1UECBMOV2VzdCBZb3Jrc2hpcmUxEDAOBgNVBAcTB0hhbGlm\n\t\t\t\t\t\tYXgxGzAZBgNVBAoTEkNhbGRlcmRhbGUgQ29sbGVnZTEdMBsGA1UEAxMUaWRwLmNh\n\t\t\t\t\t\tbGRlcmRhbGUuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDl\n\t\t\t\t\t\td9r2GlhawshfKg2mLNnNM/cDXMuNmFyO5WqggGq/KYHz0IBPyiyta6i+br5eXBKO\n\t\t\t\t\t\t1AqN50NOCd/+R8Sn6od72hEt8Rqw/mNeBpeunugR6osrfXU2jLJC3s1arRzeq9Su\n\t\t\t\t\t\ttiJIfcH5W+D/DNU8HohGu0S1O850RDNczxgv3XRtgpIZ7+StR/i7K/87CnfqPa7N\n\t\t\t\t\t\tZ5HnroRkOvnJvWVQqxeWq4uyg1SvmduZM3M5q9GHPIWNNOGD2tweqedebRfuKGS0\n\t\t\t\t\t\tzFli/TuNt71KRfbe69XRJJ8+qonpZQnBXAB9Yoy54Cdfx5xVEPM8cDIym18PPFBt\n\t\t\t\t\t\tz8XvtHII5NLdfyVeXR8TAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBALpqSF1/M+T+\n\t\t\t\t\t\ttgTfWN+2Okc+AH9CyDweJWpzlrOGNyp7A5ZlACnxtDacwOweI2smD2dw40kePPYG\n\t\t\t\t\t\tEDXNI38vkdzVLOOEVdJYXNIl48Y2bXuqP+vpzu6LCP7YtuaooutLN5o+XEuGyvkn\n\t\t\t\t\t\tteHT5ghzinJTZSYxJbm3KoXntug1voV18Z6naYJiazdhs2e5EvrnjFkwNgzjKXqx\n\t\t\t\t\t\tlDLBTzo4/aBLVsUmfJ1ulvsIeUja2lHL7jZ68ENOjtH3ttQgoCcsd26iKqyaTzrI\n\t\t\t\t\t\tDmObHsLnFUzF6kTwb/GOVLcTnRMIt6geVfLn+Fvd8TEvRL/9tpnU1QjnvfalQrec\n\t\t\t\t\t\tuF5jkFFaZrc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Calderdale College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.calderdale.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Calderdale College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://cmi-nuig.calpendo.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Robinson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul@exprodo.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Robinson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul@exprodo.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cmi-nuig.calpendo.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-09-14T14:31:19Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Calpendo for National University of Ireland Galway"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.exprodo.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Exprodo Software Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cmi-nuig.calpendo.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cmi-nuig.calpendo.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cmi-nuig.calpendo.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cmi-nuig.calpendo.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cmi-nuig.calpendo.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://cmi-nuig.calpendo.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://cmi-nuig.calpendo.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://cmi-nuig.calpendo.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Core facility management, booking system and web-based database for research/clinical facilities."
                  }
                ],
                "logo": [
                  {
                    "text": "https://downloads.exprodo.com/images/exprodo-software_271x100.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "271"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Calpendo for National University of Ireland Galway"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIJALCR79ZDW2xvMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHNoaWIuZXhwcm9kby5jb20wHhcNMTUwNjIyMTUyMTAxWhcNMjUwNjE5MTUy\n\t\t\t\t\t\tMTAxWjAbMRkwFwYDVQQDExBzaGliLmV4cHJvZG8uY29tMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAlihJNaZPZ3oGM5NQlpgwJUJxlWZ8rbWrx9Kk5rPB\n\t\t\t\t\t\t4Fb0C6CH+YIOKHb9sxVXPL5Vi9JypYE0Y7JRFEKf7qzbFNTEDAKhq0hjJ+XMWiVq\n\t\t\t\t\t\tPJjbKYW4LJtM05DoPpTe/gKZJRaktGUDGu8m5ifLtd7klhFQmV0duDriDEPiW4ik\n\t\t\t\t\t\tLeYZGiReIkvWSx4kFnQbERYuyrjXPOnhKw8pnv4HuzR/Js4tmUQbMy9VPbjbWSET\n\t\t\t\t\t\to2x9TfCubitIiOguXNGU8hcOv+ys/sWKTddPQ8208qpsfQLo+YSm9NmYDn3bJ3tg\n\t\t\t\t\t\tSdA/9OTLJSjTZrz7RUZUeCYF/yv0vhRpicDDg1Ym8kdtCQIDAQABo2MwYTBABgNV\n\t\t\t\t\t\tHREEOTA3ghBzaGliLmV4cHJvZG8uY29thiNodHRwczovL3NoaWIuZXhwcm9kby5j\n\t\t\t\t\t\tb20vc2hpYmJvbGV0aDAdBgNVHQ4EFgQU7xBaV9vU2BCTDlQLhTkL5L6/1ckwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBAChUHGR1vS+giyhBJLy6gvfWFpfmo6dJlVn9zTIiztus\n\t\t\t\t\t\tSNX3AR7Xe3KLO+YV/8r1vUz5WO+xnUwFQd7Et20M5oeeZqbDqyPJqynepUZ3NeE5\n\t\t\t\t\t\tGfzERa8Rdvr6t6HoY0H19u0IMiMemtxQpFDt2uLtkawJLw7L3A2hUdbVta8MyUAQ\n\t\t\t\t\t\t7WV7raxbNae56DlNuivOY2kkEl9T39xiLNpQ4cHtB2Z1uGLxPcE49j1AzfAM5ugk\n\t\t\t\t\t\t29ai5m2neGiTzsvlEvw88pW7CMGcfZEPNsDA4zbQNTAu0FYIhrP60+OifLLZoMen\n\t\t\t\t\t\tlT/unHR4GJe4dtKbypAo6cvgW2Uu7aCV0wO0ni7MiCE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cmi-nuig.calpendo.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cmi-nuig.calpendo.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cmi-nuig.calpendo.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://cmi-nuig.calpendo.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://cmi-nuig.calpendo.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://cmi-nuig.calpendo.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Calpendo for National University of Ireland Galway"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://xenosmilus2.umdc.umu.se:8087/sp.xml",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hedberg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dirg@its.umu.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roland"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://xenosmilus2.umdc.umu.se:8087/sp.xml",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Umea Universitet - ITS"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Umea Universitet ITS"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.its.umu.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ITS"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://xenosmilus2.umdc.umu.se:8087/slo",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://xenosmilus2.umdc.umu.se:8087/disco",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8jCCAlugAwIBAgIJAJHg2V5J31I8MA0GCSqGSIb3DQEBBQUAMFoxCzAJBgNV\nBAYTAlNFMQ0wCwYDVQQHEwRVbWVhMRgwFgYDVQQKEw9VbWVhIFVuaXZlcnNpdHkx\nEDAOBgNVBAsTB0lUIFVuaXQxEDAOBgNVBAMTB1Rlc3QgU1AwHhcNMDkxMDI2MTMz\nMTE1WhcNMTAxMDI2MTMzMTE1WjBaMQswCQYDVQQGEwJTRTENMAsGA1UEBxMEVW1l\nYTEYMBYGA1UEChMPVW1lYSBVbml2ZXJzaXR5MRAwDgYDVQQLEwdJVCBVbml0MRAw\nDgYDVQQDEwdUZXN0IFNQMIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQDkJWP7\nbwOxtH+E15VTaulNzVQ/0cSbM5G7abqeqSNSs0l0veHr6/ROgW96ZeQ57fzVy2MC\nFiQRw2fzBs0n7leEmDJyVVtBTavYlhAVXDNa3stgvh43qCfLx+clUlOvtnsoMiiR\nmo7qf0BoPKTj7c0uLKpDpEbAHQT4OF1HRYVxMwIDAQABo4G/MIG8MB0GA1UdDgQW\nBBQ7RgbMJFDGRBu9o3tDQDuSoBy7JjCBjAYDVR0jBIGEMIGBgBQ7RgbMJFDGRBu9\no3tDQDuSoBy7JqFepFwwWjELMAkGA1UEBhMCU0UxDTALBgNVBAcTBFVtZWExGDAW\nBgNVBAoTD1VtZWEgVW5pdmVyc2l0eTEQMA4GA1UECxMHSVQgVW5pdDEQMA4GA1UE\nAxMHVGVzdCBTUIIJAJHg2V5J31I8MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEF\nBQADgYEAMuRwwXRnsiyWzmRikpwinnhTmbooKm5TINPE7A7gSQ710RxioQePPhZO\nzkM27NnHTrCe2rBVg0EGz7QTd1JIwLPvgoj4VTi/fSha/tXrYUaqc9AqU1kWI4WN\n+vffBGQ09mo+6CffuFTZYeOhzP/2stAPwCTU4kxEoiy0KpZMANI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8jCCAlugAwIBAgIJAJHg2V5J31I8MA0GCSqGSIb3DQEBBQUAMFoxCzAJBgNV\nBAYTAlNFMQ0wCwYDVQQHEwRVbWVhMRgwFgYDVQQKEw9VbWVhIFVuaXZlcnNpdHkx\nEDAOBgNVBAsTB0lUIFVuaXQxEDAOBgNVBAMTB1Rlc3QgU1AwHhcNMDkxMDI2MTMz\nMTE1WhcNMTAxMDI2MTMzMTE1WjBaMQswCQYDVQQGEwJTRTENMAsGA1UEBxMEVW1l\nYTEYMBYGA1UEChMPVW1lYSBVbml2ZXJzaXR5MRAwDgYDVQQLEwdJVCBVbml0MRAw\nDgYDVQQDEwdUZXN0IFNQMIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQDkJWP7\nbwOxtH+E15VTaulNzVQ/0cSbM5G7abqeqSNSs0l0veHr6/ROgW96ZeQ57fzVy2MC\nFiQRw2fzBs0n7leEmDJyVVtBTavYlhAVXDNa3stgvh43qCfLx+clUlOvtnsoMiiR\nmo7qf0BoPKTj7c0uLKpDpEbAHQT4OF1HRYVxMwIDAQABo4G/MIG8MB0GA1UdDgQW\nBBQ7RgbMJFDGRBu9o3tDQDuSoBy7JjCBjAYDVR0jBIGEMIGBgBQ7RgbMJFDGRBu9\no3tDQDuSoBy7JqFepFwwWjELMAkGA1UEBhMCU0UxDTALBgNVBAcTBFVtZWExGDAW\nBgNVBAoTD1VtZWEgVW5pdmVyc2l0eTEQMA4GA1UECxMHSVQgVW5pdDEQMA4GA1UE\nAxMHVGVzdCBTUIIJAJHg2V5J31I8MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEF\nBQADgYEAMuRwwXRnsiyWzmRikpwinnhTmbooKm5TINPE7A7gSQ710RxioQePPhZO\nzkM27NnHTrCe2rBVg0EGz7QTd1JIwLPvgoj4VTi/fSha/tXrYUaqc9AqU1kWI4WN\n+vffBGQ09mo+6CffuFTZYeOhzP/2stAPwCTU4kxEoiy0KpZMANI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://xenosmilus2.umdc.umu.se:8087/acs/redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://xenosmilus2.umdc.umu.se:8087/acs/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://fides.rivm.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://fides.rivm.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-05-01T16:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/e880c6bc54e8854478e8739122e342b6",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Rijksinstituut voor Volksgezondheid en Milieu"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "National Institute for Public Health and the Environment"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/RIVM_Logo.png",
                    "height": "101",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "500"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Rijksinstituut voor Volksgezondheid en Milieu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "National Institute for Public Health and the Environment"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://rivm.nl/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://rivm.nl/English"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Rijksinstituut voor Volksgezondheid en Milieu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National Institute for Public Health and the Environment"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://tc-web-04.groupgti.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:targetconnect.support@groupgti.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TARGETconnect Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Masters"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chris.masters@groupgti.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://tc-web-04.groupgti.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GTI: TARGETconnect Web4"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.groupgti.com/home/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GTI Media Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEXjCCA0agAwIBAgIJAMke5AjSxi5OMA0GCSqGSIb3DQEBBQUAMIGvMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEUMBIGA1UECBMLT3hmb3Jkc2hpcmUxFDASBgNVBAcTC1dhbGxpbmdm\n\t\t\t\t\t\tb3JkMRYwFAYDVQQKEw1HVEkgTWVkaWEgTHRkMTIwMAYDVQQDEylodHRwczovL3Rj\n\t\t\t\t\t\tLXdlYi0wNC5ncm91cGd0aS5uZXQvc2hpYmJvbGV0aDEoMCYGCSqGSIb3DQEJARYZ\n\t\t\t\t\t\tY2hyaXMubWFzdGVyc0Bncm91cHRpLmNvbTAeFw0xMDA5MjMyMTA5NDRaFw0yMDA5\n\t\t\t\t\t\tMjAyMTA5NDRaMIGvMQswCQYDVQQGEwJHQjEUMBIGA1UECBMLT3hmb3Jkc2hpcmUx\n\t\t\t\t\t\tFDASBgNVBAcTC1dhbGxpbmdmb3JkMRYwFAYDVQQKEw1HVEkgTWVkaWEgTHRkMTIw\n\t\t\t\t\t\tMAYDVQQDEylodHRwczovL3RjLXdlYi0wNC5ncm91cGd0aS5uZXQvc2hpYmJvbGV0\n\t\t\t\t\t\taDEoMCYGCSqGSIb3DQEJARYZY2hyaXMubWFzdGVyc0Bncm91cHRpLmNvbTCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL0ZYat2MyEhnbeVgaS6DfqdejK4\n\t\t\t\t\t\tZspciHTMNsflPGSyUL+bjhQiP9q+QqkUQTRD6QvP3cwz0pGQPqrjh+bFLwuveyjw\n\t\t\t\t\t\tONzdJReT3YAMF0ykekIHhY2YEUCSdAV5MI6ABV1DHYRMYIMauac9BE8mxGbBPzDB\n\t\t\t\t\t\tXO7NEzqOCsqAMqSxFpETUaTLlCGBNrf4/dqKGMHeWZTfxreET2nmGFy3vGy3WNzj\n\t\t\t\t\t\tPrIvmNMV2BS+GK146TzTI8WSDTeFylu3FDcG8EDagY1AdsI2E67WWtXENnqh7nhg\n\t\t\t\t\t\tCyXnHPlrWiWB7G1/dcMqFMiL7o4LdbrPah9SuSx5d3z5opC3hFqAyiLAPH0CAwEA\n\t\t\t\t\t\tAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0\n\t\t\t\t\t\tZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFNOJpQGCNKkje2TJJrIQJrLEIPy5MB8G\n\t\t\t\t\t\tA1UdIwQYMBaAFNOJpQGCNKkje2TJJrIQJrLEIPy5MA0GCSqGSIb3DQEBBQUAA4IB\n\t\t\t\t\t\tAQBgAcdiAEiBYPdZKlhnP+lapwnxjYas7iPagZxh3VM48tMF4hYVQISOOWxkqhX+\n\t\t\t\t\t\tJbdBv8IW6Hmm3nS32akZjGXLiXwcrXjQO+1V2JbfCRGV6Q0SMu4AToJBIcIykSRP\n\t\t\t\t\t\t2YB1u8DSnsXGfzGjpsL0EIxEKrD4UWtw6o9r2JKqnNUocsDZNRZjS9gaF6ksZFMt\n\t\t\t\t\t\trrIVqvtKDRcWH9TezJ/JJPAhocQDKXstcd2m63uAlh3IjEaCnU0Dus2e3HTryBEM\n\t\t\t\t\t\t/Og+MVynXgDdcG9XgVroHCR8TqohFzzmtK1Wl+Hbew5/xwi3Tzm44ZyUj00hyxAG\n\t\t\t\t\t\tyD3GZhGlZ1YZtg+2iJdZmyox"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEXjCCA0agAwIBAgIJAMke5AjSxi5OMA0GCSqGSIb3DQEBBQUAMIGvMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEUMBIGA1UECBMLT3hmb3Jkc2hpcmUxFDASBgNVBAcTC1dhbGxpbmdm\n\t\t\t\t\t\tb3JkMRYwFAYDVQQKEw1HVEkgTWVkaWEgTHRkMTIwMAYDVQQDEylodHRwczovL3Rj\n\t\t\t\t\t\tLXdlYi0wNC5ncm91cGd0aS5uZXQvc2hpYmJvbGV0aDEoMCYGCSqGSIb3DQEJARYZ\n\t\t\t\t\t\tY2hyaXMubWFzdGVyc0Bncm91cHRpLmNvbTAeFw0xMDA5MjMyMTA5NDRaFw0yMDA5\n\t\t\t\t\t\tMjAyMTA5NDRaMIGvMQswCQYDVQQGEwJHQjEUMBIGA1UECBMLT3hmb3Jkc2hpcmUx\n\t\t\t\t\t\tFDASBgNVBAcTC1dhbGxpbmdmb3JkMRYwFAYDVQQKEw1HVEkgTWVkaWEgTHRkMTIw\n\t\t\t\t\t\tMAYDVQQDEylodHRwczovL3RjLXdlYi0wNC5ncm91cGd0aS5uZXQvc2hpYmJvbGV0\n\t\t\t\t\t\taDEoMCYGCSqGSIb3DQEJARYZY2hyaXMubWFzdGVyc0Bncm91cHRpLmNvbTCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL0ZYat2MyEhnbeVgaS6DfqdejK4\n\t\t\t\t\t\tZspciHTMNsflPGSyUL+bjhQiP9q+QqkUQTRD6QvP3cwz0pGQPqrjh+bFLwuveyjw\n\t\t\t\t\t\tONzdJReT3YAMF0ykekIHhY2YEUCSdAV5MI6ABV1DHYRMYIMauac9BE8mxGbBPzDB\n\t\t\t\t\t\tXO7NEzqOCsqAMqSxFpETUaTLlCGBNrf4/dqKGMHeWZTfxreET2nmGFy3vGy3WNzj\n\t\t\t\t\t\tPrIvmNMV2BS+GK146TzTI8WSDTeFylu3FDcG8EDagY1AdsI2E67WWtXENnqh7nhg\n\t\t\t\t\t\tCyXnHPlrWiWB7G1/dcMqFMiL7o4LdbrPah9SuSx5d3z5opC3hFqAyiLAPH0CAwEA\n\t\t\t\t\t\tAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0\n\t\t\t\t\t\tZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFNOJpQGCNKkje2TJJrIQJrLEIPy5MB8G\n\t\t\t\t\t\tA1UdIwQYMBaAFNOJpQGCNKkje2TJJrIQJrLEIPy5MA0GCSqGSIb3DQEBBQUAA4IB\n\t\t\t\t\t\tAQBgAcdiAEiBYPdZKlhnP+lapwnxjYas7iPagZxh3VM48tMF4hYVQISOOWxkqhX+\n\t\t\t\t\t\tJbdBv8IW6Hmm3nS32akZjGXLiXwcrXjQO+1V2JbfCRGV6Q0SMu4AToJBIcIykSRP\n\t\t\t\t\t\t2YB1u8DSnsXGfzGjpsL0EIxEKrD4UWtw6o9r2JKqnNUocsDZNRZjS9gaF6ksZFMt\n\t\t\t\t\t\trrIVqvtKDRcWH9TezJ/JJPAhocQDKXstcd2m63uAlh3IjEaCnU0Dus2e3HTryBEM\n\t\t\t\t\t\t/Og+MVynXgDdcG9XgVroHCR8TqohFzzmtK1Wl+Hbew5/xwi3Tzm44ZyUj00hyxAG\n\t\t\t\t\t\tyD3GZhGlZ1YZtg+2iJdZmyox"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://saml2.targetconnect.net/samlengine/shibb/acs",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://saml2.targetconnect.net/samlengine/s2/wbsso/acs",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://saml2.targetconnect.net/samlengine/s2/wbsso/acs",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://connect-stable.sunet.se/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@nordu.net"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "NORDUnet NOC"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://connect-stable.sunet.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://connect-stable.sunet.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://connect-stable.sunet.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect-stable.sunet.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect-stable.sunet.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SUNET E-Meeting Service (stable)"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "SUNET E-Meeting Service (stable)"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://connect-stable.sunet.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://connect-stable.sunet.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://connect-stable.sunet.se/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://connect-stable.sunet.se/Shibboleth.sso/DS/kalmar2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://connect-stable.sunet.se/Shibboleth.sso/DS/nordu.net",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "4"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "connect-stable.sunet.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAJ+bOx8RXj3iMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2Nvbm5lY3Qtc3RhYmxlLnN1bmV0LnNlMB4XDTEyMTEwMTE0MTEzNFoXDTIy\nMTAzMDE0MTEzNFowIjEgMB4GA1UEAxMXY29ubmVjdC1zdGFibGUuc3VuZXQuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDOuf57LwczW6o8YEv8IlZe\n6mWurJUD3iDMS1jyt9/HxUpHcQfMVrHmei7aBLzYiQMON7sYSi0pQ6/EtFMpoaeN\nWYIAEXdXVfhGVCte9mfTmLEtgxsELyK+YofXwTXkNX1VzBK3z9qRyV6BBqzgA6Zu\n4BkTabmubG4qdwHf+TJWfwJ9QkwOIuy+j+KCXELW8Cgy1q8WUvocpTfEXzILEHL8\nkel1ej8sclf0cdHjYLJpPSaBvJ+2DmvZgVLdZcWxSVLbwoMOFq4g5spFT8bZxemY\nmG185UwcQtFK3VoXdfiBn28HChMgdSxSWvt8CWj3dK49i6/eKaq/0Dam3SPHbJIN\nAgMBAAGjRTBDMCIGA1UdEQQbMBmCF2Nvbm5lY3Qtc3RhYmxlLnN1bmV0LnNlMB0G\nA1UdDgQWBBQW0PGcUIDR4qgsERc7Jy1PpfkPujANBgkqhkiG9w0BAQUFAAOCAQEA\nQ7MY+AQRal0ZYIvqjw36YQZyBCGADzI/v5K1xMxGiPAj+WiSXRIHozVFRL8lqStO\n2zh68/yWkEl4SxyU0dQ+/YpZjolRMVNPxYaUd5YhhvpS4wOwwERhuMo1KOqO/04t\nTfN3/ASiYN5qhxO7DoJy0/jJwhy6QNE8Ey3FU4t2aFo9/FcUIE6huoBqLWMP5M4N\nXc+d9o3tWDW8EzEbxsyZhpin7qczxWHl5MeztPY3kvr4M6lVswf8KkGUxgdy1a5W\nEpnud0wADmhSb4J6hSbUreM6gyvYvMNI4Tzv5xxL/+CTuIv/Ys+IAKh/g2tT3ct0\nSgXS3Q4K3pF+qwGrb3INKQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=connect-stable.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "connect-stable.sunet.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAJ+bOx8RXj3iMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2Nvbm5lY3Qtc3RhYmxlLnN1bmV0LnNlMB4XDTEyMTEwMTE0MTEzNFoXDTIy\nMTAzMDE0MTEzNFowIjEgMB4GA1UEAxMXY29ubmVjdC1zdGFibGUuc3VuZXQuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDOuf57LwczW6o8YEv8IlZe\n6mWurJUD3iDMS1jyt9/HxUpHcQfMVrHmei7aBLzYiQMON7sYSi0pQ6/EtFMpoaeN\nWYIAEXdXVfhGVCte9mfTmLEtgxsELyK+YofXwTXkNX1VzBK3z9qRyV6BBqzgA6Zu\n4BkTabmubG4qdwHf+TJWfwJ9QkwOIuy+j+KCXELW8Cgy1q8WUvocpTfEXzILEHL8\nkel1ej8sclf0cdHjYLJpPSaBvJ+2DmvZgVLdZcWxSVLbwoMOFq4g5spFT8bZxemY\nmG185UwcQtFK3VoXdfiBn28HChMgdSxSWvt8CWj3dK49i6/eKaq/0Dam3SPHbJIN\nAgMBAAGjRTBDMCIGA1UdEQQbMBmCF2Nvbm5lY3Qtc3RhYmxlLnN1bmV0LnNlMB0G\nA1UdDgQWBBQW0PGcUIDR4qgsERc7Jy1PpfkPujANBgkqhkiG9w0BAQUFAAOCAQEA\nQ7MY+AQRal0ZYIvqjw36YQZyBCGADzI/v5K1xMxGiPAj+WiSXRIHozVFRL8lqStO\n2zh68/yWkEl4SxyU0dQ+/YpZjolRMVNPxYaUd5YhhvpS4wOwwERhuMo1KOqO/04t\nTfN3/ASiYN5qhxO7DoJy0/jJwhy6QNE8Ey3FU4t2aFo9/FcUIE6huoBqLWMP5M4N\nXc+d9o3tWDW8EzEbxsyZhpin7qczxWHl5MeztPY3kvr4M6lVswf8KkGUxgdy1a5W\nEpnud0wADmhSb4J6hSbUreM6gyvYvMNI4Tzv5xxL/+CTuIv/Ys+IAKh/g2tT3ct0\nSgXS3Q4K3pF+qwGrb3INKQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=connect-stable.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://connect-stable.sunet.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://connect-stable.sunet.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect-stable.sunet.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect-stable.sunet.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect-stable.sunet.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://connect-stable.sunet.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect-stable.sunet.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://connect-stable.sunet.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://connect-stable.sunet.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://connect-stable.sunet.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.rediris.es/sir/umaidp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sir@rediris.es"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SIR helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.rediris.es/sir/umaidp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.rediris.es/sir/edugain/SIR_MRPS.pdf"
              }
            ],
            "registration_instant": "2012-10-09T13:08:24Z",
            "registration_authority": "http://www.rediris.es/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "response_location": "http://sir.rediris.es/uma/saml2/idp/SingleLogoutService.php",
              "location": "http://sir.rediris.es/uma/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "http://sir.rediris.es/uma/shib13/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "http://sir.rediris.es/uma/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Identity Provider of University of Malaga"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "El proveedor de identidad de la Universidad de M\u00e1laga"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UMA - University of Malaga"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UMA - Universidad de M\u00e1laga"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uma.es"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEeTCCA2GgAwIBAgIQCP9faAGj247/+QVzgpX08zANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDcwMTAwMDAwMFoXDTE2MDYzMDIzNTk1OVowRDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMR8wHQYDVQQDExZzYW1saWRwLnNp\nci5yZWRpcmlzLmVzMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA5tO6\ntYAdozpFMDwS7QH1qm7eECkY05lG1sp14vcVOdyN0mAf8oai+M8dCQ5iyMxD/RaG\noSmhXfHUvJ+0x8Cp/NHYbKr0cXskANcYTI0JFMFypn9Uac62CGxUYZRhHQ/2LxiE\nvzNgKrm2JiXCvOQbWrbg0sZDEsONv2G1Ln3fvOLiSiO1AjWLvOeYFPNgkNy5dxxt\n7ms7mZ0bFth6Cj38BBL0I1RebVnMgAKZWSgICUXDx35nkB+iLtidIykBgz92ZQ5h\nUrVNndP5+lraoMRuIewESSFt+LBYVeUZFTBGlupiUZ/bi7rhtIuhMM8ahaKIstbu\nIgfQBHPqRkkiiKOJawIDAQABo4IBczCCAW8wHwYDVR0jBBgwFoAUDL2TaAzz3quj\nSWsrN1dH6pDjue0wHQYDVR0OBBYEFARoBLDWcsveEZQhaMVIR9mmJkUkMA4GA1Ud\nDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggr\nBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNV\nHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNT\nTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQu\ndGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRw\nOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAhBgNVHREEGjAYghZzYW1saWRwLnNpci5y\nZWRpcmlzLmVzMA0GCSqGSIb3DQEBBQUAA4IBAQB0gmr232YgpUC4HkwAHXaH91Zx\n8ZrwiEc8c4jGLh5VsaO0OqMfUEIXMuqZ+P9JNWVwlc6VLtmsypqTuqb9a06DS88q\n2o5sAUpbXZwhArhQs1bQnu5HJ6S84Ajn+NfMOyaO7NF8Colq/9lf3DihkT0jlD7i\nPHPMw2zauvtR/WPwdPszgfIOV/vkJ0rq9AjOXxSX7V2jpkxISGW/m93iahwXEoVF\nc8VXQhNjEfcm6uawmISjsyp6ta/U3e/8GJka2csDrF/bfipMBDSdWcLMscpYO8cb\nDC0L6vehZJ+lPz3wPH6YJmlstICZUdJIgDV3TUhmji6NNKa4p6by34QdYcDH"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UMA - University of Malaga"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UMA - Universidad de M\u00e1laga"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rediris.es/index.php.en"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rediris.es/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UMA"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UMA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "dev.lararlyftet-validering.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "dev.lararlyftet-validering.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.lararlyftet-validering.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev.lararlyftet-validering.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.lararlyftet-validering.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.lararlyftet-validering.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.lararlyftet-validering.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.lararlyftet-validering.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dev.lararlyftet-validering.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Valideringssystemet f\u00f6r L\u00e4rarlyftet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service is the validation system for L\u00e4rarlyftet"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "L\u00e4rarlyftet Validering"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "L\u00e4rarlyftet Validation"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "uhr-1297.i.uhr.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+jCCAeKgAwIBAgIJAK9uhgtga6STMA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\nBAMTEXVoci0xMjk3LmkudWhyLnNlMB4XDTE0MTIwMjEyNDgyM1oXDTI0MTEyOTEy\nNDgyM1owHDEaMBgGA1UEAxMRdWhyLTEyOTcuaS51aHIuc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDSxkWORCuz0qV48LpqRMlD6H4eEe8tbGAvr0N2\nKBmz+l9FBeCBr3Q8NgTeBBnMa23i3VbEdB1016jdJ0h9jXMHN1AQMd/3tR2EoWWM\n+VjFmffjIfF0LBYyHJakmnEKmdIwjKPiVqOgwlS+a9af/wiI8XnD8sIaqFopaoA1\nhKKuANSR/TVOkDhKfdaBQcDUCyww2/sGBthhDdlC0rpgRr6nA/vbrjsYRC7PE6js\n2wFzTcMkF9gjeduKZDwpRqQdkSkIL2K1/ZBptaPOOaal6fpve6AcxmjSWZHmR3Tb\nx6ylG3e+B8O8ArwyNyam4TSMhFO57GqVuAtD8Q4uRdq3XSUzAgMBAAGjPzA9MBwG\nA1UdEQQVMBOCEXVoci0xMjk3LmkudWhyLnNlMB0GA1UdDgQWBBR9FQbRYBUqAd81\nDwOhDd+M8XDmyjANBgkqhkiG9w0BAQUFAAOCAQEAd68cfIyNUjLMpTTQuKQBJs9W\nim084wgTvsAdycV9EbYuuLrQhALQuTuGhBf8qZY16gx23ICpn12nwcXdu02Xcg5U\nxK8cv3PFIgOcXB00dfmOkwwzgtZkYuRZz4bzf4TgrQv9vMhrVJEwHPog4HuU6N8l\nJPCgGoM1ape2Nyf198u6F4qXp5MZsS+vBOXxAyvHzWOr5uMzxg0oAJQwpkVp/b2z\n3N5QAVVFxkbyHn+8RkZQZ9FiWh7Yl56wU3gvGnZrPT2AaJtVaW4cQkw0gL+dAYfm\n3osR1KprOY0+GpXcvgi9X9YlLMzfcsBIiCEoV4wjwziY99phU80XLkFKmYLsmA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=uhr-1297.i.uhr.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.lararlyftet-validering.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev.lararlyftet-validering.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.lararlyftet-validering.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.lararlyftet-validering.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.lararlyftet-validering.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.lararlyftet-validering.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dev.lararlyftet-validering.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dev.lararlyftet-validering.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dev.lararlyftet-validering.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://fire.rettorato.unito.it/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sewi-id@unito.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sewi-id@unito.it"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://fire.rettorato.unito.it/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2009-12-31T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "YouBlog provided by Universit\u00e0 degli Studi di Torino"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "YouBlog erogato da Universit\u00e0 degli Studi di Torino"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unito.it/"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unito.it"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli Studi di Torino"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli Studi di Torino"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.serviziweb.unito.it/youblog/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.serviziweb.unito.it/youblog/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.serviziweb.unito.it/youblog/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.serviziweb.unito.it/youblog/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "YouBlog"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The system after authentication, allow to create one or more blogs, articles and add comments, send private messages to the authors of the blog. It 'a space of interaction, a way to be (virtually) with the other and freely express their creativity, their opinions on various topics and environment interaction that could become a tool for collaboration in institutional activities."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.serviziweb.unito.it/youblog/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.serviziweb.unito.it/youblog"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The system after authentication, allow to create one or more blogs, articles and add comments, send private messages to the authors of the blog. It 'a space of interaction, a way to be (virtually) with the other and freely express their creativity, their opinions on various topics and environment interaction that could become a tool for collaboration in institutional activities."
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Questo servizio permette previa autenticazione, di creare uno o pi\u00f9 blog, inserire articoli e commenti, inviare messaggi privati agli autori dei blog. E' uno spazio di interazione, un modo per stare (virtualmente) insieme agli altri e per esprimere liberamente la propria creativit\u00e0, la propria opinione sui pi\u00f9 svariati argomenti e un ambiente di interazione che pu\u00f2 diventare strumento di collaborazione nell\u2019ambito delle attivit\u00e0 istituzionali."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "YouBlog"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "YouBlog"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.serviziweb.unito.it/youblog/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.serviziweb.unito.it/youblog/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEjTCCA3WgAwIBAgIRALMOFHysegGUCjSEYcftmJowDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDA0MTYwMDAwMDBaFw0xNzA0MTUyMzU5NTlaMEExITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEcMBoGA1UEAxMTc2Vydml6aXdl\nYi51bml0by5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAO3e9ULQ\n7Jx4dvGUcStS+blvUigQrfOGh7RUZYWEV71pBHazp8ajnNCCw1gfSi3iF2PSEC1Q\nOFZnhivkLmgJ3GaiAtaIMWb9zhjDV9ILfaKdwHZ6p9Fzb54M7qFNDn0iIJyCNCbe\nwAxyyNPx8mKnQn3KfHfiGCMi73X+u1XDiJLSXTvaOcd6rRJ3ol7335mH6eK+VN1X\ndDJJcIBaUGrhCwSt5zis0n1CH07OdXcbeC62kbxUVQxf7QzgECPsld/E4/bbCNSh\n74i82A6AlKKvAkzd8P/LMDKVjlaok89erKuWQoSWusWSaGegmig34D4/0Mh/m0B6\nkxKnR3QUP4jOCvsCAwEAAaOCAYkwggGFMB8GA1UdIwQYMBaAFAy9k2gM896ro0lr\nKzdXR+qQ47ntMB0GA1UdDgQWBBQIiUxAEj/RAjyl0nYAsamjHHQmbDAOBgNVHQ8B\nAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYB\nBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0f\nBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xD\nQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRj\ncy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDov\nL29jc3AudGNzLnRlcmVuYS5vcmcwNwYDVR0RBDAwLoITc2Vydml6aXdlYi51bml0\nby5pdIIXd3d3LnNlcnZpeml3ZWIudW5pdG8uaXQwDQYJKoZIhvcNAQEFBQADggEB\nACDeDzqAHJ6FEj6VnX2+MqsnG5qdbfO8f+WDbEUtX1uQEskLl52A6C7fOhUvwb+z\nP1T+LD5OxEDWFOfDuMjOY8p+eqbXjL8Pj6B2c6QVJZoDVI6AJAQdRckAZJepzdzV\nmRwkKgxoOhhJGR/rpzuTjRxQbZugh7iVKKnMPSF52O1hibTJosYRGFyM4ICpo8Yf\nn5E1tth8U9DKoCTXE3pKxiqfWXpJW5cFX2MZcVdo5GTqe9dvelwx93iAdmioJ3RZ\nb0FyxAbrdFq2jGEYvXtRAfJXs04jIpBoJ/0oJyllaZCH4pYM5icvdoQx6vPs53t7\nrzXp6dkn7WJjKlafzxTRso8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.serviziweb.unito.it/youblog/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.serviziweb.unito.it/youblog/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.serviziweb.unito.it/youblog/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.serviziweb.unito.it/youblog/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.serviziweb.unito.it/youblog/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.serviziweb.unito.it/youblog/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.serviziweb.unito.it/youblog/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.serviziweb.unito.it/youblog/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.serviziweb.unito.it/youblog/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.serviziweb.unito.it/youblog/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-16.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-16.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-16.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-16.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-16.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-16.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-16.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-16.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-16.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;16"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;16"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-16.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-16.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJALSkL+aFzM/DMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0xNi5sYWRvay51bXUuc2UwHhcNMTQwOTAxMTQ0NTI1WhcNMjQw\nODI5MTQ0NTI1WjAhMR8wHQYDVQQDExZsYWRvazMtMTYubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA3ZlgVsaBiDcOlZJbtFlpbJTm\nMd54vnLPBrDtXjC3YKMBzzH9kdrAYDn1mFOPT5PwT6OKhj2YzSwZFmTykXfjfHnA\n70/5SkvnLEAvTm7i5e7PID+Ztfu78drzW51UmzwN/mYGjIYP5EER9MxF+lCuBwG2\ndgbn1Q8nHLaem2a7FwjOV4q7OF7gjPhZYHHqVhQ0I2iZwDKC8ztgbHZQFk3OPHLi\n4bcpHfmGqMaC39QhPD4l38NncIHhxHif+IL/kQ95usRJH6ZfGXHRVQc4MYmpp0FY\npjBWysUZ3WtJrVpFr2hTubaB09rk9UH6oDSRHB1nAmHuBvLjkjG3+vMEltuTiQID\nAQABo2swaTBIBgNVHREEQTA/ghZsYWRvazMtMTYubGFkb2sudW11LnNlhiVodHRw\nczovL2xhZG9rMy0xNi5sYWRvay51bXUuc2UvZ3VpLXNwMB0GA1UdDgQWBBSQReqF\nXiaxoIZrbC9nn0zcxLFzSjANBgkqhkiG9w0BAQUFAAOCAQEAOoxsWXWL5Uqm5Q3i\n1e6Xh8YuowWALF6mqdhUgMnIothAfPZMs2iefWoqdoHwrCBBXFp1BTQ647c96UQ6\nO4MJTdQ7f0089D1cAMEjHm2jeeh3QTpX6BbNmuFVgSiWMXa8gX2h2/AIGTRTY/rP\n/pCQMgA1498bPLP9U+gkplAOAolDaaOpSx6chNECc00eoKrG7ydc2VQ+8YhFjFX0\nu0dHxSBu8YfA2PHV3jzvugpMgl7NePIvtcEJzb2lY12y7zDoEHDleGZNYwVtt0L6\nsT/mrrBnjohjKgWCDe/OgZ/52A6gezsRZ/8ZNLQJHZhUovn/NPX1OP4wbRx2hq3M\nLVruwg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-16.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-16.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-16.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-16.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-16.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-16.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-16.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-16.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-16.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-16.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://xenosmilus2.umdc.umu.se:8086/sp.xml",
    {
      "entity_id": "https://xenosmilus2.umdc.umu.se:8086/sp.xml",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://xenosmilus2.umdc.umu.se:8086/disco",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICIzCCAYwCCQDFqR2p3amCSjANBgkqhkiG9w0BAQUFADBWMQswCQYDVQQGEwJT\nRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UECgwDVW1VMQwwCgYDVQQLDANJVFMxHDAa\nBgNVBAMME2xpbmdvbi5sYWRvay51bXUuc2UwHhcNMTMwNjE0MTY1MjAyWhcNMTQw\nNjE0MTY1MjAyWjBWMQswCQYDVQQGEwJTRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UE\nCgwDVW1VMQwwCgYDVQQLDANJVFMxHDAaBgNVBAMME2xpbmdvbi5sYWRvay51bXUu\nc2UwgZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGBAM8nCb97J2QNi/U+4EnR2vL/\nvGtUM44dyOrdQ4xdD/feHyu0kWoNal/8CXJTYtDVrbKMg90fakPfw6Lw5KxQTzGl\nR6qNRyuuMq7KIgRzlbZEWiAh1YKQMOn+C3qIM0HqkfjD/rnCokIpFhGFi+7886AD\nVNB5CnUQXrSTAkUJzVS7AgMBAAEwDQYJKoZIhvcNAQEFBQADgYEABfQAzyDkwIQZ\nHu3tPi7QvJbdTDH8F3q8iSQwOT7MvxmHmCO/DZFwYu5jjYg/FtBfpbh8mQTziCy8\nFyVMuMKNSZn2rEIJF1ghgQqtHwn08zsPPhD9XW0LXeP6Exl/xIguWJElU9JzmPU6\naZOix3ahmr0PwcIhFbWaZvsjL46MdHI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICIzCCAYwCCQDFqR2p3amCSjANBgkqhkiG9w0BAQUFADBWMQswCQYDVQQGEwJT\nRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UECgwDVW1VMQwwCgYDVQQLDANJVFMxHDAa\nBgNVBAMME2xpbmdvbi5sYWRvay51bXUuc2UwHhcNMTMwNjE0MTY1MjAyWhcNMTQw\nNjE0MTY1MjAyWjBWMQswCQYDVQQGEwJTRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UE\nCgwDVW1VMQwwCgYDVQQLDANJVFMxHDAaBgNVBAMME2xpbmdvbi5sYWRvay51bXUu\nc2UwgZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGBAM8nCb97J2QNi/U+4EnR2vL/\nvGtUM44dyOrdQ4xdD/feHyu0kWoNal/8CXJTYtDVrbKMg90fakPfw6Lw5KxQTzGl\nR6qNRyuuMq7KIgRzlbZEWiAh1YKQMOn+C3qIM0HqkfjD/rnCokIpFhGFi+7886AD\nVNB5CnUQXrSTAkUJzVS7AgMBAAEwDQYJKoZIhvcNAQEFBQADgYEABfQAzyDkwIQZ\nHu3tPi7QvJbdTDH8F3q8iSQwOT7MvxmHmCO/DZFwYu5jjYg/FtBfpbh8mQTziCy8\nFyVMuMKNSZn2rEIJF1ghgQqtHwn08zsPPhD9XW0LXeP6Exl/xIguWJElU9JzmPU6\naZOix3ahmr0PwcIhFbWaZvsjL46MdHI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://xenosmilus2.umdc.umu.se:8086/acs/redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://xenosmilus2.umdc.umu.se:8086/acs/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://nordunet.tv/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://nordunet.tv/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nordunet.tv/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nordunet.tv/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nordunet.tv/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nordunet.tv/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "NORDUnet TV"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "NORDUnet Media Distribution Site"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nordunet.tv/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://nordunet.tv/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "nordunet.tv"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9TCCAd2gAwIBAgIJAJbH0STVcsEQMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC25vcmR1bmV0LnR2MB4XDTExMDUzMTE1NDg1NloXDTIxMDUyODE1NDg1Nlow\nFjEUMBIGA1UEAxMLbm9yZHVuZXQudHYwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQDgvw+Ecpy85/x9dFLRnI11QoYRx9eRC/H23k5ItE5g/HOinHkl7tT2\nKYhXE8orDVpvtj1edXppIE0C3XWkgltdJTvPOXxnfto2rQOx6h8lZHldFzNhlaD1\ngNNzrNLD/PqOJ4vGgqFogV7BAQFHBWz1hiU98xle7Jqa8/7rWj2V1T7ZcjkfaRhU\nq/4EoJg0UTy0NURQjhgD8pk4gw9PdUfnxWBeiukIFFIiRzPVy6E/DnMHO/Lj3UYU\nhlVK4CZJ1eMaDlqq2msAM2NXFEvfG7jd/XfCdx8ZSqKCRsa4o8pTOcbAW9cxhso8\nrC2gcjgeZypevNVxHzcepMMeCrbs1rblAgMBAAGjRjBEMCMGA1UdEQQcMBqCC25v\ncmR1bmV0LnR2hgtub3JkdW5ldC50djAdBgNVHQ4EFgQULkNNPNMu2YQkJwXc62KQ\ngVs9cTcwDQYJKoZIhvcNAQEFBQADggEBAEQw4jnSd7l+50jXx9lDY4Ffn9s2m69M\npdKjSUlCN/0+MFRzpZcgJcVSrivqiICeDOW1QHNJZLmiZXzOV4QHwrOGObCMCclo\n+lCmV0sLvZ/N9E5mAne/61kx251w1ub/aQJ5H2HV+wgcGMLyrJN+Fas3Z6D0WIwE\nln9IKS3JyKG+VBcpLWosX1jaSP6XFJe7kZ58SVbRnAoaGoIWh7tww13KsHkPEmU3\nUuGq63xCD7WDlXE0wpoWBE2dJUti1P4OovwFCUN4aqYT1c2y4wneVj/KTEWy8qKz\n000W3/HStrhj0L5kZNAkal6vzZ0Ux9n3V/9/ZoeSilM5ZiFD9whUQho="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=nordunet.tv"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "nordunet.tv"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9TCCAd2gAwIBAgIJAJbH0STVcsEQMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC25vcmR1bmV0LnR2MB4XDTExMDUzMTE1NDg1NloXDTIxMDUyODE1NDg1Nlow\nFjEUMBIGA1UEAxMLbm9yZHVuZXQudHYwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQDgvw+Ecpy85/x9dFLRnI11QoYRx9eRC/H23k5ItE5g/HOinHkl7tT2\nKYhXE8orDVpvtj1edXppIE0C3XWkgltdJTvPOXxnfto2rQOx6h8lZHldFzNhlaD1\ngNNzrNLD/PqOJ4vGgqFogV7BAQFHBWz1hiU98xle7Jqa8/7rWj2V1T7ZcjkfaRhU\nq/4EoJg0UTy0NURQjhgD8pk4gw9PdUfnxWBeiukIFFIiRzPVy6E/DnMHO/Lj3UYU\nhlVK4CZJ1eMaDlqq2msAM2NXFEvfG7jd/XfCdx8ZSqKCRsa4o8pTOcbAW9cxhso8\nrC2gcjgeZypevNVxHzcepMMeCrbs1rblAgMBAAGjRjBEMCMGA1UdEQQcMBqCC25v\ncmR1bmV0LnR2hgtub3JkdW5ldC50djAdBgNVHQ4EFgQULkNNPNMu2YQkJwXc62KQ\ngVs9cTcwDQYJKoZIhvcNAQEFBQADggEBAEQw4jnSd7l+50jXx9lDY4Ffn9s2m69M\npdKjSUlCN/0+MFRzpZcgJcVSrivqiICeDOW1QHNJZLmiZXzOV4QHwrOGObCMCclo\n+lCmV0sLvZ/N9E5mAne/61kx251w1ub/aQJ5H2HV+wgcGMLyrJN+Fas3Z6D0WIwE\nln9IKS3JyKG+VBcpLWosX1jaSP6XFJe7kZ58SVbRnAoaGoIWh7tww13KsHkPEmU3\nUuGq63xCD7WDlXE0wpoWBE2dJUti1P4OovwFCUN4aqYT1c2y4wneVj/KTEWy8qKz\n000W3/HStrhj0L5kZNAkal6vzZ0Ux9n3V/9/ZoeSilM5ZiFD9whUQho="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=nordunet.tv"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nordunet.tv/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nordunet.tv/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nordunet.tv/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nordunet.tv/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nordunet.tv/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://nordunet.tv/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nordunet.tv/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://nordunet.tv/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://nordunet.tv/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://nordunet.tv/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cafe.ifro.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Joilson Dantas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "suporte.reitoria@ifro.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.ifro.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICyjCCAbICAQAwDQYJKoZIhvcNAQEFBQAwKzENMAsGA1UECxMEREdUSTELMAkG\nA1UEBhMCQlIxDTALBgNVBAMTBGNhZmUwHhcNMTQwNzI0MTkxNzEwWhcNMTkwNzIz\nMTkxNzEwWjArMQ0wCwYDVQQLEwRER1RJMQswCQYDVQQGEwJCUjENMAsGA1UEAxME\nY2FmZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN6ZCm5rnhEwPjrr\nhJeWHqx+5Uj4/0xBuiU+7EIDJfkCWGAjmo3wyn7fnl9NkAsBzf+CKrWSOPEcgOS5\np2EPsP4XL+/AH24s86tdFN/5GNY9gYVv9HdgxHXX5CsS+35X1J3vtVMbyc40+UNp\nYgLlocluN+xyYYFgi4hjXo64YGgWfAEOVkpQaQftVJTd5B06PlfI3zRV+s4yD+1r\n1hcz9coOSmsE/fZX7QRJQ1imxm6w6xBj5xP95hw3knOZ4G7m7YzApEg8P0nak2fs\nEYYYOnMSKnKB2Ss9Y57hffnvvXsBScSP+u28mJB6eFz92WMyH7hrhyttR9mVn8pj\nv/pqK00CAwEAATANBgkqhkiG9w0BAQUFAAOCAQEATr5qM9J/dGnTA81HMB10gQ78\nV9o++8gwlRqjK+TEM5XdUqu1Fw6ela0etECzoaWQpuFbU2S3tkP0VrN5ONabgPGK\nlx9s8N+uY80QUzUaAIAePVA77dYaQK/nC+lRWtOSRig5ZfYW8nrbPkwe9YN/Z0Yl\na5oKJj745bgtCC4E8ymffGQNW45/cbLXGGkZ/uxUyHWUhBg4GVmCa1sjXTJDBzDN\niOLJsZO2Byu4nNTDHzRbtrIZDNsJ0M12sjEO2AVCOP4hXDoRFoZJtzCq+4q4f3lh\nzDUAzBmzpM9dLuP2WBQkKjZNg6PwOzmIF0JRBaGx4PaRAha3GWG91vo5zI+lVg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.ifro.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.ifro.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.ifro.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.ifro.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.ifro.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.ifro.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.ifro.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.ifro.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifro.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifro.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFRO - Instituto Federal de Rondonia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFRO - Instituto Federal de Rondonia"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFRO - Instituto Federal de Rondonia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFRO - Instituto Federal de Rondonia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICyjCCAbICAQAwDQYJKoZIhvcNAQEFBQAwKzENMAsGA1UECxMEREdUSTELMAkG\nA1UEBhMCQlIxDTALBgNVBAMTBGNhZmUwHhcNMTQwNzI0MTkxNzEwWhcNMTkwNzIz\nMTkxNzEwWjArMQ0wCwYDVQQLEwRER1RJMQswCQYDVQQGEwJCUjENMAsGA1UEAxME\nY2FmZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN6ZCm5rnhEwPjrr\nhJeWHqx+5Uj4/0xBuiU+7EIDJfkCWGAjmo3wyn7fnl9NkAsBzf+CKrWSOPEcgOS5\np2EPsP4XL+/AH24s86tdFN/5GNY9gYVv9HdgxHXX5CsS+35X1J3vtVMbyc40+UNp\nYgLlocluN+xyYYFgi4hjXo64YGgWfAEOVkpQaQftVJTd5B06PlfI3zRV+s4yD+1r\n1hcz9coOSmsE/fZX7QRJQ1imxm6w6xBj5xP95hw3knOZ4G7m7YzApEg8P0nak2fs\nEYYYOnMSKnKB2Ss9Y57hffnvvXsBScSP+u28mJB6eFz92WMyH7hrhyttR9mVn8pj\nv/pqK00CAwEAATANBgkqhkiG9w0BAQUFAAOCAQEATr5qM9J/dGnTA81HMB10gQ78\nV9o++8gwlRqjK+TEM5XdUqu1Fw6ela0etECzoaWQpuFbU2S3tkP0VrN5ONabgPGK\nlx9s8N+uY80QUzUaAIAePVA77dYaQK/nC+lRWtOSRig5ZfYW8nrbPkwe9YN/Z0Yl\na5oKJj745bgtCC4E8ymffGQNW45/cbLXGGkZ/uxUyHWUhBg4GVmCa1sjXTJDBzDN\niOLJsZO2Byu4nNTDHzRbtrIZDNsJ0M12sjEO2AVCOP4hXDoRFoZJtzCq+4q4f3lh\nzDUAzBmzpM9dLuP2WBQkKjZNg6PwOzmIF0JRBaGx4PaRAha3GWG91vo5zI+lVg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFRO - Instituto Federal de Rondonia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFRO - Instituto Federal de Rondonia"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifro.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifro.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFRO - Instituto Federal de Rondonia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFRO - Instituto Federal de Rondonia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.pima.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ejerue@pima.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Erik Jerue"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "krenshaw@pima.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kellen Renshaw"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cbonhorst@pima.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris Bonhorst"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mweber3@pima.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matt Weber"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://idp.pima.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.pima.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.pima.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.pima.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.pima.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.pima.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pima.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.pima.edu"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.pima.edu/privacy-policy/index.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Pima County Community College District"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAI8RApJaLNJSvMXpCrnt7hb5JMR2MA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDGlkcC5waW1hLmVkdTAeFw0xMzEyMTExNjE3MTFaFw0z\nMzEyMTExNjE3MTFaMBcxFTATBgNVBAMTDGlkcC5waW1hLmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAKaONUO2QeOvi5wklyGNDnrsp1rWU3SxoRK1\nFKCd2SUJXJnmanY3udbCtjEO+VKrhGkc/c+9QOwWGA2n7t9U5S/vvmJNCI1zu6q9\nJnr7osAnPYwSZ8Ee36HK4epL47vyLjqBC1psspkyBgKwe6h+Dk7QZXXMeClq6GuT\nDRCyEyr0uXgXxbZtvOHjMtNzSZHNPIgd8CTLhXS0K9+zS+67HRRueSfMpXNKtGhn\nxXlefCNZhJeUpMf58DxoGmqko6sy7n6Y2d7gdJUDuAO9Wu1ZDY1Ts4KPoyuFMHzF\nNyI+13RWDkDqPtDaxBNZJRaFPi1pPdW8zBYuQFXxBI5RiNyktbUCAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMaWRwLnBpbWEuZWR1hiNodHRwczovL2lkcC5waW1hLmVkdS9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU1NqJMb5Tjvls997bnBJR/IFIke4wDQYJ\nKoZIhvcNAQEFBQADggEBAAPJBOHUQ/toEICXbgm/6KOezWlpsj0wT9PtZCV00w01\n+/PIp41j6ChZOi5aznKyje1mXJ7zhs9LsohEJG5M6+2aaOb4DDG2H/WZB/yr4LKw\nt5zmwZkNEhDFpzYjlDAf8czEvAPFeO53kxILu42BEntqyEPqBH8L+8mifwcOiZTr\n1LUkjeG2iCrZ+4AepJuq60mNjdDp78bOnQPTraPsrwysIBO+D0IU70zbJdlTTjqa\nDNcSc3EJTHGKT8FTBZ4AhAqFSC7Y8szne3fNsoCZgy3JUCiYvFqkeZNXqRsWAfh4\n0Tv6+3GYpfV3wLPnSTqH/35dNRD3MJebUFZzPCZdc2E="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Pima County Community College District"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.pima.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Pima County Community College District"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.hs-emden-leer.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "van Loh"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nils.van.loh@hs-emden-leer.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nils"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "van Loh"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nils.van.loh@hs-emden-leer.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nils"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.hs-emden-leer.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2014-12-02T06:52:28Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.hs-emden-leer.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF8TCCBNmgAwIBAgIHF2YO9TQKfTANBgkqhkiG9w0BAQUFADB9MQswCQYDVQQG\nEwJERTEWMBQGA1UECBMNTmllZGVyc2FjaHNlbjEeMBwGA1UEChMVSG9jaHNjaHVs\nZSBFbWRlbi9MZWVyMREwDwYDVQQDEwhIUy1FTCBDQTEjMCEGCSqGSIb3DQEJARYU\ncGtpQGhzLWVtZGVuLWxlZXIuZGUwHhcNMTQwNDEwMTI0MTA5WhcNMTkwNDA5MTI0\nMTA5WjCBjDELMAkGA1UEBhMCREUxFjAUBgNVBAgTDU5pZWRlcnNhY2hzZW4xDjAM\nBgNVBAcTBUVtZGVuMR4wHAYDVQQKExVIb2Noc2NodWxlIEVtZGVuL0xlZXIxFjAU\nBgNVBAsTDVJlY2hlbnplbnRydW0xHTAbBgNVBAMTFGlkcC5ocy1lbWRlbi1sZWVy\nLmRlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2n62r7K8WT1SOEvK\nlLzfy6eWEmPlaxbiRNSzj9qhGyiG0MT3olJRbk1EYgRQnSskhP1J0fTs8jyRUHTg\n2hpTvQhCKM6hpYpR/syy71GZpxg5kB6XH5yiLq7w7smPhMPXKlvZU7gYdiTxXFud\nRbVt/Wp8uP0hLGMeJqD5lM3Gx1YR7RXt6+R82LhFDzDQJbwucFvCUA84xwRaKs46\nOokRvvttAswlZwW+nLCnIGHQQbeBb8LpvQu88tzrR3/2yOqf0s2SSUxXsoLNbZj9\nBhIL+A8ifijLkevQF6PXUTHIAgolzmJ+I9oYwYvZyY1/mCT713zSlF8+vJXN+wDR\nfB4dQQIDAQABo4ICZDCCAmAwOQYDVR0gBDIwMDARBg8rBgEEAYGtIYIsAQEEAwEw\nEQYPKwYBBAGBrSGCLAIBBAMBMAgGBmeBDAECAjAJBgNVHRMEAjAAMAsGA1UdDwQE\nAwIF4DAdBgNVHSUEFjAUBggrBgEFBQcDAgYIKwYBBQUHAwEwHQYDVR0OBBYEFHtH\nfymHYWiApAXIHeAn+oCZbeF5MB8GA1UdIwQYMBaAFLWOwZTIi3pZbkGKl9QbJ1kL\n0vLPMD4GA1UdEQQ3MDWCFGlkcC5ocy1lbWRlbi1sZWVyLmRlgR1uaWxzLnZhbi5s\nb2hAaHMtZW1kZW4tbGVlci5kZTCBjQYDVR0fBIGFMIGCMD+gPaA7hjlodHRwOi8v\nY2RwMS5wY2EuZGZuLmRlL2hzLWVtZGVuLWxlZXItY2EvcHViL2NybC9jYWNybC5j\ncmwwP6A9oDuGOWh0dHA6Ly9jZHAyLnBjYS5kZm4uZGUvaHMtZW1kZW4tbGVlci1j\nYS9wdWIvY3JsL2NhY3JsLmNybDCB2wYIKwYBBQUHAQEEgc4wgcswMwYIKwYBBQUH\nMAGGJ2h0dHA6Ly9vY3NwLnBjYS5kZm4uZGUvT0NTUC1TZXJ2ZXIvT0NTUDBJBggr\nBgEFBQcwAoY9aHR0cDovL2NkcDEucGNhLmRmbi5kZS9ocy1lbWRlbi1sZWVyLWNh\nL3B1Yi9jYWNlcnQvY2FjZXJ0LmNydDBJBggrBgEFBQcwAoY9aHR0cDovL2NkcDIu\ncGNhLmRmbi5kZS9ocy1lbWRlbi1sZWVyLWNhL3B1Yi9jYWNlcnQvY2FjZXJ0LmNy\ndDANBgkqhkiG9w0BAQUFAAOCAQEAWsMlRKRQratCL8EzmlbDeliEGym0a0feGbrh\nRQo8xi9CglyKERHs1cGO3TJuGWgcc7CiPRGA+EEsMWO1n4PHGIQGeTUQpCHqK8N7\nIW7P2e9zyM/meC598PoZxxQaIzT6bo90B07IEooplxASGF4voXkhEWH4fFUkKnp7\nyTPWiLOgIi1biiQXbGPjdeqb4MkrORRXsJTzKMj/RzxrSbFOHVG2dRXGkNDgJfFC\nKI6KoWF8UHUJ0CfutHB1PxWjIcbGGFTglnIcdQRo/N228uw++vAhj5+DdEG6JiQj\nIM1biUq8Xi0kRMiKUCmA6SItkZNrtAgav/JmjITPj8vFR7/JzQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.hs-emden-leer.de,OU=Rechenzentrum,O=Hochschule Emden/Leer,L=Emden,ST=Niedersachsen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hs-emden-leer.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.hs-emden-leer.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.hs-emden-leer.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.hs-emden-leer.de/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.hs-emden-leer.de/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.hs-emden-leer.de:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.hs-emden-leer.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.hs-emden-leer.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.hs-emden-leer.de/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.hs-emden-leer.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.hs-emden-leer.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.hs-emden-leer.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hs-emden-leer.de"
              },
              {
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IDP der Hochschule Emden/Leer"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IDP of the University of Applied Sciences Emden/Leer"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hochschule Emden/Leer"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Applied Sciences Emden/Leer"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.hs-emden-leer.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF8TCCBNmgAwIBAgIHF2YO9TQKfTANBgkqhkiG9w0BAQUFADB9MQswCQYDVQQG\nEwJERTEWMBQGA1UECBMNTmllZGVyc2FjaHNlbjEeMBwGA1UEChMVSG9jaHNjaHVs\nZSBFbWRlbi9MZWVyMREwDwYDVQQDEwhIUy1FTCBDQTEjMCEGCSqGSIb3DQEJARYU\ncGtpQGhzLWVtZGVuLWxlZXIuZGUwHhcNMTQwNDEwMTI0MTA5WhcNMTkwNDA5MTI0\nMTA5WjCBjDELMAkGA1UEBhMCREUxFjAUBgNVBAgTDU5pZWRlcnNhY2hzZW4xDjAM\nBgNVBAcTBUVtZGVuMR4wHAYDVQQKExVIb2Noc2NodWxlIEVtZGVuL0xlZXIxFjAU\nBgNVBAsTDVJlY2hlbnplbnRydW0xHTAbBgNVBAMTFGlkcC5ocy1lbWRlbi1sZWVy\nLmRlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2n62r7K8WT1SOEvK\nlLzfy6eWEmPlaxbiRNSzj9qhGyiG0MT3olJRbk1EYgRQnSskhP1J0fTs8jyRUHTg\n2hpTvQhCKM6hpYpR/syy71GZpxg5kB6XH5yiLq7w7smPhMPXKlvZU7gYdiTxXFud\nRbVt/Wp8uP0hLGMeJqD5lM3Gx1YR7RXt6+R82LhFDzDQJbwucFvCUA84xwRaKs46\nOokRvvttAswlZwW+nLCnIGHQQbeBb8LpvQu88tzrR3/2yOqf0s2SSUxXsoLNbZj9\nBhIL+A8ifijLkevQF6PXUTHIAgolzmJ+I9oYwYvZyY1/mCT713zSlF8+vJXN+wDR\nfB4dQQIDAQABo4ICZDCCAmAwOQYDVR0gBDIwMDARBg8rBgEEAYGtIYIsAQEEAwEw\nEQYPKwYBBAGBrSGCLAIBBAMBMAgGBmeBDAECAjAJBgNVHRMEAjAAMAsGA1UdDwQE\nAwIF4DAdBgNVHSUEFjAUBggrBgEFBQcDAgYIKwYBBQUHAwEwHQYDVR0OBBYEFHtH\nfymHYWiApAXIHeAn+oCZbeF5MB8GA1UdIwQYMBaAFLWOwZTIi3pZbkGKl9QbJ1kL\n0vLPMD4GA1UdEQQ3MDWCFGlkcC5ocy1lbWRlbi1sZWVyLmRlgR1uaWxzLnZhbi5s\nb2hAaHMtZW1kZW4tbGVlci5kZTCBjQYDVR0fBIGFMIGCMD+gPaA7hjlodHRwOi8v\nY2RwMS5wY2EuZGZuLmRlL2hzLWVtZGVuLWxlZXItY2EvcHViL2NybC9jYWNybC5j\ncmwwP6A9oDuGOWh0dHA6Ly9jZHAyLnBjYS5kZm4uZGUvaHMtZW1kZW4tbGVlci1j\nYS9wdWIvY3JsL2NhY3JsLmNybDCB2wYIKwYBBQUHAQEEgc4wgcswMwYIKwYBBQUH\nMAGGJ2h0dHA6Ly9vY3NwLnBjYS5kZm4uZGUvT0NTUC1TZXJ2ZXIvT0NTUDBJBggr\nBgEFBQcwAoY9aHR0cDovL2NkcDEucGNhLmRmbi5kZS9ocy1lbWRlbi1sZWVyLWNh\nL3B1Yi9jYWNlcnQvY2FjZXJ0LmNydDBJBggrBgEFBQcwAoY9aHR0cDovL2NkcDIu\ncGNhLmRmbi5kZS9ocy1lbWRlbi1sZWVyLWNhL3B1Yi9jYWNlcnQvY2FjZXJ0LmNy\ndDANBgkqhkiG9w0BAQUFAAOCAQEAWsMlRKRQratCL8EzmlbDeliEGym0a0feGbrh\nRQo8xi9CglyKERHs1cGO3TJuGWgcc7CiPRGA+EEsMWO1n4PHGIQGeTUQpCHqK8N7\nIW7P2e9zyM/meC598PoZxxQaIzT6bo90B07IEooplxASGF4voXkhEWH4fFUkKnp7\nyTPWiLOgIi1biiQXbGPjdeqb4MkrORRXsJTzKMj/RzxrSbFOHVG2dRXGkNDgJfFC\nKI6KoWF8UHUJ0CfutHB1PxWjIcbGGFTglnIcdQRo/N228uw++vAhj5+DdEG6JiQj\nIM1biUq8Xi0kRMiKUCmA6SItkZNrtAgav/JmjITPj8vFR7/JzQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.hs-emden-leer.de,OU=Rechenzentrum,O=Hochschule Emden/Leer,L=Emden,ST=Niedersachsen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hochschule Emden/Leer"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Applied Sciences Emden/Leer"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hs-emden-leer.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hs-emden-leer.de/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e391"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e391"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://aai-login.phsg.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@phsg.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "PHSG"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Keel"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:stefan.keel@phsg.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stefan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://aai-login.phsg.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2016-03-07T14:52:15Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVALNxp/wH2YQYb204i6svZSMm3LcrMA0GCSqGSIb3DQEB\nCwUAMBwxGjAYBgNVBAMMEWFhaS1sb2dpbi5waHNnLmNoMB4XDTE2MDExNTE0MDYz\nM1oXDTE5MDExNTE0MDYzM1owHDEaMBgGA1UEAwwRYWFpLWxvZ2luLnBoc2cuY2gw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCAmUJrpcGvUqqsq2/peAy6\nwjo2k8hC3biqtBAYlJTE82N5ans+w1fMhB6kREEOE4raWUz8WUjMXQjsxBSriYHm\nzqFG2uw3eniLk/5Glor5fDs7CRlYmmyq3A//ZKJ1vcjTtp2qEGF87fpjYgrMgaiv\nDSZjbPMjcTQODmxI2NWOsw/vqIlP0oMieMloAEK5tCRnEWqtud3yBtQoJlKnu3IE\nv1LQuGBI9tY/namgRS/Loy+zRwAe+ceRZBCfHmCsAKxKfhgZDraDiRAlrSHmA0zW\nN5udheceywg4CdqE280zPDvxyXdqjzMGexMhkKDX/q3mwoDeaGK9TKzQ5TE+wLQz\nAgMBAAGjaTBnMB0GA1UdDgQWBBScAKZ0mGe9eB8bIWY87N2evj5jITBGBgNVHREE\nPzA9ghFhYWktbG9naW4ucGhzZy5jaIYoaHR0cHM6Ly9hYWktbG9naW4ucGhzZy5j\naC9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAJr1m1HBjaunBDUuq\nOOiDkBPZ8xrDIuND+RBJtvKi/aHjnmh+alhsQkj/YbQGWpszE7icHUkf83mXnJHS\nYeoveySJ4VNVFY7y1k5HDo428EmIyM3cmK3oNE+CsvdkjVLdhjEUM32eD+3FqcMk\nF/9Tx9Nl6YkPjAS3eEx4dYvZ6O7cSVJ+wWW+1e3HPnoD2wsjR4nrSvTsepKknAcp\ngvjk1jpuIm1sim4/gx6GX69sAhhQgiocFAZSzV+zTZbHJekYsrIkplNHcmY3+swv\ncqS+TPtZ1IvWnlY+blGm4nFPgRUHTz/8opjx+HiAl5pccUMS06w5f3cL2f1dRoeP\ntKCbvw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "phsg.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-login.phsg.ch/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-login.phsg.ch/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aai-login.phsg.ch/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai-login.phsg.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai-login.phsg.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aai-login.phsg.ch/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-login.phsg.ch/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-login.phsg.ch/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "phsg.ch"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.phsg.ch"
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.phsg.ch"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "P\u00e4dagogische Hochschule St.Gallen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "P\u00e4dagogische Hochschule St.Gallen"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAxklEQVQ4EWP4//8/JxBPBuInQEwsAKltAWI2BiAxjVhdWNS1MwIFvzEwMHACMTngNciA/+TohOlhgTGIoTfdWMCw6eZCsFI/9XgGP40EBiYQr7SsAo5hBoHEYADGhmkGicPYYANAAt1dHWAMUwwSIwbg9QK6YSBnw2wGscEAFIglpeVwDOKDAEgMBpDZMDEYDXcByAvkAHgYkKMZpIfidECxC0AGfCfX+UB9L0AGLKDAgGWg3AjKznOA+C0saoigQWpnAjEnAIt5HRA+6LqUAAAAAElFTkSuQmCC",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PHSG - P\u00e4dagogische Hochschule St.Gallen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PHSG - P\u00e4dagogische Hochschule St.Gallen"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "phsg.ch"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.430364,9.382454"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.472613,9.494863"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.409875,9.252674"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.16.128/25"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.18.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "error_url": "https://helpdesk.phsg.ch",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVALNxp/wH2YQYb204i6svZSMm3LcrMA0GCSqGSIb3DQEB\nCwUAMBwxGjAYBgNVBAMMEWFhaS1sb2dpbi5waHNnLmNoMB4XDTE2MDExNTE0MDYz\nM1oXDTE5MDExNTE0MDYzM1owHDEaMBgGA1UEAwwRYWFpLWxvZ2luLnBoc2cuY2gw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCAmUJrpcGvUqqsq2/peAy6\nwjo2k8hC3biqtBAYlJTE82N5ans+w1fMhB6kREEOE4raWUz8WUjMXQjsxBSriYHm\nzqFG2uw3eniLk/5Glor5fDs7CRlYmmyq3A//ZKJ1vcjTtp2qEGF87fpjYgrMgaiv\nDSZjbPMjcTQODmxI2NWOsw/vqIlP0oMieMloAEK5tCRnEWqtud3yBtQoJlKnu3IE\nv1LQuGBI9tY/namgRS/Loy+zRwAe+ceRZBCfHmCsAKxKfhgZDraDiRAlrSHmA0zW\nN5udheceywg4CdqE280zPDvxyXdqjzMGexMhkKDX/q3mwoDeaGK9TKzQ5TE+wLQz\nAgMBAAGjaTBnMB0GA1UdDgQWBBScAKZ0mGe9eB8bIWY87N2evj5jITBGBgNVHREE\nPzA9ghFhYWktbG9naW4ucGhzZy5jaIYoaHR0cHM6Ly9hYWktbG9naW4ucGhzZy5j\naC9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAJr1m1HBjaunBDUuq\nOOiDkBPZ8xrDIuND+RBJtvKi/aHjnmh+alhsQkj/YbQGWpszE7icHUkf83mXnJHS\nYeoveySJ4VNVFY7y1k5HDo428EmIyM3cmK3oNE+CsvdkjVLdhjEUM32eD+3FqcMk\nF/9Tx9Nl6YkPjAS3eEx4dYvZ6O7cSVJ+wWW+1e3HPnoD2wsjR4nrSvTsepKknAcp\ngvjk1jpuIm1sim4/gx6GX69sAhhQgiocFAZSzV+zTZbHJekYsrIkplNHcmY3+swv\ncqS+TPtZ1IvWnlY+blGm4nFPgRUHTz/8opjx+HiAl5pccUMS06w5f3cL2f1dRoeP\ntKCbvw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PHSG - P\u00e4dagogische Hochschule St.Gallen"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PHSG - P\u00e4dagogische Hochschule St.Gallen"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.phsg.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.phsg.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "phsg.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://fsdev.iceruganda.org/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-support@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Technical Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-support@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-support@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Technical Support"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-support@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Administrative Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://fsdev.iceruganda.org/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "National Institutes of Health"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nih.gov/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National Institutes of Health"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://spdev.iceruganda.org/spinfo"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "NIAID ICER Microsoft Active Directory Federation Services (ADFS) deployment serving as the federated authentication gateway for a SharePoint 2013 deployment"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://spdev.iceruganda.org/spinfo/SitePages/PrivacyPolicy.aspx"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NIAID ICER SharePoint 2013 Authentication Gateway"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFaTCCA1GgAwIBAgIJAPlger1zZr9+MA0GCSqGSIb3DQEBDQUAMEsxHTAbBgNV\nBAMMFGZzZGV2LmljZXJ1Z2FuZGEub3JnMSowKAYJKoZIhvcNAQkBFhtpY2VyLXZy\nby1hZG1pbkBsaXN0Lm5paC5nb3YwHhcNMTYwMTExMTUzNjQxWhcNMjYwMTA4MTUz\nNjQxWjBLMR0wGwYDVQQDDBRmc2Rldi5pY2VydWdhbmRhLm9yZzEqMCgGCSqGSIb3\nDQEJARYbaWNlci12cm8tYWRtaW5AbGlzdC5uaWguZ292MIICIjANBgkqhkiG9w0B\nAQEFAAOCAg8AMIICCgKCAgEAup+KDPz0JbptGhqhXoo9A+/gHiGmYP3j5Fh/gz3i\nd+WrlZ+FJZj2XACUDUDBj3w3W91dODlbpjxXG2XJNS9IjxxnsczwN9agbLH7LcE/\nxD4ESDqGPXh7SijO3Y0jdE1p1zFk8GiesU+MqsnMnIwhxiqEf3xSRSFsSDLca1Ux\nDMqbBKxsaqlG4Vi2+wTsr1fm4MmzhydH5puLiNShEjCIQhQ4vJmZCnCzbZcg9MDF\nKlgmGWRGMz91r2P0eLO+nFtoNaptTJYihlZ0BXYF38UD9krcvYa8rxg1zSjpPuAy\nvZl3YGW3znCRTf0jWgZHAYwELI8hsCnUohsk2UHbMt3vK5Z7oo55DJ6Cp6QlMgo7\n2J8fttSJjlxnJjpn1TLWZBtWUYlkq8UhH4ilpNqItlDlG1+dN5v38QGL+NCWaonV\nwBDluF+bA7omvby2w2zNotAC7sJQ59PL8UjZ1PWnb0J6VUQ4DsToEYbRDXx+kqfj\n6QOXpMVC+iJBt4atV39rfg3w2SstJnkicfzPRylbh62LwyCbFKoouzyjdu7m9XNr\nkX1unAJer5vBb7uMvg4AnHYjCBde8ux6zNbPzYf4eV1S60ry+B+mac+/rwqU+oba\nYZUGt0x62eL/2GnSvtfcNeMhJDRCfxFd5W89ONskKmxz1qy2Iwy0f0wH4jGHyO37\nZf8CAwEAAaNQME4wHQYDVR0OBBYEFA2q+ih60u8+ypdjmuESOca5udUdMB8GA1Ud\nIwQYMBaAFA2q+ih60u8+ypdjmuESOca5udUdMAwGA1UdEwQFMAMBAf8wDQYJKoZI\nhvcNAQENBQADggIBAFWWZEbZ2EKUg6GlE2/4Blgub6hFpPIroQYV5/BOEfwoOMIs\nyB/sdEjPWikJj37sYTXU3aQvXSJDl03mcostT4e9S2c1b2WUefo+yT+gRo+jcS7T\nuHJnod8vntkOsYBAJI84K2wLPzXmvKwhCnyfj/tbxIDN4CgLeWJjooKVgg/R5Ez5\n6BHUpaS4rbDuIrVVLIMrKvpjd/eofwOMRCJO9YWWHwyRFzHc55AznUkkuoqQi0S7\nm6l7VioRkWRBSrB4BauK1zqsiZS+GBHfIBvqFzoOEszaeYfLklnoMWXAc81yrIIf\neUZyOHcxhihAkz2MdvqvKrlVkxz6qKcJcfyUM6byemFiSyu9+pugnKZSlHyMpHyw\nf7Os3Fy/8umEMNCSe+kAwiu7pUx3Rx0Fc+Q9spsix8FFzVZOZRlK2uU+TzmmL/GU\nQSVWXMcuaYoA2HfSOeF5ImmWqODnUjP/l6qTttNqUyacU/p+F5oYJO1iDA2BxvDo\nQI82s3X0kXo/yc+0S4a2SR1bS9MI4Zfr/TmnJqgqiiO4FzlSt154T90439OaaH0R\nPfMuuqb4C6Oph/TbgYvSXjOeFKlxwCpxtJT1dRL2zVpzCtrX/AntAoQNJz5yb8M9\n9TXNd/TjvHllKjl27Wo9VDjaPsIkErxtiCU9eKE2xkhkFgNdvQqlPVOqEiyO"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://fsdev.iceruganda.org/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "NIAID ICER SharePoint 2013 Authentication Gateway"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "NIAID ICER Microsoft Active Directory Federation Services (ADFS) deployment serving as the federated authentication gateway for a SharePoint 2013 deployment"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "http://federatie.trimbos.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://federatie.trimbos.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-04-15T20:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/54fc1218e61c75e7734f563802e8c467",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Trimbos Instituut"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Trimbos Instituut"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/trimbos.png",
                    "height": "34",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Trimbos Instituut"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Trimbos Instituut"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Trimbos Instituut"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.trimbos.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Trimbos Instituut"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.entpe.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Christian GARDET"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "christian.gardet@entpe.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.entpe.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-10-05T09:54:38Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.entpe.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.entpe.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.entpe.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "entpe.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "entpe.net"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.entpe.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENTPE - Vaulx en Velin"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENTPE - Vaulx en Velin"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAIcupykPhzWwN/P9ju7uKjH1/diEMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDGlkcC5lbnRwZS5mcjAeFw0xMjA4MzAxMzQyMzRaFw0z\nMjA4MzAxMzQyMzRaMBcxFTATBgNVBAMTDGlkcC5lbnRwZS5mcjCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAIBXq+m0dzCNCaWhUxNWKFezemlJDt+bxukb\na8mtA3V2EXQnENCt8YQUC64SdA3TWwdx8IJ/YRIpTqbX8WssBaNXU2ugWbFkaJ2P\n2LUIAXTycbU+j2XzM1eonxfeqn8qcIEN4Saz65OiHtXBamjm4Uc3H5ICCLJJb+yB\nB96JQeScJU39kQEL26dVIJuaW5kjRNEQa2kZW9r2Ovf1mfiRcyXZBvYss4HTM0jV\n8Jo5xULb3fQXE7+s9dox218g/ITBtYnGBa38Og6dDTurbjuhyJNA/xWq0fbQp6K1\nOVLR64FG6gi/UHkG7SQlA40Jeb7dbi5ehocyfOjvPO5AH0UiUXcCAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMaWRwLmVudHBlLmZyhiNodHRwczovL2lkcC5lbnRwZS5mci9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUX9y2zApvJ+zBx2GaVq+hWcrLdTowDQYJ\nKoZIhvcNAQEFBQADggEBAEq1KyPR75ZoWdwLXL/z/dn0SPYRAyhQQizq7Oy9kqTL\nV8VoisIXbe+J1kLrgNTz27n7ly1ulJWT/NZcdAL0xoX4tDpBZLs/eLIfhKHpcyhl\n3GzzFSiFOVjz1NlaVwElBfPf7A4SZqWHgVZkrmKVt0I5Ai6ZKrARayGdQi0cvC43\ngPjZyS2WLKKQr3zO5RYT+D3Z2Cx+0buIdDWpfOawV8cMAVxkub7uvjgnt8LRddDn\nhz5Ka52K32oCM/oo9XNZsXDL7uA83DKl//sRCrRmbrtp0G1xUXzZa+vCbQ2ndUSX\nBY7XFJgwUuyw39r64rK9lOkAjCZntHyPjx/sy8m020A="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ENTPE - Vaulx en Velin"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.entpe.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ENTPE - Vaulx en Velin"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.shu.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ithelp@shu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Help"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Turner"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:a.p.turner@shu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Moore"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:g.r.moore@shu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gavin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.shu.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEPjCCAyagAwIBAgIJANXnLNjnFdG5MA0GCSqGSIb3DQEBBQUAMIGfMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEYMBYGA1UECBMPU291dGggWW9ya3NoaXJlMRIwEAYDVQQHEwlTaGVm\n\t\t\t\t\t\tZmllbGQxJDAiBgNVBAoTG1NoZWZmaWVsZCBIYWxsYW0gVW5pdmVyc2l0eTEkMCIG\n\t\t\t\t\t\tA1UECxQbU3R1ZGVudCAmIExlYXJuaW5nIFNlcnZpY2VzMRYwFAYDVQQDEw1pZHAu\n\t\t\t\t\t\tc2h1LmFjLnVrMB4XDTEzMDQxNzEyMjgyMloXDTIzMDQxNTEyMjgyMlowgZ8xCzAJ\n\t\t\t\t\t\tBgNVBAYTAkdCMRgwFgYDVQQIEw9Tb3V0aCBZb3Jrc2hpcmUxEjAQBgNVBAcTCVNo\n\t\t\t\t\t\tZWZmaWVsZDEkMCIGA1UEChMbU2hlZmZpZWxkIEhhbGxhbSBVbml2ZXJzaXR5MSQw\n\t\t\t\t\t\tIgYDVQQLFBtTdHVkZW50ICYgTGVhcm5pbmcgU2VydmljZXMxFjAUBgNVBAMTDWlk\n\t\t\t\t\t\tcC5zaHUuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCuW416\n\t\t\t\t\t\tPl4npHeAmyrW3n2vFClbxTr9V2U78FNTSG3ZcI5L4Yq/6RiiU90o8gzgHKWljfio\n\t\t\t\t\t\tEkx361zSrch84AuE5WFDc+tjXY7LfcrnVS4Vq/uk1UBAip/rvnSjkvG7eQxwo+uw\n\t\t\t\t\t\tHbl1nsZd1g2+e3EIWOenVk+/1F4CaQi7oyx9lmVU1OqX1P8FjS9YE0KWh0cppzll\n\t\t\t\t\t\taYN67fm1ahVHL0DSAiW0/tsZqUTcMK6SuaiGyijYC1RSH/sJxlaR5wNvoKSfowr+\n\t\t\t\t\t\tYMKcD/IpYxDpyqXldPuNjZNkWEjffAPnphRZc27G0THOtdIxmQ75uveBUJHILivY\n\t\t\t\t\t\tAv2nZK57RHe5kLF3AgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8W\n\t\t\t\t\t\tHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBQ8AKwYB1Wj\n\t\t\t\t\t\tWw1YwE0CmgD64hNpaTAfBgNVHSMEGDAWgBQ8AKwYB1WjWw1YwE0CmgD64hNpaTAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAROO+SyHXrArH+14peCMWvIi2rf6FrKhbATmMNh3z\n\t\t\t\t\t\tff1pCCCdhCAAjDPgyLJkJRye4qwUZ0UswSfolowqbT1b6qyV3eka2y3inmVrWR65\n\t\t\t\t\t\to0B12LDsD2Xw1dlepsB87a/2AaXoMlWPr9ka3fH3bL//BiCleUbP9C+RMIlKmfw+\n\t\t\t\t\t\tHyCSmwmzwOGUe5LsfT9DNJ+0XnYmGIjsTVvhngrhUVwnqC6r7KaQYXbYnaeG05Zv\n\t\t\t\t\t\teW2XrAsGKATf6ILhGnVWK2tGOekfyb5qaa3rAlTiAxeXYvO7GVo1KDKIt7T/4RiD\n\t\t\t\t\t\tWFFlehGW+U5vzTOD62jQeVmq/gcPZqB5TkizAcYdMnzoWw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "shu.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.shu.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.shu.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.shu.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.shu.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.shu.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.shu.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.shu.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.shu.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "shu.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://extra.shu.ac.uk/ukfed/shu-logo.png",
                    "height": "43",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sheffield Hallam University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEPjCCAyagAwIBAgIJANXnLNjnFdG5MA0GCSqGSIb3DQEBBQUAMIGfMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEYMBYGA1UECBMPU291dGggWW9ya3NoaXJlMRIwEAYDVQQHEwlTaGVm\n\t\t\t\t\t\tZmllbGQxJDAiBgNVBAoTG1NoZWZmaWVsZCBIYWxsYW0gVW5pdmVyc2l0eTEkMCIG\n\t\t\t\t\t\tA1UECxQbU3R1ZGVudCAmIExlYXJuaW5nIFNlcnZpY2VzMRYwFAYDVQQDEw1pZHAu\n\t\t\t\t\t\tc2h1LmFjLnVrMB4XDTEzMDQxNzEyMjgyMloXDTIzMDQxNTEyMjgyMlowgZ8xCzAJ\n\t\t\t\t\t\tBgNVBAYTAkdCMRgwFgYDVQQIEw9Tb3V0aCBZb3Jrc2hpcmUxEjAQBgNVBAcTCVNo\n\t\t\t\t\t\tZWZmaWVsZDEkMCIGA1UEChMbU2hlZmZpZWxkIEhhbGxhbSBVbml2ZXJzaXR5MSQw\n\t\t\t\t\t\tIgYDVQQLFBtTdHVkZW50ICYgTGVhcm5pbmcgU2VydmljZXMxFjAUBgNVBAMTDWlk\n\t\t\t\t\t\tcC5zaHUuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCuW416\n\t\t\t\t\t\tPl4npHeAmyrW3n2vFClbxTr9V2U78FNTSG3ZcI5L4Yq/6RiiU90o8gzgHKWljfio\n\t\t\t\t\t\tEkx361zSrch84AuE5WFDc+tjXY7LfcrnVS4Vq/uk1UBAip/rvnSjkvG7eQxwo+uw\n\t\t\t\t\t\tHbl1nsZd1g2+e3EIWOenVk+/1F4CaQi7oyx9lmVU1OqX1P8FjS9YE0KWh0cppzll\n\t\t\t\t\t\taYN67fm1ahVHL0DSAiW0/tsZqUTcMK6SuaiGyijYC1RSH/sJxlaR5wNvoKSfowr+\n\t\t\t\t\t\tYMKcD/IpYxDpyqXldPuNjZNkWEjffAPnphRZc27G0THOtdIxmQ75uveBUJHILivY\n\t\t\t\t\t\tAv2nZK57RHe5kLF3AgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8W\n\t\t\t\t\t\tHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBQ8AKwYB1Wj\n\t\t\t\t\t\tWw1YwE0CmgD64hNpaTAfBgNVHSMEGDAWgBQ8AKwYB1WjWw1YwE0CmgD64hNpaTAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAROO+SyHXrArH+14peCMWvIi2rf6FrKhbATmMNh3z\n\t\t\t\t\t\tff1pCCCdhCAAjDPgyLJkJRye4qwUZ0UswSfolowqbT1b6qyV3eka2y3inmVrWR65\n\t\t\t\t\t\to0B12LDsD2Xw1dlepsB87a/2AaXoMlWPr9ka3fH3bL//BiCleUbP9C+RMIlKmfw+\n\t\t\t\t\t\tHyCSmwmzwOGUe5LsfT9DNJ+0XnYmGIjsTVvhngrhUVwnqC6r7KaQYXbYnaeG05Zv\n\t\t\t\t\t\teW2XrAsGKATf6ILhGnVWK2tGOekfyb5qaa3rAlTiAxeXYvO7GVo1KDKIt7T/4RiD\n\t\t\t\t\t\tWFFlehGW+U5vzTOD62jQeVmq/gcPZqB5TkizAcYdMnzoWw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Sheffield Hallam University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.shu.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Sheffield Hallam University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://aiwip.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Khazarchiev"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ruslan@aiwip.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ruslan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Khazarchiev"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ruslan@aiwip.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ruslan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://aiwip.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-11-02T10:40:29Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Aiwip"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://aiwip.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Aiwip Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aiwip.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aiwip.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aiwip.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://aiwip.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aiwip.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://aiwip.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Free printing for University students"
                  }
                ],
                "logo": [
                  {
                    "text": "https://aiwip.com/static/images/logo2-dark.png",
                    "height": "135",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "90"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Aiwip"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDijCCAnKgAwIBAgIJALiUPWnEh4GGMA0GCSqGSIb3DQEBCwUAMEYxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMQ8wDQYDVQQIDAZMb25kb24xEjAQBgNVBAoMCUFpd2lwIEx0ZDESMBAG\n\t\t\t\t\t\tA1UEAwwJYWl3aXAuY29tMB4XDTE1MDkxMTE1MTMyNVoXDTI1MDkwODE1MTMyNVow\n\t\t\t\t\t\tRjELMAkGA1UEBhMCR0IxDzANBgNVBAgMBkxvbmRvbjESMBAGA1UECgwJQWl3aXAg\n\t\t\t\t\t\tTHRkMRIwEAYDVQQDDAlhaXdpcC5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQDW6jJEpL8vmaLnf8npBWtft8THcVkhJSGWyHkKlRxIKeiXc3PeN+O0\n\t\t\t\t\t\tuxqaLq4D+ffRm2uXxtDF8bkpCmrqMujAMgUdYxpXh3La9OOHjirY3f4XnA0+lEoe\n\t\t\t\t\t\txN0v8n9eHdf8pGXxCRR9q1VR9izbo8yRexxMlAk6WnRRYIKTaDFRAEhqIgeto+qd\n\t\t\t\t\t\t8rxlzaAIQY6c82wfYoVEUfLcZa09Beo0UxOp8drpCQx4ognawlg1Lt7nXuSagXIq\n\t\t\t\t\t\tvxXpWb5Gs3M1dDIuVjtVh3SYL2LXlC5g//ZBU/0TadR68MadZxRFlWf7piV/AjBJ\n\t\t\t\t\t\t8pI5DGn29F0ENYIol7xxDfmK8qxVlsUZAgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJ\n\t\t\t\t\t\tYIZIAYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1Ud\n\t\t\t\t\t\tDgQWBBT4McZ381AJbH3wftoeRd+VmqqA6TAfBgNVHSMEGDAWgBT4McZ381AJbH3w\n\t\t\t\t\t\tftoeRd+VmqqA6TANBgkqhkiG9w0BAQsFAAOCAQEARUzxoddJ5qQm2u+pvw6xcaNM\n\t\t\t\t\t\t2/cXhVLuSnIDtxZr+xlo3oHbwdIyk5uOiK7ekH8JmPAbs0sUpuk6K4WXIFK+wRlF\n\t\t\t\t\t\tfwsZ2MRujTbtg3ttpI4xMVgvO6s2vSAzoy0ibuRos0Mfokmsd9Z22N//jeJrzdQx\n\t\t\t\t\t\tPmhaExV64i5NSTAMulG7j7MsF08Rv1lylG3ZbaVOVCMctweQaUysiLwHPvlX6VU1\n\t\t\t\t\t\tqgXfL+JQhd70ZZyylbpqEbfl0JlZz/bGOYuF5meBhfy3BDj8zYjPZycwEuSZ+slY\n\t\t\t\t\t\tyb9mD1eP67TQAaShznHlfwmsTquWKUVdCwSUAd+oYzFj1w9lebTT4awLFP7EpQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aiwip.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aiwip.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://aiwip.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://aiwip.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://aiwip.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://aiwip.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.silverchair.com/spie/staging/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:technicaloperations@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:technicaloperations@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Operations"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.silverchair.com/spie/staging/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-07-19T09:42:09Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Silverchair Staging: SPIE Digital Library"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://spiedigitallibrary.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Silverchair Science + Communications, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://spierc.silverchair.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://spierc.silverchair.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://spierc.silverchair.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://spierc.silverchair.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://spierc.silverchair.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://spierc.silverchair.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJANpeel3qLSr0MA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\n\t\t\t\t\t\tBAMTFnNwaWVyYy5zaWx2ZXJjaGFpci5jb20wHhcNMTUwNjEwMTQ0NTI5WhcNMjUw\n\t\t\t\t\t\tNjA3MTQ0NTI5WjAhMR8wHQYDVQQDExZzcGllcmMuc2lsdmVyY2hhaXIuY29tMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAt4+KRwTSRzRPPSFZShN3H30F\n\t\t\t\t\t\tciOzYa3qrl8ipBIeEQtV8K9wAeydT+o2FwWiPLEKamv6R7oit98dCnzWLDrgIDnA\n\t\t\t\t\t\twVnYGX27QbkNJsTJbXeQpJh3dkrPq+jlp3cZM6XQ0bUsJh76JqOzhJDUzmyZ4FMR\n\t\t\t\t\t\taWvAm0sBcprSf5nxiOPH2VzCyun/C1EIK2gU9CrUxFTIfKptEPrkuGFXh5xSOn4y\n\t\t\t\t\t\t9/68TPv/SE0XsPwEBCdqZ/EpbOuaJDZ2EzOe1c9fxpKtR7CuGMx71haY85/6knbZ\n\t\t\t\t\t\tHwIeHA03MkHxE6ZQUNjnusDdZWaany+hGLK/CkK2IIyotfZ2IsPcPIaCUxCFQQID\n\t\t\t\t\t\tAQABo0QwQjAhBgNVHREEGjAYghZzcGllcmMuc2lsdmVyY2hhaXIuY29tMB0GA1Ud\n\t\t\t\t\t\tDgQWBBTSNV95kaVHM+na7Z+piM/kAwguvzANBgkqhkiG9w0BAQUFAAOCAQEAMy9J\n\t\t\t\t\t\t71MkiFqNmDkx0qyZTfw8LZf3n7hZQzk9+/oC7+UOMr2gRQov8Gr78SYygJJQj+Ga\n\t\t\t\t\t\t50T+6qn/iutj7yiW2fFE6ODzTFWwx9NmsRaPEK59asVuvzGLIZFiT1izkZZs8rJB\n\t\t\t\t\t\t5kdJ3uAQgF2L+HETUGLVI7Qq2fcNfOVVkewlsadhCxScCYg0FbN4Xxk4RDdjxS2Y\n\t\t\t\t\t\tXL1JpLRQV3Uh1mO4W/nFIKedVJBxlCXMHX0uRx1kEq0xUHDGZvADeJh5DGTDy0Sm\n\t\t\t\t\t\tlwBvLW3jYxApTijN0OtJY5T+FrCKi0GHAmxfXJHhgOvd3UbnhjSx7aPiIkMY6TIE\n\t\t\t\t\t\ttDq3WK+nizIMVNDEcg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://spierc.silverchair.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://spierc.silverchair.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://spierc.silverchair.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://spierc.silverchair.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://spierc.silverchair.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://spierc.silverchair.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.reigate.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Farbrother"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ash.farbrother@reigate.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ash"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Freeman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Michael.Freeman@reigate.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.reigate.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-09-29T13:32:19Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAPBD4Ch8c1eFKJwVl1SVemY1lNWFMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBwxGjAYBgNVBAMMEWlkcC5yZWlnYXRlLmFjLnVrMB4XDTE1MDkwMzEyNDQz\n\t\t\t\t\t\tNFoXDTM1MDkwMzEyNDQzNFowHDEaMBgGA1UEAwwRaWRwLnJlaWdhdGUuYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCMM/KcdoK3m7gK8nwGwsfX\n\t\t\t\t\t\tJaysjFdGnrj/SMrQJu8VTZ8Xw+SOegbBfi8TBuMSujixsjzHMYCUx4o3wmbGf9Oh\n\t\t\t\t\t\t8Cl9e0cwKiyjx/qOvG2iGJ3jVitx0UCkaBUhn7U7FXo9HfpO4WB3ag4Slnc1DazW\n\t\t\t\t\t\tckINoM0bWEKETOCIyEx6his4La5yaPHk0AknVj3xZUjkRF5N81pCy0O4T1Nb1ULS\n\t\t\t\t\t\tU23rl1j+qczQXGXOp1nZuR9BBpG2K6NUF0A6AorvwSJPhTWLeK7YTbBvoT3DR+l0\n\t\t\t\t\t\tQyXR4WoZ2jCtepZLXFyY7zJ3V+tAxnMx+rhJKJfRVKCFPvhOqNovDNUevC8JgiY3\n\t\t\t\t\t\tAgMBAAGjaTBnMB0GA1UdDgQWBBSbm+055qnFRYimNDAt+YhvstqF1TBGBgNVHREE\n\t\t\t\t\t\tPzA9ghFpZHAucmVpZ2F0ZS5hYy51a4YoaHR0cHM6Ly9pZHAucmVpZ2F0ZS5hYy51\n\t\t\t\t\t\tay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAFF6DG0eNff8fase4\n\t\t\t\t\t\tYF+Dub2nrJ717scQpdMPKaYZC0Y4EMKNTJnTaWsJ3aIBo1DxzydKlQi2RkZBqGZn\n\t\t\t\t\t\tQp1wqL6uHanv9VuquxdOj3hFItEssRi0uvISrSVDsu+9zaDA4W5FYKY+cOs+qAo1\n\t\t\t\t\t\tgpqHPqswkE7RCXdWZ0NLKQrxEubAACrGDX9E5kbrlxTZAgHTzDd2UWR2E7kD9Bxt\n\t\t\t\t\t\t3KGq84XhTKd5VOEWf2NfewGDKssWEko673Kgt70inVCuEb9t1BMcv1PV2HNws8bR\n\t\t\t\t\t\tzUyyzg1bGcmlKawqZ+Yoegt2JNa9yhAsUfvv909vTYw6Uw0LzzEmjZFMc40W3R9c\n\t\t\t\t\t\tYrbmYw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "reigate.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.reigate.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.reigate.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.reigate.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.reigate.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.reigate.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.reigate.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.reigate.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.reigate.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.reigate.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.reigate.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.reigate.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "reigate.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAPBD4Ch8c1eFKJwVl1SVemY1lNWFMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBwxGjAYBgNVBAMMEWlkcC5yZWlnYXRlLmFjLnVrMB4XDTE1MDkwMzEyNDQz\n\t\t\t\t\t\tNFoXDTM1MDkwMzEyNDQzNFowHDEaMBgGA1UEAwwRaWRwLnJlaWdhdGUuYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCMM/KcdoK3m7gK8nwGwsfX\n\t\t\t\t\t\tJaysjFdGnrj/SMrQJu8VTZ8Xw+SOegbBfi8TBuMSujixsjzHMYCUx4o3wmbGf9Oh\n\t\t\t\t\t\t8Cl9e0cwKiyjx/qOvG2iGJ3jVitx0UCkaBUhn7U7FXo9HfpO4WB3ag4Slnc1DazW\n\t\t\t\t\t\tckINoM0bWEKETOCIyEx6his4La5yaPHk0AknVj3xZUjkRF5N81pCy0O4T1Nb1ULS\n\t\t\t\t\t\tU23rl1j+qczQXGXOp1nZuR9BBpG2K6NUF0A6AorvwSJPhTWLeK7YTbBvoT3DR+l0\n\t\t\t\t\t\tQyXR4WoZ2jCtepZLXFyY7zJ3V+tAxnMx+rhJKJfRVKCFPvhOqNovDNUevC8JgiY3\n\t\t\t\t\t\tAgMBAAGjaTBnMB0GA1UdDgQWBBSbm+055qnFRYimNDAt+YhvstqF1TBGBgNVHREE\n\t\t\t\t\t\tPzA9ghFpZHAucmVpZ2F0ZS5hYy51a4YoaHR0cHM6Ly9pZHAucmVpZ2F0ZS5hYy51\n\t\t\t\t\t\tay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAFF6DG0eNff8fase4\n\t\t\t\t\t\tYF+Dub2nrJ717scQpdMPKaYZC0Y4EMKNTJnTaWsJ3aIBo1DxzydKlQi2RkZBqGZn\n\t\t\t\t\t\tQp1wqL6uHanv9VuquxdOj3hFItEssRi0uvISrSVDsu+9zaDA4W5FYKY+cOs+qAo1\n\t\t\t\t\t\tgpqHPqswkE7RCXdWZ0NLKQrxEubAACrGDX9E5kbrlxTZAgHTzDd2UWR2E7kD9Bxt\n\t\t\t\t\t\t3KGq84XhTKd5VOEWf2NfewGDKssWEko673Kgt70inVCuEb9t1BMcv1PV2HNws8bR\n\t\t\t\t\t\tzUyyzg1bGcmlKawqZ+Yoegt2JNa9yhAsUfvv909vTYw6Uw0LzzEmjZFMc40W3R9c\n\t\t\t\t\t\tYrbmYw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Reigate College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.reigate.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Reigate College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.nwkcollege.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Parker"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:darrenparker@nwkcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Darren"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Playfoot"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:barbplayfoot@nwkcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Barb"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.nwkcollege.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-01-25T12:01:59Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNjCCAh4CCQCyyXWzJHWtUDANBgkqhkiG9w0BAQUFADBdMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjENMAsGA1UECBMES2VudDEgMB4GA1UEChMXTm9ydGggV2VzdCBLZW50IENvbGxl\n\t\t\t\t\t\tZ2UxHTAbBgNVBAMTFGlkcC5ud2tjb2xsZWdlLmFjLnVrMB4XDTEyMTIxMTExNDgx\n\t\t\t\t\t\tNVoXDTIyMTIwOTExNDgxNVowXTELMAkGA1UEBhMCR0IxDTALBgNVBAgTBEtlbnQx\n\t\t\t\t\t\tIDAeBgNVBAoTF05vcnRoIFdlc3QgS2VudCBDb2xsZWdlMR0wGwYDVQQDExRpZHAu\n\t\t\t\t\t\tbndrY29sbGVnZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAPSswRYhQiGvi0f6QdjpgZq89Y68roiF8SxRL+MQWCTfoyuKff7cgy35BeXi6NrK\n\t\t\t\t\t\tzVAEWd96DACayN85bzMnby4Si1ntiCpyrRGDFxAoCLQFle2kiAn+n3RLnn/kiuw8\n\t\t\t\t\t\tMDIplFabdcJf83IQy+TKZgTScqKwfwEaZgsOyMkp006BztmkzYKs0XdLZZW6FAWb\n\t\t\t\t\t\t+9MWMMNVNwtDZkqJoUTgOlItJYzeukXA5TSNJG/oX3vGpldI+/2GwJEPZQS36qXn\n\t\t\t\t\t\tt6C+G9TRMHbqO6F2jHdG7xPNeqU5sjlpcd0NJ3TRRYPdMd5iiSBvBdQ4TZxybekE\n\t\t\t\t\t\tiALOike2BHXM21D85pWkr9UCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAYMRQDoWE\n\t\t\t\t\t\tB/h1NI6oa1FOoY3051eaULcGqPGNm846pdxEU17z6N3YqRWpjh8kEcYxZwPu78Vg\n\t\t\t\t\t\tDkUKBmV9CZMxNtpjyOKWm7aXUlpcaqyuc+2QpDZYff/y0r2wMnmCQz/GEzUpCehT\n\t\t\t\t\t\t7DJBgdVLO1d7d2Yl90VoOPxKnhIUY/ZdkHue1NYczwzBoei2id8k3id97mist8yU\n\t\t\t\t\t\tT8+gGlFBbA9YRd4tbmmyTxQZkm2dFECh4/PdSy9Yd9mmgGUt1f7fUlJdz+mNGPJu\n\t\t\t\t\t\tW/0kRLt8mAFvSYVo5hAsObBzrtFNrRCDSGSRycRuLHLsSPIaL8FuuIGlpjfFpYzt\n\t\t\t\t\t\tG9+M5fDBQwR/lA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nwkcollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.nwkcollege.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nwkcollege.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.nwkcollege.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.nwkcollege.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.nwkcollege.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.nwkcollege.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.nwkcollege.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nwkcollege.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nwkcollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNjCCAh4CCQCyyXWzJHWtUDANBgkqhkiG9w0BAQUFADBdMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjENMAsGA1UECBMES2VudDEgMB4GA1UEChMXTm9ydGggV2VzdCBLZW50IENvbGxl\n\t\t\t\t\t\tZ2UxHTAbBgNVBAMTFGlkcC5ud2tjb2xsZWdlLmFjLnVrMB4XDTEyMTIxMTExNDgx\n\t\t\t\t\t\tNVoXDTIyMTIwOTExNDgxNVowXTELMAkGA1UEBhMCR0IxDTALBgNVBAgTBEtlbnQx\n\t\t\t\t\t\tIDAeBgNVBAoTF05vcnRoIFdlc3QgS2VudCBDb2xsZWdlMR0wGwYDVQQDExRpZHAu\n\t\t\t\t\t\tbndrY29sbGVnZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAPSswRYhQiGvi0f6QdjpgZq89Y68roiF8SxRL+MQWCTfoyuKff7cgy35BeXi6NrK\n\t\t\t\t\t\tzVAEWd96DACayN85bzMnby4Si1ntiCpyrRGDFxAoCLQFle2kiAn+n3RLnn/kiuw8\n\t\t\t\t\t\tMDIplFabdcJf83IQy+TKZgTScqKwfwEaZgsOyMkp006BztmkzYKs0XdLZZW6FAWb\n\t\t\t\t\t\t+9MWMMNVNwtDZkqJoUTgOlItJYzeukXA5TSNJG/oX3vGpldI+/2GwJEPZQS36qXn\n\t\t\t\t\t\tt6C+G9TRMHbqO6F2jHdG7xPNeqU5sjlpcd0NJ3TRRYPdMd5iiSBvBdQ4TZxybekE\n\t\t\t\t\t\tiALOike2BHXM21D85pWkr9UCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAYMRQDoWE\n\t\t\t\t\t\tB/h1NI6oa1FOoY3051eaULcGqPGNm846pdxEU17z6N3YqRWpjh8kEcYxZwPu78Vg\n\t\t\t\t\t\tDkUKBmV9CZMxNtpjyOKWm7aXUlpcaqyuc+2QpDZYff/y0r2wMnmCQz/GEzUpCehT\n\t\t\t\t\t\t7DJBgdVLO1d7d2Yl90VoOPxKnhIUY/ZdkHue1NYczwzBoei2id8k3id97mist8yU\n\t\t\t\t\t\tT8+gGlFBbA9YRd4tbmmyTxQZkm2dFECh4/PdSy9Yd9mmgGUt1f7fUlJdz+mNGPJu\n\t\t\t\t\t\tW/0kRLt8mAFvSYVo5hAsObBzrtFNrRCDSGSRycRuLHLsSPIaL8FuuIGlpjfFpYzt\n\t\t\t\t\t\tG9+M5fDBQwR/lA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "North West Kent College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nwkcollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "North West Kent College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.cityofbristol.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it.helpdesk@cityofbristol.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Simpkins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dale.simpkins@cityofbristol.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dale"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cityofbristol.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEZjCCA06gAwIBAgIJAI1toHyODheqMA0GCSqGSIb3DQEBBQUAMIGzMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEQMA4GA1UECBMHQnJpc3RvbDEQMA4GA1UEBxMHQnJpc3RvbDEgMB4G\n\t\t\t\t\t\tA1UEChMXQ2l0eSBvZiBCcmlzdG9sIENvbGxlZ2UxDDAKBgNVBAsTA0lDVDEgMB4G\n\t\t\t\t\t\tA1UEAxMXaWRwLmNpdHlvZmJyaXN0b2wuYWMudWsxLjAsBgkqhkiG9w0BCQEWH2l0\n\t\t\t\t\t\tLmhlbHBkZXNrQGNpdHlvZmJyaXN0b2wuYWMudWswHhcNMTMwOTA5MTQyMTA2WhcN\n\t\t\t\t\t\tMjMwOTA3MTQyMTA2WjCBszELMAkGA1UEBhMCR0IxEDAOBgNVBAgTB0JyaXN0b2wx\n\t\t\t\t\t\tEDAOBgNVBAcTB0JyaXN0b2wxIDAeBgNVBAoTF0NpdHkgb2YgQnJpc3RvbCBDb2xs\n\t\t\t\t\t\tZWdlMQwwCgYDVQQLEwNJQ1QxIDAeBgNVBAMTF2lkcC5jaXR5b2ZicmlzdG9sLmFj\n\t\t\t\t\t\tLnVrMS4wLAYJKoZIhvcNAQkBFh9pdC5oZWxwZGVza0BjaXR5b2ZicmlzdG9sLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxEl6P5t+xyRzY0Wa\n\t\t\t\t\t\tbd/a2MC83Kxrc97VfUi3fMh2+FPQ/Dgu7o7KwTL+HhC7cQNJUHyTRUMV43TrIRPs\n\t\t\t\t\t\tLjHtCzVi0XYQSBE88p77aVX7K/OEcrxkKdQ/pIAafw9pXeSc1FAu48npCypP6w3b\n\t\t\t\t\t\t4cFRd0SzbYHGThMBDVoSqraK6c2lB1g2z4f0q4IP6RmM3/5UCqO2vw4wKNLfvfVV\n\t\t\t\t\t\ttC9fu+UHv1hMvBjb0JLpRNQk/RWQSIXJmAycpzAzbnUJnEtief8xktMbcsWRrJL4\n\t\t\t\t\t\tT0xeFFlfH6vf3MMaJ2IvRuIqr5yf/RqACda27qKxuxND3TXb2ZFBYv9p8ECxWmda\n\t\t\t\t\t\t0GnIdQIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NM\n\t\t\t\t\t\tIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUzvFe/y/teU8C+1OsLgTj\n\t\t\t\t\t\tkDxpTrgwHwYDVR0jBBgwFoAUzvFe/y/teU8C+1OsLgTjkDxpTrgwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAK0jlGscDnh+m84UTJ364uJ5tzDQaaVQ+OhjQBGQV9m2uRj4t2EU\n\t\t\t\t\t\t/Exc05LVgRK14pBWwlJ6EaJm7y5PUOQRD7PiCTq3nIEObvbg7X+8/Cj3KHrquSBE\n\t\t\t\t\t\tWw9GQ/d4MSbRMJISEkaCy4onoTlg4ulzzkSChpqJeRyk+acUCVYcfZxW2aHcAdFm\n\t\t\t\t\t\tpPyEOMOQGHUDtD+9c1fb2ICmcVs6vHM05QXaXzAP5wS66+Z2L3wI0RPHJji8RMzT\n\t\t\t\t\t\tRcBdINvWCrZHyLLxIqCpE9U95kY1JYsxLuVpkwTlf25VZIhAO0aTu0RI9Waq+DIm\n\t\t\t\t\t\tFn2vK00uJvNRLNZs0Cjgz4ZWOQzJHWQt0Tk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cityofbristol.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cityofbristol.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cityofbristol.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.cityofbristol.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cityofbristol.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.cityofbristol.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cityofbristol.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cityofbristol.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cityofbristol.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cityofbristol.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEZjCCA06gAwIBAgIJAI1toHyODheqMA0GCSqGSIb3DQEBBQUAMIGzMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEQMA4GA1UECBMHQnJpc3RvbDEQMA4GA1UEBxMHQnJpc3RvbDEgMB4G\n\t\t\t\t\t\tA1UEChMXQ2l0eSBvZiBCcmlzdG9sIENvbGxlZ2UxDDAKBgNVBAsTA0lDVDEgMB4G\n\t\t\t\t\t\tA1UEAxMXaWRwLmNpdHlvZmJyaXN0b2wuYWMudWsxLjAsBgkqhkiG9w0BCQEWH2l0\n\t\t\t\t\t\tLmhlbHBkZXNrQGNpdHlvZmJyaXN0b2wuYWMudWswHhcNMTMwOTA5MTQyMTA2WhcN\n\t\t\t\t\t\tMjMwOTA3MTQyMTA2WjCBszELMAkGA1UEBhMCR0IxEDAOBgNVBAgTB0JyaXN0b2wx\n\t\t\t\t\t\tEDAOBgNVBAcTB0JyaXN0b2wxIDAeBgNVBAoTF0NpdHkgb2YgQnJpc3RvbCBDb2xs\n\t\t\t\t\t\tZWdlMQwwCgYDVQQLEwNJQ1QxIDAeBgNVBAMTF2lkcC5jaXR5b2ZicmlzdG9sLmFj\n\t\t\t\t\t\tLnVrMS4wLAYJKoZIhvcNAQkBFh9pdC5oZWxwZGVza0BjaXR5b2ZicmlzdG9sLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxEl6P5t+xyRzY0Wa\n\t\t\t\t\t\tbd/a2MC83Kxrc97VfUi3fMh2+FPQ/Dgu7o7KwTL+HhC7cQNJUHyTRUMV43TrIRPs\n\t\t\t\t\t\tLjHtCzVi0XYQSBE88p77aVX7K/OEcrxkKdQ/pIAafw9pXeSc1FAu48npCypP6w3b\n\t\t\t\t\t\t4cFRd0SzbYHGThMBDVoSqraK6c2lB1g2z4f0q4IP6RmM3/5UCqO2vw4wKNLfvfVV\n\t\t\t\t\t\ttC9fu+UHv1hMvBjb0JLpRNQk/RWQSIXJmAycpzAzbnUJnEtief8xktMbcsWRrJL4\n\t\t\t\t\t\tT0xeFFlfH6vf3MMaJ2IvRuIqr5yf/RqACda27qKxuxND3TXb2ZFBYv9p8ECxWmda\n\t\t\t\t\t\t0GnIdQIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NM\n\t\t\t\t\t\tIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUzvFe/y/teU8C+1OsLgTj\n\t\t\t\t\t\tkDxpTrgwHwYDVR0jBBgwFoAUzvFe/y/teU8C+1OsLgTjkDxpTrgwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAK0jlGscDnh+m84UTJ364uJ5tzDQaaVQ+OhjQBGQV9m2uRj4t2EU\n\t\t\t\t\t\t/Exc05LVgRK14pBWwlJ6EaJm7y5PUOQRD7PiCTq3nIEObvbg7X+8/Cj3KHrquSBE\n\t\t\t\t\t\tWw9GQ/d4MSbRMJISEkaCy4onoTlg4ulzzkSChpqJeRyk+acUCVYcfZxW2aHcAdFm\n\t\t\t\t\t\tpPyEOMOQGHUDtD+9c1fb2ICmcVs6vHM05QXaXzAP5wS66+Z2L3wI0RPHJji8RMzT\n\t\t\t\t\t\tRcBdINvWCrZHyLLxIqCpE9U95kY1JYsxLuVpkwTlf25VZIhAO0aTu0RI9Waq+DIm\n\t\t\t\t\t\tFn2vK00uJvNRLNZs0Cjgz4ZWOQzJHWQt0Tk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "City of Bristol College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cityofbristol.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "City of Bristol College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://icarus.sdstate.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Gary.Christensen@sdstate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gary Christensen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Andy.Kanuch@sdstate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andy Kanuch"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Kevin.Brandt@sdstate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kevin Brandt"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Ryan.Knutson@sdstate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ryan Knutson"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://icarus.sdstate.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://icarus.sdstate.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://icarus.sdstate.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://icarus.sdstate.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://icarus.sdstate.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://icarus.sdstate.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://icarus.sdstate.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sdstate.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "South Dakota State University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUKA/N5InEM8Fk3MEN5e7UAQ9cOzcwDQYJKoZIhvcNAQEF\nBQAwHTEbMBkGA1UEAxMSaWNhcnVzLnNkc3RhdGUuZWR1MB4XDTEyMDUzMTIwMTg0\nNloXDTMyMDUzMTIwMTg0NlowHTEbMBkGA1UEAxMSaWNhcnVzLnNkc3RhdGUuZWR1\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkNiBja9DimDPJi8snAgp\nsOFdV8AZxumd2LwAvfVygEuUZFMBsZQlF25f4CHoCJm7zga4molJK4Y4EUn8rz0u\nIgSZKQrbEPvqL2k8Zd8jx0FtFEExzhkWvM4NtTkYm6FTrOMmEyQq6A3Zc1e4QT5z\nt8TFTze1637Ow12L/QHuqtwwYIPenzmEsondUe5vyrciEpFmL8ajR1/VxD4EUg1m\ngwgx13wIghyaq2J47TgjPZdKbEuvWsDTnOHNkF3C/BzhmKPSLCyhCqKZLYWAkWGT\nW3f9UDDE8hlvKosukhc+hv271p1wLR4/V5nENtJ6WqHH2xLDbsRzOifQ2YXv1Rdw\nawIDAQABo2swaTBIBgNVHREEQTA/ghJpY2FydXMuc2RzdGF0ZS5lZHWGKWh0dHBz\nOi8vaWNhcnVzLnNkc3RhdGUuZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQa\nEzkNjjzfH2WlulsJQaKUTG0J2zANBgkqhkiG9w0BAQUFAAOCAQEATpTa8hA5Txcn\nDtz2rijhsam8OR5FZoJtnNf75QMiy2lKanXGwmKPszzFWb8DLmpFkxGVcfTauA/n\ngd/YaaZwuE0Y4xVReRd1marJgoTM+vzc/I8C4LXfJYH/p6E+JIYFTv6Q8FCSqc7Z\naNOJ92M42hKbI3CK+GyOHOtwLfUmYNw880X64PkH+LWZ7NyyTxazfGDijDnRSPej\nKY8D/vt7ACNjpqMMsbBxDlB/wqcy655OeW4Ek1u0GzbmButiwjbsQ1V1wI7jdj52\nyUueGe5EjM8yKE0EhGTpcsf+7p7sbEJMFNZbOiJWKKIMlGD9NQnOKVesZCjrhsuA\neDYD2tg4hg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://icarus.sdstate.edu/error.html/"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "South Dakota State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www3.sdstate.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "South Dakota State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.u-clermont1.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Fed-Admin@u-clermont1.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.u-clermont1.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-04-16T09:12:33Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.u-clermont1.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.u-clermont1.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.u-clermont1.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "u-clermont1.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-bpclermont.fr/"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Clermont Ferrand 1 - Auvergne"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Clermont Ferrand 1 - Auvergne"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUNwZDNaZ3tdkFE1H1v5fQOZ0h7xIwDQYJKoZIhvcNAQEF\nBQAwHTEbMBkGA1UEAxMSaWRwLnUtY2xlcm1vbnQxLmZyMB4XDTA4MTEyNjA4MjQy\nOFoXDTI4MTEyNjA4MjQyOFowHTEbMBkGA1UEAxMSaWRwLnUtY2xlcm1vbnQxLmZy\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoz9+2ei+Cj+D9fmqSgXV\niDUF2Fv9KCEoRmxpIVmQJExVgGpBPzAToKzPu6vP0UXnJTItEGq0cQiOZvdkiwjb\ni9lYCJTzp6NA8kSjfI0F7/U3DMAOaqBMIv5NaLkZTH+6YPAqMOBQOb1oBs4YsjW+\nelFvesreBaPmbSotHWCYgfnb29OLAg37CgAmqDjL7ymPAsE0tPgr9USyjtUhWXsI\nkz2A2OPd3Qy+EizPJevne5gNu/2nfa0RwxTUG7p9Q2FXhJj1Jg3Ijs0PwWpqSM/q\nqrmKActd9uzeHenor13kprK47Ep+K+xIV3CC0gFlRxbZohFrpqvXUun4Gyk3dOuq\n/QIDAQABo2swaTBIBgNVHREEQTA/ghJpZHAudS1jbGVybW9udDEuZnKGKWh0dHBz\nOi8vaWRwLnUtY2xlcm1vbnQxLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTP\nx7ipW2IlVbBux4f/glTdrZcq8zANBgkqhkiG9w0BAQUFAAOCAQEAAUqxVk6Dm5ZS\njQl1fY+x4Qcc7kSE7vksmWNlhO5WC7NMftDOSzJaoyOlPlP15ONoSPaH/0R2rBRE\nFTvvQNQ7Mpckur1lnTFvLpkAaZ9YSe+wiksHeXQhxN8vb6PYT4Td1CS98efueae4\n1bFIzour2gi4h4e86Zgv18YAr5eBmp38mYYOghxwk67uVdwU2trVIi2EjSbE4AWL\n+tu/H6jCK1dMSPCt0UZnv0jSOGU+eCtDPOhD2P/338GEPw2NfwpB85TlGIOf5u0a\nKmDbVb0p+dFwUH3zICKCDJM7OBcUNDM/fcHMBWJ64r17AiGtdZ5Cj0dZQt4ClMC9\nMcelq5/l9A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Clermont Ferrand 1 - Auvergne"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-bpclermont.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Clermont Ferrand 1 - Auvergne"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://keystone-beta.cloud.ipnett.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://keystone-beta.cloud.ipnett.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://keystone-beta.cloud.ipnett.se/Shibboleth.sso/Logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IPnett Cloud Services OpenStack"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IPnett Cloud Services OpenStack"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.cloud.ipnett.se/ipnett.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "77"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IPnett Cloud Services Beta"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IPnett Cloud Services Beta"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIJAPPowPSKvgZgMA0GCSqGSIb3DQEBCwUAMCgxJjAkBgNV\n            BAMMHWtleXN0b25lLWJldGEuY2xvdWQuaXBuZXR0LnNlMB4XDTE2MDMzMDA2MTY0\n            OVoXDTI3MDMxMzA2MTY0OVowKDEmMCQGA1UEAwwda2V5c3RvbmUtYmV0YS5jbG91\n            ZC5pcG5ldHQuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDbE4Dd\n            PYdXSY28N+u22x7Zpe+9tw/GA8ZqUY82loAk0tZ1m5erQNcW11USum8a8socSi0r\n            QDzHsratiV6s/+8pyp+NorwfONAx/tP5HdvDDWUhJFld6oo6fEhyxk7XIFyuz9Th\n            PkGls8CLphjPvUcvoBu86Uw0bBGC4+bmde5UiNN/8spCWB4IeAzWLNYtF81r9+wA\n            uDPqimL5u2SUH3INquU72oGg6brL+lGOkoFt162YQnBnN6fQEzVmLzvagdXGKw+m\n            /YTph+WnNEeOz2gV9Hhf5gyri3fPk1kXqGlO0w/F4UdTSIV7ypdW8NkrYCf7INbk\n            kETtWcxTjNYOEnL7AgMBAAGjUDBOMB0GA1UdDgQWBBRJBzbqYNaDlZW94WVGApLN\n            XtSrrjAfBgNVHSMEGDAWgBRJBzbqYNaDlZW94WVGApLNXtSrrjAMBgNVHRMEBTAD\n            AQH/MA0GCSqGSIb3DQEBCwUAA4IBAQAHw0OXubM7aFCCQal1ZQiNBMZnvePqzujg\n            Yn6c9IRNNMvax9w31hVOLWaE6Kpa++T6LppwI952y3wSqevDPf180dySQWtstziI\n            D7Lz/Kjll9LN8mArW1jJ4psqDU9RX4otDP8AUUVo5K9daCjBbxcj4RIMfpmlcw7a\n            MpN8pGtS0Z6VNxC4XsCmM+2mRu4cvlwhHOwu7hy4vK8OLOaj6SNiJYHSi/5ZoQv7\n            VNEtE1FJ0y6Fox7OG48x+S//SkzDkNkOgo/tRSJhb5bQQBpOMtNF6WNp8cqnkFst\n            uCNQenEiZ9DSiyNJmsiqWMsdir/9+GWp0VpsJLLq878kAxtPFQid"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIJAPPowPSKvgZgMA0GCSqGSIb3DQEBCwUAMCgxJjAkBgNV\n            BAMMHWtleXN0b25lLWJldGEuY2xvdWQuaXBuZXR0LnNlMB4XDTE2MDMzMDA2MTY0\n            OVoXDTI3MDMxMzA2MTY0OVowKDEmMCQGA1UEAwwda2V5c3RvbmUtYmV0YS5jbG91\n            ZC5pcG5ldHQuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDbE4Dd\n            PYdXSY28N+u22x7Zpe+9tw/GA8ZqUY82loAk0tZ1m5erQNcW11USum8a8socSi0r\n            QDzHsratiV6s/+8pyp+NorwfONAx/tP5HdvDDWUhJFld6oo6fEhyxk7XIFyuz9Th\n            PkGls8CLphjPvUcvoBu86Uw0bBGC4+bmde5UiNN/8spCWB4IeAzWLNYtF81r9+wA\n            uDPqimL5u2SUH3INquU72oGg6brL+lGOkoFt162YQnBnN6fQEzVmLzvagdXGKw+m\n            /YTph+WnNEeOz2gV9Hhf5gyri3fPk1kXqGlO0w/F4UdTSIV7ypdW8NkrYCf7INbk\n            kETtWcxTjNYOEnL7AgMBAAGjUDBOMB0GA1UdDgQWBBRJBzbqYNaDlZW94WVGApLN\n            XtSrrjAfBgNVHSMEGDAWgBRJBzbqYNaDlZW94WVGApLNXtSrrjAMBgNVHRMEBTAD\n            AQH/MA0GCSqGSIb3DQEBCwUAA4IBAQAHw0OXubM7aFCCQal1ZQiNBMZnvePqzujg\n            Yn6c9IRNNMvax9w31hVOLWaE6Kpa++T6LppwI952y3wSqevDPf180dySQWtstziI\n            D7Lz/Kjll9LN8mArW1jJ4psqDU9RX4otDP8AUUVo5K9daCjBbxcj4RIMfpmlcw7a\n            MpN8pGtS0Z6VNxC4XsCmM+2mRu4cvlwhHOwu7hy4vK8OLOaj6SNiJYHSi/5ZoQv7\n            VNEtE1FJ0y6Fox7OG48x+S//SkzDkNkOgo/tRSJhb5bQQBpOMtNF6WNp8cqnkFst\n            uCNQenEiZ9DSiyNJmsiqWMsdir/9+GWp0VpsJLLq878kAxtPFQid"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://keystone-beta.cloud.ipnett.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "IPnett Cloud Services OpenStack"
                },
                {
                  "lang": "sv",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "IPnett Cloud Services OpenStack"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://umdac-stdout.umdc.umu.se/shibboleth",
    {
      "entity_id": "https://umdac-stdout.umdc.umu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://umdac-stdout.umdc.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://umdac-stdout.umdc.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://umdac-stdout.umdc.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://umdac-stdout.umdc.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://umdac-stdout.umdc.umu.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "umdac-stdout.umdc.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIELDCCAxSgAwIBAgICAYswDQYJKoZIhvcNAQEFBQAwdDELMAkGA1UEBhMCU0Ux\nGTAXBgNVBAoTEFVtZWEgdW5pdmVyc2l0ZXQxGjAYBgNVBAsTEVRlc3QgQ2VydGlm\naWNhdGVzMRQwEgYDVQQDEwtVbVUgVGVzdCBDQTEYMBYGCSqGSIb3DQEJARYJY2FA\ndW11LnNlMB4XDTA5MTEwMjE1NDkyMVoXDTEwMTAyODE1NDkyMVowZzELMAkGA1UE\nBhMCU0UxGTAXBgNVBAoTEFVtZWEgdW5pdmVyc2l0ZXQxGjAYBgNVBAsTEVRlc3Qg\nQ2VydGlmaWNhdGVzMSEwHwYDVQQDExh1bWRhYy1zdGRvdXQudW1kYy51bXUuc2Uw\ngZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGBALW8cJS327S7dbj5m35I8ir4mPrC\ngMe6h7/9VSYwKNwlLgd88Vr+VaVBT3lTZTe1XiHvK6keYXCpRKgzhL9GWPpPzlX4\n4D+NGePVIQzP6yC3Be5AamsA8xYzDzxtWsn+xEpfzo1eeNG7mxCu7Eh4c1Xh1Fo9\nk7wVoCo84ui9iV+1AgMBAAGjggFXMIIBUzAJBgNVHRMEAjAAMAsGA1UdDwQEAwIF\n4DAdBgNVHQ4EFgQUV29zu1B/v7I2bvj0NSEYZfX9nR4wgZ4GA1UdIwSBljCBk4AU\njXOYXAXzhT5d63px9eWem3+tpNuheKR2MHQxCzAJBgNVBAYTAlNFMRkwFwYDVQQK\nExBVbWVhIHVuaXZlcnNpdGV0MRowGAYDVQQLExFUZXN0IENlcnRpZmljYXRlczEU\nMBIGA1UEAxMLVW1VIFRlc3QgQ0ExGDAWBgkqhkiG9w0BCQEWCWNhQHVtdS5zZYIB\nADAJBgNVHREEAjAAMDcGA1UdHwQwMC4wLKAqoCiGJmh0dHA6Ly93d3cuY2EudW11\nLnNlL3Rlc3RjYS9jcmxfdjIuY3JsMBEGCWCGSAGG+EIBAQQEAwIGQDAiBglghkgB\nhvhCAQ0EFRYTT25seSBmb3IgdGVzdCB1c2FnZTANBgkqhkiG9w0BAQUFAAOCAQEA\nknTqV4ZqO4JEuv30s9Hc5o5VrWwiIm1++PZLn+VVx6fzx3X+hjo6UuXsTYvT/Cwh\nPc/+Xi9cHaYh3na269+0eZ49W/XFRKp2MRUZeIWB2d2XVH4xVos0N8BWsvLWqOfk\ncTwgoijo/badxi74ZSPRh7kOp/t9qm16Zx2+b4EX+4Kofp1PtxWDQj4//McjgEfu\nm87g+4FTwxmeYEobc/9Njk3sKz0ecjxhJF60Sr1IuipOroVfaVkfkeOdvIgOaeeR\nkp4lNB24SaDlqLpb4ZbVOSAdnrBo/oA3hZfj24cXm8/p3+NNm8ryrC+fi5CZcZFT\npxWTuR+O1MsLut2Mjqaq5Q=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=umdac-stdout.umdc.umu.se,OU=Test Certificates,O=Umea universitet,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "umdac-stdout.umdc.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIELDCCAxSgAwIBAgICAYswDQYJKoZIhvcNAQEFBQAwdDELMAkGA1UEBhMCU0Ux\nGTAXBgNVBAoTEFVtZWEgdW5pdmVyc2l0ZXQxGjAYBgNVBAsTEVRlc3QgQ2VydGlm\naWNhdGVzMRQwEgYDVQQDEwtVbVUgVGVzdCBDQTEYMBYGCSqGSIb3DQEJARYJY2FA\ndW11LnNlMB4XDTA5MTEwMjE1NDkyMVoXDTEwMTAyODE1NDkyMVowZzELMAkGA1UE\nBhMCU0UxGTAXBgNVBAoTEFVtZWEgdW5pdmVyc2l0ZXQxGjAYBgNVBAsTEVRlc3Qg\nQ2VydGlmaWNhdGVzMSEwHwYDVQQDExh1bWRhYy1zdGRvdXQudW1kYy51bXUuc2Uw\ngZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGBALW8cJS327S7dbj5m35I8ir4mPrC\ngMe6h7/9VSYwKNwlLgd88Vr+VaVBT3lTZTe1XiHvK6keYXCpRKgzhL9GWPpPzlX4\n4D+NGePVIQzP6yC3Be5AamsA8xYzDzxtWsn+xEpfzo1eeNG7mxCu7Eh4c1Xh1Fo9\nk7wVoCo84ui9iV+1AgMBAAGjggFXMIIBUzAJBgNVHRMEAjAAMAsGA1UdDwQEAwIF\n4DAdBgNVHQ4EFgQUV29zu1B/v7I2bvj0NSEYZfX9nR4wgZ4GA1UdIwSBljCBk4AU\njXOYXAXzhT5d63px9eWem3+tpNuheKR2MHQxCzAJBgNVBAYTAlNFMRkwFwYDVQQK\nExBVbWVhIHVuaXZlcnNpdGV0MRowGAYDVQQLExFUZXN0IENlcnRpZmljYXRlczEU\nMBIGA1UEAxMLVW1VIFRlc3QgQ0ExGDAWBgkqhkiG9w0BCQEWCWNhQHVtdS5zZYIB\nADAJBgNVHREEAjAAMDcGA1UdHwQwMC4wLKAqoCiGJmh0dHA6Ly93d3cuY2EudW11\nLnNlL3Rlc3RjYS9jcmxfdjIuY3JsMBEGCWCGSAGG+EIBAQQEAwIGQDAiBglghkgB\nhvhCAQ0EFRYTT25seSBmb3IgdGVzdCB1c2FnZTANBgkqhkiG9w0BAQUFAAOCAQEA\nknTqV4ZqO4JEuv30s9Hc5o5VrWwiIm1++PZLn+VVx6fzx3X+hjo6UuXsTYvT/Cwh\nPc/+Xi9cHaYh3na269+0eZ49W/XFRKp2MRUZeIWB2d2XVH4xVos0N8BWsvLWqOfk\ncTwgoijo/badxi74ZSPRh7kOp/t9qm16Zx2+b4EX+4Kofp1PtxWDQj4//McjgEfu\nm87g+4FTwxmeYEobc/9Njk3sKz0ecjxhJF60Sr1IuipOroVfaVkfkeOdvIgOaeeR\nkp4lNB24SaDlqLpb4ZbVOSAdnrBo/oA3hZfj24cXm8/p3+NNm8ryrC+fi5CZcZFT\npxWTuR+O1MsLut2Mjqaq5Q=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=umdac-stdout.umdc.umu.se,OU=Test Certificates,O=Umea universitet,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://umdac-stdout.umdc.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://umdac-stdout.umdc.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://umdac-stdout.umdc.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://umdac-stdout.umdc.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://umdac-stdout.umdc.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://umdac-stdout.umdc.umu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://umdac-stdout.umdc.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://umdac-stdout.umdc.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://umdac-stdout.umdc.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://umdac-stdout.umdc.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://oa.globaldata.com/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Imran"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:assad.imran@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Assad"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sfikas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:panagiotis.sfikas@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Panagiotis"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hogg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ghogg@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Geoffrey"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Imran"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:assad.imran@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Assad"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sfikas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:panagiotis.sfikas@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Panagiotis"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hogg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ghogg@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Geoffrey"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://oa.globaldata.com/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-02-25T15:44:52Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Marketline Advantage"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://progressivemediagroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GlobalData PLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Marketline Advantage"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDoDCCAoigAwIBAgIJAISMDAVITeK2MA0GCSqGSIb3DQEBBQUAMD4xIDAeBgNV\n\t\t\t\t\t\tBAoTF1Byb2dyZXNzaXZlIE1lZGlhIEdyb3VwMRowGAYDVQQDExFvYS5nbG9iYWxk\n\t\t\t\t\t\tYXRhLmNvbTAeFw0xNjAyMTkxNDE1MjBaFw0yNjAyMTYxNDE1MjBaMD4xIDAeBgNV\n\t\t\t\t\t\tBAoTF1Byb2dyZXNzaXZlIE1lZGlhIEdyb3VwMRowGAYDVQQDExFvYS5nbG9iYWxk\n\t\t\t\t\t\tYXRhLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANtK8T0njyyE\n\t\t\t\t\t\tC+nrW0F/TY/XfYlFV/dGCU0zkh9TsPlxrPmEl0eRLSVzovmIAPpmC1RaekEMiwZp\n\t\t\t\t\t\tIdfI9rHbBd6zt3Ull9IjutR4uqz5qW1AOkPLKUYF4oatN26RG7wp3rEMhvQ8IeGF\n\t\t\t\t\t\tHbH6LvkuSBL+oZ6w0/LyCwgbS6wWs9K9kjPj6ErD+HZO19FAS6tuvjiyPCXO1OyL\n\t\t\t\t\t\tsVFZlxMavhW9CQ5LvjzVyxiZbm8rB1Dwr77/STJD0wehYtuDlKPnB13rAW3srLHf\n\t\t\t\t\t\t/sOany34MW9s3GpISRCLNlsTJmAIEHuZ9uIzFuynRKFeiOCw+61GG2uXLj0OaZtt\n\t\t\t\t\t\tRRTR+SeOlYcCAwEAAaOBoDCBnTAdBgNVHQ4EFgQU8s+2m7H9POieKhWJIrEAoZbz\n\t\t\t\t\t\tVAEwbgYDVR0jBGcwZYAU8s+2m7H9POieKhWJIrEAoZbzVAGhQqRAMD4xIDAeBgNV\n\t\t\t\t\t\tBAoTF1Byb2dyZXNzaXZlIE1lZGlhIEdyb3VwMRowGAYDVQQDExFvYS5nbG9iYWxk\n\t\t\t\t\t\tYXRhLmNvbYIJAISMDAVITeK2MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAHnOUBL6X32GrxDo0HzlZCg1VPH6WIEmNde4F9PmMnEkdIdH3OSZRWpZ+xbM\n\t\t\t\t\t\t6jKaPoIsk8Zve2IA+8fde9v1iYWlFWgfbmc3FO8hWA0s8bhWuDLMrOaPUNtekSdK\n\t\t\t\t\t\t9sm7eI51hIr9H4gG4aIA4n+HmNI+zowzxSH0HqkAsRXpAldQDds8s/uirYlj8v6R\n\t\t\t\t\t\tM23m4SPioqp045ldUcYYolVN38DIQEYOlFNe3IeisCaTKTCy5g8MGs/W1SZmNPzf\n\t\t\t\t\t\tTyiagqhj/avcrpYCeYxnKYmp7TQwPU0eq2HCpwtEuMceqfGRNug21kq7My5PSXWc\n\t\t\t\t\t\tEvdqICU/AKM0Q4zExpC0dXX01Ic="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDoDCCAoigAwIBAgIJAISMDAVITeK2MA0GCSqGSIb3DQEBBQUAMD4xIDAeBgNV\n\t\t\t\t\t\tBAoTF1Byb2dyZXNzaXZlIE1lZGlhIEdyb3VwMRowGAYDVQQDExFvYS5nbG9iYWxk\n\t\t\t\t\t\tYXRhLmNvbTAeFw0xNjAyMTkxNDE1MjBaFw0yNjAyMTYxNDE1MjBaMD4xIDAeBgNV\n\t\t\t\t\t\tBAoTF1Byb2dyZXNzaXZlIE1lZGlhIEdyb3VwMRowGAYDVQQDExFvYS5nbG9iYWxk\n\t\t\t\t\t\tYXRhLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANtK8T0njyyE\n\t\t\t\t\t\tC+nrW0F/TY/XfYlFV/dGCU0zkh9TsPlxrPmEl0eRLSVzovmIAPpmC1RaekEMiwZp\n\t\t\t\t\t\tIdfI9rHbBd6zt3Ull9IjutR4uqz5qW1AOkPLKUYF4oatN26RG7wp3rEMhvQ8IeGF\n\t\t\t\t\t\tHbH6LvkuSBL+oZ6w0/LyCwgbS6wWs9K9kjPj6ErD+HZO19FAS6tuvjiyPCXO1OyL\n\t\t\t\t\t\tsVFZlxMavhW9CQ5LvjzVyxiZbm8rB1Dwr77/STJD0wehYtuDlKPnB13rAW3srLHf\n\t\t\t\t\t\t/sOany34MW9s3GpISRCLNlsTJmAIEHuZ9uIzFuynRKFeiOCw+61GG2uXLj0OaZtt\n\t\t\t\t\t\tRRTR+SeOlYcCAwEAAaOBoDCBnTAdBgNVHQ4EFgQU8s+2m7H9POieKhWJIrEAoZbz\n\t\t\t\t\t\tVAEwbgYDVR0jBGcwZYAU8s+2m7H9POieKhWJIrEAoZbzVAGhQqRAMD4xIDAeBgNV\n\t\t\t\t\t\tBAoTF1Byb2dyZXNzaXZlIE1lZGlhIEdyb3VwMRowGAYDVQQDExFvYS5nbG9iYWxk\n\t\t\t\t\t\tYXRhLmNvbYIJAISMDAVITeK2MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAHnOUBL6X32GrxDo0HzlZCg1VPH6WIEmNde4F9PmMnEkdIdH3OSZRWpZ+xbM\n\t\t\t\t\t\t6jKaPoIsk8Zve2IA+8fde9v1iYWlFWgfbmc3FO8hWA0s8bhWuDLMrOaPUNtekSdK\n\t\t\t\t\t\t9sm7eI51hIr9H4gG4aIA4n+HmNI+zowzxSH0HqkAsRXpAldQDds8s/uirYlj8v6R\n\t\t\t\t\t\tM23m4SPioqp045ldUcYYolVN38DIQEYOlFNe3IeisCaTKTCy5g8MGs/W1SZmNPzf\n\t\t\t\t\t\tTyiagqhj/avcrpYCeYxnKYmp7TQwPU0eq2HCpwtEuMceqfGRNug21kq7My5PSXWc\n\t\t\t\t\t\tEvdqICU/AKM0Q4zExpC0dXX01Ic="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://oa.globaldata.com/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://oa.globaldata.com/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://login.umt.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "josh.odowd@umontana.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Josh O'Dowd"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "gary.trethewey@umontana.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gary Trethewey"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "adrian.irish@umontana.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adrian Irish"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://login.umt.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.umt.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.umt.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.umt.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.umt.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.umt.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "umt.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.umt.edu"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The University of Montana"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Montana federated identity provider via InCommon."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.umt.edu/_common/assets/imx/um_logo.png",
                    "lang": "en",
                    "height": "30",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "163"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.umt.edu/privacy/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUNwdPADxM5zSBnh6CyfSZ8WK45hEwDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNbG9naW4udW10LmVkdTAeFw0xNDA2MjMyMTE2MTFaFw0z\nNDA2MjMyMTE2MTFaMBgxFjAUBgNVBAMTDWxvZ2luLnVtdC5lZHUwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDclm8XLCLGyEhkLCMZVRcWFKByiAd0Wje9\n9x344wMRYwGvtct2eWpUECe4yA07KsuZBUTS+KvncnZhRfrt7VjEnSSgUol1hQb1\nJDRAQYV9WqPGRAmQJiwrhPuAbpNW0Fx6h+DP2uvtlZMTnCDn+ImUaN3xTXtmystB\nkDdXuyD5iIA0V2f492jkW5MGBmZzR0A28cSsELdXRt+nqxy6aAeu7DM29sBA6/3P\nrVYHjHAclp0fY6tarwbSxx6CxBiME0JJZxgfGTjZN74i/SELA6nsYiV5yTrJBgQx\n/fhC6L9RzwwY4BzkaZ3z39pRT1qYLi51BLK1VmRqDUEfGQZPs0r/AgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDWxvZ2luLnVtdC5lZHWGJGh0dHBzOi8vbG9naW4udW10LmVk\ndS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU1WylNNK2pkCt65wRpcDRPvMrKuww\nDQYJKoZIhvcNAQEFBQADggEBAFZpW9MMW4BG8OxlxAUdUKpe0rD4CgH2G0d4xtUU\nf6m65GFQ50QjfJBrx0DP9OPU00aXd7U3+/NIoaiZqttVZ5342zbLpoUMoouh0X6k\ngIJwFO7csVymp/sLX49lzFbFHF3uMYjq827Z+P+MlkB4siFOQ+wp/VGivPN2+AyY\ngE5eqFpIj9joU0ElQotyVB4+3HSZnU9dHfTTQq4vrM0s92eLzyTNIiTic8htUc6L\nSEx2DQoFwQwLwdadb2CdhqB5mW/v4j9dO55gx5p7HgI6B2a2Zuh+imdyAWIvMw48\nA3X832P78ktaAO25Bspo0Oyk4aCo7Ge4xRrlgGhWll6rAL0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The University of Montana"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.umt.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Montana"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://engine.elixir-czech.org/authentication/sp/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "aai-contact@elixir-europe.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ELIXIR Directory"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "aai-contact@elixir-europe.or"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ELIXIR Directory"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "aai-contact@elixir-europe.or"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ELIXIR Directory"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://engine.elixir-czech.org/authentication/sp/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2016-03-17T13:38:01Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ELIXIR CZ"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ELIXIR CZ"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.elixir-czech.cz"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.elixir-czech.cz"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ELIXIR CZ"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://login.elixir-czech.org/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://login.elixir-czech.org/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service is the common gateway to the services ELIXIR\nresearch infrastructure provides for biological data."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service is the common gateway to the services ELIXIR\nresearch infrastructure provides for biological data."
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.elixir-czech.org/media/elixir-ds.jpg",
                    "height": "96",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "96"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ELIXIR research infrastructure AAI"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ELIXIR research infrastructure AAI"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFMTCCBBmgAwIBAgIIIespBL5TmnswDQYJKoZIhvcNAQELBQAwgbQxCzAJBgNV\nBAYTAlVTMRAwDgYDVQQIEwdBcml6b25hMRMwEQYDVQQHEwpTY290dHNkYWxlMRow\nGAYDVQQKExFHb0RhZGR5LmNvbSwgSW5jLjEtMCsGA1UECxMkaHR0cDovL2NlcnRz\nLmdvZGFkZHkuY29tL3JlcG9zaXRvcnkvMTMwMQYDVQQDEypHbyBEYWRkeSBTZWN1\ncmUgQ2VydGlmaWNhdGUgQXV0aG9yaXR5IC0gRzIwHhcNMTUxMDA2MTMyNzM5WhcN\nMTgxMDA2MTMyNzM5WjBAMSEwHwYDVQQLExhEb21haW4gQ29udHJvbCBWYWxpZGF0\nZWQxGzAZBgNVBAMMEiouZWxpeGlyLWN6ZWNoLm9yZzCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBANduYwpgat3apqc/pV/hoFGtOjZ1HJ9OI01krvmrOobM\ne5w5jCzL8Sf0R6ltreV3MSpAuLdJLu8Tz0++4vGDdIqze20AHkh64/zu3I75VdZI\nWWD8iBBUNvIwjW3G0scLiwjK5/HMjO/HZuyCH4ppQvL0u86U0gAsVoFn2b4WqIIz\nyH1n85Fi71CufekD9LrbSukGUZV0QAvqFGrAPxm1LupBdwgXSVeVJlx8ZA0CBtCK\nyYnTWhRVa1Xod5/E0zd5zpuGU4VSf9r1JcSxgTnsODFb8piRJv+BErVAGj4DTHQI\n4bUf1ESvyDYz6BDy/PLOi/IV6iVATHiktphmv4P4eUkCAwEAAaOCAbgwggG0MAwG\nA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMA4GA1Ud\nDwEB/wQEAwIFoDA3BgNVHR8EMDAuMCygKqAohiZodHRwOi8vY3JsLmdvZGFkZHku\nY29tL2dkaWcyczEtMTM0LmNybDBTBgNVHSAETDBKMEgGC2CGSAGG/W0BBxcBMDkw\nNwYIKwYBBQUHAgEWK2h0dHA6Ly9jZXJ0aWZpY2F0ZXMuZ29kYWRkeS5jb20vcmVw\nb3NpdG9yeS8wdgYIKwYBBQUHAQEEajBoMCQGCCsGAQUFBzABhhhodHRwOi8vb2Nz\ncC5nb2RhZGR5LmNvbS8wQAYIKwYBBQUHMAKGNGh0dHA6Ly9jZXJ0aWZpY2F0ZXMu\nZ29kYWRkeS5jb20vcmVwb3NpdG9yeS9nZGlnMi5jcnQwHwYDVR0jBBgwFoAUQMK9\nJ47MNIMwojPX+2yz8LQsgM4wLwYDVR0RBCgwJoISKi5lbGl4aXItY3plY2gub3Jn\nghBlbGl4aXItY3plY2gub3JnMB0GA1UdDgQWBBQmJim6lGWIf9VusC8ms7npEYgl\n2zANBgkqhkiG9w0BAQsFAAOCAQEAFumHQHq1geOegg6EzHxwnvrQLfWcEWfcoRWT\nhj0MnINUoSEdJscQEihRPiQgxe1CYHVAsWyLcnZLpKHerM/f//i6bmoqLbh0fLyp\n2kjAC3Uph4VBPdmz5a3LUS6G8nomoRwXtO+CXB3xPXvamXyppMYb0xdV1YONrmuN\nrs0ldKjUtU8ieb88vJ0fcYXDjJBngTGjVEeFLllzlpHdZ0gMAJ7XuDHHupg9ISSe\nX+oaZlcJVzARIhZzLynBGKygtPjCtSeIhIpLitsBiKA354ZntN+CWV8PP6OQhRv/\nGtsSzA726/B+flEAviTfdsgY0QytNtOd3Uz26GUR21PH2OS+xg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "want_assertions_signed": "true",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://engine.elixir-czech.org/authentication/sp/consume-assertion",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ELIXIR Services"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Services of ELIXIR, the European research infrastructure for biological information, supporting life science research and its translation to medicine, agriculture, bioindustries and society"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "http://venturacollege.instructure.com/saml2",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "http://venturacollege.instructure.com/saml2",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Instructure, Inc"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.instructure.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Instructure, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://venturacollege.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://venturacollege.test.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://venturacollege.beta.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.canvaslms.com/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://canvas.instructure.com/images/canvas/header_canvas_logo@2x.png",
                    "lang": "en",
                    "height": "220",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "220"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.canvaslms.com/policies/privacy-policy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "OEI - Ventura College - Canvas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE8TCCA9mgAwIBAgIJAOBms/PYWcPLMA0GCSqGSIb3DQEBCwUAMIGrMQswCQYD\nVQQGEwJVUzENMAsGA1UECBMEVXRhaDEXMBUGA1UEBxMOU2FsdCBMYWtlIENpdHkx\nGTAXBgNVBAoTEEluc3RydWN0dXJlLCBJbmMxEzARBgNVBAsTCk9wZXJhdGlvbnMx\nIDAeBgNVBAMTF0NhbnZhcyBTQU1MIENlcnRpZmljYXRlMSIwIAYJKoZIhvcNAQkB\nFhNvcHNAaW5zdHJ1Y3R1cmUuY29tMB4XDTE1MDQxNTAxMDAwMFoXDTE3MDQyMjAx\nMDAwMFowgasxCzAJBgNVBAYTAlVTMQ0wCwYDVQQIEwRVdGFoMRcwFQYDVQQHEw5T\nYWx0IExha2UgQ2l0eTEZMBcGA1UEChMQSW5zdHJ1Y3R1cmUsIEluYzETMBEGA1UE\nCxMKT3BlcmF0aW9uczEgMB4GA1UEAxMXQ2FudmFzIFNBTUwgQ2VydGlmaWNhdGUx\nIjAgBgkqhkiG9w0BCQEWE29wc0BpbnN0cnVjdHVyZS5jb20wggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDckDPQGWedlVGC2Z9fn1wNFmN+0IPNi6OSE1nM\nvoTWx2oZlQepaAu4zI5QqOfnV0rW2V1volpoJbu0WelH0DkGzdOEQdWJjAs3nRBf\ny0evxtpg0tK5kIvGsnN6YcD41YmkfWzvwbMf0cEq1Y0wCmymF6XzOUUE4zsi0nhP\nm2Z7WiuongDQdR01UsDN13YcpD/i1JXr3YtkNnJ/a1Kc9OXNycI8M5NVo5QQgdx/\nQ7zAmTk8p9E0ZRthdOQ/PBicWx39mNmBij5KpqCWlHu3NWdgcG8KXSv5atXU8Crd\nTRJ3aGIEN9vBYIHe8MHGCzs1QlRfJmXFMkeUSOTnJJx78rMDAgMBAAGjggEUMIIB\nEDAdBgNVHQ4EFgQUo0WWVlJ1SxZOs11L85ZAuZGyuzEwgeAGA1UdIwSB2DCB1YAU\no0WWVlJ1SxZOs11L85ZAuZGyuzGhgbGkga4wgasxCzAJBgNVBAYTAlVTMQ0wCwYD\nVQQIEwRVdGFoMRcwFQYDVQQHEw5TYWx0IExha2UgQ2l0eTEZMBcGA1UEChMQSW5z\ndHJ1Y3R1cmUsIEluYzETMBEGA1UECxMKT3BlcmF0aW9uczEgMB4GA1UEAxMXQ2Fu\ndmFzIFNBTUwgQ2VydGlmaWNhdGUxIjAgBgkqhkiG9w0BCQEWE29wc0BpbnN0cnVj\ndHVyZS5jb22CCQDgZrPz2FnDyzAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUA\nA4IBAQBV3EmmnzYqYQ5fXNZymG2WaspEW0NeFMhDXa3p3AMIQJbnnU14lR7bqIvf\n/bLW1YE0fw1kSzsw8VrkQp7k1U+kaYA3i5/FQBy2WtqUCVq2GXZA2gs5YD4nvJB/\nF57E//0kEhbATZH9+wJqDkqyIgsrSIlJjiXDth1BppGK8weboPtr9sWV24Ui0+ls\nw16XTsGlnRRO19g+gXKOZp5ApXkDrB+HwZQvZxiCuSgvJlcBzMdxVvWSL+vPtg8Y\nshIKzobIhaQ2MzXHLcxrDhW10YFPwDXh8Tfn5iU9ONsaJivuvVhtDYZD1ZzSoPpm\nq4vYqxxY/6rFJhrCtnlLepSaxlXM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://venturacollege.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://venturacollege.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://venturacollege.beta.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://venturacollege.beta.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://venturacollege.test.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://venturacollege.test.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vcccd.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vcccd.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vcccd.test.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vcccd.test.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vcccd.beta.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vcccd.beta.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "OEI - Ventura College - Canvas"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://play.kth.se/external/kaltura.com",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "saml_admin@kaltura.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://play.kth.se/external/kaltura.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "KTH Play (Kaltura)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://corp.kaltura.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "KTH Play (Kaltura)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://play.kth.se/user/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Videoportal vid KTH"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Video portal at KTH"
                  }
                ],
                "logo": [
                  {
                    "text": "https://saml.sys.kth.se/idp/images/logo.png",
                    "height": "166",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "166"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "KTH Play"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "KTH Play"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEjCCAfqgAwIBAgIJAK195gtIeoCnMA0GCSqGSIb3DQEBCwUAMBYxFDASBgNV\nBAMTC3BsYXkua3RoLnNlMB4XDTE0MTAyOTA5MjgyOFoXDTI0MTAyNjA5MjgyOFow\nFjEUMBIGA1UEAxMLcGxheS5rdGguc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQC1EWaeEQViRtUt+Rocl/5n4+9G0WMfpbRy74vEY0yZDTtC6O1NB/5l\ntws/3Mlx/EBIasszeJh5cXBbzE803KRy8nCJcE+8dFJWXPWHiW7QfqRfdS5pq20q\nq1cXpBptVkt/Xf5cU10Nv8HncwqW8BI8W50nOJtC7vdm8Q2MojZijPVc8dV/Klar\nJRxU5+hwHOcuCTQ4NUDVimQfUsDZUq9HN/vfNoErrSMhrcOFYzAIfrH02XmENviq\n127MsiIRn+pbpBRQTkenVbjFKYixbaLN8cP0v9xiVQF5zOn/qvgiKAKQdWIZ+BXG\nYNwxU89vEUku00307pXbKsUHGgZLV2FfAgMBAAGjYzBhMEAGA1UdEQQ5MDeCC3Bs\nYXkua3RoLnNlhihodHRwczovL3BsYXkua3RoLnNlL2V4dGVybmFsL2thbHR1cmEu\nY29tMB0GA1UdDgQWBBR5t6n0EslcO73PHaCd2O0AKVKMjzANBgkqhkiG9w0BAQsF\nAAOCAQEAWvLPZDw0sNsZjlhLtL9b2R+ZSdroJ9B2kSaZRsRM7obSulHxyjXEUdoG\nIKsRmUcNsPyPAFU3JctWEgSH3MVV1D23OflfVB3frbZeIzX65h4xeeABfUpQlonB\nwxpM2hA8VBj+CHSHY3n9U5LNN+/OhuXDHVowV4qfqN8UgeJV5pHb3kmgJSZmk3iJ\nhQeOvTkgoB+Co5E2wicXUX/LLNlldIyLofjlXeXvE1qwyICg/7chKiVTJHd77qyf\nCMjv9XK4ujIYPDLmwHLmWNK1ETL8tajP/NvJh0sS6Ni1djONPN7YAs+BokqN1aRx\njyfJSjzHuZ9xMjMF/qdblGtl222vyg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEjCCAfqgAwIBAgIJAK195gtIeoCnMA0GCSqGSIb3DQEBCwUAMBYxFDASBgNV\nBAMTC3BsYXkua3RoLnNlMB4XDTE0MTAyOTA5MjgyOFoXDTI0MTAyNjA5MjgyOFow\nFjEUMBIGA1UEAxMLcGxheS5rdGguc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQC1EWaeEQViRtUt+Rocl/5n4+9G0WMfpbRy74vEY0yZDTtC6O1NB/5l\ntws/3Mlx/EBIasszeJh5cXBbzE803KRy8nCJcE+8dFJWXPWHiW7QfqRfdS5pq20q\nq1cXpBptVkt/Xf5cU10Nv8HncwqW8BI8W50nOJtC7vdm8Q2MojZijPVc8dV/Klar\nJRxU5+hwHOcuCTQ4NUDVimQfUsDZUq9HN/vfNoErrSMhrcOFYzAIfrH02XmENviq\n127MsiIRn+pbpBRQTkenVbjFKYixbaLN8cP0v9xiVQF5zOn/qvgiKAKQdWIZ+BXG\nYNwxU89vEUku00307pXbKsUHGgZLV2FfAgMBAAGjYzBhMEAGA1UdEQQ5MDeCC3Bs\nYXkua3RoLnNlhihodHRwczovL3BsYXkua3RoLnNlL2V4dGVybmFsL2thbHR1cmEu\nY29tMB0GA1UdDgQWBBR5t6n0EslcO73PHaCd2O0AKVKMjzANBgkqhkiG9w0BAQsF\nAAOCAQEAWvLPZDw0sNsZjlhLtL9b2R+ZSdroJ9B2kSaZRsRM7obSulHxyjXEUdoG\nIKsRmUcNsPyPAFU3JctWEgSH3MVV1D23OflfVB3frbZeIzX65h4xeeABfUpQlonB\nwxpM2hA8VBj+CHSHY3n9U5LNN+/OhuXDHVowV4qfqN8UgeJV5pHb3kmgJSZmk3iJ\nhQeOvTkgoB+Co5E2wicXUX/LLNlldIyLofjlXeXvE1qwyICg/7chKiVTJHd77qyf\nCMjv9XK4ujIYPDLmwHLmWNK1ETL8tajP/NvJh0sS6Ni1djONPN7YAs+BokqN1aRx\njyfJSjzHuZ9xMjMF/qdblGtl222vyg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.kth.se/user/authenticate",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.tu-clausthal.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hasenfu\u00df"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hasenfuss@rz.tu-clausthal.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alexander"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hasenfu\u00df"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hasenfuss@rz.tu-clausthal.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alexander"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.tu-clausthal.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2012-01-23T11:26:08Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.tu-clausthal.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGFjCCBP6gAwIBAgIHGYPBFL1P5DANBgkqhkiG9w0BAQsFADCBmDELMAkGA1UE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\n+A9Tm6pmSCWUc89MfO/PCoexbG5rxNoaedI="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.tu-clausthal.de,OU=Rechenzentrum,O=Technische Universitaet Clausthal,L=Clausthal,ST=Niedersachsen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tu-clausthal.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.tu-clausthal.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.tu-clausthal.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.tu-clausthal.de/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.tu-clausthal.de/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.tu-clausthal.de:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.tu-clausthal.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.tu-clausthal.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.tu-clausthal.de/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.tu-clausthal.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.tu-clausthal.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.tu-clausthal.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tu-clausthal.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.tu-clausthal.de/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.tu-clausthal.de/"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider fuer TU Clausthal"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider fuer TU Clausthal"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.tu-clausthal.de/idp/images/tu-clausthal-klein.gif",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.tu-clausthal.de/idp/images/tu-clausthal.gif",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "344"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Technische Universit\u00e4t Clausthal"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Technische Universit\u00e4t Clausthal"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.tu-clausthal.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGFjCCBP6gAwIBAgIHGYPBFL1P5DANBgkqhkiG9w0BAQsFADCBmDELMAkGA1UE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\n+A9Tm6pmSCWUc89MfO/PCoexbG5rxNoaedI="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.tu-clausthal.de,OU=Rechenzentrum,O=Technische Universitaet Clausthal,L=Clausthal,ST=Niedersachsen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Technische Universit\u00e4t Clausthal"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Technische Universit\u00e4t Clausthal"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tu-clausthal.de/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tu-clausthal.de/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e291"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e291"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://l4l-sp-02.kent.ac.uk/entity",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Slowe"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:M.Slowe@kent.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matthew"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Siu"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:K.W.S.Siu@kent.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kristy"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://l4l-sp-02.kent.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Kent: Logins for Life"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kent.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Kent"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://l4l-idp-01.kent.ac.uk/simplesaml/module.php/saml/sp/saml2-logout.php/UK-AMF",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEJjCCAw6gAwIBAgIJAKa9P2cE2HGrMA0GCSqGSIb3DQEBBQUAMIGTMQswCQYD\n\t\t\t\t\t\tVQQGEwJVSzENMAsGA1UECBMES2VudDETMBEGA1UEBxMKQ2FudGVyYnVyeTEbMBkG\n\t\t\t\t\t\tA1UEChMSVW5pdmVyc2l0eSBvZiBLZW50MQ4wDAYDVQQLEwVpc3NyZzETMBEGA1UE\n\t\t\t\t\t\tAxMKS3Jpc3R5IFNpdTEeMBwGCSqGSIb3DQEJARYPa3dzc0BrZW50LmFjLnVrMB4X\n\t\t\t\t\t\tDTEyMDExMTE0MjE0M1oXDTIyMDEwODE0MjE0M1owgZMxCzAJBgNVBAYTAlVLMQ0w\n\t\t\t\t\t\tCwYDVQQIEwRLZW50MRMwEQYDVQQHEwpDYW50ZXJidXJ5MRswGQYDVQQKExJVbml2\n\t\t\t\t\t\tZXJzaXR5IG9mIEtlbnQxDjAMBgNVBAsTBWlzc3JnMRMwEQYDVQQDEwpLcmlzdHkg\n\t\t\t\t\t\tU2l1MR4wHAYJKoZIhvcNAQkBFg9rd3NzQGtlbnQuYWMudWswggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQC2APnwJCFAJGZgARhHGG1q9EYwpVkWiVvScfbM\n\t\t\t\t\t\tgSxgGhs4jhzYX3bLUqOFM1+FVqRQsQjka1pEt3sNsH1rTkQG0BCRNXfiUOAzH+ex\n\t\t\t\t\t\txNtyj6M3Rj2Jb7wUo/Dk9IJaEKrRWYRczFa4UoTLBfuh98T+ii3+nx9143zXz3fu\n\t\t\t\t\t\tdUKSOm2VBGQx9BfucN55C90uBg3FzdaSgh3DUErnuVOtaR2ORKCgW8VanjkzrWv0\n\t\t\t\t\t\t/mtdhNycFh9ECBy/Emgyw5zG2fxyEL3KftNJxogBDcEC6dU3PZPFo1p+TTIjOZa1\n\t\t\t\t\t\tc0Z0cvzLeTqDJsYi07CWMotobZ5XMmM+T2oS3adB8hXb4DVLAgMBAAGjezB5MAkG\n\t\t\t\t\t\tA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRp\n\t\t\t\t\t\tZmljYXRlMB0GA1UdDgQWBBT2YT5wLzaLNBPtBUgm1xylI03WXDAfBgNVHSMEGDAW\n\t\t\t\t\t\tgBT2YT5wLzaLNBPtBUgm1xylI03WXDANBgkqhkiG9w0BAQUFAAOCAQEAJIYNiO5b\n\t\t\t\t\t\tYzb3dZ2PqL3WdhMTg3vHXTBVKKnSegNwd/huTybPzs6oqNIxgDqsxT6/p5WZVz/f\n\t\t\t\t\t\t6MT3bvUnGoy70gNVaSjHZg01QXKCzbEi1C/hcMO1cMdYVYZYAiQeFv7+4HuChkC6\n\t\t\t\t\t\tZIkwMmoSeX/Q13G3ZOltY+xV81E7Afc3+MTeowDYayfRHTpp4SHqRe098k/XJ6w9\n\t\t\t\t\t\t3PMjGO33JAAAaNAJzsmzrtb86q5d9O4r4Y45vRypyBfu6Mr8TbufXsxUEKcdFaRv\n\t\t\t\t\t\tDsKvkemCd+Dir273mcUN+zhGKUhjPAYJsFhb/wWkTmbdk1mBNjIhqavarm/OIyG8\n\t\t\t\t\t\tc91vv7jVI/bPgA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEJjCCAw6gAwIBAgIJAKa9P2cE2HGrMA0GCSqGSIb3DQEBBQUAMIGTMQswCQYD\n\t\t\t\t\t\tVQQGEwJVSzENMAsGA1UECBMES2VudDETMBEGA1UEBxMKQ2FudGVyYnVyeTEbMBkG\n\t\t\t\t\t\tA1UEChMSVW5pdmVyc2l0eSBvZiBLZW50MQ4wDAYDVQQLEwVpc3NyZzETMBEGA1UE\n\t\t\t\t\t\tAxMKS3Jpc3R5IFNpdTEeMBwGCSqGSIb3DQEJARYPa3dzc0BrZW50LmFjLnVrMB4X\n\t\t\t\t\t\tDTEyMDExMTE0MjE0M1oXDTIyMDEwODE0MjE0M1owgZMxCzAJBgNVBAYTAlVLMQ0w\n\t\t\t\t\t\tCwYDVQQIEwRLZW50MRMwEQYDVQQHEwpDYW50ZXJidXJ5MRswGQYDVQQKExJVbml2\n\t\t\t\t\t\tZXJzaXR5IG9mIEtlbnQxDjAMBgNVBAsTBWlzc3JnMRMwEQYDVQQDEwpLcmlzdHkg\n\t\t\t\t\t\tU2l1MR4wHAYJKoZIhvcNAQkBFg9rd3NzQGtlbnQuYWMudWswggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQC2APnwJCFAJGZgARhHGG1q9EYwpVkWiVvScfbM\n\t\t\t\t\t\tgSxgGhs4jhzYX3bLUqOFM1+FVqRQsQjka1pEt3sNsH1rTkQG0BCRNXfiUOAzH+ex\n\t\t\t\t\t\txNtyj6M3Rj2Jb7wUo/Dk9IJaEKrRWYRczFa4UoTLBfuh98T+ii3+nx9143zXz3fu\n\t\t\t\t\t\tdUKSOm2VBGQx9BfucN55C90uBg3FzdaSgh3DUErnuVOtaR2ORKCgW8VanjkzrWv0\n\t\t\t\t\t\t/mtdhNycFh9ECBy/Emgyw5zG2fxyEL3KftNJxogBDcEC6dU3PZPFo1p+TTIjOZa1\n\t\t\t\t\t\tc0Z0cvzLeTqDJsYi07CWMotobZ5XMmM+T2oS3adB8hXb4DVLAgMBAAGjezB5MAkG\n\t\t\t\t\t\tA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRp\n\t\t\t\t\t\tZmljYXRlMB0GA1UdDgQWBBT2YT5wLzaLNBPtBUgm1xylI03WXDAfBgNVHSMEGDAW\n\t\t\t\t\t\tgBT2YT5wLzaLNBPtBUgm1xylI03WXDANBgkqhkiG9w0BAQUFAAOCAQEAJIYNiO5b\n\t\t\t\t\t\tYzb3dZ2PqL3WdhMTg3vHXTBVKKnSegNwd/huTybPzs6oqNIxgDqsxT6/p5WZVz/f\n\t\t\t\t\t\t6MT3bvUnGoy70gNVaSjHZg01QXKCzbEi1C/hcMO1cMdYVYZYAiQeFv7+4HuChkC6\n\t\t\t\t\t\tZIkwMmoSeX/Q13G3ZOltY+xV81E7Afc3+MTeowDYayfRHTpp4SHqRe098k/XJ6w9\n\t\t\t\t\t\t3PMjGO33JAAAaNAJzsmzrtb86q5d9O4r4Y45vRypyBfu6Mr8TbufXsxUEKcdFaRv\n\t\t\t\t\t\tDsKvkemCd+Dir273mcUN+zhGKUhjPAYJsFhb/wWkTmbdk1mBNjIhqavarm/OIyG8\n\t\t\t\t\t\tc91vv7jVI/bPgA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://l4l-idp-01.kent.ac.uk/simplesaml/module.php/saml/sp/saml2-acs.php/UK-AMF",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://l4l-idp-01.kent.ac.uk/simplesaml/module.php/saml/sp/saml1-acs.php/UK-AMF",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://l4l-idp-01.kent.ac.uk/simplesaml/module.php/saml/sp/saml2-acs.php/UK-AMF",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://l4l-idp-01.kent.ac.uk/simplesaml/module.php/saml/sp/saml1-acs.php/UK-AMF/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.lancs.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:iss-service-desk@lancaster.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ISS Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bennett"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:S.Bennett@lancaster.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.lancs.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-04-16T16:54:28Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJjCCAg6gAwIBAgITE/T96ytOqT8HI/CQq7WILI+KmjANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tADAaMRgwFgYDVQQDEw9pZHAubGFuY3MuYWMudWswHhcNMTMwMjE4MTUwNzQyWhcN\n\t\t\t\t\t\tMzMwMjE4MTUwNzQyWjAaMRgwFgYDVQQDEw9pZHAubGFuY3MuYWMudWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCsu+5TFlPyDOccJHktBu8NSnY+Vdwq\n\t\t\t\t\t\tTzwPkSdCGlLzGrqQB0m5vDDIMxBC30i05tknFZP6KBvgPJj5pk0MSmOCXIGU0IG3\n\t\t\t\t\t\tkWUgpOF4Y7fd9NRuD53EF12pZfj88m3w/pVtPTrQOvi/agKgjZGbTDsEfRe0bIkf\n\t\t\t\t\t\tc3z4lzohXGIX+YcOGz0IC6b+XEiioAPMRodtTW8O53p3ttnLJ7Zv5Qs4zul8NQKY\n\t\t\t\t\t\tYmN2/sn2zkJEsE5gz61hY39FFlzAoJ8lGpeF5JgSeJ//2nyFAZ2ik8L8JnvqTwml\n\t\t\t\t\t\tr1UU7cd7tRxG+xy31gKxzqlNaI1PaafjPVdlXcyHROz7ACfznlrZxntZAgMBAAGj\n\t\t\t\t\t\tZTBjMEIGA1UdEQQ7MDmCD2lkcC5sYW5jcy5hYy51a4YmaHR0cHM6Ly9pZHAubGFu\n\t\t\t\t\t\tY3MuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFLuSKcwtlxU2Ivaq/A7T\n\t\t\t\t\t\t5g8LjqVRMA0GCSqGSIb3DQEBBQUAA4IBAQCjrOUZv0J2s8E7MWlO0qAlBeRwRI9/\n\t\t\t\t\t\t/UjuEM1uqgdKqTtFkKkug6BayVXIKErwYVnvhFFkwRqkewPjEeQxIZrnvPYWfqCl\n\t\t\t\t\t\tKV6zaykfU9VCYmP6/yK89A5nTY93IZQ4Rm63mF20LxqZeRxDNLGAd7Fm6y1pdoq7\n\t\t\t\t\t\tDuhJoqENTcQ2ludpmptKESInGhn4r/Pzk6x/SQvRF5/jZLLMy8flrB8KPKUJ3sN0\n\t\t\t\t\t\t6VanTXJSl+jZvaa69WfW+/vlKHnCPEGEuBZFw3b7BJA6wnYuH25Fzrg7zf23nLsB\n\t\t\t\t\t\t74wrr0WZQi7ryvmVcpxoclU/i5jee6m0IHMOtadvVoA625KVX/JBH4Kf"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lancaster.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.lancs.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.lancs.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.lancs.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.lancs.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.lancs.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.lancs.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.lancs.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.lancs.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lancaster.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://idp.lancs.ac.uk/logo-small.png",
                    "height": "54",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "157"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lancaster University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJjCCAg6gAwIBAgITE/T96ytOqT8HI/CQq7WILI+KmjANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tADAaMRgwFgYDVQQDEw9pZHAubGFuY3MuYWMudWswHhcNMTMwMjE4MTUwNzQyWhcN\n\t\t\t\t\t\tMzMwMjE4MTUwNzQyWjAaMRgwFgYDVQQDEw9pZHAubGFuY3MuYWMudWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCsu+5TFlPyDOccJHktBu8NSnY+Vdwq\n\t\t\t\t\t\tTzwPkSdCGlLzGrqQB0m5vDDIMxBC30i05tknFZP6KBvgPJj5pk0MSmOCXIGU0IG3\n\t\t\t\t\t\tkWUgpOF4Y7fd9NRuD53EF12pZfj88m3w/pVtPTrQOvi/agKgjZGbTDsEfRe0bIkf\n\t\t\t\t\t\tc3z4lzohXGIX+YcOGz0IC6b+XEiioAPMRodtTW8O53p3ttnLJ7Zv5Qs4zul8NQKY\n\t\t\t\t\t\tYmN2/sn2zkJEsE5gz61hY39FFlzAoJ8lGpeF5JgSeJ//2nyFAZ2ik8L8JnvqTwml\n\t\t\t\t\t\tr1UU7cd7tRxG+xy31gKxzqlNaI1PaafjPVdlXcyHROz7ACfznlrZxntZAgMBAAGj\n\t\t\t\t\t\tZTBjMEIGA1UdEQQ7MDmCD2lkcC5sYW5jcy5hYy51a4YmaHR0cHM6Ly9pZHAubGFu\n\t\t\t\t\t\tY3MuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFLuSKcwtlxU2Ivaq/A7T\n\t\t\t\t\t\t5g8LjqVRMA0GCSqGSIb3DQEBBQUAA4IBAQCjrOUZv0J2s8E7MWlO0qAlBeRwRI9/\n\t\t\t\t\t\t/UjuEM1uqgdKqTtFkKkug6BayVXIKErwYVnvhFFkwRqkewPjEeQxIZrnvPYWfqCl\n\t\t\t\t\t\tKV6zaykfU9VCYmP6/yK89A5nTY93IZQ4Rm63mF20LxqZeRxDNLGAd7Fm6y1pdoq7\n\t\t\t\t\t\tDuhJoqENTcQ2ludpmptKESInGhn4r/Pzk6x/SQvRF5/jZLLMy8flrB8KPKUJ3sN0\n\t\t\t\t\t\t6VanTXJSl+jZvaa69WfW+/vlKHnCPEGEuBZFw3b7BJA6wnYuH25Fzrg7zf23nLsB\n\t\t\t\t\t\t74wrr0WZQi7ryvmVcpxoclU/i5jee6m0IHMOtadvVoA625KVX/JBH4Kf"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lancaster University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lancaster.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Lancaster"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://bsp-idp-test.shibboleth.ox.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:team@sysdev.oucs.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Services IAM Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:team@sysdev.oucs.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Services IAM Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bsp-idp-test.shibboleth.ox.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-07-19T16:38:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZzCCAk+gAwIBAgIJAM3e/P6wMOMuMA0GCSqGSIb3DQEBBQUAMCsxKTAnBgNV\n\t\t\t\t\t\tBAMTIGJzcC1pZHAtdGVzdC5zaGliYm9sZXRoLm94LmFjLnVrMB4XDTE0MDcwMjA3\n\t\t\t\t\t\tMTI1NloXDTM0MDcwMjA3MTI1NlowKzEpMCcGA1UEAxMgYnNwLWlkcC10ZXN0LnNo\n\t\t\t\t\t\taWJib2xldGgub3guYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCt/2e1JENtpBwhw42LY4rGCDtc90BV3+LCKws4GUTs+OWqUcgpzk0/uDSbIOtl\n\t\t\t\t\t\tAuWR0Sl/EPSbrHdATYOxYXIvBuYWfrBu/h91EcJEaM+ZO72ElDQgahXnTarZMWX6\n\t\t\t\t\t\tJJKPlYgLRVg5e5L98O9BU4u2w5xcvMAlKZ0UgHpTeEBPtgdXIVTltaPFI1601S+b\n\t\t\t\t\t\tB/fDAofXpzYa3HkmaLNJ41QA0rFXAVsek5WFKgsY79ncYkMa5eb69ysj3BLIbAPy\n\t\t\t\t\t\t7DSKFJKMX26+TSRs/j/v2lr1TgGnAvuAkZ9BXwhkRh6jaO59W0oGWtJ2kmxAL4fy\n\t\t\t\t\t\tMuiWxYAuVe9Q+lgMs4Au9/a3AgMBAAGjgY0wgYowHQYDVR0OBBYEFGBKWbztDye4\n\t\t\t\t\t\tIfOgk3iFZXCIcw8HMFsGA1UdIwRUMFKAFGBKWbztDye4IfOgk3iFZXCIcw8HoS+k\n\t\t\t\t\t\tLTArMSkwJwYDVQQDEyBic3AtaWRwLXRlc3Quc2hpYmJvbGV0aC5veC5hYy51a4IJ\n\t\t\t\t\t\tAM3e/P6wMOMuMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBADTLWycf\n\t\t\t\t\t\tBRfbYZl3N+08fIzb+d3lA82OKXTopCv4Jxn5dE8rnql8qunq19PKymn2JvMImTQ5\n\t\t\t\t\t\tgEd+kCxCvWnQdQSmSUhfDbNB3LgBkIw4yIbOdzIlVmzAPL7WaIqjgRyx1JmMPheH\n\t\t\t\t\t\tiGQYoLfVIcDSrLt7mu4ssIrgzxzH/xNgLru+ZW6yuY4UdntS3OyWTssGFW3pqftv\n\t\t\t\t\t\t6aPCyW8KB6ycsPwZGHyGFIbBmJMRFztYVlfKi4MzI7uhsv6TXVfsIxzNopTLL8CS\n\t\t\t\t\t\tw/O6T47a6BBXJjj5BtU9t7h15TTjG/X5Sie1mIPYUjprTZhcuNyzN/LX90F1yM0G\n\t\t\t\t\t\tTIMOueSzlXJLKyY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ox.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://bsp-idp-test.shibboleth.ox.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bsp-idp-test.shibboleth.ox.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://bsp-idp-test.shibboleth.ox.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bsp-idp-test.shibboleth.ox.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://bsp-idp-test.shibboleth.ox.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://bsp-idp-test.shibboleth.ox.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://bsp-idp-test.shibboleth.ox.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bsp-idp-test.shibboleth.ox.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ox.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZzCCAk+gAwIBAgIJAM3e/P6wMOMuMA0GCSqGSIb3DQEBBQUAMCsxKTAnBgNV\n\t\t\t\t\t\tBAMTIGJzcC1pZHAtdGVzdC5zaGliYm9sZXRoLm94LmFjLnVrMB4XDTE0MDcwMjA3\n\t\t\t\t\t\tMTI1NloXDTM0MDcwMjA3MTI1NlowKzEpMCcGA1UEAxMgYnNwLWlkcC10ZXN0LnNo\n\t\t\t\t\t\taWJib2xldGgub3guYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCt/2e1JENtpBwhw42LY4rGCDtc90BV3+LCKws4GUTs+OWqUcgpzk0/uDSbIOtl\n\t\t\t\t\t\tAuWR0Sl/EPSbrHdATYOxYXIvBuYWfrBu/h91EcJEaM+ZO72ElDQgahXnTarZMWX6\n\t\t\t\t\t\tJJKPlYgLRVg5e5L98O9BU4u2w5xcvMAlKZ0UgHpTeEBPtgdXIVTltaPFI1601S+b\n\t\t\t\t\t\tB/fDAofXpzYa3HkmaLNJ41QA0rFXAVsek5WFKgsY79ncYkMa5eb69ysj3BLIbAPy\n\t\t\t\t\t\t7DSKFJKMX26+TSRs/j/v2lr1TgGnAvuAkZ9BXwhkRh6jaO59W0oGWtJ2kmxAL4fy\n\t\t\t\t\t\tMuiWxYAuVe9Q+lgMs4Au9/a3AgMBAAGjgY0wgYowHQYDVR0OBBYEFGBKWbztDye4\n\t\t\t\t\t\tIfOgk3iFZXCIcw8HMFsGA1UdIwRUMFKAFGBKWbztDye4IfOgk3iFZXCIcw8HoS+k\n\t\t\t\t\t\tLTArMSkwJwYDVQQDEyBic3AtaWRwLXRlc3Quc2hpYmJvbGV0aC5veC5hYy51a4IJ\n\t\t\t\t\t\tAM3e/P6wMOMuMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBADTLWycf\n\t\t\t\t\t\tBRfbYZl3N+08fIzb+d3lA82OKXTopCv4Jxn5dE8rnql8qunq19PKymn2JvMImTQ5\n\t\t\t\t\t\tgEd+kCxCvWnQdQSmSUhfDbNB3LgBkIw4yIbOdzIlVmzAPL7WaIqjgRyx1JmMPheH\n\t\t\t\t\t\tiGQYoLfVIcDSrLt7mu4ssIrgzxzH/xNgLru+ZW6yuY4UdntS3OyWTssGFW3pqftv\n\t\t\t\t\t\t6aPCyW8KB6ycsPwZGHyGFIbBmJMRFztYVlfKi4MzI7uhsv6TXVfsIxzNopTLL8CS\n\t\t\t\t\t\tw/O6T47a6BBXJjj5BtU9t7h15TTjG/X5Sie1mIPYUjprTZhcuNyzN/LX90F1yM0G\n\t\t\t\t\t\tTIMOueSzlXJLKyY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Oxford: (BSP-test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ox.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Oxford"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://coastline.instructure.com/saml2",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "http://coastline.instructure.com/saml2",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Instructure, Inc"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.instructure.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Instructure, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://coastline.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://coastline.test.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://coastline.beta.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.canvaslms.com/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://canvas.instructure.com/images/canvas/header_canvas_logo@2x.png",
                    "lang": "en",
                    "height": "220",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "220"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.canvaslms.com/policies/privacy-policy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "OEI - Coastline Community College - Canvas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE8TCCA9mgAwIBAgIJAOBms/PYWcPLMA0GCSqGSIb3DQEBCwUAMIGrMQswCQYD\nVQQGEwJVUzENMAsGA1UECBMEVXRhaDEXMBUGA1UEBxMOU2FsdCBMYWtlIENpdHkx\nGTAXBgNVBAoTEEluc3RydWN0dXJlLCBJbmMxEzARBgNVBAsTCk9wZXJhdGlvbnMx\nIDAeBgNVBAMTF0NhbnZhcyBTQU1MIENlcnRpZmljYXRlMSIwIAYJKoZIhvcNAQkB\nFhNvcHNAaW5zdHJ1Y3R1cmUuY29tMB4XDTE1MDQxNTAxMDAwMFoXDTE3MDQyMjAx\nMDAwMFowgasxCzAJBgNVBAYTAlVTMQ0wCwYDVQQIEwRVdGFoMRcwFQYDVQQHEw5T\nYWx0IExha2UgQ2l0eTEZMBcGA1UEChMQSW5zdHJ1Y3R1cmUsIEluYzETMBEGA1UE\nCxMKT3BlcmF0aW9uczEgMB4GA1UEAxMXQ2FudmFzIFNBTUwgQ2VydGlmaWNhdGUx\nIjAgBgkqhkiG9w0BCQEWE29wc0BpbnN0cnVjdHVyZS5jb20wggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDckDPQGWedlVGC2Z9fn1wNFmN+0IPNi6OSE1nM\nvoTWx2oZlQepaAu4zI5QqOfnV0rW2V1volpoJbu0WelH0DkGzdOEQdWJjAs3nRBf\ny0evxtpg0tK5kIvGsnN6YcD41YmkfWzvwbMf0cEq1Y0wCmymF6XzOUUE4zsi0nhP\nm2Z7WiuongDQdR01UsDN13YcpD/i1JXr3YtkNnJ/a1Kc9OXNycI8M5NVo5QQgdx/\nQ7zAmTk8p9E0ZRthdOQ/PBicWx39mNmBij5KpqCWlHu3NWdgcG8KXSv5atXU8Crd\nTRJ3aGIEN9vBYIHe8MHGCzs1QlRfJmXFMkeUSOTnJJx78rMDAgMBAAGjggEUMIIB\nEDAdBgNVHQ4EFgQUo0WWVlJ1SxZOs11L85ZAuZGyuzEwgeAGA1UdIwSB2DCB1YAU\no0WWVlJ1SxZOs11L85ZAuZGyuzGhgbGkga4wgasxCzAJBgNVBAYTAlVTMQ0wCwYD\nVQQIEwRVdGFoMRcwFQYDVQQHEw5TYWx0IExha2UgQ2l0eTEZMBcGA1UEChMQSW5z\ndHJ1Y3R1cmUsIEluYzETMBEGA1UECxMKT3BlcmF0aW9uczEgMB4GA1UEAxMXQ2Fu\ndmFzIFNBTUwgQ2VydGlmaWNhdGUxIjAgBgkqhkiG9w0BCQEWE29wc0BpbnN0cnVj\ndHVyZS5jb22CCQDgZrPz2FnDyzAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUA\nA4IBAQBV3EmmnzYqYQ5fXNZymG2WaspEW0NeFMhDXa3p3AMIQJbnnU14lR7bqIvf\n/bLW1YE0fw1kSzsw8VrkQp7k1U+kaYA3i5/FQBy2WtqUCVq2GXZA2gs5YD4nvJB/\nF57E//0kEhbATZH9+wJqDkqyIgsrSIlJjiXDth1BppGK8weboPtr9sWV24Ui0+ls\nw16XTsGlnRRO19g+gXKOZp5ApXkDrB+HwZQvZxiCuSgvJlcBzMdxVvWSL+vPtg8Y\nshIKzobIhaQ2MzXHLcxrDhW10YFPwDXh8Tfn5iU9ONsaJivuvVhtDYZD1ZzSoPpm\nq4vYqxxY/6rFJhrCtnlLepSaxlXM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://coastline.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://coastline.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://coastline.beta.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://coastline.beta.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://coastline.test.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://coastline.test.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "OEI - Coastline Community College - Canvas"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib.ufg.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Douglas Borges de Oliveira Filho"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "douglasfilho@cercomp.ufg.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.ufg.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEEjCCAvoCAQAwDQYJKoZIhvcNAQEFBQAwgc4xLDAqBgNVBAoTI1VGRyAtIFVu\naXZlcnNpZGFkZSBGZWRlcmFsIGRlIEdvaWFzMTQwMgYDVQQLEytDRVJDT01QIC0g\nQ2VudHJvIGRlIFJlY3Vyc29zIENvbXB1dGFjaW9uYWlzMSMwIQYJKoZIhvcNAQkB\nFhRyZWRlcy5jZXJjb21wQHVmZy5icjEQMA4GA1UEBxMHR29pYW5pYTEOMAwGA1UE\nCBMFR29pYXMxCzAJBgNVBAYTAkJSMRQwEgYDVQQDEwtzaGliLnVmZy5icjAeFw0x\nNDA3MjIxNTU1NTRaFw0xOTA3MjExNTU1NTRaMIHOMSwwKgYDVQQKEyNVRkcgLSBV\nbml2ZXJzaWRhZGUgRmVkZXJhbCBkZSBHb2lhczE0MDIGA1UECxMrQ0VSQ09NUCAt\nIENlbnRybyBkZSBSZWN1cnNvcyBDb21wdXRhY2lvbmFpczEjMCEGCSqGSIb3DQEJ\nARYUcmVkZXMuY2VyY29tcEB1ZmcuYnIxEDAOBgNVBAcTB0dvaWFuaWExDjAMBgNV\nBAgTBUdvaWFzMQswCQYDVQQGEwJCUjEUMBIGA1UEAxMLc2hpYi51ZmcuYnIwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDjd7v1zv9XiZujENayVRf+lRcF\nHvUq3KtLFWnys3UhsAlQPiXl3rCdCV3qgC3mLFKoQtCIvxW0ubaX7E+7U1FGdLZH\nZBgkCXdvJ32wMtF/DEhiD/AwT6JMjSWLcE9eGK35NBaB6kC91Pn9oID8OjggQmFA\not2NQ7KRlSNJg3nY3RQYCFZghgsLec9+0h/YHaRuKgDKcFnreAQ9UQ4M4Q1jPKit\nFkn/IJa2okSwXIu6gwV/2Y2I92ar3LgbNfpXCPW/gGqflkPEA+4AXwRb7ZbOdqsD\ng/PLMzi3jS4VHIOVUHx4fg7PZF+CEJpNG65i5pQB2d9VI2he2e3gUtnYxZeBAgMB\nAAEwDQYJKoZIhvcNAQEFBQADggEBAIGSDjTFfq0AONjf4OEJxiG1pZ5um0QwIzUD\nhC+CCdoxsZcUc47cT+VxHi5vrJ1TBJF8mwk1zTp0CKfNxPt+etJMhNwnXhjR7qF/\nA7JtQE9MuoHiWpjIWiwck00x6pAqJCkEcYRrz5UorN6YjBd/3SEkKU0qv1haRVPV\nEqoljRD7IOrbW5m12y+UCojor5ttyl5aYIk3DYXLlqiddtxHwyAyP4VKxOS5373c\nCmAJ4XbSf9+t9lVDXZtJ7GST/AoVT4775ELCkfN/EjEXzqg8uxWgl89feJQyz1u6\n4mvZ4bNMmCEq59Krwicex9EzFraCH4W99LvdMvKBp88MseBihz8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufg.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.ufg.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.ufg.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.ufg.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.ufg.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.ufg.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.ufg.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.ufg.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.ufg.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufg.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufg.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufg.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFG - Universidade Federal de Goias"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFG - Universidade Federal de Goias"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFG - Universidade Federal de Goias"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFG - Universidade Federal de Goias"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEEjCCAvoCAQAwDQYJKoZIhvcNAQEFBQAwgc4xLDAqBgNVBAoTI1VGRyAtIFVu\naXZlcnNpZGFkZSBGZWRlcmFsIGRlIEdvaWFzMTQwMgYDVQQLEytDRVJDT01QIC0g\nQ2VudHJvIGRlIFJlY3Vyc29zIENvbXB1dGFjaW9uYWlzMSMwIQYJKoZIhvcNAQkB\nFhRyZWRlcy5jZXJjb21wQHVmZy5icjEQMA4GA1UEBxMHR29pYW5pYTEOMAwGA1UE\nCBMFR29pYXMxCzAJBgNVBAYTAkJSMRQwEgYDVQQDEwtzaGliLnVmZy5icjAeFw0x\nNDA3MjIxNTU1NTRaFw0xOTA3MjExNTU1NTRaMIHOMSwwKgYDVQQKEyNVRkcgLSBV\nbml2ZXJzaWRhZGUgRmVkZXJhbCBkZSBHb2lhczE0MDIGA1UECxMrQ0VSQ09NUCAt\nIENlbnRybyBkZSBSZWN1cnNvcyBDb21wdXRhY2lvbmFpczEjMCEGCSqGSIb3DQEJ\nARYUcmVkZXMuY2VyY29tcEB1ZmcuYnIxEDAOBgNVBAcTB0dvaWFuaWExDjAMBgNV\nBAgTBUdvaWFzMQswCQYDVQQGEwJCUjEUMBIGA1UEAxMLc2hpYi51ZmcuYnIwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDjd7v1zv9XiZujENayVRf+lRcF\nHvUq3KtLFWnys3UhsAlQPiXl3rCdCV3qgC3mLFKoQtCIvxW0ubaX7E+7U1FGdLZH\nZBgkCXdvJ32wMtF/DEhiD/AwT6JMjSWLcE9eGK35NBaB6kC91Pn9oID8OjggQmFA\not2NQ7KRlSNJg3nY3RQYCFZghgsLec9+0h/YHaRuKgDKcFnreAQ9UQ4M4Q1jPKit\nFkn/IJa2okSwXIu6gwV/2Y2I92ar3LgbNfpXCPW/gGqflkPEA+4AXwRb7ZbOdqsD\ng/PLMzi3jS4VHIOVUHx4fg7PZF+CEJpNG65i5pQB2d9VI2he2e3gUtnYxZeBAgMB\nAAEwDQYJKoZIhvcNAQEFBQADggEBAIGSDjTFfq0AONjf4OEJxiG1pZ5um0QwIzUD\nhC+CCdoxsZcUc47cT+VxHi5vrJ1TBJF8mwk1zTp0CKfNxPt+etJMhNwnXhjR7qF/\nA7JtQE9MuoHiWpjIWiwck00x6pAqJCkEcYRrz5UorN6YjBd/3SEkKU0qv1haRVPV\nEqoljRD7IOrbW5m12y+UCojor5ttyl5aYIk3DYXLlqiddtxHwyAyP4VKxOS5373c\nCmAJ4XbSf9+t9lVDXZtJ7GST/AoVT4775ELCkfN/EjEXzqg8uxWgl89feJQyz1u6\n4mvZ4bNMmCEq59Krwicex9EzFraCH4W99LvdMvKBp88MseBihz8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFG - Universidade Federal de Goias"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFG - Universidade Federal de Goias"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufg.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufg.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFG - Universidade Federal de Goias"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFG - Universidade Federal de Goias"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dlib-shandon.ucs.ed.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Stuart"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alex.stuart@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Stuart"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alex.stuart@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dlib-shandon.ucs.ed.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-02-08T16:02:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EDINA test SP Shandon"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://dlib-shandon.ucs.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-shandon.ucs.ed.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dlib-shandon.ucs.ed.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dlib-shandon.ucs.ed.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dlib-shandon.ucs.ed.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-shandon.ucs.ed.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "EDINA test SP Shandon"
                  }
                ],
                "logo": [
                  {
                    "text": "https://dlib-shandon.ucs.ed.ac.uk/alex.stuart.128x128.png",
                    "height": "128",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "128"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EDINA test SP Shandon"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dlib-shandon.ucs.ed.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dlib-shandon.ucs.ed.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEiDCCA3CgAwIBAgIJAPqKfjAaPVnJMA0GCSqGSIb3DQEBBQUAMIHEMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjERMA8GA1UECAwIU2NvdGxhbmQxEjAQBgNVBAcMCUVkaW5idXJnaDEg\n\t\t\t\t\t\tMB4GA1UECgwXVW5pdmVyc2l0eSBvZiBFZGluYnVyZ2gxIzAhBgNVBAsMGkVESU5B\n\t\t\t\t\t\tIGFuZCBUaGUgRGF0YSBMaWJyYXJ5MSIwIAYDVQQDDBlkbGliLXNoYW5kb24udWNz\n\t\t\t\t\t\tLmVkLmFjLnVrMSMwIQYJKoZIhvcNAQkBFhRhbGV4LnN0dWFydEBlZC5hYy51azAe\n\t\t\t\t\t\tFw0xNDA1MDcxNTU4MjJaFw0yNDA1MDQxNTU4MjJaMIHEMQswCQYDVQQGEwJHQjER\n\t\t\t\t\t\tMA8GA1UECAwIU2NvdGxhbmQxEjAQBgNVBAcMCUVkaW5idXJnaDEgMB4GA1UECgwX\n\t\t\t\t\t\tVW5pdmVyc2l0eSBvZiBFZGluYnVyZ2gxIzAhBgNVBAsMGkVESU5BIGFuZCBUaGUg\n\t\t\t\t\t\tRGF0YSBMaWJyYXJ5MSIwIAYDVQQDDBlkbGliLXNoYW5kb24udWNzLmVkLmFjLnVr\n\t\t\t\t\t\tMSMwIQYJKoZIhvcNAQkBFhRhbGV4LnN0dWFydEBlZC5hYy51azCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBAL0j7OIzaKbgJNrZe3ZLqU+uFjS7fz+JxRoM\n\t\t\t\t\t\tTOeRH7NogfeG1PsaKQ4XS1yjcwYfdo+uXY26RGj9MCGzhzA4DLG1ATFjS+JTovkZ\n\t\t\t\t\t\tVZKvqokVANinHj036TL/VblLNssHzwvylQB6/SS9R0TvLMShl/3QGIzy8OgHAFao\n\t\t\t\t\t\tp7Bq34l40Y3Qyiz70bWhBGXvgdWdidfW5K7qm29MPiikZDrAhB96Ip1F4VPIiTDx\n\t\t\t\t\t\t4WgITpb975DpWv73Doxu49DFXva79ap1any8fFITU8VzC2W2LStJF9bghIBOH2QX\n\t\t\t\t\t\tQPY8nxd17eaUhcSZ0pVYsbp6nVeXCVDm0IPdiZbb+79V73XkN4sCAwEAAaN7MHkw\n\t\t\t\t\t\tCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2Vy\n\t\t\t\t\t\tdGlmaWNhdGUwHQYDVR0OBBYEFOC+S9U3B8a38AldV3o2P82UrA2UMB8GA1UdIwQY\n\t\t\t\t\t\tMBaAFOC+S9U3B8a38AldV3o2P82UrA2UMA0GCSqGSIb3DQEBBQUAA4IBAQA+/SO8\n\t\t\t\t\t\tWtEc1/L5m35DCHMXRko5cHlKvmi74Wl8pJuQvnUSiQ1wlwapAD2uQOfXtSOC/0Kp\n\t\t\t\t\t\tMtuVbmDtF3YKlxJwRovhMS8D7P9EYkoFm8f2nALAoWkQ1Ol5MiYfunz+0eDaWwON\n\t\t\t\t\t\twlvP5m3o8h7UjFdcekE0A8aMBgc6eHbqwjJKRyk9kuoMVbi4zOW310AB+hyYDxuU\n\t\t\t\t\t\tNM83E+8je9IYeR0ErHXsfcNeCABHeE35HgOOGAaQ0iMRnWfjNcLfHaPlhYHLx1PD\n\t\t\t\t\t\t8HNLKwjHo3p8Ps2yLftHKlTlvs3Co3i4S06bIGwpTCqrsQrd9DX2TKU1yL2FerGf\n\t\t\t\t\t\taR2/8JsykowRxXZw"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dlib-shandon.ucs.ed.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dlib-shandon.ucs.ed.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dlib-shandon.ucs.ed.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dlib-shandon.ucs.ed.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dlib-shandon.ucs.ed.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dlib-shandon.ucs.ed.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.vet-alfort.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Herv\u00e9 Battaglia"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "herve.battaglia@vet-alfort.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.vet-alfort.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-06-06T14:14:52Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.vet-alfort.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.vet-alfort.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.vet-alfort.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vet-alfort.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.vet-alfort.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ENVA Students, Teachers and researchers and employees."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Etudiants, Enseignants-Chercheur, Personnels de l'ENVA"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "National Veterinary School of Alfort"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Nationale V\u00e9t\u00e9rinaire d'ALFORT"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAO3N41irRpARAo+XP9yzoR89gA0sMA0GCSqGSIb3DQEB\nBQUAMBwxGjAYBgNVBAMTEWlkcC52ZXQtYWxmb3J0LmZyMB4XDTE0MDYwNjA4NDcz\nNVoXDTM0MDYwNjA4NDczNVowHDEaMBgGA1UEAxMRaWRwLnZldC1hbGZvcnQuZnIw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCDMy3shCyhtNVjXK6/6gSc\nseewwAOZRAPaOppoj+iGJ+261cOu/JthyfDkRnxXvuDkbwatFyqzGBAjZUWrjj9F\nvpLA8AhKFn555ZdFaEz613xB1Ixt2erYh0/B7n54jMKX/R6puVfBPqviYagJBBav\nGe2tNJu2Q2/qjkWBf9tIE0ZrKAXQJWYwAiaWIFa4nECbmlEq2Y5iyA/Um6xLRwLZ\njPPr0CNDE86h8z4HTppc5q6Vam7mN4wHlKUWlf6Ie4zPy7WnW6Bp1gxqkx1zGeeA\npqHYd3H3Mw6Nxpa3W1CUsIXdIYSKpo/ahfpipK8ci5DExUgfjG+IUMnGcoACdX2X\nAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEWlkcC52ZXQtYWxmb3J0LmZyhihodHRwczov\nL2lkcC52ZXQtYWxmb3J0LmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQdpcAH\nJJCWpA6ERBlywLRbThojDTANBgkqhkiG9w0BAQUFAAOCAQEAeVSp+V5olBI0kcyV\n02igfUKwnrCD116/yABfvo8lpLCVhTI0Hydfyywq9duJNZnpmtlNdgRN+d+OUnx3\nhlDvg1BAh1jPObwa0e9i4KtAr6fZHVxs3TczaUW2V+qdzQCPDj2y+qkEeFyCFEoP\ntAv7a/xGeAqQ4dupq2j6RlqfB62GdZGhfvzLJIUCz4MkH+X2SSRoAwrTUwPkeeqa\nxQIiyDnuAGh+RL+tU4BzJZkfmyLDtgrN+jP1rlmBIph0JB3uV2zG0FuIboFlIkZP\n8juD6wsMppjhxFHr+jq4B9iUmMNMCgsg6gX60VF7JNvTuoB6iXE77dJ/a1o7SXlh\n95exag=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ecole Nationale V\u00e9t\u00e9rinaire d'ALFORT"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vet-alfort.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ecole Nationale V\u00e9t\u00e9rinaire d'ALFORT"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://census.mimas.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:census@mimas.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CDU Census Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mimas-shib-tech@listserv.manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mimas Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://census.mimas.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-07-01T11:00:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MIMAS: Census Datasets including SARs and CIDER"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://cdu.mimas.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Manchester"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://census.mimas.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://census.mimas.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://census.mimas.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://census.mimas.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Online access to aggregate data from the 1971, 1981, 1991 and 2001 UK Census of Population."
                  }
                ],
                "logo": [
                  {
                    "text": "https://census.mimas.ac.uk/cdu_new.jpg",
                    "height": "75",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "200"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Census Dissemination Unit"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKzCCAxOgAwIBAgIJAMTX7HKZbFDFMA0GCSqGSIb3DQEBBQUAMIGLMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjETMBEGA1UECBMKTWFuY2hlc3RlcjETMBEGA1UEBxMKTWFuY2hlc3Rl\n\t\t\t\t\t\tcjElMCMGA1UEChMcVGhlIFVuaXZlcnNpdHkgb2YgTWFuY2hlc3RlcjEOMAwGA1UE\n\t\t\t\t\t\tCxMFTWltYXMxGzAZBgNVBAMTEmNlbnN1cy5taW1hcy5hYy51azAeFw0xMzA1MzAx\n\t\t\t\t\t\tNTI3MzBaFw0yMzA1MjgxNTI3MzBaMIGLMQswCQYDVQQGEwJHQjETMBEGA1UECBMK\n\t\t\t\t\t\tTWFuY2hlc3RlcjETMBEGA1UEBxMKTWFuY2hlc3RlcjElMCMGA1UEChMcVGhlIFVu\n\t\t\t\t\t\taXZlcnNpdHkgb2YgTWFuY2hlc3RlcjEOMAwGA1UECxMFTWltYXMxGzAZBgNVBAMT\n\t\t\t\t\t\tEmNlbnN1cy5taW1hcy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBALfJujuG3l2vwtdzi3/ZIcAKfFwC5RKAHLHLBUejvFA/nkt7OnOonu0x689R\n\t\t\t\t\t\tIEBd877zeYd0ZH3GAMBVX7zJiQ11jdLYHUEVi8d/8Hx3dZ2nXXFdPzJL2OIJzHc2\n\t\t\t\t\t\taQQgdWmRrTge6r10NcVOAAJ5mIIHK7PPifDwVMMN1GuF4OBA3aojaMP0Dj+DO1gr\n\t\t\t\t\t\tFCZtGi3VE17cxKTZdmuiRsFYGifIBvkSdmopv3+ibW6fukO564pRxHAywRqhZd2E\n\t\t\t\t\t\tpMGx3G7pbXNIZYB6Xje5DGp/qOB0SOdC6kSJjdeaWsyYfSQOAdyVZm91ZFD8qmES\n\t\t\t\t\t\tZ5aL66VIprPYDGjYx6tZ+eHsGfsCAwEAAaOBjzCBjDAJBgNVHRMEAjAAMAsGA1Ud\n\t\t\t\t\t\tDwQEAwIEsDAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwHQYDVR0RBBYw\n\t\t\t\t\t\tFIISY2Vuc3VzLm1pbWFzLmFjLnVrMDQGA1UdEgQtMCuBKW1pbWFzLXNoaWItdGVj\n\t\t\t\t\t\taEBsaXN0c2Vydi5tYW5jaGVzdGVyLmFjLnVrMA0GCSqGSIb3DQEBBQUAA4IBAQAl\n\t\t\t\t\t\tpfv7zAn13s6WPzfCqNEBqsr9h8Vg79uNxsLfql484q/7CSkTcpe7pTVa1TlOqXbK\n\t\t\t\t\t\t0emzlq6YDyESAw+jtlfFz0Rd1CUU9YrpS3dMXlx+7gbicJKi3H5dOpvMz1mxqni7\n\t\t\t\t\t\tqERoTHr+xMHTNsnuIe/h7osNo7sJJhMrLhgmywVeSNbEg4Y5pudwDMBegts7Vwa1\n\t\t\t\t\t\tCMLitQ8xllB/hq7QUaZNDgv4SVuWLaJENE4jmE6/Q3UVz82ocs0IlQT2+8eKcA8N\n\t\t\t\t\t\tO+QI2PQgwQ5bUHCPKsZz/04ZwAGER/CGgN+2gRPSigWmcU/uFgp63mZ8Q1a3qA6m\n\t\t\t\t\t\t2j+Cllx9NsHLxRQvuS3t"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://census.mimas.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://census.mimas.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://census.mimas.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://census.mimas.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://census.mimas.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://census.mimas.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://census.mimas.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://census.mimas.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://census.mimas.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://census.mimas.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://denali.accessiblelearning.com/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rob.armas@dsaim.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert Armas"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "haris.gunadi@dsaim.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Haris Gunadi"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://denali.accessiblelearning.com/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Accessible Information Management, LLC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://accessiblelearning.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Accessible Information Management, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://denali.accessiblelearning.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.accessiblelearning.com"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Accessible Information Management, LLC"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "AIM LLC provides software and support, systems implementation and integration, strategic consulting, and technology management services to help colleges and universities build, unify, and manage their disability services accommodations. Enterprise solutions for administration and recordkeeping. Portal solutions to enhance Web-based experiences and support community building Technology management services to better manage technology resources and provide metrics on demand. Bringing together people, processes, and technology, AIM LLC works with colleges and universities to help them strengthen performance and services through improved data accuracy and integrity, increased accountability, and enhanced educational experiences."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.accessiblelearning.com/Shibboleth/logo.png",
                    "lang": "en",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.accessiblelearning.com/Policies.aspx"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFWTCCBEGgAwIBAgIJAJCgU68qOR2fMA0GCSqGSIb3DQEBCwUAMIG0MQswCQYD\nVQQGEwJVUzEQMA4GA1UECBMHQXJpem9uYTETMBEGA1UEBxMKU2NvdHRzZGFsZTEa\nMBgGA1UEChMRR29EYWRkeS5jb20sIEluYy4xLTArBgNVBAsTJGh0dHA6Ly9jZXJ0\ncy5nb2RhZGR5LmNvbS9yZXBvc2l0b3J5LzEzMDEGA1UEAxMqR28gRGFkZHkgU2Vj\ndXJlIENlcnRpZmljYXRlIEF1dGhvcml0eSAtIEcyMB4XDTE1MDkwOTA2MDg0NVoX\nDTE4MDkwOTA2MDg0NVowSzEhMB8GA1UECxMYRG9tYWluIENvbnRyb2wgVmFsaWRh\ndGVkMSYwJAYDVQQDEx1kZW5hbGkuYWNjZXNzaWJsZWxlYXJuaW5nLmNvbTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAPn8KQ5vbg7jbT2WBLeoU/NEf380\nD5e1FcpRGwOKLSB8GHEJyiTUrAdGWIuiolLNcyPs+gc3Pe/rlI7RXJEbMuTkl0h6\nKfrrHhaeQRru1KDOBobZpojrGI6QwouXqboJ0DQap3vIQ9eHNyp3HHtBpq9ixey8\ndcci6g2zf/DVHAfPLr/iBc310201Fd2PxWwYPWIFxc7ADXlSOd6dLWwLi/HqiCgP\nEqGEFI/hNxcGknjKO4kvWP+EXyGMHId45trKs17aL4qQ5YqZJzBUT9MMFuQULe4l\nOxqi9i8yVGv9sx3ZIBgtHQ9sOcnqG6fCRI8eiX1UN0ygT2BP4uiXmKts5OECAwEA\nAaOCAdQwggHQMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsG\nAQUFBwMCMA4GA1UdDwEB/wQEAwIFoDA3BgNVHR8EMDAuMCygKqAohiZodHRwOi8v\nY3JsLmdvZGFkZHkuY29tL2dkaWcyczEtMTIwLmNybDBTBgNVHSAETDBKMEgGC2CG\nSAGG/W0BBxcBMDkwNwYIKwYBBQUHAgEWK2h0dHA6Ly9jZXJ0aWZpY2F0ZXMuZ29k\nYWRkeS5jb20vcmVwb3NpdG9yeS8wdgYIKwYBBQUHAQEEajBoMCQGCCsGAQUFBzAB\nhhhodHRwOi8vb2NzcC5nb2RhZGR5LmNvbS8wQAYIKwYBBQUHMAKGNGh0dHA6Ly9j\nZXJ0aWZpY2F0ZXMuZ29kYWRkeS5jb20vcmVwb3NpdG9yeS9nZGlnMi5jcnQwHwYD\nVR0jBBgwFoAUQMK9J47MNIMwojPX+2yz8LQsgM4wSwYDVR0RBEQwQoIdZGVuYWxp\nLmFjY2Vzc2libGVsZWFybmluZy5jb22CIXd3dy5kZW5hbGkuYWNjZXNzaWJsZWxl\nYXJuaW5nLmNvbTAdBgNVHQ4EFgQUWapayNiWuz6gDq0SA5Msc5i6tXMwDQYJKoZI\nhvcNAQELBQADggEBAKM7pRD7bqey9WbCO/a63znlwuoXoQihCZgNzny58mDkZid3\n5YdTwWwv3FYOSgcuGkos5/Nr/vWbD0SFF2PotRGCfUuMe2EUp9Ln5h00OdtxV2lt\nEVtTL/HbR++4hW2H3wk3uJZrYKS58SGAwRxwY6gk18iQM0TI8vLMnx3eiFkDFEYt\nnMn7NPdmaJmi1M5CdNhNVcmesTLuDot3GTxIoJCTg5N6eRvGCmZTMXlHXiar/Abn\n4pYZMHZ7ZupS5lGlnQg8UG8lFToDcxqlhNDwuzlmHKOF0NI/dv/OFg3Hnz5uzqLy\n+dCDacyJY1Rr3eQl4Mrvdc5Zm5umdklSbQ7BBX8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://denali.accessiblelearning.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://denali.accessiblelearning.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://denali.accessiblelearning.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://denali.accessiblelearning.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://denali.accessiblelearning.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://denali.accessiblelearning.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Accessible Information Management, LLC"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "AIM LLC provides software and support, systems implementation and integration, strategic consulting, and technology management services to help colleges and universities build, unify, and manage their disability services accommodations. Enterprise solutions for administration and recordkeeping. Portal solutions to enhance Web-based experiences and support community building Technology management services to better manage technology resources and provide metrics on demand. Bringing together people, processes, and technology, AIM LLC works with colleges and universities to help them strengthen performance and services through improved data accuracy and integrity, increased accountability, and enhanced educational experiences."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "cn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "o",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://wayf.wayf.dk",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://wayf.wayf.dk",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2008-03-28T00:00:00Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://wayf.wayf.dk/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://wayf.wayf.dk/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kb.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hi.is"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ruc.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "orphanage.wayf.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucl.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aau.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "viauc.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucc.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "drlund-gym.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sdu.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "itu.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aip.itsf.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gg.itsf.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mg.itsf.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sska.itsf.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sss.itsf.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "its.itsf.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sikker-adgang.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ibc.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rungsted-gym.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucsj.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dab.minibib.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fsv.minibib.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dsl.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "zbc.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "frsgym.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cbs.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uniit.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ku.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kristne-gym.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vordingborg-gym.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dmjx.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "apoteket.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "erhvervsakademiaarhus.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kadk.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dtu.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucn.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "frhavn-gym.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sde.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eal.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hrs.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "au.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "knord.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eucnord.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "phmetropol.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "handelsskolen.com"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cphbusiness.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kea.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eadania.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dansidp.stads.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "umit.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rosborg-gym.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "basyd.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "statsbiblioteket.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eamv.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aams.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "regionsjaelland.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dskd.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fms.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "smk.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "msk.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "drcmr.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "simac.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucsyd.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "this.is.not.a.valid.idp"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "adm.aau.dk@aau.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aub.aau.dk@aau.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "civil.aau.dk@aau.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "create.aau.dk@aau.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "es.aau.dk@aau.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hst.aau.dk@aau.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "id.aau.dk@aau.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "its.aau.dk@aau.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "learning.aau.dk@aau.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "m-tech.aau.dk@aau.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "plan.aau.dk@aau.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sbi.aau.dk@aau.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "staff.aau.dk@aau.dk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "student.aau.dk@aau.dk"
              },
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "WAYF - den danske identitetsfederation for forskning og uddannelse"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "WAYF - The Danish identity federation for research and higher education"
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WAYF - Where Are You From"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WAYF - Where Are You From"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "WAYF - Where are you from"
          },
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "WAYF - Where are you from"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://wayf.dk/index.php/da"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://wayf.dk/index.php/en"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "WAYF - Where are you from"
          },
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "WAYF - Where are you from"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.www.kielipankki.fi",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Matthiesen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kielipankki@csc.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Aalto"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kielipankki@csc.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tero"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.www.kielipankki.fi",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.csc.fi/english/institutions/haka/instructions/join/eduGAINRegistrationStatement/"
              }
            ],
            "registration_authority": "http://www.csc.fi/haka",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CSC - Tieteen tietotekniikan keskus Oy"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CSC - IT Center for Science Ltd."
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CSC - Tieteen tietotekniikan keskus Oy"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csc.fi"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csc.fi"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csc.fi"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CSC - Tieteen tietotekniikan keskus Oy"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CSC - IT Center for Science Ltd."
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CSC - Tieteen tietotekniikan keskus Oy"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.kielipankki.fi/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Kielipankin portaali"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Web portal of the Language Bank of Finland"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.kielipankki.fi/wp-content/uploads/KIELIPANKKI_logotxt_SU_EN.png",
                    "height": "58",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "300"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.kielipankki.fi/privacy-policy/"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.kielipankki.fi/tietosuojaseloste/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kielipankki"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kielipankki (The Language Bank of Finland)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGOjCCBSKgAwIBAgIQBEdR8xdmmq3NYQebTVAwOjANBgkqhkiG9w0BAQ0FADBk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\nukUJvoKA4qzHcF2rQn4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://www.kielipankki.fi/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Kielipankin portaali"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Web portal of the Language Bank of Finland"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Kielipankki"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Kielipankki (The Language Bank of Finland)"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "cn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.hec.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sysrxadm@hec.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.hec.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-05-30T17:41:27Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.hec.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.hec.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.hec.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hec.edu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hec.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.hec.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "hec.fr"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "hec.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "HEC Paris"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "HEC Paris"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAIBa5+GwoumXjRKqli33Kv809ka2MA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC5oZWMuZnIwHhcNMTQwNTI2MTI1MjQ1WhcNMzQw\nNTI2MTI1MjQ1WjAVMRMwEQYDVQQDEwppZHAuaGVjLmZyMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAs2ddxGn8jnI0f+CiK8kkYgXsmvo0mdj7d9ONHxqo\nu9/eM0iVxBJ3Nm8DE8NPfwqQ8b7YgYp3D4IABKQsf9qv3ZY9d8t5ZIH4QpGYV0oQ\n7vA8ENTxT8w9/guwzQ/IbHRRxOrb/yUnWGGHNhdkqK9R/dicYIJtqaEVvV5nXak1\nkWS8NSKt0lqBsVk4nbEMBiQ4DSioh94QmM9Gk9C7KGsbWYlou/7OaEAnrxLuJjhu\nLVp2oyqlNpLa0D3MUP0cFCJdvC7adCYp9QhfM+F3RT9F5VswssQpwjzy73LPSsIM\nMtnQDpFbWzxatab6YrHsYd27VVsSKBMaDi+V8P62nwbAnQIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAuaGVjLmZyhiFodHRwczovL2lkcC5oZWMuZnIvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFBrlIFW8BhPWzf/KmmnPQeDLI6emMA0GCSqGSIb3DQEB\nBQUAA4IBAQAlHB/u8LUZqoFJcyHutPdhyIppdHMyN3E/cHVsOeHnAZzXrCaiNXak\nvZjymOGHsPq1ySs7ytueu0glwIy76fdLYws1z+iM3swctvAqgRNCv6W2foSLxygD\nB4z5EvUrYQe5a2UdJPYkx8IQSF7PVB6+737ecXPL6zE77wJun9vQjvYBnK0p+aJE\nE78mIpl/HazMsw7Hi5drLGi5hl0D4QWg1FlCtEdQlLizzwTA1fQpFR4B8V7Pi7BD\nurLe9BfmSB9pKYM38V5hbcPoZWXMHASiOsWem0KLofPQe+uLd3SS//aqJJy7tWna\nyR8iVSZb+1XrsdYfsXmZIJjw/OfeN3eA"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "HEC Paris"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hec.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HEC Paris"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://wasp.princeton.edu/simplesaml/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "serge@princeton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Serge Goldstein"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "serge@princeton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Serge Goldstein"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "perry@princeton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kevin Perry"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "serge@princeton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Serge Goldstein"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://wasp.princeton.edu/simplesaml/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Princeton University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.princeton.edu/index.shtml"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Princeton University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://wasp.princeton.edu/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://wasp.princeton.edu/docs/WASP.docx"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "WASP allows the scheduling of office/advising hour appointments via a web interface.  The system can sync appointments into Exchange of Google calendars.  It has a reminder system.  It supports LTI integration."
                  }
                ],
                "logo": [
                  {
                    "text": "https://wasp.princeton.edu/princeton/views/images/wasplogo.gif",
                    "lang": "en",
                    "height": "110",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "341"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WASP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEHTCCAwWgAwIBAgIJAPRNAT0aQ+S5MA0GCSqGSIb3DQEBCwUAMIGkMQswCQYD\nVQQGEwJVUzETMBEGA1UECAwKTmV3IEplcnNleTESMBAGA1UEBwwJUHJpbmNldG9u\nMR0wGwYDVQQKDBRQcmluY2V0b24gVW5pdmVyc2l0eTEMMAoGA1UECwwDT0lUMRsw\nGQYDVQQDDBJ3YXNwLnByaW5jZXRvbi5lZHUxIjAgBgkqhkiG9w0BCQEWE3Nlcmdl\nQHByaW5jZXRvbi5lZHUwHhcNMTUwODE0MTgxODA4WhcNMjUwODEzMTgxODA4WjCB\npDELMAkGA1UEBhMCVVMxEzARBgNVBAgMCk5ldyBKZXJzZXkxEjAQBgNVBAcMCVBy\naW5jZXRvbjEdMBsGA1UECgwUUHJpbmNldG9uIFVuaXZlcnNpdHkxDDAKBgNVBAsM\nA09JVDEbMBkGA1UEAwwSd2FzcC5wcmluY2V0b24uZWR1MSIwIAYJKoZIhvcNAQkB\nFhNzZXJnZUBwcmluY2V0b24uZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\nCgKCAQEAvZkxf3g7BLrMfd6SbQvD0uBbkwlzYJhqcijxGHupH+G3wWY29i6GGVvM\nzrtcc+lEuGeUdeMGvCaCzF5sEjIu3PIaNxJ5i2oyGRd/InSeL5ryhkws4smGweXw\ngTc0Iqfosha6U6X7XUvW5uo9VFj1g7F0JBZ307cltTns1vGdIrp5O5N+LeBhGm2N\nnB0q3ZKUS+CoHFwKEYqAXxYnzPJ0AiFDkh2ykNX1OpI1OmdE+wcmKj6F0pfPXNYU\nE6tkIr0wZeuyG0vMTMtWRxyfhlkbUIV9bcHEaIsQd2CIaVOPC+3zr32VBr0oUCEf\nsuhheG9ChroWl817G56Ky9pP/uPU8wIDAQABo1AwTjAdBgNVHQ4EFgQUlDLQgbJd\nx6pXW+goY2AawSYC2HYwHwYDVR0jBBgwFoAUlDLQgbJdx6pXW+goY2AawSYC2HYw\nDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAQEAH4CsJEJgV9WVmKbxwVvw\nE8OaeAkDOYvx9+I7WbpX0w/Rub2Lc6RS+IRFOwf/iXMCBTKC3KP44PjQitaz1yq1\nv9mcs6CLIR7LnZ7OzHcWxv0yvEnG6NoCn6AKA1NlVodardk5G9AetJUsq6azJl70\n2bb4O+ChAJ972uy4mekmHOAJ5SuSI09ZgDJ9qpOYoGQLrsxRPO3l2CXECeUxcJgB\n9lna+TsnlO7NTbU7y6coZTGQj6/v2ujJhG1RZotxJuqCinozERehO1xoRVd+4YtG\nXD0CM2DXnzaFsSdZVsfS/EXgliB6PcEkMr0O2ue45mCIwag7Y+hXuMfg/eDtfubN\nmQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wasp.princeton.edu/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://wasp.princeton.edu/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wasp.princeton.edu/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://wasp.princeton.edu/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "WASP"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "WASP allows the scheduling of office/advising hour appointments via a web interface.  The system can sync appointments into Exchange of Google calendars.  It has a reminder system.  It supports LTI integration."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "cn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://portal.moonshot.ja.net/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bishop"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Adam.bishop@ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bishop"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Adam.bishop@ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://portal.moonshot.ja.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-06-04T09:59:13Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Moonshot Portal"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://assent.jisc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "JISC Collections and Janet Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://assent.jisc.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://assent.jisc.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://assent.jisc.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://assent.jisc.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://assent.jisc.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Self-service portal to configure trust links for Moonshot IdPs and RPs"
                  }
                ],
                "logo": [
                  {
                    "text": "https://wiki.moonshot.ja.net/download/attachments/360449/global.logo?version=2&modificationDate=1390577635000&api=v2",
                    "height": "400",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "400"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Moonshot Portal"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://assent.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://assent.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAPSyqGhwjBRoMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\n\t\t\t\t\t\tBAMTEnAxLm1vb25zaG90LmphLm5ldDAeFw0xNDA2MDMxNTE5MzVaFw0yNDA1MzEx\n\t\t\t\t\t\tNTE5MzVaMB0xGzAZBgNVBAMTEnAxLm1vb25zaG90LmphLm5ldDCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBAJuhB6CwLcwlMU1BCmk7K2dV0tbnx7uOd2xP\n\t\t\t\t\t\t6u2OIMpfc6DybIXXbrFlvQc0iu74D8BwVZliaThcufwdCCuRYawa+WgfGq2vbC+e\n\t\t\t\t\t\tZDLWub927i71sVPGvUbjpf2o70CWWd8mnJI8O1GW/4h75izs4o6rzIUYKKhhZj8+\n\t\t\t\t\t\tbT1WfpQIEl6f4dfCaL0BwxcJdtUB5mRXIluvJ/jIOwrZfUwBtt4kTwNv+O5ZnSDR\n\t\t\t\t\t\tka9xUVMb5zo5ThKQwvyIasrWHvtJTVrDgipgl5U3yy0pICbefHsVRGsWI9tpedGE\n\t\t\t\t\t\tyk9lBy4aaitqVUw0wAj9c819R/kFfUO7rrFDL9XXW6fb89JSwsECAwEAAaNAMD4w\n\t\t\t\t\t\tHQYDVR0RBBYwFIIScDEubW9vbnNob3QuamEubmV0MB0GA1UdDgQWBBQG/nxwZyg5\n\t\t\t\t\t\tWmVT7dW1ls/M1vbiozANBgkqhkiG9w0BAQUFAAOCAQEAkLBx3gDitwIxjSCuMSxd\n\t\t\t\t\t\t5ll6UJCygSwaYm6Xi6mjH1ORIInecwlZkJpGpKALcfQK5bKnSMZ+uP2WR5xOawuf\n\t\t\t\t\t\ty0Thr2Kpi+zHhU1Va2rS92OUTPGzTiFEeg6ZCFx2Gx+8zAHv217cE7c4L1ubwWIh\n\t\t\t\t\t\tdPnM3T/hDlfNmnxVwsFSlq/bpPL6rtLzkJkguh/4/0RcBo8qiBU524S6Tg06CDIv\n\t\t\t\t\t\tJRAUSwga2eSyN/TtSCo0cHOhSyngdaInidFRKtt/Fx7MUp6IcmnoeoqeEFw8LfG3\n\t\t\t\t\t\tXbypI2H0IHybvdGVRRGXWQpkPrjUXnu4D5m5jc+C+/XqzIiaN3/FEAG0fKdIHHDt\n\t\t\t\t\t\tHQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://assent.jisc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://assent.jisc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://assent.jisc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://assent.jisc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://assent.jisc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://assent.jisc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Self-service portal to configure trust links for Moonshot IdPs and RPs"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Moonshot Portal"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonTargetedID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.worc.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Reed"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:j.reed@worc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Judy"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Attwood"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:g.attwood@worc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ged"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.worc.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-07-14T17:53:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.worc.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.worc.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "worc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDlzCCAn+gAwIBAgIJAM9gbhSqyROWMA0GCSqGSIb3DQEBBQUAMDsxIDAeBgNV\n\t\t\t\t\t\tBAoTF1VuaXZlcnNpdHkgb2YgV29yY2VzdGVyMRcwFQYDVQQDEw5pZHAud29yYy5h\n\t\t\t\t\t\tYy51azAeFw0xMTA3MDYxMDQ4MTdaFw0yMTA3MDMxMDQ4MTdaMDsxIDAeBgNVBAoT\n\t\t\t\t\t\tF1VuaXZlcnNpdHkgb2YgV29yY2VzdGVyMRcwFQYDVQQDEw5pZHAud29yYy5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMZDA7qffg7TU6jYsSUq\n\t\t\t\t\t\t3rdyqGyXqCvENST8ytpZeo5GXpZwu+BB3d5s8+mjD055tl60AGvJ14DYix2hzJ/d\n\t\t\t\t\t\tHrcGTSeeqfl4aXGZZ3BAUAPy9kiRQqG72EeY1t4QgzOoJlHD/rnWKrHDGZgo2/S2\n\t\t\t\t\t\tOKUudCkz/Ep0Z4sUg9N0KdoIlcbMc7b1vUE/ACsasQCsSjU63rb/fyYxW/UQZWXh\n\t\t\t\t\t\txmGvGmmk9G0cNUwipv+s04Rqh6gq3s7ukbCtSd64FrSKG/RkwNTRRg1+S2N+9Vbm\n\t\t\t\t\t\t+feCYnJvGEkNN+m+9Lcq77vu3+uiQRKZFkBkR/rU42/WsqXDQAspiOwoO6GVibAD\n\t\t\t\t\t\tBcsCAwEAAaOBnTCBmjAdBgNVHQ4EFgQUC/NgmG4G9V4HMA3TWbPetEyLnL0wawYD\n\t\t\t\t\t\tVR0jBGQwYoAUC/NgmG4G9V4HMA3TWbPetEyLnL2hP6Q9MDsxIDAeBgNVBAoTF1Vu\n\t\t\t\t\t\taXZlcnNpdHkgb2YgV29yY2VzdGVyMRcwFQYDVQQDEw5pZHAud29yYy5hYy51a4IJ\n\t\t\t\t\t\tAM9gbhSqyROWMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAIBKZ9GG\n\t\t\t\t\t\tREabLBEsXHsBrvSZhYA+tUv+NI7dzgy7ZpDlu11hY7ZvW0fUxhdOKjgBi8d4JULT\n\t\t\t\t\t\ttrMafGP1PuYNCD4Mq9crfXCX9nqM+QBAPiWHQmHeWqVB+ibSKRHd1LoCgNqnyb9z\n\t\t\t\t\t\t/f1CC2RGHNdXANO4DGeYqf2dxEVHtlxo2mTlQj6OtrJ02T4auqztM7QBbxKfesxe\n\t\t\t\t\t\todciW+HA2B/fA+G23KSazb74AIKrXT5YZSDgWvcyMS25shYbuwbj1KIqU7IsBQQw\n\t\t\t\t\t\tJPIj5C1aB1XqXb/f875iu38rBNg0ZEsqKP4SnX5e5nlpQk4KCdkj34RGeCctzEGF\n\t\t\t\t\t\tFqqTiJna2FaWzV0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDlzCCAn+gAwIBAgIJAM9gbhSqyROWMA0GCSqGSIb3DQEBBQUAMDsxIDAeBgNV\n\t\t\t\t\t\tBAoTF1VuaXZlcnNpdHkgb2YgV29yY2VzdGVyMRcwFQYDVQQDEw5pZHAud29yYy5h\n\t\t\t\t\t\tYy51azAeFw0xMTA3MDYxMDQ4MTdaFw0yMTA3MDMxMDQ4MTdaMDsxIDAeBgNVBAoT\n\t\t\t\t\t\tF1VuaXZlcnNpdHkgb2YgV29yY2VzdGVyMRcwFQYDVQQDEw5pZHAud29yYy5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMZDA7qffg7TU6jYsSUq\n\t\t\t\t\t\t3rdyqGyXqCvENST8ytpZeo5GXpZwu+BB3d5s8+mjD055tl60AGvJ14DYix2hzJ/d\n\t\t\t\t\t\tHrcGTSeeqfl4aXGZZ3BAUAPy9kiRQqG72EeY1t4QgzOoJlHD/rnWKrHDGZgo2/S2\n\t\t\t\t\t\tOKUudCkz/Ep0Z4sUg9N0KdoIlcbMc7b1vUE/ACsasQCsSjU63rb/fyYxW/UQZWXh\n\t\t\t\t\t\txmGvGmmk9G0cNUwipv+s04Rqh6gq3s7ukbCtSd64FrSKG/RkwNTRRg1+S2N+9Vbm\n\t\t\t\t\t\t+feCYnJvGEkNN+m+9Lcq77vu3+uiQRKZFkBkR/rU42/WsqXDQAspiOwoO6GVibAD\n\t\t\t\t\t\tBcsCAwEAAaOBnTCBmjAdBgNVHQ4EFgQUC/NgmG4G9V4HMA3TWbPetEyLnL0wawYD\n\t\t\t\t\t\tVR0jBGQwYoAUC/NgmG4G9V4HMA3TWbPetEyLnL2hP6Q9MDsxIDAeBgNVBAoTF1Vu\n\t\t\t\t\t\taXZlcnNpdHkgb2YgV29yY2VzdGVyMRcwFQYDVQQDEw5pZHAud29yYy5hYy51a4IJ\n\t\t\t\t\t\tAM9gbhSqyROWMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAIBKZ9GG\n\t\t\t\t\t\tREabLBEsXHsBrvSZhYA+tUv+NI7dzgy7ZpDlu11hY7ZvW0fUxhdOKjgBi8d4JULT\n\t\t\t\t\t\ttrMafGP1PuYNCD4Mq9crfXCX9nqM+QBAPiWHQmHeWqVB+ibSKRHd1LoCgNqnyb9z\n\t\t\t\t\t\t/f1CC2RGHNdXANO4DGeYqf2dxEVHtlxo2mTlQj6OtrJ02T4auqztM7QBbxKfesxe\n\t\t\t\t\t\todciW+HA2B/fA+G23KSazb74AIKrXT5YZSDgWvcyMS25shYbuwbj1KIqU7IsBQQw\n\t\t\t\t\t\tJPIj5C1aB1XqXb/f875iu38rBNg0ZEsqKP4SnX5e5nlpQk4KCdkj34RGeCctzEGF\n\t\t\t\t\t\tFqqTiJna2FaWzV0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Worcester"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.worcester.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Worcester"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.elgaronline.com/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Itkowsky"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mitkowsky@safaribooksonline.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marissa"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Istratov"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mistratov@safaribooksonline.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.elgaronline.com/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-07-17T08:44:58Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Elgar Online"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.e-elgar.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Edward Elgar Publishing Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBDCCAeygAwIBAgIEU6rnhTANBgkqhkiG9w0BAQUFADBEMSQwIgYDVQQKExtF\n\t\t\t\t\t\tZHdhcmQgRWxnYXIgUHVibGlzaGluZyBMdGQxHDAaBgNVBAMTE3d3dy5lbGdhcm9u\n\t\t\t\t\t\tbGluZS5jb20wHhcNMTQwNjI1MTUxNTE3WhcNMjQwNjIyMTUxNTE3WjBEMSQwIgYD\n\t\t\t\t\t\tVQQKExtFZHdhcmQgRWxnYXIgUHVibGlzaGluZyBMdGQxHDAaBgNVBAMTE3d3dy5l\n\t\t\t\t\t\tbGdhcm9ubGluZS5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDk\n\t\t\t\t\t\tzi0IFONPfHSf+k9V6m3TUL7jmAyEzOMRsNd3xe8VDzompult1mnkRNQsJtXlH8dT\n\t\t\t\t\t\t9zlsa8Sg7GWZuB33GUDZAduwh2zrDLHEX26zcRiwVMEGHO+ExZtb3Tj6rYIabd3M\n\t\t\t\t\t\tK7omCRTXKoGgpjembqpUSkyfo1tXb0n3VLWSg+c0rD3OsxmlSKYGOIM/IJWLeETf\n\t\t\t\t\t\tRFO+/wbMBiznGB2v0gE1OwBMuW9MhJGNuTzl6JBzsUtWaxve6uUaFGO0VsJkgt+1\n\t\t\t\t\t\tblkMrfKLxeBNpCwjJ0p5uf2NFzQqSyGutY4WOUKJikJGAgwewI1eGGMXAu5yILDG\n\t\t\t\t\t\tTx4qzyn9Y3FAOXv6awbVAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAFejm2GsOBLa\n\t\t\t\t\t\t3MjfY1y5gF0O3CB9S3PUAgA2p1wB0j+MzThgw6qlCWCCAoBmqNIWQ9b7ehGf2gXU\n\t\t\t\t\t\tUXI01W5ze1FLZap/B04GHbdSVPg7zc/Wp5+lnb+J0V28sPMXT3n7r6Kpp4vmnmub\n\t\t\t\t\t\thc4j8O9cJrleXFtB2w5rkgPqX2/Ws9eWK5Ngbri+PDw/b0OtaHJimsl8IzftdmBb\n\t\t\t\t\t\tfYKS821VM/dQ463zbqZ0Vj1hwXL+y4bc1WPjNHxiY4uQfEVfw5lBEZBHG2o2g3ys\n\t\t\t\t\t\tTA+7CGeJEhhBdtMHAV7salX0SDV1XDS2icJrFqEbgsJADKM71qFneDNLP874hvmR\n\t\t\t\t\t\tCYoHEdBLhyA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBDCCAeygAwIBAgIEU6rnhTANBgkqhkiG9w0BAQUFADBEMSQwIgYDVQQKExtF\n\t\t\t\t\t\tZHdhcmQgRWxnYXIgUHVibGlzaGluZyBMdGQxHDAaBgNVBAMTE3d3dy5lbGdhcm9u\n\t\t\t\t\t\tbGluZS5jb20wHhcNMTQwNjI1MTUxNTE3WhcNMjQwNjIyMTUxNTE3WjBEMSQwIgYD\n\t\t\t\t\t\tVQQKExtFZHdhcmQgRWxnYXIgUHVibGlzaGluZyBMdGQxHDAaBgNVBAMTE3d3dy5l\n\t\t\t\t\t\tbGdhcm9ubGluZS5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDk\n\t\t\t\t\t\tzi0IFONPfHSf+k9V6m3TUL7jmAyEzOMRsNd3xe8VDzompult1mnkRNQsJtXlH8dT\n\t\t\t\t\t\t9zlsa8Sg7GWZuB33GUDZAduwh2zrDLHEX26zcRiwVMEGHO+ExZtb3Tj6rYIabd3M\n\t\t\t\t\t\tK7omCRTXKoGgpjembqpUSkyfo1tXb0n3VLWSg+c0rD3OsxmlSKYGOIM/IJWLeETf\n\t\t\t\t\t\tRFO+/wbMBiznGB2v0gE1OwBMuW9MhJGNuTzl6JBzsUtWaxve6uUaFGO0VsJkgt+1\n\t\t\t\t\t\tblkMrfKLxeBNpCwjJ0p5uf2NFzQqSyGutY4WOUKJikJGAgwewI1eGGMXAu5yILDG\n\t\t\t\t\t\tTx4qzyn9Y3FAOXv6awbVAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAFejm2GsOBLa\n\t\t\t\t\t\t3MjfY1y5gF0O3CB9S3PUAgA2p1wB0j+MzThgw6qlCWCCAoBmqNIWQ9b7ehGf2gXU\n\t\t\t\t\t\tUXI01W5ze1FLZap/B04GHbdSVPg7zc/Wp5+lnb+J0V28sPMXT3n7r6Kpp4vmnmub\n\t\t\t\t\t\thc4j8O9cJrleXFtB2w5rkgPqX2/Ws9eWK5Ngbri+PDw/b0OtaHJimsl8IzftdmBb\n\t\t\t\t\t\tfYKS821VM/dQ463zbqZ0Vj1hwXL+y4bc1WPjNHxiY4uQfEVfw5lBEZBHG2o2g3ys\n\t\t\t\t\t\tTA+7CGeJEhhBdtMHAV7salX0SDV1XDS2icJrFqEbgsJADKM71qFneDNLP874hvmR\n\t\t\t\t\t\tCYoHEdBLhyA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://www.elgaronline.com/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.elgaronline.com/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.elgaronline.com/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.elgaronline.com/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://wifi.dir.garr.it:12081/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:system.support@garr.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://wifi.dir.garr.it:12081/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2013-07-30T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Wi-Fi provided by Consortium GARR"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Wi-Fi erogato da Consortium GARR"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.garr.it"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.garr.it/b/eng"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consortium GARR"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consortium GARR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://wifi.dir.garr.it:12081/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://wifi.dir.garr.it:12081/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wifi.dir.garr.it:12081/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wifi.dir.garr.it:12081/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "WIFI connection provided by GARR"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Wifi access for guests in the GARR wireless network (Rome)"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://wifi.dir.garr.it:12081/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.garr.it/wifi/info"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.garr.it/wifi/info"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Wi-Fi connection to the wireless network in GARR (Rome, IT). This service enables the authentication by IDEM credentials at wireless network in GARR"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Connessione Wi-Fi alla rete wireless di GARR nella sede di Roma (IT). Questo servizio abilita l'autenticazione mediante credenziali IDEM presso la rete wireless della Direzione GARR"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.garr.it/wifi/privacy"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.garr.it/wifi/privacy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WIFI provided by GARR"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WIFI erogato da GARR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://wifi.dir.garr.it:12081/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://wifi.dir.garr.it:12081/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEbjCCA1agAwIBAgIRALxMXgZtagsFRXGxHmc7ojQwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xMzA3MDUwMDAwMDBaFw0xNjA3MDQyMzU5NTlaMD4xITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEZMBcGA1UEAxMQd2lmaS5kaXIu\nZ2Fyci5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM1nKllgz7Q6\nu14Q9efpbAAculFFENIAIIJQVCU/rE7HFPGxxaEDxpBWpq7oUAd9wYT+sFiQk1Zf\nkFwWCxbpwqftLBytbCpOFmzqxcKqtaBX4d8qkBI8v4fIOjYPeC6inMXLZOf+3/QL\nITNjj70N2S3GXm+JvNBhVik1UiQ3HxVJbjUHAyj33RaMfQGQNonu4H1YOBWTTtXw\nFY1hHAERTRfJBDv7LzGoYo1e6gOYyz2QHNJO3hzHWG+MHZfAA1RpIHO6v9Xs67ZG\nuN9FoeAQMZ89L7Xc8a4b+paS2ShD4BZcw5Htxn8qhdbWfhBfZOUbK+8TQWUO6MNT\nri2whivd78cCAwEAAaOCAW0wggFpMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdX\nR+qQ47ntMB0GA1UdDgQWBBR6K1Z+w6BoJOYYHclzDHTOD4QsETAOBgNVHQ8BAf8E\nBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUH\nAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0fBDMw\nMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5j\ncmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50\nZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29j\nc3AudGNzLnRlcmVuYS5vcmcwGwYDVR0RBBQwEoIQd2lmaS5kaXIuZ2Fyci5pdDAN\nBgkqhkiG9w0BAQUFAAOCAQEApWK44BT0P8QiG0UbsMl3x8nW93tHdrIeuXd/2ET1\n43pIBU6o+cvCZolOzzmU5D3tQuvG3+Uhs5aBKDA3sdklV1wK85Tf/FrVGw5OFlxn\nUCXWIXAHYqZrUZVSBJiUsGLhyNxtME/wL5vgjBFtnBUagkYZAoSI6HIAPFC4WmAG\nT7jgUwih9oD9bZqNGy3q8QsJZlAuj65RmLJUTz4XUcS5RJrePlQSMj3WQklkoKkO\n3/o35Z0PboOdmDyvBkGP7vdkZ3xuBH9F8C3FZ91t5F0hieeFnFOEXyZcPq14vQ5C\nJp4P35Fmyp0bxWiEwrpCwV8TZ5lpllIJvrB1rVPxSYE80w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://wifi.dir.garr.it:12081/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://wifi.dir.garr.it:12081/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wifi.dir.garr.it:12081/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wifi.dir.garr.it:12081/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wifi.dir.garr.it:12081/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://wifi.dir.garr.it:12081/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wifi.dir.garr.it:12081/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://wifi.dir.garr.it:12081/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://wifi.dir.garr.it:12081/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://wifi.dir.garr.it:12081/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.nuim.ie/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Doran"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jason.doran@nuim.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jason"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dearbhla O'Reilly"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dearbhla.oreilly@nuim.ie"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "systrack@nuim.ie"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:systrack@nuim.ie"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.nuim.ie/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2011-08-16T00:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.nuim.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.nuim.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.nuim.ie/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nuim.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://computercentre.nuim.ie/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/MaynoothUniversity.png",
                    "height": "119",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "243"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Maynooth University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.3846672,-6.6012125"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFJzCCBA+gAwIBAgIJAIJfD55vGsQ3MA0GCSqGSIb3DQEBBQUAMIG9MQswCQYD\nVQQGEwJJRTEUMBIGA1UECBMLQ28uIEtpbGRhcmUxETAPBgNVBAcTCE1heW5vb3Ro\nMTEwLwYDVQQKEyhOYXRpb25hbCBVbml2ZXJzaXR5IG9mIElyZWxhbmQsIE1heW5v\nb3RoMRowGAYDVQQLExFDb21wdXRlciBTZXJ2aWNlczEUMBIGA1UEAxMLaWRwLm51\naW0uaWUxIDAeBgkqhkiG9w0BCQEWEXN5cy1ncm91cEBudWltLmllMB4XDTEyMDEx\nMDE0NTUxNFoXDTE3MDEwODE0NTUxNFowgb0xCzAJBgNVBAYTAklFMRQwEgYDVQQI\nEwtDby4gS2lsZGFyZTERMA8GA1UEBxMITWF5bm9vdGgxMTAvBgNVBAoTKE5hdGlv\nbmFsIFVuaXZlcnNpdHkgb2YgSXJlbGFuZCwgTWF5bm9vdGgxGjAYBgNVBAsTEUNv\nbXB1dGVyIFNlcnZpY2VzMRQwEgYDVQQDEwtpZHAubnVpbS5pZTEgMB4GCSqGSIb3\nDQEJARYRc3lzLWdyb3VwQG51aW0uaWUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQCqYOcqJ5Noxcg5x/pGaiawCouvWi1jYCZWgleEQydX3uPCJYi1s2Ku\nLlOFaJW5tDzHO0dyMQ+y04dRsSKYgczsMgWrSNghD+vCezx3Zeu3g51eXMUz+rbB\nAP9c5TnDHk/ftYChMVbrih+xTJ30jXsQnfwXueO0JhQ5RZ8ON6Cesxq7hjnJJ0EA\n/DH/hiaI2M4KoPyT6b9p808M52cHMac0QpUz4dHSZ87sV4vQKiYIS76uShT7o+Hk\ntUfX24TY8uqoeyBohB/dvBMwdzBjr88TIO5e8ACjl25L+EzkEITSqKppAN3NhCUN\naDN1g77S19a8X4bGRblkTOrYZoJVj/0/AgMBAAGjggEmMIIBIjAdBgNVHQ4EFgQU\nmQ7I+TlEqPr/emxYU5mFxFeRnkgwgfIGA1UdIwSB6jCB54AUmQ7I+TlEqPr/emxY\nU5mFxFeRnkihgcOkgcAwgb0xCzAJBgNVBAYTAklFMRQwEgYDVQQIEwtDby4gS2ls\nZGFyZTERMA8GA1UEBxMITWF5bm9vdGgxMTAvBgNVBAoTKE5hdGlvbmFsIFVuaXZl\ncnNpdHkgb2YgSXJlbGFuZCwgTWF5bm9vdGgxGjAYBgNVBAsTEUNvbXB1dGVyIFNl\ncnZpY2VzMRQwEgYDVQQDEwtpZHAubnVpbS5pZTEgMB4GCSqGSIb3DQEJARYRc3lz\nLWdyb3VwQG51aW0uaWWCCQCCXw+ebxrENzAMBgNVHRMEBTADAQH/MA0GCSqGSIb3\nDQEBBQUAA4IBAQACcYADyyTILLVeCYD7/m6TcYlwt+0k7wTyhMzOC54h0OVon6FW\n2/E0OyK3izzC6JkuNjbDCpnZG5+DyBj0jZI3UqPSN085z0rOfsPYLLqztytwduZv\n3jfgvDs/myj301xD1FdYWZmyVOuVTjB64XfAtTLqA2YJ9GvOL+egN8gh4DWu/mx9\nYCfuRE0VjS1C5qU3qrvQTRfm+mHIXvCJqEq+QdXMnJm2jc+rvm9s4Y3/P+dOJqZ2\nmSq9+fohezZUYgCirIJuORsZiubp0lExD9/P9hYK6tNtxCeKpOrFKfqDonlcFwq4\n08qWRqOhxna9IY/GleVcTnlR/8w9YOQ9kn0V"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Maynooth University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.maynoothuniversity.ie"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Maynooth University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.highbury.ac.uk/entity",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Butcher"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul.butcher@highbury.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@highbury.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "College IT Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Whitehead"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ian.whitehead@highbury.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.highbury.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-08-20T12:09:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUQBVfv1Tnt7N17RL6y6sE8mngYOYwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJTEjMCEGA1UEAxMac2hpYmJvbGV0aDIuaGlnaGJ1cnkuYWMudWswHhcNMTQx\n\t\t\t\t\t\tMjE3MDk0NDEzWhcNMjQxMjE3MDk0NDEzWjAlMSMwIQYDVQQDExpzaGliYm9sZXRo\n\t\t\t\t\t\tMi5oaWdoYnVyeS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAIGsz5d+S+Z7C3YQjZXV0cDX4KzZw/AdpgMtdCKAq/KAv4FcXqWUgmm8UNqSUpaZ\n\t\t\t\t\t\tj+yai6rtwWfDxa6PO1nz6X827qmc+ZNzSSwn8P5vRjEune7M+dp2Azf1iZTEdEvo\n\t\t\t\t\t\tWxeHBadrsK35IVv8gpenI+/oECfw1TJgbZ50b+lC1GYa42BSu9oT0c9ngcmd9MIg\n\t\t\t\t\t\tmZtah4vnTG9GavQh7JiKRJEAy/oKLVZ+QxHwqNvoPjmHXNH31P4yG0uSkQMXIncF\n\t\t\t\t\t\tb02LrVM6N5zQHNj3BxT5OiC9XMJTJIE3qezgp4jVeHgchk8bbQbAd4LrPMl8UmGW\n\t\t\t\t\t\t2N4+EJs9AOKWcqME7sIN1HkCAwEAAaN7MHkwWAYDVR0RBFEwT4Iac2hpYmJvbGV0\n\t\t\t\t\t\taDIuaGlnaGJ1cnkuYWMudWuGMWh0dHBzOi8vc2hpYmJvbGV0aDIuaGlnaGJ1cnku\n\t\t\t\t\t\tYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFNXlKPvM2RUd6FsHoFbZSI9T\n\t\t\t\t\t\tvK4QMA0GCSqGSIb3DQEBBQUAA4IBAQA4+wfuBit/wjBIgqDiR45MkZGITZHX3lZc\n\t\t\t\t\t\t0KW7qSCxsJvmBnlluHUzMpvYEfa0PFgNHTcdCVPOAShSjq4GvZIEloDDw/rIU9X0\n\t\t\t\t\t\tTdluFnW38P3KZ+e8+veBkmEQpHBJr8j2+mHGURjS5uFIYpbRRDl7Zhbjx/aCNECD\n\t\t\t\t\t\tkfGgRUQOcrFOLZC7yZVKLPhen6FrglCpMHxTAOEVudICBM8qix8Sa9RSF/Wa+koC\n\t\t\t\t\t\t++RNvHw5/Gy8oAgdLUWga8jTEy9814Omh+CZ1aD57edykSPBYqVgPbp4+qe6qHjP\n\t\t\t\t\t\tW7hlXIP3zSHP9R17i+v25+UsbOTujB09Q1480Yte2Urglnv7umRs"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "highbury.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth2.highbury.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2.highbury.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth2.highbury.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2.highbury.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth2.highbury.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2.highbury.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth2.highbury.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2.highbury.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "highbury.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUQBVfv1Tnt7N17RL6y6sE8mngYOYwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJTEjMCEGA1UEAxMac2hpYmJvbGV0aDIuaGlnaGJ1cnkuYWMudWswHhcNMTQx\n\t\t\t\t\t\tMjE3MDk0NDEzWhcNMjQxMjE3MDk0NDEzWjAlMSMwIQYDVQQDExpzaGliYm9sZXRo\n\t\t\t\t\t\tMi5oaWdoYnVyeS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAIGsz5d+S+Z7C3YQjZXV0cDX4KzZw/AdpgMtdCKAq/KAv4FcXqWUgmm8UNqSUpaZ\n\t\t\t\t\t\tj+yai6rtwWfDxa6PO1nz6X827qmc+ZNzSSwn8P5vRjEune7M+dp2Azf1iZTEdEvo\n\t\t\t\t\t\tWxeHBadrsK35IVv8gpenI+/oECfw1TJgbZ50b+lC1GYa42BSu9oT0c9ngcmd9MIg\n\t\t\t\t\t\tmZtah4vnTG9GavQh7JiKRJEAy/oKLVZ+QxHwqNvoPjmHXNH31P4yG0uSkQMXIncF\n\t\t\t\t\t\tb02LrVM6N5zQHNj3BxT5OiC9XMJTJIE3qezgp4jVeHgchk8bbQbAd4LrPMl8UmGW\n\t\t\t\t\t\t2N4+EJs9AOKWcqME7sIN1HkCAwEAAaN7MHkwWAYDVR0RBFEwT4Iac2hpYmJvbGV0\n\t\t\t\t\t\taDIuaGlnaGJ1cnkuYWMudWuGMWh0dHBzOi8vc2hpYmJvbGV0aDIuaGlnaGJ1cnku\n\t\t\t\t\t\tYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFNXlKPvM2RUd6FsHoFbZSI9T\n\t\t\t\t\t\tvK4QMA0GCSqGSIb3DQEBBQUAA4IBAQA4+wfuBit/wjBIgqDiR45MkZGITZHX3lZc\n\t\t\t\t\t\t0KW7qSCxsJvmBnlluHUzMpvYEfa0PFgNHTcdCVPOAShSjq4GvZIEloDDw/rIU9X0\n\t\t\t\t\t\tTdluFnW38P3KZ+e8+veBkmEQpHBJr8j2+mHGURjS5uFIYpbRRDl7Zhbjx/aCNECD\n\t\t\t\t\t\tkfGgRUQOcrFOLZC7yZVKLPhen6FrglCpMHxTAOEVudICBM8qix8Sa9RSF/Wa+koC\n\t\t\t\t\t\t++RNvHw5/Gy8oAgdLUWga8jTEy9814Omh+CZ1aD57edykSPBYqVgPbp4+qe6qHjP\n\t\t\t\t\t\tW7hlXIP3zSHP9R17i+v25+UsbOTujB09Q1480Yte2Urglnv7umRs"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Highbury College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.highbury.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Highbury College, Portsmouth"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:utah.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Caprice.Post@Utah.Edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Caprice Post"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Robert.Roll@Utah.Edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert Roll"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "bryan.wooten@utah.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bryan Wooten"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tim.richardson@utah.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim Richardson"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:utah.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://incommon2.sso.utah.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://incommon2.sso.utah.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIUNKGu8wOF9BnZeWHZWXe1e0FzhbswDQYJKoZIhvcNAQEF\nBQAwITEfMB0GA1UEAxMWaW5jb21tb24yLnNzby51dGFoLmVkdTAeFw0xMjAyMjIx\nNDE2MjBaFw0zMjAyMjIxNDE2MjBaMCExHzAdBgNVBAMTFmluY29tbW9uMi5zc28u\ndXRhaC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCdsIv0Mok5\n7t9I1reRFzXyiMKr4sIIqHJmAU4vIfUJKTQnag8or8UNfTVSuVoiuFK3Y+luj7DH\neGOHKXT1/6ijpa8a4Xqd/4m9znYiJznKEzXFFK+/kaXnxOZrieBC84iDMz5tM1JU\nGeP/C08IZP12cLfVaZh1EwwBwwvlTV369HU9RGYruCIY/KB5Kg6dA0JrRQ96lHdd\noA9Vvme13w0m3CpAasIKQa3tkucS8T2VHuoswIjFS7ZghdSZqW/oQ2QOccCWCIlZ\n0u6dRR1p0/LyisMZhUaw/BE3FfI4XHUxPwhqpoag/HZ/9Un4KHT45MVeOTcJsYUl\nFiAwbrFWwLzFAgMBAAGjYDBeMD0GA1UdEQQ2MDSCFmluY29tbW9uMi5zc28udXRh\naC5lZHWGGnVybjptYWNlOmluY29tbW9uOnV0YWguZWR1MB0GA1UdDgQWBBR2NZXC\nE4XVo97LgWbwBI8KGWGrhTANBgkqhkiG9w0BAQUFAAOCAQEAjiT3XYm5IkX2JDKK\n9OwLBcja+C6eA/bkbM/QSz6s2e3R7PhXfHvcAxYxbsrdQwBQtFMgnlfR/P2r5/ja\nFQxeF43HX7P+R4pxLSCw8616O4CnKavxJJB0cu9fYMuLjuDbaGVmbrbmfd2fvGVD\nQEB914XUZYgkzwpmOwWd8UHe0yekCp1hh9+nNDFk8igygIgCK3S3GI92a8nPk+q5\n5sww8+31zIp4TNX4Wm5cr+LBmjduLwzJAZby/2TbKJK4hamZIxR/g6hfM4XYCZdl\nh0/pbgjQw2DUQBBatGw8zWsm3JzHUhIsZiiVP2ssUblwHzK4HcNHX1Y3xrTINpgW\nchyV0g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utah.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://incommon2.sso.utah.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://incommon2.sso.utah.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://incommon2.sso.utah.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://incommon2.sso.utah.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://incommon2.sso.utah.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://incommon2.sso.utah.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utah.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Utah"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIUNKGu8wOF9BnZeWHZWXe1e0FzhbswDQYJKoZIhvcNAQEF\nBQAwITEfMB0GA1UEAxMWaW5jb21tb24yLnNzby51dGFoLmVkdTAeFw0xMjAyMjIx\nNDE2MjBaFw0zMjAyMjIxNDE2MjBaMCExHzAdBgNVBAMTFmluY29tbW9uMi5zc28u\ndXRhaC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCdsIv0Mok5\n7t9I1reRFzXyiMKr4sIIqHJmAU4vIfUJKTQnag8or8UNfTVSuVoiuFK3Y+luj7DH\neGOHKXT1/6ijpa8a4Xqd/4m9znYiJznKEzXFFK+/kaXnxOZrieBC84iDMz5tM1JU\nGeP/C08IZP12cLfVaZh1EwwBwwvlTV369HU9RGYruCIY/KB5Kg6dA0JrRQ96lHdd\noA9Vvme13w0m3CpAasIKQa3tkucS8T2VHuoswIjFS7ZghdSZqW/oQ2QOccCWCIlZ\n0u6dRR1p0/LyisMZhUaw/BE3FfI4XHUxPwhqpoag/HZ/9Un4KHT45MVeOTcJsYUl\nFiAwbrFWwLzFAgMBAAGjYDBeMD0GA1UdEQQ2MDSCFmluY29tbW9uMi5zc28udXRh\naC5lZHWGGnVybjptYWNlOmluY29tbW9uOnV0YWguZWR1MB0GA1UdDgQWBBR2NZXC\nE4XVo97LgWbwBI8KGWGrhTANBgkqhkiG9w0BAQUFAAOCAQEAjiT3XYm5IkX2JDKK\n9OwLBcja+C6eA/bkbM/QSz6s2e3R7PhXfHvcAxYxbsrdQwBQtFMgnlfR/P2r5/ja\nFQxeF43HX7P+R4pxLSCw8616O4CnKavxJJB0cu9fYMuLjuDbaGVmbrbmfd2fvGVD\nQEB914XUZYgkzwpmOwWd8UHe0yekCp1hh9+nNDFk8igygIgCK3S3GI92a8nPk+q5\n5sww8+31zIp4TNX4Wm5cr+LBmjduLwzJAZby/2TbKJK4hamZIxR/g6hfM4XYCZdl\nh0/pbgjQw2DUQBBatGw8zWsm3JzHUhIsZiiVP2ssUblwHzK4HcNHX1Y3xrTINpgW\nchyV0g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Utah"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utah.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Utah"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.wheatonma.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "incommon@wheatoncollege.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brian Gibson"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.wheatonma.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.wheatonma.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.wheatonma.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.wheatonma.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.wheatonma.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.wheatonma.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wheatonma.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Wheaton College Norton, MA"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Wheaton College (MA)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDTCCAfWgAwIBAgIJAP6+QFyXUWbFMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMMEnNoaWIud2hlYXRvbm1hLmVkdTAeFw0xNDA0MTAxMjU2MzJaFw0yNDA0MDcx\nMjU2MzJaMB0xGzAZBgNVBAMMEnNoaWIud2hlYXRvbm1hLmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAMAdKq3FBYmschbWPLHn133qKNJXf6VQnEwJ\npwwypn9oKxAywzzsDcp/j8nUQs47PG3W9XtrF84vh3N/H4rDi3JoNTrMyk4bFyYk\nVX+VFWxy+NVXWXi2egOIxwMfL9IBDMVCSkyrUW10PigLxhg+4DBSlNQtQpcK61D8\ngu2LNSqVvS4aDz5Tf0KD1p+dAYi/RwvmEYupklfyj/MFfgbNFrlpRmtgH5FLpd2t\nhuxpLiaQR+g4WkTBlWTz0xJmVKEtVEcmD6fSKm0niHkmoSPL9hdk0jH454sXW4c3\nxO1aH1ndjc80F87iXc/bxxyo/eAJStxzkyT2wzF1dfAAK1SiP2UCAwEAAaNQME4w\nHQYDVR0OBBYEFBIqM49eCOA0H7TU18z0I81MDdvNMB8GA1UdIwQYMBaAFBIqM49e\nCOA0H7TU18z0I81MDdvNMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEB\nAAiN0t8hkKKEz/QuTizhE/KSq2g3FVPAY2v5GfExkc8Rrfco5eDIt/+6KCBcT+oK\n/HrVf3QUpaY8wWpLIsmnxDljYsKlakbx39KZXkGBaQ9YekxAtETwij7pwmluTVS7\npC9bdNsv25+F/BbQ61ccsfcWK0y2im+u2efE972ksJm1Ch19TxBidRh+9WJAr7pk\nS2QrfAb23EkRNm9JHzM7s5BBJJ/3D3ZvK52/XEb8fH//u0Y5cynkwpemf5PZYFnR\nUHlWki9gH3Vd3GPCCnSYDIuKE0QtzrjFoNdBgBsGxs82wyT/Tt6emn86g/xzWi/M\nLcl69y1Yfli289CCOSkgiaU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Wheaton College (MA)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wheatoncollege.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Wheaton College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-24.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-24.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-24.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-24.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-24.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-24.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-24.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-24.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-24.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;24"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-24.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-24.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJAMqoBGnCYN7/MA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0yNC5sYWRvay51bXUuc2UwHhcNMTQwOTAxMTQ0NTUwWhcNMjQw\nODI5MTQ0NTUwWjAhMR8wHQYDVQQDExZsYWRvazMtMjQubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtgemjrI3Z6u8sxv8gDOBRJp9\nXtUtG9Qj7f+TeF8J61WPZ+41pd6jHxfkGWZdBhJe0TzrY2r+rlHYjdOol9wsnqL1\nWb4Q3gt58mcHoXFDU653jo5ptlYzBrO1382HMaAqwHAkiZaMfwk70w3zk6iX8fPq\n2tJPBme2NTwCFjxuGhBpNjjQC3aq5P4oPmkkvVsd8UdRlf+tp/+x48XpazJWmphy\nrce0q50yTykXHeTOPvh9RYPFs78rUaBvJRl3rnJVL7xJzwiuBkmpvPWbeaMabg8O\n9fJpAVWi38Mol9Hnf43JEjDVUoBfPyJEBmZNlcq8nPeaG16vDkb6yGL5Iq2HdwID\nAQABo2swaTBIBgNVHREEQTA/ghZsYWRvazMtMjQubGFkb2sudW11LnNlhiVodHRw\nczovL2xhZG9rMy0yNC5sYWRvay51bXUuc2UvZ3VpLXNwMB0GA1UdDgQWBBQsxiD5\nnvlsfsTP/fHXkp64HQTI8zANBgkqhkiG9w0BAQUFAAOCAQEAOY++zJhaPxdgLyAA\nAIbGQQsA7J6Rq9JCJk61asf3pBaIzX105N4rK/nS/IWOgRNERn7ZHLM8oYNCt/8+\nu1rDvkAmgprOQS4GyNsLQHuJd94E4L0+nvYQHJuU48pkGcXxUYiALhHtOMO0TbRs\nfeK5IMxlwaFWhr4ObtKvfVo3mt74o1KY5dSv1Ri8nGg07oVeZCIjdWzeNxG5NyPA\n92BgfWxe5M71Q/tPoKy9PtpR7g1LaEDXXMkuOhnYlr4o/WA9ToXwftd9j3ML6Yq6\n5kBIqtJWSXTzwl/veVz6KOEgU4xa9xbrhj3QoONp2Y9URm/c8PHdWgSo8x5zPoAj\nAHgxyA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-24.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-24.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-24.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-24.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-24.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-24.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-24.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-24.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-24.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-24.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.nulc.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.nulc.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/nulc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/nulc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nulc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Newcastle-under-Lyme College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nulc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://terena.org/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@terena.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TERENA AAI Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@terena.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TERENA AAI Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://terena.org/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "TERENA: Service Provider Proxy"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.terena.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "TERENA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.terena.org/wayf/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEkjCCA3qgAwIBAgIJAL90CxMEVb/kMA0GCSqGSIb3DQEBBQUAMIGMMQswCQYD\n\t\t\t\t\t\tVQQGEwJOTDELMAkGA1UECBMCTkgxEjAQBgNVBAcTCUFtc3RlcmRhbTEPMA0GA1UE\n\t\t\t\t\t\tChMGVEVSRU5BMQwwCgYDVQQLEwNJVFMxHjAcBgNVBAMTFWh0dHBzOi8vdGVyZW5h\n\t\t\t\t\t\tLm9yZy9zcDEdMBsGCSqGSIb3DQEJARYOYWFpQHRlcmVuYS5vcmcwHhcNMTEwMTEy\n\t\t\t\t\t\tMTUyNjM4WhcNMjEwMTExMTUyNjM4WjCBjDELMAkGA1UEBhMCTkwxCzAJBgNVBAgT\n\t\t\t\t\t\tAk5IMRIwEAYDVQQHEwlBbXN0ZXJkYW0xDzANBgNVBAoTBlRFUkVOQTEMMAoGA1UE\n\t\t\t\t\t\tCxMDSVRTMR4wHAYDVQQDExVodHRwczovL3RlcmVuYS5vcmcvc3AxHTAbBgkqhkiG\n\t\t\t\t\t\t9w0BCQEWDmFhaUB0ZXJlbmEub3JnMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAwTxx8JBWSpBJiZgdvGOJDXLwaE29Opx1CBbIrYHm47Oy4btsf0BzCmfd\n\t\t\t\t\t\tSPDlydDm6//355hsQU8BgIh/waEwFZZCg/XyzrJEXCDTZBm1H210aT7FNp356azq\n\t\t\t\t\t\tKOO1bYWcku0xpFOWWf3jCIkjtOiTkbl12Tw7Y+zJRhV2+jleC5td3JxZ6k1qotgN\n\t\t\t\t\t\t+1cGwZ2Tv2HhSNeMC4QsGOyBqeP+7B1CLFqFZSiLWGVqcZi0fGkXf+SrTSEH/kLz\n\t\t\t\t\t\tdciEg2EePyQPcLCKNz9RiIhSmsLE/Rr1ksOvZGmyWFe7YsPyJOLsNyYcZTufDVwp\n\t\t\t\t\t\tl9fDuJdYy2GdMT1kSNNOpZXZ7QcgYwIDAQABo4H0MIHxMB0GA1UdDgQWBBQ6tVqj\n\t\t\t\t\t\tpKC8+30XF/qWlaZ3fUKTvDCBwQYDVR0jBIG5MIG2gBQ6tVqjpKC8+30XF/qWlaZ3\n\t\t\t\t\t\tfUKTvKGBkqSBjzCBjDELMAkGA1UEBhMCTkwxCzAJBgNVBAgTAk5IMRIwEAYDVQQH\n\t\t\t\t\t\tEwlBbXN0ZXJkYW0xDzANBgNVBAoTBlRFUkVOQTEMMAoGA1UECxMDSVRTMR4wHAYD\n\t\t\t\t\t\tVQQDExVodHRwczovL3RlcmVuYS5vcmcvc3AxHTAbBgkqhkiG9w0BCQEWDmFhaUB0\n\t\t\t\t\t\tZXJlbmEub3JnggkAv3QLEwRVv+QwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAn+06i7zZE7MjuB68gCaNvnCkrgfumi4PWiP6kaE6+LU2MTbxdFyoSAoK\n\t\t\t\t\t\th6Ft9TDi+8ANAsn5jRQ5xLUE4YoVbub/KufMwdlX0zO9i+Q//npDTFESnWsiMi7D\n\t\t\t\t\t\tHg/av1LtzrYYZvE2E1e5c/7wo/axx8Bk7qsE9YXFRs372vDkDwOGSkLbRtgwdCUX\n\t\t\t\t\t\t47CE/fXvccPDHH217XMed2cVOGFjQgidsFZlJbSfSvQjWYw5LIE0wo9RtsEu5I3W\n\t\t\t\t\t\tAIar8Wr6/nhVOgIBUStpcw94GwlPxLywfij5CJ9HT+sN2SOj4YmKPBtcwHI75uNZ\n\t\t\t\t\t\tp7XRy85jRjrvhahg5baIQ0u3aL8aMA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEkjCCA3qgAwIBAgIJAL90CxMEVb/kMA0GCSqGSIb3DQEBBQUAMIGMMQswCQYD\n\t\t\t\t\t\tVQQGEwJOTDELMAkGA1UECBMCTkgxEjAQBgNVBAcTCUFtc3RlcmRhbTEPMA0GA1UE\n\t\t\t\t\t\tChMGVEVSRU5BMQwwCgYDVQQLEwNJVFMxHjAcBgNVBAMTFWh0dHBzOi8vdGVyZW5h\n\t\t\t\t\t\tLm9yZy9zcDEdMBsGCSqGSIb3DQEJARYOYWFpQHRlcmVuYS5vcmcwHhcNMTEwMTEy\n\t\t\t\t\t\tMTUyNjM4WhcNMjEwMTExMTUyNjM4WjCBjDELMAkGA1UEBhMCTkwxCzAJBgNVBAgT\n\t\t\t\t\t\tAk5IMRIwEAYDVQQHEwlBbXN0ZXJkYW0xDzANBgNVBAoTBlRFUkVOQTEMMAoGA1UE\n\t\t\t\t\t\tCxMDSVRTMR4wHAYDVQQDExVodHRwczovL3RlcmVuYS5vcmcvc3AxHTAbBgkqhkiG\n\t\t\t\t\t\t9w0BCQEWDmFhaUB0ZXJlbmEub3JnMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAwTxx8JBWSpBJiZgdvGOJDXLwaE29Opx1CBbIrYHm47Oy4btsf0BzCmfd\n\t\t\t\t\t\tSPDlydDm6//355hsQU8BgIh/waEwFZZCg/XyzrJEXCDTZBm1H210aT7FNp356azq\n\t\t\t\t\t\tKOO1bYWcku0xpFOWWf3jCIkjtOiTkbl12Tw7Y+zJRhV2+jleC5td3JxZ6k1qotgN\n\t\t\t\t\t\t+1cGwZ2Tv2HhSNeMC4QsGOyBqeP+7B1CLFqFZSiLWGVqcZi0fGkXf+SrTSEH/kLz\n\t\t\t\t\t\tdciEg2EePyQPcLCKNz9RiIhSmsLE/Rr1ksOvZGmyWFe7YsPyJOLsNyYcZTufDVwp\n\t\t\t\t\t\tl9fDuJdYy2GdMT1kSNNOpZXZ7QcgYwIDAQABo4H0MIHxMB0GA1UdDgQWBBQ6tVqj\n\t\t\t\t\t\tpKC8+30XF/qWlaZ3fUKTvDCBwQYDVR0jBIG5MIG2gBQ6tVqjpKC8+30XF/qWlaZ3\n\t\t\t\t\t\tfUKTvKGBkqSBjzCBjDELMAkGA1UEBhMCTkwxCzAJBgNVBAgTAk5IMRIwEAYDVQQH\n\t\t\t\t\t\tEwlBbXN0ZXJkYW0xDzANBgNVBAoTBlRFUkVOQTEMMAoGA1UECxMDSVRTMR4wHAYD\n\t\t\t\t\t\tVQQDExVodHRwczovL3RlcmVuYS5vcmcvc3AxHTAbBgkqhkiG9w0BCQEWDmFhaUB0\n\t\t\t\t\t\tZXJlbmEub3JnggkAv3QLEwRVv+QwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAn+06i7zZE7MjuB68gCaNvnCkrgfumi4PWiP6kaE6+LU2MTbxdFyoSAoK\n\t\t\t\t\t\th6Ft9TDi+8ANAsn5jRQ5xLUE4YoVbub/KufMwdlX0zO9i+Q//npDTFESnWsiMi7D\n\t\t\t\t\t\tHg/av1LtzrYYZvE2E1e5c/7wo/axx8Bk7qsE9YXFRs372vDkDwOGSkLbRtgwdCUX\n\t\t\t\t\t\t47CE/fXvccPDHH217XMed2cVOGFjQgidsFZlJbSfSvQjWYw5LIE0wo9RtsEu5I3W\n\t\t\t\t\t\tAIar8Wr6/nhVOgIBUStpcw94GwlPxLywfij5CJ9HT+sN2SOj4YmKPBtcwHI75uNZ\n\t\t\t\t\t\tp7XRy85jRjrvhahg5baIQ0u3aL8aMA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.terena.org/wayf/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.terena.org/wayf/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://44uoc-shib.hosted.exlibrisgroup.com/shib",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://44uoc-shib.hosted.exlibrisgroup.com/shib",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-11-26T11:18:34Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Primo - University of Cumbria"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://exlibrisgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ex Libris (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://44uoc-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://44uoc-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://44uoc-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://44uoc-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://44uoc-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://44uoc-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://44uoc-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAPWl7V7VX/BFMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB2FpbzAwNDQwHhcNMTUxMDI1MTQ0NTQ2WhcNMjUxMDIyMTQ0NTQ2WjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdhaW8wMDQ0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tuIcM5XvuJ5roqwsphtfHdwjxqIVJunIy0pwyck/KeRY0rZy3K/ai42qCmTdSPGMU\n\t\t\t\t\t\tWrwfdl/JR8A4e2/b/AntlpDl2/G+jPQ3dhFx4eG/sk04ut/X+LO0RuGNdkKe4VbJ\n\t\t\t\t\t\tha63y/A9kE9a1lQ8oKsqed8Cr0nmB5H/nthYQ6UA+8aRZWO1g0qT6UHg5CTX7Zub\n\t\t\t\t\t\tsIkn3bQgNm5dVUFj5x6CBMeWHz+BWy3XzXn75kI4pN1NZ9HiD8jGmQCFF6lRzizJ\n\t\t\t\t\t\tTUjtKQhypNhcFrQKoMwMXgs8x4qB4MAI302NaBIz4V1R62kha6rNKn45wJEZXLmf\n\t\t\t\t\t\tbN9rScqFZvDdTG/SkX6SQQIDAQABozUwMzASBgNVHREECzAJggdhaW8wMDQ0MB0G\n\t\t\t\t\t\tA1UdDgQWBBQXn/9ZqY5Ort4ff/XLCRX62+IwYTANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tR8xjk3N+t3FLTObtLn35afpxZfNBOpJzbFLKwFKSRI4iZt10VVE1nSRdljLkaMhR\n\t\t\t\t\t\tvpiPPtjEYYvKHt5kRNA15NxnGpxYr9qfQGu+3fAtAG1auBFowVQVhOoKQEbzcrQh\n\t\t\t\t\t\tUwOLwcpN/8P+iPSkC8YxuyK7aXKF9w0xUZrSjAd8iQQ6vbFDQrMWYGy5oqOU/rqP\n\t\t\t\t\t\tE07zzDN6vGUjOBs1x3cETWhHM+albmFtA2dy8c/OCt5VnVclq8fEwtl/RUnYcXEw\n\t\t\t\t\t\t6CUcCp/EGnOJy+SfLxLpMR8A6o6Nt0XY41xVVzZBq8HIEa7TPmLcDU/AuSnDcRMV\n\t\t\t\t\t\tUYiWPI94pu+HFPXSz+yu3w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://44uoc-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://44uoc-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://44uoc-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://44uoc-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://44uoc-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://44uoc-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.upmc.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "exploitationdsi@upmc.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.upmc.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2010-03-30T10:20:06Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.upmc.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.upmc.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.upmc.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "upmc.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.upmc.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Paris 6 - Pierre et Marie Curie"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Paris 6 - Pierre et Marie Curie"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAN1AZOqK88JKnAIFyCt2qtu7oPjcMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2lkcC51cG1jLmZyMB4XDTA5MTIyOTEyMDUwN1oXDTI5\nMTIyOTEyMDUwN1owFjEUMBIGA1UEAxMLaWRwLnVwbWMuZnIwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCoXzLI2AobGhWJRoofrUz1FYBOgAk68Q5TIZ+h\nGvBAJj7/23JkOyaz6vaGqls+iqycDPHx3grJ6KsDbIoCPcgbyb3vyAJOkxT49fzp\nC0RGJVKGPZoNaCV2KXSO49Il5yWb7zIwXBKBn5QSRSOE7S2YINHzzlGVj2SWCaCJ\nLY3K7R+O5TMaiqqKXcO20tmme7FDckHc/fPw8H+R8r9TgLvoPbCIqjnvCHsj+192\nWNtzs99sMwZ21xaMo0QS9VsX6JMmsJViQwNyAgE6gxbG1SEWD2G1ja7bW/o9LuUG\nJvDjfDmzNj316AeYMWnzY+275B2fr/JcawcmmF3aK6xPjqRZAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2lkcC51cG1jLmZyhiJodHRwczovL2lkcC51cG1jLmZyL2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBQHbFPNG0miSxq1PVDJGqFQbHEdtjANBgkqhkiG\n9w0BAQUFAAOCAQEAiznIMyBVikg8EfABaENTvB0ND8rZN1cVNIU/LoiBHL6DF7bQ\nhGd7JManqhNH5TdHXmfK5CsIZMBGbYIMhyTDxsW3ASNR5Ip2Lpq+9YgTSi+k4FzM\nVYCRAJw9mjTrDfCVVG2ZdN0FaWLezJhGG0iJDlmpzhDDpBsAt88Aj6uqXJrKGp3Z\nExxnD0z0ECRqrbfgM8lUgAW2hS1C4wgO8sz6FpOIJ1kkXZ54TjI9UE2rmWKkD+iT\nnBrz6NcdhS32ZUARncfqoFZvOY+9rh4Q2SQIRyjKrAG/2TNVxVo6E+xEzx8nN63D\nGz5/Q64Ts766vZwDA9u1fXIedZRbjJHYD4o6Fw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Paris 6 - Pierre et Marie Curie"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.upmc.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Paris 6 - Pierre et Marie Curie"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.crous-clermont.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dsi@crous-clermont.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.crous-clermont.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-02-07T15:26:52Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.crous-clermont.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.crous-clermont.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.crous-clermont.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "crous-clermont.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.crous-clermont.fr"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Clermont-Ferrand"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Clermont-Ferrand"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUSGgZ2BiSEkpo4LfpMRytX1Ewj7YwDQYJKoZIhvcNAQEF\nBQAwIDEeMBwGA1UEAxMVaWRwLmNyb3VzLWNsZXJtb250LmZyMB4XDTEzMDIxMjA5\nMTIxNVoXDTMzMDIxMjA5MTIxNVowIDEeMBwGA1UEAxMVaWRwLmNyb3VzLWNsZXJt\nb250LmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAypdI1XWeWpyQ\nKK2ipthV2k6uItAQ0D1T2JW5iQd7VSXGRDVW87Zc4pORHHYpP9a6Pod8RiQ3oV3g\nNxbe6KmqJHG2FWi7rU6YVD9P9Cq4ehXeHE1IPP/EyJWkQ+bwQsIdjsA4APhUZfZK\ny4yQ5GHH/kTPXSVtmzmL52vyHADo2JJgeFoENn5Oowgp2NiC5j8W/SCIYVXSWOFx\n+9xFNpuI1crvroONko9OHGryf3w8SbkzAfBm2CfyJbwiprFo6T+uF3VDSUUss/m/\nWUL+hJT7z5UjaQg6wazyMHuQBUP1pZ9a48V6eTbRaGjpVwrW7PxJarUviA5DLK5S\npHAU0KaDWwIDAQABo3EwbzBOBgNVHREERzBFghVpZHAuY3JvdXMtY2xlcm1vbnQu\nZnKGLGh0dHBzOi8vaWRwLmNyb3VzLWNsZXJtb250LmZyL2lkcC9zaGliYm9sZXRo\nMB0GA1UdDgQWBBQIPelJ6PRctrShUnviqE24f1IPtDANBgkqhkiG9w0BAQUFAAOC\nAQEAh/cffEhRnuqX6aMzkHWVe4QA3nuUUTO+ckfbdxqXqu8tqIab1zpSibhFYz6N\n990n2k8Pj6AcVDslx3HntU2z8fuCwZXerk3YuIbcncRcoR+Dq0BuE+Lz2fwkF/xR\nGW7Fs7QPT1u9e6Gc4LD/JVjUK/7WdwgGMQpYnUt6HLefsgdmAEwJZXR4XnUf26yn\nwanyC1UVgvD9u8IHnKUgJ1zB0nEEhtc6i0gpGxireo0fAEPIRkJNYmOPWobj0k5u\nW2E7UTJHp3V5SlkS0nBj+hIa9UYTFtWpDWNooygEWKdJ6qtVNq0LCRoLwS1icdPB\nrQpa7Omoq1LaBUSMRTaVxentYQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS Clermont-Ferrand"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.crous-clermont.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS Clermont-Ferrand"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp-test.warwick.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Howes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:n.howes@warwick.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nick"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Howes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:n.howes@warwick.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nick"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-test.warwick.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-01-24T16:20:30Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUMIS+8kDOqLvJbUPFF2xn+2rtu2AwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwITEfMB0GA1UEAxMWaWRwLXRlc3Qud2Fyd2ljay5hYy51azAeFw0xNDA3MDkx\n\t\t\t\t\t\tNDM4NTdaFw0zNDA3MDkxNDM4NTdaMCExHzAdBgNVBAMTFmlkcC10ZXN0Lndhcndp\n\t\t\t\t\t\tY2suYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDlWqm4NoAE\n\t\t\t\t\t\ttvOm4rJwmxQROFZePbsoT+s2AKABtCe+huTRwccxoMVKxNcRgiXrC9axXOMYtn2F\n\t\t\t\t\t\t7Vet6JPTSh2byxP/GRAFzgmbB5wUtDEWnrchbDELwDBBs4gf0f2+xsW8CcDnwAKO\n\t\t\t\t\t\tYn70mFO5z+gOfrNQjUN4NoIrrXKhOXmvus+3igWcJtgZBjZ4GWEybkk45PNPvLmM\n\t\t\t\t\t\tNTAchGTn+XJeOqYQi5YrxQOr7AaQX5lMNULZ/vC8d38lfwnKEbnZ6RNA7BS7Oo4K\n\t\t\t\t\t\t/kYbnZCJ4Surzd86PCRXqPWECqZukH30QUclQ7vgajZNQ5nYkw17fRVxRl0lzR6y\n\t\t\t\t\t\tAwwbVjUr63NxAgMBAAGjczBxMFAGA1UdEQRJMEeCFmlkcC10ZXN0LndhcndpY2su\n\t\t\t\t\t\tYWMudWuGLWh0dHBzOi8vaWRwLXRlc3Qud2Fyd2ljay5hYy51ay9pZHAvc2hpYmJv\n\t\t\t\t\t\tbGV0aDAdBgNVHQ4EFgQUNlj6h7hKB35Ej1IlTOV6jeEtFt4wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQADggEBAHARtRPuPljRh+ExT44KfsA82jRt5H9y/B4BRR4Inn0is2F5RgYn4N3u\n\t\t\t\t\t\tKkCYBEos0ntfnjx+pzI7wJS3AETizZoqVGdPscxsXrvqyx563yr4ceoy0DSRfroE\n\t\t\t\t\t\tx9r1dEYMCwmk21c4LSB7pKY3n0bGfKkoxoOU2HtjeZ2c0W0YfnhgUu1YWPBRMah6\n\t\t\t\t\t\tZYMBot6VqwVMhwBhubbKp1qmLGS8s6YT7UvTUtSI3G9h6W8FWgCQF4X5i8MjTisJ\n\t\t\t\t\t\tI4SuWzKOc8mKnhAOms8r10DMOttuIvgCs1cZtHZmZPen1SpXVFx92sWeN2oRlN99\n\t\t\t\t\t\tUkwJwkWY8lTvMN7ELcyAHFYYTqjILF4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "warwick.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-test.warwick.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-test.warwick.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-test.warwick.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-test.warwick.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-test.warwick.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-test.warwick.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-test.warwick.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-test.warwick.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "warwick.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUMIS+8kDOqLvJbUPFF2xn+2rtu2AwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwITEfMB0GA1UEAxMWaWRwLXRlc3Qud2Fyd2ljay5hYy51azAeFw0xNDA3MDkx\n\t\t\t\t\t\tNDM4NTdaFw0zNDA3MDkxNDM4NTdaMCExHzAdBgNVBAMTFmlkcC10ZXN0Lndhcndp\n\t\t\t\t\t\tY2suYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDlWqm4NoAE\n\t\t\t\t\t\ttvOm4rJwmxQROFZePbsoT+s2AKABtCe+huTRwccxoMVKxNcRgiXrC9axXOMYtn2F\n\t\t\t\t\t\t7Vet6JPTSh2byxP/GRAFzgmbB5wUtDEWnrchbDELwDBBs4gf0f2+xsW8CcDnwAKO\n\t\t\t\t\t\tYn70mFO5z+gOfrNQjUN4NoIrrXKhOXmvus+3igWcJtgZBjZ4GWEybkk45PNPvLmM\n\t\t\t\t\t\tNTAchGTn+XJeOqYQi5YrxQOr7AaQX5lMNULZ/vC8d38lfwnKEbnZ6RNA7BS7Oo4K\n\t\t\t\t\t\t/kYbnZCJ4Surzd86PCRXqPWECqZukH30QUclQ7vgajZNQ5nYkw17fRVxRl0lzR6y\n\t\t\t\t\t\tAwwbVjUr63NxAgMBAAGjczBxMFAGA1UdEQRJMEeCFmlkcC10ZXN0LndhcndpY2su\n\t\t\t\t\t\tYWMudWuGLWh0dHBzOi8vaWRwLXRlc3Qud2Fyd2ljay5hYy51ay9pZHAvc2hpYmJv\n\t\t\t\t\t\tbGV0aDAdBgNVHQ4EFgQUNlj6h7hKB35Ej1IlTOV6jeEtFt4wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQADggEBAHARtRPuPljRh+ExT44KfsA82jRt5H9y/B4BRR4Inn0is2F5RgYn4N3u\n\t\t\t\t\t\tKkCYBEos0ntfnjx+pzI7wJS3AETizZoqVGdPscxsXrvqyx563yr4ceoy0DSRfroE\n\t\t\t\t\t\tx9r1dEYMCwmk21c4LSB7pKY3n0bGfKkoxoOU2HtjeZ2c0W0YfnhgUu1YWPBRMah6\n\t\t\t\t\t\tZYMBot6VqwVMhwBhubbKp1qmLGS8s6YT7UvTUtSI3G9h6W8FWgCQF4X5i8MjTisJ\n\t\t\t\t\t\tI4SuWzKOc8mKnhAOms8r10DMOttuIvgCs1cZtHZmZPen1SpXVFx92sWeN2oRlN99\n\t\t\t\t\t\tUkwJwkWY8lTvMN7ELcyAHFYYTqjILF4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Warwick (Test IdP - do not use)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.warwick.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Warwick"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.blackburn.ac.uk/entity",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lorgat"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:h.lorgat@blackburn.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hussein"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lorgat"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:h.lorgat@blackburn.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hussein"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.blackburn.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-07-03T16:57:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDXDCCAkQCCQCDh5l0tXKOTzANBgkqhkiG9w0BAQUFADBwMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjETMBEGA1UECBMKTGFuY2FzaGlyZTESMBAGA1UEBxMJQmxhY2tidXJuMRowGAYD\n\t\t\t\t\t\tVQQKExFCbGFja2J1cm4gQ29sbGVnZTEcMBoGA1UEAxMTaWRwLmJsYWNrYnVybi5h\n\t\t\t\t\t\tYy51azAeFw0xNDA0MDkwNzU2MzNaFw0zNDA0MDQwNzU2MzNaMHAxCzAJBgNVBAYT\n\t\t\t\t\t\tAkdCMRMwEQYDVQQIEwpMYW5jYXNoaXJlMRIwEAYDVQQHEwlCbGFja2J1cm4xGjAY\n\t\t\t\t\t\tBgNVBAoTEUJsYWNrYnVybiBDb2xsZWdlMRwwGgYDVQQDExNpZHAuYmxhY2tidXJu\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAwBW5mNKzK19M\n\t\t\t\t\t\t0cPz3xt5l5rckUonhNxfbzrEYqrRomyBRMPwv9rDcepIvl/ATrRqkhqppibRnAk9\n\t\t\t\t\t\ts7RsDCoLboLTHLi/1bb3I8+Pm1Hy+ay0+BgSvMnBHeLqCAwLiE5V+oexN4ha3JJH\n\t\t\t\t\t\tPVpwN7+HFdGtHO2ZO9K2VrpvwuaUZfhOEAnfuNFnTHA7doKwQWWyvlTfqrY2XNuE\n\t\t\t\t\t\tZkUD6RdvxeDB555Nzl7BvMWL+nr41WuWW5r7jZyl5EEOgr7AiwbyRrpaKdZ4ditW\n\t\t\t\t\t\tozyRSSo/gQDbXF0fhlomrPQzegnOwRmmD96lKAcd1xk61PE3AkrC8oA0pj+PWe90\n\t\t\t\t\t\tvUxeeftg2QIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQBjnFevePhXMt3YQOIs3l2p\n\t\t\t\t\t\t35bLcLUc1yLy+2+7ynCH2Vsy8UpB1puQQE3wug7/zYhxp6RV2OKpTXPugW9Mx8TB\n\t\t\t\t\t\t8eM/ZCoqVbc4H6VH29G8XhwI+XYBnsnT6wS9KU3v5fEUIErP2dLnSBDpqBKyuAwP\n\t\t\t\t\t\tyzpDwmqPTzifuv5QB2MaFMM5t/qBUFAXbSuueRgA1gICtdb7kVUv0n/7BE6IsncC\n\t\t\t\t\t\toaR0/Gdlwm+88m394nirzjEkGX3YHIPMh5Sd6DOyiyG+apm59uv5lzl4WNZbCBhl\n\t\t\t\t\t\tiJ5xfqTVtk2Ic+IW+u3PQ8sqH9v+UnIxr1o51pAQL4ambSFHaE7mr4tMUHv5mlFC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "blackburn.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.blackburn.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.blackburn.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.blackburn.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.blackburn.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.blackburn.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.blackburn.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.blackburn.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.blackburn.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "blackburn.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDXDCCAkQCCQCDh5l0tXKOTzANBgkqhkiG9w0BAQUFADBwMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjETMBEGA1UECBMKTGFuY2FzaGlyZTESMBAGA1UEBxMJQmxhY2tidXJuMRowGAYD\n\t\t\t\t\t\tVQQKExFCbGFja2J1cm4gQ29sbGVnZTEcMBoGA1UEAxMTaWRwLmJsYWNrYnVybi5h\n\t\t\t\t\t\tYy51azAeFw0xNDA0MDkwNzU2MzNaFw0zNDA0MDQwNzU2MzNaMHAxCzAJBgNVBAYT\n\t\t\t\t\t\tAkdCMRMwEQYDVQQIEwpMYW5jYXNoaXJlMRIwEAYDVQQHEwlCbGFja2J1cm4xGjAY\n\t\t\t\t\t\tBgNVBAoTEUJsYWNrYnVybiBDb2xsZWdlMRwwGgYDVQQDExNpZHAuYmxhY2tidXJu\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAwBW5mNKzK19M\n\t\t\t\t\t\t0cPz3xt5l5rckUonhNxfbzrEYqrRomyBRMPwv9rDcepIvl/ATrRqkhqppibRnAk9\n\t\t\t\t\t\ts7RsDCoLboLTHLi/1bb3I8+Pm1Hy+ay0+BgSvMnBHeLqCAwLiE5V+oexN4ha3JJH\n\t\t\t\t\t\tPVpwN7+HFdGtHO2ZO9K2VrpvwuaUZfhOEAnfuNFnTHA7doKwQWWyvlTfqrY2XNuE\n\t\t\t\t\t\tZkUD6RdvxeDB555Nzl7BvMWL+nr41WuWW5r7jZyl5EEOgr7AiwbyRrpaKdZ4ditW\n\t\t\t\t\t\tozyRSSo/gQDbXF0fhlomrPQzegnOwRmmD96lKAcd1xk61PE3AkrC8oA0pj+PWe90\n\t\t\t\t\t\tvUxeeftg2QIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQBjnFevePhXMt3YQOIs3l2p\n\t\t\t\t\t\t35bLcLUc1yLy+2+7ynCH2Vsy8UpB1puQQE3wug7/zYhxp6RV2OKpTXPugW9Mx8TB\n\t\t\t\t\t\t8eM/ZCoqVbc4H6VH29G8XhwI+XYBnsnT6wS9KU3v5fEUIErP2dLnSBDpqBKyuAwP\n\t\t\t\t\t\tyzpDwmqPTzifuv5QB2MaFMM5t/qBUFAXbSuueRgA1gICtdb7kVUv0n/7BE6IsncC\n\t\t\t\t\t\toaR0/Gdlwm+88m394nirzjEkGX3YHIPMh5Sd6DOyiyG+apm59uv5lzl4WNZbCBhl\n\t\t\t\t\t\tiJ5xfqTVtk2Ic+IW+u3PQ8sqH9v+UnIxr1o51pAQL4ambSFHaE7mr4tMUHv5mlFC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Blackburn College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.blackburn.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Blackburn College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://test-secure.palgraveconnect.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Abia"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:C.Abia@nature.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chike"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ollier"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:j.ollier@nature.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Abia"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:C.Abia@nature.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chike"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ollier"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:j.ollier@nature.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test-secure.palgraveconnect.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-05-08T17:38:32Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Macmillan Publishers Limited: Palgrave Connect Test"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.palgraveconnect.com/pc/info/about.html"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Macmillan Publishers Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIEUiiGYTANBgkqhkiG9w0BAQUFADBqMQswCQYDVQQGEwJV\n\t\t\t\t\t\tSzEPMA0GA1UEBxMGTG9uZG9uMRIwEAYDVQQKEwlNYWNtaWxsYW4xDDAKBgNVBAsT\n\t\t\t\t\t\tA05QRzEoMCYGA1UEAxMfdGVzdC1zZWN1cmUucGFsZ3JhdmVjb25uZWN0LmNvbTAe\n\t\t\t\t\t\tFw0xMzA5MDUxMzI1NTNaFw0yMzA5MDMxMzI1NTNaMGoxCzAJBgNVBAYTAlVLMQ8w\n\t\t\t\t\t\tDQYDVQQHEwZMb25kb24xEjAQBgNVBAoTCU1hY21pbGxhbjEMMAoGA1UECxMDTlBH\n\t\t\t\t\t\tMSgwJgYDVQQDEx90ZXN0LXNlY3VyZS5wYWxncmF2ZWNvbm5lY3QuY29tMIIBIjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsUYvYU275ISzg9fuYD4q550xgkOF\n\t\t\t\t\t\tzpY/9rRNc+fFM0EsAWU8REv+lombeK4PQzRcK654Xyd6+WhCd5JViFJIZK+/E3KZ\n\t\t\t\t\t\tjEghitSkY+sicWsjzA/L5v1QyX60s7HBvsYoNCLezbrjeFIN35qol/FgQJsEc/vr\n\t\t\t\t\t\t2/dLDYkC/bDIC6O29mZEIt1lyrBXGUe8Dc1MshUNvkiw8vBHVCMJBxuDpB4aeHzS\n\t\t\t\t\t\t5AvsQPkHAhB93cG7su1evDLZnsael3xD/58qbDFQqfsyKR1ScJxqsTcYU10UTA8m\n\t\t\t\t\t\tzGC+1c7748O5j+NnbzoGH1ceRxF/xkAjGnnk3doTUvdTivxYdtP4PB9O5QIDAQAB\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQBEzosiuF1PrqV9xnxsggY6+kLgGRYlYNDabyYa\n\t\t\t\t\t\t6sqmH6VZK/xyDNiclAFq6zwodf+JQ937hbKJ92kef8HicvwdtZUugSVVp8200qRW\n\t\t\t\t\t\tPb2zeasxzMr/qDJi+aXD2MQ9o7Ek+EOIi3jHzsjSEvsfhZhhFgFumGfmxHfP8UGe\n\t\t\t\t\t\tX4wqxqTD1XCB74snLGfBWiA8HTBSFWu2I6TcLOaB/h22q53Fb0kWGbKGxnQsIHxx\n\t\t\t\t\t\tc5kRAY+dxwWbALv8WroHrVqTX6LhKujTWkxzh/xQg8hQ7tji/kcDLFi2ymeSpVmX\n\t\t\t\t\t\txSAwo3R1lMXGqwWXGZzadVh5xcajQcO2OX6Ce10amprpfM64"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://test-secure.palgraveconnect.com/shibboleth/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://test-secure.palgraveconnect.com/shibboleth/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test-secure.palgraveconnect.com/shibboleth/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test-secure.palgraveconnect.com/shibboleth/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.umassd.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "coliveira@umassd.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Craig R. Oliveira"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.umassd.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.umassd.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.umassd.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAJcM3MOQxZ8si0E5BGYr72Fa/81LMA0GCSqGSIb3DQEB\nCwUAMBkxFzAVBgNVBAMMDmlkcC51bWFzc2QuZWR1MB4XDTE1MTExMDE2MjUzMFoX\nDTM1MTExMDE2MjUzMFowGTEXMBUGA1UEAwwOaWRwLnVtYXNzZC5lZHUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDMlE4wxaYgi/u5MybqncY2X4DOieFH\nz7IoDlAm5OpV8C2CPMW+BjiQ6TBjGxgmJVpBdPyG1/cnuLuS8irtIWjvGXE16TqN\noZv5zMI1wo4ns4mvHWSyS4HMpELQCrhDF1gYl5WpAZTSiOTnzeFTmrJcj519MJIm\nFQcEahb9k4eSKoTbP7bqRbD66b2NUvOXvpsU/cDS1iEWvP8T5nuSs0IV2MNmeTjU\nM4Te9ue8elUyQTZLeAIaYh9LbDnExGu7LgOr9C3OwVNRyXF0+TeATS6Xk7OkNyV2\nIylGeNisJE7PsiAnO9kLaMdciiLZlUSsFCrvw62FI/4T31Aq+yWvWsyXAgMBAAGj\nYzBhMB0GA1UdDgQWBBR1WiFVOyvGgIOqYiG2mBm6Bvm0TDBABgNVHREEOTA3gg5p\nZHAudW1hc3NkLmVkdYYlaHR0cHM6Ly9pZHAudW1hc3NkLmVkdS9pZHAvc2hpYmJv\nbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAEJyy9dkQrYBgzRkVlthKAoVZYFx7owV1\ngHN9w50xzBevvmeGg5JzT9ASEmG8oJnIc7Bp1+MCzAcQfHym1J6m1zuLO4IP92nj\nLbLQxeRtTGasIPxs5NsMwKJw15+Kvw+NRDS0Q04cNz/VKEe2FZ9Ejbh3bAG0OOdi\nhHAQYEb+nF5icqLWRcM3Dy2O7B+DraQaVAxPl1zLH8hESJCTxUPZw2Ztpgpycz+u\nvd40Lau00JitxcFWd5OainenB/QIhYlcQtsEqBgubyiTXzlBSq+ndxwwsCUucyxW\njRlpHHp503ULaAZOVJz+t/3mK0Il1DaWIueXOHYeWFC3t5NE+Mzajg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "umassd.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.umassd.edu"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.umassd.edu/idp/images/umassd.png",
                    "lang": "en",
                    "height": "55",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Massachusetts - Dartmouth"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Massachusetts - Dartmouth"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.umassd.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Massachusetts - Dartmouth"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso.csumb.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idavis-king@csumb.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Isaac Davis-King"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.csumb.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.csumb.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.csumb.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFizCCBHOgAwIBAgICApswDQYJKoZIhvcNAQEFBQAwVjELMAkGA1UEBhMCVVMx\nHDAaBgNVBAoTE0luQ29tbW9uIEZlZGVyYXRpb24xKTAnBgNVBAMTIEluQ29tbW9u\nIENlcnRpZmljYXRpb24gQXV0aG9yaXR5MB4XDTA5MTAwOTE3MDgzMloXDTExMTAx\nMDE3MDgzMlowGDEWMBQGA1UEAxMNc3NvLmNzdW1iLmVkdTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBALN8+nYi1O6eOdWM45pGEgSG/K94eRIYWJybavJx\n42YE6ekJGSPPmU92L+M5E+ESFUu+oXy0YWfEvOuI5PSoRvfBjeS6jMofcnHRnzvv\n+vfoEQdIKjkDiTp/tB/9ggX9V6MWxpP+hXB7wgqv7V+0R4FMs6lcHONqRdNrfdE0\nK6teorVEiWiJq8CJuUHzGq6Jxt1YArVrFn8CcZsPgy0B218Q0xDj5mp9wwQAi6ax\n6FaPPuKUgbPOYv8VzovwLaCZxFo9su0oOSW+GxQnCqeMgkOZCLQTCaNY7wdeNXp+\n2gn7mvC67O4uWf6ZJRIUobzLU7lo18Dm8X6MqPLUiR4SgqUCAwEAAaOCAp8wggKb\nMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUF\nBwMBBggrBgEFBQcDAjAdBgNVHQ4EFgQUC6KlCB98bz+RaJydZyq3ZqyNXKswfgYD\nVR0jBHcwdYAUky3IYRitY+ObZbOd3Y2TuufKY0WhWqRYMFYxCzAJBgNVBAYTAlVT\nMRwwGgYDVQQKExNJbkNvbW1vbiBGZWRlcmF0aW9uMSkwJwYDVQQDEyBJbkNvbW1v\nbiBDZXJ0aWZpY2F0aW9uIEF1dGhvcml0eYIBADCBsgYIKwYBBQUHAQEEgaUwgaIw\nTwYIKwYBBQUHMAKGQ2h0dHA6Ly9pbmNvbW1vbmNhMS5pbmNvbW1vbmZlZGVyYXRp\nb24ub3JnL2JyaWRnZS9jZXJ0cy9jYS1jZXJ0cy5wN2IwTwYIKwYBBQUHMAKGQ2h0\ndHA6Ly9pbmNvbW1vbmNhMi5pbmNvbW1vbmZlZGVyYXRpb24ub3JnL2JyaWRnZS9j\nZXJ0cy9jYS1jZXJ0cy5wN2IwgY0GA1UdHwSBhTCBgjA/oD2gO4Y5aHR0cDovL2lu\nY29tbW9uY3JsMS5pbmNvbW1vbmZlZGVyYXRpb24ub3JnL2NybC9lZWNybHMuY3Js\nMD+gPaA7hjlodHRwOi8vaW5jb21tb25jcmwyLmluY29tbW9uZmVkZXJhdGlvbi5v\ncmcvY3JsL2VlY3Jscy5jcmwwXgYDVR0gBFcwVTBTBgsrBgEEAa4jAQQBATBEMEIG\nCCsGAQUFBwIBFjZodHRwOi8vaW5jb21tb25jYS5pbmNvbW1vbmZlZGVyYXRpb24u\nb3JnL3ByYWN0aWNlcy5wZGYwGAYDVR0RBBEwD4INc3NvLmNzdW1iLmVkdTANBgkq\nhkiG9w0BAQUFAAOCAQEADINiuOQSVU3QnFlJEDsUNFZQf7LEhoj1S2NDNwALQ8Q6\nrKG/CDg1V5ves3tX8xwsM8FhW+KPJR1wKd6QnxsQvt+BEGxSV1jsOhpQjKa0oDmQ\n9Sn+YdfJn9f3iTn17B6tgZI5ngOY6HkZnhGtYrQ0KJ24hNBMQs7CqTYbA1eDxXaS\nVlrb/LPwut26OfziQnj+97HTDz4ex2pTkzOuskC7csDQDX4elWGMjYJIDN2dswZI\nNZkp1RZ6ac9X9y7eu9yI5eZGL8Oc9o5btU0A02TwZAheryrarsITh4FLKtVgivk2\nhrxoBGH+jmibPK4kGAdYItS9gF2QBBH+wRoIBWdBkw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAJ4bXqO6GpvPMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDXNzby5jc3VtYi5lZHUwHhcNMTExMDExMDQxNjU0WhcNMjExMDA4MDQxNjU0\nWjAYMRYwFAYDVQQDEw1zc28uY3N1bWIuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEA4VCVPa0t+KdnmRFqxSQ28hG5MojLWZm0VfIvqaQJJsmZg8cP\nTqHDl6DlsvwnMjJ7lpFXjl6F1uwvSXqAZjvc4sbgHTJiq6NM+TR1trZ2tTbV3z4n\nwYl86IdN3enfTN7ohFlWIi1S4a/iGmTxmJtH7KPHr7YETvAaGnuwgJuS780JkgGW\nRmgzm+EWUM/YJ89M8ixOusOiHBoEONx+g/KWxTOXi/qofwkYHRial0xFj8XChBk5\n04vqtNe+17cpz2D4C8z+lvsTWIlujq78cxb6uh7OwJ7M3bi+LGSy79ofxWGv4PLS\nKsBI76kWz14ksJpAGdXs2gx5oJS8UzsKCihxLQIDAQABo3kwdzAdBgNVHQ4EFgQU\n+mAL7jpG/y3m4hlqRGHUsdfjd4AwSAYDVR0jBEEwP4AU+mAL7jpG/y3m4hlqRGHU\nsdfjd4ChHKQaMBgxFjAUBgNVBAMTDXNzby5jc3VtYi5lZHWCCQCeG16juhqbzzAM\nBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCjbZuyuGfmpIrh4tQSecZi\n412e0rpPgUtI0YlAEnHSzM6IcYlC5GMkjS9DYcMCnd1brPzi63HejHlzgoPCBojI\nFJWGcbxy5IourV7O4zJLW9yLZljC5AQ5Dy4JAwa1Ng3rQYmYB9EQYd3Y3JVsHcyQ\nXf4/+88QgvVLCNwBmDJh/dl+9LgXkYolLyGHHXBkKJpquiCPAKCVu4NXsv4tVxI3\ndMdSS+qrcdWD3HIH2wdkI+i916HBLA9q06HsbrlhSPjphFgYJkjpw0ngKSPmXU39\nq8P6Y9qHgb8m5DEKVxakf/26wy2LraW0P1mxgsZnr5KdMfoK3GWboss9POvErkkp"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csumb.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.csumb.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso.csumb.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sso.csumb.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.csumb.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.csumb.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.csumb.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csumb.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "California State University, Monterey Bay"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFizCCBHOgAwIBAgICApswDQYJKoZIhvcNAQEFBQAwVjELMAkGA1UEBhMCVVMx\nHDAaBgNVBAoTE0luQ29tbW9uIEZlZGVyYXRpb24xKTAnBgNVBAMTIEluQ29tbW9u\nIENlcnRpZmljYXRpb24gQXV0aG9yaXR5MB4XDTA5MTAwOTE3MDgzMloXDTExMTAx\nMDE3MDgzMlowGDEWMBQGA1UEAxMNc3NvLmNzdW1iLmVkdTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBALN8+nYi1O6eOdWM45pGEgSG/K94eRIYWJybavJx\n42YE6ekJGSPPmU92L+M5E+ESFUu+oXy0YWfEvOuI5PSoRvfBjeS6jMofcnHRnzvv\n+vfoEQdIKjkDiTp/tB/9ggX9V6MWxpP+hXB7wgqv7V+0R4FMs6lcHONqRdNrfdE0\nK6teorVEiWiJq8CJuUHzGq6Jxt1YArVrFn8CcZsPgy0B218Q0xDj5mp9wwQAi6ax\n6FaPPuKUgbPOYv8VzovwLaCZxFo9su0oOSW+GxQnCqeMgkOZCLQTCaNY7wdeNXp+\n2gn7mvC67O4uWf6ZJRIUobzLU7lo18Dm8X6MqPLUiR4SgqUCAwEAAaOCAp8wggKb\nMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUF\nBwMBBggrBgEFBQcDAjAdBgNVHQ4EFgQUC6KlCB98bz+RaJydZyq3ZqyNXKswfgYD\nVR0jBHcwdYAUky3IYRitY+ObZbOd3Y2TuufKY0WhWqRYMFYxCzAJBgNVBAYTAlVT\nMRwwGgYDVQQKExNJbkNvbW1vbiBGZWRlcmF0aW9uMSkwJwYDVQQDEyBJbkNvbW1v\nbiBDZXJ0aWZpY2F0aW9uIEF1dGhvcml0eYIBADCBsgYIKwYBBQUHAQEEgaUwgaIw\nTwYIKwYBBQUHMAKGQ2h0dHA6Ly9pbmNvbW1vbmNhMS5pbmNvbW1vbmZlZGVyYXRp\nb24ub3JnL2JyaWRnZS9jZXJ0cy9jYS1jZXJ0cy5wN2IwTwYIKwYBBQUHMAKGQ2h0\ndHA6Ly9pbmNvbW1vbmNhMi5pbmNvbW1vbmZlZGVyYXRpb24ub3JnL2JyaWRnZS9j\nZXJ0cy9jYS1jZXJ0cy5wN2IwgY0GA1UdHwSBhTCBgjA/oD2gO4Y5aHR0cDovL2lu\nY29tbW9uY3JsMS5pbmNvbW1vbmZlZGVyYXRpb24ub3JnL2NybC9lZWNybHMuY3Js\nMD+gPaA7hjlodHRwOi8vaW5jb21tb25jcmwyLmluY29tbW9uZmVkZXJhdGlvbi5v\ncmcvY3JsL2VlY3Jscy5jcmwwXgYDVR0gBFcwVTBTBgsrBgEEAa4jAQQBATBEMEIG\nCCsGAQUFBwIBFjZodHRwOi8vaW5jb21tb25jYS5pbmNvbW1vbmZlZGVyYXRpb24u\nb3JnL3ByYWN0aWNlcy5wZGYwGAYDVR0RBBEwD4INc3NvLmNzdW1iLmVkdTANBgkq\nhkiG9w0BAQUFAAOCAQEADINiuOQSVU3QnFlJEDsUNFZQf7LEhoj1S2NDNwALQ8Q6\nrKG/CDg1V5ves3tX8xwsM8FhW+KPJR1wKd6QnxsQvt+BEGxSV1jsOhpQjKa0oDmQ\n9Sn+YdfJn9f3iTn17B6tgZI5ngOY6HkZnhGtYrQ0KJ24hNBMQs7CqTYbA1eDxXaS\nVlrb/LPwut26OfziQnj+97HTDz4ex2pTkzOuskC7csDQDX4elWGMjYJIDN2dswZI\nNZkp1RZ6ac9X9y7eu9yI5eZGL8Oc9o5btU0A02TwZAheryrarsITh4FLKtVgivk2\nhrxoBGH+jmibPK4kGAdYItS9gF2QBBH+wRoIBWdBkw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAJ4bXqO6GpvPMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDXNzby5jc3VtYi5lZHUwHhcNMTExMDExMDQxNjU0WhcNMjExMDA4MDQxNjU0\nWjAYMRYwFAYDVQQDEw1zc28uY3N1bWIuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEA4VCVPa0t+KdnmRFqxSQ28hG5MojLWZm0VfIvqaQJJsmZg8cP\nTqHDl6DlsvwnMjJ7lpFXjl6F1uwvSXqAZjvc4sbgHTJiq6NM+TR1trZ2tTbV3z4n\nwYl86IdN3enfTN7ohFlWIi1S4a/iGmTxmJtH7KPHr7YETvAaGnuwgJuS780JkgGW\nRmgzm+EWUM/YJ89M8ixOusOiHBoEONx+g/KWxTOXi/qofwkYHRial0xFj8XChBk5\n04vqtNe+17cpz2D4C8z+lvsTWIlujq78cxb6uh7OwJ7M3bi+LGSy79ofxWGv4PLS\nKsBI76kWz14ksJpAGdXs2gx5oJS8UzsKCihxLQIDAQABo3kwdzAdBgNVHQ4EFgQU\n+mAL7jpG/y3m4hlqRGHUsdfjd4AwSAYDVR0jBEEwP4AU+mAL7jpG/y3m4hlqRGHU\nsdfjd4ChHKQaMBgxFjAUBgNVBAMTDXNzby5jc3VtYi5lZHWCCQCeG16juhqbzzAM\nBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCjbZuyuGfmpIrh4tQSecZi\n412e0rpPgUtI0YlAEnHSzM6IcYlC5GMkjS9DYcMCnd1brPzi63HejHlzgoPCBojI\nFJWGcbxy5IourV7O4zJLW9yLZljC5AQ5Dy4JAwa1Ng3rQYmYB9EQYd3Y3JVsHcyQ\nXf4/+88QgvVLCNwBmDJh/dl+9LgXkYolLyGHHXBkKJpquiCPAKCVu4NXsv4tVxI3\ndMdSS+qrcdWD3HIH2wdkI+i916HBLA9q06HsbrlhSPjphFgYJkjpw0ngKSPmXU39\nq8P6Y9qHgb8m5DEKVxakf/26wy2LraW0P1mxgsZnr5KdMfoK3GWboss9POvErkkp"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California State University, Monterey Bay"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://csumb.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California State University, Monterey Bay"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.structuralbiology.eu/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:admin@structuralbiology.eu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Instruct Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smith"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:callum@strubi.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Callum"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.structuralbiology.eu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-08-27T09:57:09Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Instruct"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.structuralbiology.eu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Instruct Academic Services Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.structuralbiology.eu/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.structuralbiology.eu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.structuralbiology.eu/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.structuralbiology.eu/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.structuralbiology.eu/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.structuralbiology.eu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.structuralbiology.eu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Instruct Hub & Submission Systems"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.structuralbiology.eu/images/idplogo.png",
                    "height": "800",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "800"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Instruct"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEjCCAfqgAwIBAgIJAN+JlXZQTIqEMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\n\t\t\t\t\t\tBAMTGWluc3RydWN0My5zdHJ1Ymkub3guYWMudWswHhcNMTUwODIwMTQyNDAwWhcN\n\t\t\t\t\t\tMjUwODE3MTQyNDAwWjAkMSIwIAYDVQQDExlpbnN0cnVjdDMuc3RydWJpLm94LmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkyRI12GbWmUSDeBQ\n\t\t\t\t\t\t8nSH5ZPoda7nNceqsdnfnO+lLZ70XwOqgmFVVAqNbg1WeYydWpyR6iKqOsczwuXa\n\t\t\t\t\t\t/J6korvSUzpdADJKZG1bZXkyLeDdDSVNjeUKRtLPIQWUdTSRJDlBCklEis7IQ6+R\n\t\t\t\t\t\t/BNoLx++vajYR7XrhMPC3nQ2SkVwuLQ7W0Ajq6Sn7Z7JxmYjEJZCmaRWadG1qCiB\n\t\t\t\t\t\tg7qPSesOcgIDgXKPNUT+Ozh+c5GxvORLPoAr6s3eExqd5SUt2po5+bufy8iBwAZE\n\t\t\t\t\t\t2sSzZ0g231mAfTzgVI369nPkpoup2va0+JMT3ujn5B/qqzriT/s5o4HEBhyXfU1f\n\t\t\t\t\t\t09+fXQIDAQABo0cwRTAkBgNVHREEHTAbghlpbnN0cnVjdDMuc3RydWJpLm94LmFj\n\t\t\t\t\t\tLnVrMB0GA1UdDgQWBBR7lXIwMNuLrfnsNGce+qvw1bplnzANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAbfSyse9rOaR/APyq3n8sZ46hOn2Wnu9IThkfHTJ1m5Hx1G7iX2aU4cdz\n\t\t\t\t\t\t3KVw11B7u1oJM4CsYP/kV80xp8IfcEWf0JZI1HYQH+vO6to6u9mNPA5nvOdg3l5u\n\t\t\t\t\t\tsLsxc8SliF7yD7jVkKgfGfmgTlaIYg74nl0fS45Z2v8yw7Pvj1pkHY2udm+vqskv\n\t\t\t\t\t\t2x2tdK1pLFIXu5ut1yw7mEQ6jjlYf/puELbKlftUUsWNjrS8lTY4RZou29NHLE3m\n\t\t\t\t\t\tbXSBng+QaO933jEauYxkAiHIddQn+KCPu+bOFW1MRvd4ttKt5dtNTikRIDBm3f6C\n\t\t\t\t\t\tMf9E9cJ5KenVAYmDtaBbf17stP5/1A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.structuralbiology.eu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.structuralbiology.eu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.structuralbiology.eu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.structuralbiology.eu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.structuralbiology.eu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.structuralbiology.eu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://access-check.edugain.org/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "edugain-integration@geant.net"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://access-check.edugain.org/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-01-30T15:32:58Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://access-check.edugain.org/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "access-check.edugain.org"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.renater.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "eduGAIN Access Check allows administrators of a Service Provider (SP) registered in eduGAIN to create test accounts with different profiles to validate the behaviour and test federated login. The test accounts can only be used to access own services."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "eduGAIN Access Check allows administrators of a Service Provider (SP) registered in eduGAIN to create test accounts with different profiles to validate the behaviour and test federated login. The test accounts can only be used to access own services."
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "eduGAIN Access Check"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "eduGAIN Access Check"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID2zCCAsOgAwIBAgIJAJpdV2MFitUqMA0GCSqGSIb3DQEBBQUAMIGDMQswCQYD\nVQQGEwJGUjEVMBMGA1UEBwwMRGVmYXVsdCBDaXR5MQ4wDAYDVQQKDAVHRUFOVDEd\nMBsGA1UEAwwUdGVzdC1pZHAuZWR1Z2Fpbi5vcmcxLjAsBgkqhkiG9w0BCQEWH3Rl\nc3RpZHBhY2NvdW50bWFuYWdlckBnZWFudC5uZXQwHhcNMTQxMjE4MTAxODU5WhcN\nMjQxMjE3MTAxODU5WjCBgzELMAkGA1UEBhMCRlIxFTATBgNVBAcMDERlZmF1bHQg\nQ2l0eTEOMAwGA1UECgwFR0VBTlQxHTAbBgNVBAMMFHRlc3QtaWRwLmVkdWdhaW4u\nb3JnMS4wLAYJKoZIhvcNAQkBFh90ZXN0aWRwYWNjb3VudG1hbmFnZXJAZ2VhbnQu\nbmV0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAo48FFP0P/81e3WHb\nU91F/TYDZC/JypEqO2XQNH50baXpk2JrJFVFOWdgdK6qWHsLznuxngRsfOasAaVA\nOb1Bf3g2xgPUd2htSLxds+o/Y24DOM6ZairxbWJk2rOvLhJFchlrcNWCpMtUCkfJ\nxmqGmeo93XAud5byj3wQ1NuH2o8rjTPAkMgQdr8D2b8EG1NYEH00AqRlXZTFCWGL\nKDEuZwyta6vgMQYT4K6UF/F+HWF2wzbmVgRTHguJ0rzNqz6t+9CtLkhyZO+/57Ro\n4U0ikshVWkUOENPKCnB1t+ebs/AsNozbIGA/HcdtwUwDgIowv/K0hdnLDC1vz6/S\nF3rnGQIDAQABo1AwTjAdBgNVHQ4EFgQUgWN9jmJxOEHYU5m8D0atl895HxowHwYD\nVR0jBBgwFoAUgWN9jmJxOEHYU5m8D0atl895HxowDAYDVR0TBAUwAwEB/zANBgkq\nhkiG9w0BAQUFAAOCAQEAXvlBHMaBK6m0PQNanTqGBRdRAFt8Xkr5texD5mPTmS/7\nnqnxlN0orqYWGCaARmQE+T77EB2a2n9g2s130pUXwJxcbUwIOdPKH6CMKEHT/512\nbndJXQ3DyhkuVSLtRFOdfleIhi8qUkNC9FWxM4jDHDTTQtNEHnCjFxlhxw+ri5QJ\nAVKpH9MkcuIkM6Jx+QhNwTDwCRIJffoDOH420yR5EWx/sQ4tjKQGiFOPv/WHFjXd\nLqHU+X8ErzxeNmUHHST6pHePWRCMtoPTdCPhEroJhou6NMHh8ylQOIVHt6gggc7r\nkUWMUybDUxPp49qMeNkdKqFPby2aW7ouKRoOXuxZhg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "eduGAIN Access Check"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.renater.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "eduGAIN Access Check"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/sso.sdu.dk/wayf",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/sso.sdu.dk/wayf",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2010-08-17T13:36:49Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayf.sdu.dk/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sdu.dk"
              },
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Syddansk Universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Southern Denmark"
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Syddansk Universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Southern Denmark"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "sdu.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICuDCCAaACAQcwDQYJKoZIhvcNAQELBQAwIjEgMB4GA1UEAwwXaHR0cHM6Ly9z\nc28uc2R1LmRrL3dheWYwHhcNMTUwMTAxMDAwMDAwWhcNMjUxMjMxMjM1OTU5WjAi\nMSAwHgYDVQQDDBdodHRwczovL3Nzby5zZHUuZGsvd2F5ZjCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAMeIDApqEFO4jhn4gnWuA54SIILLdtH1Ah7cGkKx\n6MUJTmtLORYA2pW5zU8N+nQl0hmGs9eyYMlAyaJ08IY8gNAqj5uT5p/f4RQVL8j/\n7fmxIFfa9/6HUMe9lX2OzOealJWOnsdn9ag9YHKRYEk7QA5WbMHnOVqqRLfonvr7\nDF6vB2m4TFWdhI13vdL4DJP8Rn61cA77qVDwUv9gyUmdSRJpKotIcXLTUPaoE2Zh\nHAGkJLr91RnLGLS3mPyCEpQPgEc5lVq+frknrZwl1eI5wxHJQAinnsZdCsvrcq2u\nMhxd12r4JnJnm3fsR1Q4jPjaOgVzLvcwU6e3KeUoS87DUEkCAwEAATANBgkqhkiG\n9w0BAQsFAAOCAQEACS/KoQ5/zG5slfeumGF7VD/qNY1Chhl2yrqabVx0GGTsZz/C\neadVX++yblAqpTIoJqONPBbQbkHjrJoldBBS/xZwjHf/cxUY3v+91AJcUUSIcuD8\n7CClgaQzqciyXNsUhChN8ifiCsIkYHXrChEeCIHdsRn/Iga2cFryanhxCOVIeuli\nIWHwuRYZUHvlSUPGe+e5N+RFmuG27Onic1758ckWx9Z6v4Vdtk1JY/8zQRBsDpwR\nuLPggQhaFN4l/GFI0a8wKQd7xvvyFjpUVbDkFXyVHdOBJwmaL5djSlybfS1JP293\njZehS9P/tKKffrsqCxpzGtwrXTEfxfMsmYVKeQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Syddansk Universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Southern Denmark"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sdu.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sdu.dk/?sc_lang=en"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Syddansk Universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Southern Denmark"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://rkh.adfs-proxy-test.swamid.se/Saml2IDP/proxy.xml",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "technical@example.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@example.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://rkh.adfs-proxy-test.swamid.se/Saml2IDP/proxy.xml",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#md5",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#ripemd160",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http,//www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-md5",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-ripemd160",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://adfs-proxy-test.swamid.se:10000/Saml2/sso/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://adfs-proxy-test.swamid.se:10000/Saml2/sso/redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEBjCCAu6gAwIBAgIJANwxpCjfD5fLMA0GCSqGSIb3DQEBBQUAMF8xCzAJBgNV\nBAYTAkFVMRMwEQYDVQQIEwpTb21lLVN0YXRlMSEwHwYDVQQKExhJbnRlcm5ldCBX\naWRnaXRzIFB0eSBMdGQxGDAWBgNVBAMTD2xva2kuaXRzLnVtdS5zZTAeFw0xNTEy\nMTAxNDMzNTlaFw0yNTEyMDcxNDMzNTlaMF8xCzAJBgNVBAYTAkFVMRMwEQYDVQQI\nEwpTb21lLVN0YXRlMSEwHwYDVQQKExhJbnRlcm5ldCBXaWRnaXRzIFB0eSBMdGQx\nGDAWBgNVBAMTD2xva2kuaXRzLnVtdS5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAOCyQM982ZWJRI6SJ5nPCX2TZATHJfpsWHzXRQpt/vrtmYkvaWKL\nBqSzNhJkiPRrZl4xtJQXtDfUH8ZOnQU0T4IivOuvlP4pytlTYzE1WjSPZY6UJCw5\nMfGnZ+l5vdYv4XiR2dS+L3IYfQeX+pAh61LHXayxMdfNdXRfV+/pnp93qhW5ZjMn\nK076hicbfg4XCXk3Lw7PoJPNWWgcKCwddHMHFSpIhBgp5LtNiooT5hfHypbTSHaQ\napVlScuzXlMAkeH9srhEO0BDT1Rq0dScMuttF1eY/h+T1N9Vha1dVu1WgynfboaC\n8BUBLM0KoxcguRuGD2/ruFaOCWCMXAv54DcCAwEAAaOBxDCBwTAdBgNVHQ4EFgQU\nas56pDo5FS+9I7xnVXOVp5De8H0wgZEGA1UdIwSBiTCBhoAUas56pDo5FS+9I7xn\nVXOVp5De8H2hY6RhMF8xCzAJBgNVBAYTAkFVMRMwEQYDVQQIEwpTb21lLVN0YXRl\nMSEwHwYDVQQKExhJbnRlcm5ldCBXaWRnaXRzIFB0eSBMdGQxGDAWBgNVBAMTD2xv\na2kuaXRzLnVtdS5zZYIJANwxpCjfD5fLMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcN\nAQEFBQADggEBAAERtzf3jrf0VnwbGr0iOoJUFcuanAObMG6PM20Y/PBdPi0XBnlH\nReXHkGnMiY44cdyQByJH/HRTIGPmNEwUPtzvsLcwpxWz6sAogQlXhgI6ZHVaTt3T\nXBJGBi+cuG4ggRZSvcmJLwJ1EpwWXNVekiIEQbW+mlwARLbM5N7btQRA3DWofbIx\nJLn4HckD/n5dq5ueniyDqDgc2o1V2/G/zpEg90lIN7gsSOOqsbttMZFvGq3m+t3E\nKxjpGx+7PhkGMf9zCVrXXztaqDyZjeNa/rpADj+kU6KudZ9eESvdppCBR0EiROm0\n8xZOMdYU6Sc6SJVa/W48bqJsv95pCZM6joU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RKH ADFS Test"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://example.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RKH ADFS Test (IdP)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.silverchair.com/amav2/development/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ShibbolethAdmin@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wang"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:zhaow@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Zhao"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.silverchair.com/amav2/development/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-14T08:28:08Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Silverchair Development:  JAMA Network v2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://jamanetwork.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Silverchair Science + Communications, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://new.amadev.silverchair.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://new.amadev.silverchair.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://new.amadev.silverchair.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://new.amadev.silverchair.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://new.amadev.silverchair.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://new.amadev.silverchair.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTzCCAjegAwIBAgIJANiTZEkGOfWhMA0GCSqGSIb3DQEBBQUAMCUxIzAhBgNV\n\t\t\t\t\t\tBAMTGm5ldy5hbWFkZXYuc2lsdmVyY2hhaXIuY29tMB4XDTE2MDQwNTE3MzEwOVoX\n\t\t\t\t\t\tDTE5MDQwNTE3MzEwOVowJTEjMCEGA1UEAxMabmV3LmFtYWRldi5zaWx2ZXJjaGFp\n\t\t\t\t\t\tci5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDjBjrjRuoGNFY2\n\t\t\t\t\t\tBDehqRvg8NO5t9CCfQpfut/OcfY0MXsG9MnABOwE6gPQ+p4d6F3XYTrZ3p8Nn+Ei\n\t\t\t\t\t\t5Twr14JbjvY0n4xbFkl8BRmpyf+mMAoQLRmehV8atXgKlwy1g2sTZXMCOrQchNi9\n\t\t\t\t\t\tyHjDAu/mGtSVVYsUMvK/PBl5LYCbea21LMi9s5e4+LuZZ3UZgW4+y6AexJ+YQDS4\n\t\t\t\t\t\tanGBqbICjUjQYGBlRCrB+MC9dlXUBrfmehV6I5DmsuzFtS80et7xWJx5i/78zdk8\n\t\t\t\t\t\tz+IeaKmQ23p5NFfQQwBmwB4F9n/st56ccwOtnMjZnpW9NqAhxPLxfvpOki4cAII0\n\t\t\t\t\t\tvDpjprwPAgMBAAGjgYEwfzBeBgNVHREEVzBVghpuZXcuYW1hZGV2LnNpbHZlcmNo\n\t\t\t\t\t\tYWlyLmNvbYY3aHR0cHM6Ly9zcC5zaWx2ZXJjaGFpci5jb20vYW1hdjIvZGV2ZWxv\n\t\t\t\t\t\tcG1lbnQvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUn8dSQhKM96+Si1hgf3PqAOLbTFww\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAMmISEfomZlQwi3uYvc6c4MFl4tC65XpOols+NYu\n\t\t\t\t\t\teO8yknultKVM5GvEnRXYsJtW4exvzX9bLnOyB5QClLwQaFMbvltr3U6KUNmaW867\n\t\t\t\t\t\tGhPIyRHMqrbRBqpsjFAnDdJhQffX5fTn4ZmTFQF9bKZo6rYaZg4+M1Fe2a3IxJFN\n\t\t\t\t\t\tdBzqPA9nOQZPR7bWTylUo9F9bPzfRwbzdspzk08dqMoLZ0EvS7Q7OtrwLlIGs+iB\n\t\t\t\t\t\tZm/lXvGC3bdn8vu/UolHHhtOjFMBJwEaV2am7lEsovQyRZvq/Wnx2AcFAiXCJjhX\n\t\t\t\t\t\tgXdX0Csq+GNp7MHduR2cVhqhaXhJx4pIUM1gXBVJAZWAPw8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://new.amadev.silverchair.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://new.amadev.silverchair.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://new.amadev.silverchair.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://new.amadev.silverchair.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://new.amadev.silverchair.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://new.amadev.silverchair.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.sissa.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ritossa"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@sissa.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Massimiliano"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@sissa.it"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.sissa.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2013-07-03T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUBDNUKHsGJPdh6XQWcjVI7QsO2fUwDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMaWRwLnNpc3NhLml0MB4XDTEwMTExMTEyMTAyNVoXDTMw\nMTExMTEyMTAyNVowFzEVMBMGA1UEAxMMaWRwLnNpc3NhLml0MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAijIA8AmcGKkBom6g4javpNcollJH9oq+13Fd\nwvNPUJTXPNDRrmNO9jhgY7Jcx2+I8jkOryP7ifpKtlmEt3k3W0o08Om/jKbdayKx\nI8phZMe2/fKiUVtUJz1zQ9cE02Cmd0vTb8421Y7JnmKcf7uwNLQnU4elT079Clak\n3gwk2VJJja+yzrB9DMLhHs+rRZp4cqgJaH1LqcLtrp435xcFEr+NL15Ei2dFWtym\npGgf/wLASEgqws2RSdvEu2Kz+m2vDIox6N9mZN/FW2chyjSJ/scv9pkYXeZAyaOB\nPtmGF50A7HOZDFUnQQ62EEQ74QmE/mhgSyPSGUjs/i+utY96PQIDAQABo18wXTA8\nBgNVHREENTAzggxpZHAuc2lzc2EuaXSGI2h0dHBzOi8vaWRwLnNpc3NhLml0L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBRVL7DD1CdWBVf38sDt3Plq+UeOzzANBgkq\nhkiG9w0BAQUFAAOCAQEADshw70QDPxPI3c9iJReHPp9xpkTrCV4i+oqK2ChSp3UT\nP2guauh6zdXbOMCBD1Zs+rMP5/LinkJpT7P9dM0jQgmD8uXbi6livyB4Brf49P0r\njtKgeiplWeXSXzKnAwELHEDa5ixsvMT/WfBWVCNfrnTE/fR0YjGw35SqYgYiUfpE\nj/oS9mPKY09i92fgmfmVjtGvhY5ZD+nWpzdO+quvwKsYUyU9gfrB2EwW5eh+G1oF\nNWYprJEp7gYuge/L84Gq90zXkCvRlN+pYFDOHwQqPkaQZ8B1anEoH/5/wpI5CGlI\nDqa9SIiHIzb6oiTRzBRED+zbqd+EzvCwEdoMBnarPQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sissa.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sissa.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sissa.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.sissa.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sissa.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.sissa.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sissa.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sissa.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sissa.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sissa.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.itcs.sissa.it/services/idem"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SISSA"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SISSA"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Scuola Internazionale Superiore di Studi Avanzati"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Scuola Internazionale Superiore di Studi Avanzati"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.sissa.it/img/logo16x16.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.sissa.it/img/logo16x16.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.sissa.it/img/logo80x60.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idp.sissa.it/img/logo80x60.png",
                    "lang": "it",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.itcs.sissa.it/services/idem"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUBDNUKHsGJPdh6XQWcjVI7QsO2fUwDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMaWRwLnNpc3NhLml0MB4XDTEwMTExMTEyMTAyNVoXDTMw\nMTExMTEyMTAyNVowFzEVMBMGA1UEAxMMaWRwLnNpc3NhLml0MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAijIA8AmcGKkBom6g4javpNcollJH9oq+13Fd\nwvNPUJTXPNDRrmNO9jhgY7Jcx2+I8jkOryP7ifpKtlmEt3k3W0o08Om/jKbdayKx\nI8phZMe2/fKiUVtUJz1zQ9cE02Cmd0vTb8421Y7JnmKcf7uwNLQnU4elT079Clak\n3gwk2VJJja+yzrB9DMLhHs+rRZp4cqgJaH1LqcLtrp435xcFEr+NL15Ei2dFWtym\npGgf/wLASEgqws2RSdvEu2Kz+m2vDIox6N9mZN/FW2chyjSJ/scv9pkYXeZAyaOB\nPtmGF50A7HOZDFUnQQ62EEQ74QmE/mhgSyPSGUjs/i+utY96PQIDAQABo18wXTA8\nBgNVHREENTAzggxpZHAuc2lzc2EuaXSGI2h0dHBzOi8vaWRwLnNpc3NhLml0L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBRVL7DD1CdWBVf38sDt3Plq+UeOzzANBgkq\nhkiG9w0BAQUFAAOCAQEADshw70QDPxPI3c9iJReHPp9xpkTrCV4i+oqK2ChSp3UT\nP2guauh6zdXbOMCBD1Zs+rMP5/LinkJpT7P9dM0jQgmD8uXbi6livyB4Brf49P0r\njtKgeiplWeXSXzKnAwELHEDa5ixsvMT/WfBWVCNfrnTE/fR0YjGw35SqYgYiUfpE\nj/oS9mPKY09i92fgmfmVjtGvhY5ZD+nWpzdO+quvwKsYUyU9gfrB2EwW5eh+G1oF\nNWYprJEp7gYuge/L84Gq90zXkCvRlN+pYFDOHwQqPkaQZ8B1anEoH/5/wpI5CGlI\nDqa9SIiHIzb6oiTRzBRED+zbqd+EzvCwEdoMBnarPQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SISSA"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SISSA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sissa.it/"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sissa.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Scuola Internazionale Superiore di Studi Avanzati"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Scuola Internazionale Superiore di Studi Avanzati"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://gracedb.ligo.org/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "warren.anderson@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Warren Anderson"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "branson.stephens@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Branson Stephens"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rt-auth@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LIGO Identity Management Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lsc-seccomm@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LIGO Security Committee"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://gracedb.ligo.org/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "LIGO Scientific Collaboration"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ligo.caltech.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LIGO Scientific Collaboration"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://gracedb.ligo.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://gracedb.ligo.org/SPInfo"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "GraceDB organizes candidate events from gravitational-wave searches and provides an environment to record information about follow-ups."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://gracedb.ligo.org/SPPrivacy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Gravitational-wave Candidate Event Database"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIJAPkWkyNL3l8nMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGdyYWNlZGIubGlnby5vcmcwHhcNMTQxMDIwMTUyODQ2WhcNMjQxMDE3MTUy\nODQ2WjAbMRkwFwYDVQQDExBncmFjZWRiLmxpZ28ub3JnMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA/o9eGY4UWkqL2GhIryXEpNAqqXTEJnEVv7zaV62o\nDDiDbYEZdYkd9r9wuKtDO7t1OqHE98BrvcOZI+2Yu4REUm6I0MSsdtQTDr5SUfAe\naS6C1XS1hg1b+IMeRBOVunmdGYGPqOjBkQ32MhPFPyJ57DFTfEYiSAI16kMJH2xe\ncw/sbnJt0+0x6zL9O4sGUM3BKHeFh2n6Z7lV8rrDR/5pJAAD7Ida4bSNCe7ovuWJ\nXIgWdxskeqOuZT45biPEjT+UGTfZG7jEzMc2IXBBg55sIFSihv6utwGpD43jX3ex\nHl9opHgB1djMdK3rOsBQbI2um+ssrMqtL3RArd7u3YF6SwIDAQABo2YwZDBDBgNV\nHREEPDA6ghBncmFjZWRiLmxpZ28ub3JnhiZodHRwczovL2dyYWNlZGIubGlnby5v\ncmcvc2hpYmJvbGV0aC1zcDAdBgNVHQ4EFgQU/oULXvyKrAjzat8Uex0YHjAZCWow\nDQYJKoZIhvcNAQEFBQADggEBAPgDTXaELegbLw3Zf7/BE/NCjjGNrX6Cj6wqkp98\n1KT886B7bDlCdmiPDLXgok3oI67+Flk1PFw9r8KFYkZOgB2EPKYLsUTUg+yH8NSe\nb6H/iq+ziJOQmnSZWvx/d88xTkOF4aEP1f0hQOXt3ElmZldgQfCCteVLLbhSF5D0\nRmuXgPAZEv19nTEdQKEFyx9iFmdOFc7/IKQdPQWVriSBzJRdc7dl1+RnUzZ2hsY3\n1BLiz9m09Au4/VVc1Sc4h8k5rs2+SWmAOk1Zob2yKKzdLwxuiCExg6XHgWSR/xgs\n2K9d1rqY3G7AQFM+zmhbRzIA18x4oVi4gTckD5Uxq1e0pdw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gracedb.ligo.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://gracedb.ligo.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://gracedb.ligo.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://gracedb.ligo.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gracedb.ligo.org/lvem_view/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://gracedb.ligo.org/lvem_view/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://gracedb.ligo.org/lvem_view/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://gracedb.ligo.org/lvem_view/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Gravitational-wave Candidate Event Database"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "GraceDB organizes candidate events from gravitational-wave searches and provides an environment to record information about follow-ups."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://testoala.surrey.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gill"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:c.j.gill@surrey.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Claire"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Minhas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:a.minhas@surrey.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Abdul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://testoala.surrey.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_instant": "2012-05-09T16:18:51Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://testoala.surrey.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://testoala.surrey.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "surrey.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIIRNFxRp/Jwa8wDQYJKoZIhvcNAQEFBQAwPzEdMBsGA1UE\n\t\t\t\t\t\tCgwUVW5pdmVyc2l0eSBvZiBTdXJyZXkxHjAcBgNVBAMMFXRlc3RvYWxhLnN1cnJl\n\t\t\t\t\t\teS5hYy51azAeFw0xMjAzMjkxNTM1MThaFw0yMjAzMjkxNTM1MThaMD8xHTAbBgNV\n\t\t\t\t\t\tBAoMFFVuaXZlcnNpdHkgb2YgU3VycmV5MR4wHAYDVQQDDBV0ZXN0b2FsYS5zdXJy\n\t\t\t\t\t\tZXkuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC1j2zQKc7z\n\t\t\t\t\t\tR2V/VMIag9WMfd66ABeoUemxyKIxtUi925IAuspYjlM54eFDzTxl9bkS/nEHF461\n\t\t\t\t\t\tM/qusiKKasjxctKjllFKt81kiUvki20ghFA3GoxfHf9Ggdn0/9kCxJqaQC04E2+F\n\t\t\t\t\t\tAmBKp2ndkfsg77eSfpfKoBlLzYCwm2Z/yWQtV1Emxlg/BiVHaiGXls/uB8jRYRR5\n\t\t\t\t\t\trTypT7QBgktFSTV2jJ4HZjbibC106DMseDwKuE+4sPjCtDIY0xB+CEWvIWFZ7m7i\n\t\t\t\t\t\t4sQAEE/iNymvSgfD8FVM6qN3QZJktLND+ytw7xT2ApCyhufjVYXzChEdv8JAxtFc\n\t\t\t\t\t\tyjupxFetN221AgMBAAGjUDBOMB0GA1UdDgQWBBS7I/yqh/AoV6xFYMqRCoLShzpp\n\t\t\t\t\t\t/jAfBgNVHSMEGDAWgBS7I/yqh/AoV6xFYMqRCoLShzpp/jAMBgNVHRMEBTADAQH/\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQBS+xHB77QPjESIz1lySOo6JzrQU14Tpt7/KXEN\n\t\t\t\t\t\tm1QNxZEnuRh6ApWKHjAWGW0XvnkIh8QDzB9ypnBEskTe9mF7cimv3D1YCf12FyDZ\n\t\t\t\t\t\tgn3NQNE21cOiZa9Ul2jaJLNoLVlj4pH75KMYUDSjNJaqa20qz2G0iCu5FPPz6kfz\n\t\t\t\t\t\tN52TVaCkDD3rJ4lo4w5Q1BHy8GhzHGcw0nqVpEfkkEH0YJIFqhhwcUkWo1auD1k2\n\t\t\t\t\t\tcQZH5tf4evWS55wxZai4h9IipxrFvVzizvIhYiiZl1LVAKu/L2JrabFjH0wkWYMK\n\t\t\t\t\t\ts4lnRLncL6eQ8Adihl6jJY+qwdJLBoms/5AD7cJ1qPw0qkLS"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIIRNFxRp/Jwa8wDQYJKoZIhvcNAQEFBQAwPzEdMBsGA1UE\n\t\t\t\t\t\tCgwUVW5pdmVyc2l0eSBvZiBTdXJyZXkxHjAcBgNVBAMMFXRlc3RvYWxhLnN1cnJl\n\t\t\t\t\t\teS5hYy51azAeFw0xMjAzMjkxNTM1MThaFw0yMjAzMjkxNTM1MThaMD8xHTAbBgNV\n\t\t\t\t\t\tBAoMFFVuaXZlcnNpdHkgb2YgU3VycmV5MR4wHAYDVQQDDBV0ZXN0b2FsYS5zdXJy\n\t\t\t\t\t\tZXkuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC1j2zQKc7z\n\t\t\t\t\t\tR2V/VMIag9WMfd66ABeoUemxyKIxtUi925IAuspYjlM54eFDzTxl9bkS/nEHF461\n\t\t\t\t\t\tM/qusiKKasjxctKjllFKt81kiUvki20ghFA3GoxfHf9Ggdn0/9kCxJqaQC04E2+F\n\t\t\t\t\t\tAmBKp2ndkfsg77eSfpfKoBlLzYCwm2Z/yWQtV1Emxlg/BiVHaiGXls/uB8jRYRR5\n\t\t\t\t\t\trTypT7QBgktFSTV2jJ4HZjbibC106DMseDwKuE+4sPjCtDIY0xB+CEWvIWFZ7m7i\n\t\t\t\t\t\t4sQAEE/iNymvSgfD8FVM6qN3QZJktLND+ytw7xT2ApCyhufjVYXzChEdv8JAxtFc\n\t\t\t\t\t\tyjupxFetN221AgMBAAGjUDBOMB0GA1UdDgQWBBS7I/yqh/AoV6xFYMqRCoLShzpp\n\t\t\t\t\t\t/jAfBgNVHSMEGDAWgBS7I/yqh/AoV6xFYMqRCoLShzpp/jAMBgNVHRMEBTADAQH/\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQBS+xHB77QPjESIz1lySOo6JzrQU14Tpt7/KXEN\n\t\t\t\t\t\tm1QNxZEnuRh6ApWKHjAWGW0XvnkIh8QDzB9ypnBEskTe9mF7cimv3D1YCf12FyDZ\n\t\t\t\t\t\tgn3NQNE21cOiZa9Ul2jaJLNoLVlj4pH75KMYUDSjNJaqa20qz2G0iCu5FPPz6kfz\n\t\t\t\t\t\tN52TVaCkDD3rJ4lo4w5Q1BHy8GhzHGcw0nqVpEfkkEH0YJIFqhhwcUkWo1auD1k2\n\t\t\t\t\t\tcQZH5tf4evWS55wxZai4h9IipxrFvVzizvIhYiiZl1LVAKu/L2JrabFjH0wkWYMK\n\t\t\t\t\t\ts4lnRLncL6eQ8Adihl6jJY+qwdJLBoms/5AD7cJ1qPw0qkLS"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Surrey (OALA TEST)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.surrey.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Surrey"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.unioncloudstaging.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@zendesk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Menon"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shoba.menon@arrkgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shoba"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kancherla"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sudheer.kancherla@arrkgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sudheer"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.unioncloudstaging.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-07-05T14:40:53Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NUS Digital Unioncloud Test Service Provider"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unioncloud.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NUS Services Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.unioncloudstaging.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.unioncloudstaging.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.unioncloudstaging.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.unioncloudstaging.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.unioncloudstaging.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.unioncloudstaging.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVzCCAj+gAwIBAgIJANZRUr3l66IUMA0GCSqGSIb3DQEBBQUAMDsxOTA3BgNV\n\t\t\t\t\t\tBAMTMGVjMi00Ni0xMzctMy0xNjIuZXUtd2VzdC0xLmNvbXB1dGUuYW1hem9uYXdz\n\t\t\t\t\t\tLmNvbTAeFw0xMjA1MTQwOTExNThaFw0yMjA1MTIwOTExNThaMDsxOTA3BgNVBAMT\n\t\t\t\t\t\tMGVjMi00Ni0xMzctMy0xNjIuZXUtd2VzdC0xLmNvbXB1dGUuYW1hem9uYXdzLmNv\n\t\t\t\t\t\tbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMOKLRNP923gpEphaq9H\n\t\t\t\t\t\tlqaeg3wIr6k6CQEZTnVeXHaqBS1T/IeLChh0MGikmqzAGz4gL3Jp7xg+LjAb7fHW\n\t\t\t\t\t\ts84wG6ZkDFxy2plDsNoVPatzgKQYtiXsGqtlXdW8UzTpIpsvVAlJ+QGqhIibAZWK\n\t\t\t\t\t\taIsU6V38NGafvB4UWFlIpbECHgFz41x1cmK7gYFD7wzsA6hojAOWaY8UmQgW+nJn\n\t\t\t\t\t\t4WxKl+gDe8qUiwdMzrEUK1yOFjsDuqdHnejSrtyc8b7iccE7hzo1Y/kw40FVG7gW\n\t\t\t\t\t\toiKrzF49G14BiHwkt448mCiXGDMnFM0TYfs1nkS/FdTpyhHgICu1qHX8pqJnnNbn\n\t\t\t\t\t\tuNMCAwEAAaNeMFwwOwYDVR0RBDQwMoIwZWMyLTQ2LTEzNy0zLTE2Mi5ldS13ZXN0\n\t\t\t\t\t\tLTEuY29tcHV0ZS5hbWF6b25hd3MuY29tMB0GA1UdDgQWBBRAI6NKxAK3XKLGUqTb\n\t\t\t\t\t\tgJhCWI0FuzANBgkqhkiG9w0BAQUFAAOCAQEAf+1jf17uxp5uGeGJUFI/t2bhxnfD\n\t\t\t\t\t\tTbmnNBzQST5/+VK+qNAc6tCw+0gngBGREBkdVmcebIw8AmfhciDqe3xEl3Pp2oWT\n\t\t\t\t\t\tHSnbl7bZnoG90FlxEbHm8THMNFjTDTmrlX37ldH5mfiP0EOFpMaCmlkNr9D617tF\n\t\t\t\t\t\tgZ2xUEelwk+5dg5RpIHsgOnVr6zcUMdYHZPs64O/kySxnuN+PaOIOt9JERw1jHT6\n\t\t\t\t\t\tLbD66CIPaC/TtydoiCUfS7s9Hr3hSJUnJ0gi+fzXh/5/z/+NjMZXd4G4FPVMonXy\n\t\t\t\t\t\tXrRfr87YvwJm38sU/z+Gnka487212biN6XS36YGLSohRByTKTNZM+H1x8A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://umsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://umsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://umsu.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://umsu.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://umsu.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://umsu.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://kusu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://kusu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://kusu.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://kusu.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://kusu.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://kusu.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "18"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sunderlandsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "19"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sunderlandsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "20"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sunderlandsu.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "21"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sunderlandsu.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "22"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sunderlandsu.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "23"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sunderlandsu.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "24"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://kclsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "25"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://kclsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "26"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://kclsu.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "27"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://kclsu.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "28"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://kclsu.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "29"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://kclsu.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "30"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ntsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "31"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ntsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "32"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ntsu.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "33"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ntsu.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "34"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ntsu.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "35"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ntsu.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "36"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://suarts.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "37"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://suarts.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "38"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://suarts.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "39"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://suarts.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "40"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://suarts.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "41"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://suarts.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "42"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "43"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://bsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "44"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bsu.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "45"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://bsu.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "46"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://bsu.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "47"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://bsu.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "48"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://esu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "49"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://esu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "50"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://esu.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "51"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://esu.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "52"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://esu.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "53"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://esu.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "54"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://abert.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "55"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://abert.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "56"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://abert.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "57"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://abert.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "58"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://abert.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "59"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://abert.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "60"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lgos.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "61"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://lgos.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "62"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lgos.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "63"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://lgos.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "64"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://lgos.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "65"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://lgos.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "66"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ljmu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "67"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ljmu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "68"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ljmu.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "69"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ljmu.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "70"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ljmu.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "71"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ljmu.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "72"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hudsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "73"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://hudsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "74"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hudsu.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "75"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://hudsu.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "76"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://hudsu.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "77"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://hudsu.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "78"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bedssu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "79"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://bedssu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "80"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bedssu.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "81"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://bedssu.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "82"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://bedssu.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "83"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://bedssu.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "84"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://durhamsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "85"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://durhamsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "86"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://durhamsu.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "87"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://durhamsu.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "88"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://durhamsu.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "89"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://durhamsu.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "90"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mdxsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "91"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://mdxsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "92"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mdxsu.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "93"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://mdxsu.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "94"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://mdxsu.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "95"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://mdxsu.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "96"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uclan.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "97"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://uclan.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "98"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uclan.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "99"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://uclan.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "100"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://uclan.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "101"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://uclan.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "102"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ucsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "103"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ucsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "104"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ucsu.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "105"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ucsu.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "106"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ucsu.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "107"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ucsu.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "108"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ssu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "109"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ssu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "110"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ssu.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "111"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ssu.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "112"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ssu.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "113"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ssu.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "114"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://loughsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "115"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://loughsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "116"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://loughsu.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "117"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://loughsu.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "118"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://loughsu.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "119"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://loughsu.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "120"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uea.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "127"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://uea.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "128"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uea.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "129"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://uea.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "130"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://uea.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "131"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://uea.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "132"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uwlsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "133"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://uwlsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "134"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uwlsu.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "135"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://uwlsu.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "136"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://uwlsu.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "137"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://uwlsu.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "138"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gcusa.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "151"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://gcusa.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "152"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://gcusa.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "153"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://gcusa.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "154"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://gcusa.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "155"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://gcusa.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "156"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "157"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://lsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "158"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lsu.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "159"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://lsu.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "160"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://lsu.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "161"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://lsu.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "162"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://suffolk.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "163"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://suffolk.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "164"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://suffolk.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "165"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://suffolk.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "166"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://suffolk.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "167"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://suffolk.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "168"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://salford.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "169"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://salford.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "170"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://salford.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "171"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://salford.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "172"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://salford.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "173"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://salford.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "174"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uswsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "175"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://uswsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "176"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uswsu.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "177"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://uswsu.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "178"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://uswsu.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "179"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://uswsu.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "180"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://stmary.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "181"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://stmary.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "182"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://stmary.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "183"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://stmary.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "184"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://stmary.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "185"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://stmary.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "186"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://leedsbeckettsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "187"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://leedsbeckettsu.unioncloudstaging.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "188"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://leedsbeckettsu.unioncloudstaging.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "189"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://leedsbeckettsu.unioncloudstaging.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "190"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://leedsbeckettsu.unioncloudstaging.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "191"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://leedsbeckettsu.unioncloudstaging.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "192"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://repos.ids-mannheim.de/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Witt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:witt@ids-mannheim.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andreas"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Schonefeld"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:schonefeld@ids-mannheim.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Oliver"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@ids-mannheim.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAI"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://repos.ids-mannheim.de/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2013-02-08T13:14:47Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://clarin.eu/category/clarin-member"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institut f\u00fcr Deutsche Sprache (IDS)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institut f\u00fcr Deutsche Sprache (IDS)"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ids-mannheim.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ids-mannheim.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e217"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e217"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://repos.ids-mannheim.de/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://repos.ids-mannheim.de/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://repos.ids-mannheim.de/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://repos.ids-mannheim.de/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://repos.ids-mannheim.de/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://repos.ids-mannheim.de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://repos.ids-mannheim.de"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Forschungsprim\u00e4rdatenrepository"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Research Data Respository"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Das Forschungsprim\u00e4rdatenrepository des Institut f\u00fcr Deutsche Sprache (IDS)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Repository of language resources provided by the Institute for the German Language (IDS)."
                  }
                ],
                "logo": [
                  {
                    "text": "https://repos.ids-mannheim.de/logos/ids-logo-small.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://repos.ids-mannheim.de/logos/ids-logo-large.png",
                    "height": "63",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "318"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://repos.ids-mannheim.de/privacy.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "repos.ids-mannheim.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGJzCCBQ+gAwIBAgIHGHGxH2MWmjANBgkqhkiG9w0BAQsFADCBoDELMAkGA1UE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\nPZjG46BQGsou6pJHmLhC/+tMXlY0jVRn6uQ4yFjtazWE24EYG+Q7dJ5yMw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=aai@ids-mannheim.de,CN=repos.ids-mannheim.de,O=Institut fuer Deutsche Sprache,L=Mannheim,ST=Baden-Wuerttemberg,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://repos.ids-mannheim.de/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://repos.ids-mannheim.de/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://repos.ids-mannheim.de/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://repos.ids-mannheim.de/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://repos.ids-mannheim.de/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://repos.ids-mannheim.de/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Forschungsprim\u00e4rdatenrepository"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Research Data Respository"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Das Forschungsprim\u00e4rdatenrepository des Institut f\u00fcr Deutsche Sprache (IDS)"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Repository of language resources provided by the Institute for the German Language (IDS)."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://dev.nais.uhr.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://dev.nais.uhr.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.nais.uhr.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev.nais.uhr.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.nais.uhr.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.nais.uhr.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.nais.uhr.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.nais.uhr.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dev.nais.uhr.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "NAIS st\u00e5r f\u00f6r Nationellt Administrations- och Informationssystem f\u00f6r samordnare av s\u00e4rskilt pedagogiskt st\u00f6d"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "NAIS stands for National Administration- and Information system for coordination of pedagogical aid"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NaisSP"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NaisSP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "uhr-1297.i.uhr.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+jCCAeKgAwIBAgIJAK9uhgtga6STMA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\nBAMTEXVoci0xMjk3LmkudWhyLnNlMB4XDTE0MTIwMjEyNDgyM1oXDTI0MTEyOTEy\nNDgyM1owHDEaMBgGA1UEAxMRdWhyLTEyOTcuaS51aHIuc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDSxkWORCuz0qV48LpqRMlD6H4eEe8tbGAvr0N2\nKBmz+l9FBeCBr3Q8NgTeBBnMa23i3VbEdB1016jdJ0h9jXMHN1AQMd/3tR2EoWWM\n+VjFmffjIfF0LBYyHJakmnEKmdIwjKPiVqOgwlS+a9af/wiI8XnD8sIaqFopaoA1\nhKKuANSR/TVOkDhKfdaBQcDUCyww2/sGBthhDdlC0rpgRr6nA/vbrjsYRC7PE6js\n2wFzTcMkF9gjeduKZDwpRqQdkSkIL2K1/ZBptaPOOaal6fpve6AcxmjSWZHmR3Tb\nx6ylG3e+B8O8ArwyNyam4TSMhFO57GqVuAtD8Q4uRdq3XSUzAgMBAAGjPzA9MBwG\nA1UdEQQVMBOCEXVoci0xMjk3LmkudWhyLnNlMB0GA1UdDgQWBBR9FQbRYBUqAd81\nDwOhDd+M8XDmyjANBgkqhkiG9w0BAQUFAAOCAQEAd68cfIyNUjLMpTTQuKQBJs9W\nim084wgTvsAdycV9EbYuuLrQhALQuTuGhBf8qZY16gx23ICpn12nwcXdu02Xcg5U\nxK8cv3PFIgOcXB00dfmOkwwzgtZkYuRZz4bzf4TgrQv9vMhrVJEwHPog4HuU6N8l\nJPCgGoM1ape2Nyf198u6F4qXp5MZsS+vBOXxAyvHzWOr5uMzxg0oAJQwpkVp/b2z\n3N5QAVVFxkbyHn+8RkZQZ9FiWh7Yl56wU3gvGnZrPT2AaJtVaW4cQkw0gL+dAYfm\n3osR1KprOY0+GpXcvgi9X9YlLMzfcsBIiCEoV4wjwziY99phU80XLkFKmYLsmA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=uhr-1297.i.uhr.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.nais.uhr.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev.nais.uhr.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.nais.uhr.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.nais.uhr.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.nais.uhr.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.nais.uhr.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dev.nais.uhr.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dev.nais.uhr.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dev.nais.uhr.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.educause.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "achaux@educause.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex Chaux"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ITHelpdesk@educause.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EDUCAUSE IT Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ITinfo@educause.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EDUCAUSE IT Administrative Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ITHelpdesk@educause.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EDUCAUSE IT Support"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://idp.educause.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.educause.edu/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.educause.edu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.educause.edu/idp/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.educause.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.educause.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.educause.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.educause.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.educause.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "educause.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.educause.edu/about/incommon"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EDUCAUSE"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "EDUCAUSE IdP server"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.educause.edu/idp/images/educause_logo.png",
                    "lang": "en",
                    "height": "57",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "225"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.educause.edu/privacy-policy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAJNPiKyEc5HKN8RKL24zsWZeSSk0MA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMMEGlkcC5lZHVjYXVzZS5lZHUwHhcNMTUxMTA1MDAzMzUz\nWhcNMzUxMTA1MDAzMzUzWjAbMRkwFwYDVQQDDBBpZHAuZWR1Y2F1c2UuZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApAl9m3C4SRNIdDAqPs3SmgnL\nPjRsg0HJC++axyofMIgOB7rZKBrearu5jjY5NcVkSh5rb0ik75hqhgqPg7LtImFd\nbKeU5Tppd1FXeFoc9yBF5pBbHaZWl1VLERBIyX1wTKKnBAHuzCpnwh7/kbq42bMD\ne77AVxEzuMFXOVy8ng35eDgeqqFwxXBdoGQlM31S7PzTAP7OtkY85WOgRqVoRlDG\nz/yGvqi5m3lb4225UhyaHmP9l6NeJvwwftnHO0FeZQIaDmQxaRBk4Oy+EmHQXOQp\nSsxf0TAVQkxZspQcEPljfJA99dBrxZfPTpHJYcecYVIsWwYMEVAaciNKjcyKJQID\nAQABo2cwZTAdBgNVHQ4EFgQUbeBXV+O0oh0vgJOoHZ9sN6l0vcUwRAYDVR0RBD0w\nO4IQaWRwLmVkdWNhdXNlLmVkdYYnaHR0cHM6Ly9pZHAuZWR1Y2F1c2UuZWR1L2lk\ncC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBBQUAA4IBAQAZ5Zjf8+NGtL/ourPI/kNM\nSqlN3jCnZUi59EB7V8G2HEP3OaF61LIxmkBQFIBbNRDIpk20+ji+r3KmO0hhB0zX\nL4YeTSvi+ASTcR4kHPVaEJb7sB5Sl7OpSZ/7wHCEZELn2riGoYfTcuz17ztjOQKq\nK1yH/FHWh0PWngLrDAjxi4tMy3B+DNoyIZeMAA5ZYJ8bzcYs9FJW+1Tcz483U2Ub\n1QwAk4MHPT7KZ8+9A9cH7rLsHjnslO31Mv9mQC9IBVg77h0v92CbzVV7I497kkFZ\neyM2CkBFPjiindy5cUI/vzdn+zrf7DSh4VH2s5sBBaGT6oMkNpSpU7wa7NN5AuPI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EDUCAUSE"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.educause.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "EDUCAUSE"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://stage.mahara.qmul.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:its-helpdesk@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Services helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:moodle-support@ulcc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Moodle Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://stage.mahara.qmul.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-07-13T09:07:23Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Queen Mary and Westfield College, University of London: Staging Mahara"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qmul.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Queen Mary and Westfield College, University of London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://stage.mahara.qmul.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://stage.mahara.qmul.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://stage.mahara.qmul.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://stage.mahara.qmul.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://stage.mahara.qmul.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://stage.mahara.qmul.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAMZqbUlmc/4pMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\n\t\t\t\t\t\tBAMTF3N0YWdlLm1haGFyYS5xbXVsLmFjLnVrMB4XDTEyMDYwNzE0NTU0N1oXDTIy\n\t\t\t\t\t\tMDYwNTE0NTU0N1owIjEgMB4GA1UEAxMXc3RhZ2UubWFoYXJhLnFtdWwuYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDDZvKm8ggjSAsLt7kGFZ2t\n\t\t\t\t\t\tbGdbkDjwkTYPeCFNFRIy+Fi904W2Ff89/ryb56iyA8N9USlj1VUv3QMlvKQNrhbw\n\t\t\t\t\t\txad6u6/9F2PjL78zkoYc+uJ8U8z23CaMWFBi53nLQfXmVqby7grEd/ZPmBbXFmen\n\t\t\t\t\t\tuZfPVB4pb2s7JG1yRKwxdAvq/Du8srEQMOnKLX0A0kFumhabL+lri/VXiWGnbYcm\n\t\t\t\t\t\tlYrv/Hmh/e/ZoYFwPXajrLwmlAcA+adOqz0exzuZ1G91qAV2/buSXbS5gq+C/Y3H\n\t\t\t\t\t\toy5JYDmrpXjW3USSpueih9CCXINGjEHlAnaqaa0TCNYGFIQOVO7il0QonGIVeCuB\n\t\t\t\t\t\tAgMBAAGjRTBDMCIGA1UdEQQbMBmCF3N0YWdlLm1haGFyYS5xbXVsLmFjLnVrMB0G\n\t\t\t\t\t\tA1UdDgQWBBTbCH9ZyI7zqpqMbWKMMIDVxkc5DjANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\touDXbFLxN9s6JB+FMZXoH8ColtAmWTnial/A+tlDqp4QjbMOXBUP/dlNx55XYYyz\n\t\t\t\t\t\teiQwTf347Ap6ZhcC1t6o46VC247AKfBlGwe73ASTJujDiK3RmqAXjg1/tkAMzWrz\n\t\t\t\t\t\t5GKNeLoTPP5TyuJ3614gZmZB6uLb8bfAVyXRmSH/IfxO616yF/LBzFtnTdERiHgX\n\t\t\t\t\t\t5YYc1q/rFFhZW5VYzmdIUsY4SuZ6qwzfhzgJAhYz7s0bkwoBz6xZk1vMGtyqUXUh\n\t\t\t\t\t\tTO8QG6ljEC4VQMB4AzASlawzv7IGaLbVJqIfypibgAuTMIio35JNpt+h92ySdMX5\n\t\t\t\t\t\tMp+1A9Jpnpwe7nn45pBkBA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://stage.mahara.qmul.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://stage.mahara.qmul.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://stage.mahara.qmul.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://stage.mahara.qmul.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://stage.mahara.qmul.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://stage.mahara.qmul.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.it.gu.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lena Str\u00f6m"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lena.strom@gu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University of Gothenburg"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46707104070"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pablo Millet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pablo.millet@gu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University of Gothenburg"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46317862020"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "GU-Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@gu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University of Gothenburg"
          }
        }
      ],
      "entity_id": "https://idp.it.gu.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oasis:names:tc:SAML:attribute:assurance-certification",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUGLU4YqWFYHboh+F+iLNYkBw8XNAwDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMaWRwLml0Lmd1LnNlMB4XDTA5MDgyNDExMzA1OFoXDTI5\nMDgyNDExMzA1OFowFzEVMBMGA1UEAxMMaWRwLml0Lmd1LnNlMIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEApOVkzaHuTCe+7lf79UnQ5iQ/8OLbJpwOxPTF\nwEPIHbMMU/aCVnxoZnwNApblqvpP2uOsQvh8d0uDv2iVC5BMN0ff9M+9rN7D/gAo\nL+w8CmWiHRudKyZLu8Gu89SGxyQ59AVCbJzGaEE9h/CmMYHCj/ONJ8mtjG9uw6u+\nVj+L8PHXsPHQsLvcl3/D7duIYH/xHRbPzXS0imux+r/OcSCR3aCPCx3uuAfVPxGS\n9Y/ifynV586V3szIM7O15SeXKenFMKjQhzA23ZPcHhDSxWnVGUDWFDRDNAXfD7BF\nKRBCaUlWZvczqsV3eGtW8XgOmuW/7yJT5REfrrSLOKprAK8yoQIDAQABo18wXTA8\nBgNVHREENTAzggxpZHAuaXQuZ3Uuc2WGI2h0dHBzOi8vaWRwLml0Lmd1LnNlL2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBSpKDUl7ZRxhQ1/HRmVbFd+NbwxmzANBgkq\nhkiG9w0BAQUFAAOCAQEAXfaYlHQj4KRaJmMbWFV0XyNUlHNio8010vLv3t6WztlZ\njZFL/hTQIFhmYEA04Davdk+1/1JvcRePSpg2VCxT/QwHyOR3eimmQ6FKXWls/zO/\nV01sJrlLdf/53pzXYsVSOf50UK+GtrSB3hhzrFmeaBALOysGqk2h2/UdYISXxa/e\nMyQ/aOI5u+0Wlq2RdIXF8MrtnwBTRhNXLcXYzz4fPsdjd4TmmJLQLXLmFLE/IA+/\nCP9nuvekzvPla7AXlXPwPvbUunwZIZkN3aHzMY/08FKIYRLb9VmqInKXw8tIBSqG\nMoX9SCDPBh2j39QZupTaPkylXDshurod7B2XtXdHPg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gu.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.it.gu.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.it.gu.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.it.gu.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.it.gu.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.it.gu.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.it.gu.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.it.gu.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.it.gu.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gu.se"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r anst\u00e4llda och studenter vid G\u00f6teborgs universitet."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The University of Gothenburg Identity Provider is used by employees and students at the university."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.gu.se/digitalAssets/1374/1374690_lo_gu_left.png",
                    "lang": "sv",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "344"
                  },
                  {
                    "text": "https://www.gu.se/digitalAssets/1374/1374690_lo_gu_left.png",
                    "lang": "en",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "376"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "G\u00f6teborgs Universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Gothenburg"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "gu.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:57.6981,11.9716"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.241.0.0/18"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:6b0:d::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUGLU4YqWFYHboh+F+iLNYkBw8XNAwDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMaWRwLml0Lmd1LnNlMB4XDTA5MDgyNDExMzA1OFoXDTI5\nMDgyNDExMzA1OFowFzEVMBMGA1UEAxMMaWRwLml0Lmd1LnNlMIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEApOVkzaHuTCe+7lf79UnQ5iQ/8OLbJpwOxPTF\nwEPIHbMMU/aCVnxoZnwNApblqvpP2uOsQvh8d0uDv2iVC5BMN0ff9M+9rN7D/gAo\nL+w8CmWiHRudKyZLu8Gu89SGxyQ59AVCbJzGaEE9h/CmMYHCj/ONJ8mtjG9uw6u+\nVj+L8PHXsPHQsLvcl3/D7duIYH/xHRbPzXS0imux+r/OcSCR3aCPCx3uuAfVPxGS\n9Y/ifynV586V3szIM7O15SeXKenFMKjQhzA23ZPcHhDSxWnVGUDWFDRDNAXfD7BF\nKRBCaUlWZvczqsV3eGtW8XgOmuW/7yJT5REfrrSLOKprAK8yoQIDAQABo18wXTA8\nBgNVHREENTAzggxpZHAuaXQuZ3Uuc2WGI2h0dHBzOi8vaWRwLml0Lmd1LnNlL2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBSpKDUl7ZRxhQ1/HRmVbFd+NbwxmzANBgkq\nhkiG9w0BAQUFAAOCAQEAXfaYlHQj4KRaJmMbWFV0XyNUlHNio8010vLv3t6WztlZ\njZFL/hTQIFhmYEA04Davdk+1/1JvcRePSpg2VCxT/QwHyOR3eimmQ6FKXWls/zO/\nV01sJrlLdf/53pzXYsVSOf50UK+GtrSB3hhzrFmeaBALOysGqk2h2/UdYISXxa/e\nMyQ/aOI5u+0Wlq2RdIXF8MrtnwBTRhNXLcXYzz4fPsdjd4TmmJLQLXLmFLE/IA+/\nCP9nuvekzvPla7AXlXPwPvbUunwZIZkN3aHzMY/08FKIYRLb9VmqInKXw8tIBSqG\nMoX9SCDPBh2j39QZupTaPkylXDshurod7B2XtXdHPg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "G\u00f6teborgs Universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Gothenburg"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gu.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GU"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.edina.ac.uk/shibboleth/cris",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:edina@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EDINA Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Soares"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ben.soares@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ben"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.edina.ac.uk/shibboleth/cris",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Edinburgh: EDINA CRIS"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://edina.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vsp2.edina.ac.uk/cris/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vsp2.edina.ac.uk/cris/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vsp2.edina.ac.uk/cris/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vsp2.edina.ac.uk/cris/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vsp2.edina.ac.uk/cris/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIESDCCAzCgAwIBAgIJAKrBnZO7TvNTMA0GCSqGSIb3DQEBBQUAMIGkMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjERMA8GA1UECBMIU2NvdGxhbmQxEjAQBgNVBAcTCUVkaW5idXJnaDEk\n\t\t\t\t\t\tMCIGA1UEChMbVGhlIFVuaXZlcnNpdHkgb2YgRWRpbmJ1cmdoMQ4wDAYDVQQLEwVF\n\t\t\t\t\t\tRElOQTEZMBcGA1UEAxMQdnNwMi5lZGluYS5hYy51azEdMBsGCSqGSIb3DQEJARYO\n\t\t\t\t\t\tZWRpbmFAZWQuYWMudWswHhcNMTAwMjAxMTY0OTI1WhcNMjAwMTMwMTY0OTI1WjCB\n\t\t\t\t\t\tpDELMAkGA1UEBhMCR0IxETAPBgNVBAgTCFNjb3RsYW5kMRIwEAYDVQQHEwlFZGlu\n\t\t\t\t\t\tYnVyZ2gxJDAiBgNVBAoTG1RoZSBVbml2ZXJzaXR5IG9mIEVkaW5idXJnaDEOMAwG\n\t\t\t\t\t\tA1UECxMFRURJTkExGTAXBgNVBAMTEHZzcDIuZWRpbmEuYWMudWsxHTAbBgkqhkiG\n\t\t\t\t\t\t9w0BCQEWDmVkaW5hQGVkLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAynwMFgT8x37YBNpxAGTtLJxF3iG1adpqRmin40XS86HdJP21dzsH7JD1\n\t\t\t\t\t\tRanxUJJOWU8wud9e//ZZTC58TZbc8Zp0JRc5hlTOmLRksYt4B0QxrCqJ4EmFKlIM\n\t\t\t\t\t\tigE5ZNgoR+lwS1ENKikIHibnVcNF9IpIkX8sTzCY18JcileM8Yz5b+R91yoha1MU\n\t\t\t\t\t\tasRefMf2j7RR6kldAJw2Xj63aFtN0NXL6Z+HiLyg4JNslJTH9c3Ha88tI+6Ce1Q6\n\t\t\t\t\t\trG7rztkpHAD5Rd+ovQMysk9ihA3RN18X0Uu8LqExH2tUqq51Fmd+KQ04hyjE4gx+\n\t\t\t\t\t\tw2T6MwPmdp6zLQSXFf6x9CeRai7MwwIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCG\n\t\t\t\t\t\tSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4E\n\t\t\t\t\t\tFgQU59hHQ8+jwnn2x3Yz4BDaEaDHUrswHwYDVR0jBBgwFoAU59hHQ8+jwnn2x3Yz\n\t\t\t\t\t\t4BDaEaDHUrswDQYJKoZIhvcNAQEFBQADggEBAB5CEE4B61l2mn/sBlc7+qN+obOW\n\t\t\t\t\t\tgZURJvs/EeIlfR7LpWRITMSn4pE5mPR4R96tL0vNXc1jl5c2sTV9dtztazWmU+Z1\n\t\t\t\t\t\tu3rniEM6jETPFqlmYhOPFzYWoQTB0LGv3Id0NR4dCFDtFNl+EPaQAug9C39gkOCN\n\t\t\t\t\t\tiLZJlzOZxUALuUvebPbZMfqSTo8SdFT1Cv2No0hQIBjvlO1OimSjAWgkFR3snW8b\n\t\t\t\t\t\txzZ/lWUqrLDZYSo5LXQad3yNfhwi4dMJ5PRuAuTH1akdwlVf4AIeIQDm3QBKJIhj\n\t\t\t\t\t\tTOGrFRiCdlp4cIQwN66UelzUH2KjlI/iQXYLbq5uUHN/EI47I/E0gpnYr5E="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIESDCCAzCgAwIBAgIJAKrBnZO7TvNTMA0GCSqGSIb3DQEBBQUAMIGkMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjERMA8GA1UECBMIU2NvdGxhbmQxEjAQBgNVBAcTCUVkaW5idXJnaDEk\n\t\t\t\t\t\tMCIGA1UEChMbVGhlIFVuaXZlcnNpdHkgb2YgRWRpbmJ1cmdoMQ4wDAYDVQQLEwVF\n\t\t\t\t\t\tRElOQTEZMBcGA1UEAxMQdnNwMi5lZGluYS5hYy51azEdMBsGCSqGSIb3DQEJARYO\n\t\t\t\t\t\tZWRpbmFAZWQuYWMudWswHhcNMTAwMjAxMTY0OTI1WhcNMjAwMTMwMTY0OTI1WjCB\n\t\t\t\t\t\tpDELMAkGA1UEBhMCR0IxETAPBgNVBAgTCFNjb3RsYW5kMRIwEAYDVQQHEwlFZGlu\n\t\t\t\t\t\tYnVyZ2gxJDAiBgNVBAoTG1RoZSBVbml2ZXJzaXR5IG9mIEVkaW5idXJnaDEOMAwG\n\t\t\t\t\t\tA1UECxMFRURJTkExGTAXBgNVBAMTEHZzcDIuZWRpbmEuYWMudWsxHTAbBgkqhkiG\n\t\t\t\t\t\t9w0BCQEWDmVkaW5hQGVkLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAynwMFgT8x37YBNpxAGTtLJxF3iG1adpqRmin40XS86HdJP21dzsH7JD1\n\t\t\t\t\t\tRanxUJJOWU8wud9e//ZZTC58TZbc8Zp0JRc5hlTOmLRksYt4B0QxrCqJ4EmFKlIM\n\t\t\t\t\t\tigE5ZNgoR+lwS1ENKikIHibnVcNF9IpIkX8sTzCY18JcileM8Yz5b+R91yoha1MU\n\t\t\t\t\t\tasRefMf2j7RR6kldAJw2Xj63aFtN0NXL6Z+HiLyg4JNslJTH9c3Ha88tI+6Ce1Q6\n\t\t\t\t\t\trG7rztkpHAD5Rd+ovQMysk9ihA3RN18X0Uu8LqExH2tUqq51Fmd+KQ04hyjE4gx+\n\t\t\t\t\t\tw2T6MwPmdp6zLQSXFf6x9CeRai7MwwIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCG\n\t\t\t\t\t\tSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4E\n\t\t\t\t\t\tFgQU59hHQ8+jwnn2x3Yz4BDaEaDHUrswHwYDVR0jBBgwFoAU59hHQ8+jwnn2x3Yz\n\t\t\t\t\t\t4BDaEaDHUrswDQYJKoZIhvcNAQEFBQADggEBAB5CEE4B61l2mn/sBlc7+qN+obOW\n\t\t\t\t\t\tgZURJvs/EeIlfR7LpWRITMSn4pE5mPR4R96tL0vNXc1jl5c2sTV9dtztazWmU+Z1\n\t\t\t\t\t\tu3rniEM6jETPFqlmYhOPFzYWoQTB0LGv3Id0NR4dCFDtFNl+EPaQAug9C39gkOCN\n\t\t\t\t\t\tiLZJlzOZxUALuUvebPbZMfqSTo8SdFT1Cv2No0hQIBjvlO1OimSjAWgkFR3snW8b\n\t\t\t\t\t\txzZ/lWUqrLDZYSo5LXQad3yNfhwi4dMJ5PRuAuTH1akdwlVf4AIeIQDm3QBKJIhj\n\t\t\t\t\t\tTOGrFRiCdlp4cIQwN66UelzUH2KjlI/iQXYLbq5uUHN/EI47I/E0gpnYr5E="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vsp2.edina.ac.uk/cris/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vsp2.edina.ac.uk/cris/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vsp2.edina.ac.uk/cris/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vsp2.edina.ac.uk/cris/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vsp2.edina.ac.uk/cris/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vsp2.edina.ac.uk/cris/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vsp2.edina.ac.uk/cris/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vsp2.edina.ac.uk/cris/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vsp2.edina.ac.uk/cris/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vsp2.edina.ac.uk/cris/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vsp3.edina.ac.uk/cris/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vsp3.edina.ac.uk/cris/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vsp3.edina.ac.uk/cris/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vsp3.edina.ac.uk/cris/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vsp3.edina.ac.uk/cris/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vsp3.edina.ac.uk/cris/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vsp4.edina.ac.uk/cris/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "18"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vsp4.edina.ac.uk/cris/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "19"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vsp4.edina.ac.uk/cris/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "20"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vsp4.edina.ac.uk/cris/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "21"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vsp4.edina.ac.uk/cris/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "22"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vsp4.edina.ac.uk/cris/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "23"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://auth.edina.ac.uk/cris/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "24"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://auth.edina.ac.uk/cris/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "25"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://auth.edina.ac.uk/cris/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "26"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://auth.edina.ac.uk/cris/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "27"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.edina.ac.uk/cris/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "28"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://auth.edina.ac.uk/cris/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "29"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.cefet-rj.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cesar Gama"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cesar.gama@cefet-rj.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.cefet-rj.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIELDCCAxQCAQAwDQYJKoZIhvcNAQEFBQAwgdsxRzBFBgNVBAoUPkNlbnRybyBG\nZWRlcmFsIGRlIEVkdWNh5+NvIFRlY25vbPNnaWNhIENlbHNvIFN1Y2tvdyBkYSBG\nb25zZWNhMQ4wDAYDVQQLEwVEVElORjEgMB4GCSqGSIb3DQEJARYRZHRpbmZAY2Vm\nZXQtcmouYnIxFzAVBgNVBAcTDlJpbyBkZSBKYW5laXJvMRcwFQYDVQQIEw5SaW8g\nZGUgSmFuZWlybzELMAkGA1UEBhMCQlIxHzAdBgNVBAMTFnNoaWJib2xldGguY2Vm\nZXQtcmouYnIwHhcNMTUxMDIzMTQxMjM5WhcNMTgxMDIyMTQxMjM5WjCB2zFHMEUG\nA1UEChQ+Q2VudHJvIEZlZGVyYWwgZGUgRWR1Y2Hn428gVGVjbm9s82dpY2EgQ2Vs\nc28gU3Vja293IGRhIEZvbnNlY2ExDjAMBgNVBAsTBURUSU5GMSAwHgYJKoZIhvcN\nAQkBFhFkdGluZkBjZWZldC1yai5icjEXMBUGA1UEBxMOUmlvIGRlIEphbmVpcm8x\nFzAVBgNVBAgTDlJpbyBkZSBKYW5laXJvMQswCQYDVQQGEwJCUjEfMB0GA1UEAxMW\nc2hpYmJvbGV0aC5jZWZldC1yai5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBAKAHz/3nFY8T9shurcbmk+DAaA5pUY28eCmtYLHygAZ2Dz2qdJcsWY0U\n1WjWzoxlaXIjRSffiG1xrq/BMxHppGo8qrGdbi34T9989eCJ5AMesoyVj3qy3nQe\nF08mdE2gKeq8ZN+kRpVNEH6rkJzdH06hrgtvHNrnPtsnWuuo+kK2G53vbD+/O+Yb\nEYEPOyZI0poLYhsFR+qBMLMxo/Kfu9cfWsVixYmPHFnqiF0HiwElX9cEB1YqH+xN\nmvfs8aa4sqY05IYhOmOZXQbn8GmV6m1KNglUQbwuq7cMWwi82qo8Nb8bh+NH0Jxw\nJ1tY4db/G0EBpWrBcu2Q4qR4EKfaLfkCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\nmogHpnDhhAruiF2aQQiLp216GJ4XM6ZmlqPq5q8s8r59pfNO+9Ork/AHZR8Z/Hkp\nDkfoso1qkYAbpNDdiGt4vleUfCHdHoq2N3SG/tYKatx/ozp7L/PWSXBy+C4GT6u+\nm1mKJBRLjIPxc3jYovdSBJDvTwWzT16Jh4xls+mHXK2NQtObPIAMjkFUYZKYNFTf\n6Pk43YzySIldWH8zQk+7T1sucVAgV/C5qw4BlJdywX6xBSjG0KoX6xsClgdsjuuU\ned0HOE+rbfcdak8uDdywV4Fqbi6IkKGo/mTO/OImm9aMqHMoG05HzRFDqPjn3Uv8\nfVFA8m9TqEvrRbsw1wmqyg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cefet-rj.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.cefet-rj.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.cefet-rj.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.cefet-rj.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.cefet-rj.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.cefet-rj.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.cefet-rj.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.cefet-rj.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.cefet-rj.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cefet-rj.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.cefet-rj.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.cefet-rj.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CEFET/RJ - Centro Federal de Educacao Tecnologica Celso Suckow da Fonseca"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CEFET/RJ - Centro Federal de Educacao Tecnologica Celso Suckow da Fonseca"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CEFET/RJ - Centro Federal de Educacao Tecnologica Celso Suckow da Fonseca"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CEFET/RJ - Centro Federal de Educacao Tecnologica Celso Suckow da Fonseca"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIELDCCAxQCAQAwDQYJKoZIhvcNAQEFBQAwgdsxRzBFBgNVBAoUPkNlbnRybyBG\nZWRlcmFsIGRlIEVkdWNh5+NvIFRlY25vbPNnaWNhIENlbHNvIFN1Y2tvdyBkYSBG\nb25zZWNhMQ4wDAYDVQQLEwVEVElORjEgMB4GCSqGSIb3DQEJARYRZHRpbmZAY2Vm\nZXQtcmouYnIxFzAVBgNVBAcTDlJpbyBkZSBKYW5laXJvMRcwFQYDVQQIEw5SaW8g\nZGUgSmFuZWlybzELMAkGA1UEBhMCQlIxHzAdBgNVBAMTFnNoaWJib2xldGguY2Vm\nZXQtcmouYnIwHhcNMTUxMDIzMTQxMjM5WhcNMTgxMDIyMTQxMjM5WjCB2zFHMEUG\nA1UEChQ+Q2VudHJvIEZlZGVyYWwgZGUgRWR1Y2Hn428gVGVjbm9s82dpY2EgQ2Vs\nc28gU3Vja293IGRhIEZvbnNlY2ExDjAMBgNVBAsTBURUSU5GMSAwHgYJKoZIhvcN\nAQkBFhFkdGluZkBjZWZldC1yai5icjEXMBUGA1UEBxMOUmlvIGRlIEphbmVpcm8x\nFzAVBgNVBAgTDlJpbyBkZSBKYW5laXJvMQswCQYDVQQGEwJCUjEfMB0GA1UEAxMW\nc2hpYmJvbGV0aC5jZWZldC1yai5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBAKAHz/3nFY8T9shurcbmk+DAaA5pUY28eCmtYLHygAZ2Dz2qdJcsWY0U\n1WjWzoxlaXIjRSffiG1xrq/BMxHppGo8qrGdbi34T9989eCJ5AMesoyVj3qy3nQe\nF08mdE2gKeq8ZN+kRpVNEH6rkJzdH06hrgtvHNrnPtsnWuuo+kK2G53vbD+/O+Yb\nEYEPOyZI0poLYhsFR+qBMLMxo/Kfu9cfWsVixYmPHFnqiF0HiwElX9cEB1YqH+xN\nmvfs8aa4sqY05IYhOmOZXQbn8GmV6m1KNglUQbwuq7cMWwi82qo8Nb8bh+NH0Jxw\nJ1tY4db/G0EBpWrBcu2Q4qR4EKfaLfkCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\nmogHpnDhhAruiF2aQQiLp216GJ4XM6ZmlqPq5q8s8r59pfNO+9Ork/AHZR8Z/Hkp\nDkfoso1qkYAbpNDdiGt4vleUfCHdHoq2N3SG/tYKatx/ozp7L/PWSXBy+C4GT6u+\nm1mKJBRLjIPxc3jYovdSBJDvTwWzT16Jh4xls+mHXK2NQtObPIAMjkFUYZKYNFTf\n6Pk43YzySIldWH8zQk+7T1sucVAgV/C5qw4BlJdywX6xBSjG0KoX6xsClgdsjuuU\ned0HOE+rbfcdak8uDdywV4Fqbi6IkKGo/mTO/OImm9aMqHMoG05HzRFDqPjn3Uv8\nfVFA8m9TqEvrRbsw1wmqyg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CEFET/RJ - Centro Federal de Educacao Tecnologica Celso Suckow da Fonseca"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CEFET/RJ - Centro Federal de Educacao Tecnologica Celso Suckow da Fonseca"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cefet-rj.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cefet-rj.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CEFET/RJ - Centro Federal de Educacao Tecnologica Celso Suckow da Fonseca"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CEFET/RJ - Centro Federal de Educacao Tecnologica Celso Suckow da Fonseca"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.cnn.group.cam.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:falcon-support@ucs.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Falcon Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:falcon-support@ucs.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Falcon Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.cnn.group.cam.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-11-16T17:50:10Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Cambridge: Cambridge Networks Network"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cnn.group.cam.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Cambridge"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cnn.group.cam.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.cnn.group.cam.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cnn.group.cam.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cnn.group.cam.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cnn.group.cam.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.cnn.group.cam.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.cnn.group.cam.ac.uk/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.cnn.group.cam.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.cnn.group.cam.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAOB8D/FajzX8MA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHd3dy1mYWxjb24uY3N4LmNhbS5hYy51azAeFw0xMDAxMTgxMTAwMDdaFw0y\n\t\t\t\t\t\tMDAxMTYxMTAwMDdaMCMxITAfBgNVBAMTGHd3dy1mYWxjb24uY3N4LmNhbS5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKpU2AuemKJSIeDmgjkZ\n\t\t\t\t\t\ttPgKaPPkM5CKu3QUHm5JzmtnG3UFMxbOumt6sxWWF72ceXQNPgBNGqFI/sFdaCIo\n\t\t\t\t\t\tHxZj+Z2i+k7/IVXhc4wjs72YUfrjvTMDhHHzndm3KkJS8imsIYQ8/bBnJEF93zVJ\n\t\t\t\t\t\tgPYTrX1C8JxqF/wfY/XCGbEqHgJtqDrSEvK+vLF7LaYI4oTotZOg/vhN7uwaEa7n\n\t\t\t\t\t\tGU2+bKuhcAL+rolEM6sbdrQAj3KarTafacfh9IiAclzyOQTA6pfjFWrucNIuWXc4\n\t\t\t\t\t\tYhaEPyOMubMsp+0eXZAwEPTJ61x+nQZd3UAf7Rm5v7agrzRAdqdwpnqb4yyprJlI\n\t\t\t\t\t\t+lkCAwEAAaNGMEQwIwYDVR0RBBwwGoIYd3d3LWZhbGNvbi5jc3guY2FtLmFjLnVr\n\t\t\t\t\t\tMB0GA1UdDgQWBBTz/ES/EvNaSsqqXUxLuIFc9YHi/TANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAAvFTJS2L6StZuqKA935AD3bBOHe5pg+LCF6ydHdTuyWEJYIWBRJ1WXsKMyaG\n\t\t\t\t\t\tyvdlX60XziJARq2UiYxt4yRjuGLAjQl9kNdrlqeb2AJFnA5E1Mt56FtzPiwu2zrC\n\t\t\t\t\t\tTQlklC4Xfie1Yaw2kEVO2vAoRfg9bgSBfyvFC4oR3vCery3Z687oCeQqDp7LPRcn\n\t\t\t\t\t\t+k5qQD8pout57IYzwyo7GPeVkYEPb3GO2KYmoENlDR/xah2VcsTZF7aIsMBFxaPv\n\t\t\t\t\t\tO+oqrQcnQXTviY9yWLbAlSrPPqGNYDxayVHn+zDSO4scLlOoqZJ8iC5NboNKqFyB\n\t\t\t\t\t\tRsenNm/aXp0wIU+jHVmi/GAPCQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cnn.group.cam.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.cnn.group.cam.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cnn.group.cam.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cnn.group.cam.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cnn.group.cam.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.cnn.group.cam.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cnn.group.cam.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.cnn.group.cam.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.cnn.group.cam.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.cnn.group.cam.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://oba.coppin.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "trsmith@coppin.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Thomas R. Smith, III"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://oba.coppin.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://oba.coppin.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://oba.coppin.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://oba.coppin.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://oba.coppin.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://oba.coppin.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "coppin.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Coppin State University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUM+YnW+6Qcco4W7bnmL64pyaxlZMwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOb2JhLmNvcHBpbi5lZHUwHhcNMTQwMjA1MjE1NTI2WhcN\nMzQwMjA1MjE1NTI2WjAZMRcwFQYDVQQDEw5vYmEuY29wcGluLmVkdTCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBALOtb2EvK7e1tp1r0pvDdNPvmfEniN7u\nIBj0XXxqS7TdTMTHl9SMxnMy14sVGZb4GmrG7mvxnnv+RSuBekMWHCLUGWu9W1O9\n7vYJR6TF6OgkXCu3iB73w0AzfzqJATi6m0NOzd5fby+BYLhZ1Sey0sk/ZxwOevNU\nhwRh2oXXQjlIwt+CFh5dd4hqqXsxJ0rmr/qUnapWbC9U3VnW/FVcmBeqo2yFryhj\nWNvWFLVDQnkSh0OnBXj8ThwUElGLeRD8ICIzGV78WB0MbbL7nTx8EY+W/xWNJLt8\nLD9v/fINAJ56v8xjLde8ivWmzLFlpBYu1eRW0HD+e30JBNs6UNkABbMCAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOb2JhLmNvcHBpbi5lZHWGJWh0dHBzOi8vb2JhLmNvcHBp\nbi5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFFkZQzl8FiFjuRzHjF8gumg9\nn+AkMA0GCSqGSIb3DQEBBQUAA4IBAQB84oObYgvvaz8mx5KnoDroIkyz85dK8lrJ\n5lNVlHMx0z7Mh8TipV60R/TF3a2JSUepdlUGFFMbDMULTD0fn54SaTBaAm2YHQo+\n+Ed2UnWT6epWTXmdwJBftOhE0Q5UL6XCaVfGjIcUbY5BElaxOUIfEM9BTL1gqe3/\nB/RK5gLO5wMAQNywsguqKxVWqqv+pSzN6X8NW7z0SwBP4SAcK0gD5LLcMIIV0eyS\npbe3tUvx4hVxod9fgPO1iBs38OweAif/Y3/T0Vn3gCPhSs4hYwu0dtXeYthcdTwe\nPBpVV8y+Fk1DknVpIx9v4ZbVQptzbTL3tmH9D1JpaV7BrrtW7wHc"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Coppin State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://coppin.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Coppin State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dev.qmplus.qmul.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:its-aa@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Academic Applications"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:moodle-support@ulcc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Moodle Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:its-aa@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Academic Applications"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dev.qmplus.qmul.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-07-07T11:56:50Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Queen Mary and Westfield College: Development QMPlus service"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qmul.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Queen Mary and Westfield College, University of London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.qmplus.qmul.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.qmplus.qmul.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJAIPqU3kVAWyhMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\n\t\t\t\t\t\tBAMTFWRldi5xbXBsdXMucW11bC5hYy51azAeFw0xMjA2MDcxNDQ5MzRaFw0yMjA2\n\t\t\t\t\t\tMDUxNDQ5MzRaMCAxHjAcBgNVBAMTFWRldi5xbXBsdXMucW11bC5hYy51azCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJQ/1Fmpe7Y4Fczs9FF+B6/sS/N9\n\t\t\t\t\t\t1SRvn3IYtio8Nt0JUB+thfKvl68yUnHwn5QXTZdBCZeQtAD26PY3CkdYtB/xoqLu\n\t\t\t\t\t\t0/WB5oVFnYDPfHIFgbLGU4D3yTEpkJDjFEj2lfXs29JFvGs1veZnMup+QDTSeA2Q\n\t\t\t\t\t\tFl6efsN/zWkwqH0vEvLAm2ar7ovCRqekVVCU18z6XAlmBRAr3RPWCNJ1ANFyhHz0\n\t\t\t\t\t\tiQKBDK4VWWRcK+851jcRqGQxtCq/e36pISLD90tay5T8zqBWsDJ5V5w57/vhVyN0\n\t\t\t\t\t\tO/lPS2ACONnA/p2KJEJoPjfx4/8S5QIyWZr+B2sRUmxrn+2g4u5yclL6OTcCAwEA\n\t\t\t\t\t\tAaNDMEEwIAYDVR0RBBkwF4IVZGV2LnFtcGx1cy5xbXVsLmFjLnVrMB0GA1UdDgQW\n\t\t\t\t\t\tBBS74EpjVaBI09AbjkKq11ifr73KtjANBgkqhkiG9w0BAQUFAAOCAQEALoXD6Y4c\n\t\t\t\t\t\tBKSKOyINLvgG7cbakQBDQvrRKNI4upoY54PG/mt2PT7LD/GNqK59L6J8hGsC9dMI\n\t\t\t\t\t\tGtfg7x4lmxneJ/REhyrVH+WaUEH6jfjzHo8Dx7cnyDsRHEeOLLMMOmj5TuzFHwNq\n\t\t\t\t\t\tVpRjDA9HUHxcewIEjI+kpgtKu29pt1PcKpGvQyQZHABdPOTJSkys8EL6b8gbYofG\n\t\t\t\t\t\t5h+rt2LoqtmR6mtO/YvW9SDldfl5SLYEqBlrK4t6AYGzlUguqnTd24nVL9ow38OB\n\t\t\t\t\t\tmFqHxq0Fz6XbSqKOAVhGMqqLplS1gusquKWYDLo5GdHCeFlw5qT42q9RZzBaGJrU\n\t\t\t\t\t\tFh/8cnvaYjotUw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dev.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dev.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dev.qmplus.qmul.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dev.qmplus.qmul.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sso.educause.edu/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "achaux@educause.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex Chaux"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ITinfo@educause.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Administrative Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ITHelpdesk@educause.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.educause.edu/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EDUCAUSE"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.educause.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "EDUCAUSE"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.educause.edu/about/incommon"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EDUCAUSE SSO"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "EDUCAUSE is a nonprofit association and the foremost community of IT leaders and professionals committed to advancing higher education.  This service provides access to collaborative and informative services for faculty and staff if the form of curated content, publications, IT benchmarking data and research, list servers, blogs, wikis, and events."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.educause.edu/sites/all/themes/edutheme/logo.png",
                    "lang": "en",
                    "height": "57",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "225"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.educause.edu/privacy-policy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+jCCAeKgAwIBAgIGAVKap2yFMA0GCSqGSIb3DQEBCwUAMD4xCzAJBgNVBAYTAlVTMREwDwYD\nVQQKEwhlZHVjYXVzZTEcMBoGA1UEAxMTc3NvLWRzLmVkdWNhdXNlLmVkdTAeFw0xNjAyMDEwMjI2\nNDlaFw0xODAxMzEwMjI2NDlaMD4xCzAJBgNVBAYTAlVTMREwDwYDVQQKEwhlZHVjYXVzZTEcMBoG\nA1UEAxMTc3NvLWRzLmVkdWNhdXNlLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAMiYhZkpBh5pZ5bJs+LbqWN4DRNOwqq2mfNl6jJHlvBiv5cUnCVMdVdE+wCF5ZDaY0dolYeln3Xz\n7jQBEfgfxgP4LJgSgd4nuwAYpR3Bz6V4wVWodlwHgzPXOBoPymt40NV8wWi+7lANu2KJVyvAV+ln\n2ikGKjJF8LX8y+jgEx43CDfHHtFTqnG831ayXEVMiodDzIwGV4+eBLJSnpK0x7f6PD5imIJzzqgY\nvvkYuLIIMhyaw2CJ793JIQO4ZcCkZIHmuEaQOuFkZTp/J/v4JAOBRacTyW4Y+05hJLXPc94aW07O\nPfG5l7py3P0DZ+vlc3azboo2RHPeChG75fQOEekCAwEAATANBgkqhkiG9w0BAQsFAAOCAQEAFQ1E\nLRbfn5jeGhbruKZMv4+ieFnn1AeDGKwy7QfX3KcDHjNCA1P2JTVQWIkqFrQvxCiLYHKEg91Rt6qH\nVTuYygTmNKRCr9AQZQfpl1PAfAm8yCyIagCS6Y4b4qhGYLhbh7WB2yN8mRJihC2S1I6YRwjmccy3\nwIYcfJLdh1HhzGUEwzLOEyjWJmZBKq3PLRD+8ikpL0FXry9i4Jp0OE5UrnvNRn77WAtXAQEu7hsO\nNdqWxNaWjSX5B9mtseJPAPCRU1LJjqMO8LSVbe3HlfKqqZ0pcRwqWFobiKuDe6UeG4AZy+iI3hH1\nDjG7U+yjWFViwzT+zlX+3ZOrtEj4J1/vLw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.educause.edu/sp/ACS.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "EDUCAUSE SSO"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "EDUCAUSE is a nonprofit association and the foremost community of IT leaders and professionals committed to advancing higher education.  This service provides access to collaborative and informative services for faculty and staff if the form of curated content, publications, IT benchmarking data and research, list servers, blogs, wikis, and events."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.parchment.com/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jscanlon@parchment.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Scanlon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "alillie@parchment.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew Lillie"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.parchment.com/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.parchment.com/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFpTCCBI2gAwIBAgIRAOvwTZoQX/74EujZauqakIowDQYJKoZIhvcNAQEFBQAw\ngYkxCzAJBgNVBAYTAkdCMRswGQYDVQQIExJHcmVhdGVyIE1hbmNoZXN0ZXIxEDAO\nBgNVBAcTB1NhbGZvcmQxGjAYBgNVBAoTEUNPTU9ETyBDQSBMaW1pdGVkMS8wLQYD\nVQQDEyZDT01PRE8gSGlnaC1Bc3N1cmFuY2UgU2VjdXJlIFNlcnZlciBDQTAeFw0x\nNDAyMjQwMDAwMDBaFw0xNTA0MTMyMzU5NTlaMIG7MQswCQYDVQQGEwJVUzEOMAwG\nA1UEERMFODUyNTAxCzAJBgNVBAgTAkFaMRMwEQYDVQQHEwpTY290dHNkYWxlMS4w\nLAYDVQQJEyU2MjYzIE5vcnRoIFNjb3R0c2RhbGUgUm9hZCwgU3VpdGUgMzMwMRIw\nEAYDVQQKEwlQYXJjaG1lbnQxHDAaBgNVBAsTE1ByZW1pdW1TU0wgV2lsZGNhcmQx\nGDAWBgNVBAMUDyoucGFyY2htZW50LmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBANUkP1RCvY0fgAJ1b2t482fgCZRUriTh15Ylwuo5vxhXiNxg7Eit\nUb2Ixy1dQJ7BYydJCXcC719sv5CZ7TfB3AXCZLMyWhcbd4ZLWGsP5x2ZcDb38bwP\nbKHUQKb/g+zizTi092c6N7toy2V4Pr9d79vTiWf8wU26+F0AkZlGYKO1cthoXR0A\nrQdHmyMAdJpffClZmNW1NtwWxPuEv61REt4ez6br9NfjLXvrDZ/bY5nwOMODlnOT\nlHF28/dj5gChLyHfEAxukbGfjYWe5th4Vdt6FkJGC2USMQbOOA1oiY4FgKgaeD2i\nmS2oMC1bTMNdK0AXjhaOCpwpdXaLOly1jKcCAwEAAaOCAdIwggHOMB8GA1UdIwQY\nMBaAFD/VtdDWRHlQShejm4xK3LiwImRrMB0GA1UdDgQWBBTDfyCJkB4KbmP90POP\npQIntKnEDDAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAU\nBggrBgEFBQcDAQYIKwYBBQUHAwIwUAYDVR0gBEkwRzA7BgwrBgEEAbIxAQIBAwQw\nKzApBggrBgEFBQcCARYdaHR0cHM6Ly9zZWN1cmUuY29tb2RvLmNvbS9DUFMwCAYG\nZ4EMAQICME8GA1UdHwRIMEYwRKBCoECGPmh0dHA6Ly9jcmwuY29tb2RvY2EuY29t\nL0NPTU9ET0hpZ2gtQXNzdXJhbmNlU2VjdXJlU2VydmVyQ0EuY3JsMIGABggrBgEF\nBQcBAQR0MHIwSgYIKwYBBQUHMAKGPmh0dHA6Ly9jcnQuY29tb2RvY2EuY29tL0NP\nTU9ET0hpZ2gtQXNzdXJhbmNlU2VjdXJlU2VydmVyQ0EuY3J0MCQGCCsGAQUFBzAB\nhhhodHRwOi8vb2NzcC5jb21vZG9jYS5jb20wKQYDVR0RBCIwIIIPKi5wYXJjaG1l\nbnQuY29tgg1wYXJjaG1lbnQuY29tMA0GCSqGSIb3DQEBBQUAA4IBAQBaicNSqh0X\nuPyTEefD9AFCATyBWz0vevGanYqaC8rE5oS5kPeWb2W83uCjTFUX2VA39ETzxn7+\nOaYHDGG5PjxA63pDCpoUvZQrzOv9Wd01Dmc9fBMp10rtnDKSgsIxGv0KWjSG4FLr\ndEjTPLtLqWb+36a/01bK4Z4CwnJS5Dd60xDCv7N37/YY0uBIzx8aeq1A5x3ZxLFZ\ngqOWebh3VgXbxSxE8+uYvJ4+eS13iIy0thwr+Xl1sw9ymXgsxs9FVOA9oPURLzz0\nL40uf/jZGnuHXaQh/XRUbsHUOTa0glWs0lRADrGSQBhRYJxNFgWW4rYntPtYYS92\nLbnhhG02Fwo/"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "parchment.com"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.parchment.com/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.parchment.com/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.parchment.com/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.parchment.com/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.parchment.com/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.parchment.com/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "parchment.com"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Parchment, Inc."
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFpTCCBI2gAwIBAgIRAOvwTZoQX/74EujZauqakIowDQYJKoZIhvcNAQEFBQAw\ngYkxCzAJBgNVBAYTAkdCMRswGQYDVQQIExJHcmVhdGVyIE1hbmNoZXN0ZXIxEDAO\nBgNVBAcTB1NhbGZvcmQxGjAYBgNVBAoTEUNPTU9ETyBDQSBMaW1pdGVkMS8wLQYD\nVQQDEyZDT01PRE8gSGlnaC1Bc3N1cmFuY2UgU2VjdXJlIFNlcnZlciBDQTAeFw0x\nNDAyMjQwMDAwMDBaFw0xNTA0MTMyMzU5NTlaMIG7MQswCQYDVQQGEwJVUzEOMAwG\nA1UEERMFODUyNTAxCzAJBgNVBAgTAkFaMRMwEQYDVQQHEwpTY290dHNkYWxlMS4w\nLAYDVQQJEyU2MjYzIE5vcnRoIFNjb3R0c2RhbGUgUm9hZCwgU3VpdGUgMzMwMRIw\nEAYDVQQKEwlQYXJjaG1lbnQxHDAaBgNVBAsTE1ByZW1pdW1TU0wgV2lsZGNhcmQx\nGDAWBgNVBAMUDyoucGFyY2htZW50LmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBANUkP1RCvY0fgAJ1b2t482fgCZRUriTh15Ylwuo5vxhXiNxg7Eit\nUb2Ixy1dQJ7BYydJCXcC719sv5CZ7TfB3AXCZLMyWhcbd4ZLWGsP5x2ZcDb38bwP\nbKHUQKb/g+zizTi092c6N7toy2V4Pr9d79vTiWf8wU26+F0AkZlGYKO1cthoXR0A\nrQdHmyMAdJpffClZmNW1NtwWxPuEv61REt4ez6br9NfjLXvrDZ/bY5nwOMODlnOT\nlHF28/dj5gChLyHfEAxukbGfjYWe5th4Vdt6FkJGC2USMQbOOA1oiY4FgKgaeD2i\nmS2oMC1bTMNdK0AXjhaOCpwpdXaLOly1jKcCAwEAAaOCAdIwggHOMB8GA1UdIwQY\nMBaAFD/VtdDWRHlQShejm4xK3LiwImRrMB0GA1UdDgQWBBTDfyCJkB4KbmP90POP\npQIntKnEDDAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAU\nBggrBgEFBQcDAQYIKwYBBQUHAwIwUAYDVR0gBEkwRzA7BgwrBgEEAbIxAQIBAwQw\nKzApBggrBgEFBQcCARYdaHR0cHM6Ly9zZWN1cmUuY29tb2RvLmNvbS9DUFMwCAYG\nZ4EMAQICME8GA1UdHwRIMEYwRKBCoECGPmh0dHA6Ly9jcmwuY29tb2RvY2EuY29t\nL0NPTU9ET0hpZ2gtQXNzdXJhbmNlU2VjdXJlU2VydmVyQ0EuY3JsMIGABggrBgEF\nBQcBAQR0MHIwSgYIKwYBBQUHMAKGPmh0dHA6Ly9jcnQuY29tb2RvY2EuY29tL0NP\nTU9ET0hpZ2gtQXNzdXJhbmNlU2VjdXJlU2VydmVyQ0EuY3J0MCQGCCsGAQUFBzAB\nhhhodHRwOi8vb2NzcC5jb21vZG9jYS5jb20wKQYDVR0RBCIwIIIPKi5wYXJjaG1l\nbnQuY29tgg1wYXJjaG1lbnQuY29tMA0GCSqGSIb3DQEBBQUAA4IBAQBaicNSqh0X\nuPyTEefD9AFCATyBWz0vevGanYqaC8rE5oS5kPeWb2W83uCjTFUX2VA39ETzxn7+\nOaYHDGG5PjxA63pDCpoUvZQrzOv9Wd01Dmc9fBMp10rtnDKSgsIxGv0KWjSG4FLr\ndEjTPLtLqWb+36a/01bK4Z4CwnJS5Dd60xDCv7N37/YY0uBIzx8aeq1A5x3ZxLFZ\ngqOWebh3VgXbxSxE8+uYvJ4+eS13iIy0thwr+Xl1sw9ymXgsxs9FVOA9oPURLzz0\nL40uf/jZGnuHXaQh/XRUbsHUOTa0glWs0lRADrGSQBhRYJxNFgWW4rYntPtYYS92\nLbnhhG02Fwo/"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Parchment, Inc."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.parchment.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Parchment, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.vho.de/idpvzg",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Borel"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:borel@gbv.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Franck"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Steilen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steilen@gbv.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gerald"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kinstler"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kinstler@gbv.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Till"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.vho.de/idpvzg",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2010-02-10T14:50:56Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.vho.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIG5zCCBc+gAwIBAgIHGU8vu26rPTANBgkqhkiG9w0BAQsFADCBuzELMAkGA1UE\nBhMCREUxFjAUBgNVBAgTDU5JRURFUlNBQ0hTRU4xEzARBgNVBAcTCkdPRVRUSU5H\nRU4xPjA8BgNVBAoTNUdlc2VsbHNjaGFmdCBmdWVyIHdpc3NlbnNjaGFmdGxpY2hl\nIERhdGVudmVyYXJiZWl0dW5nMQ0wCwYDVQQLEwRHV0RHMRAwDgYDVQQDEwdHV0RH\nIENBMR4wHAYJKoZIhvcNAQkBFg9nd2RnLWNhQGd3ZGcuZGUwHhcNMTUwNDE2MTI1\nOTI0WhcNMTgwNzEzMTI1OTI0WjB+MQswCQYDVQQGEwJERTEWMBQGA1UECAwNTklF\nREVSU0FDSFNFTjETMBEGA1UEBwwKR09FVFRJTkdFTjEtMCsGA1UECgwkR2VtZWlu\nc2FtZXIgQmlibGlvdGhla3N2ZXJidW5kIChHQlYpMRMwEQYDVQQDDAp3d3cudmhv\nLmRlMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAzFY9DXHtUWOOHzmh\nA0cwushHtT1mUHkdz6EezlhYsO95F+hb8LctkXywuR3UEfVt31boS4HkhHM9IfGf\nXSbFhBZ97NqWBj80JLFqDkRTMkajjlKF3kH/90FcwW5XF3eYIZnsamLZjC8pBk6M\n9OCzpYl4Kw3L2eys17x2EreuzBUj9/mmOEcN3mjjffjy4xjhuNWa0GR7Yhaj89jg\n4xkjGwcybnC7eZb1V+ZPHYN5vYbw9Qc16p2LK/UB86wKBELwGEerm2DS3MDy7nYI\nNcUhHvO6+U90E38sxvoMwh3ITkKoUZptj+f8QoV7ECJPP56+WkeKE9OPHSzTSWd3\nhbTI/BkS1obHNw6cvKAT82OgYD7YPKbQ6j42cYC8U3YVVNGuoolX/oP/c6HXFfbI\nAAxi/7UaXJ4k5F4IP4WSLlwej8luCm7XILbfBiuy3/bkEiU+8PGt295m5VN1dzif\nufnU8FNfvRH8a+RD1K/1PnIbBtUKdPWiy0KP9DDADLELwfV1yHmES9FFDL7OZ7kB\ndzBeG0CMStQSaSfXd5dFZDAuSu1lxsFjyJt2VCF2C7Bd22StLfy1fhbIV3iPnWiX\nCgQ8teNTna73qcKOQe07obJedT35lxZLEl4+auYZbE627c2w6lyb1GGu06UPFinu\nfXu1nrikhkUiI9u/Z8YxdK08k3MCAwEAAaOCAiowggImME8GA1UdIARIMEYwEQYP\nKwYBBAGBrSGCLAEBBAMDMBEGDysGAQQBga0hgiwCAQQDATAPBg0rBgEEAYGtIYIs\nAQEEMA0GCysGAQQBga0hgiweMAkGA1UdEwQCMAAwCwYDVR0PBAQDAgXgMB0GA1Ud\nJQQWMBQGCCsGAQUFBwMCBggrBgEFBQcDATAdBgNVHQ4EFgQUgeUJOnQfDaLG09KD\nsheNA4eieMUwHwYDVR0jBBgwFoAUpuT/mP3lSTJ+XHXyFqJNjHQ13iIwFQYDVR0R\nBA4wDIIKd3d3LnZoby5kZTB5BgNVHR8EcjBwMDagNKAyhjBodHRwOi8vY2RwMS5w\nY2EuZGZuLmRlL2d3ZGctY2EvcHViL2NybC9jYWNybC5jcmwwNqA0oDKGMGh0dHA6\nLy9jZHAyLnBjYS5kZm4uZGUvZ3dkZy1jYS9wdWIvY3JsL2NhY3JsLmNybDCByQYI\nKwYBBQUHAQEEgbwwgbkwMwYIKwYBBQUHMAGGJ2h0dHA6Ly9vY3NwLnBjYS5kZm4u\nZGUvT0NTUC1TZXJ2ZXIvT0NTUDBABggrBgEFBQcwAoY0aHR0cDovL2NkcDEucGNh\nLmRmbi5kZS9nd2RnLWNhL3B1Yi9jYWNlcnQvY2FjZXJ0LmNydDBABggrBgEFBQcw\nAoY0aHR0cDovL2NkcDIucGNhLmRmbi5kZS9nd2RnLWNhL3B1Yi9jYWNlcnQvY2Fj\nZXJ0LmNydDANBgkqhkiG9w0BAQsFAAOCAQEAIhlmQn3roI/XHEH3X/mswugaPm9P\nA1kQ2RJOjNOyWZi35CB2lh6Zi4hCZm9ZoEOxvtsP9JPliwnnMNeK4BdM0Pvjs8iR\nUpYnpFFxzc3w1heZ4+rR/F2PyxmZyQEEwdBA2nZHqwXKMbV/dFQPo08ljst6GwNu\nDvQZHKOJBbYvLe2bwDSp14eAwnJjX/JUKW0J+4prAx684qTS7bycYXcErU6ENc95\nh6ZnXWIR/hFykNOyKWQdVt9Azz7gClrJwypVWp7U1uCcVDIuVzI6u+CPcaLNy6t/\nNBtxgZjOFsGvbdVNBzjz26LYkgbur7z7lMG4ReTzhHeFMCD3h3rwF6cyOA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.vho.de,O=Gemeinsamer Bibliotheksverbund (GBV),L=GOETTINGEN,ST=NIEDERSACHSEN,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gbv.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://www.vho.de:8443/idpvzg/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.vho.de:8443/idpvzg/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://www.vho.de/idpvzg/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.vho.de/idpvzg/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.vho.de/idpvzg/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.vho.de/idpvzg/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://www.vho.de:8443/idpvzg/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.vho.de:8443/idpvzg/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gbv.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.vho.de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.vho.de"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IdP der Verbundzentrale des GBV (VZG)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IdP der Verbundzentrale des GBV (VZG)"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Verbundzentrale des GBV (VZG)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Verbundzentrale des GBV (VZG)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.vho.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIG5zCCBc+gAwIBAgIHGU8vu26rPTANBgkqhkiG9w0BAQsFADCBuzELMAkGA1UE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\nNBtxgZjOFsGvbdVNBzjz26LYkgbur7z7lMG4ReTzhHeFMCD3h3rwF6cyOA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.vho.de,O=Gemeinsamer Bibliotheksverbund (GBV),L=GOETTINGEN,ST=NIEDERSACHSEN,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Verbundzentrale des GBV (VZG)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Verbundzentrale des GBV (VZG)"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vho.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vho.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e45"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e45"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://vetucation.vu-wien.ac.at/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:elearning@vetmeduni.ac.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "E-Learning"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:elearning@vetmeduni.ac.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "E-Learning"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://vetucation.vu-wien.ac.at/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://eduid.at/policy/mdrps-20140606"
              }
            ],
            "registration_instant": "2015-12-18T18:00:00Z",
            "registration_authority": "http://eduid.at",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://aai.dfn.de/category/vetmed-member"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Veterin\u00e4rmedizinische Universit\u00e4t Wien"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Veterinary Medicine Vienna"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vetmeduni.ac.at/de/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vetmeduni.ac.at/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Veterin\u00e4rmedizinische Universit\u00e4t Wien"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Veterinary Medicine Vienna"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vetucation.vu-wien.ac.at/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vetucation.vu-wien.ac.at/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vetucation.vu-wien.ac.at/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vetucation.vu-wien.ac.at/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vetucation.vu-wien.ac.at/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vetucation.vu-wien.ac.at/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://vetucation.vu-wien.ac.at/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://vetucation.vetmeduni.ac.at/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://vetucation.vetmeduni.ac.at/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Vetucation"
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Vetucation"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Vetucation is the e-learning platform of the University of Veterinary Medicine Vienna. Its purpose is the management of teaching and learning contents and the support of face-to-face teaching with various online communication and collaboration tools."
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Vetucation ist die e-learning Plattform der Vetmeduni Vienna. Sie dient der Verwaltung von Lehr- und Lernmaterial und Unterst\u00fctzung der Pr\u00e4senzlehre mit Online Kommunikations- und Kollaborations-Tools."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.vetmeduni.ac.at/favicon.ico",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://www.vetmeduni.ac.at/fileadmin/vetmed/img/logo.gif",
                    "height": "69",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "231"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.vetmeduni.ac.at/en/infos/vetucation-privacy-policy-shibboleth/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAJ0uN/nroe1EMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\nBAMTGHZldHVjYXRpb24udnUtd2llbi5hYy5hdDAeFw0xNTEwMDgwOTE2MDlaFw0y\nNTEwMDUwOTE2MDlaMCMxITAfBgNVBAMTGHZldHVjYXRpb24udnUtd2llbi5hYy5h\ndDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANcquQ1PwnT0kh8Lnj7+\nuFAYvMvJ2C20vX9gQwHd0JknKshOvcTL3o+cFhrQoyBZwBZ++WjMPjI8aqXwgCD9\n0edbQzt/KKe75yDaU3LEpu5DwEpGyzKeYdDk3E5EFZLWsFDIfg/Wb0nHYrjL8DsJ\nESZ30vRJX7bOo+7r1LIpF0cbr7qU4GN5PxMlSEWSThpxnHp1ogNf4/awaZIiP5Fm\n3j1XG18/JPUhzOlHCW/UUNFQ1ckJvay5HzsXCsgA9Dh000OrrmvXXGrAUF1S9clU\n+gKkLm/7UcsNmuhb/P+1N5Tm7+5nY3rL+PXIdUYqmz+0+cSNTXyIiPZUeNUhM95A\nmGcCAwEAAaNGMEQwIwYDVR0RBBwwGoIYdmV0dWNhdGlvbi52dS13aWVuLmFjLmF0\nMB0GA1UdDgQWBBRLMEHagUOiL3lTyJk44M8WtqIjXjANBgkqhkiG9w0BAQUFAAOC\nAQEAGWNr9ZRRjDyWTsqRxS0rrK4CC+seW9q7Xo5ZOYIQeO3fGdEDS7fnLk1kL835\ngBU08s+VwwcBDUTvZRrgnQmcx6wn+QFehpw3gE01XQ1ZDOVEGKSgGj4h0cHfuSr1\nS93BkR2jRGurKQuGNGFfOw/DkzqKk+wMub0anS1FWZYXxQvfMw7RXQ8Gb95CF815\np/ElK1Ifeztv7H+Af42jzwhYuLF/YhXDBekcyPXjqjobxRWzgKkqp+FtxZzOAoY8\n74e9Pp+cKc3ZkqNh5DQy9zStiClBdHta8mh8m4jGUOyUz3qy1IuFZ64Fx5e3p+Dn\nmPmdVWCZHlIbHEZLKp9V+fu71Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vetucation.vu-wien.ac.at/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vetucation.vu-wien.ac.at/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vetucation.vu-wien.ac.at/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vetucation.vu-wien.ac.at/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Vetucation"
                },
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Vetucation"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Vetucation is the e-learning platform of the University of Veterinary Medicine Vienna. Its purpose is the management of teaching and learning contents and the support of face-to-face teaching with various online communication and collaboration tools."
                },
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Vetucation ist die e-learning Plattform der Vetmeduni Vienna. Sie dient der Verwaltung von Lehr- und Lernmaterial und Unterst\u00fctzung der Pr\u00e4senzlehre mit Online Kommunikations- und Kollaborations-Tools."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.british-history.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Blaney"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Jonathan.Blaney@sas.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jonathan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Steer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Martin.Steer@sas.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.british-history.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-09-10T16:11:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "British History Online"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.british-history.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.british-history.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.british-history.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.british-history.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.british-history.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.british-history.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Additional premium content including The Parliament Rolls of Medieval\n\t\t\t\t\tEngland (Edward I to Henry VII), all the volumes of the Calendar of\n\t\t\t\t\tState Papers, Domestic 1537-1714, the Calendars of State Papers for\n\t\t\t\t\tScotland and Ireland, plus the Calendar of Close Rolls"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.british-history.ac.uk/images/logo.gif",
                    "height": "33",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "487"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "British History Online"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEjCCAfqgAwIBAgIJALh/eAye3WYvMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\n\t\t\t\t\t\tBAMTGXd3dy5icml0aXNoLWhpc3RvcnkuYWMudWswHhcNMTAwOTAyMDczODE4WhcN\n\t\t\t\t\t\tMjAwODMwMDczODE4WjAkMSIwIAYDVQQDExl3d3cuYnJpdGlzaC1oaXN0b3J5LmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAv5Fo2rXmIk7rzSrS\n\t\t\t\t\t\tr2l8ComzSzAubn2P+3aH0kXln8uijcbKjqp16eSnaRO3hjPVGqxiUpERX/vkSRYf\n\t\t\t\t\t\tYQi1BXJSTc965iQi6YbQLtUESCMHaGnhMQTA94n3R0dF1lRjn19SoLvKq16nInxc\n\t\t\t\t\t\tV8mdKZtP0fsLVxflrjemmnl7i56HZFXPjfBcTHzlUnIT2VOhC/hOqTyeSAEOuTKO\n\t\t\t\t\t\tePTH0udgPVTOLKzU6xxrR2QgDx/v7XH/KDraqlBThM/5yvS15IpdTmxWGyGlJx+Q\n\t\t\t\t\t\ti8s1+KuRf20JTi9s41o3csrCs/iRuTcccDFI4J5Bu96CmT+hLh+zioQF/UfNsI/H\n\t\t\t\t\t\tb5TUbQIDAQABo0cwRTAkBgNVHREEHTAbghl3d3cuYnJpdGlzaC1oaXN0b3J5LmFj\n\t\t\t\t\t\tLnVrMB0GA1UdDgQWBBRB18xhmEjac8eJrYMgCbrBrF3oJjANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAeKbONxHaEPx/1HTc/jfFLRagds7HYz3Ce4QKxrvge/TK4oObe8ZiICYM\n\t\t\t\t\t\t4sTaeRkT3ioBt1Gm3ZCGtiUM5pg7QtUwG3HXBfqv/8Z1swfOxUDebab6m04aMk2i\n\t\t\t\t\t\t2rb7aArAHATlV5a72H5CAWeEaif6WclWWo7rgTl8f7akYNt7qkZKttoHj0aWfNum\n\t\t\t\t\t\tecepIeAKuyBkUex3UCvzQlEr67A0wlxPSqUm9UNtYMB5KgTJjzSWVennzzRcqUFT\n\t\t\t\t\t\tJyLIrCA/d3S+4FGrnDNNVr0KWD/h2M53lhk5ohh147oP6qwVOwqalnMIqzHDjFrm\n\t\t\t\t\t\tVh9RR1SnWTuXhAGE8kZHTZLj7wi3sg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEjCCAfqgAwIBAgIJALh/eAye3WYvMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\n\t\t\t\t\t\tBAMTGXd3dy5icml0aXNoLWhpc3RvcnkuYWMudWswHhcNMTAwOTAyMDczODE4WhcN\n\t\t\t\t\t\tMjAwODMwMDczODE4WjAkMSIwIAYDVQQDExl3d3cuYnJpdGlzaC1oaXN0b3J5LmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAv5Fo2rXmIk7rzSrS\n\t\t\t\t\t\tr2l8ComzSzAubn2P+3aH0kXln8uijcbKjqp16eSnaRO3hjPVGqxiUpERX/vkSRYf\n\t\t\t\t\t\tYQi1BXJSTc965iQi6YbQLtUESCMHaGnhMQTA94n3R0dF1lRjn19SoLvKq16nInxc\n\t\t\t\t\t\tV8mdKZtP0fsLVxflrjemmnl7i56HZFXPjfBcTHzlUnIT2VOhC/hOqTyeSAEOuTKO\n\t\t\t\t\t\tePTH0udgPVTOLKzU6xxrR2QgDx/v7XH/KDraqlBThM/5yvS15IpdTmxWGyGlJx+Q\n\t\t\t\t\t\ti8s1+KuRf20JTi9s41o3csrCs/iRuTcccDFI4J5Bu96CmT+hLh+zioQF/UfNsI/H\n\t\t\t\t\t\tb5TUbQIDAQABo0cwRTAkBgNVHREEHTAbghl3d3cuYnJpdGlzaC1oaXN0b3J5LmFj\n\t\t\t\t\t\tLnVrMB0GA1UdDgQWBBRB18xhmEjac8eJrYMgCbrBrF3oJjANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAeKbONxHaEPx/1HTc/jfFLRagds7HYz3Ce4QKxrvge/TK4oObe8ZiICYM\n\t\t\t\t\t\t4sTaeRkT3ioBt1Gm3ZCGtiUM5pg7QtUwG3HXBfqv/8Z1swfOxUDebab6m04aMk2i\n\t\t\t\t\t\t2rb7aArAHATlV5a72H5CAWeEaif6WclWWo7rgTl8f7akYNt7qkZKttoHj0aWfNum\n\t\t\t\t\t\tecepIeAKuyBkUex3UCvzQlEr67A0wlxPSqUm9UNtYMB5KgTJjzSWVennzzRcqUFT\n\t\t\t\t\t\tJyLIrCA/d3S+4FGrnDNNVr0KWD/h2M53lhk5ohh147oP6qwVOwqalnMIqzHDjFrm\n\t\t\t\t\t\tVh9RR1SnWTuXhAGE8kZHTZLj7wi3sg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.british-history.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.british-history.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.british-history.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.british-history.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.british-history.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.british-history.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.british-history.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.british-history.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.british-history.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.british-history.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.vub.ac.be/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Technical Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@vub.ac.be"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.vub.ac.be/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://federation.belnet.be/files/Belnet-metadata-registration-practice-statement.txt"
              }
            ],
            "registration_instant": "2012-03-27T12:00:00Z",
            "registration_authority": "http://federation.belnet.be/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUUfJ0sMk1r7U/7VeOC4dUi0tFk+4wDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNaWRwLnZ1Yi5hYy5iZTAeFw0xMzEyMTcwODQ5NDRaFw0z\nMzEyMTcwODQ5NDRaMBgxFjAUBgNVBAMTDWlkcC52dWIuYWMuYmUwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCgAg+ICRsB+l1EPx8pRtbp/W/s0DruoIHO\nwlHgtvhVToh/GDdAqDNHdhGGTSTVc77JO1j1yV3sQgczH+4Hz/bczwUCbna3ItgN\nSvnhzzFcpzdJ7MKJJaIc4CszrZG4TBA3hHaAIOsjlOz8QwG7DIhx7pF/wZktYJkQ\nRE6vC6Y579QcFqxBF8nNi+jKELWgwean36+lqIDYLhsWDye/lJ/h5dgp0W1bfYM+\nCNXNbBF5IiLY9RgypiGBtm+717vig8GVpHOsiFsN7+CPboRr0BFVwg2NEpnvlZSa\nplqYBHOlmqLDJv8l7Du6ss1Vp1eLgp/cdb0pbeBme/+NCMZIGOJvAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDWlkcC52dWIuYWMuYmWGJGh0dHBzOi8vaWRwLnZ1Yi5hYy5i\nZS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUb3yOJUsB5SdaKAXaXW+Xxlub4Dgw\nDQYJKoZIhvcNAQEFBQADggEBAArzqWvBazHyT82L/HbNUH+KbrbOtgj2eiLRmWDT\nGCB1/qXuuh+WLejyvN7EJ+SBGGdWEdytBvZyAmIq4Kv4EDDupu/ynYCxP03v6oW5\nucpeNa/q3lA9oAXPNp4z5DXJYTTMlRXOojmJnokizp4pxKM9hKVPBN7QB7n6KjPy\n2F+EAkHGF5c4LKgMsOK4Gsjux1vi/PbAO0qiMOfsHdKM1ZUJQP+skNYkhjMCVV4d\n/h/4Ex6XuS8nqlpwIti+gqTmnULy0Aa3fBluoLmvB38uDPdlC3QkBiFbQtX+GUDG\ndnwz715sBlh9o1XpY8ZJk6VAdG4njwd/RBj9cZcya3tIaMw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vub.ac.be"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.vub.ac.be:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.vub.ac.be:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.vub.ac.be/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.vub.ac.be/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.vub.ac.be:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.vub.ac.be/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.vub.ac.be/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.vub.ac.be/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.vub.ac.be/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.vub.ac.be:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.vub.ac.be:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vub.ac.be"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Vrije Universiteit Brussel"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.vub.ac.be/logo/vub-small.jpg",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.vub.ac.be/logo/vub-large.png",
                    "height": "110",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "347"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "VUB - Vrije Universiteit Brussel"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "vub.ac.be"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:50.8213690,4.3957100"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "134.184.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:06a8:1190::/64"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUUfJ0sMk1r7U/7VeOC4dUi0tFk+4wDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNaWRwLnZ1Yi5hYy5iZTAeFw0xMzEyMTcwODQ5NDRaFw0z\nMzEyMTcwODQ5NDRaMBgxFjAUBgNVBAMTDWlkcC52dWIuYWMuYmUwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCgAg+ICRsB+l1EPx8pRtbp/W/s0DruoIHO\nwlHgtvhVToh/GDdAqDNHdhGGTSTVc77JO1j1yV3sQgczH+4Hz/bczwUCbna3ItgN\nSvnhzzFcpzdJ7MKJJaIc4CszrZG4TBA3hHaAIOsjlOz8QwG7DIhx7pF/wZktYJkQ\nRE6vC6Y579QcFqxBF8nNi+jKELWgwean36+lqIDYLhsWDye/lJ/h5dgp0W1bfYM+\nCNXNbBF5IiLY9RgypiGBtm+717vig8GVpHOsiFsN7+CPboRr0BFVwg2NEpnvlZSa\nplqYBHOlmqLDJv8l7Du6ss1Vp1eLgp/cdb0pbeBme/+NCMZIGOJvAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDWlkcC52dWIuYWMuYmWGJGh0dHBzOi8vaWRwLnZ1Yi5hYy5i\nZS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUb3yOJUsB5SdaKAXaXW+Xxlub4Dgw\nDQYJKoZIhvcNAQEFBQADggEBAArzqWvBazHyT82L/HbNUH+KbrbOtgj2eiLRmWDT\nGCB1/qXuuh+WLejyvN7EJ+SBGGdWEdytBvZyAmIq4Kv4EDDupu/ynYCxP03v6oW5\nucpeNa/q3lA9oAXPNp4z5DXJYTTMlRXOojmJnokizp4pxKM9hKVPBN7QB7n6KjPy\n2F+EAkHGF5c4LKgMsOK4Gsjux1vi/PbAO0qiMOfsHdKM1ZUJQP+skNYkhjMCVV4d\n/h/4Ex6XuS8nqlpwIti+gqTmnULy0Aa3fBluoLmvB38uDPdlC3QkBiFbQtX+GUDG\ndnwz715sBlh9o1XpY8ZJk6VAdG4njwd/RBj9cZcya3tIaMw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "VUB - Vrije Universiteit Brussel"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vub.ac.be"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Vrije Universiteit Brussel"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://webauth.scrippscollege.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jeff@scrippscollege.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeff Sessler"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jeff@scrippscollege.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeff Sessler"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jeff@scrippscollege.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeff Sessler"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jeff@scrippscollege.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeff Sessler"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://webauth.scrippscollege.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webauth.scrippscollege.edu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://webauth.scrippscollege.edu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webauth.scrippscollege.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://webauth.scrippscollege.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "scrippscollege.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider service for Scripps College."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Scripps College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIVAOpDjT7coAA9QWrjD1kbiAsVt7zDMA0GCSqGSIb3DQEB\nBQUAMCUxIzAhBgNVBAMTGndlYmF1dGguc2NyaXBwc2NvbGxlZ2UuZWR1MB4XDTE0\nMDgyOTAwMDYyMloXDTM0MDgyOTAwMDYyMlowJTEjMCEGA1UEAxMad2ViYXV0aC5z\nY3JpcHBzY29sbGVnZS5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQC9HbPIMAc0BT+aTPL5KojEEQgxPpOaRHpAin0HOlZkq2wT8mUx+LH0ZI9QiuoI\n/JYItHk5z3S99PyIqWCJKgBdtwyZsQtNqOA6LD0gNnQ29OQPKpdcREN7EYocBKbw\niRyK9pt1UtN8Ht3WfnZt91I/FOYgZ/WlIn1tBuj53Vfe4BTlhzb0wGZedzim1llM\nnjXFstO7aBZ1oBSFIcrgpdK43qZqzRrgHxzk/Ek9PvWxDA2OV6fKJ+KC8arVR6BB\ng1OxH+WmEp7jvCu8LGAptB+pOrdZJOb5/bQQ7t+oZRK9Per2XVNXY1eNTx9++HTR\nvkuIpgxmRRNquolDraRwAZbpAgMBAAGjezB5MFgGA1UdEQRRME+CGndlYmF1dGgu\nc2NyaXBwc2NvbGxlZ2UuZWR1hjFodHRwczovL3dlYmF1dGguc2NyaXBwc2NvbGxl\nZ2UuZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRWVDmn0HSAcmKTxFZzGYqK\n0RfxqjANBgkqhkiG9w0BAQUFAAOCAQEAKtDhaGgrizvBIYTyYl7udiYCHZ972Dl9\nLbS/5IGBvipphw2FZAA6ZuFDlbbSBDwmEBX+l451s7A2YI8IuZ+OyLF3Nms3svVH\na1IWl5BlRcOk3qdZqnWBvZ/0XaU4xmGH0neX7Nkf6wzkhzWMZeS/gw+J9zPuBMqR\nczwZlKdDGYB8sMf0o933y/SPyjqSjOENNSE02l0sSjJkrYkAM0IBNb7E44rJZj0x\nF0ImO4Fv5/Vy2RaahHaHoC4lvUix0pR4w8d50k/XEkCoEMu1Ekvdh05rFNZA8WtD\nB9BnGxr829tOOS2Sq1zdJCXsYF2fIKksQq3xvl8iFiRmA7YXD2mOvg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "error_url": "https://webauth.scrippscollege.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Scripps College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.scrippscollege.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Scripps College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.owncloud.gla.ac.uk/entity",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Watt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:John.Watt@glasgow.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Watt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:John.Watt@glasgow.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.owncloud.gla.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-02-23T14:19:43Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Glasgow Cloud"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gla.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Glasgow"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://owncloud.gla.ac.uk/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "simpleSAMLPHP SP for federated access to Uni. Of Glasgow cloud infrastructure."
                  }
                ],
                "logo": [
                  {
                    "text": "https://milngavie.cent.gla.ac.uk/UoG_colour_80x60.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Glasgow Cloud"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIECjCCAvKgAwIBAgIJAKwtx3NdckJyMA0GCSqGSIb3DQEBCwUAMIGFMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjERMA8GA1UECAwIU2NvdGxhbmQxEDAOBgNVBAcMB0dsYXNnb3cxHjAc\n\t\t\t\t\t\tBgNVBAoMFVVuaXZlcnNpdHkgb2YgR2xhc2dvdzEUMBIGA1UECwwLSVQgU2Vydmlj\n\t\t\t\t\t\tZXMxGzAZBgNVBAMMEm93bmNsb3VkLmdsYS5hYy51azAeFw0xNTAyMjMxMDI5NDNa\n\t\t\t\t\t\tFw0yNTAyMjAxMDI5NDNaMIGFMQswCQYDVQQGEwJHQjERMA8GA1UECAwIU2NvdGxh\n\t\t\t\t\t\tbmQxEDAOBgNVBAcMB0dsYXNnb3cxHjAcBgNVBAoMFVVuaXZlcnNpdHkgb2YgR2xh\n\t\t\t\t\t\tc2dvdzEUMBIGA1UECwwLSVQgU2VydmljZXMxGzAZBgNVBAMMEm93bmNsb3VkLmds\n\t\t\t\t\t\tYS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAPW7Jsg02GHZ\n\t\t\t\t\t\t/E01ULgwISkQ4Qr/Rid4+bhe3TG4OH5aHcdChNRdxP55PYuIV+yy4yOYD6ZP+veE\n\t\t\t\t\t\tPlmBw0VYl6IIQTpFVeY+j2LrxL9vdRmSfn4+qnd0xbr2hBdd5xtC0SMvxZLEzM7U\n\t\t\t\t\t\tgGHu4LUn9WDhwRiuCSZFoEhEjVFOcV8MdnxUA3GsleMdVQaI7Hb7yR9o5cYMsXPj\n\t\t\t\t\t\tsCCCpnH5E76O9/uNuh+0CzBJaVqxwjungiXrWz1tr/+j/dKtpf/sTdH+Tw+xj02X\n\t\t\t\t\t\tHXCwjO8My8rPf2q5hn6+xKjsHnnIJXGHIxiYbEzESbffLzOFl8mevIQLQWxDz8L1\n\t\t\t\t\t\tKhwjk85sw18CAwEAAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3Bl\n\t\t\t\t\t\tblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFPz/VTu8R3dicZ/o\n\t\t\t\t\t\tTV75yyBGAgSvMB8GA1UdIwQYMBaAFPz/VTu8R3dicZ/oTV75yyBGAgSvMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBCwUAA4IBAQAElnHrdy1FhRqY0gV7Ml2+QUdaI/o3Z2SAlDlKhk9dlOsw\n\t\t\t\t\t\tdzyizx/wdXksEgBk/oqXglL5LgsvbPITtx8VfTbxZ9azdvD2ke+rc5I4vuzlHu/R\n\t\t\t\t\t\tY7l8W96uek7tSYpHJElPPOkktXJuPH1e4e58loyeLFBTmYHgvTSxbY8/+L21M2DB\n\t\t\t\t\t\tW4Xvn7yK6tXwYACCGw3h0dVy62OoQHGef8uxeiJJAuQQ9Bu6VMsUWTsgpZ14h0Qh\n\t\t\t\t\t\t4Ucenlt3BaKnK3VatoEjN/qo99xeWuIfjj9YWRKpuPV4k95VuK9ye9bfBmpEjpqu\n\t\t\t\t\t\t8JmOVu1HXJd97u281HNmTHuDPFEHCPMK/qYtDP4Y"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIECjCCAvKgAwIBAgIJAKwtx3NdckJyMA0GCSqGSIb3DQEBCwUAMIGFMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjERMA8GA1UECAwIU2NvdGxhbmQxEDAOBgNVBAcMB0dsYXNnb3cxHjAc\n\t\t\t\t\t\tBgNVBAoMFVVuaXZlcnNpdHkgb2YgR2xhc2dvdzEUMBIGA1UECwwLSVQgU2Vydmlj\n\t\t\t\t\t\tZXMxGzAZBgNVBAMMEm93bmNsb3VkLmdsYS5hYy51azAeFw0xNTAyMjMxMDI5NDNa\n\t\t\t\t\t\tFw0yNTAyMjAxMDI5NDNaMIGFMQswCQYDVQQGEwJHQjERMA8GA1UECAwIU2NvdGxh\n\t\t\t\t\t\tbmQxEDAOBgNVBAcMB0dsYXNnb3cxHjAcBgNVBAoMFVVuaXZlcnNpdHkgb2YgR2xh\n\t\t\t\t\t\tc2dvdzEUMBIGA1UECwwLSVQgU2VydmljZXMxGzAZBgNVBAMMEm93bmNsb3VkLmds\n\t\t\t\t\t\tYS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAPW7Jsg02GHZ\n\t\t\t\t\t\t/E01ULgwISkQ4Qr/Rid4+bhe3TG4OH5aHcdChNRdxP55PYuIV+yy4yOYD6ZP+veE\n\t\t\t\t\t\tPlmBw0VYl6IIQTpFVeY+j2LrxL9vdRmSfn4+qnd0xbr2hBdd5xtC0SMvxZLEzM7U\n\t\t\t\t\t\tgGHu4LUn9WDhwRiuCSZFoEhEjVFOcV8MdnxUA3GsleMdVQaI7Hb7yR9o5cYMsXPj\n\t\t\t\t\t\tsCCCpnH5E76O9/uNuh+0CzBJaVqxwjungiXrWz1tr/+j/dKtpf/sTdH+Tw+xj02X\n\t\t\t\t\t\tHXCwjO8My8rPf2q5hn6+xKjsHnnIJXGHIxiYbEzESbffLzOFl8mevIQLQWxDz8L1\n\t\t\t\t\t\tKhwjk85sw18CAwEAAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3Bl\n\t\t\t\t\t\tblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFPz/VTu8R3dicZ/o\n\t\t\t\t\t\tTV75yyBGAgSvMB8GA1UdIwQYMBaAFPz/VTu8R3dicZ/oTV75yyBGAgSvMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBCwUAA4IBAQAElnHrdy1FhRqY0gV7Ml2+QUdaI/o3Z2SAlDlKhk9dlOsw\n\t\t\t\t\t\tdzyizx/wdXksEgBk/oqXglL5LgsvbPITtx8VfTbxZ9azdvD2ke+rc5I4vuzlHu/R\n\t\t\t\t\t\tY7l8W96uek7tSYpHJElPPOkktXJuPH1e4e58loyeLFBTmYHgvTSxbY8/+L21M2DB\n\t\t\t\t\t\tW4Xvn7yK6tXwYACCGw3h0dVy62OoQHGef8uxeiJJAuQQ9Bu6VMsUWTsgpZ14h0Qh\n\t\t\t\t\t\t4Ucenlt3BaKnK3VatoEjN/qo99xeWuIfjj9YWRKpuPV4k95VuK9ye9bfBmpEjpqu\n\t\t\t\t\t\t8JmOVu1HXJd97u281HNmTHuDPFEHCPMK/qYtDP4Y"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://owncloud.gla.ac.uk/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://owncloud.gla.ac.uk/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://owncloud.gla.ac.uk/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://owncloud.gla.ac.uk/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ieeexplore.ieee.org/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Caldwell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:d.caldwell@ieee.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Don"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Trivedi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mh.trivedi@ieee.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mehul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ieeexplore.ieee.org/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IEEE XploreDigital Library"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ieee.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Institute of Electrical And Electronics Engineers, Incorporated"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICuDCCAaCgAwIBAgIEUdwYxzANBgkqhkiG9w0BAQUFADAeMRwwGgYDVQQDExNpZWVleHBsb3Jl\n\t\t\t\t\t\tLmllZWUub3JnMB4XDTEzMDcwOTE0MDU1OVoXDTE2MDcwODE0MDU1OVowHjEcMBoGA1UEAxMTaWVl\n\t\t\t\t\t\tZXhwbG9yZS5pZWVlLm9yZzCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOA75zEbFib1\n\t\t\t\t\t\toKwcgYsUgZh/RGIYQKeVLG96sghJd0VvxeMKq0hgF7/jWjXPUqcHCTjNg50joOH4nAjlvRZ81Iw0\n\t\t\t\t\t\tcKyMmnaucv8scBnBfUwQjfkVOyUW3IxizoH66RLVXJvq8knRbB+d25kLDcA0Wsby/RIMGkF5TJK5\n\t\t\t\t\t\tPy6GBXF5VqH+E41ZvJNagkd2LiOc+oW9m/1df8MhcS02m1foWeJeax8GA4lyeGGTXCk3G3KO1PCz\n\t\t\t\t\t\twc3UZqsaM3l2golNWx3eRqWKVjEj59+IkChkHm7MHnerKoWq+1EG/VbNnkTNn1AzRmqtcmMuSte6\n\t\t\t\t\t\t6aEyGsZ6UTPjOKNIDnBnKT1PRmUCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAD1f85Q5nzBzUOUIl\n\t\t\t\t\t\tnftTsixhHhQOm6KNUxP6O2VGfbnkjikn972e3ypMtBxkloQTOyEti/qWw3tIvnadgKpQazkDGSMh\n\t\t\t\t\t\t1RR6yJc2MWkuaah4rMET34XshUg7oQBRFThYrtX9g0yU3Sbriy2mRayz5+C51XF5U/lUKvepeBAQ\n\t\t\t\t\t\t8T/5jnXGN2Acfi2r/QYSK8uPnnzuwPYlhTicyN2khwhBjokYXy/HEW1OjFe2VPmcKROPEwMkeNHD\n\t\t\t\t\t\tite5CXfTutjiX6Wlmy2iiCp09SzEy2Zfan4iMf8hgdD/8994EkEQSYluvKKl+tc0BwdpKxxuoNke\n\t\t\t\t\t\txhXvRxt/N3hR1GDsAZjQow=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ieeexplore.ieee.org/Shibboleth/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ieeexplore.ieee.org/Shibboleth/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ieeexplore.ieee.org/Shibboleth/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ieeexplore.ieee.org/Shibboleth/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cafetools.ufpi.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Arinaldo Silva"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "arinaldo@ufpi.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafetools.ufpi.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEMDCCAxgCAQAwDQYJKoZIhvcNAQEFBQAwgd0xLjAsBgNVBAoUJVVGUEkgLSBV\nbml2ZXJzaWRhZGUgRmVkZXJhbCBkbyBQaWF1w60xNDAyBgNVBAsUK05USSAtIE7D\numNsZW8gZGUgVGVjbm9sb2dpYSBkYSBJbmZvcm1hw6fDo28xKDAmBgkqhkiG9w0B\nCQEWGWRpcmV0b3JpYS5udGlAdWZwaS5lZHUuYnIxETAPBgNVBAcTCFRlcmVzaW5h\nMQ8wDQYDVQQIFAZQaWF1w60xCzAJBgNVBAYTAkJSMRowGAYDVQQDExFjYWZldG9v\nbHMudWZwaS5icjAeFw0xNDExMTQxMzAzMTdaFw0xOTExMTMxMzAzMTdaMIHdMS4w\nLAYDVQQKFCVVRlBJIC0gVW5pdmVyc2lkYWRlIEZlZGVyYWwgZG8gUGlhdcOtMTQw\nMgYDVQQLFCtOVEkgLSBOw7pjbGVvIGRlIFRlY25vbG9naWEgZGEgSW5mb3JtYcOn\nw6NvMSgwJgYJKoZIhvcNAQkBFhlkaXJldG9yaWEubnRpQHVmcGkuZWR1LmJyMREw\nDwYDVQQHEwhUZXJlc2luYTEPMA0GA1UECBQGUGlhdcOtMQswCQYDVQQGEwJCUjEa\nMBgGA1UEAxMRY2FmZXRvb2xzLnVmcGkuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQCqSNE0nKTN/6lhDB8H4elZGeRVyD6Usj/CNCMI19yM15IWxdFV\no8KtbNUnoOUydgzWzGSn1v5Z7kHn+3g/3Zcz5l4Uu8UR3mRuLnQmUCoUtVDFUGMs\nl0n0C9TEyfnltACH2bDgA0xvRTSJhwHbk84nq9aPEK5BHrzFXi2eqBg6Tz93b32l\nfF5l3xUw99qx9rPOi/V9rZqql2tvx2pf7r9EwmbvV3ecEew8m47LmLFGsTccdhLw\nrnYRqHn0ZjQ0EXcSl5qsOMIj9bYpWYwkTqQ20wOSrxyM4YtkKxvuwRv+4ulafRLF\n3s09zpWRHM3mbV4V7h1AHevPV3L2eARr4ZCPAgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBAAmsgsRWIlUth927g9UcnA1rT4LHc78ZV6AnJniQOLo+rsDqvOQ+lTN00/q0\noKfhaScSzslE2YPG6VTyXsQEWOT/q0A+3110mWm3JphWsvCeik3nnzdQpXJdsT/Q\n1MxWTsxG3Xtueak/T1Nq3XVkaTSD5IdyDIKXUrHQ2OWlWurGw8/YBYTF2fq00OnI\n72aHstdeUOvFROEhdo4tEoP6uvXwNyzs69Uy6oTavBJCAKRQ17LuQixqeSWikIgu\nNXq23/pXhWb/nnrVc7SE/WNAWq7Wah2W1ZRuQ09HyRJ3M8JW1GrOjn+hZYSCne+x\nHBWX1bzoumpjN3JxtpmDWihKENM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufpi.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafetools.ufpi.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafetools.ufpi.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafetools.ufpi.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafetools.ufpi.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafetools.ufpi.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafetools.ufpi.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafetools.ufpi.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafetools.ufpi.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufpi.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufpi.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufpi.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFPI - Universidade Federal do Piaui"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFPI - Universidade Federal do Piaui"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFPI - Universidade Federal do Piaui"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFPI - Universidade Federal do Piaui"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEMDCCAxgCAQAwDQYJKoZIhvcNAQEFBQAwgd0xLjAsBgNVBAoUJVVGUEkgLSBV\nbml2ZXJzaWRhZGUgRmVkZXJhbCBkbyBQaWF1w60xNDAyBgNVBAsUK05USSAtIE7D\numNsZW8gZGUgVGVjbm9sb2dpYSBkYSBJbmZvcm1hw6fDo28xKDAmBgkqhkiG9w0B\nCQEWGWRpcmV0b3JpYS5udGlAdWZwaS5lZHUuYnIxETAPBgNVBAcTCFRlcmVzaW5h\nMQ8wDQYDVQQIFAZQaWF1w60xCzAJBgNVBAYTAkJSMRowGAYDVQQDExFjYWZldG9v\nbHMudWZwaS5icjAeFw0xNDExMTQxMzAzMTdaFw0xOTExMTMxMzAzMTdaMIHdMS4w\nLAYDVQQKFCVVRlBJIC0gVW5pdmVyc2lkYWRlIEZlZGVyYWwgZG8gUGlhdcOtMTQw\nMgYDVQQLFCtOVEkgLSBOw7pjbGVvIGRlIFRlY25vbG9naWEgZGEgSW5mb3JtYcOn\nw6NvMSgwJgYJKoZIhvcNAQkBFhlkaXJldG9yaWEubnRpQHVmcGkuZWR1LmJyMREw\nDwYDVQQHEwhUZXJlc2luYTEPMA0GA1UECBQGUGlhdcOtMQswCQYDVQQGEwJCUjEa\nMBgGA1UEAxMRY2FmZXRvb2xzLnVmcGkuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQCqSNE0nKTN/6lhDB8H4elZGeRVyD6Usj/CNCMI19yM15IWxdFV\no8KtbNUnoOUydgzWzGSn1v5Z7kHn+3g/3Zcz5l4Uu8UR3mRuLnQmUCoUtVDFUGMs\nl0n0C9TEyfnltACH2bDgA0xvRTSJhwHbk84nq9aPEK5BHrzFXi2eqBg6Tz93b32l\nfF5l3xUw99qx9rPOi/V9rZqql2tvx2pf7r9EwmbvV3ecEew8m47LmLFGsTccdhLw\nrnYRqHn0ZjQ0EXcSl5qsOMIj9bYpWYwkTqQ20wOSrxyM4YtkKxvuwRv+4ulafRLF\n3s09zpWRHM3mbV4V7h1AHevPV3L2eARr4ZCPAgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBAAmsgsRWIlUth927g9UcnA1rT4LHc78ZV6AnJniQOLo+rsDqvOQ+lTN00/q0\noKfhaScSzslE2YPG6VTyXsQEWOT/q0A+3110mWm3JphWsvCeik3nnzdQpXJdsT/Q\n1MxWTsxG3Xtueak/T1Nq3XVkaTSD5IdyDIKXUrHQ2OWlWurGw8/YBYTF2fq00OnI\n72aHstdeUOvFROEhdo4tEoP6uvXwNyzs69Uy6oTavBJCAKRQ17LuQixqeSWikIgu\nNXq23/pXhWb/nnrVc7SE/WNAWq7Wah2W1ZRuQ09HyRJ3M8JW1GrOjn+hZYSCne+x\nHBWX1bzoumpjN3JxtpmDWihKENM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFPI - Universidade Federal do Piaui"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFPI - Universidade Federal do Piaui"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufpi.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufpi.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFPI - Univerisdade Federal do Piaui"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFPI - Univerisdade Federal do Piaui"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:nyu.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tte3@nyu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tracy Edappara"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "gwc1@nyu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gary Chapman"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "yy27@nyu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Yavor Yanakiev"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:nyu.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.nyu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.nyu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE6DCCA9CgAwIBAgIJAI2V7DmlgLQ1MA0GCSqGSIb3DQEBBQUAMIGoMQswCQYD\nVQQGEwJVUzERMA8GA1UECBMITmV3IFlvcmsxETAPBgNVBAcTCE5ldyBZb3JrMRww\nGgYDVQQKExNOZXcgWW9yayBVbml2ZXJzaXR5MQwwCgYDVQQLEwNJVFMxIjAgBgNV\nBAMTGXVybjptYWNlOmluY29tbW9uOm55dS5lZHUxIzAhBgkqhkiG9w0BCQEWFGlk\nbS5zZXJ2aWNlc0BueXUuZWR1MB4XDTEyMDgxMDIxMzUxNloXDTIyMDgwODIxMzUx\nNlowgagxCzAJBgNVBAYTAlVTMREwDwYDVQQIEwhOZXcgWW9yazERMA8GA1UEBxMI\nTmV3IFlvcmsxHDAaBgNVBAoTE05ldyBZb3JrIFVuaXZlcnNpdHkxDDAKBgNVBAsT\nA0lUUzEiMCAGA1UEAxMZdXJuOm1hY2U6aW5jb21tb246bnl1LmVkdTEjMCEGCSqG\nSIb3DQEJARYUaWRtLnNlcnZpY2VzQG55dS5lZHUwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDfb4botPJTcMPCLDenzHqWAOJFenUGEAL33ROzA687b73F\ng72Fnlh2Pp7HNhbB3+cQjsQODitjFdUVQgX8EAP3xMZAGKU2M/0ZGfnGokj5oiU0\n80ii6zOzEDUCkulR5CW6p+mgdoCYXs3b9riwm1X5pqi/4ZbCKP+K6TiSBOGWxtCs\nBp7mWFdJlWUT6a3VRdoYmUUQEOJfrTyT8CW0dk0DGToWe2j3taxGT89E3VA6w5Gk\ntQK5sxllEAVQ23fiMdouDAtr4gDNvOSwtYUuDwh/Ppl/lAMwjU+dv08pNuJR9drF\njYM0jKoiPsG9AdEwkFSGQb0IB1wt8+wAeTCXIKMrAgMBAAGjggERMIIBDTAdBgNV\nHQ4EFgQUleQurEqBxsOHqhL90hCiWMKIvx0wgd0GA1UdIwSB1TCB0oAUleQurEqB\nxsOHqhL90hCiWMKIvx2hga6kgaswgagxCzAJBgNVBAYTAlVTMREwDwYDVQQIEwhO\nZXcgWW9yazERMA8GA1UEBxMITmV3IFlvcmsxHDAaBgNVBAoTE05ldyBZb3JrIFVu\naXZlcnNpdHkxDDAKBgNVBAsTA0lUUzEiMCAGA1UEAxMZdXJuOm1hY2U6aW5jb21t\nb246bnl1LmVkdTEjMCEGCSqGSIb3DQEJARYUaWRtLnNlcnZpY2VzQG55dS5lZHWC\nCQCNlew5pYC0NTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQDC7w4Z\nzk/qgpNhmee03UxGOixlFn+UaY6QEdjBIO3O3m20hEWLp4Pa+TBvsSlsFWQh1Wlf\nngZfgK/MjZykdg0+bGwRT9JMcZbg9xeuznOCEenuTMJtDriquzTlN6ms2emelgBe\nfiQOpDC/hsX3Hr0miTgVq6xb3mRxUpMSRFAQqgkmV403fQ+kd8FcsSy1jjS5XLwX\niB30XNuA1VE0HlWs4l4DV1G/24Jc1Hr7iUyiZMfZlZkEuju7POrmxtU0RZ00Dyis\ntzuHg2kl7HlTBftOs8FDxM3sqityZScutQmvMe6NCy/3nSFyHCQFPfu66bycssYG\nR+4YvtjCZRUas5kS"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nyu.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "New York University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "New York University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nyu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "New York University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.polytechnique.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@polytechnique.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.polytechnique.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-02-04T14:05:02Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.polytechnique.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.polytechnique.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.polytechnique.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "polytechnique.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.polytechnique.edu/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IDP Ecole Polytechnique - Palaiseau"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IDP Ecole Polytechnique - Palaiseau"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Polytechnique - Palaiseau"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Polytechnique - Palaiseau"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUenAlQJGY5nvpRbOTuDq3P/4fTVYwDQYJKoZIhvcNAQEF\nBQAwHzEdMBsGA1UEAwwUaWRwLnBvbHl0ZWNobmlxdWUuZnIwHhcNMTUwMTI5MTUy\nMzQwWhcNMzUwMTI5MTUyMzQwWjAfMR0wGwYDVQQDDBRpZHAucG9seXRlY2huaXF1\nZS5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMwd3SB1Lwii2xUU\nyoq487drsFL4bpi4zVj/iwV6mYXBfV/bVQrW6PMxfr8T5OIHCRNe3CvAIS0LIlKb\njLoqaorF4D9daJSR+S/v5qSm7nFmjp0O4SxommuOjHgn1Y/gwUOQrMsrREo71CeR\n7WqXsdvxAs35OO0fit0cTavQjyuiYT45uvvInMHNw3iClh0omueHvP02HYZBFW4M\nLzKLtC6mmz+4PbFXvXrkexwMz2+U0+k+ctP9ubBHIcLJrMULeemEOpbMlY9JAXAf\n7JqV9dOI97DeZec3kE+O3YgaTxZ3a5a0CVdR9Bwjozx8FvPp3FCloVER3OOOkJc5\n2aQYR1sCAwEAAaNvMG0wHQYDVR0OBBYEFK85QKHZCd+M/76TQtYrhl5Kk6+TMEwG\nA1UdEQRFMEOCFGlkcC5wb2x5dGVjaG5pcXVlLmZyhitodHRwczovL2lkcC5wb2x5\ndGVjaG5pcXVlLmZyL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBBQUAA4IBAQAl\nbSG2vkSOBwry4bM0iju7l7mTV0+xWjEA9hFWBc7cFweQWwKVuw6KseQnGm1iVS1K\nLIH8lpiWW6XD/GPhqNia3iyG4OLuX91bnT1a5onOIt+bLise5bc+Q5oSe+vF3HBb\n6rlumrLdMDn8QFgXhQyVMIbj7br12vn7/0bCyYedqDgDsmr4Vjk9D6oV9ZBjofnV\npK8FvrHJzFKiz/jLrrhIFuGOXG6oiitYVvc09Mv6a00sMjpDViwtHMVXmNkQN+HZ\nsqcrjIGFkPOyHZqYr2I9f4VKX7/FZn63ID4N2WdU+e3D6ACnJiLpe5tG9vwNPfk5\nrmrzBJcTpS6kyxMBlKCw"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ecole Polytechnique - Palaiseau"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.polytechnique.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ecole Polytechnique - Palaiseau"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.tresham.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mewes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:smewes@tresham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stuart"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Foster"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mfoster@tresham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.tresham.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-05-22T08:15:19Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDojCCAooCCQC38OS+e7lEUzANBgkqhkiG9w0BAQUFADCBkjELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxGTAXBgNVBAgMEE5vcnRoYW1wdG9uc2hpcmUxEjAQBgNVBAcMCUtldHRlcmlu\n\t\t\t\t\t\tZzE4MDYGA1UECgwvVHJlc2hhbSBDb2xsZWdlIG9mIEZ1cnRoZXIgYW5kIEhpZ2hl\n\t\t\t\t\t\tciBFZHVjYXRpb24xGjAYBgNVBAMMEWlkcC50cmVzaGFtLmFjLnVrMB4XDTEzMDUx\n\t\t\t\t\t\tNzA3NDIxOVoXDTMzMDUxMjA3NDIxOVowgZIxCzAJBgNVBAYTAkdCMRkwFwYDVQQI\n\t\t\t\t\t\tDBBOb3J0aGFtcHRvbnNoaXJlMRIwEAYDVQQHDAlLZXR0ZXJpbmcxODA2BgNVBAoM\n\t\t\t\t\t\tL1RyZXNoYW0gQ29sbGVnZSBvZiBGdXJ0aGVyIGFuZCBIaWdoZXIgRWR1Y2F0aW9u\n\t\t\t\t\t\tMRowGAYDVQQDDBFpZHAudHJlc2hhbS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQAD\n\t\t\t\t\t\tggEPADCCAQoCggEBAMDNPjJPLfGBvb57Jln2kd2w6QLzt//vhZudjZZrKhQirlVD\n\t\t\t\t\t\t8GAgVU7XYrZeHQLzLXQF1j2fZnLrzkRPFL15Ru9qkFeftSabMn1TeegKibLbUrFk\n\t\t\t\t\t\tpMcUfFCs4j6ybNFt6ZCfIk426xTRFXVuLKSegPoQYj+dsTvlPIGt8SsRC/ydqP9C\n\t\t\t\t\t\tIzwGwE6CjZPIiAa7Q9MyNs8G5tqZ9C7YPWy8ArG+SZ9Xt1iyXV4lerwmf2D147oR\n\t\t\t\t\t\tY03saO6fNSCknSBjAA6UP3xAE5HimHKwjvl5MXF1H0puVG5P3b+xfCT2yCMhbsRj\n\t\t\t\t\t\tYJK4HSzYdCnRR91cxB8EISYRcbtVo2lKrsLw+LcCAwEAATANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEALJNw1SaVhAsHqu2ENnh9KNWDuaUA/b9k2M9nNSx4LWa9Lpkw1+qdjZQ+\n\t\t\t\t\t\ttfVRIb2E2AJp9+7RuWKN9Xa6l0VenbumDeOpwhp8LooiZR+Qt9pIg28Be9bYics7\n\t\t\t\t\t\t4qnQDA2b0HiLEMcM+xW0HCp5j0q9+RZPF7rtqdu/Yw6qtIkmWe/L6OqRUfVfTy70\n\t\t\t\t\t\tekbD3d5N/xvhGGKETyV3Yp0Ayw8aGjG1a4WCUn+r/IY3JuKjOq+QOMb5lkl0I4ol\n\t\t\t\t\t\t6T7XDYHlahNcl1lrv1oMxKfQDO8ISaLr/BREEmKQBKOpZpxfrJ0ISW5f60ndYkRr\n\t\t\t\t\t\tZta8/DXmlXmxEaTCt9czo3528Y0HQQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tresham.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.tresham.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.tresham.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.tresham.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.tresham.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.tresham.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.tresham.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.tresham.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.tresham.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.tresham.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.tresham.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.tresham.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tresham.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDojCCAooCCQC38OS+e7lEUzANBgkqhkiG9w0BAQUFADCBkjELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxGTAXBgNVBAgMEE5vcnRoYW1wdG9uc2hpcmUxEjAQBgNVBAcMCUtldHRlcmlu\n\t\t\t\t\t\tZzE4MDYGA1UECgwvVHJlc2hhbSBDb2xsZWdlIG9mIEZ1cnRoZXIgYW5kIEhpZ2hl\n\t\t\t\t\t\tciBFZHVjYXRpb24xGjAYBgNVBAMMEWlkcC50cmVzaGFtLmFjLnVrMB4XDTEzMDUx\n\t\t\t\t\t\tNzA3NDIxOVoXDTMzMDUxMjA3NDIxOVowgZIxCzAJBgNVBAYTAkdCMRkwFwYDVQQI\n\t\t\t\t\t\tDBBOb3J0aGFtcHRvbnNoaXJlMRIwEAYDVQQHDAlLZXR0ZXJpbmcxODA2BgNVBAoM\n\t\t\t\t\t\tL1RyZXNoYW0gQ29sbGVnZSBvZiBGdXJ0aGVyIGFuZCBIaWdoZXIgRWR1Y2F0aW9u\n\t\t\t\t\t\tMRowGAYDVQQDDBFpZHAudHJlc2hhbS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQAD\n\t\t\t\t\t\tggEPADCCAQoCggEBAMDNPjJPLfGBvb57Jln2kd2w6QLzt//vhZudjZZrKhQirlVD\n\t\t\t\t\t\t8GAgVU7XYrZeHQLzLXQF1j2fZnLrzkRPFL15Ru9qkFeftSabMn1TeegKibLbUrFk\n\t\t\t\t\t\tpMcUfFCs4j6ybNFt6ZCfIk426xTRFXVuLKSegPoQYj+dsTvlPIGt8SsRC/ydqP9C\n\t\t\t\t\t\tIzwGwE6CjZPIiAa7Q9MyNs8G5tqZ9C7YPWy8ArG+SZ9Xt1iyXV4lerwmf2D147oR\n\t\t\t\t\t\tY03saO6fNSCknSBjAA6UP3xAE5HimHKwjvl5MXF1H0puVG5P3b+xfCT2yCMhbsRj\n\t\t\t\t\t\tYJK4HSzYdCnRR91cxB8EISYRcbtVo2lKrsLw+LcCAwEAATANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEALJNw1SaVhAsHqu2ENnh9KNWDuaUA/b9k2M9nNSx4LWa9Lpkw1+qdjZQ+\n\t\t\t\t\t\ttfVRIb2E2AJp9+7RuWKN9Xa6l0VenbumDeOpwhp8LooiZR+Qt9pIg28Be9bYics7\n\t\t\t\t\t\t4qnQDA2b0HiLEMcM+xW0HCp5j0q9+RZPF7rtqdu/Yw6qtIkmWe/L6OqRUfVfTy70\n\t\t\t\t\t\tekbD3d5N/xvhGGKETyV3Yp0Ayw8aGjG1a4WCUn+r/IY3JuKjOq+QOMb5lkl0I4ol\n\t\t\t\t\t\t6T7XDYHlahNcl1lrv1oMxKfQDO8ISaLr/BREEmKQBKOpZpxfrJ0ISW5f60ndYkRr\n\t\t\t\t\t\tZta8/DXmlXmxEaTCt9czo3528Y0HQQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Tresham College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tresham.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Tresham College of Further and Higher Education"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://trshibtest.falmouth.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pellow"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve.pellow@fxplus.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pellow"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve.pellow@fxplus.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://trshibtest.falmouth.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-03-24T16:06:57Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://trshibtest.falmouth.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://trshibtest.falmouth.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://trshibtest.falmouth.ac.uk/idp/profile/SAML2/POST-SimpleSign/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://trshibtest.falmouth.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://trshibtest.falmouth.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://trshibtest.falmouth.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://trshibtest.falmouth.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://trshibtest.falmouth.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://trshibtest.falmouth.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://trshibtest.falmouth.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "falmouth.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fxplus.ac.uk"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Falmouth University & FXPlus IdP"
                  }
                ],
                "logo": [
                  {
                    "text": "https://trshibtest.falmouth.ac.uk/idp/images/falmouth-university-logo-print.png",
                    "height": "80",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Falmouth University TEST"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVALQiK8QYmXH3vEarjOmgkNsvKZyyMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCQxIjAgBgNVBAMTGXNoaWJib2xldGguZmFsbW91dGguYWMudWswHhcNMTQx\n\t\t\t\t\t\tMTExMTUxMzMxWhcNMzQxMTExMTUxMzMxWjAkMSIwIAYDVQQDExlzaGliYm9sZXRo\n\t\t\t\t\t\tLmZhbG1vdXRoLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\thtyRP37lfHCQSvTtB09QGwRMXaHxV0KcAyDm2haJWRVnS/Q2nCXkDH4N0l3nsb8S\n\t\t\t\t\t\tibeizS3gnWkJM52C4VXm1Dn/4jZEu0tT/yrjfz4LOWx6pPluUg29euLr7ICLdPAv\n\t\t\t\t\t\tfjH0iQ4Ah2mVc0iEwtFhrnDCV1uGPgxsu8DpiV0TrpoqTlEIzcB9z6Y4ha7yuZ2j\n\t\t\t\t\t\tp0SP1piRoFBoeXeRDJ3D4Lprw8YV1ZKLOZaeyI8n8KIwspLZLcAqIkGoJ0k1u1Fl\n\t\t\t\t\t\tOcqRD2xPzQ+CgOtzzvSIOrPD0yKhuwb1zJ66cu2cpRdITRnrg2ayP/gXiF+LAhTJ\n\t\t\t\t\t\tybc9lDB//HyWDrj9iU00cwIDAQABo3kwdzBWBgNVHREETzBNghlzaGliYm9sZXRo\n\t\t\t\t\t\tLmZhbG1vdXRoLmFjLnVrhjBodHRwczovL3NoaWJib2xldGguZmFsbW91dGguYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFDl7aG6kieISm3+HL81qMYelebh9\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQBvm0t4OJ4W610vCQDGC5irYM4JqFYItWAL783e\n\t\t\t\t\t\traMoAAhoQ37r+qfeXeZXox0tpz1A2Jt//4ub46//AOksCPbAa22mWoHyFxcJcjRR\n\t\t\t\t\t\tZR17kXkAaopgrcUhrrPSt+TFy2i2CHnuWcR1ypqyPj6nq5RfgptUYkJEVe4fwF6n\n\t\t\t\t\t\tzjv7yp0173zZckOhbclz2yer9jl92eYG0eTVtOY43TILPkc55e5JDd72A2YfqLSz\n\t\t\t\t\t\t8PF/30MxntDXnOWtFXYktXQW7u4cIEVFcOytK1kap6TQhjDVHulpPvFocfGj/OVp\n\t\t\t\t\t\tVk5or0/R1H+xdwevs2D+MnCZfXq8lZPgZHgthYP/lhIhlvvB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Falmouth University TEST"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.falmouth.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Falmouth University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.rcpsych.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.rcpsych.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-07-29T15:43:27Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Journals of the Royal College of Psychiatrists"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rcpsych.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HighWire Press, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.highwire.org/applications/rcpsych/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.highwire.org/applications/rcpsych/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIJAMTRVlqTJ11lMA0GCSqGSIb3DQEBBQUAMIG+MQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBD\n\t\t\t\t\t\taXR5MRcwFQYDVQQKEw5IaWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUx\n\t\t\t\t\t\tIDAeBgNVBAMTF3NoaWJib2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkB\n\t\t\t\t\t\tFiZzaGliYm9sZXRoLWFkbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTAeFw0xNDA0\n\t\t\t\t\t\tMTUxOTQzMDNaFw0yNDA0MTIxOTQzMDNaMIG+MQswCQYDVQQGEwJVUzETMBEGA1UE\n\t\t\t\t\t\tCBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBDaXR5MRcwFQYDVQQKEw5I\n\t\t\t\t\t\taWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUxIDAeBgNVBAMTF3NoaWJi\n\t\t\t\t\t\tb2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkBFiZzaGliYm9sZXRoLWFk\n\t\t\t\t\t\tbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALPB99M9iWjentrddY/rLgzKn1X0j4Ao191iyiowBBt/r/pmn2oz\n\t\t\t\t\t\tfrbONkkTVBB++mNtiufK6jyKnBM5mffPOkXHRo+K1DQec7TvpQ1PmLv/BpBgPrr9\n\t\t\t\t\t\tldViOSUnYJuB0IgJVV8oylgeH2Ay0XRkNPlBUjBA2fUPWVpXcvFe+aD2tLdVR9uO\n\t\t\t\t\t\tXvfTMxAEGqzxTU+OxO6pW2sBXNBmGvZQ0TRyovQh5+pTURY/lm0V/iWvRmRe51WE\n\t\t\t\t\t\tO/nhYyvRuMmNj8EL38o10S9TXuCkVzY00hK5cclaFge7gz/tfjmadVVcbe8xCVxc\n\t\t\t\t\t\tnb1lhmt1kH2XtKvU5hyZMTO+VUfXQvqcQyECAwEAAaN7MHkwCQYDVR0TBAIwADAs\n\t\t\t\t\t\tBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYD\n\t\t\t\t\t\tVR0OBBYEFJpUZq/XaW9/bPvjffkxX0IDvuPiMB8GA1UdIwQYMBaAFJpUZq/XaW9/\n\t\t\t\t\t\tbPvjffkxX0IDvuPiMA0GCSqGSIb3DQEBBQUAA4IBAQCq/FF56ZB1cL3KbniEJP99\n\t\t\t\t\t\tU9wTD6KpOrWxvqNbUSV1cefLf5cYHonOjy6oAJSSBSNuP7U5Q//0tXtkvlJoqGUY\n\t\t\t\t\t\tvqngmeg9wLZ/Fla3tXcDdTj0n1F+NZOx9vBDacIk0Ua4aHXDA4bdytzkV1QyZDRq\n\t\t\t\t\t\tQ8vq7RoQ8E5IF7Cll+kt2dZXQk8o6Qp3w2ppoMRtYdKOQassqn+V1MYcMPgdxZkS\n\t\t\t\t\t\tDrcgzktR/JMb5OmPrp4mSy1OWDGrFvUIigsLBPZV9tw1f7y42lnbmQas3RCS30yr\n\t\t\t\t\t\tCtUPT/PQDkCdBRViGmmMkYwjdaOTiHOJveWtrVXu8vLvO36pqFF4Kft0pgqlfvAE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.highwire.org/applications/rcpsych/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.highwire.org/applications/rcpsych/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.highwire.org/applications/rcpsych/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.highwire.org/applications/rcpsych/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.teimes.gr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ilaridis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@teimes.gr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Panagiotis"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@teimes.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Technological Educational Institute of Messolonghi Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.teimes.gr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEZzCCA0+gAwIBAgIQVdiu+LQ1e98NKDokhhkKcDANBgkqhkiG9w0BAQUFADA2\n                            MQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n                            U1NMIENBMB4XDTEzMDUzMTAwMDAwMFoXDTE2MDUzMDIzNTk1OVowOzEhMB8GA1UE\n                            CxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRYwFAYDVQQDEw1pZHAudGVpbWVz\n                            LmdyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzbE8l+xoFqVZuFeG\n                            7k7A0STEWr356z4LEypiCZgtnXYAEsPdJgtUfLVoBJUJgka3SNAdrsBOITiIpbhx\n                            MyUwiVyEDgAgFN6Wp+SL6Rf6oomdkdy2uQ6COyJ3z+9zhiLEo+HsZe+TyMwnaoJr\n                            iXgRGaar3x57WLg4ljlZgMeRaS59w9J4BSq8v+pF9uhJmRuMf2QoMUhqaw9y9x9/\n                            v8lbTk/xNizMwTkf83MXqeAR2goT8wrNjtrBJguPwL/vEsKeXTilIdP3kAvWaVda\n                            mfQzhT9hXX4cXuUOzyKq/z57c6dAXDQAOZELuqYw8OsTsheKAnEZA3skCFqDPQmU\n                            4r/oMQIDAQABo4IBajCCAWYwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH6pDj\n                            ue0wHQYDVR0OBBYEFHTMEzcFNJFW+wMBl0baf+KkwVPuMA4GA1UdDwEB/wQEAwIF\n                            oDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAi\n                            BgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAxMC+g\n                            LaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNybDBt\n                            BggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVu\n                            YS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8vb2NzcC50\n                            Y3MudGVyZW5hLm9yZzAYBgNVHREEETAPgg1pZHAudGVpbWVzLmdyMA0GCSqGSIb3\n                            DQEBBQUAA4IBAQB6jKDy+7FTyLyqJj4KdyK4bmi2Apfw0EQS5n94kBGUdX3btuSb\n                            w9R4O17L4KPGHcBw+gXUTbFpKhU0vcxyfXBR7W1G80vWXK/c74ceiAsnsvgXK+h8\n                            Cq/NtoyRfAs4Tp/TeuDqz7Cokg15694T8TY3YZr2IdPmmYjajJUZlC0VmGZ8xpy8\n                            Stb0JnndVME7qsHMG+3JFnGDJ/hTQho9mXqrpGf/DhqYDIHvjAIgjSYUT59oz1Vr\n                            l2JbcEBafD9Vw3PvU7npUD0zCKoGxXOIS/euILZpRZpPpl0/P4eeGoF0mPn9yAjk\n                            oM+F3tyjZKVbapPixpkTOQrfv21F08UOTAVV"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "teimes.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.teimes.gr:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.teimes.gr:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.teimes.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.teimes.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.teimes.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.teimes.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.teimes.gr:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.teimes.gr:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "teimes.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEZzCCA0+gAwIBAgIQVdiu+LQ1e98NKDokhhkKcDANBgkqhkiG9w0BAQUFADA2\n                            MQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n                            U1NMIENBMB4XDTEzMDUzMTAwMDAwMFoXDTE2MDUzMDIzNTk1OVowOzEhMB8GA1UE\n                            CxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRYwFAYDVQQDEw1pZHAudGVpbWVz\n                            LmdyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzbE8l+xoFqVZuFeG\n                            7k7A0STEWr356z4LEypiCZgtnXYAEsPdJgtUfLVoBJUJgka3SNAdrsBOITiIpbhx\n                            MyUwiVyEDgAgFN6Wp+SL6Rf6oomdkdy2uQ6COyJ3z+9zhiLEo+HsZe+TyMwnaoJr\n                            iXgRGaar3x57WLg4ljlZgMeRaS59w9J4BSq8v+pF9uhJmRuMf2QoMUhqaw9y9x9/\n                            v8lbTk/xNizMwTkf83MXqeAR2goT8wrNjtrBJguPwL/vEsKeXTilIdP3kAvWaVda\n                            mfQzhT9hXX4cXuUOzyKq/z57c6dAXDQAOZELuqYw8OsTsheKAnEZA3skCFqDPQmU\n                            4r/oMQIDAQABo4IBajCCAWYwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH6pDj\n                            ue0wHQYDVR0OBBYEFHTMEzcFNJFW+wMBl0baf+KkwVPuMA4GA1UdDwEB/wQEAwIF\n                            oDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAi\n                            BgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAxMC+g\n                            LaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNybDBt\n                            BggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVu\n                            YS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8vb2NzcC50\n                            Y3MudGVyZW5hLm9yZzAYBgNVHREEETAPgg1pZHAudGVpbWVzLmdyMA0GCSqGSIb3\n                            DQEBBQUAA4IBAQB6jKDy+7FTyLyqJj4KdyK4bmi2Apfw0EQS5n94kBGUdX3btuSb\n                            w9R4O17L4KPGHcBw+gXUTbFpKhU0vcxyfXBR7W1G80vWXK/c74ceiAsnsvgXK+h8\n                            Cq/NtoyRfAs4Tp/TeuDqz7Cokg15694T8TY3YZr2IdPmmYjajJUZlC0VmGZ8xpy8\n                            Stb0JnndVME7qsHMG+3JFnGDJ/hTQho9mXqrpGf/DhqYDIHvjAIgjSYUT59oz1Vr\n                            l2JbcEBafD9Vw3PvU7npUD0zCKoGxXOIS/euILZpRZpPpl0/P4eeGoF0mPn9yAjk\n                            oM+F3tyjZKVbapPixpkTOQrfv21F08UOTAVV"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Technological Educational Institute of Western Greece"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03b9\u03ba\u03cc \u0395\u03ba\u03c0\u03b1\u03b9\u03b4\u03b5\u03c5\u03c4\u03b9\u03ba\u03cc \u038a\u03b4\u03c1\u03c5\u03bc\u03b1 \u0394\u03c5\u03c4\u03b9\u03ba\u03ae\u03c2 \u0395\u03bb\u03bb\u03ac\u03b4\u03b1\u03c2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.teimes.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.teimes.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Technological Educational Institute of Western Greece"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03b9\u03ba\u03cc \u0395\u03ba\u03c0\u03b1\u03b9\u03b4\u03b5\u03c5\u03c4\u03b9\u03ba\u03cc \u038a\u03b4\u03c1\u03c5\u03bc\u03b1 \u0394\u03c5\u03c4\u03b9\u03ba\u03ae\u03c2 \u0395\u03bb\u03bb\u03ac\u03b4\u03b1\u03c2"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idpcafe.usp.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "DTI - Departamento de Tecnologia da Informacao"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "consulta@usp.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idpcafe.usp.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEADCCAugCAQAwDQYJKoZIhvcNAQELBQAwgcUxIjAgBgNVBAoTGVVOSVZFUlNJ\nREFERSBERSBTQU8gUEFVTE8xNTAzBgNVBAsTLFNVUEVSSU5URU5ERU5DSUEgREUg\nVEVDTk9MT0dJQSBEQSBJTkZPUk1BQ0FPMRowGAYJKoZIhvcNAQkBFgtzY252QHVz\ncC5icjESMBAGA1UEBxMJU0FPIFBBVUxPMRIwEAYDVQQIEwlTQU8gUEFVTE8xCzAJ\nBgNVBAYTAkJSMRcwFQYDVQQDEw5pZHBjYWZlLnVzcC5icjAeFw0xNDExMDQyMzU5\nMDNaFw0xOTExMDMyMzU5MDNaMIHFMSIwIAYDVQQKExlVTklWRVJTSURBREUgREUg\nU0FPIFBBVUxPMTUwMwYDVQQLEyxTVVBFUklOVEVOREVOQ0lBIERFIFRFQ05PTE9H\nSUEgREEgSU5GT1JNQUNBTzEaMBgGCSqGSIb3DQEJARYLc2NudkB1c3AuYnIxEjAQ\nBgNVBAcTCVNBTyBQQVVMTzESMBAGA1UECBMJU0FPIFBBVUxPMQswCQYDVQQGEwJC\nUjEXMBUGA1UEAxMOaWRwY2FmZS51c3AuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQC2k4nQeMwb/eT3VPbza4lVzks+rAnc9t5rc2YmWOYYk+wMBEU7\nitfeBxaXpetPRMubgW3SrQO7DLwBEfoQQ0nj0gy9zusJdeYZU/BlKwyCgs2ScGqn\nMki+TJOieVhOumPSOULNOE+xEzAqjS1V55H6DkXklte8F6UjNyIyd9x5id58prJK\nZpClqQMorVrhxF3A99jQK4Pupcqhy+mQOoA51Cge4ZubdlXIrzk0SFwwS9XB8//S\nxeHyN3dTiXLafJ+WfDx6uBKYQbzRKT2QC/KWbL03Rxd2wmoldNHJXDlseq++UFYY\nkRA9vE92sg40zwjqnO/5V7AdpJ38CNKAEZ41AgMBAAEwDQYJKoZIhvcNAQELBQAD\nggEBAAAd8mF0jClrCZ46eYceZ95KA+XfkY0ViAyHW/13wc07M7gGgurLQgYHdMNZ\nMYJoyB1HrwdliS/ZpfEspWhtvnmMRNLYOnghDlFE5pSRo53/qtQ2VqwvZv6xtcnx\nuMdDVtbXn8txZi6T3n6nNn/JwYA3ANUJKHfo0eE+E5E+Xdl7APBeOZLYdjhQykzM\nutKY4CRyqBVaJhpmf1A8QzmAR+iXoI2Zh4U2xO8sWUUuxOEP1fsv1rs2VorQHrBw\nmWthxf1cxDLaWMV6/uWFy+iKPiHKDB4X1NFOEXU7teIz8LgzsGiF/PPoMeNRCfn1\nXmViErkqVYyvS+Fpeslb5K1Zlyk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "usp.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idpcafe.usp.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idpcafe.usp.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idpcafe.usp.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idpcafe.usp.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idpcafe.usp.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idpcafe.usp.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idpcafe.usp.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idpcafe.usp.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "usp.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.usp.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.usp.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "USP - Universidade de Sao Paulo"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "USP - Universidade de Sao Paulo"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "USP - Universidade de Sao Paulo"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "USP - Universidade de Sao Paulo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEADCCAugCAQAwDQYJKoZIhvcNAQELBQAwgcUxIjAgBgNVBAoTGVVOSVZFUlNJ\nREFERSBERSBTQU8gUEFVTE8xNTAzBgNVBAsTLFNVUEVSSU5URU5ERU5DSUEgREUg\nVEVDTk9MT0dJQSBEQSBJTkZPUk1BQ0FPMRowGAYJKoZIhvcNAQkBFgtzY252QHVz\ncC5icjESMBAGA1UEBxMJU0FPIFBBVUxPMRIwEAYDVQQIEwlTQU8gUEFVTE8xCzAJ\nBgNVBAYTAkJSMRcwFQYDVQQDEw5pZHBjYWZlLnVzcC5icjAeFw0xNDExMDQyMzU5\nMDNaFw0xOTExMDMyMzU5MDNaMIHFMSIwIAYDVQQKExlVTklWRVJTSURBREUgREUg\nU0FPIFBBVUxPMTUwMwYDVQQLEyxTVVBFUklOVEVOREVOQ0lBIERFIFRFQ05PTE9H\nSUEgREEgSU5GT1JNQUNBTzEaMBgGCSqGSIb3DQEJARYLc2NudkB1c3AuYnIxEjAQ\nBgNVBAcTCVNBTyBQQVVMTzESMBAGA1UECBMJU0FPIFBBVUxPMQswCQYDVQQGEwJC\nUjEXMBUGA1UEAxMOaWRwY2FmZS51c3AuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQC2k4nQeMwb/eT3VPbza4lVzks+rAnc9t5rc2YmWOYYk+wMBEU7\nitfeBxaXpetPRMubgW3SrQO7DLwBEfoQQ0nj0gy9zusJdeYZU/BlKwyCgs2ScGqn\nMki+TJOieVhOumPSOULNOE+xEzAqjS1V55H6DkXklte8F6UjNyIyd9x5id58prJK\nZpClqQMorVrhxF3A99jQK4Pupcqhy+mQOoA51Cge4ZubdlXIrzk0SFwwS9XB8//S\nxeHyN3dTiXLafJ+WfDx6uBKYQbzRKT2QC/KWbL03Rxd2wmoldNHJXDlseq++UFYY\nkRA9vE92sg40zwjqnO/5V7AdpJ38CNKAEZ41AgMBAAEwDQYJKoZIhvcNAQELBQAD\nggEBAAAd8mF0jClrCZ46eYceZ95KA+XfkY0ViAyHW/13wc07M7gGgurLQgYHdMNZ\nMYJoyB1HrwdliS/ZpfEspWhtvnmMRNLYOnghDlFE5pSRo53/qtQ2VqwvZv6xtcnx\nuMdDVtbXn8txZi6T3n6nNn/JwYA3ANUJKHfo0eE+E5E+Xdl7APBeOZLYdjhQykzM\nutKY4CRyqBVaJhpmf1A8QzmAR+iXoI2Zh4U2xO8sWUUuxOEP1fsv1rs2VorQHrBw\nmWthxf1cxDLaWMV6/uWFy+iKPiHKDB4X1NFOEXU7teIz8LgzsGiF/PPoMeNRCfn1\nXmViErkqVYyvS+Fpeslb5K1Zlyk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "USP - Universidade de Sao Paulo"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "USP - Universidade de Sao Paulo"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.usp.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.usp.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "USP - Universidade de Sao Paulo"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "USP - Universidade de Sao Paulo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://testidp1.ntu.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cross"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:richard.cross@ntu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hallam"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ITSShibbolethTechnical@ntu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lee"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://testidp1.ntu.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-12-10T18:01:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEcjCCA1qgAwIBAgIRAPTb+rk6jOmXCD8nphThP4UwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzA1MjkwMDAwMDBaFw0xNjA1MjgyMzU5NTlaMEAxITAfBgNV\n\t\t\t\t\t\tBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEbMBkGA1UEAxMSdGVzdGlkcDEu\n\t\t\t\t\t\tbnR1LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1ORxXKiX\n\t\t\t\t\t\tDYnYrh0URq0YrQvXUrUABDoA0oRStRQGmwgYBNHD4fTid9qJxRAXddoOxWHR3eLM\n\t\t\t\t\t\t+LV7VAMuZvzNq4x5LXFhqkfRHPXuM1GwMT8t8kHIsgv3xlxf3xjAjyHGswnlv8kU\n\t\t\t\t\t\t1uMiCj1u+q59WTt7VYGQkdiPYthy9pp6RCCWLvoeH2fpsE8Zfni/8YqkSLR0o7XX\n\t\t\t\t\t\tFSw2BvgqNlxrdQtiVKSaAKqv6MtYLQfsPAf7KyHXcOn/Wa79zsyh7Gr5tkMHWCyO\n\t\t\t\t\t\tz6/uA1UeHm+/00mCLJ2HxwGA/mQpiWmuTUtZRNyhIl6RCCpQvYmEYLcyTjXXgyCZ\n\t\t\t\t\t\tbtwqLlDrmrNeZwIDAQABo4IBbzCCAWswHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsr\n\t\t\t\t\t\tN1dH6pDjue0wHQYDVR0OBBYEFCi+rC8oIr09eQTC9ySKAjItBWkrMA4GA1UdDwEB\n\t\t\t\t\t\t/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEF\n\t\t\t\t\t\tBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8E\n\t\t\t\t\t\tMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENB\n\t\t\t\t\t\tLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNz\n\t\t\t\t\t\tLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8v\n\t\t\t\t\t\tb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJ0ZXN0aWRwMS5udHUuYWMu\n\t\t\t\t\t\tdWswDQYJKoZIhvcNAQEFBQADggEBAFUt0QpPH6WC/+XltCugdJr76oMYrwjNsOtK\n\t\t\t\t\t\tHakoQSRsf4uYg66wmJKnHhxEyFZeogB6cMAMe06PsaUB/86X35gkxFm2uMJGfsJB\n\t\t\t\t\t\tiE67ALWlN2hwWDePC/07Olud9e8Nq4u473yKLqsS7S3uY6aFYLXE9rWMXq2fIBj8\n\t\t\t\t\t\tiQFeWXQe0VfuG2l3k0UGs5Nty4UwRzLABv5sTmpnm8PJmDO5oAXmZg+lNYhRHkMO\n\t\t\t\t\t\tkdhsjKI5gAW+1PdlGwcHdx98KyqoVSLQw9HcWAE7Wo7MoKCsFrnyBqC/8N+k+8tm\n\t\t\t\t\t\ts7Obnw4aOinAMW06Fka45GA6qoSnJVj3y741U5pHrw0fWtVRZ3A="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ntu.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://testidp1.ntu.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://testidp1.ntu.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://testidp1.ntu.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://testidp1.ntu.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://testidp1.ntu.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://testidp1.ntu.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://testidp1.ntu.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://testidp1.ntu.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ntu.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEcjCCA1qgAwIBAgIRAPTb+rk6jOmXCD8nphThP4UwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzA1MjkwMDAwMDBaFw0xNjA1MjgyMzU5NTlaMEAxITAfBgNV\n\t\t\t\t\t\tBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEbMBkGA1UEAxMSdGVzdGlkcDEu\n\t\t\t\t\t\tbnR1LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1ORxXKiX\n\t\t\t\t\t\tDYnYrh0URq0YrQvXUrUABDoA0oRStRQGmwgYBNHD4fTid9qJxRAXddoOxWHR3eLM\n\t\t\t\t\t\t+LV7VAMuZvzNq4x5LXFhqkfRHPXuM1GwMT8t8kHIsgv3xlxf3xjAjyHGswnlv8kU\n\t\t\t\t\t\t1uMiCj1u+q59WTt7VYGQkdiPYthy9pp6RCCWLvoeH2fpsE8Zfni/8YqkSLR0o7XX\n\t\t\t\t\t\tFSw2BvgqNlxrdQtiVKSaAKqv6MtYLQfsPAf7KyHXcOn/Wa79zsyh7Gr5tkMHWCyO\n\t\t\t\t\t\tz6/uA1UeHm+/00mCLJ2HxwGA/mQpiWmuTUtZRNyhIl6RCCpQvYmEYLcyTjXXgyCZ\n\t\t\t\t\t\tbtwqLlDrmrNeZwIDAQABo4IBbzCCAWswHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsr\n\t\t\t\t\t\tN1dH6pDjue0wHQYDVR0OBBYEFCi+rC8oIr09eQTC9ySKAjItBWkrMA4GA1UdDwEB\n\t\t\t\t\t\t/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEF\n\t\t\t\t\t\tBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8E\n\t\t\t\t\t\tMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENB\n\t\t\t\t\t\tLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNz\n\t\t\t\t\t\tLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8v\n\t\t\t\t\t\tb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJ0ZXN0aWRwMS5udHUuYWMu\n\t\t\t\t\t\tdWswDQYJKoZIhvcNAQEFBQADggEBAFUt0QpPH6WC/+XltCugdJr76oMYrwjNsOtK\n\t\t\t\t\t\tHakoQSRsf4uYg66wmJKnHhxEyFZeogB6cMAMe06PsaUB/86X35gkxFm2uMJGfsJB\n\t\t\t\t\t\tiE67ALWlN2hwWDePC/07Olud9e8Nq4u473yKLqsS7S3uY6aFYLXE9rWMXq2fIBj8\n\t\t\t\t\t\tiQFeWXQe0VfuG2l3k0UGs5Nty4UwRzLABv5sTmpnm8PJmDO5oAXmZg+lNYhRHkMO\n\t\t\t\t\t\tkdhsjKI5gAW+1PdlGwcHdx98KyqoVSLQw9HcWAE7Wo7MoKCsFrnyBqC/8N+k+8tm\n\t\t\t\t\t\ts7Obnw4aOinAMW06Fka45GA6qoSnJVj3y741U5pHrw0fWtVRZ3A="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Nottingham Trent University (testidp1)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ntu.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Nottingham Trent University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.bishopb-college.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.bishopb-college.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/bishopb-college.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/bishopb-college.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bishopb-college.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bishop Burton College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bishopb-college.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.havering-sfc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.havering-sfc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/havering-sfc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/havering-sfc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "havering-sfc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Havering Sixth Form College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.havering-sfc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-06.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-06.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-06.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-06.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-06.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-06.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-06.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-06.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-06.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;06"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;06"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-06.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-06.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJALk1rPJOG1teMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wNi5sYWRvay51bXUuc2UwHhcNMTIwNjI5MTIwODEwWhcNMjIw\nNjI3MTIwODEwWjAhMR8wHQYDVQQDExZsYWRvazMtMDYubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAy7RjhC7f4/gfQK127LuRggwD\n6VUcajCmZ8HpXZp29b/ghxNhgVlLDiIrLpD+bDaRoyJ20VssaWJ7KdLj2jFAjOmz\nCfPhvAd3kVmLLvVVOG12XlOh81RdQKZBm6qkvC/kTS6fxUHkympbGzFPmhGt6kEs\nz6BbdoOTzXTlXO4/H5N7N9ShspBhbc9NETinrPtIIykgjHSbfWMVdYQqCJbIdbM7\ny61Re55wfl8m6ppNra+oykYly2jhvlN0Vb4QGqpJBB0XzOAVh/DHt9oEDryxxaeG\n6JVhDwD15vx4tdm6ypd7qwNXp0c9nYteYNiSL+qXisKVJZ/JLcllxC7dLZ6GHQID\nAQABo2swaTBIBgNVHREEQTA/ghZsYWRvazMtMDYubGFkb2sudW11LnNlhiVodHRw\nczovL2xhZG9rMy0wNi5sYWRvay51bXUuc2UvZ3VpLXNwMB0GA1UdDgQWBBRK+n8d\nwSrEb8l1peNFBoe/bchVGjANBgkqhkiG9w0BAQUFAAOCAQEAqV8BTMudvEvzIUu1\n7bdjIVNCvNRb914WsPmQR6KhKhRzHVRJFqeSkMtvzCTi4YzaNE59l6iKcFG20ffZ\nO5WwEUhy8TtPgLrdK+Zi1rYfE3pULUs+LQLxz3h0reEW35y084ahB9uhYdkfjqEU\n/8LYg09v4gGOnjCLLj+mOEjpH7oVMWPuLSPbgL8RMfBX1SF51pDs1tp+rjGdbc7c\nPsCzYLHD+n9ygXpZsmmVmYi0YjZbrpYOLJlg/IU+jTfQ8ag4d8QEEz6Zfv+BL8iy\nU5ov36jyE84soQ3NsxFo3cndYZE3Epi7pMNaKAO2OUlS2R2R+l/9pdyzQqcOU6bq\nz181Cw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-06.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-06.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-06.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-06.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-06.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-06.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-06.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-06.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-06.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-06.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://nyainloggning.hv.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://nyainloggning.hv.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nyainloggning.hv.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nyainloggning.hv.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nyainloggning.hv.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nyainloggning.hv.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nyainloggning.hv.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://mittkonto.hv.se"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://mittkonto.hv.se"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Denna tj\u00e4nst anv\u00e4nds f\u00f6r att du som ny vid h\u00f6gskolan ska kunna aktivera ditt anv\u00e4ndarkonto vid universitetet. Om du redan har ett aktivt konto kan du s\u00e4tta nytt l\u00f6senord om du gl\u00f6mt bort det."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "As a new user you use this service to activate your university user account. You can also use this service to reset your password for your user account after the account activation."
                  }
                ],
                "logo": [
                  {
                    "text": "https://logo.hv.se/logo-sv.jpg",
                    "lang": "sv",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "https://logo.hv.se/logo-en.jpg",
                    "lang": "en",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "H\u00f6gskolan V\u00e4st kontoaktivering och l\u00f6senords\u00e5terst\u00e4llning"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University West user account activation and password reset"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://nyainloggning.hv.se/Shibboleth.sso/WAYF/shibboleth.antagning.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://nyainloggning.hv.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://nyainloggning.hv.se/shibboleth"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "nyainloggning.hv.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIJALJyR8XRTchcMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE255YWlubG9nZ25pbmcuaHYuc2UwHhcNMTUwMTIxMTgyNjU0WhcNMjUwMTE4\nMTgyNjU0WjAeMRwwGgYDVQQDExNueWFpbmxvZ2duaW5nLmh2LnNlMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmSk5lF9o2Dwt7rLyBF/i5wHbR0/lAS07\nhe4C7JMmQlytOsY6jID/dXhoO1o22xLfOHVigdH0LGTSI9nk8w0VwIhFufvwlCXk\nFOkqSj9wy5YNdAavdPsZ1BvmXDMjrbbt4X20b6nrE7FmYcPP+j3CXFTmaBB7cHsR\nYj5eJS85qRIFXilYEc+WCNci11fYPVT9nzX5fVzdxROHE5klp2LGLox6foACbBOL\nehTyZ+SnKx0mpcDqHHyLkJYbCrV5SFwOoLoLmlc1GCvQnyI8EPEE3G5N/A7t+nPI\n/mFz2kgJlFm8ILox3KRxX+FmsHMkpfIO2fqzDKW7ljIozb/A1MCpvwIDAQABo2kw\nZzBGBgNVHREEPzA9ghNueWFpbmxvZ2duaW5nLmh2LnNlhiZodHRwczovL255YWlu\nbG9nZ25pbmcuaHYuc2Uvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUueuyFYnfWLQbejjf\nltTKdRx7IgwwDQYJKoZIhvcNAQEFBQADggEBACTm4QiXXyc6XSGKuNfuy1AdeD8c\nieSXb6DfQ9cAAW58y5NU+SLdwjWU+1SrSy4JFjvDUMhZVEo/xumiTj9hcc96EgBU\nc7tTYNPoF1XGFTGJ2aEm4MH8hxmcGmn2HpATB1Pwc0pQjtbKnV87ahfd08W0uZWR\nHEp/eSV2NhjSWC7qPCXLx+WUoM8ZFlgNXdHRH5vFP2IIufsRXWJi2PfYMQVPnRMa\nhdJHNlDC2zsWXQ/mFSdsWg1B7j5lDP4gkxvTrgefsB8+VydZ9lol762Lgw3iOktT\nJG+lIY6SLd88XLEaeUmL3q8whBeQtliHLqzXxjSH3stdJnYnYGNZGZTIzyk="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=nyainloggning.hv.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://nyainloggning.hv.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://nyainloggning.hv.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nyainloggning.hv.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://nyainloggning.hv.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nyainloggning.hv.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://upkcontent.imparando.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:upk-support@imparando.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "upk-support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:technical@imparando.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "technical"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://upkcontent.imparando.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-05-14T16:01:41Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Imparando: Oracle UPK Training Environment"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.imparando.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Imparando (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://upkcontent.imparando.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://upkcontent.imparando.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://upkcontent.imparando.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://upkcontent.imparando.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://upkcontent.imparando.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://upkcontent.imparando.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSzCCAjOgAwIBAgIJAOd6oO6JdGfIMA0GCSqGSIb3DQEBBQUAMCgxJjAkBgNV\n\t\t\t\t\t\tBAMTHWltcC1jb250ZW50MDEtcC5pbXBhcmFuZG8uY29tMB4XDTEyMDUwODE1MjEw\n\t\t\t\t\t\tMVoXDTIyMDUwNjE1MjEwMVowKDEmMCQGA1UEAxMdaW1wLWNvbnRlbnQwMS1wLmlt\n\t\t\t\t\t\tcGFyYW5kby5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCwCqZL\n\t\t\t\t\t\tlGdDR1+8p9tWhNpAiWwR4N1Fe0ZuAosO++DU8ihOg9shAuaIbgavZ+LQDxDT4q60\n\t\t\t\t\t\tH/NSpFm0L5NCNdJbztlZDST30MkvbQk/x6rVWUV7N/vmH2uGlbYfXLdSWiIJN0lt\n\t\t\t\t\t\tBFZt9BejI85TLGcQQmU844KF1+QdlhcAETTvCJ9e4gJvOnua46WIDjcc+lE+a9fL\n\t\t\t\t\t\tB6vto9gliTiKzP9AbrCOKo5lPgcxozJ5ZV77KckRYzJnwOna8GTqwiJXqhMB6uPi\n\t\t\t\t\t\taYVMhbT7tq1veiCvRT8ME/pZTNV3g5UVby6ZTsit19jATqQ0IRZdfLBzPMVf13f6\n\t\t\t\t\t\tYXexYEP3N5sMCmnpAgMBAAGjeDB2MFUGA1UdEQROMEyCHWltcC1jb250ZW50MDEt\n\t\t\t\t\t\tcC5pbXBhcmFuZG8uY29thitodHRwczovL3Vwa2NvbnRlbnQuaW1wYXJhbmRvLmNv\n\t\t\t\t\t\tbS9zaGliYm9sZXRoMB0GA1UdDgQWBBSzFWIXER4HxW6ugBZoKX8DmGwYLjANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAET9AJLSfmZZSI6yvQrQWTplBulwW7thsItdk/2YMY4In\n\t\t\t\t\t\tOAFieBBkZehVWj2j+y8HytWgYh0S3WC3RQ3+/YPAAH/IN+k7y9MIsQBhKU27/FAR\n\t\t\t\t\t\tLE7IdN0YqKBK/kHvKdCPQn9ePpwEhVR27yArZiVkb50PMX+YfkAZgS6rFg2M1NL9\n\t\t\t\t\t\ttSuKU0Ka/7lb6xcc6naWaRfBxhUjMzKnWTFAgKF0873nr3TDvSokmJjvUrU5NHGG\n\t\t\t\t\t\tA05LtZya40PZ6vdC56IE0Ch0Sqjn0kLbt6KnKT8sfqXfwdOCvXLdvs2ISzzQZMak\n\t\t\t\t\t\tKbW8+5q5lNgkgzIwTRFYyp1vbDoPNm2tqPuMfJsOOA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://upkcontent.imparando.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://upkcontent.imparando.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://upkcontent.imparando.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://upkcontent.imparando.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://upkcontent.imparando.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://upkcontent.imparando.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.stamford.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@stamford.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "The IT Department"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cottrell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rob.cottrell@stamford.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rob"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.stamford.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEeDCCA2CgAwIBAgIJAK+NSDEsMrPuMA0GCSqGSIb3DQEBBQUAMIG8MQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEVMBMGA1UECBMMTGluY29sbnNoaXJlMREwDwYDVQQHEwhTdGFtZm9y\n\t\t\t\t\t\tZDEdMBsGA1UEChMUTmV3IENvbGxlZ2UgU3RhbWZvcmQxEzARBgNVBAsTCklUIFN1\n\t\t\t\t\t\tcHBvcnQxIjAgBgNVBAMTGXNoaWJib2xldGguc3RhbWZvcmQuYWMudWsxKzApBgkq\n\t\t\t\t\t\thkiG9w0BCQEWHGFkbWluaXN0cmF0b3JAc3RhbWZvcmQuYWMudWswHhcNMTMwOTE5\n\t\t\t\t\t\tMTEyMDEzWhcNMjMwOTE3MTEyMDEzWjCBvDELMAkGA1UEBhMCR0IxFTATBgNVBAgT\n\t\t\t\t\t\tDExpbmNvbG5zaGlyZTERMA8GA1UEBxMIU3RhbWZvcmQxHTAbBgNVBAoTFE5ldyBD\n\t\t\t\t\t\tb2xsZWdlIFN0YW1mb3JkMRMwEQYDVQQLEwpJVCBTdXBwb3J0MSIwIAYDVQQDExlz\n\t\t\t\t\t\taGliYm9sZXRoLnN0YW1mb3JkLmFjLnVrMSswKQYJKoZIhvcNAQkBFhxhZG1pbmlz\n\t\t\t\t\t\tdHJhdG9yQHN0YW1mb3JkLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAxNZhRlfySArnO5DOBDE9vfyzUzoKovS7ek9eQTI0kcze+pG227ymsKwW\n\t\t\t\t\t\tB/vhPHZt2344CtXqBiKxUv0U9jCf3/Dway3SvQ4fCAxgx0ceLqHToSZY1V67apeV\n\t\t\t\t\t\tR75t4Cexv2OZJ5mdvBA6Re1i37J+xZyKiSFnI2Bw0tCEY34tyxsdJFH2Q+S7kmiq\n\t\t\t\t\t\tYB56/pq3y8FDeDMntCJQNGPtjPQg0wNYz8z3FxBN7X/ko1bpr8TSYe/jfGOIiEbT\n\t\t\t\t\t\t/zE3izycJIpeLbTUX0RWsmA35mRdEe/SUPykEBaWhzcdE2aDAQMrCXSYdbf2hrCF\n\t\t\t\t\t\tDV6ekslfNFcfnoDVd4idzcC/AnvmfQIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCG\n\t\t\t\t\t\tSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4E\n\t\t\t\t\t\tFgQUZE2SOgx8EKt1Vry6YLh4zpTWE6cwHwYDVR0jBBgwFoAUZE2SOgx8EKt1Vry6\n\t\t\t\t\t\tYLh4zpTWE6cwDQYJKoZIhvcNAQEFBQADggEBAG/yhdTzRTEiwb5aApbiIFT9di/+\n\t\t\t\t\t\ti9pClFe37QWrqTr+oNrbbIThq/gB4tEeFNXopYg8ZQIgLTsc1HZKmociZ1zYMQ3C\n\t\t\t\t\t\t4eHvRxRpflQtIGy61+An9q5Gsx39ttAtLt4lG6VhJZQFFVD9CT6sBoQoFM+G2NQA\n\t\t\t\t\t\tRO1nSa2NmA2ezlRRuq0sJ7Ves9T4A0llSSpuPYVn0mOpU/oOgbWl88Fwr1G4/xIL\n\t\t\t\t\t\tdgcT7aAQbRSmDIuqhN8vjZzDyzXeBvtrHAhfRZh3QRbKoHeXtRCNAZbGxPPi9X64\n\t\t\t\t\t\t/puoYMet3mzYin0PEI6zw1AAZly79koe0tQZtjeybnmvvGrN6PrqCEWs2KY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stamford.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.stamford.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.stamford.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.stamford.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.stamford.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.stamford.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.stamford.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.stamford.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.stamford.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stamford.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEeDCCA2CgAwIBAgIJAK+NSDEsMrPuMA0GCSqGSIb3DQEBBQUAMIG8MQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEVMBMGA1UECBMMTGluY29sbnNoaXJlMREwDwYDVQQHEwhTdGFtZm9y\n\t\t\t\t\t\tZDEdMBsGA1UEChMUTmV3IENvbGxlZ2UgU3RhbWZvcmQxEzARBgNVBAsTCklUIFN1\n\t\t\t\t\t\tcHBvcnQxIjAgBgNVBAMTGXNoaWJib2xldGguc3RhbWZvcmQuYWMudWsxKzApBgkq\n\t\t\t\t\t\thkiG9w0BCQEWHGFkbWluaXN0cmF0b3JAc3RhbWZvcmQuYWMudWswHhcNMTMwOTE5\n\t\t\t\t\t\tMTEyMDEzWhcNMjMwOTE3MTEyMDEzWjCBvDELMAkGA1UEBhMCR0IxFTATBgNVBAgT\n\t\t\t\t\t\tDExpbmNvbG5zaGlyZTERMA8GA1UEBxMIU3RhbWZvcmQxHTAbBgNVBAoTFE5ldyBD\n\t\t\t\t\t\tb2xsZWdlIFN0YW1mb3JkMRMwEQYDVQQLEwpJVCBTdXBwb3J0MSIwIAYDVQQDExlz\n\t\t\t\t\t\taGliYm9sZXRoLnN0YW1mb3JkLmFjLnVrMSswKQYJKoZIhvcNAQkBFhxhZG1pbmlz\n\t\t\t\t\t\tdHJhdG9yQHN0YW1mb3JkLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAxNZhRlfySArnO5DOBDE9vfyzUzoKovS7ek9eQTI0kcze+pG227ymsKwW\n\t\t\t\t\t\tB/vhPHZt2344CtXqBiKxUv0U9jCf3/Dway3SvQ4fCAxgx0ceLqHToSZY1V67apeV\n\t\t\t\t\t\tR75t4Cexv2OZJ5mdvBA6Re1i37J+xZyKiSFnI2Bw0tCEY34tyxsdJFH2Q+S7kmiq\n\t\t\t\t\t\tYB56/pq3y8FDeDMntCJQNGPtjPQg0wNYz8z3FxBN7X/ko1bpr8TSYe/jfGOIiEbT\n\t\t\t\t\t\t/zE3izycJIpeLbTUX0RWsmA35mRdEe/SUPykEBaWhzcdE2aDAQMrCXSYdbf2hrCF\n\t\t\t\t\t\tDV6ekslfNFcfnoDVd4idzcC/AnvmfQIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCG\n\t\t\t\t\t\tSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4E\n\t\t\t\t\t\tFgQUZE2SOgx8EKt1Vry6YLh4zpTWE6cwHwYDVR0jBBgwFoAUZE2SOgx8EKt1Vry6\n\t\t\t\t\t\tYLh4zpTWE6cwDQYJKoZIhvcNAQEFBQADggEBAG/yhdTzRTEiwb5aApbiIFT9di/+\n\t\t\t\t\t\ti9pClFe37QWrqTr+oNrbbIThq/gB4tEeFNXopYg8ZQIgLTsc1HZKmociZ1zYMQ3C\n\t\t\t\t\t\t4eHvRxRpflQtIGy61+An9q5Gsx39ttAtLt4lG6VhJZQFFVD9CT6sBoQoFM+G2NQA\n\t\t\t\t\t\tRO1nSa2NmA2ezlRRuq0sJ7Ves9T4A0llSSpuPYVn0mOpU/oOgbWl88Fwr1G4/xIL\n\t\t\t\t\t\tdgcT7aAQbRSmDIuqhN8vjZzDyzXeBvtrHAhfRZh3QRbKoHeXtRCNAZbGxPPi9X64\n\t\t\t\t\t\t/puoYMet3mzYin0PEI6zw1AAZly79koe0tQZtjeybnmvvGrN6PrqCEWs2KY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "New College Stamford"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.stamford.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "New College Stamford"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.craw.eu/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jacquemain"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "maintenance@cra.wallonie.be"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mikhael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.craw.eu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://federation.belnet.be/files/Belnet-metadata-registration-practice-statement.txt"
              }
            ],
            "registration_instant": "2012-03-27T12:00:00Z",
            "registration_authority": "http://federation.belnet.be/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAIP1OBVd297uoZOia+Zqp6HAJ9DDMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2lkcC5jcmF3LmV1MB4XDTEzMDIxNTA3NDMyMVoXDTMz\nMDIxNTA3NDMyMVowFjEUMBIGA1UEAxMLaWRwLmNyYXcuZXUwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDuCWtJ/aDFBmejY17mEqrlgFxmetfLJWKCy6vU\n25241tsMqWW42YVuxtPwKP6Z5ure+RCzgUF0ZdddKqyaUpmNxeIq7OC7q21mMeBQ\nyahzvjzq8VgcM2iKcgCw/nNnrSZwkIaJMaej7Aw2U5VVs65rZ6bbztQbMKj51BbJ\nFM28lyTLC96+mTaofJ8hvkn2cPH3IecCFlRwNcx4w5SGuVGIPNEISQ8ypEzd2MNA\nDcnwemG46Ipv/MyILJPWP19xjl7z6VgeBLNHc0iigepBOrSnSq49WXpdwvFlkjMY\nsbPxGD1CQfPXBo6dDBNQdjn3V4cdfWRO5/Dp0J4mkkFsJkzDAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2lkcC5jcmF3LmV1hiJodHRwczovL2lkcC5jcmF3LmV1L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBQNbK63mDGwrA0LIPx4J3pCP/MHqjANBgkqhkiG\n9w0BAQUFAAOCAQEANbBixgiBQhJ/xB9Et8d+kZwK/OIC+Q08aCUuSlJ8URS7yB8a\ntQlX9xCW1Dj9eBVzsCNEVZQVhUA7SepbCHXwPh3cjim/255V/dboxEa5HtH76Pn5\nRSqOLhoN5SrqZn9JMZfJqIbU8vcLEwR9HqbFT0gDseyCExBdGEZb2cbnidxaTIrr\nyf6vu9LsSxP4gck3NrkfrUAWqxYis+a2qSXTni00wDcj5Si0DxZTIIFUfVeTPm02\ntEQG0fUEqzyBDxdQFuNsput7RfHF9S6iXjAEUyOc8+dXbxLs+kziJteBX01SSNI4\nNuU+VQNtPt46TiTwvP7DiXqrbeMbYZkfPB/jLQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "craw.eu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.craw.eu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.craw.eu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.craw.eu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.craw.eu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.craw.eu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.craw.eu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.craw.eu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.craw.eu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cra.wallonie.be"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Centre Wallon de Recherches Agronomiques"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "75",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "153"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CRA-W"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "CRA.WALLONIE.BE"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:50.5662,4.7247"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.115.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:06a8:3960::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAIP1OBVd297uoZOia+Zqp6HAJ9DDMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2lkcC5jcmF3LmV1MB4XDTEzMDIxNTA3NDMyMVoXDTMz\nMDIxNTA3NDMyMVowFjEUMBIGA1UEAxMLaWRwLmNyYXcuZXUwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDuCWtJ/aDFBmejY17mEqrlgFxmetfLJWKCy6vU\n25241tsMqWW42YVuxtPwKP6Z5ure+RCzgUF0ZdddKqyaUpmNxeIq7OC7q21mMeBQ\nyahzvjzq8VgcM2iKcgCw/nNnrSZwkIaJMaej7Aw2U5VVs65rZ6bbztQbMKj51BbJ\nFM28lyTLC96+mTaofJ8hvkn2cPH3IecCFlRwNcx4w5SGuVGIPNEISQ8ypEzd2MNA\nDcnwemG46Ipv/MyILJPWP19xjl7z6VgeBLNHc0iigepBOrSnSq49WXpdwvFlkjMY\nsbPxGD1CQfPXBo6dDBNQdjn3V4cdfWRO5/Dp0J4mkkFsJkzDAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2lkcC5jcmF3LmV1hiJodHRwczovL2lkcC5jcmF3LmV1L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBQNbK63mDGwrA0LIPx4J3pCP/MHqjANBgkqhkiG\n9w0BAQUFAAOCAQEANbBixgiBQhJ/xB9Et8d+kZwK/OIC+Q08aCUuSlJ8URS7yB8a\ntQlX9xCW1Dj9eBVzsCNEVZQVhUA7SepbCHXwPh3cjim/255V/dboxEa5HtH76Pn5\nRSqOLhoN5SrqZn9JMZfJqIbU8vcLEwR9HqbFT0gDseyCExBdGEZb2cbnidxaTIrr\nyf6vu9LsSxP4gck3NrkfrUAWqxYis+a2qSXTni00wDcj5Si0DxZTIIFUfVeTPm02\ntEQG0fUEqzyBDxdQFuNsput7RfHF9S6iXjAEUyOc8+dXbxLs+kziJteBX01SSNI4\nNuU+VQNtPt46TiTwvP7DiXqrbeMbYZkfPB/jLQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CRA-W"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cra.wallonie.be"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CRA-W"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.nhc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Haley"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mhaley@nhc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Haley"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mhaley@nhc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.nhc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-08-28T16:56:47Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUNuc5nh8nE6/6dgrZJmkSDgYUjPowDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGDEWMBQGA1UEAxMNaWRwLm5oYy5hYy51azAeFw0xMzA5MTcxNDAyNTdaFw0z\n\t\t\t\t\t\tMzA5MTcxNDAyNTdaMBgxFjAUBgNVBAMTDWlkcC5uaGMuYWMudWswggEiMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDVAxTlV/bVEVPw+4l3mVPRI/D9qbra1yQ7\n\t\t\t\t\t\t3vPIJ7Zhn4l4YLRoJsFbRWdEGVfvy1Ie2NutU45AgAnHDmzW2fCKoIaS5KqkJjD7\n\t\t\t\t\t\tfQHwBxDTrqweQhkrddZ5HuXj/DHlY23q+1/tw1k19fZTuEo6VWZu8orWdo7IOWtk\n\t\t\t\t\t\tQvCRACAXQcDTKRA5Uhnub8Z08QmdeBlac1wQ6ALcpFHmWA7vqouUGgYnjJNU+Soi\n\t\t\t\t\t\tXxiUDv7FipkmPWeQpJlHv/5fVkp/PW+bv48cL6DkTis486/8thdIJETySvTEu/oA\n\t\t\t\t\t\t/MlCKfOnvWm/nJk52Uq7Qot/s4hSGL5mQZTaL52x85HFuh4JgahlAgMBAAGjYTBf\n\t\t\t\t\t\tMD4GA1UdEQQ3MDWCDWlkcC5uaGMuYWMudWuGJGh0dHBzOi8vaWRwLm5oYy5hYy51\n\t\t\t\t\t\tay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUdnHc1Y7HF5N9zJhFS1ifKZuSrmcw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAL4RnY4z2aISPmdAiYOXurpzJZvZ3HAJS6UxNyuG\n\t\t\t\t\t\tZlAg5CtUM4dLpHjN8ajx9oYpMxK9uG47I/NFKvjxdGScWyTEYR6Myp2eGuz404Un\n\t\t\t\t\t\t+SMjYxnJ2MQg4TfkX+WdMTp65Zw+6d3hKdcaAgBjske+3C4Shj6rzohXMXav6TMo\n\t\t\t\t\t\t6kCN7IEhkpk5OQy3iMAhfNy+2rDpnJEHrUrdAIV74V55k60UX3Pg2M72Pexh1FVp\n\t\t\t\t\t\tqnhkB5Cb3ZOmXacyhKtdqxwdetV/CeBsAgKkgQhpcfOGMVgrDev1TloiTpBhztJ8\n\t\t\t\t\t\tKUOIvFZJgKFEIOZLmPagprpvbjZAHnZMQCyERkglvdkQ2Z0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nhc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.nhc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nhc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.nhc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.nhc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.nhc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.nhc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.nhc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nhc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nhc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUNuc5nh8nE6/6dgrZJmkSDgYUjPowDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGDEWMBQGA1UEAxMNaWRwLm5oYy5hYy51azAeFw0xMzA5MTcxNDAyNTdaFw0z\n\t\t\t\t\t\tMzA5MTcxNDAyNTdaMBgxFjAUBgNVBAMTDWlkcC5uaGMuYWMudWswggEiMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDVAxTlV/bVEVPw+4l3mVPRI/D9qbra1yQ7\n\t\t\t\t\t\t3vPIJ7Zhn4l4YLRoJsFbRWdEGVfvy1Ie2NutU45AgAnHDmzW2fCKoIaS5KqkJjD7\n\t\t\t\t\t\tfQHwBxDTrqweQhkrddZ5HuXj/DHlY23q+1/tw1k19fZTuEo6VWZu8orWdo7IOWtk\n\t\t\t\t\t\tQvCRACAXQcDTKRA5Uhnub8Z08QmdeBlac1wQ6ALcpFHmWA7vqouUGgYnjJNU+Soi\n\t\t\t\t\t\tXxiUDv7FipkmPWeQpJlHv/5fVkp/PW+bv48cL6DkTis486/8thdIJETySvTEu/oA\n\t\t\t\t\t\t/MlCKfOnvWm/nJk52Uq7Qot/s4hSGL5mQZTaL52x85HFuh4JgahlAgMBAAGjYTBf\n\t\t\t\t\t\tMD4GA1UdEQQ3MDWCDWlkcC5uaGMuYWMudWuGJGh0dHBzOi8vaWRwLm5oYy5hYy51\n\t\t\t\t\t\tay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUdnHc1Y7HF5N9zJhFS1ifKZuSrmcw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAL4RnY4z2aISPmdAiYOXurpzJZvZ3HAJS6UxNyuG\n\t\t\t\t\t\tZlAg5CtUM4dLpHjN8ajx9oYpMxK9uG47I/NFKvjxdGScWyTEYR6Myp2eGuz404Un\n\t\t\t\t\t\t+SMjYxnJ2MQg4TfkX+WdMTp65Zw+6d3hKdcaAgBjske+3C4Shj6rzohXMXav6TMo\n\t\t\t\t\t\t6kCN7IEhkpk5OQy3iMAhfNy+2rDpnJEHrUrdAIV74V55k60UX3Pg2M72Pexh1FVp\n\t\t\t\t\t\tqnhkB5Cb3ZOmXacyhKtdqxwdetV/CeBsAgKkgQhpcfOGMVgrDev1TloiTpBhztJ8\n\t\t\t\t\t\tKUOIvFZJgKFEIOZLmPagprpvbjZAHnZMQCyERkglvdkQ2Z0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "North Hertfordshire College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nhc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "North Hertfordshire College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://birk.wayf.dk/birk.php/ucnsso.ucn.dk/adfs/services/trust",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://birk.wayf.dk/birk.php/ucnsso.ucn.dk/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2015-06-09T09:51:19Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/ucnsso.ucn.dk/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucn.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University College Nordjylland"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University College of Northern Denmark"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "ucn.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC2jCCAcICAQcwDQYJKoZIhvcNAQELBQAwMzExMC8GA1UEAwwoaHR0cDovL3Vj\nbnNzby51Y24uZGsvYWRmcy9zZXJ2aWNlcy90cnVzdDAeFw0xNTAxMDEwMDAwMDBa\nFw0yNTEyMzEyMzU5NTlaMDMxMTAvBgNVBAMMKGh0dHA6Ly91Y25zc28udWNuLmRr\nL2FkZnMvc2VydmljZXMvdHJ1c3QwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQDHiAwKahBTuI4Z+IJ1rgOeEiCCy3bR9QIe3BpCsejFCU5rSzkWANqVuc1P\nDfp0JdIZhrPXsmDJQMmidPCGPIDQKo+bk+af3+EUFS/I/+35sSBX2vf+h1DHvZV9\njsznmpSVjp7HZ/WoPWBykWBJO0AOVmzB5zlaqkS36J76+wxerwdpuExVnYSNd73S\n+AyT/EZ+tXAO+6lQ8FL/YMlJnUkSaSqLSHFy01D2qBNmYRwBpCS6/dUZyxi0t5j8\nghKUD4BHOZVavn65J62cJdXiOcMRyUAIp57GXQrL63KtrjIcXddq+CZyZ5t37EdU\nOIz42joFcy73MFOntynlKEvOw1BJAgMBAAEwDQYJKoZIhvcNAQELBQADggEBALgQ\nmWqIboqnWbk9WMHObnwVUp/7CLaA0nVF1Q3T3jMqYdjj6aI6Fdv+dTFOvpPJHRJy\nhMqV+8S2bYLvajGyyS/N4fZAhGGGEkl5lfDeXjvfVptIY0lwFcFZOq27d/m/6Oyv\nwGLhzikcsR97FTVbsgQ3Isyjq7G8jFilZUKa3VrT78z0zx4vS/DMstMEG1V0YIqA\niw1GOsAmeKodFt0tcitbo1dIqjTaXeK+D9/OOf6aOxoejtnwqr5wkXgfYarDiMtg\nRscebjExrf9kQhSEyquUD4dGbwDvWNwkL6gOtbKzw96PfzYKxUXs/SnBb3/rR1Mq\nI7eDefwR237lfmpOKMk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University College Nordjylland"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University College of Northern Denmark"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ucn.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ucn.dk"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University College Nordjylland"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University College of Northern Denmark"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://retrieverstories.umbc.edu/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "collier@umbc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "B. Collier Jones"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "erude1@umbc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ed Rude"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "will3@umbc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Billy Schneider"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://retrieverstories.umbc.edu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Maryland Baltimore County"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.umbc.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Maryland Baltimore County"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://retrieverstories.umbc.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://retrieverstories.umbc.edu"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Retriever Stories"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHjCCAgagAwIBAgIJAI0RUT0r/oX8MA0GCSqGSIb3DQEBBQUAMCgxJjAkBgNV\nBAMTHWphYmJhLXd3dy1wcm9kMS5jb3JlLnVtYmMuZWR1MB4XDTExMTAxMDIwMzYx\nMFoXDTIxMTAwNzIwMzYxMFowKDEmMCQGA1UEAxMdamFiYmEtd3d3LXByb2QxLmNv\ncmUudW1iYy5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC2IDFJ\nAGo41UtzNssD22c7fX0B+pRbMR51qpQL041yLnzcOJ+bke+R6OmX34pIWA0vagKM\nqu9iY+3GyEUxGHiuTNhDBvFKYcnO6qAEsgSroUrBCDbZo9Ntpli3ktf4zA5l11Wi\nzcMBt4HAbuXOlqD2LfE3jiPyUtOhgr2ODUoqBBIoYk3RjqxnWJ5kg5uroNjtWHOQ\nTpAM+lzm/aZEei9MO+iOu68kUR9Cf0QZQEAlxvUNWR/CPN2CF00FcfobN6r1rzkd\nQ7vNCXROs232WCL0RjqVl57NLg5ED02gelGzNWSl1MRN3tRxzWGyW0F5GLKwG888\ncT9LsXNEa+efkHYnAgMBAAGjSzBJMCgGA1UdEQQhMB+CHWphYmJhLXd3dy1wcm9k\nMS5jb3JlLnVtYmMuZWR1MB0GA1UdDgQWBBQh7CUvbTSbYcrvs/SftNs70q6XSDAN\nBgkqhkiG9w0BAQUFAAOCAQEASdHFzNxj+9RstGDYQxNTcBXzthJ0RZgwm2WgwRj4\npeDj19tKH7k/txzj2BaaVfusTxBBqdlWZElQuv5302MPH8zDP/lhtI2j4xsuOxHL\nWk6K8OzkjihskQeZnF6xaNlajtnab7BbrkFYmS4UCbiIOduJCmKQzbE0AFDZUN1j\nOXVVS7Im4xemrgUPAUArzcGEMhAuGc4fZgiJJ93Vtw/MzpcqXW3woU4s+yuY3Dcn\nwJC08P8O53sa3+tLYDHiJdjRo5cOXwbFhex/GrHIMAnN2s7lFw55P04VmLuo/7pB\nao6Rbsibw3/fICNNEUjDp113Ypd6MW4ncJ0OJhknmmrRRg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://retrieverstories.umbc.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://retrieverstories.umbc.edu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://retrieverstories.umbc.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://retrieverstories.umbc.edu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Retriever Stories"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://login.nd.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "eds@nd.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OIT Identity Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "eds@nd.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OIT Identity Management"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.nd.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.nd.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.nd.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.nd.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.nd.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.nd.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nd.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Notre Dame"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUMLHjiLc33hXgOaCp5dmYfydyVWwwDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMbG9naW4ubmQuZWR1MB4XDTExMDkyODE5MzYxMloXDTMx\nMDkyODE5MzYxMlowFzEVMBMGA1UEAxMMbG9naW4ubmQuZWR1MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAznU2yVyVhGpnHAik/b5ee4t7FT0UyBHVf23B\nBqZ3ithQgUQkAPzUoSxAAm/gKrI+QKoxJ1JpWB7U/c1EfDB60I8RfLLbbrCNVdaQ\nvAO1qj1zn10AzuxLTwvw9Gaga5Cmea09Le0MW32EUp7CQBGu6Fy/AOhUQ2/sugaz\nkcR4rTPuWtCdPBJ/C6/vThDsCPKS9oHs3jaZjbyoGSrVuXmPrvEPEKNI2Ghgyqtl\nXR+KYbQ/Q7v3xH2XMTb7x1ZcqSz7nJIPmKBDTgGZNg0Iqbx0/c+Jrf1FY1I3bqNY\ncAW+hNEmmKEihlexIIKcB9K8r4d8qRIwU1cmF2PEmn00ntdZvwIDAQABo18wXTA8\nBgNVHREENTAzggxsb2dpbi5uZC5lZHWGI2h0dHBzOi8vbG9naW4ubmQuZWR1L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBRN5WeLYLCunozBnymgL5/nKfimCjANBgkq\nhkiG9w0BAQUFAAOCAQEAucOVj+U3YG4t5dISqjV4kIvIQJfgrXmOpd9NMEZosSYf\nMx1Tnqj32jUsBeYzySOvcuLSo7VYeAb2aHchpemvL+FPCevH2/5yhzMcWww3taJB\nC0SP1yEjdWsTv21bxrk2xKAlgeIRvwUPqzpDF82/nVSIlCoBQ2LtoX7hGW2exeEx\nlHQMS6hV3X3Vph7DTRtgtEPJUiqYBDj19JzUNwYABPXr55jMwlvAJ2W7pO6wLrdR\n/PXobsAeIT1+agr/JnymgxVsv6I2Ge780x6V9qQ71553X1mG+vtV/tJ3Y81tXL2/\nxc/kwwyNOzorxPvN9w6vSeQk6qtTmTPmOaCNIZkj1A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Notre Dame"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nd.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Notre Dame"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://tc-web-01.groupgti.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:targetconnect.support@groupgti.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TARGETconnect Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Masters"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chris.masters@groupgti.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://tc-web-01.groupgti.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GTI: TARGETconnect Web1"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.groupgti.com/home/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GTI Media Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEXjCCA0agAwIBAgIJALr1RvO8/Hs1MA0GCSqGSIb3DQEBBQUAMIGvMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEUMBIGA1UECBMLT3hmb3Jkc2hpcmUxFDASBgNVBAcTC1dhbGxpbmdm\n\t\t\t\t\t\tb3JkMRYwFAYDVQQKEw1HVEkgTWVkaWEgTHRkMTIwMAYDVQQDEylodHRwczovL3Rj\n\t\t\t\t\t\tLXdlYi0wMS5ncm91cGd0aS5uZXQvc2hpYmJvbGV0aDEoMCYGCSqGSIb3DQEJARYZ\n\t\t\t\t\t\tY2hyaXMubWFzdGVyc0Bncm91cHRpLmNvbTAeFw0xMDA5MjMyMTA4MjZaFw0yMDA5\n\t\t\t\t\t\tMjAyMTA4MjZaMIGvMQswCQYDVQQGEwJHQjEUMBIGA1UECBMLT3hmb3Jkc2hpcmUx\n\t\t\t\t\t\tFDASBgNVBAcTC1dhbGxpbmdmb3JkMRYwFAYDVQQKEw1HVEkgTWVkaWEgTHRkMTIw\n\t\t\t\t\t\tMAYDVQQDEylodHRwczovL3RjLXdlYi0wMS5ncm91cGd0aS5uZXQvc2hpYmJvbGV0\n\t\t\t\t\t\taDEoMCYGCSqGSIb3DQEJARYZY2hyaXMubWFzdGVyc0Bncm91cHRpLmNvbTCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAO0G5rfLxGDxli2k/E//a1HfgrZA\n\t\t\t\t\t\toqvmIOcXaahpP1HCLK+3mgSU2cR3ukTvS0Pldnrn8dwXs/wsZTnGUqJNlvXVgHgf\n\t\t\t\t\t\tKSuGAwqtKPzuX+0omVbl6lekO2Ie8SZbCRi1w0S3/PpWQv/00MrjokllQZtRMMQq\n\t\t\t\t\t\t0XAmqEusMyf9O7S/CKz8Kd9FzezLdJ2E+cT6a8P+PEic9f05uk3iAEu9xafVLSgR\n\t\t\t\t\t\tB/IK5HDfMy2/o+Hj9iVhTKRzvaERWB/WozNH3y8x34QNLTFXvLwVJ/Bz/IL4/uzc\n\t\t\t\t\t\tunsARYJHZBZ6AtC7uqkXRgXIqeFJRduNNrmdRFa/MjVhpdnhOJxRy52kWTsCAwEA\n\t\t\t\t\t\tAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0\n\t\t\t\t\t\tZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFOWwAghxTnuIj9RO/+IYp+V9QGMsMB8G\n\t\t\t\t\t\tA1UdIwQYMBaAFOWwAghxTnuIj9RO/+IYp+V9QGMsMA0GCSqGSIb3DQEBBQUAA4IB\n\t\t\t\t\t\tAQCQDWQJ4xYFcUa7OMF3bgWB0pOUUCzVvdJICIp41+6xdGJDkJo3e15dhEVtVjwx\n\t\t\t\t\t\tjxvGruH07YSuYd6Sl8wEeYCR9sruxUMwNWKD/GBxuZUFrhM3avnpC81tgtMQs+BD\n\t\t\t\t\t\tND9wgQNP0oPlOmHRVAj8GZHGxRdwXfXmuc87a4+7E6ViI3zZKIZBW6PzRHHpKt00\n\t\t\t\t\t\tuNvi0wNHgzVPgECjM6Fbs4BQdIxR65UHcLOPlFfJe6VtQ7zRL247jCghHmpLAM34\n\t\t\t\t\t\tjE1agxgsSIXSbxHwZZE2S/mQZYD5SS3pjfCv5NVLar1+78ltc0UrtuAYAzNWS1JO\n\t\t\t\t\t\td7WVmWXEHEPJ0nj/KHfo0tLf"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEXjCCA0agAwIBAgIJALr1RvO8/Hs1MA0GCSqGSIb3DQEBBQUAMIGvMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEUMBIGA1UECBMLT3hmb3Jkc2hpcmUxFDASBgNVBAcTC1dhbGxpbmdm\n\t\t\t\t\t\tb3JkMRYwFAYDVQQKEw1HVEkgTWVkaWEgTHRkMTIwMAYDVQQDEylodHRwczovL3Rj\n\t\t\t\t\t\tLXdlYi0wMS5ncm91cGd0aS5uZXQvc2hpYmJvbGV0aDEoMCYGCSqGSIb3DQEJARYZ\n\t\t\t\t\t\tY2hyaXMubWFzdGVyc0Bncm91cHRpLmNvbTAeFw0xMDA5MjMyMTA4MjZaFw0yMDA5\n\t\t\t\t\t\tMjAyMTA4MjZaMIGvMQswCQYDVQQGEwJHQjEUMBIGA1UECBMLT3hmb3Jkc2hpcmUx\n\t\t\t\t\t\tFDASBgNVBAcTC1dhbGxpbmdmb3JkMRYwFAYDVQQKEw1HVEkgTWVkaWEgTHRkMTIw\n\t\t\t\t\t\tMAYDVQQDEylodHRwczovL3RjLXdlYi0wMS5ncm91cGd0aS5uZXQvc2hpYmJvbGV0\n\t\t\t\t\t\taDEoMCYGCSqGSIb3DQEJARYZY2hyaXMubWFzdGVyc0Bncm91cHRpLmNvbTCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAO0G5rfLxGDxli2k/E//a1HfgrZA\n\t\t\t\t\t\toqvmIOcXaahpP1HCLK+3mgSU2cR3ukTvS0Pldnrn8dwXs/wsZTnGUqJNlvXVgHgf\n\t\t\t\t\t\tKSuGAwqtKPzuX+0omVbl6lekO2Ie8SZbCRi1w0S3/PpWQv/00MrjokllQZtRMMQq\n\t\t\t\t\t\t0XAmqEusMyf9O7S/CKz8Kd9FzezLdJ2E+cT6a8P+PEic9f05uk3iAEu9xafVLSgR\n\t\t\t\t\t\tB/IK5HDfMy2/o+Hj9iVhTKRzvaERWB/WozNH3y8x34QNLTFXvLwVJ/Bz/IL4/uzc\n\t\t\t\t\t\tunsARYJHZBZ6AtC7uqkXRgXIqeFJRduNNrmdRFa/MjVhpdnhOJxRy52kWTsCAwEA\n\t\t\t\t\t\tAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0\n\t\t\t\t\t\tZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFOWwAghxTnuIj9RO/+IYp+V9QGMsMB8G\n\t\t\t\t\t\tA1UdIwQYMBaAFOWwAghxTnuIj9RO/+IYp+V9QGMsMA0GCSqGSIb3DQEBBQUAA4IB\n\t\t\t\t\t\tAQCQDWQJ4xYFcUa7OMF3bgWB0pOUUCzVvdJICIp41+6xdGJDkJo3e15dhEVtVjwx\n\t\t\t\t\t\tjxvGruH07YSuYd6Sl8wEeYCR9sruxUMwNWKD/GBxuZUFrhM3avnpC81tgtMQs+BD\n\t\t\t\t\t\tND9wgQNP0oPlOmHRVAj8GZHGxRdwXfXmuc87a4+7E6ViI3zZKIZBW6PzRHHpKt00\n\t\t\t\t\t\tuNvi0wNHgzVPgECjM6Fbs4BQdIxR65UHcLOPlFfJe6VtQ7zRL247jCghHmpLAM34\n\t\t\t\t\t\tjE1agxgsSIXSbxHwZZE2S/mQZYD5SS3pjfCv5NVLar1+78ltc0UrtuAYAzNWS1JO\n\t\t\t\t\t\td7WVmWXEHEPJ0nj/KHfo0tLf"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://saml2.targetconnect.net/samlengine/shibb/acs",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://saml2.targetconnect.net/samlengine/s2/wbsso/acs",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://saml2.targetconnect.net/samlengine/s2/wbsso/acs",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://nyusteinhardttickets.universitytickets.com/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@universitytickets.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UniversityTickets Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://nyusteinhardttickets.universitytickets.com/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UniversityTickets"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://universitytickets.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UniversityTickets"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://nyusteinhardttickets.universitytickets.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NYU Steinhardt Commencement Tickets"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEFzCCAv+gAwIBAgIJAOKNYZKTkGOxMA0GCSqGSIb3DQEBBQUAMIGhMQswCQYD\nVQQGEwJVUzELMAkGA1UECAwCTlkxETAPBgNVBAcMCE5ldyBZb3JrMSAwHgYDVQQK\nDBdVbml2ZXJzaXR5VGlja2V0cywgSW5jLjEiMCAGA1UEAwwZVW5pdmVyc2l0eVRp\nY2tldHMgU3VwcG9ydDEsMCoGCSqGSIb3DQEJARYdc3VwcG9ydEB1bml2ZXJzaXR5\ndGlja2V0cy5jb20wHhcNMTAwODI3MTQzNDMwWhcNMTMwODI2MTQzNDMwWjCBoTEL\nMAkGA1UEBhMCVVMxCzAJBgNVBAgMAk5ZMREwDwYDVQQHDAhOZXcgWW9yazEgMB4G\nA1UECgwXVW5pdmVyc2l0eVRpY2tldHMsIEluYy4xIjAgBgNVBAMMGVVuaXZlcnNp\ndHlUaWNrZXRzIFN1cHBvcnQxLDAqBgkqhkiG9w0BCQEWHXN1cHBvcnRAdW5pdmVy\nc2l0eXRpY2tldHMuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\ntuDuyswVfkWKroBS9oOpm2QqRJecNIyZ7DMf9m7jwFFaQiPN3NYTe9C35I3rsmqp\nUvSK075z34uNrBddsz29CnVurUv6geM+mBUZB11oFG6rGxuT3wfYTpA54kbVQps1\nGHL8HV95fB5xEagZd888i7CFmXZMJ3xF4R9h8UDe09ZlQ5sjY/E6Ff0bIaAP6phj\nl0IsIBYRPUeIGMYPqw7azmFy7XS4FPTrQmya1E7wxf/6CXot5EYhyYLr7RKdOjp5\nfoIkedY1ZhjuWZFa6EPaIYqqz8v9nGJx3uW3dZeuXfNrSjvj0RasHNXU84y0FP1S\nex6ywCFhLIVS5ewXXm6b9QIDAQABo1AwTjAdBgNVHQ4EFgQUDCeDghnKlaF2rAwJ\nrB0DSvAOpfwwHwYDVR0jBBgwFoAUDCeDghnKlaF2rAwJrB0DSvAOpfwwDAYDVR0T\nBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAEBt2aRlN01fZYYXwid/k/QaVlJUF\nRjFJouAFyC0N4sjZDEZxnOrLV8QxVABNGwJ78HDeQ7Z2xOeOEvKzORB9RJvsz4ac\nFuEmARQX8QDiSzeCvjiq0VBd46KVYlU0hSXRM99VEexB+V/S5/h4xRHaaRwcWD0k\nrcx+OJkf4WTNRm6t2+LOFcOZ1VV4C3DnPbd0nCJlJSzHYUKGfeoJJJ7ew4KZF4le\n2fdSm7mihM6r2O047IbPr9qkVRDXfaIkXfFvCBPKogZ0pv41ctocTbVvTKoAbe6i\nnpy6/mAHObt21m69If4I8DgLUvCuVIIbt/4TZVqeiN7mHIPk2XtftnMpSw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nyusteinhardttickets.universitytickets.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://nyusteinhardttickets.universitytickets.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nyusteinhardttickets.universitytickets.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://nyusteinhardttickets.universitytickets.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://nyusteinhardttickets.universitytickets.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://nyusteinhardttickets.universitytickets.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "NYU Steinhardt Commencement Tickets"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "cn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ucl-safety.co.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Layton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Simonl@optimadiagnostics.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Layton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Simonl@optimadiagnostics.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ucl-safety.co.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Optima Diagnostics Limited: Oshens Software for UCL"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oshens.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Optima Diagnostics Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ucl-safety.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ucl-safety.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ucl-safety.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ucl-safety.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ucl-safety.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAKIVioCG3ZBZMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\n\t\t\t\t\t\tBAMTD3MwMzUyLTA1NDgtd2IwMTAeFw0xMDEwMDQxNzIxNTZaFw0yMDEwMDExNzIx\n\t\t\t\t\t\tNTZaMBoxGDAWBgNVBAMTD3MwMzUyLTA1NDgtd2IwMTCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBAMxOVF1mGMeCdKb7Z0syty24insTVStJ8v9nTwFjwwu9\n\t\t\t\t\t\tczW5kz0LXEJ31BK26QOLcrf3GNJzWdSmUbwHJgv8KyzacBze6fUdKHjVEW6qIveA\n\t\t\t\t\t\tnIzKGZxG+FjzZ280oIAEvZs+8Ti9bzSkPRp0IRRnsjmiov+hp7/Ga/pZe81WTRMn\n\t\t\t\t\t\tp3cLL9UVvVg/SwUE9wOEfEIIiQ5rvQRKloTjC58b0layZgjJ1pKBkAeIwxusj++n\n\t\t\t\t\t\tCqCyue4Kz3OjDmbQplVIn3d+EJKjmW/IXyNwOri7C9o6XKlmVmRdtDLQAwso4tXc\n\t\t\t\t\t\tTvxPCm/makIaAt66yboQIuZJ6hZmTB1HqF0TlW9Gn5sCAwEAAaM9MDswGgYDVR0R\n\t\t\t\t\t\tBBMwEYIPczAzNTItMDU0OC13YjAxMB0GA1UdDgQWBBQ2UBzH2KH4WXHk1WCJyf94\n\t\t\t\t\t\tmG9F4zANBgkqhkiG9w0BAQUFAAOCAQEAxsn3j8kwu255CI0tn/uAdmNmDx+VRqrU\n\t\t\t\t\t\ttbUjP4hERBpeLCSlVS799BrmOUH3Va+KXg4NwTWJpZJ5CszB4C8/RfpHZsIYHB+5\n\t\t\t\t\t\tQk4qtFWY9KiRwgt6HxFI4eSMa8xWKnA6FU3jlc1ngN4zRx4Mjjs6IstBqg53CXYo\n\t\t\t\t\t\thqpiMWakBYHx1vco/tadDS3tON9r0zGeOIH+Q3myZoTfXZkq1TCsKqHLi0G98soK\n\t\t\t\t\t\tLARNtvz6YagTchFGL4rQoMZaGUforT1pH/2SLFRSIQvB7KE/L9KAiq0J0VtcRQeO\n\t\t\t\t\t\tE1JMlcamLZgO4OOfUch9qY3mzMk4ILX5fzEHzXPCC+ck3uV39/1/7A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAKIVioCG3ZBZMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\n\t\t\t\t\t\tBAMTD3MwMzUyLTA1NDgtd2IwMTAeFw0xMDEwMDQxNzIxNTZaFw0yMDEwMDExNzIx\n\t\t\t\t\t\tNTZaMBoxGDAWBgNVBAMTD3MwMzUyLTA1NDgtd2IwMTCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBAMxOVF1mGMeCdKb7Z0syty24insTVStJ8v9nTwFjwwu9\n\t\t\t\t\t\tczW5kz0LXEJ31BK26QOLcrf3GNJzWdSmUbwHJgv8KyzacBze6fUdKHjVEW6qIveA\n\t\t\t\t\t\tnIzKGZxG+FjzZ280oIAEvZs+8Ti9bzSkPRp0IRRnsjmiov+hp7/Ga/pZe81WTRMn\n\t\t\t\t\t\tp3cLL9UVvVg/SwUE9wOEfEIIiQ5rvQRKloTjC58b0layZgjJ1pKBkAeIwxusj++n\n\t\t\t\t\t\tCqCyue4Kz3OjDmbQplVIn3d+EJKjmW/IXyNwOri7C9o6XKlmVmRdtDLQAwso4tXc\n\t\t\t\t\t\tTvxPCm/makIaAt66yboQIuZJ6hZmTB1HqF0TlW9Gn5sCAwEAAaM9MDswGgYDVR0R\n\t\t\t\t\t\tBBMwEYIPczAzNTItMDU0OC13YjAxMB0GA1UdDgQWBBQ2UBzH2KH4WXHk1WCJyf94\n\t\t\t\t\t\tmG9F4zANBgkqhkiG9w0BAQUFAAOCAQEAxsn3j8kwu255CI0tn/uAdmNmDx+VRqrU\n\t\t\t\t\t\ttbUjP4hERBpeLCSlVS799BrmOUH3Va+KXg4NwTWJpZJ5CszB4C8/RfpHZsIYHB+5\n\t\t\t\t\t\tQk4qtFWY9KiRwgt6HxFI4eSMa8xWKnA6FU3jlc1ngN4zRx4Mjjs6IstBqg53CXYo\n\t\t\t\t\t\thqpiMWakBYHx1vco/tadDS3tON9r0zGeOIH+Q3myZoTfXZkq1TCsKqHLi0G98soK\n\t\t\t\t\t\tLARNtvz6YagTchFGL4rQoMZaGUforT1pH/2SLFRSIQvB7KE/L9KAiq0J0VtcRQeO\n\t\t\t\t\t\tE1JMlcamLZgO4OOfUch9qY3mzMk4ILX5fzEHzXPCC+ck3uV39/1/7A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ucl-safety.co.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ucl-safety.co.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ucl-safety.co.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ucl-safety.co.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ucl-safety.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ucl-safety.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ucl-safety.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ucl-safety.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ucl-safety.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ucl-safety.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib2idp.rgu.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Milne"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:r.milne@rgu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cunningham"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.cunningham@rgu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib2idp.rgu.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-10-15T14:21:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEYDCCA0igAwIBAgIJANG+SOhVkyPLMA0GCSqGSIb3DQEBCwUAMIGwMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEWMBQGA1UECBMNQWJlcmRlZW5zaGlyZTERMA8GA1UEBxMIQWJlcmRl\n\t\t\t\t\t\tZW4xITAfBgNVBAoTGFJvYmVydCBHb3Jkb24gVW5pdmVyc2l0eTEUMBIGA1UECxML\n\t\t\t\t\t\tSVQgU2VydmljZXMxGzAZBgNVBAMTEnNoaWIyaWRwLnJndS5hYy51azEgMB4GCSqG\n\t\t\t\t\t\tSIb3DQEJARYRaXRzLXN5c0ByZ3UuYWMudWswHhcNMTUwNzAxMDY1OTQzWhcNMjUw\n\t\t\t\t\t\tNjI4MDY1OTQzWjCBsDELMAkGA1UEBhMCR0IxFjAUBgNVBAgTDUFiZXJkZWVuc2hp\n\t\t\t\t\t\tcmUxETAPBgNVBAcTCEFiZXJkZWVuMSEwHwYDVQQKExhSb2JlcnQgR29yZG9uIFVu\n\t\t\t\t\t\taXZlcnNpdHkxFDASBgNVBAsTC0lUIFNlcnZpY2VzMRswGQYDVQQDExJzaGliMmlk\n\t\t\t\t\t\tcC5yZ3UuYWMudWsxIDAeBgkqhkiG9w0BCQEWEWl0cy1zeXNAcmd1LmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtlnIv3WseSau1bSwKYgWnl3w\n\t\t\t\t\t\tW4A510yAe4EVHxCDXPbblHFmZwjN3F1Elw56e1LlSwhS4zS25R/cfjrH4NPqsTqD\n\t\t\t\t\t\t5TWHmmTaduonCdzVhqJ9do9hLcFrfkCSGwJGswKGutbphOvcG2tvRCt/BBtxf5yu\n\t\t\t\t\t\tI2D/cZ1jwJoURJe1X+r2d0HyjU23wlG9ImY8VLHTLjndQAPWddnvSySTrCNagfDB\n\t\t\t\t\t\tKQU8vWEQomm4griv1CFs205eqWBriZjoyt/i8q3XY+smafZ1sRR90YoidYGK0FbU\n\t\t\t\t\t\tBiyOfsTgE++GBTXQzGPf+pIN5U8GD8PxgTNal6ncKps1hiquqQGlLCJ3pybMsQID\n\t\t\t\t\t\tAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVy\n\t\t\t\t\t\tYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUoPahtUqnvLSmYMgVnP2s16wxXpUw\n\t\t\t\t\t\tHwYDVR0jBBgwFoAUoPahtUqnvLSmYMgVnP2s16wxXpUwDQYJKoZIhvcNAQELBQAD\n\t\t\t\t\t\tggEBAEsrmXShp2e+MEVSjpWYYTh2Yj45DBeHJVpBlJzkeb7UB1EViBa0O4DPojh0\n\t\t\t\t\t\tPFjmkfCIAvoCQAF3BL8j92DL+ltQOWZ3bnUTePUrGzN6RAXC5Qcv8HzSM77t3Cm9\n\t\t\t\t\t\tStUmTfcMp0Y5Ij7nHQdllzQND4nYp2OOhcWxn1cbPGHWl5tORBKVC3CacgY34H4g\n\t\t\t\t\t\tnqpHZyD+ngZtpCdGUmqpndD5+H+l0s91nm00akyYxFuRCpm6c97Tf5BfADtAumVY\n\t\t\t\t\t\tXz2bbxGztusvVUYAr75X+daVeh+/9N9SEybqeOuk99VSHBDwwaVkFiul2LzZRi0V\n\t\t\t\t\t\tXyNCrBFWNSC7s6MHLPcmlrG8YdY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rgu.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib2idp.rgu.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib2idp.rgu.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shiblogin.rgu.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shiblogin.rgu.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shiblogin.rgu.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shiblogin.rgu.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib2idp.rgu.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib2idp.rgu.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rgu.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEYDCCA0igAwIBAgIJANG+SOhVkyPLMA0GCSqGSIb3DQEBCwUAMIGwMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEWMBQGA1UECBMNQWJlcmRlZW5zaGlyZTERMA8GA1UEBxMIQWJlcmRl\n\t\t\t\t\t\tZW4xITAfBgNVBAoTGFJvYmVydCBHb3Jkb24gVW5pdmVyc2l0eTEUMBIGA1UECxML\n\t\t\t\t\t\tSVQgU2VydmljZXMxGzAZBgNVBAMTEnNoaWIyaWRwLnJndS5hYy51azEgMB4GCSqG\n\t\t\t\t\t\tSIb3DQEJARYRaXRzLXN5c0ByZ3UuYWMudWswHhcNMTUwNzAxMDY1OTQzWhcNMjUw\n\t\t\t\t\t\tNjI4MDY1OTQzWjCBsDELMAkGA1UEBhMCR0IxFjAUBgNVBAgTDUFiZXJkZWVuc2hp\n\t\t\t\t\t\tcmUxETAPBgNVBAcTCEFiZXJkZWVuMSEwHwYDVQQKExhSb2JlcnQgR29yZG9uIFVu\n\t\t\t\t\t\taXZlcnNpdHkxFDASBgNVBAsTC0lUIFNlcnZpY2VzMRswGQYDVQQDExJzaGliMmlk\n\t\t\t\t\t\tcC5yZ3UuYWMudWsxIDAeBgkqhkiG9w0BCQEWEWl0cy1zeXNAcmd1LmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtlnIv3WseSau1bSwKYgWnl3w\n\t\t\t\t\t\tW4A510yAe4EVHxCDXPbblHFmZwjN3F1Elw56e1LlSwhS4zS25R/cfjrH4NPqsTqD\n\t\t\t\t\t\t5TWHmmTaduonCdzVhqJ9do9hLcFrfkCSGwJGswKGutbphOvcG2tvRCt/BBtxf5yu\n\t\t\t\t\t\tI2D/cZ1jwJoURJe1X+r2d0HyjU23wlG9ImY8VLHTLjndQAPWddnvSySTrCNagfDB\n\t\t\t\t\t\tKQU8vWEQomm4griv1CFs205eqWBriZjoyt/i8q3XY+smafZ1sRR90YoidYGK0FbU\n\t\t\t\t\t\tBiyOfsTgE++GBTXQzGPf+pIN5U8GD8PxgTNal6ncKps1hiquqQGlLCJ3pybMsQID\n\t\t\t\t\t\tAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVy\n\t\t\t\t\t\tYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUoPahtUqnvLSmYMgVnP2s16wxXpUw\n\t\t\t\t\t\tHwYDVR0jBBgwFoAUoPahtUqnvLSmYMgVnP2s16wxXpUwDQYJKoZIhvcNAQELBQAD\n\t\t\t\t\t\tggEBAEsrmXShp2e+MEVSjpWYYTh2Yj45DBeHJVpBlJzkeb7UB1EViBa0O4DPojh0\n\t\t\t\t\t\tPFjmkfCIAvoCQAF3BL8j92DL+ltQOWZ3bnUTePUrGzN6RAXC5Qcv8HzSM77t3Cm9\n\t\t\t\t\t\tStUmTfcMp0Y5Ij7nHQdllzQND4nYp2OOhcWxn1cbPGHWl5tORBKVC3CacgY34H4g\n\t\t\t\t\t\tnqpHZyD+ngZtpCdGUmqpndD5+H+l0s91nm00akyYxFuRCpm6c97Tf5BfADtAumVY\n\t\t\t\t\t\tXz2bbxGztusvVUYAr75X+daVeh+/9N9SEybqeOuk99VSHBDwwaVkFiul2LzZRi0V\n\t\t\t\t\t\tXyNCrBFWNSC7s6MHLPcmlrG8YdY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Robert Gordon University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rgu.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Robert Gordon University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://samltest.swamid.se/re_hei/sp.xml",
    {
      "entity_id": "https://samltest.swamid.se/re_hei/sp.xml",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish Academic Identity Federation (SWAMID)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.swamid.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SWAMID"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://samltest.swamid.se/disco",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFcTCCBFmgAwIBAgIQIu7k1beHBKgWb27d90Ad9jANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQwODAwMDAwMFoXDTE3MDQwNzIzNTk1OVowQDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRswGQYDVQQDExJzYW1sdGVzdC5z\nd2FtaWQuc2UwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCcJfNqCJmM\nCWZ9+h9MAT9WbT/e+eRpGE9H8eucnnq4weTeFbT+2Ma15hY8hI6gP4GsDIZsaxTu\nDGgIYXctfnl9MTz+9rlANOo8Wjuz6CJ2trJ6BdhPvkoITuSqmIWkFbmP7/0NGkoG\n167CGp/Eq5yZnUOdiKXquH2S5OCw3mB4HGpjUk7T13cN0jOOPiK2cQhUTuUUMaVO\nei0QblIfK/+9fusfYOjd5uzNg1QZ9FvvbB/wTw4Z11eGcZWKpAprIrbx6iw119eL\nU7dvJhgA96VJmesDQejf96Xtpn7bCbxdyBqw2AtooamyrVjnAeQ8NDXW7td9MUuM\n4/yhN9H+fHTVJNs8dCX5FKayw5YoxF8eTMjRk0ObICMrLl8M/EiOG9Eqfc3TPGTF\ndn81sOGc3WzifRyG5fXUx/Xw9vXVkRAkVO6T4n6OUQxn2be9hwXR7yFw9tTplPIl\ndabhc7iWU7NgEBcBI3RWCcRNv0OVsXIMDeGZ64SOm4mpKbXMVebsnSLXxV69T1l4\nM8EegMpraRWHrbtF27FkKZPZgCbNaQbfW4vtJoN9rN07Flz8GLr200WXAepXT14L\ndGwXqjx6Cu2oilkl2OoNWQbRg3dvn1j6XqnRLbio4bvuiCYYEPpjuWcHOs/GwMnz\npml7EL51yz9PTwNZTQXsLH/xKlzWf1BuBQIDAQABo4IBbzCCAWswHwYDVR0jBBgw\nFoAUDL2TaAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFG40O0IHvLK2kXS6s4hN\nCq0DTtPLMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQG\nCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgG\nBmeBDAECATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEu\nb3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKG\nKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsG\nAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJz\nYW1sdGVzdC5zd2FtaWQuc2UwDQYJKoZIhvcNAQEFBQADggEBAHnWOLDwhrYWfd7q\n2fwTaiRP/x/tVPocNgi/wgwo6oZzC1Ru/HPjfUmnj11zkOOHeF8cf2BT2diRptPi\nqDc+7HN8GrM87+Deqvjj4pw7j4hwMpcfNd2AzqW4nPmw4LgiRehITtUtMxL9mkDh\neN0pgldD544xQRUdxYmD9nUWiIaTmuxNqusKkqUTD/kO41i+BxIeaWiXsw6IC7o6\nkPPUQHr1h2na805Kjoy5ML8K2EO+kcvFqfo42gtwa7mN38hKB+jbKF5VqqmoSb4m\nln/3lobOqcV8rrFKjvnjC6iNTbdpQ65o8CoOcfzhWmb/7RxkZ4a9fyzxVS8fMAi6\nu3Qzm3Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFcTCCBFmgAwIBAgIQIu7k1beHBKgWb27d90Ad9jANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQwODAwMDAwMFoXDTE3MDQwNzIzNTk1OVowQDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRswGQYDVQQDExJzYW1sdGVzdC5z\nd2FtaWQuc2UwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCcJfNqCJmM\nCWZ9+h9MAT9WbT/e+eRpGE9H8eucnnq4weTeFbT+2Ma15hY8hI6gP4GsDIZsaxTu\nDGgIYXctfnl9MTz+9rlANOo8Wjuz6CJ2trJ6BdhPvkoITuSqmIWkFbmP7/0NGkoG\n167CGp/Eq5yZnUOdiKXquH2S5OCw3mB4HGpjUk7T13cN0jOOPiK2cQhUTuUUMaVO\nei0QblIfK/+9fusfYOjd5uzNg1QZ9FvvbB/wTw4Z11eGcZWKpAprIrbx6iw119eL\nU7dvJhgA96VJmesDQejf96Xtpn7bCbxdyBqw2AtooamyrVjnAeQ8NDXW7td9MUuM\n4/yhN9H+fHTVJNs8dCX5FKayw5YoxF8eTMjRk0ObICMrLl8M/EiOG9Eqfc3TPGTF\ndn81sOGc3WzifRyG5fXUx/Xw9vXVkRAkVO6T4n6OUQxn2be9hwXR7yFw9tTplPIl\ndabhc7iWU7NgEBcBI3RWCcRNv0OVsXIMDeGZ64SOm4mpKbXMVebsnSLXxV69T1l4\nM8EegMpraRWHrbtF27FkKZPZgCbNaQbfW4vtJoN9rN07Flz8GLr200WXAepXT14L\ndGwXqjx6Cu2oilkl2OoNWQbRg3dvn1j6XqnRLbio4bvuiCYYEPpjuWcHOs/GwMnz\npml7EL51yz9PTwNZTQXsLH/xKlzWf1BuBQIDAQABo4IBbzCCAWswHwYDVR0jBBgw\nFoAUDL2TaAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFG40O0IHvLK2kXS6s4hN\nCq0DTtPLMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQG\nCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgG\nBmeBDAECATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEu\nb3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKG\nKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsG\nAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJz\nYW1sdGVzdC5zd2FtaWQuc2UwDQYJKoZIhvcNAQEFBQADggEBAHnWOLDwhrYWfd7q\n2fwTaiRP/x/tVPocNgi/wgwo6oZzC1Ru/HPjfUmnj11zkOOHeF8cf2BT2diRptPi\nqDc+7HN8GrM87+Deqvjj4pw7j4hwMpcfNd2AzqW4nPmw4LgiRehITtUtMxL9mkDh\neN0pgldD544xQRUdxYmD9nUWiIaTmuxNqusKkqUTD/kO41i+BxIeaWiXsw6IC7o6\nkPPUQHr1h2na805Kjoy5ML8K2EO+kcvFqfo42gtwa7mN38hKB+jbKF5VqqmoSb4m\nln/3lobOqcV8rrFKjvnjC6iNTbdpQ65o8CoOcfzhWmb/7RxkZ4a9fyzxVS8fMAi6\nu3Qzm3Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://samltest.swamid.se/acs/re_hei/redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://samltest.swamid.se/acs/re_hei/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:eduserv.org.uk:athens:provider:liv.ac.uk",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gilbertson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webmaster@liv.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pretlove"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:T.Pretlove@liverpool.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:eduserv.org.uk:athens:provider:liv.ac.uk",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-02-09T16:53:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVANlUxUdyvt878JJZeQqXZAX2ZiW9MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCAxHjAcBgNVBAMTFXNoaWJib2xldGgzLmxpdi5hYy51azAeFw0xNDAzMjEx\n\t\t\t\t\t\tNjMxNDlaFw0zNDAzMjExNjMxNDlaMCAxHjAcBgNVBAMTFXNoaWJib2xldGgzLmxp\n\t\t\t\t\t\tdi5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKtlHz1hrD0F\n\t\t\t\t\t\tf0M6F1zN8ZBoY5qI2wYwfjcRuXVfZlSJVhODsOUWWxUnfdqV7KBA0HcgRCK008g2\n\t\t\t\t\t\th/sjZXH/VU8M0EHhaYHHkyQxSBwEjWhbVcOT9iI1TkZqHNqZtJQIw7rnybskkv/3\n\t\t\t\t\t\t6IiBtGZgkZL3CZjp0kkqsOh19k/cioEsNsd4cKUyvhVEUvqtO1VULemasTnkmUtk\n\t\t\t\t\t\txJegTZXyW2W6TYMlTxeTwJQWe97WNxpCvV/3ounzXnLTUG5Te4i2ptA67JItknmw\n\t\t\t\t\t\tkS1p/a6d9B63gvHch27jFzollXccq4Gb2VSNLq3B8eAo8+Hnny9vLYYlKH1H7H9q\n\t\t\t\t\t\tgAo8OSA2ZbUCAwEAAaNxMG8wTgYDVR0RBEcwRYIVc2hpYmJvbGV0aDMubGl2LmFj\n\t\t\t\t\t\tLnVrhixodHRwczovL3NoaWJib2xldGgzLmxpdi5hYy51ay9pZHAvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQU7Cmjd6WsvyQ90NQeufSKvO/8yVIwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAIhTLBoOX4fvW9dYMfvjD77y8lyo2UFdATt6G6KWlCosBDkOwDTGK4N5g7CU\n\t\t\t\t\t\t/AxoGWBYLtd+KHy5ii5oV781aMLPa3ClDs1UYE/NuwkylvoSO0+agpeH6oF7IJxH\n\t\t\t\t\t\tN7EsSimVuaLi/R2ghs0KLwv6JfFUkhO2G2S5VTS/FZn/B8NgmBo+fLuJ6DLCQwJJ\n\t\t\t\t\t\tvnqXf9DPozHSBUOQAEkZcjKRSl+QTO6SleKLg5ahHNC3kT+dzF2ACKJMC7f4WzAL\n\t\t\t\t\t\trA/YOcNxfwUB/eiEgmw9dDwpUvOuH+NDET/ASLH3mXUA1w7DkzzHTZkMn9k/Up6O\n\t\t\t\t\t\tSX7ypoc/4IGOgkCbLMA/5Z8ZidI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "liv.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth3.liv.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth3.liv.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth3.liv.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth3.liv.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth3.liv.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth3.liv.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth3.liv.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth3.liv.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth3.liv.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth3.liv.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth3.liv.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "liv.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVANlUxUdyvt878JJZeQqXZAX2ZiW9MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCAxHjAcBgNVBAMTFXNoaWJib2xldGgzLmxpdi5hYy51azAeFw0xNDAzMjEx\n\t\t\t\t\t\tNjMxNDlaFw0zNDAzMjExNjMxNDlaMCAxHjAcBgNVBAMTFXNoaWJib2xldGgzLmxp\n\t\t\t\t\t\tdi5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKtlHz1hrD0F\n\t\t\t\t\t\tf0M6F1zN8ZBoY5qI2wYwfjcRuXVfZlSJVhODsOUWWxUnfdqV7KBA0HcgRCK008g2\n\t\t\t\t\t\th/sjZXH/VU8M0EHhaYHHkyQxSBwEjWhbVcOT9iI1TkZqHNqZtJQIw7rnybskkv/3\n\t\t\t\t\t\t6IiBtGZgkZL3CZjp0kkqsOh19k/cioEsNsd4cKUyvhVEUvqtO1VULemasTnkmUtk\n\t\t\t\t\t\txJegTZXyW2W6TYMlTxeTwJQWe97WNxpCvV/3ounzXnLTUG5Te4i2ptA67JItknmw\n\t\t\t\t\t\tkS1p/a6d9B63gvHch27jFzollXccq4Gb2VSNLq3B8eAo8+Hnny9vLYYlKH1H7H9q\n\t\t\t\t\t\tgAo8OSA2ZbUCAwEAAaNxMG8wTgYDVR0RBEcwRYIVc2hpYmJvbGV0aDMubGl2LmFj\n\t\t\t\t\t\tLnVrhixodHRwczovL3NoaWJib2xldGgzLmxpdi5hYy51ay9pZHAvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQU7Cmjd6WsvyQ90NQeufSKvO/8yVIwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAIhTLBoOX4fvW9dYMfvjD77y8lyo2UFdATt6G6KWlCosBDkOwDTGK4N5g7CU\n\t\t\t\t\t\t/AxoGWBYLtd+KHy5ii5oV781aMLPa3ClDs1UYE/NuwkylvoSO0+agpeH6oF7IJxH\n\t\t\t\t\t\tN7EsSimVuaLi/R2ghs0KLwv6JfFUkhO2G2S5VTS/FZn/B8NgmBo+fLuJ6DLCQwJJ\n\t\t\t\t\t\tvnqXf9DPozHSBUOQAEkZcjKRSl+QTO6SleKLg5ahHNC3kT+dzF2ACKJMC7f4WzAL\n\t\t\t\t\t\trA/YOcNxfwUB/eiEgmw9dDwpUvOuH+NDET/ASLH3mXUA1w7DkzzHTZkMn9k/Up6O\n\t\t\t\t\t\tSX7ypoc/4IGOgkCbLMA/5Z8ZidI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Liverpool"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.liv.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Liverpool"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:unoh.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jbrinkman@unoh.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeremy Brinkman"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:unoh.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://webauth.unoh.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webauth.unoh.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://webauth.unoh.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://webauth.unoh.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unoh.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Northwestern Ohio"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIULy08BQkcpOnmTH92+QGu+JKU2UMwDQYJKoZIhvcNAQEF\nBQAwGzEZMBcGA1UEAxMQd2ViYXV0aC51bm9oLmVkdTAeFw0xMjAyMjgwNDE5MDda\nFw0zMjAyMjgwNDE5MDdaMBsxGTAXBgNVBAMTEHdlYmF1dGgudW5vaC5lZHUwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDNTQ99SNOAMAG2sUR5nddeVQOx\namxRlm2l/Qa7HaK0OTtHPuqaioCF4pOpH9Q8cS/MbeVJPcKsSTH7bnDANgsYgAcC\nx3rK+4zBkKm/Zk5JhbsXsXM03A1lrx7C6hspEAv6HMvLwv16V7oH+Pi1QbZTWKq+\nwgwSaAB1bgXNL/xl2utakKBNMP+qMZ1KglkvAd0rLKy7i2saq9SjIHSoGctDc15m\nbVptXk2YD5+Iv2V8/cj26pokr0firEw01V4l2Jh1bbwTZr7B5x/yGs5gko5hnL7B\n4YbesHO7ujhl0qxyzLcVw4O1epKAbYD4KTux9ioAhxAWvmq41SBDCj6xwmpLAgMB\nAAGjZzBlMEQGA1UdEQQ9MDuCEHdlYmF1dGgudW5vaC5lZHWGJ2h0dHBzOi8vd2Vi\nYXV0aC51bm9oLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUEPzvkxKJhFqL\nyRv3sXdRHNtlEVowDQYJKoZIhvcNAQEFBQADggEBAHp0Aa/XbXyp/jjgoTLx1FM9\nQ27hLwG3hL880Sl0xmEsVo1RmYvUYr6XcBZ9V7l7YgEX7cUEKd2rYjX2dCtc57Pv\nUPvOz7YC8Z+zqtrQrw4Qzej1pr1Kb8GF5J0pdiGgTDxdp8HMeT/xl9vSumnL83yS\nhAOnSgGr4+3CaQiYG2uD/usYib6kkAdG9kUtaNvSgA+kqXEgDew6K7gQRAgGgD9+\nTj0jVc553XRlzq170MaFkOWMrL/FaIRfj2OdSD/0W0B+ry2Fg1+8S3AJNPuFNMF0\nOfmbJ3v2CPAigA44FKZBy9+77vXYadvgl9q2bnhvQE6qMf+lUj6VmKa+fyuEPvk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "error_url": "https://webauth.unoh.edu/error.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Northwestern Ohio"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://unoh.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Northwestern Ohio"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.mzk.cz/simplesaml/metadata.xml",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@mzk.cz"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.mzk.cz/simplesaml/metadata.xml",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2011-08-10T11:54:57Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/library"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.mzk.cz/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.mzk.cz/simplesaml/shib13/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.mzk.cz/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.mzk.cz/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mzk.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mzk.cz/en"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mzk.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for employees and readers of the Moravian Library in Brno"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance a \u010dten\u00e1\u0159e Moravsk\u00e9 zemsk\u00e9 knihovny"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www2.eduid.cz/idp-loga/mzk.png",
                    "height": "68",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "92"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The Moravian Library in Brno"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Moravsk\u00e1 zemsk\u00e1 knihovna"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Moravian Library"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Moravsk\u00e1 zemsk\u00e1 knihovna"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mzk.cz/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mzk.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Moravian Library"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Moravsk\u00e1 zemsk\u00e1 knihovna"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://student.ate.grayzone.ladok.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://student.ate.grayzone.ladok.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://student.ate.grayzone.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok student.ate.grayzone.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok student.ate.grayzone.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://student.ate.grayzone.ladok.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "student.ate.grayzone.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWzCCAkOgAwIBAgIJAOBK9PZhQOs2MA0GCSqGSIb3DQEBCwUAMCgxJjAkBgNV\nBAMTHXN0dWRlbnQuYXRlLmdyYXl6b25lLmxhZG9rLnNlMB4XDTE2MDQyNzEyMjg0\nMVoXDTI2MDQyNTEyMjg0MVowKDEmMCQGA1UEAxMdc3R1ZGVudC5hdGUuZ3JheXpv\nbmUubGFkb2suc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCfxgev\njQV/269Epy5aAcDBvQZwV0wYvI+RejGTw5Ac7Nmk5GkyvnUrmA0S206OTaqIuudX\nga4IlckmGA/85hkkiky7FplOrcqBS3hWWM386KuOs+HmoDmobe+A7ayh0afQJPWn\nuij/jbeneh/N+1mwudS2g+Qk+S+PXPm737i2VL8or1SiVWJdQOg2qWAvvuGePNZt\nFkvAd/+Ef+oqnWONkL0hG1GBO4l2cVoTwqt4Dm3sUbukEAehcEwzAdv0vYDRDveQ\n13Y6DCRZIh1/5GYIEn55hPshdoGzXdOo4eTNyom8QqxVGgl0pmEGC0gCUjOcmA67\nFXcu1RBZMst2iDJ1AgMBAAGjgYcwgYQwYwYDVR0RBFwwWoIdc3R1ZGVudC5hdGUu\nZ3JheXpvbmUubGFkb2suc2WGOWh0dHBzOi8vc3R1ZGVudC5hdGUuZ3JheXpvbmUu\nbGFkb2suc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAdBgNVHQ4EFgQUKYqRC3vBn5WL\nbADDc9OP1ttbAuQwDQYJKoZIhvcNAQELBQADggEBAHE8V8tNdPlFRyn2XkKWLp+k\nPXVDWLIRNTQ58Nt4el7umnnHtpzjRvdvtZfA5usd4E851SKPPxYaKz6Dqe2dv6YS\n2wxiJ/soTvIP0itkxXKenl5fxBT0O33iM2x013t2CkFY1OBDJ5ZZw35hwj86q53v\nJX9l6msxElSv70clZU9S+TXEcbgMuUQvc00vdrUjy3C4oi66cSBvkN+pu5zjFBG1\nNcJjSEwosSeScrbtXcS5mMUx+8+IPqk+4rNbYA5BTpdbaEkRt1Hre8p4n9bNRgJf\n/6ALKcljd/KBbxSMvRne29oBEuJEjibi7D3+eQB+QyBne2v0EaKHxcOp6D2iJHI="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=student.ate.grayzone.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://athensla.uwe.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lib.it@uwe.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Library IT Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lib.it@uwe.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Library IT Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://athensla.uwe.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://athensla.uwe.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://athensla.uwe.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uwe.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://library.uwe.ac.uk/uwe/uwelogoopenathens.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "155"
                  },
                  {
                    "text": "https://library.uwe.ac.uk/uwe/favicon.gif",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of the West of England (UWE)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDcTCCAlmgAwIBAgIJAJ8fe5216tbDMA0GCSqGSIb3DQEBBQUAME8xMDAuBgNV\n\t\t\t\t\t\tBAoMJ1VuaXZlcnNpdHkgb2YgdGhlIFdlc3Qgb2YgRW5nbGFuZCAoVVdFKTEbMBkG\n\t\t\t\t\t\tA1UEAwwSYXRoZW5zbGEudXdlLmFjLnVrMB4XDTEzMTIwMjE2MzQ1N1oXDTIzMTEz\n\t\t\t\t\t\tMDE2MzQ1N1owTzEwMC4GA1UECgwnVW5pdmVyc2l0eSBvZiB0aGUgV2VzdCBvZiBF\n\t\t\t\t\t\tbmdsYW5kIChVV0UpMRswGQYDVQQDDBJhdGhlbnNsYS51d2UuYWMudWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCc8ii9gKVq+K5jeXMigwfR7XdrauZT\n\t\t\t\t\t\tEixNOzSZMJVmjvlQP1FYwkYY6+wq6c8OQ7OhxlCbWknz3bZo9CxS75OX8eIEr5Nx\n\t\t\t\t\t\tWww4Qh8i3XOqXgtbSRN+bLvt1A1L6YRAjyP7weIZOic4VjPoBsOUWGXC+QzZB7lV\n\t\t\t\t\t\t0x9Lq5FR3GZBQXLGXN+Vl/0WsCZYORGnkZutkUnTaJ0u3CJp7qfYJcTUIoyC1/mf\n\t\t\t\t\t\tghMBgaRr+zlXuN5B7gH89CfA8RLvSoQLzrE0y46+o9+0lEIScEzBUdBhvSABrslP\n\t\t\t\t\t\t+e3Hf9aisLE6p0mRFxHI/Jp/9W68HRfFauzIKggwcKoTNQ9yKvrmLY9DAgMBAAGj\n\t\t\t\t\t\tUDBOMB0GA1UdDgQWBBRTGhswU9gRevAWF9xO/U8h0e2K9DAfBgNVHSMEGDAWgBRT\n\t\t\t\t\t\tGhswU9gRevAWF9xO/U8h0e2K9DAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUA\n\t\t\t\t\t\tA4IBAQBXSNwVMyQ6ZkJf28QyTOpTOySPoCJTbWeQh+ZMgvVYMhxcoV552G9fLKE+\n\t\t\t\t\t\tLz7uGElnjkYGPiLzRBC+hS4rv2xxzw1NY8JVPKSJQj3+NA5W2fb/rz/dzTG/ws5H\n\t\t\t\t\t\tUQVopDsQO6nfhP39wWkc+V8j7ZdorE7OuqetlH/clf0rsXAUEvUKsnH/ZSqqCi6j\n\t\t\t\t\t\t7HdU98sddgEqv6g71J+BPECPq4FBNr9S9Enbi7NxqMicfFMiEnK5DvDaDwI+RC54\n\t\t\t\t\t\tWa4FCcK/O6SB8OgD8Dk59xmFXwEGyMUjNvjTZqKMFRmwS8zDyDtCWyi87GKqrAP1\n\t\t\t\t\t\tuzXnYMVigld+IhPeyJ4tin2r6+bQ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of the West of England (UWE)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uwe.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of the West of England, Bristol"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://openathensr.guildford.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bennett"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cbennett@guildford.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Charlie"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bennett"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cbennett@guildford.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Charlie"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://openathensr.guildford.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-06-22T11:30:09Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://openathensr.guildford.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://openathensr.guildford.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "guildford.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVjCCAj6gAwIBAgIIe3m5sSwnVj4wDQYJKoZIhvcNAQEFBQAwQjEaMBgGA1UE\n\t\t\t\t\t\tCgwRR3VpbGRmb3JkIENvbGxlZ2UxJDAiBgNVBAMMG29wZW5hdGhlbnNyLmd1aWxk\n\t\t\t\t\t\tZm9yZC5hYy51azAeFw0xMjA2MTgwOTU0MDhaFw0yMjA2MTgwOTU0MDhaMEIxGjAY\n\t\t\t\t\t\tBgNVBAoMEUd1aWxkZm9yZCBDb2xsZWdlMSQwIgYDVQQDDBtvcGVuYXRoZW5zci5n\n\t\t\t\t\t\tdWlsZGZvcmQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCa\n\t\t\t\t\t\tjH7z+VqWeDSvhMnEFsD4sZsOfJhV3NX7HGVHCVqTFsymT0wEBvO0b8b7lZCKV9b/\n\t\t\t\t\t\tH02a+SMOJ2LTvotBv8PZRAewXduxXJ6oE7WHzQhjuoEE+yKJD/QM1Si9KAABbwHg\n\t\t\t\t\t\tZue3CnUGhxxSM775UBtXiW9H6eKJTwl1IRJCVPw5HiLAjFhQxKCz0B+40a6oGxUt\n\t\t\t\t\t\tS6UPfWHL+Crpyl8aax6W9XkIfscztQKwDBna4n6XSZTX9Kx3DZccj8hy03UW+GSv\n\t\t\t\t\t\tioBJjgokeECz6XO3gO5BH5JJyILascOCYBfabt4NlJ+cA53D96sUg8OLi5RkORnB\n\t\t\t\t\t\tVj1ksTMHxy/Qtgtna+JxAgMBAAGjUDBOMB0GA1UdDgQWBBRFFB5eZ8WhztAdakWm\n\t\t\t\t\t\tcUfH9sR0bDAfBgNVHSMEGDAWgBRFFB5eZ8WhztAdakWmcUfH9sR0bDAMBgNVHRME\n\t\t\t\t\t\tBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAfA4k20dG3AmWR/ubqcyMTGk8cs4o6\n\t\t\t\t\t\tFQ/E4wYSC5CuAlrE/8NC9r52FcQ6vhoVKGKeWMvT9k7/z7lz+GOoF3TjzEk2JKhC\n\t\t\t\t\t\tiQpsPXCCCngMORcqAJVHow/Q3MEOLrr2G/Z6FMygD67bU6svpF5AZWY95xMQcVCD\n\t\t\t\t\t\tfUmYMaQlV7g+KidGHADcvmK4xufY93k+depQ2OM4rgWwk4LrtZJ+GisQR/2LJPtD\n\t\t\t\t\t\tMfNnu1LliAg8Qfmdm1sbMMrnouVuGHIbkDW3FqWMbicC7j7SGEiTjH96jhDEA/2u\n\t\t\t\t\t\tDcpYU47hTFotoLC3G834xdmNGHL9v+rdRsnSVaZ0eGmXA+MS+2QQDO60"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVjCCAj6gAwIBAgIIe3m5sSwnVj4wDQYJKoZIhvcNAQEFBQAwQjEaMBgGA1UE\n\t\t\t\t\t\tCgwRR3VpbGRmb3JkIENvbGxlZ2UxJDAiBgNVBAMMG29wZW5hdGhlbnNyLmd1aWxk\n\t\t\t\t\t\tZm9yZC5hYy51azAeFw0xMjA2MTgwOTU0MDhaFw0yMjA2MTgwOTU0MDhaMEIxGjAY\n\t\t\t\t\t\tBgNVBAoMEUd1aWxkZm9yZCBDb2xsZWdlMSQwIgYDVQQDDBtvcGVuYXRoZW5zci5n\n\t\t\t\t\t\tdWlsZGZvcmQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCa\n\t\t\t\t\t\tjH7z+VqWeDSvhMnEFsD4sZsOfJhV3NX7HGVHCVqTFsymT0wEBvO0b8b7lZCKV9b/\n\t\t\t\t\t\tH02a+SMOJ2LTvotBv8PZRAewXduxXJ6oE7WHzQhjuoEE+yKJD/QM1Si9KAABbwHg\n\t\t\t\t\t\tZue3CnUGhxxSM775UBtXiW9H6eKJTwl1IRJCVPw5HiLAjFhQxKCz0B+40a6oGxUt\n\t\t\t\t\t\tS6UPfWHL+Crpyl8aax6W9XkIfscztQKwDBna4n6XSZTX9Kx3DZccj8hy03UW+GSv\n\t\t\t\t\t\tioBJjgokeECz6XO3gO5BH5JJyILascOCYBfabt4NlJ+cA53D96sUg8OLi5RkORnB\n\t\t\t\t\t\tVj1ksTMHxy/Qtgtna+JxAgMBAAGjUDBOMB0GA1UdDgQWBBRFFB5eZ8WhztAdakWm\n\t\t\t\t\t\tcUfH9sR0bDAfBgNVHSMEGDAWgBRFFB5eZ8WhztAdakWmcUfH9sR0bDAMBgNVHRME\n\t\t\t\t\t\tBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAfA4k20dG3AmWR/ubqcyMTGk8cs4o6\n\t\t\t\t\t\tFQ/E4wYSC5CuAlrE/8NC9r52FcQ6vhoVKGKeWMvT9k7/z7lz+GOoF3TjzEk2JKhC\n\t\t\t\t\t\tiQpsPXCCCngMORcqAJVHow/Q3MEOLrr2G/Z6FMygD67bU6svpF5AZWY95xMQcVCD\n\t\t\t\t\t\tfUmYMaQlV7g+KidGHADcvmK4xufY93k+depQ2OM4rgWwk4LrtZJ+GisQR/2LJPtD\n\t\t\t\t\t\tMfNnu1LliAg8Qfmdm1sbMMrnouVuGHIbkDW3FqWMbicC7j7SGEiTjH96jhDEA/2u\n\t\t\t\t\t\tDcpYU47hTFotoLC3G834xdmNGHL9v+rdRsnSVaZ0eGmXA+MS+2QQDO60"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Guildford College Open Athens Service"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.guildford.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Guildford College of Further and Higher Education"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibbo.tul.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Adamec"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Petr.Adamec@tul.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kmoch"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "David.Kmoch@tul.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibbo.tul.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2010-09-20T11:45:42Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/university"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID6jCCAtKgAwIBAgIBCjANBgkqhkiG9w0BAQsFADCBmjELMAkGA1UEBhMCQ1ox\n                        EDAOBgNVBAcTB0xpYmVyZWMxKDAmBgNVBAoTH1RlY2huaWNhbCBVbml2ZXJzaXR5\n                        IG9mIExpYmVyZWMxDjAMBgNVBAsTBUxpYW5lMSIwIAYDVQQDExlUVUwgQ2VydGlm\n                        aWNhdGUgQXV0aG9yaXR5MRswGQYJKoZIhvcNAQkBFgxsaWFuZUB0dWwuY3owHhcN\n                        MTUxMDI2MDAwMDAwWhcNMzAxMDI1MjM1OTU5WjBxMQswCQYDVQQGEwJDWjEQMA4G\n                        A1UEBxMHTGliZXJlYzEoMCYGA1UEChMfVGVjaG5pY2FsIFVuaXZlcnNpdHkgb2Yg\n                        TGliZXJlYzEOMAwGA1UECxMFTGlhbmUxFjAUBgNVBAMTDXNoaWJiby50dWwuY3ow\n                        ggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCdUYyRY1/QVM6cuR3mTWpw\n                        wHdc6Aeuy/DNUcvzXUEnWZ6bhdPBScu231BBr9NCZ5wr8pZ3N4JB7n5qjScRqpz2\n                        D1VOtb/BLy8mFEThE/wWE6DINbAMzF1FQjGE4vLO7FWt0G1nURxqe5USZkFLIZUL\n                        Wqs1Fnrlfsl1hGbm2ELu/8gfXNbnKQKZ12a8qqojpwIec860+zGS+YkHyYz4IzUq\n                        kRHM0KQG0qcPzeB3OdQMy44nhHknLeNQ7WIpVAn1bx6g3blyAYxEhqGVjGxbm2j1\n                        r+FV2r/0ZrwVavM9aeOw3bX+F/M2VBPBsbimnuE/xYnjVhIN76PcsaMdtSsYR4+9\n                        AgMBAAGjYzBhMAsGA1UdDwQEAwIFoDAyBgNVHR8EKzApMCegJaAjhiFodHRwOi8v\n                        bGlhbmUudHVsLmN6L2NybC90dWxDQS5jcmwwHgYJYIZIAYb4QgENBBEWD3hjYSBj\n                        ZXJ0aWZpY2F0ZTANBgkqhkiG9w0BAQsFAAOCAQEAZfabkvqZVo4w4LOoLQfVtTP8\n                        VCI/HoJsgAsYl7Gf2RngZ76XAePhza0JNCfo0SJDJBWca0VtX91EzazFWkRR1cEO\n                        B0IwF0MVLQttZA8XItk0EaXi05sC/s4qeykLk31AP3mPD2SC58Vty2DbPCWJxLBQ\n                        31qNr9zxzVzDVAtzXkVWdfdRrgzFICDIfo9BqELUPCIcw2+/xzoy4h33NB05ZFa7\n                        +UqvbZl6I4Rz3ZWHt8moGUGQF04kKGI3psHS6M0hxMQccNtbb269gFcuK5vb5AZa\n                        nH0Q6NVuH5v93Y3fOM0wIgosOcrB90QrXq5BpWu+XL1VxhyPnSxTf/teOIy3hw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tul.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibbo.tul.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibbo.tul.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibbo.tul.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibbo.tul.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibbo.tul.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibbo.tul.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibbo.tul.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibbo.tul.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tul.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.tul.cz/en"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.tul.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Technical University of Liberec."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro Technickou univerzitu v Liberci."
                  }
                ],
                "logo": [
                  {
                    "text": "https://liane.tul.cz/img/znak-tul.png",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "40"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Technical University of Liberec"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Technick\u00e1 univerzita v Liberci"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID6jCCAtKgAwIBAgIBCjANBgkqhkiG9w0BAQsFADCBmjELMAkGA1UEBhMCQ1ox\n                        EDAOBgNVBAcTB0xpYmVyZWMxKDAmBgNVBAoTH1RlY2huaWNhbCBVbml2ZXJzaXR5\n                        IG9mIExpYmVyZWMxDjAMBgNVBAsTBUxpYW5lMSIwIAYDVQQDExlUVUwgQ2VydGlm\n                        aWNhdGUgQXV0aG9yaXR5MRswGQYJKoZIhvcNAQkBFgxsaWFuZUB0dWwuY3owHhcN\n                        MTUxMDI2MDAwMDAwWhcNMzAxMDI1MjM1OTU5WjBxMQswCQYDVQQGEwJDWjEQMA4G\n                        A1UEBxMHTGliZXJlYzEoMCYGA1UEChMfVGVjaG5pY2FsIFVuaXZlcnNpdHkgb2Yg\n                        TGliZXJlYzEOMAwGA1UECxMFTGlhbmUxFjAUBgNVBAMTDXNoaWJiby50dWwuY3ow\n                        ggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCdUYyRY1/QVM6cuR3mTWpw\n                        wHdc6Aeuy/DNUcvzXUEnWZ6bhdPBScu231BBr9NCZ5wr8pZ3N4JB7n5qjScRqpz2\n                        D1VOtb/BLy8mFEThE/wWE6DINbAMzF1FQjGE4vLO7FWt0G1nURxqe5USZkFLIZUL\n                        Wqs1Fnrlfsl1hGbm2ELu/8gfXNbnKQKZ12a8qqojpwIec860+zGS+YkHyYz4IzUq\n                        kRHM0KQG0qcPzeB3OdQMy44nhHknLeNQ7WIpVAn1bx6g3blyAYxEhqGVjGxbm2j1\n                        r+FV2r/0ZrwVavM9aeOw3bX+F/M2VBPBsbimnuE/xYnjVhIN76PcsaMdtSsYR4+9\n                        AgMBAAGjYzBhMAsGA1UdDwQEAwIFoDAyBgNVHR8EKzApMCegJaAjhiFodHRwOi8v\n                        bGlhbmUudHVsLmN6L2NybC90dWxDQS5jcmwwHgYJYIZIAYb4QgENBBEWD3hjYSBj\n                        ZXJ0aWZpY2F0ZTANBgkqhkiG9w0BAQsFAAOCAQEAZfabkvqZVo4w4LOoLQfVtTP8\n                        VCI/HoJsgAsYl7Gf2RngZ76XAePhza0JNCfo0SJDJBWca0VtX91EzazFWkRR1cEO\n                        B0IwF0MVLQttZA8XItk0EaXi05sC/s4qeykLk31AP3mPD2SC58Vty2DbPCWJxLBQ\n                        31qNr9zxzVzDVAtzXkVWdfdRrgzFICDIfo9BqELUPCIcw2+/xzoy4h33NB05ZFa7\n                        +UqvbZl6I4Rz3ZWHt8moGUGQF04kKGI3psHS6M0hxMQccNtbb269gFcuK5vb5AZa\n                        nH0Q6NVuH5v93Y3fOM0wIgosOcrB90QrXq5BpWu+XL1VxhyPnSxTf/teOIy3hw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Technical University of Liberec"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Technick\u00e1 univerzita v Liberci"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tul.cz/en"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tul.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Technical University of Liberec"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Technick\u00e1 univerzita v Liberci"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ndsu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ndsu.helpdesk@ndsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NDSU Help Desk"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ndsu.helpdesk@ndsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NDSU Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ndsu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ndsu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ndsu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ndsu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ndsu.edu/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ndsu.edu/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ndsu.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ndsu.edu/eci/shibboleth/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "North Dakota State University Main Campus"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "North Dakota State University"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.ndsu.edu/shibboleth/logo.png",
                    "lang": "en",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.ndsu.edu/its/security/privacy_statement/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKTCCAhGgAwIBAgIJAJsvdlzoRM6CMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDGlkcC5uZHN1LmVkdTAeFw0xMzA1MTMxOTMxMDVaFw0xODA1MTIxOTMxMDVa\nMBcxFTATBgNVBAMTDGlkcC5uZHN1LmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAMC7bcUABc9e/fkMLsftMozcIv4StDmtw2WJMkkRjyv1/neZCrQN\n2gwFzXlxwC89+xx+F9Tzj5AwmdHStJVIX3mH28ZXZiIlWkm0aBZ+Jfej71CaDXpn\nVT20rPjo/srBkGGC8k+KWlV+cXw6nXrNXNcxNrM7RK+IV73mbqdduc6mslbF8Sli\n2M+RJ/2SomDRUmCRzY4FMF2pK+0t8EbMH4DyDj/9LOmBXL5iLVZn+ooERjYzMEMY\nQBTpQDCv9MhLe6J6VG0nVk0hnFTl1IAXHPa2EaMVOQ+UOljF4vvgMlHsUGTL6O67\nwlWV7nePC0P9u4eCIE5bkjTUyqNdf9C3HX8CAwEAAaN4MHYwHQYDVR0OBBYEFEBA\nDtYWDs4yQxunFWo59NZgir71MEcGA1UdIwRAMD6AFEBADtYWDs4yQxunFWo59NZg\nir71oRukGTAXMRUwEwYDVQQDEwxpZHAubmRzdS5lZHWCCQCbL3Zc6ETOgjAMBgNV\nHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQA/mWK3R7KmAxzSAzmhYN/DCndC\nC81ew4MIO1O2hb0HaNL/AHu8HcDvzAaftLWLfaLXPMh9Rjz9uA2STFBBTM/oKUAl\nGFGz7NTnKDuGNMVmuvVsRJZazn358ut1Xfb5/71DsxwShes5EURRGcMS8k3HNMnI\nnPRxc/bMRjwLBPtRcj1xRshA23oVn6lIed1X7v9dw669D1wPokxISGfyhX/VW9Hz\n1T4qDbBdK5k9K5NyX1HtLsLHWVhZoAy1AL5rpS0l0MhLohRz7ID3aclZ8BcXe4+R\ndMYsTGki/jn1sU0tN+ygdpOluNqxubLuutgONSK4fPKLr86vj0B6rzCRo1VM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://www.ndsu.edu/its/help_desk/"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "North Dakota State University Main Campus"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ndsu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "North Dakota State University Main Campus"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sse-idp.lanet.lv",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ITserviss"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itserviss@lu.lv"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sse-idp.lanet.lv",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://laife.lanet.lv/wiki/Latvian-Academic-Identity-Federation-Policy.pdf"
              }
            ],
            "registration_instant": "2013-10-10T10:10:10Z",
            "registration_authority": "http://laife.lanet.lv/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sse-idp.lanet.lv/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sse-idp.lanet.lv/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:56.950974,24.116292"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Stockholm School of Economics in Riga"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Stockholm School of Economics in Riga - SSE IDP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://laife.lanet.lv/"
          },
          {
            "lang": "lv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sseriga.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LAIFE - SSE"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ipb.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Moniez"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "philippe.moniez@ipb.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ipb.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2011-08-29T14:12:44Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ipb.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ipb.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ipb.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ipb.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.bordeaux-inp.fr/"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IPB - Bordeaux INP"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IPB - Bordeaux INP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEYjCCA0qgAwIBAgIRALgbEIwRuh3U84klcQg/9UAwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDA1MjgwMDAwMDBaFw0xNzA1MjcyMzU5NTlaMDgxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDETMBEGA1UEAxMKaWRwLmlwYi5m\ncjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK4nVfui+Zt1Trzesy1o\n2T60W4uaIWixKu80BtFxgCW8wacQ9wOwFYWm4LfKRILmNI0p8OnXD+9wHaBOnx44\nwof+tuWZJjXVqvdgq9WIZ+3VSEJkI/wvA7KgHdPaVSPWX6OHDU0K1gm74OjEdHb+\nhFPBiyZ3VW8GALHDUWWjYjDJGUoqOKf/Y0nymNWREKN7y18BqcFhW3JMTHRoepse\nfu5uRqhYU/0YHaZD97oW7fo25N3EF3Ca59uWPYG/1Twhd/OwlIBpTzAbPt903YNk\nRtchHYflp1oJKqkz/dW1h7ueGPKz6QZj4ebM7pwF4fL0TwDtsre67jL8KjtFodvj\nvEcCAwEAAaOCAWcwggFjMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdXR+qQ47nt\nMB0GA1UdDgQWBBTnzkMBxq38x6wZ8nj2FKqHYXDW6DAOBgNVHQ8BAf8EBAMCBaAw\nDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwIgYD\nVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0fBDMwMTAvoC2g\nK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcmwwbQYI\nKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50ZXJlbmEu\nb3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29jc3AudGNz\nLnRlcmVuYS5vcmcwFQYDVR0RBA4wDIIKaWRwLmlwYi5mcjANBgkqhkiG9w0BAQUF\nAAOCAQEAe8v3WPdLO5+RWtLXf40JeFjGPbFgf9pdsJwpnHCkD7up8PapvqwxENzD\nPj6laE+YWc6GXI1IeCX7Niye/09BBtn4SW4KVIp8u9qLiDQsrmb9c56xosPQP2/l\n9fC8VzlwnAQ/hrQjyXOA6WaEGRMK5LeWDXZfkos+afU0m/gVl4i57rRNM/B1AgO2\nwORHtv4Q51ZnfSkDLOjKG98VQKN2RTtPvrnj4TnIvp8KSFbfH7ETyJq8l5nA2lHs\nZKgUrRmjDmCf5UuCYHwMtOgFzULqTmmHdveUn/tYTyooHhj9tGz0NOXuzji6RUPt\n6XlibuDkkJwzRII2QYI3FB+8/h7Vqg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IPB - Bordeaux INP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.bordeaux-inp.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IPB - Bordeaux INP"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.bolton-sfc.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ratcliffe"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kev@bolton-sfc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kevin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ratcliffe"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kev@bolton-sfc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kevin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.bolton-sfc.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVzCCAj+gAwIBAgIUWPJgrnNMjlbymBlvPaO34/X+UVswDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJjEkMCIGA1UEAxMbc2hpYmJvbGV0aC5ib2x0b24tc2ZjLmFjLnVrMB4XDTEz\n\t\t\t\t\t\tMTExMTEzMDE1OFoXDTMzMTExMTEzMDE1OFowJjEkMCIGA1UEAxMbc2hpYmJvbGV0\n\t\t\t\t\t\taC5ib2x0b24tc2ZjLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\n\t\t\t\t\t\tAQEAhQnvJrLzeiakUFvRRezAt2TPOMDRSgg6jZvnjaD489IZbDTbod7VBI3LGMKq\n\t\t\t\t\t\tD/sox6gm/tM42nYXpL/UBCyfP5GYc6ahLg0CSPtmv/uY2TUZEJzUNjQG2X7LzbUv\n\t\t\t\t\t\tyWzG8HniHgag9q0FLRx6Qf1jNWCLVEOEPtceWJz+UCDdJzOvjYE6/XIqQ/7tY+V8\n\t\t\t\t\t\t2yDafdgzOOoNNkPYuuY4qUcGLvKP0WNos04YdZZr3P5JEvey1Ssvb+LAiExKNHmC\n\t\t\t\t\t\tCFMLNd/zFwEE/TMno412PSPhfbSuAbCropK4QvV67nf7pOZQ6llX3XvWNuL7fN4t\n\t\t\t\t\t\tFtwHCwYYHDm6JzksA56K4QugkwIDAQABo30wezBaBgNVHREEUzBRghtzaGliYm9s\n\t\t\t\t\t\tZXRoLmJvbHRvbi1zZmMuYWMudWuGMmh0dHBzOi8vc2hpYmJvbGV0aC5ib2x0b24t\n\t\t\t\t\t\tc2ZjLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQ908freXtGmAgPCz06\n\t\t\t\t\t\tptbx0ZuXHjANBgkqhkiG9w0BAQUFAAOCAQEAP0xmq5ftDMTIuPDbqPNvfR/GrDTo\n\t\t\t\t\t\tNfX8pt5dTiTvTqJC0g2YCHWgQt1rOZl1ZjXyNFaDwqg4VVEVLvG2k99FshXsZzY7\n\t\t\t\t\t\tRwp8AfzaNt5B9TpRRhchBVwgfpXbhHVsSB602J0qYHHgGY7IvlaZ9xGq2B6OgCR2\n\t\t\t\t\t\t+l2Yh1ZOPqvRkj1VINzLNwJLroZLGURQoqwsADWBw9GRr/6hecHiE3T33dCHzfcd\n\t\t\t\t\t\tv16BqVBjhtbPhTq4MRodc625S0JJL6xdKuw7ieAP/ElEQV0nLGayyZQMdwpHQnfO\n\t\t\t\t\t\tXcpfcLXmf8Vsttog01faahJDcIECJTYOmK9VlxRX2KSD60rDfqmUWFGbhQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bolton-sfc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.bolton-sfc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.bolton-sfc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.bolton-sfc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.bolton-sfc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.bolton-sfc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.bolton-sfc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.bolton-sfc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.bolton-sfc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bolton-sfc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVzCCAj+gAwIBAgIUWPJgrnNMjlbymBlvPaO34/X+UVswDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJjEkMCIGA1UEAxMbc2hpYmJvbGV0aC5ib2x0b24tc2ZjLmFjLnVrMB4XDTEz\n\t\t\t\t\t\tMTExMTEzMDE1OFoXDTMzMTExMTEzMDE1OFowJjEkMCIGA1UEAxMbc2hpYmJvbGV0\n\t\t\t\t\t\taC5ib2x0b24tc2ZjLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\n\t\t\t\t\t\tAQEAhQnvJrLzeiakUFvRRezAt2TPOMDRSgg6jZvnjaD489IZbDTbod7VBI3LGMKq\n\t\t\t\t\t\tD/sox6gm/tM42nYXpL/UBCyfP5GYc6ahLg0CSPtmv/uY2TUZEJzUNjQG2X7LzbUv\n\t\t\t\t\t\tyWzG8HniHgag9q0FLRx6Qf1jNWCLVEOEPtceWJz+UCDdJzOvjYE6/XIqQ/7tY+V8\n\t\t\t\t\t\t2yDafdgzOOoNNkPYuuY4qUcGLvKP0WNos04YdZZr3P5JEvey1Ssvb+LAiExKNHmC\n\t\t\t\t\t\tCFMLNd/zFwEE/TMno412PSPhfbSuAbCropK4QvV67nf7pOZQ6llX3XvWNuL7fN4t\n\t\t\t\t\t\tFtwHCwYYHDm6JzksA56K4QugkwIDAQABo30wezBaBgNVHREEUzBRghtzaGliYm9s\n\t\t\t\t\t\tZXRoLmJvbHRvbi1zZmMuYWMudWuGMmh0dHBzOi8vc2hpYmJvbGV0aC5ib2x0b24t\n\t\t\t\t\t\tc2ZjLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQ908freXtGmAgPCz06\n\t\t\t\t\t\tptbx0ZuXHjANBgkqhkiG9w0BAQUFAAOCAQEAP0xmq5ftDMTIuPDbqPNvfR/GrDTo\n\t\t\t\t\t\tNfX8pt5dTiTvTqJC0g2YCHWgQt1rOZl1ZjXyNFaDwqg4VVEVLvG2k99FshXsZzY7\n\t\t\t\t\t\tRwp8AfzaNt5B9TpRRhchBVwgfpXbhHVsSB602J0qYHHgGY7IvlaZ9xGq2B6OgCR2\n\t\t\t\t\t\t+l2Yh1ZOPqvRkj1VINzLNwJLroZLGURQoqwsADWBw9GRr/6hecHiE3T33dCHzfcd\n\t\t\t\t\t\tv16BqVBjhtbPhTq4MRodc625S0JJL6xdKuw7ieAP/ElEQV0nLGayyZQMdwpHQnfO\n\t\t\t\t\t\tXcpfcLXmf8Vsttog01faahJDcIECJTYOmK9VlxRX2KSD60rDfqmUWFGbhQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bolton Sixth Form College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bolton-sfc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Bolton Sixth Form College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://repository.abertay.ac.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:isservicedesk@abertay.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Watt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:colin.watt@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Colin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://repository.abertay.ac.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2012-12-10T13:04:57Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Digital Research Repository"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.abertay.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Abertay Dundee"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://repository.abertay.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://repository.abertay.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://repository.abertay.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://repository.abertay.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://repository.abertay.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://repository.abertay.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJAMHx/2oqSbXWMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\n\t\t\t\t\t\tBAMTDmxhYy1yZXBvLWxpdmU5MB4XDTEyMTEyNzE0MjE1M1oXDTIyMTEyNTE0MjE1\n\t\t\t\t\t\tM1owGTEXMBUGA1UEAxMObGFjLXJlcG8tbGl2ZTkwggEiMA0GCSqGSIb3DQEBAQUA\n\t\t\t\t\t\tA4IBDwAwggEKAoIBAQDJ9vq9tg+S9T5/aGYg5Mfd2tm4NI3LcZZir3/hqJ5Bjq9F\n\t\t\t\t\t\tvJ5gafvU85Np3kdUz0CJlitvg3D6fpfL3odhfJLZ/nalafXvyVbFHEqfUgjzRCwU\n\t\t\t\t\t\txyB0ExqofsExKpvXujLRFdn6mumYupp6otb/xvfGgW23f+2ZmS7Jv9zu9SwuU+Nr\n\t\t\t\t\t\teQhqUdVnyPYydisF5iMn12aFptn/2ZscTWWtrIL7MtLLTy7WV9Eq/m1D0FlbsNPN\n\t\t\t\t\t\tF3LmeAbDM5etk4NmcFt9XCjs+J4i38PR5QrMB0RvhTXm8e+/z59pVmz76XrtXhmh\n\t\t\t\t\t\tNBN3ToPLxS4I35XoUuUt5HRC5qazF8lbcW/Nn6apAgMBAAGjPDA6MBkGA1UdEQQS\n\t\t\t\t\t\tMBCCDmxhYy1yZXBvLWxpdmU5MB0GA1UdDgQWBBTs+3Y7cFrCnQ+3Cfo4Ji5HdNsI\n\t\t\t\t\t\t/zANBgkqhkiG9w0BAQUFAAOCAQEAArPWLF9YlItvEYMxgDYgwbEd0PNWYuUagNkb\n\t\t\t\t\t\tiCxjaAFwSGj5Vuq6+XtuyQb8LtHRtm/jnqm9xVsbY8vUOvOZmrTnCZMkuK+Zcjv4\n\t\t\t\t\t\tU0yiUxFjUVttOIoH+3GoYIWFHO3lHFCOFxslZF9Hg/sSMyTtEB0w5uqcdjDPsFjD\n\t\t\t\t\t\tcaMRH5TbGtBmGRK+F/VflLfSstl5y7jOP8jFdkj9a9Ul3RtUV07Y6yeu3gpTiLYY\n\t\t\t\t\t\tykCTM40AyIXjA/Ta2ITgcF/RrDnBjZsO1e1CA4DYl7T3NYli8IXbZFfo10GNAF3w\n\t\t\t\t\t\t8pR9IZk5rxzXJj2quy653rOhqoiZJ2sJw6cQW1ZXFas7jy6vfQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://repository.abertay.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://repository.abertay.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://repository.abertay.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://repository.abertay.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://repository.abertay.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://repository.abertay.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www-utb.ladok3.its.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www-utb.ladok3.its.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www-utb.ladok3.its.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www-utb.ladok3.its.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www-utb.ladok3.its.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www-utb.ladok3.its.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www-utb.ladok3.its.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www-utb.ladok3.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www-utb.ladok3.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Stage-milj\u00f6 inf\u00f6r deployer av Ladok3 i MIT-milj\u00f6n p\u00e5 ITS, Ume\u00e5 universitet"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Stage-milj\u00f6 f\u00f6r Ladok3 MIT"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www-utb.ladok3.its.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www-utb.ladok3.its.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIJAOmAgEHs6NUaMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\nBAMTGXd3dy11dGIubGFkb2szLml0cy51bXUuc2UwHhcNMTMwNDI0MTM1NDA4WhcN\nMjMwNDIyMTM1NDA4WjAkMSIwIAYDVQQDExl3d3ctdXRiLmxhZG9rMy5pdHMudW11\nLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvzs7P2frzQpin6Ox\nYTsxBpy4Dy6tyX1BvKZhMNYOFks6qFk5UIf3t81nfCAxdeIZ7tw/FGV1jfZ+s1mZ\nlXLAH062KAAJdxhhippuGMfyWPmnu43fVQzE/6yKGowdPAZTqWrbdc858G8JwLXp\n/7HP4hcnE2oLHn+pwwiI1kTqs0gg2Q4blq0pfPm7SQ0/tbbFqQkkivF0uNj7If8Y\nbsdQhqyKVEzHKkqzKE39yjRhhE5iNVOzn2nTKcd7V53Sqaby1MQonwB1zn7cvyG4\n5HgIOt0atrnFbNGmBW8pdLClkXk6bYs9svfidQzZOhCZqXMzl9boZrS4VAmwFrBE\nbaoTBQIDAQABo3EwbzBOBgNVHREERzBFghl3d3ctdXRiLmxhZG9rMy5pdHMudW11\nLnNlhihodHRwczovL3d3dy11dGIubGFkb2szLml0cy51bXUuc2UvZ3VpLXNwMB0G\nA1UdDgQWBBTOu+elHGibS8r2uWCq6uVpiKss2TANBgkqhkiG9w0BAQUFAAOCAQEA\nfNsBNNewci2Fly7iExEsg2sPjZLaRfN4Y3ED/bnD+5yyt5a+TU5PofiMjWbibYqY\nmjpQXxoHijt2IgpWrDyhzTsYwXWbN56zqWJ/99CgKn2k4gpE7dYHoMeSXyrZE+lN\nTHxa/tXWvkcKiWHg9iAju3VdFmakhtHY0XBtbigpdh6cnEBs8GGZk+fTDFJrOVOx\nfHsM5Sga4XV2d8SgRarY/dO6RiuI1UWcqHtWRemJqCf9K5xivDFBaIamRGe33IUq\nHCJqLLaJwhW98zEnNf0DCRdbDeEV1hoW8kZG9l3Mb1K6mOBCL/SUPDb9CzJ7timi\n0bv7yeENXHeHt62NLMnMig=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www-utb.ladok3.its.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www-utb.ladok3.its.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www-utb.ladok3.its.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www-utb.ladok3.its.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www-utb.ladok3.its.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www-utb.ladok3.its.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www-utb.ladok3.its.umu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www-utb.ladok3.its.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www-utb.ladok3.its.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www-utb.ladok3.its.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www-utb.ladok3.its.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www-trg.eng.cam.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:falcon-support@ucs.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Falcon Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:falcon-support@ucs.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Falcon Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www-trg.eng.cam.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-10-13T11:44:59Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Cambridge: Transportation Research Group"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www-trg.eng.cam.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Cambridge"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www-trg.eng.cam.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www-trg.eng.cam.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www-trg.eng.cam.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www-trg.eng.cam.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www-trg.eng.cam.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www-trg.eng.cam.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www-trg.eng.cam.ac.uk/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www-trg.eng.cam.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www-trg.eng.cam.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAOB8D/FajzX8MA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHd3dy1mYWxjb24uY3N4LmNhbS5hYy51azAeFw0xMDAxMTgxMTAwMDdaFw0y\n\t\t\t\t\t\tMDAxMTYxMTAwMDdaMCMxITAfBgNVBAMTGHd3dy1mYWxjb24uY3N4LmNhbS5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKpU2AuemKJSIeDmgjkZ\n\t\t\t\t\t\ttPgKaPPkM5CKu3QUHm5JzmtnG3UFMxbOumt6sxWWF72ceXQNPgBNGqFI/sFdaCIo\n\t\t\t\t\t\tHxZj+Z2i+k7/IVXhc4wjs72YUfrjvTMDhHHzndm3KkJS8imsIYQ8/bBnJEF93zVJ\n\t\t\t\t\t\tgPYTrX1C8JxqF/wfY/XCGbEqHgJtqDrSEvK+vLF7LaYI4oTotZOg/vhN7uwaEa7n\n\t\t\t\t\t\tGU2+bKuhcAL+rolEM6sbdrQAj3KarTafacfh9IiAclzyOQTA6pfjFWrucNIuWXc4\n\t\t\t\t\t\tYhaEPyOMubMsp+0eXZAwEPTJ61x+nQZd3UAf7Rm5v7agrzRAdqdwpnqb4yyprJlI\n\t\t\t\t\t\t+lkCAwEAAaNGMEQwIwYDVR0RBBwwGoIYd3d3LWZhbGNvbi5jc3guY2FtLmFjLnVr\n\t\t\t\t\t\tMB0GA1UdDgQWBBTz/ES/EvNaSsqqXUxLuIFc9YHi/TANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAAvFTJS2L6StZuqKA935AD3bBOHe5pg+LCF6ydHdTuyWEJYIWBRJ1WXsKMyaG\n\t\t\t\t\t\tyvdlX60XziJARq2UiYxt4yRjuGLAjQl9kNdrlqeb2AJFnA5E1Mt56FtzPiwu2zrC\n\t\t\t\t\t\tTQlklC4Xfie1Yaw2kEVO2vAoRfg9bgSBfyvFC4oR3vCery3Z687oCeQqDp7LPRcn\n\t\t\t\t\t\t+k5qQD8pout57IYzwyo7GPeVkYEPb3GO2KYmoENlDR/xah2VcsTZF7aIsMBFxaPv\n\t\t\t\t\t\tO+oqrQcnQXTviY9yWLbAlSrPPqGNYDxayVHn+zDSO4scLlOoqZJ8iC5NboNKqFyB\n\t\t\t\t\t\tRsenNm/aXp0wIU+jHVmi/GAPCQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www-trg.eng.cam.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www-trg.eng.cam.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www-trg.eng.cam.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www-trg.eng.cam.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www-trg.eng.cam.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www-trg.eng.cam.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www-trg.eng.cam.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www-trg.eng.cam.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www-trg.eng.cam.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www-trg.eng.cam.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://sp.vs1.corpora.uni-hamburg.de",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lehmberg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:timm.lehmberg@uni-hamburg.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Timm"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hedeland"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hanna.hedeland@uni-hamburg.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hanna"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:corpora@uni-hamburg.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "HZSK"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://sp.vs1.corpora.uni-hamburg.de",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-05-15T09:48:13Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://clarin.eu/category/clarin-member"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://corpora.uni-hamburg.de/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://corpora.uni-hamburg.de/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://corpora.uni-hamburg.de/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://corpora.uni-hamburg.de/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://corpora.uni-hamburg.de/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://corpora.uni-hamburg.de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://corpora.uni-hamburg.de"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hamburger Zentrum f\u00fcr Sprachkorpora"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hamburg Centre for Language Corpora"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Das Hamburger Zentrum f\u00fcr Sprachkorpora bietet einen Zugang zum HZSK Repository, in dem haupts\u00e4chlich Sprachkorpora vorgehalten werden"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Hamburg Centre for Language Corpora (HZSK) provides access to the HZSK Repository (mainly including spoken language corpora)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://corpora.uni-hamburg.de/drupal/sites/default/files/hzsk-logo-mittel.png",
                    "height": "23",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "153"
                  },
                  {
                    "text": "https://corpora.uni-hamburg.de/drupal/sites/default/files/hzsk-logo.png",
                    "height": "68",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "453"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://corpora.uni-hamburg.de/drupal/en/privacy-policy"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://corpora.uni-hamburg.de/drupal/en/privacy-policy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "vs1.corpora.uni-hamburg.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIJANuIbKBKwh2kMA0GCSqGSIb3DQEBBQUAMCUxIzAhBgNV\nBAMTGnZzMS5jb3Jwb3JhLnVuaS1oYW1idXJnLmRlMB4XDTE0MDUwNzEwMTUxMFoX\nDTI0MDUwNDEwMTUxMFowJTEjMCEGA1UEAxMadnMxLmNvcnBvcmEudW5pLWhhbWJ1\ncmcuZGUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDu+569Sk8uO4aX\n4zcU6YwHbOgUW92ynGU8JbV0WqLIVRuUkwVBeKI0UCumsxjXE7ynFwv7YPXhAO4b\nm425NMCmvG/xf8HxofD1+i1FqsjLgYa46C7LchDRTdYArBzf4ZqzlBWPmS+GVqKV\n8KJZmH1ZY5NkQmq5FokV3bXesiULKPMSznY4RImqrWn8HEb2IjZwpaeAoFckR7kY\nHUtUmvsreaWwRarPY9CTPzSFKqX5Jjtwt3/Xk6A72HM5qR7mOa/MdMshrTaS/+ML\nyxW92FpT0Tb72/lFYs97jMpDvDNEJVl++xw5+7lPL9iqPgVKgLhZggLrXR4CYyt2\nhNAbIStNAgMBAAGjZzBlMEQGA1UdEQQ9MDuCGnZzMS5jb3Jwb3JhLnVuaS1oYW1i\ndXJnLmRlhh1zcC52czEuY29ycG9yYS51bmktaGFtYnVyZy5kZTAdBgNVHQ4EFgQU\nV4XXOnZkJqO/CxOzgzCw5RFWih8wDQYJKoZIhvcNAQEFBQADggEBACKcSAQd2bO/\nbZcS2wvGCENGebMueDwISTvvyGW3hUoA94K28T5WCr/WNPwDty3yBFvn/wboztZ0\n6jEuhFQ1xo/7zMBdjHSkHFLs2kp0DIfzRgWBJUVpCCV9lkxO7rhN6abiAmonvu2+\ngQcIJWAcCh//HW4fi7LPZ9DG8OjiK00DinEqm901uznyK0e/NziN/5ExP1d3onxi\nk1oLIeAl0snOKGd1Cw2MfQYh7QaJdXpM2W3aG6UVLNbzjAvInTjMT6rVJIxxGSdE\n00Ev3tKPZ6iDZDjawwChLxAlfAby3JLylUJ4Lg/bh8/fY0SUFHAYpS8+ZPvdO6iR\nLPhJPdKT3mM="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=vs1.corpora.uni-hamburg.de"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://corpora.uni-hamburg.de/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://corpora.uni-hamburg.de/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://corpora.uni-hamburg.de/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://corpora.uni-hamburg.de/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://corpora.uni-hamburg.de/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://corpora.uni-hamburg.de/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Hamburger Zentrum f\u00fcr Sprachkorpora"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Hamburg Centre for Language Corpora"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Das Hamburger Zentrum f\u00fcr Sprachkorpora bietet einen Zugang zum HZSK Repository, in dem haupts\u00e4chlich Sprachkorpora vorgehalten werden"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The Hamburg Centre for Language Corpora (HZSK) provides access to the HZSK Repository (mainly including spoken language corpora)"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://authidp.shsu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "chandler@shsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jacob Chandler"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ucs_tim@shsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim McGuffin"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "marc.barber@shsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marc Barber"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://authidp.shsu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://authidp.shsu.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://authidp.shsu.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUQeKtlGH32e7m8o5FMe04tVqQhDAwDQYJKoZIhvcNAQEF\nBQAwGzEZMBcGA1UEAxMQYXV0aGlkcC5zaHN1LmVkdTAeFw0xMjEyMDQyMTAxMzha\nFw0zMjEyMDQyMTAxMzhaMBsxGTAXBgNVBAMTEGF1dGhpZHAuc2hzdS5lZHUwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCvePaZxen5e6BcZ7ytQboYpAjx\ns0CUHF3yN2ENOG/3ocsS6fLtpXBOsOwUSKVZwFhAAjyZmiYJVzqIQpNWIBe8DYle\n5fbJ9jwRNDxSQcnjV3MTeoVDXteMWBvcX58Xl8T9IaPeQzsPTwA7ahKtzUG/vAQ5\nVZG1ub4MD1+gN3j/EdeAMu009i0DEo0N1o0ZclAsE3OPPtBlGE/wHk/PRNcZSyZV\nv73L174lSeZdnPt/EA8OS5hexSlckS5Y69s47fZ6WIlVhimBe+iyeBjAzwUcAgQX\n53HTQeQljr9KVu/paNwmU9DVp5pVDBA8IYQWbUBenpd+Gr4pUKcWy6Z9YVA1AgMB\nAAGjZzBlMEQGA1UdEQQ9MDuCEGF1dGhpZHAuc2hzdS5lZHWGJ2h0dHBzOi8vYXV0\naGlkcC5zaHN1LmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUD1xVn6mS3yHr\nU6O5SlpFiDDGLRMwDQYJKoZIhvcNAQEFBQADggEBAGjSSPDeXaIF675j+qbuBT1o\n2WkhK+W64+KdkkD0qtsgz18UeAPLe+ibg8DZyU2yJVy6OWKRGm5hm2zDCcRIV2Gl\nlIMkqZhjwdzu0AyfLFg9T/mUbYr6uHaF0MDj3WwsOK7pICnDncUHCK7BGXtNU0SQ\nlLp74eYZf80bWo5Uef4AKcWoPAc5nBCeYSrnkOFDbAr4Rgcga+jk7wCj0HBnI35e\nMOwxmjefW/KOb9f1PR+U8K+hc6FLhMEFl6CC0N7RhYLgi4f+omr1gb8t0Wcgp/JG\ndS/BQXYEQm4UNPWh570Wpz2AKs9ztJhWtBHbikIeTqVjh4sKquRZHMrdH6wv33k="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "shsu.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://authidp.shsu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://authidp.shsu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://authidp.shsu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://authidp.shsu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://authidp.shsu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://authidp.shsu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "shsu.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sam Houston State University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUQeKtlGH32e7m8o5FMe04tVqQhDAwDQYJKoZIhvcNAQEF\nBQAwGzEZMBcGA1UEAxMQYXV0aGlkcC5zaHN1LmVkdTAeFw0xMjEyMDQyMTAxMzha\nFw0zMjEyMDQyMTAxMzhaMBsxGTAXBgNVBAMTEGF1dGhpZHAuc2hzdS5lZHUwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCvePaZxen5e6BcZ7ytQboYpAjx\ns0CUHF3yN2ENOG/3ocsS6fLtpXBOsOwUSKVZwFhAAjyZmiYJVzqIQpNWIBe8DYle\n5fbJ9jwRNDxSQcnjV3MTeoVDXteMWBvcX58Xl8T9IaPeQzsPTwA7ahKtzUG/vAQ5\nVZG1ub4MD1+gN3j/EdeAMu009i0DEo0N1o0ZclAsE3OPPtBlGE/wHk/PRNcZSyZV\nv73L174lSeZdnPt/EA8OS5hexSlckS5Y69s47fZ6WIlVhimBe+iyeBjAzwUcAgQX\n53HTQeQljr9KVu/paNwmU9DVp5pVDBA8IYQWbUBenpd+Gr4pUKcWy6Z9YVA1AgMB\nAAGjZzBlMEQGA1UdEQQ9MDuCEGF1dGhpZHAuc2hzdS5lZHWGJ2h0dHBzOi8vYXV0\naGlkcC5zaHN1LmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUD1xVn6mS3yHr\nU6O5SlpFiDDGLRMwDQYJKoZIhvcNAQEFBQADggEBAGjSSPDeXaIF675j+qbuBT1o\n2WkhK+W64+KdkkD0qtsgz18UeAPLe+ibg8DZyU2yJVy6OWKRGm5hm2zDCcRIV2Gl\nlIMkqZhjwdzu0AyfLFg9T/mUbYr6uHaF0MDj3WwsOK7pICnDncUHCK7BGXtNU0SQ\nlLp74eYZf80bWo5Uef4AKcWoPAc5nBCeYSrnkOFDbAr4Rgcga+jk7wCj0HBnI35e\nMOwxmjefW/KOb9f1PR+U8K+hc6FLhMEFl6CC0N7RhYLgi4f+omr1gb8t0Wcgp/JG\ndS/BQXYEQm4UNPWh570Wpz2AKs9ztJhWtBHbikIeTqVjh4sKquRZHMrdH6wv33k="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Sam Houston State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.shsu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Sam Houston State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ifap.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Marco Pantoja"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "marco.pantoja@ifap.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ifap.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID1DCCArwCAQAwDQYJKoZIhvcNAQEFBQAwga8xKzApBgNVBAoUIklGQVAgLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkbyBBbWFww6ExDDAKBgNVBAsTA0RUSTEoMCYGCSqG\nSIb3DQEJARYZbWFyY28ucGFudG9qYUBpZmFwLmVkdS5icjEQMA4GA1UEBxQHTWFj\nYXDDoTEPMA0GA1UECBQGQW1hcMOhMQswCQYDVQQGEwJCUjEYMBYGA1UEAxMPaWRw\nLmlmYXAuZWR1LmJyMB4XDTEzMTIxOTE4MDIwM1oXDTE2MTIxODE4MDIwM1owga8x\nKzApBgNVBAoUIklGQVAgLSBJbnN0aXR1dG8gRmVkZXJhbCBkbyBBbWFww6ExDDAK\nBgNVBAsTA0RUSTEoMCYGCSqGSIb3DQEJARYZbWFyY28ucGFudG9qYUBpZmFwLmVk\ndS5icjEQMA4GA1UEBxQHTWFjYXDDoTEPMA0GA1UECBQGQW1hcMOhMQswCQYDVQQG\nEwJCUjEYMBYGA1UEAxMPaWRwLmlmYXAuZWR1LmJyMIIBIjANBgkqhkiG9w0BAQEF\nAAOCAQ8AMIIBCgKCAQEA6lU1vl2shAmZ5lk9mqgLW0fGHYgMHSqS2gQqaTW2KfAo\ne6wvyEjkmFa2KTTa7gmTjBQBGahHpKjrTpMd1FEqMC1Eu9lLlStVvUjqp23DLdwI\nKzNcR+SnvPKbPWI6168jZlE5ymytgF7wUsJj9PB77i9FpJ8kZgky9iZhHCsBp9Ad\nQVFznpEGn/pwmPwtXEzQBFdwSqXdkUpISlHPe5dBItnNx6Z8YCEcBA+IzOL38By8\nMG8LMbziCPQpQ7TgXiEE5vLsocJw/UF5DiWqSZ+nZ/GLwXx5rkbaB8wQZen2v0q+\nbghS7nmp3hKAsYKNTlw0jPxji/nitm5nZSReDv1DgwIDAQABMA0GCSqGSIb3DQEB\nBQUAA4IBAQCj9QDb4QEUtzeU527JnQqF8DGTV275Px5iJWm3+pyv1ScYcJ903JyQ\nPNxPh+WdRkAxBcCMbd1vH4toAVZX6EDMlJv/H9x/nmnWTl+GigzLz4vAOREaab15\ntQPwipCRXVnakkVxYk+1QWrmXyzZPaw3dOLVOg/SSTVk87vnhuX1nvu2r7ZVNDZv\n34WrTP8bVJd5c8yIMuvCMBPp30p4A8NGm1PkZP+OIH5CVO25cNSVq66/OeCSr3Se\nIckFRapAp4rc+PDyWiwSM6Xy8kM9pdraxGWoW0697si+Ji4MsIdah9I7+C6B6XB2\nBoOuGlC2BFe2rK9IG4bntSohpeIVUoLF"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ifap.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ifap.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ifap.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ifap.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ifap.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ifap.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ifap.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ifap.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifap.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifap.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFAP - Instituto Federal do Amapa"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFAP - Instituto Federal do Amapa"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFAP - Instituto Federal do Amapa"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFAP - Instituto Federal do Amapa"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICxjCCAa4CAQAwDQYJKoZIhvcNAQEFBQAwKTEMMAoGA1UECxMDRFRJMQswCQYD\nVQQGEwJCUjEMMAoGA1UEAxMDaWRwMB4XDTE0MDQxMDE2MTEyOFoXDTE5MDQwOTE2\nMTEyOFowKTEMMAoGA1UECxMDRFRJMQswCQYDVQQGEwJCUjEMMAoGA1UEAxMDaWRw\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA6lU1vl2shAmZ5lk9mqgL\nW0fGHYgMHSqS2gQqaTW2KfAoe6wvyEjkmFa2KTTa7gmTjBQBGahHpKjrTpMd1FEq\nMC1Eu9lLlStVvUjqp23DLdwIKzNcR+SnvPKbPWI6168jZlE5ymytgF7wUsJj9PB7\n7i9FpJ8kZgky9iZhHCsBp9AdQVFznpEGn/pwmPwtXEzQBFdwSqXdkUpISlHPe5dB\nItnNx6Z8YCEcBA+IzOL38By8MG8LMbziCPQpQ7TgXiEE5vLsocJw/UF5DiWqSZ+n\nZ/GLwXx5rkbaB8wQZen2v0q+bghS7nmp3hKAsYKNTlw0jPxji/nitm5nZSReDv1D\ngwIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQDJ9GGFu1uP2xSjX0bEPb/jhKOKU9VD\nLH2vSu9V0zbkH9/uxgGLfOHuP+83QyDLfxEJKa1Ga4Hw+y6o7vyn3mW0RXBBloF/\nGTeDI2aFAmuPNomYl+ijCxk37ur/iQ3ugo0PbvVSZV9hxic8FJbBjGg7ZvyMXwuZ\n1nQfeXL+1qESFEwm5ClCR9G/WNmhaxr1bYanl9uvCS4tmpKJ1zZthDpnCRYLoIdx\nHTc3JBOzycaHMO08/JyQND4i4t4OuiY6iemEsTuGgC2aeOZYRJ9qCyjVnFMQE8lV\narZrEBblthd0n3nlykz5YYjwsNa9rkr6Yo9NDXv3iorY6fD2Rk8z8JB2"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFAP - Instituto Federal do Amapa"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFAP - Instituto Federal do Amapa"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifap.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifap.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFAP - Instituto Federal do Amapa"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFAP - Instituto Federal do Amapa"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://groupes.france-bioinformatique.fr/sympa",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@renater.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://groupes.france-bioinformatique.fr/sympa",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-10-20T12:00:53Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/collaboratif"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/community"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GIP RENATER"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.renater.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GIP RENATER"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://groupes.france-bioinformatique.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Group service for the French Institute of BioInformatics :\n-mailing lists\n-wikis\n-surveys\n-meeting scheduler"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Service de groupes de l'Institut Fran\u00e7ais de BioInformatique : \n-listes de diffusions\n-wikis\n-sondages\n-planification de r\u00e9union"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Group service for the French Institute of BioInformatics"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Service de groupes de l'Institut Fran\u00e7ais de BioInformatique"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKjCCAxKgAwIBAgIJAI2rvCn3oTieMA0GCSqGSIb3DQEBBQUAMGsxCzAJBgNV\nBAYTAkZSMTAwLgYDVQQKDCdJbnN0aXR1dCBGcmFuw4PCp2FpcyBkZSBCaW9pbmZv\ncm1hdGlxdWUxKjAoBgNVBAMTIWdyb3VwZXMuZnJhbmNlLWJpb2luZm9ybWF0aXF1\nZS5mcjAeFw0xNDEwMjAwOTEyMzdaFw0zNDEwMTUwOTEyMzdaMGsxCzAJBgNVBAYT\nAkZSMTAwLgYDVQQKDCdJbnN0aXR1dCBGcmFuw4PCp2FpcyBkZSBCaW9pbmZvcm1h\ndGlxdWUxKjAoBgNVBAMTIWdyb3VwZXMuZnJhbmNlLWJpb2luZm9ybWF0aXF1ZS5m\ncjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANHjwFnlwrpydxosra2C\nA5wxUhpAShLUknop3e1B4K+x2aIXvbN6sChUkOLV/JKhhH52BMBZwI4qr/tv6ego\nBU6pnhYhWO8QtKKXyvox5NRbgeCX3CI8pQ5PJtWc++pOjq/10v4koBfbJcogsMGc\n3B/khJK4tmKHFvcEngRiwhaHVL4MPO65rYyjisg5Tr6EuDGW1xGD5ETHe1aliLyQ\nuIqN3Pirmqb8h32OlPkqQ/A2jzkYx9sTX2cEgSFFGL3Docr2bB7ie+GuiDgcnm5h\nYyQ5Ej1Of1jjOGF4UcSUKCLphukAbQyswRLqzYNr8No4JzY6ZcL/tSS32wfNG6BV\n7ZECAwEAAaOB0DCBzTAdBgNVHQ4EFgQUGAA0QcYlCVagyA/JmGcP9vm336EwgZ0G\nA1UdIwSBlTCBkoAUGAA0QcYlCVagyA/JmGcP9vm336Ghb6RtMGsxCzAJBgNVBAYT\nAkZSMTAwLgYDVQQKDCdJbnN0aXR1dCBGcmFuw4PCp2FpcyBkZSBCaW9pbmZvcm1h\ndGlxdWUxKjAoBgNVBAMTIWdyb3VwZXMuZnJhbmNlLWJpb2luZm9ybWF0aXF1ZS5m\ncoIJAI2rvCn3oTieMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBALrL\nS1BIC0tCkQx5G+ZnI9BGlHMeeqQqd9faGOFPtcyrrl6sUwMj8b1aNrJMICPxnwPG\n3Z9qjLOfihRz96pxhaxI7HYOuv987xRqD2l/ubkz/NF3l8A+k+hNSwILhwR0vjTo\nHSfX+jCW8FBrLlsgSkCv2xxE6Liwl+VcEczBYfMbBffD0kXPDo4KdY/zxs5dHYDI\nbLYBU/O/n+4v/kcj1VwwHX2/Lc40lLAQUe6cN+red1ELmJ7J6afTr5ru6vwG4P0g\noQoGFWdszAsq/gim7srIxz4+yb9/vCqwQBMxNZEi8522QbhrrC24R+rAeTFjbF1H\nSoGk3gs42M20S05utsA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKjCCAxKgAwIBAgIJAI2rvCn3oTieMA0GCSqGSIb3DQEBBQUAMGsxCzAJBgNV\nBAYTAkZSMTAwLgYDVQQKDCdJbnN0aXR1dCBGcmFuw4PCp2FpcyBkZSBCaW9pbmZv\ncm1hdGlxdWUxKjAoBgNVBAMTIWdyb3VwZXMuZnJhbmNlLWJpb2luZm9ybWF0aXF1\nZS5mcjAeFw0xNDEwMjAwOTEyMzdaFw0zNDEwMTUwOTEyMzdaMGsxCzAJBgNVBAYT\nAkZSMTAwLgYDVQQKDCdJbnN0aXR1dCBGcmFuw4PCp2FpcyBkZSBCaW9pbmZvcm1h\ndGlxdWUxKjAoBgNVBAMTIWdyb3VwZXMuZnJhbmNlLWJpb2luZm9ybWF0aXF1ZS5m\ncjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANHjwFnlwrpydxosra2C\nA5wxUhpAShLUknop3e1B4K+x2aIXvbN6sChUkOLV/JKhhH52BMBZwI4qr/tv6ego\nBU6pnhYhWO8QtKKXyvox5NRbgeCX3CI8pQ5PJtWc++pOjq/10v4koBfbJcogsMGc\n3B/khJK4tmKHFvcEngRiwhaHVL4MPO65rYyjisg5Tr6EuDGW1xGD5ETHe1aliLyQ\nuIqN3Pirmqb8h32OlPkqQ/A2jzkYx9sTX2cEgSFFGL3Docr2bB7ie+GuiDgcnm5h\nYyQ5Ej1Of1jjOGF4UcSUKCLphukAbQyswRLqzYNr8No4JzY6ZcL/tSS32wfNG6BV\n7ZECAwEAAaOB0DCBzTAdBgNVHQ4EFgQUGAA0QcYlCVagyA/JmGcP9vm336EwgZ0G\nA1UdIwSBlTCBkoAUGAA0QcYlCVagyA/JmGcP9vm336Ghb6RtMGsxCzAJBgNVBAYT\nAkZSMTAwLgYDVQQKDCdJbnN0aXR1dCBGcmFuw4PCp2FpcyBkZSBCaW9pbmZvcm1h\ndGlxdWUxKjAoBgNVBAMTIWdyb3VwZXMuZnJhbmNlLWJpb2luZm9ybWF0aXF1ZS5m\ncoIJAI2rvCn3oTieMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBALrL\nS1BIC0tCkQx5G+ZnI9BGlHMeeqQqd9faGOFPtcyrrl6sUwMj8b1aNrJMICPxnwPG\n3Z9qjLOfihRz96pxhaxI7HYOuv987xRqD2l/ubkz/NF3l8A+k+hNSwILhwR0vjTo\nHSfX+jCW8FBrLlsgSkCv2xxE6Liwl+VcEczBYfMbBffD0kXPDo4KdY/zxs5dHYDI\nbLYBU/O/n+4v/kcj1VwwHX2/Lc40lLAQUe6cN+red1ELmJ7J6afTr5ru6vwG4P0g\noQoGFWdszAsq/gim7srIxz4+yb9/vCqwQBMxNZEi8522QbhrrC24R+rAeTFjbF1H\nSoGk3gs42M20S05utsA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://groupes.france-bioinformatique.fr/sympa/sso_login/federation_cru/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://groupes.france-bioinformatique.fr/sympa/sso_login/federation_cru/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Service de groupes de l'Institut Fran\u00e7ais de BioInformatique"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Group service for the French Institute of BioInformatics"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Service de groupes de l'Institut Fran\u00e7ais de BioInformatique : \n-listes de diffusions\n-wikis\n-sondages\n-planification de r\u00e9union"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Group service for the French Institute of BioInformatics :\n-mailing lists\n-wikis\n-surveys\n-meeting scheduler"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://soundstage.bl.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Penty"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:david.penty@bl.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Penty"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:david.penty@bl.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://soundstage.bl.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-02-22T17:29:28Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "British Library: Archival Sound Recordings"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bl.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The British Library"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://soundstage.bl.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://soundstage.bl.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://soundstage.bl.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://soundstage.bl.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://soundstage.bl.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://soundstage.bl.uk/Shibboleth.sso/WAYF/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6DCCAdCgAwIBAgIJAMDqFzqjF6jWMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\n\t\t\t\t\t\tBAMTC3Y4Yi13ZWJwcm9kMB4XDTEzMDIxOTExMzIzMloXDTIzMDIxNzExMzIzMlow\n\t\t\t\t\t\tFjEUMBIGA1UEAxMLdjhiLXdlYnByb2QwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQDtV0Wcb1yKMcfz3CBPKqxKbUpn3P7rpOf1O0RgocPTghq4FKKiUKxg\n\t\t\t\t\t\tTDQQRpzZtjH2b6JtzIt94fTi4H5ETHqDtCC2FnExmsKAsmowH4ZDZ5WgUIea9eN0\n\t\t\t\t\t\tmYJovj3kVSGgMuo8/mFhebGLPf79BtBQZN5iwc+WWwIG4/ULdzAc1Zj2mM41LiBw\n\t\t\t\t\t\tn4cJLaAGpT8Yu8bhLBAhby3yUB+/3h+U8tjwo9srjvDD9n+Y6TnLAuxuNehBpkhm\n\t\t\t\t\t\tkKebnVqanDyjGUCoe3gVmVkQHrWrUF/L/wEBcq5sCKedCRdOCgOhiVhTypdRpUeD\n\t\t\t\t\t\tZDAEpFtnO4G4ryZF/2Npp7zx7hO6Sxk5AgMBAAGjOTA3MBYGA1UdEQQPMA2CC3Y4\n\t\t\t\t\t\tYi13ZWJwcm9kMB0GA1UdDgQWBBRGA+HLt05y3yAYOZQmk1mgc0Va+zANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAUyjkQMO113dtFxaEMHWFog6V1jVKdGa9+lU3LtNh8jat6xPs\n\t\t\t\t\t\tuV0wHYmAF8qFl17dD7vYOZBA05DTogo10/q89KJrfof6OLuHK32Hm0T8G3QoHe2G\n\t\t\t\t\t\tfSum/EGk+8M8MupRPdVI+hwhlgFiGDVCY4q+6GiU9zmVXhvCsB+Ssfx0GH0D1Auq\n\t\t\t\t\t\tCH7HN3mqNcjEsgFixzpgNsoD+McdGBeXrWNyKxJNgliq7BPvKnC2KhOXl7edd3hz\n\t\t\t\t\t\tCU1pROsZ/785vkAVYrvxKnzuCoGAnlWf2X6UExDgeWZLEJ9mrYL6pTU6eHc2ukl5\n\t\t\t\t\t\tXou/5adlzlgyMCWRMLIRs7fMaiZ3/guduGhqnw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://soundstage.bl.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://soundstage.bl.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://soundstage.bl.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://soundstage.bl.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://soundstage.bl.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://soundstage.bl.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://soundstage.bl.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://soundstage.bl.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://soundstage.bl.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://soundstage.bl.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://dl.acm.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ali"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ali@acm.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Asad"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Greenberg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:greenberg@acm.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dl.acm.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-02-15T14:02:03Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Association For Computing Machinery: ACM Digital Library"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.acm.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Association for Computing Machinery, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBDCCAeygAwIBAgIJAMD4xoKFh5MoMA0GCSqGSIb3DQEBBQUAMBUxEzARBgNV\n\t\t\t\t\t\tBAMTCmRsLmFjbS5vcmcwHhcNMTMwNzEwMTY0NjQ5WhcNMjMwNzA4MTY0NjQ5WjAV\n\t\t\t\t\t\tMRMwEQYDVQQDEwpkbC5hY20ub3JnMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEA0D83ObCYMf9mChQ1RcwAIdUcWcrfRu/xEAamnUi6XtiP5zpq2XZsP6kr\n\t\t\t\t\t\t8kDKyf1cFb61AG76LyCNpPXUjOSImtCggfO3wwjrM6cVxoLxpjNHwyekf7Qp5Xht\n\t\t\t\t\t\twQ76ME2mBZyyeeQGQADSpuiQU8ceEEuFVzE4odvsYjslUf5FdyB7DV3wHsaem0GI\n\t\t\t\t\t\tNPHMgm1aWw06Rb6TJT4+q7UVldkbFGToX/MwX6BVVn36TMllUCoPI9uC6elBtSDA\n\t\t\t\t\t\tpM5IX3xPGm+HWhzWMwNH6DbiEaWunL0mT4qz4S/8chofFCYnfBIghcIR2byi/LVq\n\t\t\t\t\t\tJsimhFLkh5pzeaN481jUXqm4CzVMsQIDAQABo1cwVTA0BgNVHREELTArggpkbC5h\n\t\t\t\t\t\tY20ub3Jnhh1odHRwczovL2RsLmFjbS5vcmcvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n\t\t\t\t\t\tFf2/iHzhnXS3ru+f8m3ffW6LB2YwDQYJKoZIhvcNAQEFBQADggEBAL3G7h2JsWau\n\t\t\t\t\t\tUg3rrbbyGlfnyj7m9c02h7liJw0ZWMSZAQADzPcaTXxjJd72e1bfVlsqoyix1yjt\n\t\t\t\t\t\tDOOd0PzgT4OmUrAu7CLnKIA2488s1TwrJgCkSKKfKYNAiAkTxbzlsJXb13Tok+vK\n\t\t\t\t\t\tC/sxD92ba9DO8uc/uqO8m874uHyE1o4aAn1L5AsWuDI7hdv1hMfktODq7rV1FTCT\n\t\t\t\t\t\tWUzSvfdP6GjtLivq3zW8+NluIu9EMSIYx/OUl13pXUjDiHl5oWO7MJoc5c6lu6Tu\n\t\t\t\t\t\tTVBr4ywIEShumuXNtgDlBgb41BHr7tqsLwbuAMbWH1ZWYFSz0AKVFkVxsmIjgWn1\n\t\t\t\t\t\tbYwfJV8VaIg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dl.acm.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dl.acm.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dl.acm.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dl.acm.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibidp.bloomu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp-admin@bloomu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Vincent Kozlek"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp-admin@bloomu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Vincent Kozlek"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp-admin@bloomu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Vincent Kozlek"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibidp.bloomu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.bloomu.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.bloomu.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUa2z6CycWE6LUrGRPn7Cemf5wDEswDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOc3NvLmJsb29tdS5lZHUwHhcNMTMwMjA3MjEzMzE1WhcN\nMzMwMjA3MjEzMzE1WjAZMRcwFQYDVQQDEw5zc28uYmxvb211LmVkdTCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJrah6PH2ovsDZBWU6vJU29edlusGHWJ\no9lUpDUYtyf6G51acfVNzvryDDK9Is+HqM8DNdpGXEURVrpGHeVs3bUC0kceMIQu\n3gQe+E0VLpYPckLOt0GW33xyRZqjvv+B4+FTYJ0NclelpKw6h0zKhI6n9OEVV9U+\n0KqeB5hFSOc3Wxmim1AFGWb7gF3zi4Pu/qK0yWw/stwF3Q1yn+ckMISSffutRCNY\nXjQULnIIo9akAP/3PLYpOrL11YZpmpkl2K+evEJctmd8h0TE7jK0c5D/6pmVaiWt\ndKHSvtT43iqQ1Hlo4K3jlXIRPh2zsr8h2nWFwoI4tOJ0hvE/Vlu3yJUCAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOc3NvLmJsb29tdS5lZHWGJWh0dHBzOi8vc3NvLmJsb29t\ndS5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFDUwz2WNduEDYYsYescY9Xpm\n64lDMA0GCSqGSIb3DQEBBQUAA4IBAQBLa26KpzbFcTiZkPRE2vaX+s0scV8GFXZ1\nTNPcfT8c1EVDB2k0DyUPCBm9kdhNm1qbl4horhilS7pVCAcw3dmTpnjMusEtxquc\n7333PpuTJ3sFvgpD3p1WB0g5mBiPAxj2YnPthWqmTdEvH/F1L8TC6xmg7YDGRPHt\ngfISZot3Vn5ux3rA8/JiXhEOi1zJlbeSRLWQRUm9+lTftEWWg19TE9NR5YJK9D1p\nR26ZBnGAXB3pxgg6q08oHO7BQ7esjKXaf4Y3rpghvA5SFf1A3vFBXrTK1WgoUTXd\nQZ8qhl/Wc9j5mSANbebH6m5IJcNikMvib+f34/Jy9j82Aw8yP1n7"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bloomu.edu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "huskies.bloomu.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.bloomu.edu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.bloomu.edu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.bloomu.edu:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.bloomu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.bloomu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso.bloomu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sso.bloomu.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.bloomu.edu:444/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.bloomu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.bloomu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bloomu.edu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "huskies.bloomu.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.bloomu.edu/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Bloomsburg University of Pennsylvania"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for all faculty, staff, and students of Bloomsburg University, one of the fourteen universities in the Pennsylvania State System of Higher Education (PASSHE)."
                  }
                ],
                "logo": [
                  {
                    "text": "https://sso.bloomu.edu/idp/images/bu.jpg",
                    "lang": "en",
                    "height": "137",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "259"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.bloomu.edu/policies_procedures"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUa2z6CycWE6LUrGRPn7Cemf5wDEswDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOc3NvLmJsb29tdS5lZHUwHhcNMTMwMjA3MjEzMzE1WhcN\nMzMwMjA3MjEzMzE1WjAZMRcwFQYDVQQDEw5zc28uYmxvb211LmVkdTCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJrah6PH2ovsDZBWU6vJU29edlusGHWJ\no9lUpDUYtyf6G51acfVNzvryDDK9Is+HqM8DNdpGXEURVrpGHeVs3bUC0kceMIQu\n3gQe+E0VLpYPckLOt0GW33xyRZqjvv+B4+FTYJ0NclelpKw6h0zKhI6n9OEVV9U+\n0KqeB5hFSOc3Wxmim1AFGWb7gF3zi4Pu/qK0yWw/stwF3Q1yn+ckMISSffutRCNY\nXjQULnIIo9akAP/3PLYpOrL11YZpmpkl2K+evEJctmd8h0TE7jK0c5D/6pmVaiWt\ndKHSvtT43iqQ1Hlo4K3jlXIRPh2zsr8h2nWFwoI4tOJ0hvE/Vlu3yJUCAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOc3NvLmJsb29tdS5lZHWGJWh0dHBzOi8vc3NvLmJsb29t\ndS5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFDUwz2WNduEDYYsYescY9Xpm\n64lDMA0GCSqGSIb3DQEBBQUAA4IBAQBLa26KpzbFcTiZkPRE2vaX+s0scV8GFXZ1\nTNPcfT8c1EVDB2k0DyUPCBm9kdhNm1qbl4horhilS7pVCAcw3dmTpnjMusEtxquc\n7333PpuTJ3sFvgpD3p1WB0g5mBiPAxj2YnPthWqmTdEvH/F1L8TC6xmg7YDGRPHt\ngfISZot3Vn5ux3rA8/JiXhEOi1zJlbeSRLWQRUm9+lTftEWWg19TE9NR5YJK9D1p\nR26ZBnGAXB3pxgg6q08oHO7BQ7esjKXaf4Y3rpghvA5SFf1A3vFBXrTK1WgoUTXd\nQZ8qhl/Wc9j5mSANbebH6m5IJcNikMvib+f34/Jy9j82Aw8yP1n7"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://sso.bloomu.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bloomsburg University of Pennsylvania"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bloomu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Bloomsburg University of Pennsylvania"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.kau.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://sp.kau.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.kau.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sp.kau.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp.kau.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sp.kau.se/Shibboleth.sso/WAYF/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sp.kau.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp.kau.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "sp.kau.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4jCCAcqgAwIBAgIJAK8+Q8SJp9cxMA0GCSqGSIb3DQEBBQUAMBQxEjAQBgNV\nBAMTCXNwLmthdS5zZTAeFw0xMTA1MDYxMzUxMzBaFw0yMTA1MDMxMzUxMzBaMBQx\nEjAQBgNVBAMTCXNwLmthdS5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\nggEBAOOdtYpLS733ksNrv8cVKtY8PCkrL8sa12dMH/Lp2Sm+eqNkJzwbmKPJm6Iu\nrp+Psc/bs767KNqDFRKi+s8iHuKIDCQnkliScR0w0wHzSiHMqEVo3OmU4hYxyYia\n7b3GNY9QYgwbalIuXvIoEVtSP6+19bnreeq0HbR+xCVOnA0EWSJHbIxIcEs1sH3n\nWVtgW5TTJqcasNp9FRtBYgUu5m6tbBZRzEpv2vjgSnhB+D67E6gfUIllWy7EoBFf\nNKtvN6KXr+Md44HanVMg6O+UOLeXY2+niXlP4sVXytCjkXMkZzBnOarPKkEa1yaP\nyyEV1FIoEVJRbQLcYHzhtVX/D+UCAwEAAaM3MDUwFAYDVR0RBA0wC4IJc3Aua2F1\nLnNlMB0GA1UdDgQWBBTDV+sbuDL/6+3K3mKMQvA4B/ctdzANBgkqhkiG9w0BAQUF\nAAOCAQEAKWQPKSkdt82pOnMqFfK07Tyx0tvH04m7TKJKQzL+FcXe4uzv2O1D9Hmg\n9SOoAxvG62KlFlFPkqjEUAuYxEfMWhrftdcWAR3VRu4vBO3QXRxvSuB2lLE487NE\nIWfQbZU6cfz+C8OondMuTtEChkvc5WJAd1HYdUzF0eRSSdKUgJmT4j9fUX0USS3E\noVtdy2lFcEQT6i7/0v8wrxndGmfGHi6vkiVUvLitX1gdUxx/egzZ9vq+uWa/FxU7\nJyw22KeyhvX+Ph1pO0iJh3yjDwSbVRDzMN5GU+aPBpeUVUxhYF3CTP4gh8rUAPJC\nmyMZEHsgIBf3jkmE9uQfRGeQLiSxfg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=sp.kau.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.kau.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp.kau.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.kau.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp.kau.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp.kau.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp.kau.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.hartpury.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@hartpury.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "West"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nick.west@hartpury.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nick"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.hartpury.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-08-15T09:56:09Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVALyl0dbpeXfYuEe49LYtPN8+LpmNMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB0xGzAZBgNVBAMTEmlkcC5oYXJ0cHVyeS5hYy51azAeFw0xMjA4MTQxODM2\n\t\t\t\t\t\tMjlaFw0zMjA4MTQxODM2MjlaMB0xGzAZBgNVBAMTEmlkcC5oYXJ0cHVyeS5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJPi0Xw859VIvqyqTHWt\n\t\t\t\t\t\tJXN7KlgEhe+OXy4YNimWwphxPFMuYkdzycnAyhzso9oSou0rcwNpKGVFSmSyjF9x\n\t\t\t\t\t\txeVb/vZtn3xG/peLC+ui20w1caoRJytCC93mWCgtBtj4cZ88jJu8Y/t/5Cmcr+ov\n\t\t\t\t\t\tR4+nJrEP+z162/Law913nLBPAW4TNKFtUGvXaaHDu4H3kAKZeVmIDMqzhyXtAvQV\n\t\t\t\t\t\tvODGiCAYEKm7nqYW5qzIs6+W4mdyYQai0Aw9C5XzlOjV4IaH6Y2kWa2AedcrBao9\n\t\t\t\t\t\tIpBR9tm6PlOT4L+gwwtPynhoHrKGVsu+633JjFIkcOK5xGQtRhe5nwJMTZVnILvG\n\t\t\t\t\t\t4n8CAwEAAaNrMGkwSAYDVR0RBEEwP4ISaWRwLmhhcnRwdXJ5LmFjLnVrhilodHRw\n\t\t\t\t\t\tczovL2lkcC5oYXJ0cHVyeS5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n\t\t\t\t\t\txqp4n/FKdmw6rnk/dIBV654mwsgwDQYJKoZIhvcNAQEFBQADggEBAF14kkpYbOAR\n\t\t\t\t\t\tReDt0Wk1RjJDj7YT3rPx3/A4+6h0WtzMRlTEOp6H99cDnRd/HKtWnhYwy9DU7MBg\n\t\t\t\t\t\trQumD2VgmCnnOTR8X/oFq3t/hB9bIRY2+w9RL+WSeM1tWCHBob+8SOibzLf/c63g\n\t\t\t\t\t\t1OpfT+X0bK40aTOvuJeVlZ66WKxW8dUr9GOzCOxkarW6HQlFhE7y+p5mt9jnKoQJ\n\t\t\t\t\t\tR93wQBJdWf3Bsr51pnY1XKCkYNQn0uxLS9zJYG2Nyvo7hV6Q2GBQko+XJSHsA3cm\n\t\t\t\t\t\tHHeZlWhHsM3MJuEK39lp1ZVtncv94hFKo2WUNfC59Hz8arKr4w3KFYQ107v3KG81\n\t\t\t\t\t\tIGu3QwNTGBs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hartpury.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.hartpury.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.hartpury.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.hartpury.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.hartpury.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.hartpury.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.hartpury.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.hartpury.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.hartpury.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hartpury.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVALyl0dbpeXfYuEe49LYtPN8+LpmNMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB0xGzAZBgNVBAMTEmlkcC5oYXJ0cHVyeS5hYy51azAeFw0xMjA4MTQxODM2\n\t\t\t\t\t\tMjlaFw0zMjA4MTQxODM2MjlaMB0xGzAZBgNVBAMTEmlkcC5oYXJ0cHVyeS5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJPi0Xw859VIvqyqTHWt\n\t\t\t\t\t\tJXN7KlgEhe+OXy4YNimWwphxPFMuYkdzycnAyhzso9oSou0rcwNpKGVFSmSyjF9x\n\t\t\t\t\t\txeVb/vZtn3xG/peLC+ui20w1caoRJytCC93mWCgtBtj4cZ88jJu8Y/t/5Cmcr+ov\n\t\t\t\t\t\tR4+nJrEP+z162/Law913nLBPAW4TNKFtUGvXaaHDu4H3kAKZeVmIDMqzhyXtAvQV\n\t\t\t\t\t\tvODGiCAYEKm7nqYW5qzIs6+W4mdyYQai0Aw9C5XzlOjV4IaH6Y2kWa2AedcrBao9\n\t\t\t\t\t\tIpBR9tm6PlOT4L+gwwtPynhoHrKGVsu+633JjFIkcOK5xGQtRhe5nwJMTZVnILvG\n\t\t\t\t\t\t4n8CAwEAAaNrMGkwSAYDVR0RBEEwP4ISaWRwLmhhcnRwdXJ5LmFjLnVrhilodHRw\n\t\t\t\t\t\tczovL2lkcC5oYXJ0cHVyeS5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n\t\t\t\t\t\txqp4n/FKdmw6rnk/dIBV654mwsgwDQYJKoZIhvcNAQEFBQADggEBAF14kkpYbOAR\n\t\t\t\t\t\tReDt0Wk1RjJDj7YT3rPx3/A4+6h0WtzMRlTEOp6H99cDnRd/HKtWnhYwy9DU7MBg\n\t\t\t\t\t\trQumD2VgmCnnOTR8X/oFq3t/hB9bIRY2+w9RL+WSeM1tWCHBob+8SOibzLf/c63g\n\t\t\t\t\t\t1OpfT+X0bK40aTOvuJeVlZ66WKxW8dUr9GOzCOxkarW6HQlFhE7y+p5mt9jnKoQJ\n\t\t\t\t\t\tR93wQBJdWf3Bsr51pnY1XKCkYNQn0uxLS9zJYG2Nyvo7hV6Q2GBQko+XJSHsA3cm\n\t\t\t\t\t\tHHeZlWhHsM3MJuEK39lp1ZVtncv94hFKo2WUNfC59Hz8arKr4w3KFYQ107v3KG81\n\t\t\t\t\t\tIGu3QwNTGBs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hartpury College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hartpury.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hartpury College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.esc.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "adam.cross@esc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam Cross"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "john.koch@esc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Koch"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "aj.lacomba@esc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AJ Lacomba"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.esc.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.esc.edu/cas/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.esc.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.esc.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.esc.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.esc.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.esc.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "esc.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://www.esc.edu/media/esc-website/style-assets/images/logos/esc-logo-orange-bkg.jpg",
                    "lang": "en",
                    "height": "302",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "57"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.esc.edu/policies/?search=cid%3D35661"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SUNY Empire State College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUJ2V9Z0LCoLuWMLmlW0TccM7q5bowDQYJKoZIhvcNAQEF\nBQAwFjEUMBIGA1UEAxMLaWRwLmVzYy5lZHUwHhcNMTMwNzAyMDM1NDAyWhcNMzMw\nNzAyMDM1NDAyWjAWMRQwEgYDVQQDEwtpZHAuZXNjLmVkdTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAJJ8cy7KjNKGMI+N4hImtIreeCTdVbErSBtjAWj9\nA4YNjwnxEMhkO5eYj4+FjEOLG3UmaEoRwMmwahPIeLEk5gCbQ66nLbwdIub77dly\najsoqwdLkU9zbSLKbshQuwR8dPzTjQSuDPSpqXaAN+o63FTs+zxNsUgWx87NXpVs\nODWJAGYCOocuXfNJYF4VrKEtpDjb4RX2ssaGlJEN0c/HeB2OwKFkYkf6U5I2upYL\nBXI7ZDuZv8CnDGbvrDJQnvu8XM17Bp/rTECAVdxY6IOeVeS9yGPSYk16I5zELATH\nkNeER3HmxujGQa6AXV5EPwMClRvlzfuU10NN+IzsdBoClU8CAwEAAaNdMFswOgYD\nVR0RBDMwMYILaWRwLmVzYy5lZHWGImh0dHBzOi8vaWRwLmVzYy5lZHUvaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFHW1WXdqkMDDqwdR3I7qfSGJ0rXFMA0GCSqGSIb3\nDQEBBQUAA4IBAQAAxbWVsS2P1gyG8jnD5PhDp97nfeHTxseaeNLZE35WpXc9CACP\n9Blj9v9jSWX6sg/tv2v+tZ9zrPHyeKmnDd7u9y3Z0jeyEptkhA4pxQ8nBTnizT81\nSqh2y4PEHbiMGhxo7yjscGrQH3+68me4zZRh8K4cwb2Yc5U1OX1AitTrRILjdmnk\nO+FO67Fjb0M3vJBtnzPE+yrHcs1X3ziXNfLiKBpMxd8F/doaBB1NsDyaZE1MvM8w\nQ3Xxxt1gOGGfIHd26VZaZAu2yQbStPmuE39wSd6qHdjhRANX/bvB9BwwWaViSwLL\ncpt9YIL8me3wWdKKULCHEj8ZjnvogpRWvrZm"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SUNY Empire State College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.esc.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SUNY Empire State College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://aai-logon.wsl.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support Contact"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@wsl.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "WSL"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@wsl.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAI"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://aai-logon.wsl.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2016-03-29T10:01:04Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIJAPZ97OKnIcuaMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGFhaS1sb2dvbi53c2wuY2gwHhcNMTQwMTI0MDc0MzM2WhcNMTcwMTIzMDc0\nMzM2WjAbMRkwFwYDVQQDExBhYWktbG9nb24ud3NsLmNoMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAw/9mnMeICEome9JwsYvR37cByiSK4bRDssG76ARD\nUjXBmxxgr+0RJFQgLtJiELwnJ41UMlY+CtorpReaf090OzqzbcKuDbZijOIi5Hic\nvfptOrRNwnsplNCpAQGzWar4yz9WnLTKrYhu24ysHZnjux3gMxLvqAl7+C21ExgA\nFu0bp4MUv7L2wVLp3ersTkFs74GXxlv3IpjgO/gjv/rtvN/ACD97pjwZIkeLeByb\n9rqNYr8jSC15Hvq14GFYq2pBNZ+8UfK4tFtX2nhmr2uC9/5IvdGEcp77moi4BQac\ntSaHF09f+AAFe8lHxwpA96kcaWn6rMYwuMu2BpmdOQRzuQIDAQABo2cwZTBEBgNV\nHREEPTA7ghBhYWktbG9nb24ud3NsLmNohidodHRwczovL2FhaS1sb2dvbi53c2wu\nY2gvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFMSFarXK3mFRGfcZQsVzW7GkO2Fw\nMA0GCSqGSIb3DQEBBQUAA4IBAQAD3Xpnezw9EHK+4iPOarnrZ1m5DLIazLLvefGm\nTM8Ok8HCbTiJppiJtozZ1EpduYwqu+cmzHH96PL4HBJSi3yxjhipGQoUcJbXVKRd\nurS4IDybcHCGP/nQw7oWmnzmPAgt3TQjjqIZ6Bik17V4+YbrLxjVWOIQ5tDB1Rvt\nfd/yHuwao2QOyRuNXE4rPKuSlEJ0z8fXJzBEITbL5dtWvT+F8Z/dDjnIu1f2w6Mq\nwuj/MeTYd+DoM/lKiZ3CADkIsdr4bTon8wmb/adGFG45IPWjNouDPLODwB1stc0x\nQciXFnoeJldeK2oUlQAt7geKp0lMf/2Er+D6VuxBQQjmjXZz"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wsl.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-logon.wsl.ch/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-logon.wsl.ch/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aai-logon.wsl.ch/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai-logon.wsl.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai-logon.wsl.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aai-logon.wsl.ch/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-logon.wsl.ch/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-logon.wsl.ch/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wsl.ch"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.wsl.ch/index_EN"
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.wsl.ch/index_DE"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Eidgen\u00f6ssische Forschungsanstalt f\u00fcr Wald, Schnee und Landschaft"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Swiss Federal Institute for Forest, Snow and Landscape Research"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WSL - Eidg. Forschungsanstalt f\u00fcr Wald, Schnee und Landschaft"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WSL - Swiss Federal Institute for Forest, Snow and Landscape Research"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "wsl.ch"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "slf.ch"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "lfi.ch"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.360644,8.454924"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.134.200.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.134.206.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "error_url": "http://helpdesk.wsl.ch",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIJAPZ97OKnIcuaMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGFhaS1sb2dvbi53c2wuY2gwHhcNMTQwMTI0MDc0MzM2WhcNMTcwMTIzMDc0\nMzM2WjAbMRkwFwYDVQQDExBhYWktbG9nb24ud3NsLmNoMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAw/9mnMeICEome9JwsYvR37cByiSK4bRDssG76ARD\nUjXBmxxgr+0RJFQgLtJiELwnJ41UMlY+CtorpReaf090OzqzbcKuDbZijOIi5Hic\nvfptOrRNwnsplNCpAQGzWar4yz9WnLTKrYhu24ysHZnjux3gMxLvqAl7+C21ExgA\nFu0bp4MUv7L2wVLp3ersTkFs74GXxlv3IpjgO/gjv/rtvN/ACD97pjwZIkeLeByb\n9rqNYr8jSC15Hvq14GFYq2pBNZ+8UfK4tFtX2nhmr2uC9/5IvdGEcp77moi4BQac\ntSaHF09f+AAFe8lHxwpA96kcaWn6rMYwuMu2BpmdOQRzuQIDAQABo2cwZTBEBgNV\nHREEPTA7ghBhYWktbG9nb24ud3NsLmNohidodHRwczovL2FhaS1sb2dvbi53c2wu\nY2gvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFMSFarXK3mFRGfcZQsVzW7GkO2Fw\nMA0GCSqGSIb3DQEBBQUAA4IBAQAD3Xpnezw9EHK+4iPOarnrZ1m5DLIazLLvefGm\nTM8Ok8HCbTiJppiJtozZ1EpduYwqu+cmzHH96PL4HBJSi3yxjhipGQoUcJbXVKRd\nurS4IDybcHCGP/nQw7oWmnzmPAgt3TQjjqIZ6Bik17V4+YbrLxjVWOIQ5tDB1Rvt\nfd/yHuwao2QOyRuNXE4rPKuSlEJ0z8fXJzBEITbL5dtWvT+F8Z/dDjnIu1f2w6Mq\nwuj/MeTYd+DoM/lKiZ3CADkIsdr4bTon8wmb/adGFG45IPWjNouDPLODwB1stc0x\nQciXFnoeJldeK2oUlQAt7geKp0lMf/2Er+D6VuxBQQjmjXZz"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "WSL - Eidg. Forschungsanstalt f\u00fcr Wald, Schnee und Landschaft"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "WSL - Swiss Federal Institute for Forest, Snow and Landscape Research"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wsl.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wsl.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "wsl.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://tcs-test.sunet.se/shibboleth",
    {
      "entity_id": "https://tcs-test.sunet.se/shibboleth",
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish University Network (SUNET)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sunet.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SUNET"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://tcs-test.sunet.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://tcs-test.sunet.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://tcs-test.sunet.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://tcs-test.sunet.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "tcs-test.sunet.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+jCCAeKgAwIBAgIJAJu2W9h/GQn5MA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\nBAMTEXRjcy10ZXN0LnN1bmV0LnNlMB4XDTA5MDkwNDA5MzU0N1oXDTE5MDkwMjA5\nMzU0N1owHDEaMBgGA1UEAxMRdGNzLXRlc3Quc3VuZXQuc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDfOz1hNo/wrI+MBbauT55gEx1IsbEK+KGhWCEG\nN18M2XU+Afad8tG5zPjKDBGNz3JDVQRb+Dldi9VnhbIliPjMpXgpnXjNN8+bYe6X\nSrJHGOOCs3aXixtcqCvkD/kkplLf/RsfVfe3FP49JDApguR4jH3vtNCNJoECUhCH\nVTBFB3BiEx2iky2v+f3NzDoSod8o2NAXLBOC25xCk7VjRa70uiPx32eE7+izsJLs\nVJkaqKmW2n1yZsOS+9puYcr19vNSQ4awo/3uRMbPrPe8Z4cMyAJB1+xZ30VXLhV/\n6nnraUZuF1w6xNp8mFbJlwd4m41bPTitJO2AqvZMzOxrgucTAgMBAAGjPzA9MBwG\nA1UdEQQVMBOCEXRjcy10ZXN0LnN1bmV0LnNlMB0GA1UdDgQWBBQjlFq8PSW2QiXN\n5RWltu60z8K8djANBgkqhkiG9w0BAQUFAAOCAQEAVgyGn2VUctqIqVUqv/AAa7MU\nDo3b3uFe4ezNCe433XJiVJBf1ys5ifBSMEPCtexBlDAKOidaiZfylb6JudgzuDSZ\nfef2y/6Fk8wiub64E4ayKDU5LlsAs43PlOQjufDsq09BesJJFXxBBDIhP4UCL+XO\nnhVX7PZBnBPhjTmt+iUtgBkkMZJMhgDyJJZiYjLcbVfPKKQqTWRK9QUj4fc6JldX\nCmO/ILoP5fWaKzwlK5ybhHyoYH6RYjuV0CBiUlZS6iejpsRokr/aQrQ3JHPWLId+\nVExt5K7bqNQpM9wqLuSjrlCueO4wNjuSTevHKZO6uB4DcnFnNMxWsvB81dLUdg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=tcs-test.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "tcs-test.sunet.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+jCCAeKgAwIBAgIJAJu2W9h/GQn5MA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\nBAMTEXRjcy10ZXN0LnN1bmV0LnNlMB4XDTA5MDkwNDA5MzU0N1oXDTE5MDkwMjA5\nMzU0N1owHDEaMBgGA1UEAxMRdGNzLXRlc3Quc3VuZXQuc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDfOz1hNo/wrI+MBbauT55gEx1IsbEK+KGhWCEG\nN18M2XU+Afad8tG5zPjKDBGNz3JDVQRb+Dldi9VnhbIliPjMpXgpnXjNN8+bYe6X\nSrJHGOOCs3aXixtcqCvkD/kkplLf/RsfVfe3FP49JDApguR4jH3vtNCNJoECUhCH\nVTBFB3BiEx2iky2v+f3NzDoSod8o2NAXLBOC25xCk7VjRa70uiPx32eE7+izsJLs\nVJkaqKmW2n1yZsOS+9puYcr19vNSQ4awo/3uRMbPrPe8Z4cMyAJB1+xZ30VXLhV/\n6nnraUZuF1w6xNp8mFbJlwd4m41bPTitJO2AqvZMzOxrgucTAgMBAAGjPzA9MBwG\nA1UdEQQVMBOCEXRjcy10ZXN0LnN1bmV0LnNlMB0GA1UdDgQWBBQjlFq8PSW2QiXN\n5RWltu60z8K8djANBgkqhkiG9w0BAQUFAAOCAQEAVgyGn2VUctqIqVUqv/AAa7MU\nDo3b3uFe4ezNCe433XJiVJBf1ys5ifBSMEPCtexBlDAKOidaiZfylb6JudgzuDSZ\nfef2y/6Fk8wiub64E4ayKDU5LlsAs43PlOQjufDsq09BesJJFXxBBDIhP4UCL+XO\nnhVX7PZBnBPhjTmt+iUtgBkkMZJMhgDyJJZiYjLcbVfPKKQqTWRK9QUj4fc6JldX\nCmO/ILoP5fWaKzwlK5ybhHyoYH6RYjuV0CBiUlZS6iejpsRokr/aQrQ3JHPWLId+\nVExt5K7bqNQpM9wqLuSjrlCueO4wNjuSTevHKZO6uB4DcnFnNMxWsvB81dLUdg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=tcs-test.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://tcs-test.sunet.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://tcs-test.sunet.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://tcs-test.sunet.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://tcs-test.sunet.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://tcs-test.sunet.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://tcs-test.sunet.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://tcs-test.sunet.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://tcs-test.sunet.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://tcs-test.sunet.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://tcs-test.sunet.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.maneyonline.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso-support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "sso-support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso-tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "sso-tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.maneyonline.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-12-16T18:04:35Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Maney Online"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.maneyonline.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIJAJDMcsKQ9DnAMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\n\t\t\t\t\t\tBAMTE3d3dy5tYW5leW9ubGluZS5jb20wHhcNMTMxMjEwMjAyODE3WhcNMjMxMjA4\n\t\t\t\t\t\tMjAyODE3WjAeMRwwGgYDVQQDExN3d3cubWFuZXlvbmxpbmUuY29tMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2eA38F/RgHF6yDJANjrq+qtQrS7BbYeG\n\t\t\t\t\t\tb47pP8OqzkjVBIQVhnIwEcfCbVym+dVUX1DZRK4YsmxzmHl/FZtSb86lR2LWlSGJ\n\t\t\t\t\t\trvj/ggUAS1MyrGKa5FIpaP87fknDrR8sU04dzu0Rv2ttrrIaRB/GJZLERY0upRYX\n\t\t\t\t\t\taVtnvebsk2XZaoGPdRdb/eFsejsA/BNSOnZkw02RYbbMhotiqRGEu1trjDAJMPDS\n\t\t\t\t\t\tc9ceQt9LNTGnraqAZwy7kWbKz76jLl9s6+uvNRkKxJ4IizZa7xAGuB3d33J4Whwz\n\t\t\t\t\t\tFOk9j501pq05p934onj+W5vODoy6/JZHAcT/DuLj1SLKA0MlAzdaGwIDAQABo2kw\n\t\t\t\t\t\tZzBGBgNVHREEPzA9ghN3d3cubWFuZXlvbmxpbmUuY29thiZodHRwczovL3d3dy5t\n\t\t\t\t\t\tYW5leW9ubGluZS5jb20vc2hpYmJvbGV0aDAdBgNVHQ4EFgQUC7pAjMI3gjmg/6ZP\n\t\t\t\t\t\tQVGTu4ka0zQwDQYJKoZIhvcNAQEFBQADggEBACiWbtf8AxBWSPuR94PO7Xnytt2N\n\t\t\t\t\t\tErSriysu6Y2lqOcjsSpaTPs8X1yZFMuDXE1aKtPgPfpnEz8ktBlLI00zmMr+qAOW\n\t\t\t\t\t\tpCLTzjKzVvC/7sIXWn+KwPOA8qbp/SzbqAfJJy2vua7tvKzbYigxbGwoQHrg8aSO\n\t\t\t\t\t\tPmz35Dd+kfdAR/Y9GGaJ8cS4zXfVSJ4vQ5blWlEHMf9eQy0mz4534FRdiiYPGr0K\n\t\t\t\t\t\t5VgbqJ0kiLAkULR25Xk7W4xzu6vIfS0TaA22W2aPjRS187wziMPhq1nUDjk77YRh\n\t\t\t\t\t\tu/QAd2A/WREM6D8cGegKwlPQ7DhdIZQMt7iZrB4uEsx9CLwYs5YwaegQhYY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.maneyonline.com/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.maneyonline.com/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.maneyonline.com/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-p06.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-p06.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p06.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p06.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p06.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p06.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p06.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-p06.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-p06.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;p06"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;p06"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-p06.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-p06.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIJAPRaN0BRzFzzMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2xhZG9rMy1wMDYubGFkb2sudW11LnNlMB4XDTE0MDgwODE3NDU0MloXDTI0\nMDgwNTE3NDU0MlowIjEgMB4GA1UEAxMXbGFkb2szLXAwNi5sYWRvay51bXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDIz+s+icEd1mcRCwTmWtPu\n1gZ5P2ye3GQLqhBDtZwWIjL2deU2aR073/j+fnsQ83ZjgF1zt6B3LMWDCJo7HnyL\nkL2ZhiuhDWu1Fv2pnukRwrIecsGPCPDzVfAd1fF+Z//JdWL8bkuWlDxnsAbgtvDy\nG6NcxghK0pDW0DNX0kLJQRSj+wfbcbkPCfLB9V9tMr8ZS3+FGY4mK0xb8cnn293J\ngRdvMhTAPS8siOzsoPgrNGLm2ldcq3xEfSPen+uW3xKWznwSJzz/2Nb26LZj0DgG\nVFW69zjToiRAo5M3zDW0J/jJl/UgXteIotewlxXvoww2U8SLL7FR0QCiZbTshqLj\nAgMBAAGjbTBrMEoGA1UdEQRDMEGCF2xhZG9rMy1wMDYubGFkb2sudW11LnNlhiZo\ndHRwczovL2xhZG9rMy1wMDYubGFkb2sudW11LnNlL2d1aS1zcDAdBgNVHQ4EFgQU\naiS83Ir7+1kdTmmAPGE64SH5XJ0wDQYJKoZIhvcNAQEFBQADggEBALu4cUdHRU5m\nXhH/XSFPWiaII+oa/3RRG3ki9B2p/hpeNtYD2UduRB6T/qEEYp4fjjJWCN47CI1n\nvYzvRXvlV2j79M6H27POKU0mU2DqDkWnK08638L71wHwqs7j9VTctZu6Cn1Fa4SH\n/WArmtUlolCl9+Ic2MyOLc8BhSpY5RtGjGkd7RjhAx4JSQH2r+qiEDyHGN5iVBax\nI9QRM6HbSCb7ZRKfCAIStwrgTm+1OrYJXQMpulu7WiwivWVgkXatsQ1CqYw0tV8J\nD46kqfNlqZ/diuIclf5pshpNx+Fl9UBfAzVeUriLtzhy/+OfKZZw7xseVSdfxIqr\naQGrAxWq3Ik="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-p06.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p06.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p06.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p06.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p06.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p06.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p06.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-p06.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-p06.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-p06.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://uclu.org/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:UCLU-wd@ucl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UCLU Web Developer"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:UCLU-wd@ucl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UCLU Web Developer"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://uclu.org/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-03-21T11:06:06Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UCLU Website"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uclu.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UCLU"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uclu.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://uclu.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uclu.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uclu.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uclu.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UCLU is the representative body for University College London students, founded in 1893."
                  }
                ],
                "logo": [
                  {
                    "text": "https://uclu.org/shibboleth-sp/logo.png",
                    "height": "80",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "206"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UCLU (University College London Union)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/zCCAeegAwIBAgIJAKwfQJ+dJ/UEMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\n\t\t\t\t\t\tBAMTCHVjbHUub3JnMB4XDTEzMDMxNDE3MzEwOFoXDTIzMDMxMjE3MzEwOFowEzER\n\t\t\t\t\t\tMA8GA1UEAxMIdWNsdS5vcmcwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDHFh0se+NKTy6reLEX+Hj6WK2A0noHMtkJKOamHMxS+Qi4wGIjJ8PghwPEgP7Z\n\t\t\t\t\t\tSGb4149KQ3MOET7/HkrwCC8DL0XxXnKyHgys5T4BrFwE3b7m2R+2QHDZ3d1Yf+EA\n\t\t\t\t\t\tvDwS6W8vmI+Xt79vNeQeno42AlOdmqoTa7caS76+Me2dhiIhWbeVyTMLaVpBNX+x\n\t\t\t\t\t\tejMdQ6xMMGSc0FYKllbnpl/DA7GZ3y3WgC+1HYD2il7R95ApCJyZay4SVpPwqRzw\n\t\t\t\t\t\tBt0pqxONisGS210SyEkRAglU1EqKW46C0OtM9e3gdKb2lENSrbqVy0y4wE3kdax2\n\t\t\t\t\t\tMHH/oubXZoSB0fPwvPDnG8czAgMBAAGjVjBUMDMGA1UdEQQsMCqCCHVjbHUub3Jn\n\t\t\t\t\t\thh5odHRwczovL3VjbHUub3JnL3NoaWJib2xldGgtc3AwHQYDVR0OBBYEFBjW1cD5\n\t\t\t\t\t\txuoeLApI9ixFbHPIT+OGMA0GCSqGSIb3DQEBBQUAA4IBAQATsVU+8YZBQC94+okM\n\t\t\t\t\t\t3vNuMvpB+oZWWV8PSs4cQbkEOTRRCv4pWD6kbQQEzPBa1wUbOoN71keSJ47tj7xH\n\t\t\t\t\t\t0P/p3Jq0LTTgnC1tZUnqQTfKxvKr/NGvgRIxYq/JuV2NVUSbb1LesWkVPEFY13l2\n\t\t\t\t\t\tPa3L99neKFzEenRFyiqk+uy69ZjX5kN9H5WBIds2oBl67UFIDFkSO6pUCsffvcBe\n\t\t\t\t\t\tNaD+/OdSqymbiaE8lQ6bXsZx5xyHdYB9WjfUFqAetRMsBRX7uOwIT8lWgBUjPurY\n\t\t\t\t\t\t2PLYR/plUVOxRfiB4eEFjuiho3vanQCj1zhKtI3D0rxS2Nlbpu2mZbndxLfBrta3\n\t\t\t\t\t\tAH0h"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uclu.org/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://uclu.org/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uclu.org/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uclu.org/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uclu.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://uclu.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uclu.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://uclu.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://uclu.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://uclu.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.clickview.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wimalasiri"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sahan.wimalasiri@clickview.com.au"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sahan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wimalasiri"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sahan.wimalasiri@clickview.com.au"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sahan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Newman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chris.newman@clickview.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.clickview.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-02-26T10:28:26Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ClickView Online"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.clickview.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ClickView Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.clickview.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.clickview.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.clickview.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth.clickview.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.clickview.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.clickview.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC5TCCAc2gAwIBAgIJAPVbJWGWsfPlMA0GCSqGSIb3DQEBBQUAMBUxEzARBgNV\n\t\t\t\t\t\tBAMTCmN2LXNoaWJiaWUwHhcNMTQwMjAzMjIzMjQ3WhcNMjQwMjAxMjIzMjQ3WjAV\n\t\t\t\t\t\tMRMwEQYDVQQDEwpjdi1zaGliYmllMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAnV1dwqyl8MfIyVDZGPZRTmEeNsJrZzWY5wFR/35trfu2bfnjRyJuuKGZ\n\t\t\t\t\t\taMj90GOwidzqXbLxbgjwbUb6RuhvOoYUHTtyohu0CWBU3e/aU4G4Ls6BmikRHrSr\n\t\t\t\t\t\t6aT6u4AFFf9v4yxO33ReJME++3wVVNPI5v+kb/MGc6FJ2PAjj4lyAetxciTFmgwq\n\t\t\t\t\t\tGiuVPklxqCK/j0KrIeE284b7DsP5HpZYjiW4wRATPfRym86vxWwrWIlBM/xSYvb1\n\t\t\t\t\t\trnGImAhg0fxTQWteHkZKscBENZCGZl8GWF6NqzqeQcvqCZOBXMHXY3ct5+M/IaSJ\n\t\t\t\t\t\tYcVg19SOyoyukEUjQzppN5zMvUMX7wIDAQABozgwNjAVBgNVHREEDjAMggpjdi1z\n\t\t\t\t\t\taGliYmllMB0GA1UdDgQWBBQxeZ/BBNNlmEB5ICBbpXjIjxUFmzANBgkqhkiG9w0B\n\t\t\t\t\t\tAQUFAAOCAQEAjjtVTDqGA+4JL2WbtqFxubs2yWHLPgkKFHNZmdryZ9EX383Gs0Ca\n\t\t\t\t\t\t3HrzTAkuJ9aZLDYdWbfxiSWePEcNYhnSKM1EmPo2BV3oVbtODDRJNcQC1fdHJHXJ\n\t\t\t\t\t\t1RdFLgH0TlaYLT0JhwCO89P87JGP0+5toAe1opZW+nYI+AzNvq4m7IBovB92/GPq\n\t\t\t\t\t\tiF49vK9SE3cKIQt+ICcLmrbU38hVtA6HDc0YxSC1CgGJOrx7RjG2+iwmcXCqnC7Y\n\t\t\t\t\t\tqkdD2iAPnL0dvkY3D5snTUOl5b/1jyE7h4wCBCYTYQ2dBjPtdtcxRHUg1Lca0cFg\n\t\t\t\t\t\tBGi6QxxdSG6OiTxeuWPZr3NkD4YI4RB0Yg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.clickview.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth.clickview.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.clickview.co.uk/Shibboleth.sso/TestShibLoginSahan",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ClickView is the market leader in digital video solutions for education"
                  }
                ],
                "logo": [
                  {
                    "text": "https://downloads.clickview.co.uk/www/images/Clickviewlogo350px.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ClickView"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://idp3.cyceron.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Antoine NOURRY"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "nourry@cyceron.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp3.cyceron.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-12-02T15:40:57Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp3.cyceron.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp3.cyceron.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp3.cyceron.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cyceron.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.cyceron.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Idp cyceron"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Idp cyceron"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/x-icon;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Cyceron"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Cyceron"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUd4yV7VyJaaQKxD07SGw7Mn368dkwDQYJKoZIhvcNAQEL\nBQAwGjEYMBYGA1UEAwwPaWRwMy5jeWNlcm9uLmZyMB4XDTE1MTIwMjEzMzQyM1oX\nDTM1MTIwMjEzMzQyM1owGjEYMBYGA1UEAwwPaWRwMy5jeWNlcm9uLmZyMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnCJRC+vTSzgV9lVg0zUR5VzPmUbi\nMXVIGNtfg9ZRukOtdksNmbXUunvrJ+gG6rU2mdFNwnYc7SoYM2IzLqDZRWNTDESg\nE3whqTQ/mIfq3GHGNowlDBUIEeNtOOrAnrLnUX1ajLUESWpeNw/dFv46xr9Be93n\ngnP4z6gxLYnwaj2t52QJl60m4iqFqsSFfQbtBoQJo0x6DR44gB8ZQ5J+f2ylDnlD\nQsZJur2u53nH9Ja00gHtVBB9DV1gPRWQ8RzhcA1S47BzieDEtNtxppyYoW25I+tR\n2uw5CNq2xJMMTcJFHIXrnv/7+HEJAW6GZylB7/R6z0SYEZGZI6ff+6U9fQIDAQAB\no2UwYzAdBgNVHQ4EFgQUHUzKe91PU4ztZ5XWpwejI2zQ+CIwQgYDVR0RBDswOYIP\naWRwMy5jeWNlcm9uLmZyhiZodHRwczovL2lkcDMuY3ljZXJvbi5mci9pZHAvc2hp\nYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEADDyuxvPXK3/OP9vZ6QCakxTzLDhP\nSz5vsenCwGRlELfqBLUT/wU2FqgaVM6Z6YyeBWcXjVZ9u1jqovn8B+9saeCoJMN/\nfqnqIzjWt84UXNmCiVdQ/zhGF4KRkXxDR0lyW7MkTI0L3tZ/TY21Dcgbm7ACaHV0\n3jVbpwNVin0fd+b0R45UlIMcVjSG44fNpctROgRstPgmnQHu+HFAl5QnYKl+12AW\n33nMIlovQpwCdCGTKk0WUUutJcCbrFFYZUHEzi4v3rqcLzaQ4xxK6tJTvGvAaQPA\noHzPlWtlZWRz8eUkil/RDUfqu2/GSUhl0CIvH7Ib10F4sZlZP00xsWd4yA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cyceron"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cyceron.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cyceron"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://abertay.unidesk.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:IS.Helpdesk@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-certs@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Application Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://abertay.unidesk.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-05-29T09:00:43Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Edinburgh: Unidesk - University of Abertay"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://abertay.unidesk.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://abertay.unidesk.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://abertay.unidesk.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://abertay.unidesk.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://abertay.unidesk.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://abertay.unidesk.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAPHsl6kKrFrnMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\n\t\t\t\t\t\tBAMTEmxpdmUudW5pZGVzay5hYy51azAeFw0xMjA0MTExNDU4MjhaFw0yMjA0MDkx\n\t\t\t\t\t\tNDU4MjhaMB0xGzAZBgNVBAMTEmxpdmUudW5pZGVzay5hYy51azCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBAL9qh/Dehm5jJdWdeFPNKqcjMdiqii8Iz9Rc\n\t\t\t\t\t\ttCAsEwRsYww4EQDG7MxG5hg4NSS+iIPFCp9gR+G7hTnZAMGgNpxs2vk4vs9lmhRY\n\t\t\t\t\t\tGmB7Y1NFloP9Pcsu+MaufaLzxi6bzIXV4dBVHqVnIcgxchDIsXmPE6xlq4poEq+q\n\t\t\t\t\t\tXJ3aFE/eWwxfwN9z0s5yeICzsil73xk9T9NLeNAeYq+jfVTcdqDbBHY6eHtMOYh/\n\t\t\t\t\t\tuPVYYxkKXjkgSH5cwG0b+7qN4z+uzKDNBXxnI1Nz+bLOazXW6ljQIDtAPQZMJSlr\n\t\t\t\t\t\t3OepVaQS+fMBi0Sku5yvADgINdXxkz6H4Zx4pZg/rTQBQ/8u2esCAwEAAaNAMD4w\n\t\t\t\t\t\tHQYDVR0RBBYwFIISbGl2ZS51bmlkZXNrLmFjLnVrMB0GA1UdDgQWBBQ2tPlzxC8e\n\t\t\t\t\t\takC2nh9qrG4TWfI3tzANBgkqhkiG9w0BAQUFAAOCAQEAWPY3Nv9ChZ+4XVNANhLq\n\t\t\t\t\t\tfGF7SbiPmUNj9vWGNjCp8Ma0tdDOZPvqBRzxKkkR+LS+fHpSQQ54RuNeZrulWBiN\n\t\t\t\t\t\takZe3LZiSH9AHG2uD0lDuxr0UQt1AHGDiLjFXuRg9+CdqqrdT3Anmy6exDDfRsjH\n\t\t\t\t\t\tk+ZJflkEtqTNd0dbEVlkYlg8Baqx/ZMOxkccx8PtQt1yptAMsH4Rn92vXLd9d3JM\n\t\t\t\t\t\tH1mrFuiriqrgsAfVLmzc4WeGmB+dK01cSB+CY7hKnoe7ds1y7kNhOmZ9HP3Iy7ev\n\t\t\t\t\t\tgF2RCdnqkP9zScihW4b20PlVa/sWMUyCj2uZE1lSO51PJcGVU0H/JFrBEpaM7u6t\n\t\t\t\t\t\tjg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://abertay.unidesk.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://abertay.unidesk.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://abertay.unidesk.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://abertay.unidesk.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://abertay.unidesk.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://abertay.unidesk.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://hr.liu.se/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Primulasupport"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:primulasupport@evry.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://hr.liu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EVRY HR"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.evry.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "EVRY HR Solutions AB"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hr.liu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://hr.liu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hr.liu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hr.liu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hr.liu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://hr.liu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://hr.liu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Webgr\u00e4nssnittet till HR-systemet Primula fr\u00e5n EVRY HR Solutions AB f\u00f6r anst\u00e4llda p\u00e5 Link\u00f6pings Universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The web interface to the HR software system Primula from EVRY HR Solutions AB for employees at Link\u00f6ping University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Primula"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Primula"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "hr.liu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4jCCAcqgAwIBAgIJAJcVspuG+BMBMA0GCSqGSIb3DQEBBQUAMBQxEjAQBgNV\nBAMTCWhyLmxpdS5zZTAeFw0xNDAxMTAxNTUyMjZaFw0yNDAxMDgxNTUyMjZaMBQx\nEjAQBgNVBAMTCWhyLmxpdS5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\nggEBAMf6XZkFiIiX6AY/Tc4d/lKBFLl7EdhuaSjzHe0i6fjPhcwG1K6NLTG3jgAc\njb01aBeqThmOfuKN63C+pixLM6JVV9W8FhWswtnxFbSj/PeZbrOClT94gdhfg/BT\nyr4R/Ibv1RULeJZEMKlj4frqagMk2LNjusO/pz0Ef1pocijMUjSP1Htuc6jrIl2R\nSeIDASe0EyPRxJbnFR67QrlgCQM+KkYzJoJGqm7i0vyZpCxHZZ0IF5yQLUfbWKqz\ngr9BcdhGMZsWgXqj0oaoNp7ToA3iWwvneJp3TR7PGZ000LRjyvFtoDfl6JMlI6Dp\n+zJgek/FwgmuXeHHq439jqji2ycCAwEAAaM3MDUwFAYDVR0RBA0wC4IJaHIubGl1\nLnNlMB0GA1UdDgQWBBS7SGYm9J60wzajV8J0EGln/krUZjANBgkqhkiG9w0BAQUF\nAAOCAQEApnOIZMXjck11Njg0PhDECJEcGw2LoTrPFLdK5P/fdhLPa//Oh1krs3Ou\niSTTqp+PQANiD+YGVcP/O7mttaDNL+jdeKL+2AcOIcBury7/F3RpIVXItl6QOiWv\nvqMicNR6N6oX3BUIjZel5J7Glz7rkevMapZmnIiDMxRxNQ+IP6tpGnsSl95VBhc4\nTzgY/9JmUTMvcBUipD21sOrkuEf0dYYQUgpQOq8vlV52lKl0NnU25YiEGKgfREo2\nJ60CBAmXpIDoGhn1QsbpDIUcEX2lVSnUhkT0kw2d09EBfBiaTkBsLGmACSPnSVyJ\nZgu8vav6NzPHTYy+UoBYKhwMNtFqIg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=hr.liu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hr.liu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://hr.liu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hr.liu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://hr.liu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://hr.liu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://hr.liu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ensait.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Vincent Dubreu"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vincent.dubreu@ensait.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ensait.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-11-06T17:33:56Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ensait.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ensait.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ensait.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ensait.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ensait.fr"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENSAIT - Roubaix"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENSAIT - Roubaix"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUQaof2K6agQCF8gpgtk0a0RLQaWQwDQYJKoZIhvcNAQEF\nBQAwHzEdMBsGA1UEAxMUc2hpYmJvbGV0aC5lbnNhaXQuZnIwHhcNMTIwNTMwMjEz\nNDI0WhcNMzIwNTMwMjEzNDI0WjAfMR0wGwYDVQQDExRzaGliYm9sZXRoLmVuc2Fp\ndC5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJbZ3w1hWqsxOWvC\n91NvUAw9j3ZoKxO/oOsMMEvUjqj4ByYVb9eBN62rCT14cjaadGwdKPjQlPZ9HDVs\nQIpjnQxazohlPsKYDzROQSuQEWzSWysl0fUtMTk2tTXn9fshyw2UFaheR/3gzHrw\nB4opDzZLPnaXvW2XfptE8QEt51+YWouoc7ZTGj6O35jWlijguScZmU54aN2KTLAe\nJLPVb/Sj6I70vpCEbTaIu7JKsl/ItbdG2AzCMP84a6Sy30Tb5ZYcJH9angf3KTkT\nQLi/03swqNUBoIk+ETYdrpjfXCv/pnzuyKEy+LDta70lJs7mfu/kngPaq98ntVmo\nXU4wE+0CAwEAAaNvMG0wTAYDVR0RBEUwQ4IUc2hpYmJvbGV0aC5lbnNhaXQuZnKG\nK2h0dHBzOi8vc2hpYmJvbGV0aC5lbnNhaXQuZnIvaWRwL3NoaWJib2xldGgwHQYD\nVR0OBBYEFKYKdm8Oq9xVUEY0k/00dVCpDDdlMA0GCSqGSIb3DQEBBQUAA4IBAQBD\nvKvLHs7gAJOPgG3fy1lfsAtqH6lvv5oEVMFl4Ko0mTvpAq+MBCd4pGVaH8JRMfK4\nOL+CPSRU/HNZ2DaglwXpRsO8eOawWAXRlBDvC62NufoXSEOTEOWrHL/n4KlF7yB9\n1BsDcBcKr3t8WCw1qPOBteOryF16tNw875qjgZrn5AmfobaC/Nw722oIN+I8f3vO\ngpUgOIXaS2fcmAZ4s9BYnfGgBGlP6PXF1FKeJtmO8JOl4CLZbP5y70qoJjb2xdcV\nC43cpFxAJzzjvIOU2iZuq8VgOYfGJhy2JGN1/OcVTzGu0dk31yUz/l1OLvvoIHeh\nLL0sXjeiiyK6lcUES5UR"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ENSAIT - Roubaix"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ensait.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ENSAIT - Roubaix"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.ac-limoges.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "cazarres thierry"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "l.das-ie@ac-limoges.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.ac-limoges.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-05-06T15:34:22Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.ac-limoges.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.ac-limoges.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.ac-limoges.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ac-limoges.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ac-limoges.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "any one"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "tout personnel Acad\u00e9mie"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rectorat Limoges shib"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rectorat Limoges shib"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGAzCCA+ugAwIBAgIRAODebMx5oGfvlJ1vAEw7CMkwDQYJKoZIhvcNAQEFBQAw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\nfbTj07Dtdw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIVAPI2OQnwEI796qTcWNc+EBU8y1vbMA0GCSqGSIb3DQEB\nBQUAMCMxITAfBgNVBAMTGHNoaWJib2xldGguYWMtbGltb2dlcy5mcjAeFw0xNDA0\nMzAxNDIzMjFaFw0zNDA0MzAxNDIzMjFaMCMxITAfBgNVBAMTGHNoaWJib2xldGgu\nYWMtbGltb2dlcy5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJRE\nS2ttB2Q4gKGoOA7GRB1u8quMRF/jC0B+dtcxhilipU7ITjiQMCto0Vvlr8MhJsiH\nXzQpucbD2jvfBqX9/3/opLgNgLEEQFiJ8mPtXwcSDiEZVrj/9wqq63wnNQQ6b0qV\njO8jrD2PmLpPTPmuxd6RpugQ+KM7sEzbM8d/GGnmuBHyKcKYXcmko6WKCwCwm7xf\nWozFuDYQQES8282sRCi1PdPaiUvqkqnx8Bl4N82iwTdN9cDvSWSSlcdamX0z4/6O\n06Cp+q8xWn24vm26UxA2PhODaLH8CAWExTtQS2DEasu6d066vaSx6UVuB2s9C+rM\nngdB7azRm1ujFU6T4akCAwEAAaN3MHUwVAYDVR0RBE0wS4IYc2hpYmJvbGV0aC5h\nYy1saW1vZ2VzLmZyhi9odHRwczovL3NoaWJib2xldGguYWMtbGltb2dlcy5mci9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU88f2Yh9G3YvxK1a9XpdwWCspbSYwDQYJ\nKoZIhvcNAQEFBQADggEBAGqCAwe7lZDbaE1Ynj11VxMaRxzphVIYtWTGVoZQmoZ1\n774wmVw96rSxU4CWgFJ+1nurcgdZvH6mkKE8O9FXYklO25mpLD6DB7cGiVjcJVn6\npuYEzKtucKDG57f6KJ2EnO7kWCmtw/56d16JE069Ze7wr8BYHy3XON29UhdBGDZo\n0jnd9p9OUdk+gHxUcc6oAa++jyUOUpJd9O/P/HjovoqvE+brI5WHXFgxXg6ILpXo\ngJ81iLD/uinQAju00xak32Ig/WMrnzCYBFotWMElnHnJkTeS6l3obIYg9JeS/Hgu\n9mMpytM+UUp81UdTXMv7RsTpHsroJoDN3OVfzKOmjnk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Rectorat Limoges shib"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ac-limoges.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Rectorat Limoges shib"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.brynmawr.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "achiarello@brynmawr.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew Chiarello"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@brynmawr.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bryn Mawr Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dbertagni@brynmawr.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David Bertagni"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.brynmawr.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.brynmawr.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.brynmawr.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.brynmawr.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.brynmawr.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.brynmawr.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brynmawr.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://idp.brynmawr.edu/idp/images/logo.jpg",
                    "lang": "en",
                    "height": "89",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "325"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Bryn Mawr College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAMZQic8OVtgucOwzh/ScyVxJkqleMA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEGlkcC5icnlubWF3ci5lZHUwHhcNMTQwNjEyMTUzNDEw\nWhcNMzQwNjEyMTUzNDEwWjAbMRkwFwYDVQQDExBpZHAuYnJ5bm1hd3IuZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0WTH1kLr4ttRM/+0iFLGE+xG\nhlwgOKVjQL8yG5nBp/mFRV8kwZB5u6iOEcUfibRUvlDg2oXwMNtEbj0ieNBg8BC4\n7l3/Y7SYc70b7gB6vwzFGvzbYpro15RoJQn3HyEcAIT14sJ29cO/o4PUjvkp3Awd\nDsoekKLpGBHwnYhlr4MSBs/pWrpVXYhpJhtCr3ZcgD3lnEKXkrwFJ+/CTti2MvTy\np6qg2znoLPtfjBi7PtkMyrNUpb7x1Ug6QszCU77bVD8QURqgTkb3mXVei2y+0zvV\nDa6gpiDeCF4KAzaY/6mZHJ//qySQlIE5h+88POfENbIOAKcisjNht9a7XbPhcQID\nAQABo2cwZTBEBgNVHREEPTA7ghBpZHAuYnJ5bm1hd3IuZWR1hidodHRwczovL2lk\ncC5icnlubWF3ci5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFFr80dQNdVOL\nO13FO9DjVgsJgFZkMA0GCSqGSIb3DQEBBQUAA4IBAQBcJI4BqqaP7eCXOtlkUxpZ\nbUzqc/24RN20Fnp/Tva35Tnpd2XwNlRTILmmRJ1Zt525ikKTFz7zzCZFg/TuGasA\nGdOEqebquuPlInkU0QShR35azgopDRLT+xT6D0kk+Mcb6R6RcuhJJX6qncnOpxBn\n7ua73b32Yv4S+YEmXa4iZ7X9k2Su5xHXoGzcI25J2XRA7PSUhpS4XtaZ/hv9Jbz7\nEi862+zrJ/dFHIW9QSPKAXPKbHd6e7dhkcNu338z+lbiat4i809Q66vNdYFwSSKD\nzLCYZhlk3ldpmygjFF5SpsEJjBIkDYxwiFYAzGQcDIawRMw21Gh3LJ2GRYUtIyrL"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bryn Mawr College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.brynmawr.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Bryn Mawr College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.sussexdowns.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Counahan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:gavin.counahan@sussexdowns.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gavin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Counahan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:gavin.counahan@sussexdowns.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gavin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.sussexdowns.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-08-02T14:30:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.sussexdowns.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sussexdowns.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.sussexdowns.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sussexdowns.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sussexdowns.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sussexdowns.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sussexdowns.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIURAFiqUwkPEeqc96JttxXGAE26L4wDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwIDEeMBwGA1UEAwwVaWRwLnN1c3NleGRvd25zLmFjLnVrMB4XDTE1MTIxNzEx\n\t\t\t\t\t\tMTkzN1oXDTM1MTIxNzExMTkzN1owIDEeMBwGA1UEAwwVaWRwLnN1c3NleGRvd25z\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAjlGQ/46Zz8XS\n\t\t\t\t\t\tITjMuhfDCzm5/oD4jbdpqXDIhZ1wYs2RGgv76L4qDT6DFM9ZayZ5j/pMyA+Nu66Y\n\t\t\t\t\t\trsO4gfhrVsaZvM16QX8+/jNdYMbBkPdIu/6VaZWXrGFyaX1G0gDR+eeUbsfhTjPA\n\t\t\t\t\t\tO/UlHeaT+veqE7qea/HcDmE4IyuPg+VihxiWbUJr7AWM3PsHY3vxGF56F660CJB6\n\t\t\t\t\t\t+3x/dITHpaLzTDjx4+EJHQx15YA3JFy/oVmzlFXiGv7bFeaGFkwXRbGITy3i9qrQ\n\t\t\t\t\t\tTkPH0d0vVoliQUy/WA6kYg3zvEo1AuvFPOBikoyuvG/S0/MdYdYtQ88XNN/JD71g\n\t\t\t\t\t\te49Rhe7PAQIDAQABo3EwbzAdBgNVHQ4EFgQU+P2pTqq/YUXsA6I/zNvITmp9m/Qw\n\t\t\t\t\t\tTgYDVR0RBEcwRYIVaWRwLnN1c3NleGRvd25zLmFjLnVrhixodHRwczovL2lkcC5z\n\t\t\t\t\t\tdXNzZXhkb3ducy5hYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOC\n\t\t\t\t\t\tAQEAOU6r12uD595fLRVZ/MZDYZ1ZeyJpGvLzQdb9UizHt8V1hdVGPcNY+GfL4bp7\n\t\t\t\t\t\tQrGPnWr+e64PvswEXA25ELy3ecpsNAdbL5u2iGpYgDLnqqX3+wmaGwSyTkT9bQ8H\n\t\t\t\t\t\tDIyt0PGnv9OjLm8Cv+UEYyneTP/sha3QRUdXrgqlAaWu489ZbSiaPoNd9gRg7E6i\n\t\t\t\t\t\tZ9HN/Yt9NiPHit56211YR/a/SZY7bX/ML3G9mOhTPy0lnYh/dFJjLLKNJnK0BXDq\n\t\t\t\t\t\tqRGS+ddJ2d88CbPTgU0IIAKzNK3OnmEX/PJ/WJOgKV1ThFXs2d3EWeL46AKrgHMW\n\t\t\t\t\t\tt52x/Ffb6//Lld/tcohp/7D89g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVAOIaZM3vDoHKS6s49KFRowGWMrhoMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMCAxHjAcBgNVBAMMFWlkcC5zdXNzZXhkb3ducy5hYy51azAeFw0xNTEyMTcx\n\t\t\t\t\t\tMTE5MzVaFw0zNTEyMTcxMTE5MzVaMCAxHjAcBgNVBAMMFWlkcC5zdXNzZXhkb3du\n\t\t\t\t\t\tcy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIpvgW9+B595\n\t\t\t\t\t\tD0WgHoZOS4cBeQc9GfA9kSPW1EyyfManq4uJ/DTqlaFTVwKUyfq4TAxrDDTR5Oty\n\t\t\t\t\t\tcEdZQVzlrWxXXCf1x1MbvGmx3XsLj3VG/CSDEoFVlUlP2Fyhf9x4WWiFETbmeDTy\n\t\t\t\t\t\tSXbI5/7i1R4sFIdatgJzEsTmVxVshtfVZca3Th0JuWUGd4bRpfFC7w32uwa/aUSx\n\t\t\t\t\t\tJRQpN6pP3Wgp0cl9LBHWvq7vvnwYFxW2WwnW15SsFXMOp8wYYxvuJd60U+tndpFL\n\t\t\t\t\t\tk5drnW33mF12so1k8MlJDu04tSMENE0U02YjF1ZElImKvtgEfLwbJzFTJFnFNJn2\n\t\t\t\t\t\tJPS/P42KlKECAwEAAaNxMG8wHQYDVR0OBBYEFG3Rqg36hQNcgq33iUo4KK4Zdy7n\n\t\t\t\t\t\tME4GA1UdEQRHMEWCFWlkcC5zdXNzZXhkb3ducy5hYy51a4YsaHR0cHM6Ly9pZHAu\n\t\t\t\t\t\tc3Vzc2V4ZG93bnMuYWMudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQAD\n\t\t\t\t\t\tggEBAIRIojOcGmCWa9k1bPDPYIoaNf/ZVXQokPMBIV6szhP1+/pYQYf3JY/0hAXv\n\t\t\t\t\t\tTcZRDFdd708Y3IByyH/WckVzQFuQq1WSN90DPIgKKXf3SLGXhnv9eVC9MnUlB7s2\n\t\t\t\t\t\t83YCmBNctkQQ4ZEu2ZvchQaxzp0Gx+Emu7lyDM20XdqCZfR2ovuLq9LlOdtlGxgO\n\t\t\t\t\t\tGRr0Do1F9M6GFLCZg/t4D7+cjOP0+v7HB/dmLItt9zAaRWDIrnQqoP940PwaBqCh\n\t\t\t\t\t\tNYbRkFbjPKQhDvO4kI4QqLYBCvVWEsba+Z+/scBMWwHU4fHONpP4s/54gYifgH/e\n\t\t\t\t\t\tAPhr3gWeqRKI8ywdO1Rm4eziOxE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUa5OG5i1Wpluu9P44ecwPAnoEUWowDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwIDEeMBwGA1UEAwwVaWRwLnN1c3NleGRvd25zLmFjLnVrMB4XDTE1MTIxNzEx\n\t\t\t\t\t\tMTkzNloXDTM1MTIxNzExMTkzNlowIDEeMBwGA1UEAwwVaWRwLnN1c3NleGRvd25z\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkGUkJb5iXiLp\n\t\t\t\t\t\t6RtG+A0Clx5j9lrmAmvU/PKUFCCv/UCuFeIVsXAeBzz0mdGOdPw+17p1xQssyro5\n\t\t\t\t\t\tmD80ikQV3eCnSqJt3N9opH+itpeZWLnvqIbv7DnCg1iqT4GbYQF2b6OlrIrdyYtO\n\t\t\t\t\t\tDR+15R2WRTz2wqhv4buLe0fhTXDFKD15SE8CEl/hRxXq8ccG1syhb/LjcG3uXgPz\n\t\t\t\t\t\twEtP4iKPCCJG2I9tX85+Darae5JIs2qHebiiuFUyUv+u2x2a9uK4VsmfWVGPdttm\n\t\t\t\t\t\tOzOrGmxQ89aP8Bjf32sxuJ6WnLpC9hmAtN0oIMRknTOckjD5c1Kyvk77yxJ2dnk5\n\t\t\t\t\t\tJHaEaUCaUQIDAQABo3EwbzAdBgNVHQ4EFgQUfHVM1sqRpbYALTwazKjUJmqyS6ow\n\t\t\t\t\t\tTgYDVR0RBEcwRYIVaWRwLnN1c3NleGRvd25zLmFjLnVrhixodHRwczovL2lkcC5z\n\t\t\t\t\t\tdXNzZXhkb3ducy5hYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOC\n\t\t\t\t\t\tAQEAWDD1JH+p8VZRUKTNOvcMIHK58/fgYudN+Ce205BdFeAk+5lQFNmbGlQ1089U\n\t\t\t\t\t\t1zCDqTkDOZOL6BuLocAPRqAK+IAyTFpHXA3XeZWU/AtEPxyaETtXiWn0CONd8oBV\n\t\t\t\t\t\t4sXKlWCUpv8PEdG8HG00ssDDDjnJwGSS0kX7pSzVfbLoKFC5CJgLAIiyBt7xk3X8\n\t\t\t\t\t\tIwccljGvtByHXsPyhiKcNwIhrCwArOqG96rmCTZh7oX6WvSMFEs+w8oBb0PMZp/3\n\t\t\t\t\t\tQ16I9/JE3NKX6hVlO19PFwBeJ9ZlVh53zBDSfIuZPlGYK5KFlC3PE/HowDnPa3Xv\n\t\t\t\t\t\tcd/dBsqyzhYBk6a6l0Gi7CukFQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Sussex Downs College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sussexdowns.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Sussex Downs College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dmponline.dcc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@dcc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "DCC Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@dcc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "DCC Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dmponline.dcc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2012-09-11T08:16:33Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Digital Curation Centre"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dcc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dmponline.dcc.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dmponline.dcc.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dmponline.dcc.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dmponline.dcc.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dmponline3.dcc.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dmponline3.dcc.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dmponline3.dcc.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dmponline3.dcc.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dmponline.dcc.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dmponline3.dcc.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dmponline.dcc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dmponline.dcc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "DMP Online is a data management planning tool provided by the Digital Curation Centre."
                  }
                ],
                "logo": [
                  {
                    "text": "https://dmponline.dcc.ac.uk/shib_logo.png",
                    "height": "92",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "310"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DMP Online"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJAOtCUnAkVkzgMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\n\t\t\t\t\t\tBAMTE2RtcG9ubGluZS5kY2MuYWMudWswHhcNMTIwODMxMTM0OTUxWhcNMjIwODI5\n\t\t\t\t\t\tMTM0OTUxWjAeMRwwGgYDVQQDExNkbXBvbmxpbmUuZGNjLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1Y7lhKA+QuVcLVmN8ZaJ+5+bq1Tuv5Qt\n\t\t\t\t\t\tkZVVoNBiO+Hg3F4p/wGIHyAS6XD1VB+7P2IokGt13JtCxJYoq2m51M4yhwp4kKtu\n\t\t\t\t\t\tvTW5bvxY/Qwl5aCIq9l9ZCIgD2wQ0F7dumt6F9/MQjhnDd81UMNm8Szcwmi58HxC\n\t\t\t\t\t\tMHYW/Gwto0FoMlursS/3/Cx/nl0jTF3U5Yl9/xEb9/Nooe6d2QZagN5JWl+jbEve\n\t\t\t\t\t\tbURMzOFC0+7hmmvrmj2MinKfZEsX4RLoH3KKdPSWBhFM4xpsezBZjlfFNngzkLWH\n\t\t\t\t\t\t47nsQnxHJyE4p33AXMb3SA8OxY06sudQUPgWIG4kBC9L68qIAegvBQIDAQABo0Ew\n\t\t\t\t\t\tPzAeBgNVHREEFzAVghNkbXBvbmxpbmUuZGNjLmFjLnVrMB0GA1UdDgQWBBSg6Qwr\n\t\t\t\t\t\t6uNEhUn4wQ5RJc3pKZbJHzANBgkqhkiG9w0BAQUFAAOCAQEASK4EQU4/iRNWN3T8\n\t\t\t\t\t\t8uSl5RVdUyHEhqAvRLMpQn2UlZ4N1zfAHhTQx3V2Qb/WGz9DWXgTHHmPvUkwsMGk\n\t\t\t\t\t\tFy1OGGX4NcTb3xRa3c8i97TXOIWqWBNL73PnF2tvCEMR4ESckAzkKoIprbMYHsTA\n\t\t\t\t\t\tkv6ZJIEbhewDT3v5zPUIZZl4eipFyV+5WIP3P9NIV89sheP3L5WeuSlkr7ne0ceO\n\t\t\t\t\t\tFhpQ3ECRS+/8WHrJvRGtTO5xeecXvmQE1Opg21XyziVpANLFSjOGLywUOcg9e2zl\n\t\t\t\t\t\tPrL11PMKc2fluPWs4Q1TVZzXOVVYw4P4LbvfWswPtvVlt2b7XNM/+uKApHYRd/Zu\n\t\t\t\t\t\tisijLg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dmponline.dcc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dmponline.dcc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dmponline.dcc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dmponline.dcc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dmponline.dcc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dmponline.dcc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dmponline3.dcc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dmponline3.dcc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dmponline3.dcc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dmponline3.dcc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dmponline3.dcc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dmponline3.dcc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://xenosmilus2.umdc.umu.se:8086/nren/sp.xml",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://xenosmilus2.umdc.umu.se:8086/nren/sp.xml",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://xenosmilus2.umdc.umu.se:8086/disco",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICIzCCAYwCCQDFqR2p3amCSjANBgkqhkiG9w0BAQUFADBWMQswCQYDVQQGEwJT\nRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UECgwDVW1VMQwwCgYDVQQLDANJVFMxHDAa\nBgNVBAMME2xpbmdvbi5sYWRvay51bXUuc2UwHhcNMTMwNjE0MTY1MjAyWhcNMTQw\nNjE0MTY1MjAyWjBWMQswCQYDVQQGEwJTRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UE\nCgwDVW1VMQwwCgYDVQQLDANJVFMxHDAaBgNVBAMME2xpbmdvbi5sYWRvay51bXUu\nc2UwgZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGBAM8nCb97J2QNi/U+4EnR2vL/\nvGtUM44dyOrdQ4xdD/feHyu0kWoNal/8CXJTYtDVrbKMg90fakPfw6Lw5KxQTzGl\nR6qNRyuuMq7KIgRzlbZEWiAh1YKQMOn+C3qIM0HqkfjD/rnCokIpFhGFi+7886AD\nVNB5CnUQXrSTAkUJzVS7AgMBAAEwDQYJKoZIhvcNAQEFBQADgYEABfQAzyDkwIQZ\nHu3tPi7QvJbdTDH8F3q8iSQwOT7MvxmHmCO/DZFwYu5jjYg/FtBfpbh8mQTziCy8\nFyVMuMKNSZn2rEIJF1ghgQqtHwn08zsPPhD9XW0LXeP6Exl/xIguWJElU9JzmPU6\naZOix3ahmr0PwcIhFbWaZvsjL46MdHI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICIzCCAYwCCQDFqR2p3amCSjANBgkqhkiG9w0BAQUFADBWMQswCQYDVQQGEwJT\nRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UECgwDVW1VMQwwCgYDVQQLDANJVFMxHDAa\nBgNVBAMME2xpbmdvbi5sYWRvay51bXUuc2UwHhcNMTMwNjE0MTY1MjAyWhcNMTQw\nNjE0MTY1MjAyWjBWMQswCQYDVQQGEwJTRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UE\nCgwDVW1VMQwwCgYDVQQLDANJVFMxHDAaBgNVBAMME2xpbmdvbi5sYWRvay51bXUu\nc2UwgZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGBAM8nCb97J2QNi/U+4EnR2vL/\nvGtUM44dyOrdQ4xdD/feHyu0kWoNal/8CXJTYtDVrbKMg90fakPfw6Lw5KxQTzGl\nR6qNRyuuMq7KIgRzlbZEWiAh1YKQMOn+C3qIM0HqkfjD/rnCokIpFhGFi+7886AD\nVNB5CnUQXrSTAkUJzVS7AgMBAAEwDQYJKoZIhvcNAQEFBQADgYEABfQAzyDkwIQZ\nHu3tPi7QvJbdTDH8F3q8iSQwOT7MvxmHmCO/DZFwYu5jjYg/FtBfpbh8mQTziCy8\nFyVMuMKNSZn2rEIJF1ghgQqtHwn08zsPPhD9XW0LXeP6Exl/xIguWJElU9JzmPU6\naZOix3ahmr0PwcIhFbWaZvsjL46MdHI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://xenosmilus2.umdc.umu.se:8086/acs/nren/redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://xenosmilus2.umdc.umu.se:8086/acs/nren/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://rnp-cafe.ifs.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Joao Silvio"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "coimr@ifs.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://rnp-cafe.ifs.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDmjCCAoICAQAwDQYJKoZIhvcNAQEFBQAwgZIxDDAKBgNVBAoTA0lGUzEMMAoG\nA1UECxMDRFRJMR8wHQYJKoZIhvcNAQkBFhBjb2ltckBpZnMuZWR1LmJyMQwwCgYD\nVQQHEwNBSlUxJTAjBgNVBAgTHElOU1RJVFVUTyBGRURFUkFMIERFIFNFUkdJUEUx\nCzAJBgNVBAYTAkJSMREwDwYDVQQDEwhybnAtY2FmZTAeFw0xNDExMTgxNzQ2MDNa\nFw0xOTExMTcxNzQ2MDNaMIGSMQwwCgYDVQQKEwNJRlMxDDAKBgNVBAsTA0RUSTEf\nMB0GCSqGSIb3DQEJARYQY29pbXJAaWZzLmVkdS5icjEMMAoGA1UEBxMDQUpVMSUw\nIwYDVQQIExxJTlNUSVRVVE8gRkVERVJBTCBERSBTRVJHSVBFMQswCQYDVQQGEwJC\nUjERMA8GA1UEAxMIcm5wLWNhZmUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQDCM5DpvNNnNY/sEgNPlwTqln/1ErY5NIUFJpd8Z8nhF/Ycg2PHgyaRS5QG\nzg/ytuSPgQwNsqQrBDPVYTM2mPN4bqy3JCMsQ/wurwGY33HQihsq7gsys6sIS3E9\nOeGP2PVEFAAOGBK8/7re/MNkk3zWxVrGHz+jWHUj/XVuz5bEOq/LNmUYgdCKA4EF\n8Fmi22aL522xCT3Fox8ReTq817YxTq+5XLsQEAnOzwIIvOAmRjNZD33lcASWzSJp\n2YMsVKeFpHslgJJUT6a5lbgwH1VOX8VQRYSDGayNfBh63AphlRPbRJRcLG6bQmbx\nD/hfNk2K0FKD9IWxVIJ4O+jxTatlAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAAXZ\nggk3PPdDktXF9fuhLnPpctJpFydTZaJOtZyiTr/YRjRa563VN7ryU7cIN6L/0v9J\nVqW3/LVA5m3vxJn0JFoez65HTVlIgaELJbIw5deHZbYe07e0cQKfEcfuJwzh33YO\n3PyBLMg/gdxoK6cYW0oPM3fZ9p7ypRHyrH/FwJOiFKOKEVdDPI5TlmWJnw85aAEP\n0j+yWPYFmv5t3igK9Iu0WM927mw6gZ0Wk1g53us1aWqoMTjkJZpfI7yBXCsuYYbp\nR2dlYBbt6VnHnQZs+va8RjGt6Q0lRgBsQ5cfwrwDVIdzdB0gOleF/xa0BeKS0GlT\nMC5VxNHzIJWcOb6+ZOc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://rnp-cafe.ifs.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://rnp-cafe.ifs.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://rnp-cafe.ifs.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://rnp-cafe.ifs.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://rnp-cafe.ifs.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://rnp-cafe.ifs.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://rnp-cafe.ifs.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://rnp-cafe.ifs.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ifs.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ifs.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFS - Instituto Federal Sergipe"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFS - Instituto Federal Sergipe"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFS - Instituto Federal Sergipe"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFS - Instituto Federal Sergipe"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDmjCCAoICAQAwDQYJKoZIhvcNAQEFBQAwgZIxDDAKBgNVBAoTA0lGUzEMMAoG\nA1UECxMDRFRJMR8wHQYJKoZIhvcNAQkBFhBjb2ltckBpZnMuZWR1LmJyMQwwCgYD\nVQQHEwNBSlUxJTAjBgNVBAgTHElOU1RJVFVUTyBGRURFUkFMIERFIFNFUkdJUEUx\nCzAJBgNVBAYTAkJSMREwDwYDVQQDEwhybnAtY2FmZTAeFw0xNDExMTgxNzQ2MDNa\nFw0xOTExMTcxNzQ2MDNaMIGSMQwwCgYDVQQKEwNJRlMxDDAKBgNVBAsTA0RUSTEf\nMB0GCSqGSIb3DQEJARYQY29pbXJAaWZzLmVkdS5icjEMMAoGA1UEBxMDQUpVMSUw\nIwYDVQQIExxJTlNUSVRVVE8gRkVERVJBTCBERSBTRVJHSVBFMQswCQYDVQQGEwJC\nUjERMA8GA1UEAxMIcm5wLWNhZmUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQDCM5DpvNNnNY/sEgNPlwTqln/1ErY5NIUFJpd8Z8nhF/Ycg2PHgyaRS5QG\nzg/ytuSPgQwNsqQrBDPVYTM2mPN4bqy3JCMsQ/wurwGY33HQihsq7gsys6sIS3E9\nOeGP2PVEFAAOGBK8/7re/MNkk3zWxVrGHz+jWHUj/XVuz5bEOq/LNmUYgdCKA4EF\n8Fmi22aL522xCT3Fox8ReTq817YxTq+5XLsQEAnOzwIIvOAmRjNZD33lcASWzSJp\n2YMsVKeFpHslgJJUT6a5lbgwH1VOX8VQRYSDGayNfBh63AphlRPbRJRcLG6bQmbx\nD/hfNk2K0FKD9IWxVIJ4O+jxTatlAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAAXZ\nggk3PPdDktXF9fuhLnPpctJpFydTZaJOtZyiTr/YRjRa563VN7ryU7cIN6L/0v9J\nVqW3/LVA5m3vxJn0JFoez65HTVlIgaELJbIw5deHZbYe07e0cQKfEcfuJwzh33YO\n3PyBLMg/gdxoK6cYW0oPM3fZ9p7ypRHyrH/FwJOiFKOKEVdDPI5TlmWJnw85aAEP\n0j+yWPYFmv5t3igK9Iu0WM927mw6gZ0Wk1g53us1aWqoMTjkJZpfI7yBXCsuYYbp\nR2dlYBbt6VnHnQZs+va8RjGt6Q0lRgBsQ5cfwrwDVIdzdB0gOleF/xa0BeKS0GlT\nMC5VxNHzIJWcOb6+ZOc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFS - Instituto Federal Sergipe"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFS - Instituto Federal Sergipe"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.ifs.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.ifs.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFS - Instituto Federal Sergipe"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFS - Instituto Federal Sergipe"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.rnp.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "GTI/RNP"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "servnac@rnp.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.rnp.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC1DCCAbwCAQAwDQYJKoZIhvcNAQEFBQAwMDEMMAoGA1UECxMDR1RJMQswCQYD\nVQQGEwJCUjETMBEGA1UEAxMKaWRwLnJucC5icjAeFw0xMzEyMDYxODQzMzVaFw0x\nNjEyMDUxODQzMzVaMDAxDDAKBgNVBAsTA0dUSTELMAkGA1UEBhMCQlIxEzARBgNV\nBAMTCmlkcC5ybnAuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCp\nwcuNgUWHb0fw6PeIrPUaOtMTIEQ5qeOJPvOYAAzwmcu8pwb6sdvLJC/NtKK8NGkv\nzT4JL/ZHoNNK1bYtYT4temrGaUmJ4QsP7eZjISLljX/NwSQH4D4Gf8iKG+yGpbpM\neSAMGMQjlZYQasJorFijzc92N5nyW/yVNrbviASeRBgQJubEvbOg3pp2wiib3kLG\nLyZCMPCGRGBZoa7+Da55D846zyr2Ck4srIA/oTgRSujQn5of7ocSFchewrYUtMPk\nlUtW9XJgwE5RcfVXSmZiAK20miqiBlvBHqnrh1EGNduwKirg5hCI172kv7pfyUrx\nayzJpuluiwd+HEVm1SDLAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAC73q9t8XD44\nEFN4Zvw/K6ffWlEShuT1Q6cQArv0sn7Z0m10bgjW2EyO3nM/iF/X7RhToyeov3Q4\nr+3en+9JMRnwFuA1ReqQR/2jjInkfvOV1a6YOn2hsqLXpskjCg+wQEyOhyOg/bUN\nl/J1fBDwIDL9ym+4vG7ujnE5vE8vbQqWIjlQV+xXvk/vQBmmmxEG6bHFwxHW5AP3\nkkjlVbW5hU4Mwj9Ac1259yulrX3viPzOkW5+Kf823GNI16LbOLNIjw98gZ6didxX\nIkwnKZWu8klBLzPjr8I4K8C4kr3SktVY1ddGNTfEUBAx54uU1T55fWFR4ZW0WO4E\nktvi8RxRxbw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rnp.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.rnp.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.rnp.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.rnp.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.rnp.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.rnp.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.rnp.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.rnp.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.rnp.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rnp.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.rnp.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.rnp.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "RNP - Rede Nacional de Ensino e Pesquisa"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "RNP - Rede Nacional de Ensino e Pesquisa"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RNP - Rede Nacional de Ensino e Pesquisa"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RNP - Rede Nacional de Ensino e Pesquisa"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC1DCCAbwCAQAwDQYJKoZIhvcNAQEFBQAwMDEMMAoGA1UECxMDR1RJMQswCQYD\nVQQGEwJCUjETMBEGA1UEAxMKaWRwLnJucC5icjAeFw0xMzEyMDYxODQzMzVaFw0x\nNjEyMDUxODQzMzVaMDAxDDAKBgNVBAsTA0dUSTELMAkGA1UEBhMCQlIxEzARBgNV\nBAMTCmlkcC5ybnAuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCp\nwcuNgUWHb0fw6PeIrPUaOtMTIEQ5qeOJPvOYAAzwmcu8pwb6sdvLJC/NtKK8NGkv\nzT4JL/ZHoNNK1bYtYT4temrGaUmJ4QsP7eZjISLljX/NwSQH4D4Gf8iKG+yGpbpM\neSAMGMQjlZYQasJorFijzc92N5nyW/yVNrbviASeRBgQJubEvbOg3pp2wiib3kLG\nLyZCMPCGRGBZoa7+Da55D846zyr2Ck4srIA/oTgRSujQn5of7ocSFchewrYUtMPk\nlUtW9XJgwE5RcfVXSmZiAK20miqiBlvBHqnrh1EGNduwKirg5hCI172kv7pfyUrx\nayzJpuluiwd+HEVm1SDLAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAC73q9t8XD44\nEFN4Zvw/K6ffWlEShuT1Q6cQArv0sn7Z0m10bgjW2EyO3nM/iF/X7RhToyeov3Q4\nr+3en+9JMRnwFuA1ReqQR/2jjInkfvOV1a6YOn2hsqLXpskjCg+wQEyOhyOg/bUN\nl/J1fBDwIDL9ym+4vG7ujnE5vE8vbQqWIjlQV+xXvk/vQBmmmxEG6bHFwxHW5AP3\nkkjlVbW5hU4Mwj9Ac1259yulrX3viPzOkW5+Kf823GNI16LbOLNIjw98gZ6didxX\nIkwnKZWu8klBLzPjr8I4K8C4kr3SktVY1ddGNTfEUBAx54uU1T55fWFR4ZW0WO4E\nktvi8RxRxbw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RNP - Rede Nacional de Ensino e Pesquisa"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RNP - Rede Nacional de Ensino e Pesquisa"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rnp.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rnp.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RNP - Rede Nacional de Ensino e Pesquisa"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RNP - Rede Nacional de Ensino e Pesquisa"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://secure.palgrave-journals.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ollier"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:j.ollier@nature.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ollier"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:j.ollier@nature.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://secure.palgrave-journals.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Palgrave Journals"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.palgrave.com/AboutUs/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Macmillan Publishers Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDbTCCAlWgAwIBAgIEJo7y3DANBgkqhkiG9w0BAQsFADBnMQswCQYDVQQGEwJVSzEPMA0GA1UE\n\t\t\t\t\t\tBxMGTG9uZG9uMRIwEAYDVQQKEwlNYWNtaWxsYW4xDDAKBgNVBAsTA05QRzElMCMGA1UEAxMcc2Vj\n\t\t\t\t\t\tdXJlLnBhbGdyYXZlLWpvdXJuYWxzLmNvbTAeFw0xNTA2MjMwODIwMzBaFw0yNTA2MjAwODIwMzBa\n\t\t\t\t\t\tMGcxCzAJBgNVBAYTAlVLMQ8wDQYDVQQHEwZMb25kb24xEjAQBgNVBAoTCU1hY21pbGxhbjEMMAoG\n\t\t\t\t\t\tA1UECxMDTlBHMSUwIwYDVQQDExxzZWN1cmUucGFsZ3JhdmUtam91cm5hbHMuY29tMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAj10XZbAkMeoa0sv8AuzBCSvR+MFTmoXRDOW6AGNp7mv+\n\t\t\t\t\t\ttLrbPmAEk6vJLB/mIcfW0S7AY0dvtChUajiiJui3Fizi6gYMkpvDlnY3UC54wfOA/T4m8EEEAQ1L\n\t\t\t\t\t\tFevGkTD0zD46gP/1qiKTuUTAiCmqiHag+Yc6jS43kCzo7/CHarqTB49InY7i9cvi+2rGaGTqU7dS\n\t\t\t\t\t\tJrbakYGWlYJlHsUpzGjHnoCQbSx/HpT787P410dIqtu0/L8puQq32cD7rii86+Pzf1vbtOLKUBUm\n\t\t\t\t\t\tq8GrgbodKMqyHzeChhw+W5PpCjZIWU/BViHRLXJRPGrpFVOzl9QJ9ZOrPvqwVObhvx1yUQIDAQAB\n\t\t\t\t\t\toyEwHzAdBgNVHQ4EFgQUUD4QCZOjPq2Z4aIoM9Btn29WUjgwDQYJKoZIhvcNAQELBQADggEBAEZm\n\t\t\t\t\t\tg/W03VrgKZ0lBu7jEjjv2IxKJkUTv4Rduunt8qGDiiAoh7+gGVkXH7ru11yDJa2GR0YdkpfCg9se\n\t\t\t\t\t\tmN/Z3cpYRZS+jhckpDyNK8Y5eYQd+dB/1SXKSjoYEZ1nFvjWo1xL9CIll5RFJZA2ow8UEvvaarQx\n\t\t\t\t\t\t31sZRzLkh2WAFw7ja6leRFL7IRO2rz+gmhmxR4rI3NlaJJxqgutArS4Tk0AkUE3bfDNz2EYTp+FK\n\t\t\t\t\t\tTUBa9dLKwTnygIRH8P9M4EpFybaKGwSsx3KOA6lUQ1NhbdBJ3kXmgt9k1mAPJU6X8LXfASKgwIcv\n\t\t\t\t\t\t7plg8LczSM6koeb2N/Za1Zh+whmyl8Eq7q8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://secure.palgrave-journals.com/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://secure.palgrave-journals.com/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://secure.palgrave-journals.com/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://secure.palgrave-journals.com/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sso.ecu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "stueverj@ecu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeremiah Stuever"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "augustusk@ecu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kris Augustus"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.ecu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.ecu.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.ecu.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIErTCCA5WgAwIBAgIJANboXNbCxTghMA0GCSqGSIb3DQEBBQUAMIGVMQswCQYD\nVQQGEwJVUzELMAkGA1UECBMCTkMxEzARBgNVBAcTCkdyZWVudmlsbGUxITAfBgNV\nBAoTGEVhc3QgQ2Fyb2xpbmEgVW5pdmVyc2l0eTENMAsGA1UECxMESVRDUzEUMBIG\nA1UEAxMLc3NvLmVjdS5lZHUxHDAaBgkqhkiG9w0BCQEWDWVhd2ViQGVjdS5lZHUw\nHhcNMTIwOTI3MTQzOTA1WhcNMjIwOTI3MTQzOTA1WjCBlTELMAkGA1UEBhMCVVMx\nCzAJBgNVBAgTAk5DMRMwEQYDVQQHEwpHcmVlbnZpbGxlMSEwHwYDVQQKExhFYXN0\nIENhcm9saW5hIFVuaXZlcnNpdHkxDTALBgNVBAsTBElUQ1MxFDASBgNVBAMTC3Nz\nby5lY3UuZWR1MRwwGgYJKoZIhvcNAQkBFg1lYXdlYkBlY3UuZWR1MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAv+x70xRWz+zCHVAjgx3XfKXE4JYhAm2/\nexcFuPVu1kOdTvicMAaCrHCQVggHtGXJB7vjI2u/bghgyOQN+LpwjCVzDPQYNKQZ\nN8hoyHyeITHUgw3pLAJNWF6Gnh+P8EX/+6KNL67Z4XJMJvBMH6i8KfSMmBD+5xbs\nh4QpiOJiw72K2HLDjzrCfFxhNeHw4szgh72fp946nrOUR/bUFNc2bMpX1flPxz2K\nPLRsyQ0chvTEvEPUL0g/zIDOHbJCV6/lmvFBifc/+UADAM3chMdWeT+MWHSYux6S\nfOxjwAgTv7cGZ+m7W5vLwIoFMkPX6QeiAhJV4M+fxUUZWS+3J04OZQIDAQABo4H9\nMIH6MB0GA1UdDgQWBBT0UGI7/A3rZ/6dqIqYxGleNUN0xTCBygYDVR0jBIHCMIG/\ngBT0UGI7/A3rZ/6dqIqYxGleNUN0xaGBm6SBmDCBlTELMAkGA1UEBhMCVVMxCzAJ\nBgNVBAgTAk5DMRMwEQYDVQQHEwpHcmVlbnZpbGxlMSEwHwYDVQQKExhFYXN0IENh\ncm9saW5hIFVuaXZlcnNpdHkxDTALBgNVBAsTBElUQ1MxFDASBgNVBAMTC3Nzby5l\nY3UuZWR1MRwwGgYJKoZIhvcNAQkBFg1lYXdlYkBlY3UuZWR1ggkA1uhc1sLFOCEw\nDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAmjFndW2FbbDdxYzfnNSS\nblQeP9DqUyzRnxoo4Gd028i15/Kqn6O4alKUYgZh4/zd9tjHFWDU7g+LkWvFzJ1a\nQSxYQ1/jWgt11QqcmkkppdRd9IjifgzXLu1iNnGRyiX2Re/0azzZQtl0IUGDcdiV\n3FvOU8cB8rL9veYKMrFQhyAHIIDJkaWd/KPl/16xIdN+lOwQGuVlyCzAXphePzyW\nem4BewflobGSobRwz7r5XgIJhxMo3wc01f3akeQJ4O3ZzgIoM+UiBe5DzaUmMQoJ\nX5KQp7NLGaQVmUQOPlUe2xNvmR+lvpkaXZp2S086gS1eWhaiP5h0nASKKd3/rQT1\nkQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ecu.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.ecu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.ecu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sso.ecu.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso.ecu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.ecu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.ecu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ecu.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "East Carolina University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIErTCCA5WgAwIBAgIJANboXNbCxTghMA0GCSqGSIb3DQEBBQUAMIGVMQswCQYD\nVQQGEwJVUzELMAkGA1UECBMCTkMxEzARBgNVBAcTCkdyZWVudmlsbGUxITAfBgNV\nBAoTGEVhc3QgQ2Fyb2xpbmEgVW5pdmVyc2l0eTENMAsGA1UECxMESVRDUzEUMBIG\nA1UEAxMLc3NvLmVjdS5lZHUxHDAaBgkqhkiG9w0BCQEWDWVhd2ViQGVjdS5lZHUw\nHhcNMTIwOTI3MTQzOTA1WhcNMjIwOTI3MTQzOTA1WjCBlTELMAkGA1UEBhMCVVMx\nCzAJBgNVBAgTAk5DMRMwEQYDVQQHEwpHcmVlbnZpbGxlMSEwHwYDVQQKExhFYXN0\nIENhcm9saW5hIFVuaXZlcnNpdHkxDTALBgNVBAsTBElUQ1MxFDASBgNVBAMTC3Nz\nby5lY3UuZWR1MRwwGgYJKoZIhvcNAQkBFg1lYXdlYkBlY3UuZWR1MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAv+x70xRWz+zCHVAjgx3XfKXE4JYhAm2/\nexcFuPVu1kOdTvicMAaCrHCQVggHtGXJB7vjI2u/bghgyOQN+LpwjCVzDPQYNKQZ\nN8hoyHyeITHUgw3pLAJNWF6Gnh+P8EX/+6KNL67Z4XJMJvBMH6i8KfSMmBD+5xbs\nh4QpiOJiw72K2HLDjzrCfFxhNeHw4szgh72fp946nrOUR/bUFNc2bMpX1flPxz2K\nPLRsyQ0chvTEvEPUL0g/zIDOHbJCV6/lmvFBifc/+UADAM3chMdWeT+MWHSYux6S\nfOxjwAgTv7cGZ+m7W5vLwIoFMkPX6QeiAhJV4M+fxUUZWS+3J04OZQIDAQABo4H9\nMIH6MB0GA1UdDgQWBBT0UGI7/A3rZ/6dqIqYxGleNUN0xTCBygYDVR0jBIHCMIG/\ngBT0UGI7/A3rZ/6dqIqYxGleNUN0xaGBm6SBmDCBlTELMAkGA1UEBhMCVVMxCzAJ\nBgNVBAgTAk5DMRMwEQYDVQQHEwpHcmVlbnZpbGxlMSEwHwYDVQQKExhFYXN0IENh\ncm9saW5hIFVuaXZlcnNpdHkxDTALBgNVBAsTBElUQ1MxFDASBgNVBAMTC3Nzby5l\nY3UuZWR1MRwwGgYJKoZIhvcNAQkBFg1lYXdlYkBlY3UuZWR1ggkA1uhc1sLFOCEw\nDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAmjFndW2FbbDdxYzfnNSS\nblQeP9DqUyzRnxoo4Gd028i15/Kqn6O4alKUYgZh4/zd9tjHFWDU7g+LkWvFzJ1a\nQSxYQ1/jWgt11QqcmkkppdRd9IjifgzXLu1iNnGRyiX2Re/0azzZQtl0IUGDcdiV\n3FvOU8cB8rL9veYKMrFQhyAHIIDJkaWd/KPl/16xIdN+lOwQGuVlyCzAXphePzyW\nem4BewflobGSobRwz7r5XgIJhxMo3wc01f3akeQJ4O3ZzgIoM+UiBe5DzaUmMQoJ\nX5KQp7NLGaQVmUQOPlUe2xNvmR+lvpkaXZp2S086gS1eWhaiP5h0nASKKd3/rQT1\nkQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "East Carolina University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ecu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "East Carolina University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.exe-coll.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itserivces@exe-coll.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Services"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Burrows"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:NigelBurrows@exe-coll.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nigel"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idpadmin@exe-coll.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IdP Admin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.exe-coll.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-10-22T10:10:10Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.exe-coll.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.exe-coll.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.exe-coll.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.exe-coll.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.exe-coll.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.exe-coll.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "exe-coll.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://www.exe-coll.ac.uk/Images/ukfederation/eclogo.png",
                    "height": "80",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Exeter College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAOBgSoILoqxp6Sd97P44EOTJO6BmMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMB0xGzAZBgNVBAMMEmlkcC5leGUtY29sbC5hYy51azAeFw0xNTEwMDUxNDQ4\n\t\t\t\t\t\tNTBaFw0zNTEwMDUxNDQ4NTBaMB0xGzAZBgNVBAMMEmlkcC5leGUtY29sbC5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJDt47Xw9yoz4+kmm7d8\n\t\t\t\t\t\taUBogCQUuoYHtKfSHtQXSwWzAGA44zNhRXrCtkaWQRcWziwpbEISl7N1DA/Et7K8\n\t\t\t\t\t\tGWxkPHLb9AY1hmuqJhI7VTcnRW9K1c35dkcU8y8iq/KtEs/Scqykk7mRdYP0220z\n\t\t\t\t\t\tMkGsKyGX4lnca+3qjTZEjIQmmrQkG6MT2TSwYIP4okPVsf0psa4gFm9zIcQ833xq\n\t\t\t\t\t\taM/JeGhWy8wC1XAR0QdON4KOmlRbOz8Gt24SZ5uFCYP/0M0bsi5bT9VFbIzDHeOU\n\t\t\t\t\t\t2Ksp3LCGW+auudlvpYNCw/f/z6zJzyjbEaaZWEC5EUNp5I17BNut+AHfQEUGg2KW\n\t\t\t\t\t\tQmcCAwEAAaNrMGkwHQYDVR0OBBYEFECBehw5Kkbqihxtl4i9xVqD+/FnMEgGA1Ud\n\t\t\t\t\t\tEQRBMD+CEmlkcC5leGUtY29sbC5hYy51a4YpaHR0cHM6Ly9pZHAuZXhlLWNvbGwu\n\t\t\t\t\t\tYWMudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAGCt0iihFupc\n\t\t\t\t\t\t7R0GLGlBisiOFz+9+DH3m1c7AXUOBSj7JeDlhD/HeN0abj4oRu3vNuDSSVbQ8r2A\n\t\t\t\t\t\t0eJAMlT+2KGjvDOpgZZM6ch2b4DwlDmaK52GAMBP34muY42GaoCA9EJ9BAM+sLQb\n\t\t\t\t\t\tOQXdOxtfEXP/Fw9khCTGXsLMm+069lR+1c0PFhKEY9ZMIYEL9H+VvXpyRRA70QP9\n\t\t\t\t\t\tglZa39ROiCKWcxTaat0q4uGrfd7rFDOZu33wfDSjQcznJdLYrsppbKWGK7gE5C8+\n\t\t\t\t\t\tEEwb4NmJVaB29/9uUdGVA7AWh5HnuGgc5mGXx7TGwFx8/xE7qk8XjwyT24BbFJ0A\n\t\t\t\t\t\tLdsw0D2RloY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUBbXkHi70ulJrjIlvWCIzdMBJiHEwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwHTEbMBkGA1UEAwwSaWRwLmV4ZS1jb2xsLmFjLnVrMB4XDTE1MTAwNTE0NDg0\n\t\t\t\t\t\tOFoXDTM1MTAwNTE0NDg0OFowHTEbMBkGA1UEAwwSaWRwLmV4ZS1jb2xsLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvwPQqi7IeM//8uxLAoaJ\n\t\t\t\t\t\tp6buQefMlgcZp26Ab0lKfllI9qXnbw7mcZVJM6GVAgiSss3qmjnbCrSNvIe/lsK6\n\t\t\t\t\t\t2Bhl7JIC50VPbR3DXYJiCZpiWAptaIJ3lFSQMBA/6aIAtqO4Uoq0mAl//qWdFnKY\n\t\t\t\t\t\tcMw3BRhI1YKTEQa78jetAklmnKEQ+8RruirfcV4l10Sn/HN54WFAzhuH/W6numGo\n\t\t\t\t\t\tNOUcp7rRhiVtBPt6mhZQQZkGCG+EkOMh8P72OBDZ5Ky9zrloPQvbv+MN26dsuOWt\n\t\t\t\t\t\tNa4R32Y+LA0zrVa2qXLsE63cJs1OS2GgZfbzhtcbsKyaRNazH39mjyw8XthMj1nN\n\t\t\t\t\t\thwIDAQABo2swaTAdBgNVHQ4EFgQUdcbpv8lSyws0CaM6oeNcbjyumiIwSAYDVR0R\n\t\t\t\t\t\tBEEwP4ISaWRwLmV4ZS1jb2xsLmFjLnVrhilodHRwczovL2lkcC5leGUtY29sbC5h\n\t\t\t\t\t\tYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAlALDqVXXotPR\n\t\t\t\t\t\tSIewI6t+QxCe+7U/V3gI/pREVIUhKgyURFkarxSbAoqLma6ttM8FjQijbRPUKMGl\n\t\t\t\t\t\ta0ug36cGohcVYKtGKySnuQDZc6MpmtjpQBYR3O1RPLXRPQpFB46qXTd8jJE3eVXI\n\t\t\t\t\t\tWIhoDPHwXECNph7Zc+37/qAplKADt+gCqOZOvb/dFywG61lkv2RLfqWu0jZAwBeB\n\t\t\t\t\t\txd2NnxQAzOGQXarWIOBDdC+Rm57Yo4QcDIDaWIFai02h30SDVNbD2IOKTTFlB9BU\n\t\t\t\t\t\tVbqI3mpvBerOgVstriPdd4rGSb6qfF+cZYiwroaQ6zEri+sVrV8qZ/w4+Xt4ncu0\n\t\t\t\t\t\tjr+x5aa4EQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAKrBnUGd75sXdnSjpLBrMHUL9Z7hMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMB0xGzAZBgNVBAMMEmlkcC5leGUtY29sbC5hYy51azAeFw0xNTEwMDUxNDQ4\n\t\t\t\t\t\tNDlaFw0zNTEwMDUxNDQ4NDlaMB0xGzAZBgNVBAMMEmlkcC5leGUtY29sbC5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKf2PWKyWWY1Xv/CvpBI\n\t\t\t\t\t\ta4ajaR9YX4wdOV9Ba+zdB3kHQyXLSMNb4OV7xaRaih6XzRjUm8tBUki+MU8k5Ncr\n\t\t\t\t\t\tR8w8EzLnxLiqsuIn+5WdXng1CaGNnw0YYzyfxU/3zuLy7/QnoRUj8TKC6zzdAanl\n\t\t\t\t\t\t05idK4kB6ZS9LNnfEq9GYRYJBBaFI0XAKMHqXGKRBmlTThd00qb+gpcSkXRDmafA\n\t\t\t\t\t\tJBBRmIc62ilViQkTB6Nu6dUmQTDTWRip3X6rJynKXX1vHCZP00aXOBiZgbD+Nu+F\n\t\t\t\t\t\tmMXEqMvA+Nm+VzX0CrffvfTLbZWoGXjea1jKYT7S+L/bt0wEcFnPTiX4ITNos18/\n\t\t\t\t\t\tmLUCAwEAAaNrMGkwHQYDVR0OBBYEFNBFc8Ql0nmSGxBro64kDuZHn+KRMEgGA1Ud\n\t\t\t\t\t\tEQRBMD+CEmlkcC5leGUtY29sbC5hYy51a4YpaHR0cHM6Ly9pZHAuZXhlLWNvbGwu\n\t\t\t\t\t\tYWMudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAA/sn2WL7uDS\n\t\t\t\t\t\tZ1txLqmXLjqCD2K8U3VPgJqsQ7da+w/MQDiYQUKs4iUe/HJNN9mkGrg4BWq/YB0v\n\t\t\t\t\t\tRP922H76+ne+JFFV/k+EZxpVcjiB+kLeIiBS341Wucdh3gJW8Sultx76Eu/POH+f\n\t\t\t\t\t\tohmndUNvofFwbMSPholtz6YhrlgXoWWzp7EVqraOZJJs2PFylngOytoqz8MKsoqg\n\t\t\t\t\t\tZi1Eyw3fIflsineDleFHE0ALKqbf2vA7r931j/GntEQ5gZfr4ytdxu6isiGM3adg\n\t\t\t\t\t\tZySpPoJYHPmJimQ7K8FRBhRuiXinhoQm9Pi/5VbPO4fZmX2rYFTUHE+6zDB2gJjN\n\t\t\t\t\t\t/F0mlEEmxK8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Exeter College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.exe-coll.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Exeter College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.aus.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp_support@aus.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IdP Support Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp_support@aus.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IdP Support Team"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp_support@aus.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IdP Support Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp_support@aus.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IdP Support Team"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://idp.aus.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.aus.edu:9443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.aus.edu:9443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJjCCAg4CCQC0u6dmZ9/CYDANBgkqhkiG9w0BAQUFADBVMQswCQYDVQQGEwJB\nRTEQMA4GA1UECAwHU2hhcmphaDEQMA4GA1UEBwwHU2hhcmphaDEMMAoGA1UECgwD\nQVVTMRQwEgYDVQQDDAtpZHAuYXVzLmVkdTAeFw0xNTAyMDkxNTEwMTJaFw0yNTAy\nMDgxNTEwMTJaMFUxCzAJBgNVBAYTAkFFMRAwDgYDVQQIDAdTaGFyamFoMRAwDgYD\nVQQHDAdTaGFyamFoMQwwCgYDVQQKDANBVVMxFDASBgNVBAMMC2lkcC5hdXMuZWR1\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArnIAxDkCLqj1r6dLNow+\nMZO+fyMglmyJTiZU1Jnq/qv8RGfODs+MXQ719T8PgrPpTLjO2H2hR62oaAxygEC8\nYKsgLZoWehvkvSBQcF7vCvDYtimusiR0HVD+1ZkL9ivFoDcH1uNZ998bW0B+yynf\nWR8+Y2ALhmKd0EvHvMtYLdnKSk7Bs73loAtT1/g+GWEKINjDigW31usFOw9Ty2xZ\n/LXTY3DEpQLDRVod9b7pBCdRNwYW1ELZXEE8hofFIArhxDCGqCTUjUiJYyvol4Qc\nmZ27PoYC/lhb6EWLXGZ4Y9NWwzpOSlJycY5G5jdsDHSF0oNfmhXvSF/A5liMwKnk\nxQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQAkzksTVrYM0fh2OjSXdP8n/BKmK4xt\nskvPq0cBCBraY9ckQiBf5frJLMbOr5WuEolJBwJVOljlN2PcYgxtQJ+VtqsvLCaU\nHVYH+YfHi0eUNJHB4/l2mEOCuDB3yo9wmevmwyayO5MxvurZsH+xZmPpiyv3AKTz\nfM7tDfyk1i3MtP1v7RecCSDboJGCYUgxtOApAOvBttTYh8Aswc9X6+JHDTXiUS+6\nbdFUpKzYfJN5qvPbN7aO4b6WYutrATd2XleDvTwdMF9/GuxATxAZuWAgSPDmIGMC\ndyrwmVwoKB3/P28kLxOLL8gvjSnWnKo3GJPob/c5rP13XMj7wRDdMpAJ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aus.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.aus.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.aus.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.aus.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.aus.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.aus.edu:9443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.aus.edu:9443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aus.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.aus.edu"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for the American University of Sharjah"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.aus.edu/site/styles/css_img/logo-final.gif",
                    "lang": "en",
                    "height": "71",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "394"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "American University of Sharjah"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJjCCAg4CCQC0u6dmZ9/CYDANBgkqhkiG9w0BAQUFADBVMQswCQYDVQQGEwJB\nRTEQMA4GA1UECAwHU2hhcmphaDEQMA4GA1UEBwwHU2hhcmphaDEMMAoGA1UECgwD\nQVVTMRQwEgYDVQQDDAtpZHAuYXVzLmVkdTAeFw0xNTAyMDkxNTEwMTJaFw0yNTAy\nMDgxNTEwMTJaMFUxCzAJBgNVBAYTAkFFMRAwDgYDVQQIDAdTaGFyamFoMRAwDgYD\nVQQHDAdTaGFyamFoMQwwCgYDVQQKDANBVVMxFDASBgNVBAMMC2lkcC5hdXMuZWR1\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArnIAxDkCLqj1r6dLNow+\nMZO+fyMglmyJTiZU1Jnq/qv8RGfODs+MXQ719T8PgrPpTLjO2H2hR62oaAxygEC8\nYKsgLZoWehvkvSBQcF7vCvDYtimusiR0HVD+1ZkL9ivFoDcH1uNZ998bW0B+yynf\nWR8+Y2ALhmKd0EvHvMtYLdnKSk7Bs73loAtT1/g+GWEKINjDigW31usFOw9Ty2xZ\n/LXTY3DEpQLDRVod9b7pBCdRNwYW1ELZXEE8hofFIArhxDCGqCTUjUiJYyvol4Qc\nmZ27PoYC/lhb6EWLXGZ4Y9NWwzpOSlJycY5G5jdsDHSF0oNfmhXvSF/A5liMwKnk\nxQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQAkzksTVrYM0fh2OjSXdP8n/BKmK4xt\nskvPq0cBCBraY9ckQiBf5frJLMbOr5WuEolJBwJVOljlN2PcYgxtQJ+VtqsvLCaU\nHVYH+YfHi0eUNJHB4/l2mEOCuDB3yo9wmevmwyayO5MxvurZsH+xZmPpiyv3AKTz\nfM7tDfyk1i3MtP1v7RecCSDboJGCYUgxtOApAOvBttTYh8Aswc9X6+JHDTXiUS+6\nbdFUpKzYfJN5qvPbN7aO4b6WYutrATd2XleDvTwdMF9/GuxATxAZuWAgSPDmIGMC\ndyrwmVwoKB3/P28kLxOLL8gvjSnWnKo3GJPob/c5rP13XMj7wRDdMpAJ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "American University of Sharjah"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aus.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "American University of Sharjah"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dluat-pub2web.theiet.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ietdl@theiet.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ghadiyali"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:openathens@publishingtechnology.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hatim"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dluat-pub2web.theiet.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-03-18T12:51:28Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IET DIGITAL LIBRARY"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://dluat-pub2web.theiet.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Publishing Technology plc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDnDCCAoSgAwIBAgIEUO2c9zANBgkqhkiG9w0BAQUFADCBjzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFDASBgNVBAgTC094Zm9yZHNoaXJlMQ8wDQYDVQQHEwZPeGZvcmQxHjAcBgNV\n\t\t\t\t\t\tBAoTFVB1Ymxpc2hpbmcgVGVjaG5vbG9neTEZMBcGA1UECxMQU2Nob2xhcmx5IE9u\n\t\t\t\t\t\tbGluZTEeMBwGA1UEAxMVUHVibGlzaGluZyBUZWNobm9sb2d5MB4XDTEzMDEwOTE2\n\t\t\t\t\t\tMzgxNVoXDTIzMDEwNzE2MzgxNVowgY8xCzAJBgNVBAYTAkdCMRQwEgYDVQQIEwtP\n\t\t\t\t\t\teGZvcmRzaGlyZTEPMA0GA1UEBxMGT3hmb3JkMR4wHAYDVQQKExVQdWJsaXNoaW5n\n\t\t\t\t\t\tIFRlY2hub2xvZ3kxGTAXBgNVBAsTEFNjaG9sYXJseSBPbmxpbmUxHjAcBgNVBAMT\n\t\t\t\t\t\tFVB1Ymxpc2hpbmcgVGVjaG5vbG9neTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\n\t\t\t\t\t\tAQoCggEBAL3ivjdsXAoP6HVxKmZg3aDgjOaw0vc3VHcTQbdCxuzd/1ydLHKkcy8f\n\t\t\t\t\t\tEdBBRK8AlY1sbEue7yvnwVUiZP/THzHKj8jtJB/D2YECLB12zR7UV/v25CiIFjVW\n\t\t\t\t\t\tvdHtnZ4pZDepKtHmRCPJWyfEsrX2l0qnoOtpKYVi+dP/Ie6gYOkVlaCUfdZx5mEY\n\t\t\t\t\t\tlk3HJ8TVeS0VmEXlJXj8zXLFoVpmbjn9jru/qjj/HB+VZpVSbpVzI4BNlbWEoN/0\n\t\t\t\t\t\tVOl7/d1C7+IWM59UZeIJpXSyO+Gh+3ydv4dJtpZing1hgCBss+5L8luA5wQQDSse\n\t\t\t\t\t\tWN/zhK2Jn3DyhBx3H04IEkQkDYGQ5ZMCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tF7amvU4Vs5KyKnubimDf/s7qAPlSN4Tz66tBN/WpWCLNuOQxtkTbC6pEXYkWfaQp\n\t\t\t\t\t\tR1CiCFhzCW6h+Di7EQenU+ooO5DCXFYfwg/t8ygLeNhvTUor/ecGXTkeBT5zqYiM\n\t\t\t\t\t\tPY/6QYCzwOh2IvItT+nTa9Rk8VL78VKg5cNjzCmibHWjoG6oFPxI77hkPRgc1u3w\n\t\t\t\t\t\tlNEk/UBVoLnyYrnvgaibNFwXv6gXqRylWZykRsixdxAF029Lmj12LepRSie/cB4e\n\t\t\t\t\t\tEj/KMG3WOjuyeqeV1iBDU8NPzYL3buJDSrPR8DZaQt56CvXRZ0y8Nb7w+hsOIrwk\n\t\t\t\t\t\tawOxBJ/9dlBVZxdn0CMTXQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDnDCCAoSgAwIBAgIEUO2c9zANBgkqhkiG9w0BAQUFADCBjzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFDASBgNVBAgTC094Zm9yZHNoaXJlMQ8wDQYDVQQHEwZPeGZvcmQxHjAcBgNV\n\t\t\t\t\t\tBAoTFVB1Ymxpc2hpbmcgVGVjaG5vbG9neTEZMBcGA1UECxMQU2Nob2xhcmx5IE9u\n\t\t\t\t\t\tbGluZTEeMBwGA1UEAxMVUHVibGlzaGluZyBUZWNobm9sb2d5MB4XDTEzMDEwOTE2\n\t\t\t\t\t\tMzgxNVoXDTIzMDEwNzE2MzgxNVowgY8xCzAJBgNVBAYTAkdCMRQwEgYDVQQIEwtP\n\t\t\t\t\t\teGZvcmRzaGlyZTEPMA0GA1UEBxMGT3hmb3JkMR4wHAYDVQQKExVQdWJsaXNoaW5n\n\t\t\t\t\t\tIFRlY2hub2xvZ3kxGTAXBgNVBAsTEFNjaG9sYXJseSBPbmxpbmUxHjAcBgNVBAMT\n\t\t\t\t\t\tFVB1Ymxpc2hpbmcgVGVjaG5vbG9neTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\n\t\t\t\t\t\tAQoCggEBAL3ivjdsXAoP6HVxKmZg3aDgjOaw0vc3VHcTQbdCxuzd/1ydLHKkcy8f\n\t\t\t\t\t\tEdBBRK8AlY1sbEue7yvnwVUiZP/THzHKj8jtJB/D2YECLB12zR7UV/v25CiIFjVW\n\t\t\t\t\t\tvdHtnZ4pZDepKtHmRCPJWyfEsrX2l0qnoOtpKYVi+dP/Ie6gYOkVlaCUfdZx5mEY\n\t\t\t\t\t\tlk3HJ8TVeS0VmEXlJXj8zXLFoVpmbjn9jru/qjj/HB+VZpVSbpVzI4BNlbWEoN/0\n\t\t\t\t\t\tVOl7/d1C7+IWM59UZeIJpXSyO+Gh+3ydv4dJtpZing1hgCBss+5L8luA5wQQDSse\n\t\t\t\t\t\tWN/zhK2Jn3DyhBx3H04IEkQkDYGQ5ZMCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tF7amvU4Vs5KyKnubimDf/s7qAPlSN4Tz66tBN/WpWCLNuOQxtkTbC6pEXYkWfaQp\n\t\t\t\t\t\tR1CiCFhzCW6h+Di7EQenU+ooO5DCXFYfwg/t8ygLeNhvTUor/ecGXTkeBT5zqYiM\n\t\t\t\t\t\tPY/6QYCzwOh2IvItT+nTa9Rk8VL78VKg5cNjzCmibHWjoG6oFPxI77hkPRgc1u3w\n\t\t\t\t\t\tlNEk/UBVoLnyYrnvgaibNFwXv6gXqRylWZykRsixdxAF029Lmj12LepRSie/cB4e\n\t\t\t\t\t\tEj/KMG3WOjuyeqeV1iBDU8NPzYL3buJDSrPR8DZaQt56CvXRZ0y8Nb7w+hsOIrwk\n\t\t\t\t\t\tawOxBJ/9dlBVZxdn0CMTXQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://dluat-pub2web.theiet.org/session/shib",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dluat-pub2web.theiet.org/session/shib",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ucs.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ithelpdesk@ucs.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Liebow"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:w.liebow@ucs.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Will"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ucs.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-05-12T14:33:22Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUHNOHSlpAfJGT9rl3zRDmwa3SDhMwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGDEWMBQGA1UEAxMNaWRwLnVjcy5hYy51azAeFw0xNDA0MTYxNDI4MDNaFw0z\n\t\t\t\t\t\tNDA0MTYxNDI4MDNaMBgxFjAUBgNVBAMTDWlkcC51Y3MuYWMudWswggEiMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCCxdBx+Yitont8++RjBk3LRjqNAvHMPUdy\n\t\t\t\t\t\tJ6hSQFmQ5EPN3YQDzJ/2m9tGH+TO8uKCiiOd0zMzA4zzkOtGTyNNqjk0+ENR4PJa\n\t\t\t\t\t\t0XOOk7PXJTuXbo5frqZ7a3wi1oVtm+SuOi7cg35ya0+w70xQ6iVE449cdGi6zi7p\n\t\t\t\t\t\tO5/BXVQGDPusH13EswEC2JeTX7dGDCvM9wYbJvIbVvrCX4R4YB+fJg5h7/JyveXc\n\t\t\t\t\t\tVtZbmGaQ0Xuu6fAXn0G2Y9/72NGpvOcM3LUPyHy1iBUzaClV9TRoBCJIvdojPQ8k\n\t\t\t\t\t\t4O+/dz3Qq2NkpSSOUsTOldzeZuRXhzrJVCmDJH0RxawJ1czDLtgxAgMBAAGjYTBf\n\t\t\t\t\t\tMD4GA1UdEQQ3MDWCDWlkcC51Y3MuYWMudWuGJGh0dHBzOi8vaWRwLnVjcy5hYy51\n\t\t\t\t\t\tay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUOU13V/q7ER53eftMiDzdpx/ur6Mw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAGrR1rz3rBUkNLDk0a7KMP+AKRP+ei+YOy1DkTt1\n\t\t\t\t\t\tnF0/QrIVulgk5/82uw5rtp07xPJLveTM71/cjC/NXhV0lDPtGe+7jDwBjsaSKf8d\n\t\t\t\t\t\tk8sRow8dIcViLwcyvS8yaC5PLdc6aTALKNYrhzKuLq9zbKXpxB6ZW3x/S16/cH+U\n\t\t\t\t\t\tjGFtEu7tGSF9K8Y8pNu7cCuDylk3iz8v7spPeAembJyNAX8x6Stwseq4L5HJuHsm\n\t\t\t\t\t\txZgo69TfUXl/v3znLYArSkQl1hRgMalzCx0xXy3BCpTQB8/TvYFy+HHCk3sLSLzE\n\t\t\t\t\t\toazcpzNwlhXSgUNXMBFi+ghU9o77fKnWXJN8L3mv8lbbf6g="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucs.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ucs.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ucs.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ucs.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ucs.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ucs.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ucs.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ucs.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ucs.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucs.ac.uk"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University Campus Suffolk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUHNOHSlpAfJGT9rl3zRDmwa3SDhMwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGDEWMBQGA1UEAxMNaWRwLnVjcy5hYy51azAeFw0xNDA0MTYxNDI4MDNaFw0z\n\t\t\t\t\t\tNDA0MTYxNDI4MDNaMBgxFjAUBgNVBAMTDWlkcC51Y3MuYWMudWswggEiMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCCxdBx+Yitont8++RjBk3LRjqNAvHMPUdy\n\t\t\t\t\t\tJ6hSQFmQ5EPN3YQDzJ/2m9tGH+TO8uKCiiOd0zMzA4zzkOtGTyNNqjk0+ENR4PJa\n\t\t\t\t\t\t0XOOk7PXJTuXbo5frqZ7a3wi1oVtm+SuOi7cg35ya0+w70xQ6iVE449cdGi6zi7p\n\t\t\t\t\t\tO5/BXVQGDPusH13EswEC2JeTX7dGDCvM9wYbJvIbVvrCX4R4YB+fJg5h7/JyveXc\n\t\t\t\t\t\tVtZbmGaQ0Xuu6fAXn0G2Y9/72NGpvOcM3LUPyHy1iBUzaClV9TRoBCJIvdojPQ8k\n\t\t\t\t\t\t4O+/dz3Qq2NkpSSOUsTOldzeZuRXhzrJVCmDJH0RxawJ1czDLtgxAgMBAAGjYTBf\n\t\t\t\t\t\tMD4GA1UdEQQ3MDWCDWlkcC51Y3MuYWMudWuGJGh0dHBzOi8vaWRwLnVjcy5hYy51\n\t\t\t\t\t\tay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUOU13V/q7ER53eftMiDzdpx/ur6Mw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAGrR1rz3rBUkNLDk0a7KMP+AKRP+ei+YOy1DkTt1\n\t\t\t\t\t\tnF0/QrIVulgk5/82uw5rtp07xPJLveTM71/cjC/NXhV0lDPtGe+7jDwBjsaSKf8d\n\t\t\t\t\t\tk8sRow8dIcViLwcyvS8yaC5PLdc6aTALKNYrhzKuLq9zbKXpxB6ZW3x/S16/cH+U\n\t\t\t\t\t\tjGFtEu7tGSF9K8Y8pNu7cCuDylk3iz8v7spPeAembJyNAX8x6Stwseq4L5HJuHsm\n\t\t\t\t\t\txZgo69TfUXl/v3znLYArSkQl1hRgMalzCx0xXy3BCpTQB8/TvYFy+HHCk3sLSLzE\n\t\t\t\t\t\toazcpzNwlhXSgUNXMBFi+ghU9o77fKnWXJN8L3mv8lbbf6g="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University Campus Suffolk"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ucs.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University Campus Suffolk"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.bsdc.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@bsdc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Coats"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alan.coats@bsdc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@bsdc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.bsdc.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-07-13T09:42:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.bsdc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.bsdc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.bsdc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.bsdc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.bsdc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.bsdc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bsdc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUN8y30toYLjtWupKH7DVDzwSSKuswDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwGjEYMBYGA1UEAwwPc2hpYi5ic2RjLmFjLnVrMB4XDTE1MDcyMjExMDkwMVoX\n\t\t\t\t\t\tDTM1MDcyMjExMDkwMVowGjEYMBYGA1UEAwwPc2hpYi5ic2RjLmFjLnVrMIIBIjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA7cEKQ9U09f5UJt9PYlw4z+Cw/fuy\n\t\t\t\t\t\t1N+4xPkfibEj/EWCUMJ/dyqtkhmmsId8GdUzPJOXgE37oMJP4BYjKGJHcGz9Q2DP\n\t\t\t\t\t\tEgSDPBVBexlQKyuIjVllaB0yCGPDekKL5PWXFbp6OVEPN+YNVEyJE6wQcqFK92Ml\n\t\t\t\t\t\tQnywsKIEC6vsAeZzBRxYnUIioL6gMKgYynuKBfPo+uylPsakFQoKF5aiqH/fdIHL\n\t\t\t\t\t\tMO17BiDQGfWyslSgDbL1YQqONvw/NtVjpLjWjnYw3SdmyvOM8CnDZFWwDOi3MWAR\n\t\t\t\t\t\tdSrtdPVICwRIFUk0/t30pCoebJmXMEtiG3QmeC6dBRchcr/4mkX4QQaUpQIDAQAB\n\t\t\t\t\t\to2UwYzAdBgNVHQ4EFgQUVLuuZKNnpMw5MMO4MsJzkeDW9SQwQgYDVR0RBDswOYIP\n\t\t\t\t\t\tc2hpYi5ic2RjLmFjLnVrhiZodHRwczovL3NoaWIuYnNkYy5hYy51ay9pZHAvc2hp\n\t\t\t\t\t\tYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAV5Z154bfv7fMTvjs+mIXf62g/znr\n\t\t\t\t\t\tJpCulJmY0ckkYsm6qpAp7jRaW3g8ZIqtwcrPWbflLdlJduFeXt3iHQzNKelCuTVQ\n\t\t\t\t\t\tzaT1uku34qLw5n8dlLSJCAYTJ3k8DP9paZAHWQutdRtfp8T52KCNEvQfaQRbMc1s\n\t\t\t\t\t\t7xBcuyaHZp371OfoieJEpzgYkR0ZgCI5GNBBjmXMEvZT5YcClmv/X80/oLIokKWT\n\t\t\t\t\t\tahWWCR4DULcp+U1czGshTbCTSosxDbJSxeiqVhaBKnmzPBtc4jXuejjCfZ/cW63A\n\t\t\t\t\t\t87436RAvjG0udEJ+1t5U5y+N8oPQC61crI39fcviBBGvdg82Y4mmCY+yxw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUTbwjzHy1V/QauduA1UWBe4i3xUwwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwGjEYMBYGA1UEAwwPc2hpYi5ic2RjLmFjLnVrMB4XDTE1MDcyMjExMDkwMFoX\n\t\t\t\t\t\tDTM1MDcyMjExMDkwMFowGjEYMBYGA1UEAwwPc2hpYi5ic2RjLmFjLnVrMIIBIjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoIEvn9RF5E6Oae2UsQZx/wyV4taa\n\t\t\t\t\t\t1LyvNNew/XYBVzULQqETqNxCMDyKVhj74s6b6Kl0rim9y4ACSOTU/rGtYbg+WnFP\n\t\t\t\t\t\tb6iRQnm0+hH/PJxlulPmp+ExqO+LUblY8+5/iohek7ybhpv5ysebuZbWlEJRutKK\n\t\t\t\t\t\tAX5N4wLKNKjwXI9B2iZ9IBNfqPrsNLFs7cr3/C2le318BbKK2x37eGSqx/1VgHt6\n\t\t\t\t\t\tJqCzZty6Y2EXRiVqktNOnPQKTrU6ycxmAhydZKVVpcOQ7MxlzbawV6Lq8xg3a1yP\n\t\t\t\t\t\tDS533vVEAWhatvqvwk6GPhfZpF62r4uFe121gV+fMWPU2U3Kmz5730ZDgQIDAQAB\n\t\t\t\t\t\to2UwYzAdBgNVHQ4EFgQUvBymfqNxuuhIloDW66n/XjoR8ZIwQgYDVR0RBDswOYIP\n\t\t\t\t\t\tc2hpYi5ic2RjLmFjLnVrhiZodHRwczovL3NoaWIuYnNkYy5hYy51ay9pZHAvc2hp\n\t\t\t\t\t\tYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAlGqFXhgYDq2lmraBfGT7hXai/+kX\n\t\t\t\t\t\tUUnYoAx6rn0g4HXuRGLN5sdQdyjUDenHZBdUkB7iiUTKjYDIaDfFCqf7BhyTZVVp\n\t\t\t\t\t\tAufFQSZkGobPNF7ryr13Nz1fxYChjg85MSfdLrHy5KzDZHGkbdK6OqJK1GQQmjg7\n\t\t\t\t\t\tEtkz0PrgplwJvWoY1fwQOT2vZLYN1ZPFbxM40Q9p6cJ3TQze8FCaSeCu1gIcHlZD\n\t\t\t\t\t\t/v833iBKd3o2FdR4hoajUlNy5qida3w+5tgQjCkIg5Uv34TZekf9KpbJeo9aC7rs\n\t\t\t\t\t\tJs7zvcVri+nme42f+NejEW+w6qOYYYZVUT09NhIEKgqUrBJuF7KVi1ELlw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAI7EL52ouKYn3I0Z+dRy2QFDx5jFMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMBoxGDAWBgNVBAMMD3NoaWIuYnNkYy5hYy51azAeFw0xNTA3MjIxMTA5MDFa\n\t\t\t\t\t\tFw0zNTA3MjIxMTA5MDFaMBoxGDAWBgNVBAMMD3NoaWIuYnNkYy5hYy51azCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJLucDSwLRP0IcDwnEEKCZm0SKtY\n\t\t\t\t\t\taOtwm6vsDDh00gJb9kYVEAY3jB0tQ1TJelP1Um+IhNVpqR6vj0wNy6TQmzC7CThZ\n\t\t\t\t\t\tT4Ivzj5/EpVXG1J8Cee5ZHXIgy8wd9JlSsJdKEXajnvLw0y979rSfFrypH6bt9D+\n\t\t\t\t\t\tM1gZcqJJ49W/nmVFO6KSMKg1aMLFXEW9gs0/FJ7KKHZc0zApbMjf7JPKcJLqcWkx\n\t\t\t\t\t\ttsS1knn3IXVgCqKa8C3abRXDFm5HCjXl5W3GRUsjMtfhj0SbR2zXObW4TfCGzwjP\n\t\t\t\t\t\tPsCB+tcJfC6ATPo6KW365qihXUdXLkwD6kDik0P7ROpIIQk/p2yPJW2gx4ECAwEA\n\t\t\t\t\t\tAaNlMGMwHQYDVR0OBBYEFKDiJVWfMtW+Wm3pSXbjxc0cpZBtMEIGA1UdEQQ7MDmC\n\t\t\t\t\t\tD3NoaWIuYnNkYy5hYy51a4YmaHR0cHM6Ly9zaGliLmJzZGMuYWMudWsvaWRwL3No\n\t\t\t\t\t\taWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAEdI61HWJApulHacwluKOoreXtFZ\n\t\t\t\t\t\tr3q7sqANksGdQGMpMqsI++fR8CHFcYj1LaiHM+R/paLIbZNVRBle5RdEaVGd7kqM\n\t\t\t\t\t\tY1LudYKFAF+Og9KEoPhLw4Z+uaQywMa5kcX3SA1hxVppAF4/Xgy5HX8BEifUAXcr\n\t\t\t\t\t\t4pm7fJp/FFyAvhlqHxZBI/etUPJ34rhbg6zxP/RPgrvxh+WnQo7sFaiy14gd2U43\n\t\t\t\t\t\tOybgnnk8z9+xVZrJPihLdrcLVLfqW88KZOWKk6f7UuRMLiuA/PI2Fm15KOjxldT8\n\t\t\t\t\t\tdMcsID2b60k2kzoN1u1QOsCwZv0CkOcRz+sjVix5YBsiAdkDOn3vXkSk4KE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Burton and South Derbyshire College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.bsdc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Burton and South Derbyshire College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://si.crous-rouen.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "service-informatique@crous-rouen.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://si.crous-rouen.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-03-07T17:54:36Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://si.crous-rouen.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://si.crous-rouen.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://si.crous-rouen.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "crous-rouen.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.crous-rouen.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Rouen - Personnels"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Rouen - Personnels"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEhzCCA2+gAwIBAgIQJvlpRPEdizrPH+vEmo4c7zANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEyMTIwNDAwMDAwMFoXDTE1MTIwNDIzNTk1OVowYTELMAkGA1UE\nBhMCRlIxFzAVBgNVBAoTDkNST1VTIGRlIFJvdWVuMR0wGwYDVQQLExRTZXJ2aWNl\nIGluZm9ybWF0aXF1ZTEaMBgGA1UEAxMRc2kuY3JvdXMtcm91ZW4uZnIwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCxhfxnSTRvwvr8huLLous5gGIB3bA0\nVhtougdS1hdlNEhd+5ndm1GXOqQx3Mh0e6cEl2fmjAO1pf4VYuNpnjyGSmcln+58\n4CY/zPq5WNwKwY10rQy3N3TeXKaafI97p1bEOBViNdDmu/I2wr9tuGjfvMmBD00J\nk35yiFb8K2XxG3WUFRXBAIXwoxZbpBPalfr1dZ85F7UHqvgwh4fZQi3Zourwey5h\n08L86LLKBgeRkkoPbYrCJI6pcquCh9whh5jbFEjxpaFJD8zioEJ/q+ARdC4qtEF2\nOQebDHSd+Gy5wXWsnlu/XfSGhzxtaB6RNLLBogYuE+liCqDXVViQ9s71AgMBAAGj\nggFkMIIBYDAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3V0fqkOO57TAdBgNVHQ4E\nFgQUF3MBzPJ4bF7LVHDZXQCs5WhxH5QwDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB\n/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMBgGA1UdIAQRMA8w\nDQYLKwYBBAGyMQECAh0wOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3Mu\ndGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsG\nAQUFBzAChilodHRwOi8vY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNy\ndDAmBggrBgEFBQcwAYYaaHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwHAYDVR0R\nBBUwE4IRc2kuY3JvdXMtcm91ZW4uZnIwDQYJKoZIhvcNAQEFBQADggEBACE/ua3I\n2BlsFzZ2gtxNlMVg6wLQhZkgoOx+Lz/IgZsCjwiIaoNDAj6XfNvSO/DAAbVoVQJt\nXzpmrdiHmG9L9U1RkVUkj7ADLF8BiHxsbXdva7fbRIry4hBdXfvy2vygdhP+YH78\nRAApFdog+ch9Q7pFovajXuJPxYa56W8OQ788uyO2cZqF834qJUbH9p6R78vLFH5Y\npE+J4hzosDSAGW1pQrD0ZpUhr4dvnIkTk71if9YppptIBkjaQRs+A3VLlGjx/h+4\nKNJE8Xihgi+rF2omHHm1CzPNO0SDP7slHJNSbXGPcW8sGTtBq3j3qd7/hZrLxFr2\n3afUu/R74xDmkXU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS Rouen - Personnels"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.crous-rouen.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS Rouen - Personnels"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.craven-college.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.craven-college.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/craven-college.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/craven-college.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "craven-college.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Craven College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.craven-college.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sgw.africa-grid.org/shibboleth",
    {
      "entity_id": "https://sgw.africa-grid.org/shibboleth",
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fargetta"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:marco.fargetta@ct.infn.it"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:credentials-admin@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marco"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barbera"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:roberto.barbera@ct.infn.it"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:credentials-admin@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roberto"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "COMETA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.consorzio-cometa.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consorzio COMETA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sgw.africa-grid.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sgw.africa-grid.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sgw.africa-grid.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sgw.africa-grid.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sgw.africa-grid.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service allows to use on a Grid infrastructure the lighthouse applications of the eI4Africa project"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Questo servizio permette l'accesso e l'uso delle applicazioni/servizi Grid sviluppati per il progetto eI4Africa"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Africa Grid Science Gateway"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Africa Grid Science Gateway"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sgw.africa-grid.org/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sgw.africa-grid.org/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.catania-science-gateways.it"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "aginfra-sg.ct.infn.it"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "cogito-med.ct.infn.it"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "earthserver-sg.consorzio-cometa.it"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ecsg.dch-rp.eu"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "garr-sg.ct.infn.it"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "klios.ct.infn.it"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "liferay2.ct.infn.it"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "sgw.africa-grid.org"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.progetto-icaro.it"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF0TCCBLmgAwIBAgIRAJjvs9uxU/ydSPVPqQh6szEwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xMzAxMDcwMDAwMDBaFw0xNjAxMDcyMzU5NTlaMIHFMQswCQYD\nVQQGEwJJVDEOMAwGA1UEERMFOTUxMjMxDjAMBgNVBAgTBUl0YWx5MRAwDgYDVQQH\nEwdDYXRhbmlhMRkwFwYDVQQJExBWaWEgUy5Tb2ZpYSBuLjY0MS4wLAYDVQQKEyVJ\nc3RpdHV0byBOYXppb25hbGUgZGkgRmlzaWNhIE51Y2xlYXJlMQ8wDQYDVQQLEwZD\nT01FVEExKDAmBgNVBAMTH3d3dy5jYXRhbmlhLXNjaWVuY2UtZ2F0ZXdheXMuaXQw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDMR2RMw4cNImWSKdvZjDhz\n3JuO7/pMOnGw4hF6uu09cqX8qqBpkU/gd33xq7J254ojywwiIlLT7QaTce4YQU2W\nO5mPyqdHjnpA+C0fJWrQgRyJEXsOzwpxyUG42tim/9jgNNDaUuNSGgrMLGlzl0sU\ni3Cq04AY0hukrtFGe6DFvDsm8xoNwfV8jmO3IipWJdJdezRnCGDgTZqgIWj3yrHo\nLjfgLbs85AJ31plMahcEni1jDZYgzu7FurbKpO4FGSLUEI8VUxncdYx3IWidqYBD\nTjxFGIiRIcD59DTIBxZYT4IgGHhG1whnUtE7nZhtuxFvnxfH4gPi7mPcRwidNHg9\nAgMBAAGjggJIMIICRDAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3V0fqkOO57TAd\nBgNVHQ4EFgQU+qOkofxo+Ei3aGD2lLEkM4L7LS0wDgYDVR0PAQH/BAQDAgWgMAwG\nA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMCIGA1Ud\nIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQICMDoGA1UdHwQzMDEwL6AtoCuG\nKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3JsMG0GCCsG\nAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3MudGVyZW5hLm9y\nZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9vY3NwLnRjcy50\nZXJlbmEub3JnMIH1BgNVHREEge0wgeqCH3d3dy5jYXRhbmlhLXNjaWVuY2UtZ2F0\nZXdheXMuaXSCFWFnaW5mcmEtc2cuY3QuaW5mbi5pdIIVY29naXRvLW1lZC5jdC5p\nbmZuLml0giJlYXJ0aHNlcnZlci1zZy5jb25zb3J6aW8tY29tZXRhLml0gg5lY3Nn\nLmRjaC1ycC5ldYISZ2Fyci1zZy5jdC5pbmZuLml0ghBrbGlvcy5jdC5pbmZuLml0\nghNsaWZlcmF5Mi5jdC5pbmZuLml0ghNzZ3cuYWZyaWNhLWdyaWQub3JnghV3d3cu\ncHJvZ2V0dG8taWNhcm8uaXQwDQYJKoZIhvcNAQEFBQADggEBAIzikPZKDI8rXlUU\niF8KUeEVYZMyBfRtl0sQYBZCprDoVpCr74CPTxQ72Jrh2mD8oAz0ZYVgOA19AbM8\nPskJlhx4bmDJvWU/C2FrOgYDNg9Tl7dqLnr18GDt7DuC0KXCDupgtBmwy7mayNgA\nn2jbIaYsfMI7k1msS1XoaVX7kBMgmeGY3V11Om9Te7iMWKFOhpavI2hbf741ODtV\nzBen58Q2WzjVEKVQYbY7UgtcYzOM44GhMcdS65lLsBviK7HzyB6I5Iu3TR0bcpFE\n2V4bd6L5foq3Qn+WO9wqOwnOk3qfD/TQId7NWv0ZE2vp8fPPaaRF2XcA7Qh5xltt\nj/MCNlE="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.catania-science-gateways.it,OU=COMETA,O=Istituto Nazionale di Fisica Nucleare,street=Via S.Sofia n.64,L=Catania,ST=Italy,postalCode=95123,C=IT"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sgw.africa-grid.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sgw.africa-grid.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sgw.africa-grid.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sgw.africa-grid.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sgw.africa-grid.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sgw.africa-grid.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Africa Grid Science Gateway"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This service allows to use on a Grid infrastructure the lighthouse applications of the eI4Africa project"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.pugetsound.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "myoung@pugetsound.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark Young"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "myoung@pugetsound.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark Young"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jhoover@pugetsound.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jared Hoover"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.pugetsound.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.pugetsound.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.pugetsound.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAOCcreUOmiOG3xoRIC3Ym1PXDT9rMA0GCSqGSIb3DQEB\nBQUAMB0xGzAZBgNVBAMTEmlkcC5wdWdldHNvdW5kLmVkdTAeFw0xNDA0MDQyMDI2\nMTNaFw0zNDA0MDQyMDI2MTNaMB0xGzAZBgNVBAMTEmlkcC5wdWdldHNvdW5kLmVk\ndTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKIFr9xIP2yR/5PaQWE1\nKQQsGVBaNLOlWrPyQsre6V6FaBpAp9i0dgFchxQA0ZGibTPxNN05ArpwLgMImZUq\n/4ed5RXC61c6p8Xg75XukTbAnREapifNkN3pgVnfGuaQ5sGHloJseeW7PvXzt+VW\ntltOi2mweNWQfc2eDD0MfGoPjUOKiKVD79QnWr5xezwMPibkDylMBiL9mjRAZy0T\nVnrP1L+haaS6mTDvHgJdqJRMFn9fpqVAXKYKUFPpXv1H3JNYf2n/Js4tySYOkU/H\nqN+CDW12HU124SEoX04PM0HMXdnE3kvKly8XD7kKXsw38JC3febo3G9oe+oeco0p\n0qcCAwEAAaNrMGkwSAYDVR0RBEEwP4ISaWRwLnB1Z2V0c291bmQuZWR1hilodHRw\nczovL2lkcC5wdWdldHNvdW5kLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\nKYEx6iRREVlZzqlIpSIBHZlPXqswDQYJKoZIhvcNAQEFBQADggEBAH9cDcUTyhvc\nbQDLqX3WbDADas8DsJDrs4kv3kFZXU96VJ2QCFHuYb2trlrTpzGzeujcFGoVxB91\ngVeMz9KBcnIJzqiIDZ+ihLfJaZZ+ELgd7VLm5SWSKrbffzeQIJj1o6QSURoNKNff\nszMYxuCaiSFyj5lnAqZ1ui9OcICeM3NDZtWy2X9yF14rQhcmFwQXovxBsJAx11vR\nDDLKGMpQHM8nP7V9l8tr69Wk7n8L/FSC7lK4rv2acn5l0akFQKp0NBg2ImeRBuZY\nqdWHUVixGVEY5CgV9iwp1JqiADrKNRol15RSTTW11sOpWjvmMAIUzXYCk5l9lkJB\nb/3hR0no3ho="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pugetsound.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for the University of Puget Sound"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Puget Sound"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Puget Sound"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.pugetsound.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Puget Sound"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.bristolsu.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.bristolsu.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-04-07T14:33:25Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bristol Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bristolsu.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.bristolsu.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.bristolsu.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.bristolsu.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.bristolsu.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.bristolsu.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.bristolsu.org.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.bristolsu.org.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.bristolsu.org.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.bristolsu.org.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.bristolsu.org.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.bristolsu.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.bristolsu.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.bristolsu.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.bristolsu.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.bristolsu.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.bristolsu.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.cwc.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bozzo-Rey"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:yves_bozzo-rey@cwc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Yves"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bozzo-Rey"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:yves_bozzo-rey@cwc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Yves"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cwc.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-09-26T10:27:14Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUGMUEvqcH0AW3uF4F0/urAdo29hQwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGDEWMBQGA1UEAxMNaWRwLmN3Yy5hYy51azAeFw0xMzA5MTgxMTIwNDJaFw0z\n\t\t\t\t\t\tMzA5MTgxMTIwNDJaMBgxFjAUBgNVBAMTDWlkcC5jd2MuYWMudWswggEiMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCsO608HeIDdoDe9MLtR9Q6F9ZfWR0u90jc\n\t\t\t\t\t\tZp6DwseLlwwNHbysoJQocFh5rxY5IYPxz3W1S1WbN3apcYJ9eNO7ze3QLWycl2J8\n\t\t\t\t\t\t4KS6Y76ViCpcBut3JhJHa/w9p4pfev27yfEIpc/wd9GsTHnz0hvUFKeFhAi/et9e\n\t\t\t\t\t\tnsDwJivp2Nj3MvK7K+j0HGwdwwmww6K0/YneMnTb6/piCOBrLc04/picXISI64H/\n\t\t\t\t\t\toU7FwCXLQLTQY4MWhZccPhuSlI+KhnhFF+mJHsbfjpp5ClNYtK1UmQJghp/UoroM\n\t\t\t\t\t\t13O2DyjGbC6vKS+9M6XWinhhp743/m/Aykiakb853/HOsjM0bAx1AgMBAAGjYTBf\n\t\t\t\t\t\tMD4GA1UdEQQ3MDWCDWlkcC5jd2MuYWMudWuGJGh0dHBzOi8vaWRwLmN3Yy5hYy51\n\t\t\t\t\t\tay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU/CWbrA4a96ioSsOcKUzzmWC2sSAw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAE7Mk9gNMgKIfx8J9blqvCakuxkHoNMJCH+74kre\n\t\t\t\t\t\t1ZBFXl3dlr8LINw8EDiAXUigQgSb3FSpGlsEzi9UUreJ45y+E0sbrzFRRcsIi2GP\n\t\t\t\t\t\t8fuXkweKi7mZVFPjVv9dC771tMij7vioKljDxPYsFTXVORnnrdWcAse2BxnGbydf\n\t\t\t\t\t\tM1xHoXl+agxTld1R3L4aP1guxomfOK48a1UCz0VlNNius0IVgw7fMCXjSrNDM3nL\n\t\t\t\t\t\tmqhLbqrMAQbaSkLiOHbN8ZZ+c/2q2Yv5HEdgvrsxXCpgINSA9zcMIEl9rAADbOOG\n\t\t\t\t\t\tK3oBkLQYth/QakEkMIiItL8GzAU0TNWO+72vhyYn7qm5W+M="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cwc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cwc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cwc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cwc.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cwc.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cwc.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.cwc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cwc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.cwc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cwc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cwc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cwc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cwc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUGMUEvqcH0AW3uF4F0/urAdo29hQwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGDEWMBQGA1UEAxMNaWRwLmN3Yy5hYy51azAeFw0xMzA5MTgxMTIwNDJaFw0z\n\t\t\t\t\t\tMzA5MTgxMTIwNDJaMBgxFjAUBgNVBAMTDWlkcC5jd2MuYWMudWswggEiMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCsO608HeIDdoDe9MLtR9Q6F9ZfWR0u90jc\n\t\t\t\t\t\tZp6DwseLlwwNHbysoJQocFh5rxY5IYPxz3W1S1WbN3apcYJ9eNO7ze3QLWycl2J8\n\t\t\t\t\t\t4KS6Y76ViCpcBut3JhJHa/w9p4pfev27yfEIpc/wd9GsTHnz0hvUFKeFhAi/et9e\n\t\t\t\t\t\tnsDwJivp2Nj3MvK7K+j0HGwdwwmww6K0/YneMnTb6/piCOBrLc04/picXISI64H/\n\t\t\t\t\t\toU7FwCXLQLTQY4MWhZccPhuSlI+KhnhFF+mJHsbfjpp5ClNYtK1UmQJghp/UoroM\n\t\t\t\t\t\t13O2DyjGbC6vKS+9M6XWinhhp743/m/Aykiakb853/HOsjM0bAx1AgMBAAGjYTBf\n\t\t\t\t\t\tMD4GA1UdEQQ3MDWCDWlkcC5jd2MuYWMudWuGJGh0dHBzOi8vaWRwLmN3Yy5hYy51\n\t\t\t\t\t\tay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU/CWbrA4a96ioSsOcKUzzmWC2sSAw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAE7Mk9gNMgKIfx8J9blqvCakuxkHoNMJCH+74kre\n\t\t\t\t\t\t1ZBFXl3dlr8LINw8EDiAXUigQgSb3FSpGlsEzi9UUreJ45y+E0sbrzFRRcsIi2GP\n\t\t\t\t\t\t8fuXkweKi7mZVFPjVv9dC771tMij7vioKljDxPYsFTXVORnnrdWcAse2BxnGbydf\n\t\t\t\t\t\tM1xHoXl+agxTld1R3L4aP1guxomfOK48a1UCz0VlNNius0IVgw7fMCXjSrNDM3nL\n\t\t\t\t\t\tmqhLbqrMAQbaSkLiOHbN8ZZ+c/2q2Yv5HEdgvrsxXCpgINSA9zcMIEl9rAADbOOG\n\t\t\t\t\t\tK3oBkLQYth/QakEkMIiItL8GzAU0TNWO+72vhyYn7qm5W+M="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "City of Westminster College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cwc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "City of Westminster College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.gowercollegeswansea.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Parkhouse"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ian.parkhouse@gowercollegeswansea.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Parkhouse"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ian.parkhouse@gowercollegeswansea.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.gowercollegeswansea.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYTCCAkmgAwIBAgIVAPaKVO7qjn5iTZ8Gic6gQPWYymlgMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCgxJjAkBgNVBAMTHWlkcC5nb3dlcmNvbGxlZ2Vzd2Fuc2VhLmFjLnVrMB4X\n\t\t\t\t\t\tDTExMDgyNDEyNDQ1NloXDTMxMDgyNDEyNDQ1NlowKDEmMCQGA1UEAxMdaWRwLmdv\n\t\t\t\t\t\td2VyY29sbGVnZXN3YW5zZWEuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQD7EU6nahXNJNscC+4O8qkavjfcOAnWVaBl7WyAmryYsudXcIitwlqv\n\t\t\t\t\t\tzjJrfc4Ncs0q6pKawJWBrqjiNyRBS4SEZpfgD2UXq/+LjfGJQKSXz4QzVmicGji6\n\t\t\t\t\t\tezsXQ0fvf7Nq7QqmT50M4xUWAbq71s6uZPKApui1hHGtFlp6IbLErcpB3jmp7skg\n\t\t\t\t\t\tAu7OoZ7lbWuRKkRea9mBuUq3+uMlONfghNb5rkX+MHvXbpbFfG+W4ERLQMPWPeAw\n\t\t\t\t\t\tV7vMInXysu70CakNJzIcvf41V73dR6LhooZyr4sIOPJdUWXBRGEWrGuBD/eGFxwY\n\t\t\t\t\t\t3c+XIeVs37RmKwxLFRjJPkT6lxPfpoUtAgMBAAGjgYEwfzBeBgNVHREEVzBVgh1p\n\t\t\t\t\t\tZHAuZ293ZXJjb2xsZWdlc3dhbnNlYS5hYy51a4Y0aHR0cHM6Ly9pZHAuZ293ZXJj\n\t\t\t\t\t\tb2xsZWdlc3dhbnNlYS5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUij+g\n\t\t\t\t\t\taDdeycJoti2x2hF12wErnSEwDQYJKoZIhvcNAQEFBQADggEBAEaiPWm87wZCFKlb\n\t\t\t\t\t\tuM8BNEQccKBxVSYdYvb5W50EPPI0FIPWc09H4EDtd8ekJHlK6uML3AYdAI4GKniL\n\t\t\t\t\t\tesApCmAdNP2jm752tp3FwTENcD/roYRWk/L+BCVSgrj+lwJNc+R+9HIqG6ZFiAG1\n\t\t\t\t\t\t/Jr5t/XLTj4W+OO99dQLpNiXnGcn3AluRVpmO2oSmQAINAVkzOv+FRaVElRZ6NMH\n\t\t\t\t\t\t58L5gnD0BmNPToS9XYiJbiJID1ViEjrkFPDfCUCC6XEEnPJ3hu/im0H8twKLb52Y\n\t\t\t\t\t\tlCgXikLauknBHaF7kl1iiuMIyNn3KATJn53IQnYEhIe3eweTHTwXiAVOOnn2MXd3\n\t\t\t\t\t\tVUkeVwI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gowercollegeswansea.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.gowercollegeswansea.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.gowercollegeswansea.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.gowercollegeswansea.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.gowercollegeswansea.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.gowercollegeswansea.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.gowercollegeswansea.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.gowercollegeswansea.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.gowercollegeswansea.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gowercollegeswansea.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYTCCAkmgAwIBAgIVAPaKVO7qjn5iTZ8Gic6gQPWYymlgMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCgxJjAkBgNVBAMTHWlkcC5nb3dlcmNvbGxlZ2Vzd2Fuc2VhLmFjLnVrMB4X\n\t\t\t\t\t\tDTExMDgyNDEyNDQ1NloXDTMxMDgyNDEyNDQ1NlowKDEmMCQGA1UEAxMdaWRwLmdv\n\t\t\t\t\t\td2VyY29sbGVnZXN3YW5zZWEuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQD7EU6nahXNJNscC+4O8qkavjfcOAnWVaBl7WyAmryYsudXcIitwlqv\n\t\t\t\t\t\tzjJrfc4Ncs0q6pKawJWBrqjiNyRBS4SEZpfgD2UXq/+LjfGJQKSXz4QzVmicGji6\n\t\t\t\t\t\tezsXQ0fvf7Nq7QqmT50M4xUWAbq71s6uZPKApui1hHGtFlp6IbLErcpB3jmp7skg\n\t\t\t\t\t\tAu7OoZ7lbWuRKkRea9mBuUq3+uMlONfghNb5rkX+MHvXbpbFfG+W4ERLQMPWPeAw\n\t\t\t\t\t\tV7vMInXysu70CakNJzIcvf41V73dR6LhooZyr4sIOPJdUWXBRGEWrGuBD/eGFxwY\n\t\t\t\t\t\t3c+XIeVs37RmKwxLFRjJPkT6lxPfpoUtAgMBAAGjgYEwfzBeBgNVHREEVzBVgh1p\n\t\t\t\t\t\tZHAuZ293ZXJjb2xsZWdlc3dhbnNlYS5hYy51a4Y0aHR0cHM6Ly9pZHAuZ293ZXJj\n\t\t\t\t\t\tb2xsZWdlc3dhbnNlYS5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUij+g\n\t\t\t\t\t\taDdeycJoti2x2hF12wErnSEwDQYJKoZIhvcNAQEFBQADggEBAEaiPWm87wZCFKlb\n\t\t\t\t\t\tuM8BNEQccKBxVSYdYvb5W50EPPI0FIPWc09H4EDtd8ekJHlK6uML3AYdAI4GKniL\n\t\t\t\t\t\tesApCmAdNP2jm752tp3FwTENcD/roYRWk/L+BCVSgrj+lwJNc+R+9HIqG6ZFiAG1\n\t\t\t\t\t\t/Jr5t/XLTj4W+OO99dQLpNiXnGcn3AluRVpmO2oSmQAINAVkzOv+FRaVElRZ6NMH\n\t\t\t\t\t\t58L5gnD0BmNPToS9XYiJbiJID1ViEjrkFPDfCUCC6XEEnPJ3hu/im0H8twKLb52Y\n\t\t\t\t\t\tlCgXikLauknBHaF7kl1iiuMIyNn3KATJn53IQnYEhIe3eweTHTwXiAVOOnn2MXd3\n\t\t\t\t\t\tVUkeVwI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Gower College Swansea"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gowercollegeswansea.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Gower College Swansea"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://voparis-auth.obspm.fr/",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vo.paris@obspm.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://voparis-auth.obspm.fr/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-02-04T14:37:54Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/metier"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/community"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Observatoire de Paris"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.obspm.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Observatoire de Paris"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://voparis-auth.obspm.fr/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Access to authenticated service of the astronomical virtual observatory at Observatoire de Paris."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Acc\u00e8s au service authentifi\u00e9 de l'observatoire virtuel astronomique de l'Observatoire de Paris."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://voparis-srv.obspm.fr/portal/privacy_policy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "VO Paris Authentication"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Authentification VO Paris"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJANXkggHBesKeMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\nBAMTFXZvcGFyaXMtYXV0aC5vYnNwbS5mcjAeFw0xNTAyMDQxMzI4MDlaFw0yNTAy\nMDExMzI4MDlaMCAxHjAcBgNVBAMTFXZvcGFyaXMtYXV0aC5vYnNwbS5mcjCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOXw2yL9a6xlFB26MUsFjKDwsWuC\nL/nn4CGRsU6cBtNQU7/z/pHRihWWxlSV+FXySkRYoy7DrpA84zo0AiYPtxuV31K/\nIb9mg5jB12M5jqDHGk8blbxStVAF5ZI7GSP1Yo0SYrMBtPzxRy5yjtyCPb3Cj/ez\n2EO+Dh0lS9FCIlaPwfyRfEFaGhKlZ0oFFn1Y4D6suNKE3tFWRtz5lPW66BGZ6303\nWWlF0wNPhJy7SlZIFeYmdoLD/n68hCmI9BUivXsbTlRJdEYhcwQbkX0e/CBONC7M\nriIOlQ/Pci2jnMo0np/x6EHKg7vCxrHr7zGZVNl8Mgiw03RZlZqrDnRSvTUCAwEA\nAaNDMEEwIAYDVR0RBBkwF4IVdm9wYXJpcy1hdXRoLm9ic3BtLmZyMB0GA1UdDgQW\nBBTbSK3h6OXJaGl0/w1Jo7as0O1xUjANBgkqhkiG9w0BAQUFAAOCAQEAUvf2DQUQ\nNonutHUXwYTIpK12+FgOmo+O8Akn+RNYzmwCmxxTfUdkXPWCI5RDE3k6RRo265xx\nU+zijD6XZia4v2oxXoIxS/dTMyysU/VvIgtnHOaaeEsDJRLB9/7pxd6uuDS5mMG6\nbk1LYTFU+wM5joK7UL7iAQGPbPXJ/yXXMYfE6E6FzPbCs6K46z1Xxc6QTZDrcwmW\nU4f0PwCtKDt6yuk8zcvPCNStQlT3udLzIb4szTSS2Mcdb+k+LJdN0AulJYZG0L3p\nUkePHzLUtvkC2YNySU+2LKUzZbyGxR3mXQ5mk/F0mrpk6Yn/frplA6nYGIWM7tb4\n8BTF+jExj09ZCw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJANXkggHBesKeMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\nBAMTFXZvcGFyaXMtYXV0aC5vYnNwbS5mcjAeFw0xNTAyMDQxMzI4MDlaFw0yNTAy\nMDExMzI4MDlaMCAxHjAcBgNVBAMTFXZvcGFyaXMtYXV0aC5vYnNwbS5mcjCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOXw2yL9a6xlFB26MUsFjKDwsWuC\nL/nn4CGRsU6cBtNQU7/z/pHRihWWxlSV+FXySkRYoy7DrpA84zo0AiYPtxuV31K/\nIb9mg5jB12M5jqDHGk8blbxStVAF5ZI7GSP1Yo0SYrMBtPzxRy5yjtyCPb3Cj/ez\n2EO+Dh0lS9FCIlaPwfyRfEFaGhKlZ0oFFn1Y4D6suNKE3tFWRtz5lPW66BGZ6303\nWWlF0wNPhJy7SlZIFeYmdoLD/n68hCmI9BUivXsbTlRJdEYhcwQbkX0e/CBONC7M\nriIOlQ/Pci2jnMo0np/x6EHKg7vCxrHr7zGZVNl8Mgiw03RZlZqrDnRSvTUCAwEA\nAaNDMEEwIAYDVR0RBBkwF4IVdm9wYXJpcy1hdXRoLm9ic3BtLmZyMB0GA1UdDgQW\nBBTbSK3h6OXJaGl0/w1Jo7as0O1xUjANBgkqhkiG9w0BAQUFAAOCAQEAUvf2DQUQ\nNonutHUXwYTIpK12+FgOmo+O8Akn+RNYzmwCmxxTfUdkXPWCI5RDE3k6RRo265xx\nU+zijD6XZia4v2oxXoIxS/dTMyysU/VvIgtnHOaaeEsDJRLB9/7pxd6uuDS5mMG6\nbk1LYTFU+wM5joK7UL7iAQGPbPXJ/yXXMYfE6E6FzPbCs6K46z1Xxc6QTZDrcwmW\nU4f0PwCtKDt6yuk8zcvPCNStQlT3udLzIb4szTSS2Mcdb+k+LJdN0AulJYZG0L3p\nUkePHzLUtvkC2YNySU+2LKUzZbyGxR3mXQ5mk/F0mrpk6Yn/frplA6nYGIWM7tb4\n8BTF+jExj09ZCw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://voparis-auth.obspm.fr/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://voparis-auth.obspm.fr/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Authentification VO Paris"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "VO Paris Authentication"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Acc\u00e8s au service authentifi\u00e9 de l'observatoire virtuel astronomique de l'Observatoire de Paris."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Access to authenticated service of the astronomical virtual observatory at Observatoire de Paris."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrimaryAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.5",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://oxfordideas.wazoku.com/",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Darke"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nicola.darke@wazoku.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nicola"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bailey"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chris.bailey@wazoku.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://oxfordideas.wazoku.com/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-08-12T10:20:26Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en-GB",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "oxfordideas.wazoku.com"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wazoku.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en-GB",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Wazoku Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDnzCCAoegAwIBAgIJALt69IM1gEANMA0GCSqGSIb3DQEBCwUAMGYxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMQ8wDQYDVQQIDAZMb25kb24xDzANBgNVBAcMBkxvbmRvbjEPMA0GA1UE\n\t\t\t\t\t\tCgwGV2F6b2t1MQswCQYDVQQLDAJJVDEXMBUGA1UEAwwOd3d3Lndhem9rdS5jb20w\n\t\t\t\t\t\tHhcNMTUwODA2MTIwNjUzWhcNMjUwODA1MTIwNjUzWjBmMQswCQYDVQQGEwJHQjEP\n\t\t\t\t\t\tMA0GA1UECAwGTG9uZG9uMQ8wDQYDVQQHDAZMb25kb24xDzANBgNVBAoMBldhem9r\n\t\t\t\t\t\tdTELMAkGA1UECwwCSVQxFzAVBgNVBAMMDnd3dy53YXpva3UuY29tMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzpKv/aasbpuVuiPoocArUaVYQNS/RQ6x\n\t\t\t\t\t\tnS0hZC+nU5NqgvboG9LgUApbCW8DvKltNuErzPeDjxxO98zvkojmv4QgFXl37E4d\n\t\t\t\t\t\tKwW8kbGgEBH2/8cvT0+9A45EP1On9CGizVVmJ46Lg0ObAjG5CRT9LYYqQ7nwK4I2\n\t\t\t\t\t\tylfFXGU17SztVmxXzp5DjMtOyCUxGlryD05+FvOzEj6Rxx5w4UX+Ceh7a5qncZSM\n\t\t\t\t\t\tFXT8wo+Gxa8pci9C66dVaJXQ2rKSMZj6ndu23XWhIWQksDr72T8HbYJdlgOVBC0w\n\t\t\t\t\t\t9f8JhTdlGoXctCw0PGQdubl80Qlib7tix0IACYfGh77C0BMgshilZQIDAQABo1Aw\n\t\t\t\t\t\tTjAdBgNVHQ4EFgQUX8mH3Mqq7NCqICtqTdgQErAMPM0wHwYDVR0jBBgwFoAUX8mH\n\t\t\t\t\t\t3Mqq7NCqICtqTdgQErAMPM0wDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOC\n\t\t\t\t\t\tAQEAe8old/r6SZ3ua3pdMWOrUOEZuH8iiiZjpjD8ENKu+/vMa5HIzMJ5ecMyxwda\n\t\t\t\t\t\t2MNhR627By5AhxuhJ2oC7/Ndgio1as1Lx8A/aj0VcvYFpa7c4BIfKWGRfWvxfn8d\n\t\t\t\t\t\tRsaDNa+fLEgtp5Dn8AFM6eCzq+rciawuCUIovoD/8gOqiPQw/EYghj4zZPaPMrVd\n\t\t\t\t\t\t/jdFEO51B0lVTLmVug0m9I2x53xNbCndVRQR3svm84xEZ93qcoq0nglrbavkpvK2\n\t\t\t\t\t\tb4HAD/AIOYY597wwV/+3Jt5yTzHMrVoDiJiGGfqKXoWdLU2HQvcKN4NmsK5Ow92P\n\t\t\t\t\t\tGmO3ftyUNMBb/z18IS+jWiKzMQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDnzCCAoegAwIBAgIJALt69IM1gEANMA0GCSqGSIb3DQEBCwUAMGYxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMQ8wDQYDVQQIDAZMb25kb24xDzANBgNVBAcMBkxvbmRvbjEPMA0GA1UE\n\t\t\t\t\t\tCgwGV2F6b2t1MQswCQYDVQQLDAJJVDEXMBUGA1UEAwwOd3d3Lndhem9rdS5jb20w\n\t\t\t\t\t\tHhcNMTUwODA2MTIwNjUzWhcNMjUwODA1MTIwNjUzWjBmMQswCQYDVQQGEwJHQjEP\n\t\t\t\t\t\tMA0GA1UECAwGTG9uZG9uMQ8wDQYDVQQHDAZMb25kb24xDzANBgNVBAoMBldhem9r\n\t\t\t\t\t\tdTELMAkGA1UECwwCSVQxFzAVBgNVBAMMDnd3dy53YXpva3UuY29tMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzpKv/aasbpuVuiPoocArUaVYQNS/RQ6x\n\t\t\t\t\t\tnS0hZC+nU5NqgvboG9LgUApbCW8DvKltNuErzPeDjxxO98zvkojmv4QgFXl37E4d\n\t\t\t\t\t\tKwW8kbGgEBH2/8cvT0+9A45EP1On9CGizVVmJ46Lg0ObAjG5CRT9LYYqQ7nwK4I2\n\t\t\t\t\t\tylfFXGU17SztVmxXzp5DjMtOyCUxGlryD05+FvOzEj6Rxx5w4UX+Ceh7a5qncZSM\n\t\t\t\t\t\tFXT8wo+Gxa8pci9C66dVaJXQ2rKSMZj6ndu23XWhIWQksDr72T8HbYJdlgOVBC0w\n\t\t\t\t\t\t9f8JhTdlGoXctCw0PGQdubl80Qlib7tix0IACYfGh77C0BMgshilZQIDAQABo1Aw\n\t\t\t\t\t\tTjAdBgNVHQ4EFgQUX8mH3Mqq7NCqICtqTdgQErAMPM0wHwYDVR0jBBgwFoAUX8mH\n\t\t\t\t\t\t3Mqq7NCqICtqTdgQErAMPM0wDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOC\n\t\t\t\t\t\tAQEAe8old/r6SZ3ua3pdMWOrUOEZuH8iiiZjpjD8ENKu+/vMa5HIzMJ5ecMyxwda\n\t\t\t\t\t\t2MNhR627By5AhxuhJ2oC7/Ndgio1as1Lx8A/aj0VcvYFpa7c4BIfKWGRfWvxfn8d\n\t\t\t\t\t\tRsaDNa+fLEgtp5Dn8AFM6eCzq+rciawuCUIovoD/8gOqiPQw/EYghj4zZPaPMrVd\n\t\t\t\t\t\t/jdFEO51B0lVTLmVug0m9I2x53xNbCndVRQR3svm84xEZ93qcoq0nglrbavkpvK2\n\t\t\t\t\t\tb4HAD/AIOYY597wwV/+3Jt5yTzHMrVoDiJiGGfqKXoWdLU2HQvcKN4NmsK5Ow92P\n\t\t\t\t\t\tGmO3ftyUNMBb/z18IS+jWiKzMQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://oxfordideas.wazoku.com/saml_ol/login",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://acc-nais.uhr.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://acc-nais.uhr.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://acc-nais.uhr.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://acc-nais.uhr.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://acc-nais.uhr.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://acc-nais.uhr.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://acc-nais.uhr.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://acc-nais.uhr.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://acc-nais.uhr.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://acc-nais.uhr.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "NAIS st\u00e5r f\u00f6r Nationellt Administrations- och Informationssystem f\u00f6r samordnare av s\u00e4rskilt pedagogiskt st\u00f6d"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "NAIS stands for National Administration- and Information system for coordination of pedagogical aid"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Acc-NaisSP"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Acc-NaisSP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "uhrval-test.i.uhr.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAKrvj/quXo0oMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFHVocnZhbC10ZXN0LmkudWhyLnNlMB4XDTE0MTIwODA5MTExMVoXDTI0MTIw\nNTA5MTExMVowHzEdMBsGA1UEAxMUdWhydmFsLXRlc3QuaS51aHIuc2UwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCtIWX5i6gPePK7nbap8snxwcLqlCID\nLWZkxbQGCVIgixRk1w87yUD882SSZjUATS8JV+8TeHNIsRSkBeXB1MQQopeDtm5C\nLDhh/RxHL3IRBlhesOE5zWcc4xeBzRIBKb1OC773XbSLx1lQhZmH+fiQvEk5FfWG\nri683HBCQq3gpc3hX2lY7C7oAxL7KST+37zLIBy7c83fzWr3eQ1myKZFfHBsmMOt\npNjBNMG8V924gaHWKAuqDa6lds53PszYZh27bN7dWXRrN0vXEZu6zfEioJVvg5RL\nc0lUqg/yu8Dk9JYYm9rQDj007livs9QllR54wsIxosVQWhAz36ZFafaNAgMBAAGj\nQjBAMB8GA1UdEQQYMBaCFHVocnZhbC10ZXN0LmkudWhyLnNlMB0GA1UdDgQWBBSG\nEGTlhQfKssjt+WgDPIKFHzzZEDANBgkqhkiG9w0BAQUFAAOCAQEAOHImN37aqOBU\nwicsP5vJ7X8yX6he/dAnRKhZbjWSlpFSZGwZrV/B6YeROAyRbzQH1fQRTup+angF\nB5m+vmxG0XjhUm8gXpMNqjgxaay72m2rPTVAkbqkMNTKNf44bRK5OGqPlJ0lwrnC\nWh1+2EdKahr4lzJaqiW2rXvX3moTYqrJlssglT+IRTzoNbL6eQLdqCVvZxXDjyUb\nD79D+ECq8yjkS4/8EQlvHdHozRMMplJTo+pXoZwV9KZgMMsxdT63VuJ/0HRCxCMC\nzcmOSN36LTlSIYY4q9pC8MCzt5YqZdnKJUIyjFy+Mmjeyw4t+ouUjjI6+AifCten\nBwquFopAQg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=uhrval-test.i.uhr.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://acc-nais.uhr.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://acc-nais.uhr.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://acc-nais.uhr.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://acc-nais.uhr.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://acc-nais.uhr.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://acc-nais.uhr.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://acc-nais.uhr.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://acc-nais.uhr.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://acc-nais.uhr.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://login.mayo.edu/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "brandt.shawn@mayo.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shawn Brandt"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Outcalt.Sandra@mayo.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sandy Outcalt"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "wirth.troy@mayo.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Troy Wirth"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://login.mayo.edu/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.mayo.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.mayo.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.mayo.edu/adfs/services/trust/artifactresolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mayo.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mayo Clinic"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGYjCCBUqgAwIBAgIQSYTipRaDfa4yYbpeDlGgmzANBgkqhkiG9w0BAQUFADCB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\nNiV1gUes"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mayo Clinic"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mayo.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Mayo Clinic"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.york.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@york.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "User Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@york.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.york.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2007-10-15T11:05:25.614639Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID+DCCAuCgAwIBAgIJAJhO6a6qGOfvMA0GCSqGSIb3DQEBBQUAMH0xCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRIwEAYDVQQIEwlZb3Jrc2hpcmUxDTALBgNVBAcTBFlvcmsxGzAZBgNV\n\t\t\t\t\t\tBAoTElVuaXZlcnNpdHkgb2YgWW9yazEUMBIGA1UECxMLSVQgU2VydmljZXMxGDAW\n\t\t\t\t\t\tBgNVBAMTD3NoaWIueW9yay5hYy51azAeFw0xMzA4MTYxMjAxNDRaFw0yMzA4MTQx\n\t\t\t\t\t\tMjAxNDRaMH0xCzAJBgNVBAYTAkdCMRIwEAYDVQQIEwlZb3Jrc2hpcmUxDTALBgNV\n\t\t\t\t\t\tBAcTBFlvcmsxGzAZBgNVBAoTElVuaXZlcnNpdHkgb2YgWW9yazEUMBIGA1UECxML\n\t\t\t\t\t\tSVQgU2VydmljZXMxGDAWBgNVBAMTD3NoaWIueW9yay5hYy51azCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBAMQQw+p+wFg6EvOtEOJWjX0W+IYuNq5EQjVW\n\t\t\t\t\t\t6iupNRMJvuG6sMJB5WK/fPSiCRzrnZKOQrL8S23fitL4bxCN2tJd60ejKsy0TVy1\n\t\t\t\t\t\twyOZNUKYOjwaV+luAiyiLNfwZpHiDXWLlW8OwrdWNKXP9klVE+bOQSVmseIN996p\n\t\t\t\t\t\tEZdsxZCwr0cmOqHC5dOssX+LWbk+q/8mqRnt/somCs+4wmc0E8OyTVsbqoR7b4vm\n\t\t\t\t\t\tc62mHsixUDg4QE21L+weQb1zHdTq2ORAGpumB57Az8k+xsB3FDrhLiZKWRrBfaYd\n\t\t\t\t\t\tbKRUDkgjUuTqVheeOS7IEUlrkA8XALDPZWyiYRCf8EkPBI+QvWcCAwEAAaN7MHkw\n\t\t\t\t\t\tCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2Vy\n\t\t\t\t\t\tdGlmaWNhdGUwHQYDVR0OBBYEFLmjsqdnc3fM4amWI6O1nF3/1biZMB8GA1UdIwQY\n\t\t\t\t\t\tMBaAFLmjsqdnc3fM4amWI6O1nF3/1biZMA0GCSqGSIb3DQEBBQUAA4IBAQBcwCD/\n\t\t\t\t\t\tmgjaj2CnORxfVcGbllIdCBDnFx6xWFbz1GxeSxzFGeL8HdWVEzYCcu9o7/GAX00c\n\t\t\t\t\t\tXAOU7qUVI6cGL9S9cuzembcLDKf1DzIf1IGA0QIaNxwEpu+MVxOp/i2tAuOnKjXp\n\t\t\t\t\t\tr/ot+oYXtU1O4QoDtO7cDOx0LN3/fi5SiELgAzfcCPB5CNC6NWhkZ9dz1t9cFMbM\n\t\t\t\t\t\tA4SSjs/kcAjGVXIv19yyulv4kZ+uUD7OoB6uGhcXA8L9ENEXmcpZ9Cr6n6Op1cEJ\n\t\t\t\t\t\tWhdbSNckji6+UTBB/qSf6hsmJnVa4CQmg0XVqy0ceBkrkYHgEuVxesT64stH5nMJ\n\t\t\t\t\t\tqc/emtVSHd3jgeSW"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "york.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.york.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.york.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.york.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.york.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.york.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.york.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.york.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.york.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "york.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID+DCCAuCgAwIBAgIJAJhO6a6qGOfvMA0GCSqGSIb3DQEBBQUAMH0xCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRIwEAYDVQQIEwlZb3Jrc2hpcmUxDTALBgNVBAcTBFlvcmsxGzAZBgNV\n\t\t\t\t\t\tBAoTElVuaXZlcnNpdHkgb2YgWW9yazEUMBIGA1UECxMLSVQgU2VydmljZXMxGDAW\n\t\t\t\t\t\tBgNVBAMTD3NoaWIueW9yay5hYy51azAeFw0xMzA4MTYxMjAxNDRaFw0yMzA4MTQx\n\t\t\t\t\t\tMjAxNDRaMH0xCzAJBgNVBAYTAkdCMRIwEAYDVQQIEwlZb3Jrc2hpcmUxDTALBgNV\n\t\t\t\t\t\tBAcTBFlvcmsxGzAZBgNVBAoTElVuaXZlcnNpdHkgb2YgWW9yazEUMBIGA1UECxML\n\t\t\t\t\t\tSVQgU2VydmljZXMxGDAWBgNVBAMTD3NoaWIueW9yay5hYy51azCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBAMQQw+p+wFg6EvOtEOJWjX0W+IYuNq5EQjVW\n\t\t\t\t\t\t6iupNRMJvuG6sMJB5WK/fPSiCRzrnZKOQrL8S23fitL4bxCN2tJd60ejKsy0TVy1\n\t\t\t\t\t\twyOZNUKYOjwaV+luAiyiLNfwZpHiDXWLlW8OwrdWNKXP9klVE+bOQSVmseIN996p\n\t\t\t\t\t\tEZdsxZCwr0cmOqHC5dOssX+LWbk+q/8mqRnt/somCs+4wmc0E8OyTVsbqoR7b4vm\n\t\t\t\t\t\tc62mHsixUDg4QE21L+weQb1zHdTq2ORAGpumB57Az8k+xsB3FDrhLiZKWRrBfaYd\n\t\t\t\t\t\tbKRUDkgjUuTqVheeOS7IEUlrkA8XALDPZWyiYRCf8EkPBI+QvWcCAwEAAaN7MHkw\n\t\t\t\t\t\tCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2Vy\n\t\t\t\t\t\tdGlmaWNhdGUwHQYDVR0OBBYEFLmjsqdnc3fM4amWI6O1nF3/1biZMB8GA1UdIwQY\n\t\t\t\t\t\tMBaAFLmjsqdnc3fM4amWI6O1nF3/1biZMA0GCSqGSIb3DQEBBQUAA4IBAQBcwCD/\n\t\t\t\t\t\tmgjaj2CnORxfVcGbllIdCBDnFx6xWFbz1GxeSxzFGeL8HdWVEzYCcu9o7/GAX00c\n\t\t\t\t\t\tXAOU7qUVI6cGL9S9cuzembcLDKf1DzIf1IGA0QIaNxwEpu+MVxOp/i2tAuOnKjXp\n\t\t\t\t\t\tr/ot+oYXtU1O4QoDtO7cDOx0LN3/fi5SiELgAzfcCPB5CNC6NWhkZ9dz1t9cFMbM\n\t\t\t\t\t\tA4SSjs/kcAjGVXIv19yyulv4kZ+uUD7OoB6uGhcXA8L9ENEXmcpZ9Cr6n6Op1cEJ\n\t\t\t\t\t\tWhdbSNckji6+UTBB/qSf6hsmJnVa4CQmg0XVqy0ceBkrkYHgEuVxesT64stH5nMJ\n\t\t\t\t\t\tqc/emtVSHd3jgeSW"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of York"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.york.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of York"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibidp.tameside.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Peach"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apeach@tameside.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Albert"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Peach"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apeach@tameside.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Albert"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibidp.tameside.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-09-17T16:46:36Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUFPl+UkOqD1xU344a+Z5gAA9KFhIwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwITEfMB0GA1UEAxMWc2hpYmlkcC50YW1lc2lkZS5hYy51azAeFw0xMzEwMDMw\n\t\t\t\t\t\tODA2MDBaFw0zMzEwMDMwODA2MDBaMCExHzAdBgNVBAMTFnNoaWJpZHAudGFtZXNp\n\t\t\t\t\t\tZGUuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCtwxXIV0H0\n\t\t\t\t\t\tN3Tn9kfx0vEjWwtR0RDsCQ5NIe4yemy1Ko/QcHoT55G0znKHbDyfufcP2C9hoqzd\n\t\t\t\t\t\tcxWhDY21aYKNUUPCiwyA3y8IjfEfDXc/zN564SI1rXt0e8IyfzTegr7nEZ4pIzb3\n\t\t\t\t\t\tZsOvvZw/guS3SFRT8I/Y4+mQHAeBxYEFHhQEyTAzEa1CkMbQ5g0DBZaZLoem+WR+\n\t\t\t\t\t\tQe5522Hqix5Vx2Dy7ttKe+5mItJAbSGI17p9r6StS7VKBpGfODeoHMIoGcMH5kWs\n\t\t\t\t\t\t79URYp9/KsJvK5xUQIxXYST21lM62fnaOjsNccCMT+6FT0bx/C4khty+ObYdDxWX\n\t\t\t\t\t\tZfbKM6X7b1uTAgMBAAGjczBxMFAGA1UdEQRJMEeCFnNoaWJpZHAudGFtZXNpZGUu\n\t\t\t\t\t\tYWMudWuGLWh0dHBzOi8vc2hpYmlkcC50YW1lc2lkZS5hYy51ay9pZHAvc2hpYmJv\n\t\t\t\t\t\tbGV0aDAdBgNVHQ4EFgQUXwU/7iPk5goOeUXikZ1DAsV1Z1UwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQADggEBABuP25r95KICsuJ/DnQFVPFxzrHFt76smE3HPMGaxxZUmyijN/llqzVx\n\t\t\t\t\t\tYqCeoMNc5mt0RKgd0FUl/ksik2tKc2J7LhFEaPSjPAGmT6ELbhTwU+/Fgnusy4tX\n\t\t\t\t\t\tFE0VKaEDasnf6Ohel5aDDVPkFO1zTAGTm7PtXspdEe0v4JiDTqsDCe3fnu2gEdPL\n\t\t\t\t\t\tw7TLUC8hL0gwos9S/WdgKCvIve41DEj6Y6n03Z2dCtlMMQbvt7OPDNpQRKssj2QV\n\t\t\t\t\t\te0DJl3bx82dv2VE65r/Ugzfu95M9GnIVTX6GZ/S6ey2/mYNi8/7XNkdk5Y5OLnP7\n\t\t\t\t\t\t2e4BhZ7ipNcvA3dRv8lUFszj/juA6xM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tameside.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.tameside.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.tameside.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.tameside.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.tameside.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibidp.tameside.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.tameside.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.tameside.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.tameside.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tameside.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUFPl+UkOqD1xU344a+Z5gAA9KFhIwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwITEfMB0GA1UEAxMWc2hpYmlkcC50YW1lc2lkZS5hYy51azAeFw0xMzEwMDMw\n\t\t\t\t\t\tODA2MDBaFw0zMzEwMDMwODA2MDBaMCExHzAdBgNVBAMTFnNoaWJpZHAudGFtZXNp\n\t\t\t\t\t\tZGUuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCtwxXIV0H0\n\t\t\t\t\t\tN3Tn9kfx0vEjWwtR0RDsCQ5NIe4yemy1Ko/QcHoT55G0znKHbDyfufcP2C9hoqzd\n\t\t\t\t\t\tcxWhDY21aYKNUUPCiwyA3y8IjfEfDXc/zN564SI1rXt0e8IyfzTegr7nEZ4pIzb3\n\t\t\t\t\t\tZsOvvZw/guS3SFRT8I/Y4+mQHAeBxYEFHhQEyTAzEa1CkMbQ5g0DBZaZLoem+WR+\n\t\t\t\t\t\tQe5522Hqix5Vx2Dy7ttKe+5mItJAbSGI17p9r6StS7VKBpGfODeoHMIoGcMH5kWs\n\t\t\t\t\t\t79URYp9/KsJvK5xUQIxXYST21lM62fnaOjsNccCMT+6FT0bx/C4khty+ObYdDxWX\n\t\t\t\t\t\tZfbKM6X7b1uTAgMBAAGjczBxMFAGA1UdEQRJMEeCFnNoaWJpZHAudGFtZXNpZGUu\n\t\t\t\t\t\tYWMudWuGLWh0dHBzOi8vc2hpYmlkcC50YW1lc2lkZS5hYy51ay9pZHAvc2hpYmJv\n\t\t\t\t\t\tbGV0aDAdBgNVHQ4EFgQUXwU/7iPk5goOeUXikZ1DAsV1Z1UwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQADggEBABuP25r95KICsuJ/DnQFVPFxzrHFt76smE3HPMGaxxZUmyijN/llqzVx\n\t\t\t\t\t\tYqCeoMNc5mt0RKgd0FUl/ksik2tKc2J7LhFEaPSjPAGmT6ELbhTwU+/Fgnusy4tX\n\t\t\t\t\t\tFE0VKaEDasnf6Ohel5aDDVPkFO1zTAGTm7PtXspdEe0v4JiDTqsDCe3fnu2gEdPL\n\t\t\t\t\t\tw7TLUC8hL0gwos9S/WdgKCvIve41DEj6Y6n03Z2dCtlMMQbvt7OPDNpQRKssj2QV\n\t\t\t\t\t\te0DJl3bx82dv2VE65r/Ugzfu95M9GnIVTX6GZ/S6ey2/mYNi8/7XNkdk5Y5OLnP7\n\t\t\t\t\t\t2e4BhZ7ipNcvA3dRv8lUFszj/juA6xM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Tameside College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tameside.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Tameside College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-13.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-13.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;13"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;13"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-13.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-13.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAMXbiREMrLiUMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0xMy5sYWRvay51bXUuc2UwHhcNMTUwMTIwMTExMTM2WhcNMjUw\nMTE3MTExMTM2WjAhMR8wHQYDVQQDExZsYWRvazMtMTMubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtRF7svmvMWTEPNaLtCif5dHs\nfCfLGEClaVF1tu0rSqO1pQ8S6/edCspkSQH0iQh6gD/F6mKjwjSAA0/PLxtPYPis\nz+X2g0QetDiyWzhJBw6V+9E5oRhq+aicQKTEsaRFP9A+dHIHkYakqfbiNIaRYYFp\nGOyXjvFi+c7lJrNCEyXtH0pMdTrmL1zsYSvw4NlDtdw6QBHK2N18cmZkdYKgRBms\n0TP2UKZw11WUxMaQPfQ3u46XlUzQJMRO1YDoLsVAXf33hl8iEjqo6rO5HpVRKT+r\njIOKuFaLJyr5AJ94AItwGq4BfJJOkfEo6momE8tJsX04O/hW3BWVKVG8QMLDcwID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMTMubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0xMy5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUxX3vj2H37MihBerj734SQJqS4LUwDQYJKoZIhvcNAQEFBQADggEB\nAJDaZCNDvYQS9YHULOb2gdRVwGUa2FvZX/UNXpVMfuQD7zS+2XA43kwu+sA+Z8zi\n4er1FcMqLznERGYuOwGM10We4Ym319GOPKx8j0T7gnZS2AvgxLzKW9rDNdwpS24d\naw9k/k8UKy20hfU8Jm1l/cx3rGefd4eucsVwd9Y3wB/Pm0DFjX7yQy+EKHymvy3n\nsi86rS+U2UG300QsYxRhE5JMgP/Od+yOuN0VVyko/j7d8yen22f+1mibrNAVksDC\nIPl4TnqugllClkqYMTdsv3PGbm44zu6DUTTzL4qo/SiXGmxNs9mKCrrIKqdlgN22\nzbxHPKCXMByJo3rJ0WuyUqY="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-13.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://aai-logon.switch.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41 44 268 1505"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@switch.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SWITCHaai"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41 44 268 1505"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@switch.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SWITCHaai"
          }
        }
      ],
      "entity_id": "https://aai-logon.switch.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2016-04-13T08:38:05Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAIHilzMu/j8KMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE2FhaS1sb2dvbi5zd2l0Y2guY2gwHhcNMTMxMjAyMTUxNzI5WhcNMTYxMjAx\nMTUxNzI5WjAeMRwwGgYDVQQDExNhYWktbG9nb24uc3dpdGNoLmNoMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA72Gf8Be0k33Ucdk6+m/wpe70eZdL8n9Q\nDk4AuJ7uLFqo9vfJFRpEDbfGAt2s9esAfxX0harLVhEP7bX4HQxDt7uM9PeDXZ3M\nGGiKL4hCNR4RKY1pfx7PoLDHthiO5vVgQzlBAis3R24kL1omDGcHaxuazC5esJ5W\ncW3utZiVvmuLyysAuRupkMsLe2Cy4nEYA3IKVjqJskTACOyBhrv1TjJyVHgUPfqk\nacqMwIHL9fVmLpJwvNHd43btsx4RWtyTMeHxN4N09LnhUP7xlJZeFTgCW02Aqz8J\nHMzqwDJLBmSo7S3tQDUcoID8wXjjC0FH2WcrAi+A6mIaSwweXPXI1wIDAQABo20w\nazBKBgNVHREEQzBBghNhYWktbG9nb24uc3dpdGNoLmNohipodHRwczovL2FhaS1s\nb2dvbi5zd2l0Y2guY2gvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFKCIdiqWvBra\nkKosFDkwV2lqXHPPMA0GCSqGSIb3DQEBBQUAA4IBAQCebaL+8PbVVbIpGsr+ZwvG\n06XdJYWW6adQiOy110041UBodrjqi40rsqfJjhysrNxW9eCyVhJ8tq7Q/QUI6KHJ\niOOciw+p2c2KNI1nq54Nebjkal+hTbUvS8N7HTMvhYdu7gqqDgnvgP7s3iFAXI5b\nqyPh4TWKXlb45GinyZ3T8OjB6UsHAmhn1hRFuwOa27csxu1qPvFhTgEgbXieo2Nr\nvmIdMu967nRbVMztmAfd7Vv0eMj+YoKuA/RUWqJI6lMjHVpkl2ggE/Kb8mXX/wX1\npSfkm5o6j1ysHdGdoojvd+BikyPR7hGEs1lukWxump98WxdIHzmo5ErBr770nWRR"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "switch.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-logon.switch.ch/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-logon.switch.ch/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aai-logon.switch.ch/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai-logon.switch.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai-logon.switch.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-logon.switch.ch/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-logon.switch.ch/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "switch.ch"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.switch.ch/about/"
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.switch.ch/de/about/"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.switch.ch/fr/about/"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.switch.ch/it/about/"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SWITCH erbringt innovative, einzigartige Internet-Dienstleistungen f\u00fcr die Schweizer Hochschulen und Internetbenutzer."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SWITCH provides innovative, unique internet services for the Swiss universities and internet users."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SWITCH fournit des prestations innovantes et uniques pour les hautes \u00e9coles suisses et les utilisateurs d'Internet."
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SWITCH eroga servizi Internet innovativi e unici per le scuole universitarie svizzere e per gli utenti di Internet."
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SWITCH"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SWITCH"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SWITCH"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SWITCH"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "switch.ch"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.37333,8.53111"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.59.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:620::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "error_url": "http://www.switch.ch/aai/contact/",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAIHilzMu/j8KMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE2FhaS1sb2dvbi5zd2l0Y2guY2gwHhcNMTMxMjAyMTUxNzI5WhcNMTYxMjAx\nMTUxNzI5WjAeMRwwGgYDVQQDExNhYWktbG9nb24uc3dpdGNoLmNoMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA72Gf8Be0k33Ucdk6+m/wpe70eZdL8n9Q\nDk4AuJ7uLFqo9vfJFRpEDbfGAt2s9esAfxX0harLVhEP7bX4HQxDt7uM9PeDXZ3M\nGGiKL4hCNR4RKY1pfx7PoLDHthiO5vVgQzlBAis3R24kL1omDGcHaxuazC5esJ5W\ncW3utZiVvmuLyysAuRupkMsLe2Cy4nEYA3IKVjqJskTACOyBhrv1TjJyVHgUPfqk\nacqMwIHL9fVmLpJwvNHd43btsx4RWtyTMeHxN4N09LnhUP7xlJZeFTgCW02Aqz8J\nHMzqwDJLBmSo7S3tQDUcoID8wXjjC0FH2WcrAi+A6mIaSwweXPXI1wIDAQABo20w\nazBKBgNVHREEQzBBghNhYWktbG9nb24uc3dpdGNoLmNohipodHRwczovL2FhaS1s\nb2dvbi5zd2l0Y2guY2gvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFKCIdiqWvBra\nkKosFDkwV2lqXHPPMA0GCSqGSIb3DQEBBQUAA4IBAQCebaL+8PbVVbIpGsr+ZwvG\n06XdJYWW6adQiOy110041UBodrjqi40rsqfJjhysrNxW9eCyVhJ8tq7Q/QUI6KHJ\niOOciw+p2c2KNI1nq54Nebjkal+hTbUvS8N7HTMvhYdu7gqqDgnvgP7s3iFAXI5b\nqyPh4TWKXlb45GinyZ3T8OjB6UsHAmhn1hRFuwOa27csxu1qPvFhTgEgbXieo2Nr\nvmIdMu967nRbVMztmAfd7Vv0eMj+YoKuA/RUWqJI6lMjHVpkl2ggE/Kb8mXX/wX1\npSfkm5o6j1ysHdGdoojvd+BikyPR7hGEs1lukWxump98WxdIHzmo5ErBr770nWRR"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SWITCH"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SWITCH"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SWITCH"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SWITCH"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.switch.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.switch.ch/"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.switch.ch/"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.switch.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "switch.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://vm-shibboleth.umb.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "leonard.kroll@umb.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "leonard kroll"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://vm-shibboleth.umb.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://vm-shibboleth.umb.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vm-shibboleth.umb.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFvzCCBKegAwIBAgIQXRVC/prBbahteHW9QGc2kDANBgkqhkiG9w0BAQsFADB2\nMQswCQYDVQQGEwJVUzELMAkGA1UECBMCTUkxEjAQBgNVBAcTCUFubiBBcmJvcjES\nMBAGA1UEChMJSW50ZXJuZXQyMREwDwYDVQQLEwhJbkNvbW1vbjEfMB0GA1UEAxMW\nSW5Db21tb24gUlNBIFNlcnZlciBDQTAeFw0xNDEwMDkwMDAwMDBaFw0xNzEwMDgy\nMzU5NTlaMIHzMQswCQYDVQQGEwJVUzEOMAwGA1UEERMFMDIxMjUxCzAJBgNVBAgT\nAk1BMQ8wDQYDVQQHEwZCb3N0b24xIDAeBgNVBAkTFzEwMCBNb3JyaXNzZXkgQm91\nbGV2YXJkMSswKQYDVQQKEyJVbml2ZXJzaXR5IG9mIE1hc3NhY2h1c2V0dHMgQm9z\ndG9uMTEwLwYDVQQLEyhJbmZvcm1hdGlvbiBUZWNobm9sb2d5IFNlcnZpY2VzIERp\ndmlzaW9uMRQwEgYDVQQLEwtQbGF0aW51bVNTTDEeMBwGA1UEAxMVdm0tc2hpYmJv\nbGV0aC51bWIuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA8PtK\n5CDTHI0ioAT7fB2d+DIWJCdDjy0lcbQPT70SeH6AKUISJTtg02aCl/+a02ZWWUus\nSrbgEsiDPCv07h4U4NLL21f+pITLISK8Q5VQDGISIqsh2oyZzvvUpi1LnCPU8tos\nFVl21Zw/k/cbl/jfG/JEYb73m7oQ6srem04GsSmbfFZJq6GTam92Bg1yxuKmhqyM\nXOcJFJXvZUBmXNyRyvT6VrESNHV9m3hFEgrL+TaL2UXBcBIYDV3hqFik9kqBkoj9\nV7rbLSdXC7s9g0NLSpPmYqE4oTWqt1RgAgxEVRXD+nuwplknPxVLCP6vRXJhWt7p\n74VOu64RgDjCI9YEqwIDAQABo4IByTCCAcUwHwYDVR0jBBgwFoAUHgWjd49sluJb\nh0umtIascQAM5zgwHQYDVR0OBBYEFMF8qgtbkD420iv5Khmt8sCcX/FpMA4GA1Ud\nDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggr\nBgEFBQcDAjBnBgNVHSAEYDBeMFIGDCsGAQQBriMBBAMBATBCMEAGCCsGAQUFBwIB\nFjRodHRwczovL3d3dy5pbmNvbW1vbi5vcmcvY2VydC9yZXBvc2l0b3J5L2Nwc19z\nc2wucGRmMAgGBmeBDAECAjBEBgNVHR8EPTA7MDmgN6A1hjNodHRwOi8vY3JsLmlu\nY29tbW9uLXJzYS5vcmcvSW5Db21tb25SU0FTZXJ2ZXJDQS5jcmwwdQYIKwYBBQUH\nAQEEaTBnMD4GCCsGAQUFBzAChjJodHRwOi8vY3J0LnVzZXJ0cnVzdC5jb20vSW5D\nb21tb25SU0FTZXJ2ZXJDQV8yLmNydDAlBggrBgEFBQcwAYYZaHR0cDovL29jc3Au\ndXNlcnRydXN0LmNvbTAgBgNVHREEGTAXghV2bS1zaGliYm9sZXRoLnVtYi5lZHUw\nDQYJKoZIhvcNAQELBQADggEBAHqEHQ84nWUbB4uaYHl8GdD+VSbQcl8j4uVC60Dz\nxK2OOVE44bOBiGi4D4qTCGx5zIyu9GR0zqJNWsqb7fDssXvLDtCJujgOeg8sC1+R\nHtJWIZDdRewvv3CjsvC8HEMOCF/ccGj6DN5GgnyQ0K8a/MjldjomVWJ7mgB3p0Hw\n4cmV4DN5nJVHx588Zcy6lbRS2PmsZ+l7F80UB1s78p4Uzbu+TVsu7Wm2H7MyV7VD\nh5hVfhvFBc3oaiIZO4BFagetIk+nb7HBj5Av0BmZUMY24RJk7kaNUspVfnr7cl7S\nS+Nii5H5ZBvs91SaKPTriRVVu4CleuRbdvYmjRbWVhQvnJk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE7jCCA9agAwIBAgIJAI//ogStsrTSMA0GCSqGSIb3DQEBBQUAMIGqMQswCQYD\nVQQGEwJVUzEWMBQGA1UECBMNTWFzc2FjaHVzZXR0czEPMA0GA1UEBxMGQm9zdG9u\nMR4wHAYDVQQKExVVbml2IG9mIE1hc3NhY2h1c2V0dHMxDDAKBgNVBAsTA0NJUzEe\nMBwGA1UEAxMVdm0tc2hpYmJvbGV0aC51bWIuZWR1MSQwIgYJKoZIhvcNAQkBFhVs\nZW9uYXJkLmtyb2xsQHVtYi5lZHUwHhcNMTQxMTA1MTgxMjQ0WhcNMzQxMTA1MTgx\nMjQ0WjCBqjELMAkGA1UEBhMCVVMxFjAUBgNVBAgTDU1hc3NhY2h1c2V0dHMxDzAN\nBgNVBAcTBkJvc3RvbjEeMBwGA1UEChMVVW5pdiBvZiBNYXNzYWNodXNldHRzMQww\nCgYDVQQLEwNDSVMxHjAcBgNVBAMTFXZtLXNoaWJib2xldGgudW1iLmVkdTEkMCIG\nCSqGSIb3DQEJARYVbGVvbmFyZC5rcm9sbEB1bWIuZWR1MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAsaRwhU0fHSeE+Gawxbz5baJa14bejtdSWbJFi3JI\n56UehHePSOCZd1sdj6vsYVW57fId1IigxET38o6MBF70vrHCZbjNTDajhOH69uqR\nM+JLNowpZzfmmU/Ekz1qlWc96u2HyELks03FM9nCV4WtuDnOHDbAkOBAe16MgYfh\nSnHcY6oJ/Qf/fj6QIlF9wh5OFCoP7LfhQv262OkejDTfPm5WHLakIcq4HvHAuIqF\ngFXeQSdR/YYymxAup058rM7JGKrHKHnfk4tVvMhtBDvEggGVOgNXpyCWRheUbdKQ\nym1eQrBKZcvzDXS7K+B8VBepebhOX1aZed12k/8aWvfhmQIDAQABo4IBEzCCAQ8w\nHQYDVR0OBBYEFJ4FmDHlI7M8ycVdK0OSE8z6J05gMIHfBgNVHSMEgdcwgdSAFJ4F\nmDHlI7M8ycVdK0OSE8z6J05goYGwpIGtMIGqMQswCQYDVQQGEwJVUzEWMBQGA1UE\nCBMNTWFzc2FjaHVzZXR0czEPMA0GA1UEBxMGQm9zdG9uMR4wHAYDVQQKExVVbml2\nIG9mIE1hc3NhY2h1c2V0dHMxDDAKBgNVBAsTA0NJUzEeMBwGA1UEAxMVdm0tc2hp\nYmJvbGV0aC51bWIuZWR1MSQwIgYJKoZIhvcNAQkBFhVsZW9uYXJkLmtyb2xsQHVt\nYi5lZHWCCQCP/6IErbK00jAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IB\nAQBqSq0DCYwsrLHAAgJgl10JOxNAGd8t9zmo4Lk9PZnomXqe5VXTKRL0kKN+syqd\nhgZ/4zD7gn8qSqHxhmg3JHQkXsPTWtvRdnF6zsldrPvxNaMEGE413D8QrK2pMIrJ\nTJNhbVZzYCof/7j8cXv6rwT2VwllJ0U/lCYbZ6LrAJKw6rnj2R97kUKE2ZtzFf5N\np9Hd1O93RXm+dicsMK+dOf/T9ib36nnNu/5DfrxipBrB4tHtXj4O3BPgUBPfcJbr\nx/5ep7qDHRpz9gSjUcVeDXb6Owd/Pa31D77U9ouYegjbEUUFQIeM6ikx6zturblH\nL5ygSdWzCKrTk65VWO6vYl+x"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "umb.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://vm-shibboleth.umb.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vm-shibboleth.umb.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vm-shibboleth.umb.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://vm-shibboleth.umb.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vm-shibboleth.umb.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "umb.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.umb.edu"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Massachusetts, Boston"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Massachusetts Boston"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFvzCCBKegAwIBAgIQXRVC/prBbahteHW9QGc2kDANBgkqhkiG9w0BAQsFADB2\nMQswCQYDVQQGEwJVUzELMAkGA1UECBMCTUkxEjAQBgNVBAcTCUFubiBBcmJvcjES\nMBAGA1UEChMJSW50ZXJuZXQyMREwDwYDVQQLEwhJbkNvbW1vbjEfMB0GA1UEAxMW\nSW5Db21tb24gUlNBIFNlcnZlciBDQTAeFw0xNDEwMDkwMDAwMDBaFw0xNzEwMDgy\nMzU5NTlaMIHzMQswCQYDVQQGEwJVUzEOMAwGA1UEERMFMDIxMjUxCzAJBgNVBAgT\nAk1BMQ8wDQYDVQQHEwZCb3N0b24xIDAeBgNVBAkTFzEwMCBNb3JyaXNzZXkgQm91\nbGV2YXJkMSswKQYDVQQKEyJVbml2ZXJzaXR5IG9mIE1hc3NhY2h1c2V0dHMgQm9z\ndG9uMTEwLwYDVQQLEyhJbmZvcm1hdGlvbiBUZWNobm9sb2d5IFNlcnZpY2VzIERp\ndmlzaW9uMRQwEgYDVQQLEwtQbGF0aW51bVNTTDEeMBwGA1UEAxMVdm0tc2hpYmJv\nbGV0aC51bWIuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA8PtK\n5CDTHI0ioAT7fB2d+DIWJCdDjy0lcbQPT70SeH6AKUISJTtg02aCl/+a02ZWWUus\nSrbgEsiDPCv07h4U4NLL21f+pITLISK8Q5VQDGISIqsh2oyZzvvUpi1LnCPU8tos\nFVl21Zw/k/cbl/jfG/JEYb73m7oQ6srem04GsSmbfFZJq6GTam92Bg1yxuKmhqyM\nXOcJFJXvZUBmXNyRyvT6VrESNHV9m3hFEgrL+TaL2UXBcBIYDV3hqFik9kqBkoj9\nV7rbLSdXC7s9g0NLSpPmYqE4oTWqt1RgAgxEVRXD+nuwplknPxVLCP6vRXJhWt7p\n74VOu64RgDjCI9YEqwIDAQABo4IByTCCAcUwHwYDVR0jBBgwFoAUHgWjd49sluJb\nh0umtIascQAM5zgwHQYDVR0OBBYEFMF8qgtbkD420iv5Khmt8sCcX/FpMA4GA1Ud\nDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggr\nBgEFBQcDAjBnBgNVHSAEYDBeMFIGDCsGAQQBriMBBAMBATBCMEAGCCsGAQUFBwIB\nFjRodHRwczovL3d3dy5pbmNvbW1vbi5vcmcvY2VydC9yZXBvc2l0b3J5L2Nwc19z\nc2wucGRmMAgGBmeBDAECAjBEBgNVHR8EPTA7MDmgN6A1hjNodHRwOi8vY3JsLmlu\nY29tbW9uLXJzYS5vcmcvSW5Db21tb25SU0FTZXJ2ZXJDQS5jcmwwdQYIKwYBBQUH\nAQEEaTBnMD4GCCsGAQUFBzAChjJodHRwOi8vY3J0LnVzZXJ0cnVzdC5jb20vSW5D\nb21tb25SU0FTZXJ2ZXJDQV8yLmNydDAlBggrBgEFBQcwAYYZaHR0cDovL29jc3Au\ndXNlcnRydXN0LmNvbTAgBgNVHREEGTAXghV2bS1zaGliYm9sZXRoLnVtYi5lZHUw\nDQYJKoZIhvcNAQELBQADggEBAHqEHQ84nWUbB4uaYHl8GdD+VSbQcl8j4uVC60Dz\nxK2OOVE44bOBiGi4D4qTCGx5zIyu9GR0zqJNWsqb7fDssXvLDtCJujgOeg8sC1+R\nHtJWIZDdRewvv3CjsvC8HEMOCF/ccGj6DN5GgnyQ0K8a/MjldjomVWJ7mgB3p0Hw\n4cmV4DN5nJVHx588Zcy6lbRS2PmsZ+l7F80UB1s78p4Uzbu+TVsu7Wm2H7MyV7VD\nh5hVfhvFBc3oaiIZO4BFagetIk+nb7HBj5Av0BmZUMY24RJk7kaNUspVfnr7cl7S\nS+Nii5H5ZBvs91SaKPTriRVVu4CleuRbdvYmjRbWVhQvnJk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE7jCCA9agAwIBAgIJAI//ogStsrTSMA0GCSqGSIb3DQEBBQUAMIGqMQswCQYD\nVQQGEwJVUzEWMBQGA1UECBMNTWFzc2FjaHVzZXR0czEPMA0GA1UEBxMGQm9zdG9u\nMR4wHAYDVQQKExVVbml2IG9mIE1hc3NhY2h1c2V0dHMxDDAKBgNVBAsTA0NJUzEe\nMBwGA1UEAxMVdm0tc2hpYmJvbGV0aC51bWIuZWR1MSQwIgYJKoZIhvcNAQkBFhVs\nZW9uYXJkLmtyb2xsQHVtYi5lZHUwHhcNMTQxMTA1MTgxMjQ0WhcNMzQxMTA1MTgx\nMjQ0WjCBqjELMAkGA1UEBhMCVVMxFjAUBgNVBAgTDU1hc3NhY2h1c2V0dHMxDzAN\nBgNVBAcTBkJvc3RvbjEeMBwGA1UEChMVVW5pdiBvZiBNYXNzYWNodXNldHRzMQww\nCgYDVQQLEwNDSVMxHjAcBgNVBAMTFXZtLXNoaWJib2xldGgudW1iLmVkdTEkMCIG\nCSqGSIb3DQEJARYVbGVvbmFyZC5rcm9sbEB1bWIuZWR1MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAsaRwhU0fHSeE+Gawxbz5baJa14bejtdSWbJFi3JI\n56UehHePSOCZd1sdj6vsYVW57fId1IigxET38o6MBF70vrHCZbjNTDajhOH69uqR\nM+JLNowpZzfmmU/Ekz1qlWc96u2HyELks03FM9nCV4WtuDnOHDbAkOBAe16MgYfh\nSnHcY6oJ/Qf/fj6QIlF9wh5OFCoP7LfhQv262OkejDTfPm5WHLakIcq4HvHAuIqF\ngFXeQSdR/YYymxAup058rM7JGKrHKHnfk4tVvMhtBDvEggGVOgNXpyCWRheUbdKQ\nym1eQrBKZcvzDXS7K+B8VBepebhOX1aZed12k/8aWvfhmQIDAQABo4IBEzCCAQ8w\nHQYDVR0OBBYEFJ4FmDHlI7M8ycVdK0OSE8z6J05gMIHfBgNVHSMEgdcwgdSAFJ4F\nmDHlI7M8ycVdK0OSE8z6J05goYGwpIGtMIGqMQswCQYDVQQGEwJVUzEWMBQGA1UE\nCBMNTWFzc2FjaHVzZXR0czEPMA0GA1UEBxMGQm9zdG9uMR4wHAYDVQQKExVVbml2\nIG9mIE1hc3NhY2h1c2V0dHMxDDAKBgNVBAsTA0NJUzEeMBwGA1UEAxMVdm0tc2hp\nYmJvbGV0aC51bWIuZWR1MSQwIgYJKoZIhvcNAQkBFhVsZW9uYXJkLmtyb2xsQHVt\nYi5lZHWCCQCP/6IErbK00jAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IB\nAQBqSq0DCYwsrLHAAgJgl10JOxNAGd8t9zmo4Lk9PZnomXqe5VXTKRL0kKN+syqd\nhgZ/4zD7gn8qSqHxhmg3JHQkXsPTWtvRdnF6zsldrPvxNaMEGE413D8QrK2pMIrJ\nTJNhbVZzYCof/7j8cXv6rwT2VwllJ0U/lCYbZ6LrAJKw6rnj2R97kUKE2ZtzFf5N\np9Hd1O93RXm+dicsMK+dOf/T9ib36nnNu/5DfrxipBrB4tHtXj4O3BPgUBPfcJbr\nx/5ep7qDHRpz9gSjUcVeDXb6Owd/Pa31D77U9ouYegjbEUUFQIeM6ikx6zturblH\nL5ygSdWzCKrTk65VWO6vYl+x"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Massachusetts Boston"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://umb.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Massachusetts Boston"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.shef.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Babraa"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:h.babraa@sheffield.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nomit"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Babraa"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:h.babraa@sheffield.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nomit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.shef.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2007-10-24T12:26:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFCjCCA/KgAwIBAgIUTWCw0LmBsiIH8aCwZ/lqP++FKzYwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwTTELMAkGA1UEBhMCQk0xGTAXBgNVBAoTEFF1b1ZhZGlzIExpbWl0ZWQxIzAh\n\t\t\t\t\t\tBgNVBAMTGlF1b1ZhZGlzIEdsb2JhbCBTU0wgSUNBIEcyMB4XDTE2MDQxNDA4MzEy\n\t\t\t\t\t\tNFoXDTE5MDQxNDA4MzEyMlowgYUxCzAJBgNVBAYTAkdCMRgwFgYDVQQIEw9Tb3V0\n\t\t\t\t\t\taCBZb3Jrc2hpcmUxEjAQBgNVBAcTCVNIRUZGSUVMRDEgMB4GA1UEChMXVW5pdmVy\n\t\t\t\t\t\tc2l0eSBvZiBTaGVmZmllbGQxDTALBgNVBAsTBENpQ1MxFzAVBgNVBAMTDmlkcC5z\n\t\t\t\t\t\taGVmLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArb100Czt\n\t\t\t\t\t\tpefaZRBV3yPwnnKabjTX1lkhDuDxG73wDxl9LHjOKVFNGClbS77D/dd9jMfIpp64\n\t\t\t\t\t\tZ0JPMSo8VZnwXD8kBwWUwpR/ldR968oGGJw0AAht+f1lrIb636bg0njnsuDFvV6r\n\t\t\t\t\t\t/9QAhz2RIRbGcJ2lv2Q6LT3pzs2PfzdFEXUq/4aBSAf5pgqhP+qWbvqS1o3kUUFO\n\t\t\t\t\t\tbK6Nlxz0GPhmqBVd4KhmxkdQdZzlnLa6sZhjxJ9jgH+P0d28JAzJUDQJ+73fA/Ai\n\t\t\t\t\t\tJPc/3jbaHa2pvu1xYZwDxTMNBDmJN7p/kI3azZHvVWBgC94KjfLkXT6SpdRPOJ/o\n\t\t\t\t\t\t74mQiXPFLt+KHQIDAQABo4IBpzCCAaMwcwYIKwYBBQUHAQEEZzBlMCoGCCsGAQUF\n\t\t\t\t\t\tBzABhh5odHRwOi8vb2NzcC5xdW92YWRpc2dsb2JhbC5jb20wNwYIKwYBBQUHMAKG\n\t\t\t\t\t\tK2h0dHA6Ly90cnVzdC5xdW92YWRpc2dsb2JhbC5jb20vcXZzc2xnMi5jcnQwLgYD\n\t\t\t\t\t\tVR0RBCcwJYIOaWRwLnNoZWYuYWMudWuCE2lkcC5zaGVmZmllbGQuYWMudWswUQYD\n\t\t\t\t\t\tVR0gBEowSDBGBgwrBgEEAb5YAAJkAQEwNjA0BggrBgEFBQcCARYoaHR0cDovL3d3\n\t\t\t\t\t\tdy5xdW92YWRpc2dsb2JhbC5jb20vcmVwb3NpdG9yeTAOBgNVHQ8BAf8EBAMCBaAw\n\t\t\t\t\t\tHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMB8GA1UdIwQYMBaAFJEZYq1b\n\t\t\t\t\t\tF6cw+/DeOSWxvYy5uFEnMDoGA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwucXVv\n\t\t\t\t\t\tdmFkaXNnbG9iYWwuY29tL3F2c3NsZzIuY3JsMB0GA1UdDgQWBBQWQhILCU6xgRJx\n\t\t\t\t\t\tV+C6Ej80mSR2STANBgkqhkiG9w0BAQsFAAOCAQEAXz/l6yuM+orHsuaNuJ2cu+0h\n\t\t\t\t\t\tj909Os3fEOxi2F+eTghyEXl7bOYAnPg/b+WQRyfh2OqHqA5SN2esTyrarzcIFMbC\n\t\t\t\t\t\t7EUhloTvgEV6uk1FmyNIdsf3TLOAwOaPoboJEa+Inpbqmohunaz/J16fDpmU25ow\n\t\t\t\t\t\tBDe59GBNR4k6fDSBOqzVOq92ykTmzqEKbkvrdYAfZUzzjslhQ9d+gOn4UZSDIRlr\n\t\t\t\t\t\tp0Uv8uSz9S1+hpGnKzutBJ4d5h8AbjoKjYsUFQed5nI0KQ3ea6v34JvyrZVaTMxm\n\t\t\t\t\t\tULmwAyJq1ECXaA9gz5jfeNcUUec5SHel2G9VpFacSQVv8RrNh/yeUpeIye+3Fg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEajCCA1KgAwIBAgIRAPS6MGNqr12OxPRxE0wftqswDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzA1MDcwMDAwMDBaFw0xNjA1MDYyMzU5NTlaMDwxITAfBgNV\n\t\t\t\t\t\tBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEXMBUGA1UEAxMOaWRwLnNoZWYu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCtvXTQLO2l59pl\n\t\t\t\t\t\tEFXfI/CecppuNNfWWSEO4PEbvfAPGX0seM4pUU0YKVtLvsP9132Mx8imnrhnQk8x\n\t\t\t\t\t\tKjxVmfBcPyQHBZTClH+V1H3rygYYnDQACG35/WWshvrfpuDSeOey4MW9Xqv/1ACH\n\t\t\t\t\t\tPZEhFsZwnaW/ZDotPenOzY9/N0URdSr/hoFIB/mmCqE/6pZu+pLWjeRRQU5sro2X\n\t\t\t\t\t\tHPQY+GaoFV3gqGbGR1B1nOWctrqxmGPEn2OAf4/R3bwkDMlQNAn7vd8D8CIk9z/e\n\t\t\t\t\t\tNtodram+7XFhnAPFMw0EOYk3un+QjdrNke9VYGAL3gqN8uRdPpKl1E84n+jviZCJ\n\t\t\t\t\t\tc8Uu34odAgMBAAGjggFrMIIBZzAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3V0fq\n\t\t\t\t\t\tkOO57TAdBgNVHQ4EFgQUFkISCwlOsYEScVfguhI/NJkkdkkwDgYDVR0PAQH/BAQD\n\t\t\t\t\t\tAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMC\n\t\t\t\t\t\tMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1UdHwQzMDEw\n\t\t\t\t\t\tL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3Js\n\t\t\t\t\t\tMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3MudGVy\n\t\t\t\t\t\tZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9vY3Nw\n\t\t\t\t\t\tLnRjcy50ZXJlbmEub3JnMBkGA1UdEQQSMBCCDmlkcC5zaGVmLmFjLnVrMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQBFQpg8CdAxF+fazlT/4DR43XEtbv+SzLg9H2ST1kKrJSb+\n\t\t\t\t\t\tKHNS6XFli0JcWP1BNFCA0TV/xyH0KWc/ZwYA5h052QHS5kOK88IjUNwW4wluqajT\n\t\t\t\t\t\tc1jByBc/bV1nVQBrKd7uLeqlEGlYySnx2kwu043nEGsP0/TDCAvdTQ9jqXCSuepg\n\t\t\t\t\t\t+IS/jkPCQF+/BvmXNOwLei4mUI2EqVnzIqDq3tA8CLxhRKv4qq1bQqicPMwwP0GV\n\t\t\t\t\t\tcrp7O+zg6I/K55qVp75ePh7jHf32AfqRKN0BhQlYoogsT5noMUDNwhRpqv9/h2MH\n\t\t\t\t\t\tPyWz043AlJssKremO7+1g998b2MkkVpiHa74usy0"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sheffield.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.shef.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.shef.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.shef.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.shef.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.shef.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.shef.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.shef.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.shef.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sheffield.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFCjCCA/KgAwIBAgIUTWCw0LmBsiIH8aCwZ/lqP++FKzYwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwTTELMAkGA1UEBhMCQk0xGTAXBgNVBAoTEFF1b1ZhZGlzIExpbWl0ZWQxIzAh\n\t\t\t\t\t\tBgNVBAMTGlF1b1ZhZGlzIEdsb2JhbCBTU0wgSUNBIEcyMB4XDTE2MDQxNDA4MzEy\n\t\t\t\t\t\tNFoXDTE5MDQxNDA4MzEyMlowgYUxCzAJBgNVBAYTAkdCMRgwFgYDVQQIEw9Tb3V0\n\t\t\t\t\t\taCBZb3Jrc2hpcmUxEjAQBgNVBAcTCVNIRUZGSUVMRDEgMB4GA1UEChMXVW5pdmVy\n\t\t\t\t\t\tc2l0eSBvZiBTaGVmZmllbGQxDTALBgNVBAsTBENpQ1MxFzAVBgNVBAMTDmlkcC5z\n\t\t\t\t\t\taGVmLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArb100Czt\n\t\t\t\t\t\tpefaZRBV3yPwnnKabjTX1lkhDuDxG73wDxl9LHjOKVFNGClbS77D/dd9jMfIpp64\n\t\t\t\t\t\tZ0JPMSo8VZnwXD8kBwWUwpR/ldR968oGGJw0AAht+f1lrIb636bg0njnsuDFvV6r\n\t\t\t\t\t\t/9QAhz2RIRbGcJ2lv2Q6LT3pzs2PfzdFEXUq/4aBSAf5pgqhP+qWbvqS1o3kUUFO\n\t\t\t\t\t\tbK6Nlxz0GPhmqBVd4KhmxkdQdZzlnLa6sZhjxJ9jgH+P0d28JAzJUDQJ+73fA/Ai\n\t\t\t\t\t\tJPc/3jbaHa2pvu1xYZwDxTMNBDmJN7p/kI3azZHvVWBgC94KjfLkXT6SpdRPOJ/o\n\t\t\t\t\t\t74mQiXPFLt+KHQIDAQABo4IBpzCCAaMwcwYIKwYBBQUHAQEEZzBlMCoGCCsGAQUF\n\t\t\t\t\t\tBzABhh5odHRwOi8vb2NzcC5xdW92YWRpc2dsb2JhbC5jb20wNwYIKwYBBQUHMAKG\n\t\t\t\t\t\tK2h0dHA6Ly90cnVzdC5xdW92YWRpc2dsb2JhbC5jb20vcXZzc2xnMi5jcnQwLgYD\n\t\t\t\t\t\tVR0RBCcwJYIOaWRwLnNoZWYuYWMudWuCE2lkcC5zaGVmZmllbGQuYWMudWswUQYD\n\t\t\t\t\t\tVR0gBEowSDBGBgwrBgEEAb5YAAJkAQEwNjA0BggrBgEFBQcCARYoaHR0cDovL3d3\n\t\t\t\t\t\tdy5xdW92YWRpc2dsb2JhbC5jb20vcmVwb3NpdG9yeTAOBgNVHQ8BAf8EBAMCBaAw\n\t\t\t\t\t\tHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMB8GA1UdIwQYMBaAFJEZYq1b\n\t\t\t\t\t\tF6cw+/DeOSWxvYy5uFEnMDoGA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwucXVv\n\t\t\t\t\t\tdmFkaXNnbG9iYWwuY29tL3F2c3NsZzIuY3JsMB0GA1UdDgQWBBQWQhILCU6xgRJx\n\t\t\t\t\t\tV+C6Ej80mSR2STANBgkqhkiG9w0BAQsFAAOCAQEAXz/l6yuM+orHsuaNuJ2cu+0h\n\t\t\t\t\t\tj909Os3fEOxi2F+eTghyEXl7bOYAnPg/b+WQRyfh2OqHqA5SN2esTyrarzcIFMbC\n\t\t\t\t\t\t7EUhloTvgEV6uk1FmyNIdsf3TLOAwOaPoboJEa+Inpbqmohunaz/J16fDpmU25ow\n\t\t\t\t\t\tBDe59GBNR4k6fDSBOqzVOq92ykTmzqEKbkvrdYAfZUzzjslhQ9d+gOn4UZSDIRlr\n\t\t\t\t\t\tp0Uv8uSz9S1+hpGnKzutBJ4d5h8AbjoKjYsUFQed5nI0KQ3ea6v34JvyrZVaTMxm\n\t\t\t\t\t\tULmwAyJq1ECXaA9gz5jfeNcUUec5SHel2G9VpFacSQVv8RrNh/yeUpeIye+3Fg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEajCCA1KgAwIBAgIRAPS6MGNqr12OxPRxE0wftqswDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzA1MDcwMDAwMDBaFw0xNjA1MDYyMzU5NTlaMDwxITAfBgNV\n\t\t\t\t\t\tBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEXMBUGA1UEAxMOaWRwLnNoZWYu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCtvXTQLO2l59pl\n\t\t\t\t\t\tEFXfI/CecppuNNfWWSEO4PEbvfAPGX0seM4pUU0YKVtLvsP9132Mx8imnrhnQk8x\n\t\t\t\t\t\tKjxVmfBcPyQHBZTClH+V1H3rygYYnDQACG35/WWshvrfpuDSeOey4MW9Xqv/1ACH\n\t\t\t\t\t\tPZEhFsZwnaW/ZDotPenOzY9/N0URdSr/hoFIB/mmCqE/6pZu+pLWjeRRQU5sro2X\n\t\t\t\t\t\tHPQY+GaoFV3gqGbGR1B1nOWctrqxmGPEn2OAf4/R3bwkDMlQNAn7vd8D8CIk9z/e\n\t\t\t\t\t\tNtodram+7XFhnAPFMw0EOYk3un+QjdrNke9VYGAL3gqN8uRdPpKl1E84n+jviZCJ\n\t\t\t\t\t\tc8Uu34odAgMBAAGjggFrMIIBZzAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3V0fq\n\t\t\t\t\t\tkOO57TAdBgNVHQ4EFgQUFkISCwlOsYEScVfguhI/NJkkdkkwDgYDVR0PAQH/BAQD\n\t\t\t\t\t\tAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMC\n\t\t\t\t\t\tMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1UdHwQzMDEw\n\t\t\t\t\t\tL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3Js\n\t\t\t\t\t\tMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3MudGVy\n\t\t\t\t\t\tZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9vY3Nw\n\t\t\t\t\t\tLnRjcy50ZXJlbmEub3JnMBkGA1UdEQQSMBCCDmlkcC5zaGVmLmFjLnVrMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQBFQpg8CdAxF+fazlT/4DR43XEtbv+SzLg9H2ST1kKrJSb+\n\t\t\t\t\t\tKHNS6XFli0JcWP1BNFCA0TV/xyH0KWc/ZwYA5h052QHS5kOK88IjUNwW4wluqajT\n\t\t\t\t\t\tc1jByBc/bV1nVQBrKd7uLeqlEGlYySnx2kwu043nEGsP0/TDCAvdTQ9jqXCSuepg\n\t\t\t\t\t\t+IS/jkPCQF+/BvmXNOwLei4mUI2EqVnzIqDq3tA8CLxhRKv4qq1bQqicPMwwP0GV\n\t\t\t\t\t\tcrp7O+zg6I/K55qVp75ePh7jHf32AfqRKN0BhQlYoogsT5noMUDNwhRpqv9/h2MH\n\t\t\t\t\t\tPyWz043AlJssKremO7+1g998b2MkkVpiHa74usy0"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Sheffield"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.shef.ac.uk/cics/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Sheffield"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.refworks.com/shibboleth/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@proquest.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Joshi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Sanjay.Joshi@proquest.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sanjay"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.refworks.com/shibboleth/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-07-29T14:31:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RefWorks"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.refworks.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Proquest Information and Learning Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.refworks.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.refworks.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.refworks.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.refworks.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.refworks.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEQjCCAyqgAwIBAgIJAPi0oqIBy55FMA0GCSqGSIb3DQEBBQUAMIGhMQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzERMA8GA1UECBMITWFyeWxhbmQxETAPBgNVBAcTCEJldGhlc2RhMRUw\n\t\t\t\t\t\tEwYDVQQKEwxQcm9RdWVzdCBMTEMxFTATBgNVBAsTDFJlZldvcmtzL0NPUzEZMBcG\n\t\t\t\t\t\tA1UEAxMQd3d3LnJlZndvcmtzLmNvbTEjMCEGCSqGSIb3DQEJARYUbmtlbm5leUBy\n\t\t\t\t\t\tZWZ3b3Jrcy5jb20wHhcNMDgxMjE1MjIwMzA1WhcNMTgxMjEzMjIwMzA1WjCBoTEL\n\t\t\t\t\t\tMAkGA1UEBhMCVVMxETAPBgNVBAgTCE1hcnlsYW5kMREwDwYDVQQHEwhCZXRoZXNk\n\t\t\t\t\t\tYTEVMBMGA1UEChMMUHJvUXVlc3QgTExDMRUwEwYDVQQLEwxSZWZXb3Jrcy9DT1Mx\n\t\t\t\t\t\tGTAXBgNVBAMTEHd3dy5yZWZ3b3Jrcy5jb20xIzAhBgkqhkiG9w0BCQEWFG5rZW5u\n\t\t\t\t\t\tZXlAcmVmd29ya3MuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\t0BNHVpHg+SvSXBH7Z9XWTpiRLEWISoqsL6N1hR7DaJeM7lqIkH3OuL9g1q76/75v\n\t\t\t\t\t\t3zrV0QqSF1xj7rM1Lq5ZJd8O2mLdlWHZvdYSmJQNu5hrnOcqv5eDuc2GsXaaI7FE\n\t\t\t\t\t\t+ipw4xamo8ei3wm0BP3hCHGRS71iwk3lwVteSfWDpGxPBNTR1szx0tazTH2gwkmN\n\t\t\t\t\t\tTxlcxkim+tgdH4etIyCSgweRvb/9jG6y/nRvBB2j7CykzfM2E2tkA63cfax+P5Wd\n\t\t\t\t\t\tCrk7CCcgNrIcWr9dmP5wyerwbW1u9wZJOJYAhZDEY497h1bRxXJcwT+P1ZhYTJdk\n\t\t\t\t\t\tVCbAFSgxsNwOEtVGIJ7JNwIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIB\n\t\t\t\t\t\tDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUqaa3\n\t\t\t\t\t\ta9bD274+w6y7JHvNGkoZRs4wHwYDVR0jBBgwFoAUqaa3a9bD274+w6y7JHvNGkoZ\n\t\t\t\t\t\tRs4wDQYJKoZIhvcNAQEFBQADggEBAHjTPGg2GmOXGh0cboOOkFYXtXZmk3wXePyr\n\t\t\t\t\t\tFa8OHe5CqEhZhcidRq1IrPt/QDF76KofX43SnpJ24Hha1RuXDKQu5vV387TwUTdl\n\t\t\t\t\t\tufWJrWpAZybWZ55OMpG1crHbuozEFW+GGJ34s4e6fygeIcLTigkN6rf5WkbLBVyX\n\t\t\t\t\t\t6qqB4GNdfqj+18xbVaM7yWMk0ShlBzFMl15DO25zoAh+l/J3Ti1vDbbusjE27H7D\n\t\t\t\t\t\t207Q3sTfK+tvRQVkFrLeYce9IOUYgMS7f4drQAR/6pAnSXmMLzAFc5s896/iGDEX\n\t\t\t\t\t\tafJHv7LMPbJAn4/aPxZ+VDE8GBrYzc8sOy5DZzjvZ6uvw8VGMEI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.refworks.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.refworks.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.refworks.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.refworks.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.refworks.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.refworks.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.refworks.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.refworks.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.refworks.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.refworks.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.c2kqa.net/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Boyle"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:joe.boyle@capita.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Joe"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Boyle"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:joe.boyle@capita.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Joe"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.c2kqa.net/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-06-08T12:31:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUOmrWnoGvFDkaJ0RFpEBraZk80cMwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAxMUc2hpYmJvbGV0aC5jMmtxYS5uZXQwHhcNMTAwNjIzMTAy\n\t\t\t\t\t\tOTA0WhcNMzAwNjIzMTAyOTA0WjAfMR0wGwYDVQQDExRzaGliYm9sZXRoLmMya3Fh\n\t\t\t\t\t\tLm5ldDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJAaXKjkiDo2I09Y\n\t\t\t\t\t\tlpyzrWyIg2MrK0AKi5dIi5Svue8pv9XXCwhlBaFqvPZgmI6isdCUzOXAh0lV/XzY\n\t\t\t\t\t\tOEvvQsBVoEeebWpWm7pPOS8rtGYuUvwFPkdi6MyXsVw7Ei+d70rFeKJijNbhnMkg\n\t\t\t\t\t\toMRk/pRTPROQCffl4SqmFAqb2vn+L4XbXcXdcT/bhaxitbjalTffvx3PrGhco/D1\n\t\t\t\t\t\twjWxoR9kY8Q6t9K9/8hnZU3xlUUqy5Viq5fCacu7zv9frhZ1O85p6F/NZSwnKQq0\n\t\t\t\t\t\twZrbDDBGwXHVh4IMIwVLTaCmB7gNUWTfo0dOPKjakUMNaIEsyDt6KNRe0CGslv3J\n\t\t\t\t\t\teVzKMJcCAwEAAaNvMG0wTAYDVR0RBEUwQ4IUc2hpYmJvbGV0aC5jMmtxYS5uZXSG\n\t\t\t\t\t\tK2h0dHBzOi8vc2hpYmJvbGV0aC5jMmtxYS5uZXQvaWRwL3NoaWJib2xldGgwHQYD\n\t\t\t\t\t\tVR0OBBYEFOA3DMt6qji7fUywGEUlp+SNCqGGMA0GCSqGSIb3DQEBBQUAA4IBAQBj\n\t\t\t\t\t\tCI4GK5AcY+NYY3twlyOt4BTjECTWTndFbctqKM1eLgNOrucaKchRGoqZUs5TOjpM\n\t\t\t\t\t\tDWTD6sROH1SSmPb+igQeR7H1hLBsVCHt25WCNfaSlw9v4s1+6H78iugY30bdP00/\n\t\t\t\t\t\twx1YQ8oQAT/f0u0QyNCmwHrFc3Z0KL7Ep/Ja8Dv2BfKXZ2D1epNins1ehZeMbEbT\n\t\t\t\t\t\t/FYibzNtKmBDmCiTF20Bglf6nJySn8cN31z+VlHQNZxyCz/vae4TfgOktsDN7AOL\n\t\t\t\t\t\tq3KitZrzJZ0KGE9R1nnKSuW86fm+eLp6ai0jhUZP9NV+uUb/O4wRuJP8JTec0tjd\n\t\t\t\t\t\tDE3ljx9HJYZ7RbLYPnxd"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "c2kqa.net"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.c2kqa.net:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.c2kqa.net:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.c2kqa.net/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.c2kqa.net/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.c2kqa.net/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.c2kqa.net/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.c2kqa.net:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.c2kqa.net:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "c2kqa.net"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUOmrWnoGvFDkaJ0RFpEBraZk80cMwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAxMUc2hpYmJvbGV0aC5jMmtxYS5uZXQwHhcNMTAwNjIzMTAy\n\t\t\t\t\t\tOTA0WhcNMzAwNjIzMTAyOTA0WjAfMR0wGwYDVQQDExRzaGliYm9sZXRoLmMya3Fh\n\t\t\t\t\t\tLm5ldDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJAaXKjkiDo2I09Y\n\t\t\t\t\t\tlpyzrWyIg2MrK0AKi5dIi5Svue8pv9XXCwhlBaFqvPZgmI6isdCUzOXAh0lV/XzY\n\t\t\t\t\t\tOEvvQsBVoEeebWpWm7pPOS8rtGYuUvwFPkdi6MyXsVw7Ei+d70rFeKJijNbhnMkg\n\t\t\t\t\t\toMRk/pRTPROQCffl4SqmFAqb2vn+L4XbXcXdcT/bhaxitbjalTffvx3PrGhco/D1\n\t\t\t\t\t\twjWxoR9kY8Q6t9K9/8hnZU3xlUUqy5Viq5fCacu7zv9frhZ1O85p6F/NZSwnKQq0\n\t\t\t\t\t\twZrbDDBGwXHVh4IMIwVLTaCmB7gNUWTfo0dOPKjakUMNaIEsyDt6KNRe0CGslv3J\n\t\t\t\t\t\teVzKMJcCAwEAAaNvMG0wTAYDVR0RBEUwQ4IUc2hpYmJvbGV0aC5jMmtxYS5uZXSG\n\t\t\t\t\t\tK2h0dHBzOi8vc2hpYmJvbGV0aC5jMmtxYS5uZXQvaWRwL3NoaWJib2xldGgwHQYD\n\t\t\t\t\t\tVR0OBBYEFOA3DMt6qji7fUywGEUlp+SNCqGGMA0GCSqGSIb3DQEBBQUAA4IBAQBj\n\t\t\t\t\t\tCI4GK5AcY+NYY3twlyOt4BTjECTWTndFbctqKM1eLgNOrucaKchRGoqZUs5TOjpM\n\t\t\t\t\t\tDWTD6sROH1SSmPb+igQeR7H1hLBsVCHt25WCNfaSlw9v4s1+6H78iugY30bdP00/\n\t\t\t\t\t\twx1YQ8oQAT/f0u0QyNCmwHrFc3Z0KL7Ep/Ja8Dv2BfKXZ2D1epNins1ehZeMbEbT\n\t\t\t\t\t\t/FYibzNtKmBDmCiTF20Bglf6nJySn8cN31z+VlHQNZxyCz/vae4TfgOktsDN7AOL\n\t\t\t\t\t\tq3KitZrzJZ0KGE9R1nnKSuW86fm+eLp6ai0jhUZP9NV+uUb/O4wRuJP8JTec0tjd\n\t\t\t\t\t\tDE3ljx9HJYZ7RbLYPnxd"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "C2k"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.c2kni.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Western Education and Library Board"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idpshibboleth.irf.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+4698079000"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mats Luspa"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:datagruppen@irf.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Swedish Institute of Space Physics"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+4698079022"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mats Luspa"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:matsl@irf.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Swedish Institute of Space Physics"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+4698079022"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mats Luspa"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:matsl@irf.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Swedish Institute of Space Physics"
          }
        }
      ],
      "entity_id": "https://idpshibboleth.irf.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idpshibboleth.irf.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idpshibboleth.irf.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idpshibboleth.irf.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idpshibboleth.irf.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idpshibboleth.irf.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "irf.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.irf.se"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institutet f\u00f6r rymdfysik"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Swedish Institute of Space Physics"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r Institutet f\u00f6r rymdfysik"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for the Swedish Institute of Space Physics"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.irf.se/image/IRF_logo.png",
                    "height": "145",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "144"
                  },
                  {
                    "text": "https://www.irf.se/image/IRF_logo.png",
                    "lang": "sv",
                    "height": "145",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "144"
                  },
                  {
                    "text": "https://www.irf.se/image/IRF_logo.png",
                    "lang": "en",
                    "height": "145",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "144"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://documents.irf.se/get_document.php?group=Computer%26docid=302"
                  }
                ]
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "irf.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:67.84,20.41"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.71.13.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.33.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.71.152.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUA93wi+Avn0weW0JMfqJ3DxZWLjgwDQYJKoZIhvcNAQEL\nBQAwHzEdMBsGA1UEAwwUaWRwc2hpYmJvbGV0aC5pcmYuc2UwHhcNMTYwMjA4MTIy\nMDMzWhcNMzYwMjA4MTIyMDMzWjAfMR0wGwYDVQQDDBRpZHBzaGliYm9sZXRoLmly\nZi5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMRf6rttUT2iQB/z\nkEiVH7YzON4WB92Y/UmnD3WiN8fjkvbZEMLj3ESWP/ldqVIutldlksAPFTf7xhRm\nwMtOJQmf7WvXY0IR+d/zxNOTH8raeYDmlcaeNAcEjmLNCwgZv51Ow2kq0piAN5EK\n35RuV0khqm79R7hc11Gx30ZMxcuV+7sAm6T2ojFx6F/lsj6sQxrTD/uqBY28hVBy\nm58srJDeWiE5VbUmiQaEAnMXr5oFrCK9/UDDFFEX/Y25UOgQIHnUa/G43jVvPIV4\nNYT8wUkuijo5jkXb72eRq3Fqg0T1Ou8uVTYvTMvRNeAVUqKsFgOpbqWPT6kh27/1\ntOGRsycCAwEAAaNvMG0wHQYDVR0OBBYEFBuWdnt63xXR5ZTkEG0YaoTUVQUtMEwG\nA1UdEQRFMEOCFGlkcHNoaWJib2xldGguaXJmLnNlhitodHRwczovL2lkcHNoaWJi\nb2xldGguaXJmLnNlL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQAG\nZCuTZpgSP69Qgz3JHPPcqi7+PF893zb5omDPf0AdWC+CrLGdYEOpOrODQ7gC2t/3\n318o0vjj4hyShPO3DczMPMKH0DoI7PvS8pJ9dR3vSsc9i04z9nMEOVg3+ofPRWR3\niDPll7XTALQNSwen7/Q1TxQQS/PFUGbgxSt+Hk9woU5QMlbvsiqM813JsVS7vxgA\nAJ1MDeT4luzSG1Vc/bfH8RkaDI+lhR0FZe0xmhYaS2nG7kyEn0lBYjbevE1ZpaRe\nwrDZBcvSQ6jJw91F/CHHutF2nzaZuALlK9/3azDGx5LbUFCIxvmeM4Gmz8csx8rz\n4okhyqwoeyl2XUl1z+PB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAKNIMRVddJl8Eq2nzLvhFamfj39qMA0GCSqGSIb3DQEB\nCwUAMB8xHTAbBgNVBAMMFGlkcHNoaWJib2xldGguaXJmLnNlMB4XDTE2MDIwODEy\nMjAzMloXDTM2MDIwODEyMjAzMlowHzEdMBsGA1UEAwwUaWRwc2hpYmJvbGV0aC5p\ncmYuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCa/mHPOa5/M9Ur\nINayTyL9eTIYmYet2QHaVICODn20KBzRBIVrm0n33Z3N6bZ2qqi4yJ48qQsJnJWi\n951yN0CUXVEGWgJIb0ERQrnKHw63d/JBqmp1ImYBWom97Upzdiy0eXwkASzD3ztl\n6ri3+SqZmltEXc9bIEavVcFUTPqU68aP8AtoiRzTxjGfwWBcsDri+ZkN76t1mt/Y\nepWvt/EPEX6Xp1/1qAiyZO6ja8zcksfKn70u6fPgCYHXxqJ0pEwRwReT8PbuQmyl\nvHhncs/EXqTiNlfcpK67ydigQ84Cp1f1qf8snYZPuIUfUbuFrTUnoKjGP1qiaxJo\nl/qaSqz5AgMBAAGjbzBtMB0GA1UdDgQWBBSYP4tgO7b03F98vWe6ZEbQkqbzETBM\nBgNVHREERTBDghRpZHBzaGliYm9sZXRoLmlyZi5zZYYraHR0cHM6Ly9pZHBzaGli\nYm9sZXRoLmlyZi5zZS9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEA\nb0dwwUW0J0ZTdbZeehpoOQGB71sc3ZwdBxkmlFqr+xJqjT/shX3yNYrpmuhcVjog\ni4hnWitIE79kJ9FXEvgSnJORuIvaKzlheno7fa5x3mU3TnnHrPdc5nLSXNhFnezk\n4kqvIK5GL0bJQGuf6BKU/Ot8GFYPTKAi1D2aRaI3xzc7cj/EpCpFiEKWUbBFOHN8\nFYtcAWcGkYZsHioAMaaKNuVnk2srKT4lNrIVMFn+8mzri18rIs7GPrUi2tK2LoX0\nCkZfFUJynwfG4GDixCdVykAiT+DJAZ0AUOGAD0ASgp0fcYp4q54WqFngl3IvCr2T\n0Kcn98Fuw5/qCHZ1mIAgyA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAN/1x1Wau72Xw/BL88E9dnVPnD1MMA0GCSqGSIb3DQEB\nCwUAMB8xHTAbBgNVBAMMFGlkcHNoaWJib2xldGguaXJmLnNlMB4XDTE2MDIwODEy\nMjAzMloXDTM2MDIwODEyMjAzMlowHzEdMBsGA1UEAwwUaWRwc2hpYmJvbGV0aC5p\ncmYuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDc87Ku2vkiAXTa\nRroaKkTsMlazPXje3jgxIW+k+tIZruBChAoRT1BMuhVgy5K2qWUT027B/kZBpzzg\nsOmWPcoXDnItMFMDmSNFM18NuE+Hr02/rhpD4hHQCazZrBSbIHJxlEVDUAc00BXq\nz7tnHz5XGDnDfRtEqqTE1L0QAIN7Y+vsdAGdMfvMfOHN8za7d8/wWdoE6rTofBPU\nnMdrSNdk+ZwVKrszq2E+G7ppZ3QpyBaPXc41tkml1GXYhh6c7+GDJ8QZssLFLrpB\nTPLGz6DKDXwQ5Yn0ViF0a1AZI91+0sM1yvKExU1lFRD8vGO5gtqn+aa7MY59IZ+/\ne9mAI9ObAgMBAAGjbzBtMB0GA1UdDgQWBBTEa8AlX8hAecrW1mTHw/rHN9fiZTBM\nBgNVHREERTBDghRpZHBzaGliYm9sZXRoLmlyZi5zZYYraHR0cHM6Ly9pZHBzaGli\nYm9sZXRoLmlyZi5zZS9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEA\nt4r3f0DdNjsG1BVjQGE0/r3wzKwD9VgfI7YTyj9T01G0SzTPzEjwS2xSvPyBh+SY\nXGKoaSjrvMQRLyQ0yzGUkJkrEA026bAS+XtKXt3N1QnSnCDg8iyRG3eMJMQxlADw\ntM7KXBNdmmyZoFQsvgazQKCfcqpSieznAfpHS6QkOjSJS7qjmZvE9gR9+LrQjtGb\nSUpvSthL7xqz9bSHJsH3LBh/0fnQ1+eEY5XkMAKzdjaesWYSfJOUWcUojcyYY7TO\nvsUgGd85RO4yz1NF7JL/8KMHODq6/vHeE53VgHXRdeH0ntl04Gvzu6oyl7En3G5B\nCQNfH97cIrTE5N/RQ7XWcw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institutet f\u00f6r rymdfysik"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish Institute of Space Physics"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.irf.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IRF"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://testgu.pingpong.net/Shibboleth.sso/Metadata",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://testgu.pingpong.net/Shibboleth.sso/Metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://testgu.pingpong.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "testgu.pingpong.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJAME2EogsaBsxMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE3Rlc3RndS5waW5ncG9uZy5uZXQwHhcNMTUwNzMxMDAxNjI1WhcNMjUwNzI4\nMDAxNjI1WjAeMRwwGgYDVQQDExN0ZXN0Z3UucGluZ3BvbmcubmV0MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAyYPbn4CeU3tNI/8FdjRRUJcTb/gG+g0j\nMvE2RPC//eJw/UR0IwFsJy1R7bwEHynfpwMck+0K9nxNUtp84kN//k86Oy2sQVey\nAi0OCg5smTguBedA2n8lH7RDFkSvwtoASaGLSEoxXrE0nizDf3uWePLOqewzn5+o\njXWTS4RhnU12mP+fDVcrO8SqGsbOBXh8AGuUkfLOeyOD9Ayc1rNR6+KuObFqs05q\nBKsy+klw3b1OKk5L2eRgcPlZpNzLIfwVPVpanjItgBdZ1crs58oFpKzarVodjDwY\nkozDsyFCczo/YAlovWq5bvGnkap2I3ltuLGN19GIFoABa8XIPhXtbQIDAQABo0Ew\nPzAeBgNVHREEFzAVghN0ZXN0Z3UucGluZ3BvbmcubmV0MB0GA1UdDgQWBBQwKdDx\n5NCyLEP4EiCnI49AdPCJNTANBgkqhkiG9w0BAQUFAAOCAQEAMhDQdkJ+oFVKylVM\nLH9AlRmQlC0uqqaZfPECYwepQ08sAb1f6H3OGS8VfHB0PGrMlSgtu3mJImB3LZ+h\nDu69XL+oQV9qr4XNUYhUXAPXkbiojcUEy2WrJ2kEf3GrNomUm234fLu8WEhDV4iU\nl6EOZqEFS5sUtHpQEkW6ITn7MJH+/g412nbxtNRsVCbaEf8jX6n3qG93xyilOgJ3\ncpCuEjbgpDdWe3DPCrL9Kn4ab88aoblJVmjfH4t6t6TMc+zskhKXiQUGogGxzol3\nMSKIqXKgkSbbCtsduu3LvzmWV1r9U8J1QN7BSz7XBjqHvXgxDQzYMFr1SHtIKmN5\nv3gw1w=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=testgu.pingpong.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Test version of GUL, L\u00e4rplattformen PING PONG vid G\u00f6teborgs universitet."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Test version of GUL, The learning platform PING PONG at Gothenburg university."
                  }
                ],
                "logo": [
                  {
                    "text": "https://testgu.pingpong.net/login/pingpong-logo-168x50.png",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "168"
                  },
                  {
                    "text": "https://testgu.pingpong.net/login/pingpong-logo-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TEST-GUL, PING PONG vid G\u00f6teborgs universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TEST-GUL, PING PONG at Gothenburg university"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://testgu.pingpong.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://zbgva-edusso.zettabox.com/core/AuthServices",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Belkin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:grigory@zettabox.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Grigory"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Russell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:russell@zettabox.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Albert"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://zbgva-edusso.zettabox.com/core/AuthServices",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2016-03-02T17:13:36Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ZettaBox1"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.zettabox.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ZettaBox"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "zettabox.com"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Share, sync, collaborate in a safe European cloud, keeping you and your company compliant with EU law."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Zettabox"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFRDCCBCygAwIBAgISESFUpPvOFMU7IkSQ7nOMKq0FMA0GCSqGSIb3DQEBCwUA\nMGYxCzAJBgNVBAYTAkJFMRkwFwYDVQQKExBHbG9iYWxTaWduIG52LXNhMTwwOgYD\nVQQDEzNHbG9iYWxTaWduIE9yZ2FuaXphdGlvbiBWYWxpZGF0aW9uIENBIC0gU0hB\nMjU2IC0gRzIwHhcNMTQwNTA2MTMwMTAzWhcNMTYwNjI0MTY1MDAyWjBwMQswCQYD\nVQQGEwJHQjEPMA0GA1UECBMGTG9uZG9uMQ8wDQYDVQQHEwZMb25kb24xJjAkBgNV\nBAoTHUludGVyb3V0ZSBDb21tdW5pY2F0aW9ucyBMdGQuMRcwFQYDVQQDDA4qLnpl\ndHRhYm94LmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL1hYaEd\nGI3lBN4mXTJffl9sms4/uCm62/51dM4nsYB7SFvpPzF54mDsqnA1HYSdcVemsfdb\nUl+Fv1kk/4yybs7rbTpMtAE+m1d5KdGdOvxWdmATn6cemxC5dbpOo7YAgPB8xf+b\nIatI/5kRGHz/5nTb3yPeTaXooIDeydvwYGdxn2g0+ogAywb7vdOpiggK8di1QAl9\nA/PDvsOe83JegNJ4ARgE2BH2raQnqBz4pjf8/dUNLmrXC8xDHIvu9+yxcZu0nxjN\nnXa5aE9QnyfG0S0n4uKj4an5Cnb9/dbtRKztfGXTsfI4hrXoI2x0lXrvVRayRkCu\nxklevOpYviBc2EcCAwEAAaOCAeAwggHcMA4GA1UdDwEB/wQEAwIFoDBJBgNVHSAE\nQjBAMD4GBmeBDAECAjA0MDIGCCsGAQUFBwIBFiZodHRwczovL3d3dy5nbG9iYWxz\naWduLmNvbS9yZXBvc2l0b3J5LzAnBgNVHREEIDAegg4qLnpldHRhYm94LmNvbYIM\nemV0dGFib3guY29tMAkGA1UdEwQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsG\nAQUFBwMCMEkGA1UdHwRCMEAwPqA8oDqGOGh0dHA6Ly9jcmwuZ2xvYmFsc2lnbi5j\nb20vZ3MvZ3Nvcmdhbml6YXRpb252YWxzaGEyZzIuY3JsMIGgBggrBgEFBQcBAQSB\nkzCBkDBNBggrBgEFBQcwAoZBaHR0cDovL3NlY3VyZS5nbG9iYWxzaWduLmNvbS9j\nYWNlcnQvZ3Nvcmdhbml6YXRpb252YWxzaGEyZzJyMS5jcnQwPwYIKwYBBQUHMAGG\nM2h0dHA6Ly9vY3NwMi5nbG9iYWxzaWduLmNvbS9nc29yZ2FuaXphdGlvbnZhbHNo\nYTJnMjAdBgNVHQ4EFgQUAsBEtNcnCUtyf3G1bGCETtrA9SAwHwYDVR0jBBgwFoAU\nlt5h8b0cFilTHMDMfTuDAEDmGnwwDQYJKoZIhvcNAQELBQADggEBAF08BaKt/auc\nHSeCMANxNXnq14PrWNXjXdghq7u2PuhbAKkJiCf7k4NRlAQfsvSB+bZ/+rbZ9Ijl\nDWxLW5N9IY15/KrLYG5ZcR2ciSjXYaXlagHvv0J892Tt85rroHv0zL1nveCsWTA1\nLJSXN0iqLYza2nHDTn0NrhMoHAENc/Za44a/yXffa/kQbgCN37FzM69wzwrr8CjO\nxsVd3HpHjWql0BPnxK1bXFXk3NbZZLd6z5guCECHApIkvOvnLMRUXGj8PuUyubV2\nu2iJkBeqsi5RPHeMZ+2TJx66zAIQXRQRSkSF2VNWfCSJr+p1/0AhR9hpCEuzjAO5\nGrEsD4kUa1U="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://zbgva-edusso.zettabox.com/core/AuthServices/Acs",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Zettabox"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Share, sync, collaborate in a safe European cloud, keeping you and your company compliant with EU law."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "preferredLanguage",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.39",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://hig-test.blackboard.com/shibboleth-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://hig-test.blackboard.com/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TEST-Blackboard is a web based learning management system, for courses at the University of G\u00e4vle. The system is used for both campus courses and distance learning."
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TEST-Blackboard \u00e4r ett webbaserat system f\u00f6r hantering av kurser vid H\u00f6gskolan i G\u00e4vle, en s\u00e5 kallad l\u00e4rplattform. Systemet kan anv\u00e4ndas f\u00f6r b\u00e5de campus- och distanskurser."
                  }
                ],
                "logo": [
                  {
                    "text": "https://webkonto.student.hig.se/img/cencolor-50.gif",
                    "height": "45",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "https://webkonto.student.hig.se/img/cenfarg-50.gif",
                    "lang": "sv",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.blackboard.com/Footer/Privacy-Center.aspx"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TEST-Blackboard (Learning Management System)"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TEST-Blackboard l\u00e4rplattform"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://hig-test.blackboard.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://hig-test.blackboard.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "fgtd-137892-9998-app001"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAJd/AIjAineLMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2ZndGQtMTM3ODkyLTk5OTgtYXBwMDAxMB4XDTE1MDYyNTEyMTUzN1oXDTI1\nMDYyMjEyMTUzN1owIjEgMB4GA1UEAxMXZmd0ZC0xMzc4OTItOTk5OC1hcHAwMDEw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDFN9XBwB0/w2UM2Wr2NIKF\n3QsQf8JnmvwFAoEVQbru+VAM2TtLROtKejBrgK1v6yFNfBBWHNWsXF1cDsTo1S2C\nZQy5tuwJwmA/IVx9zVHQNEPCtutRla6HYuysQM/8lMwMW7g9i/Iz5/VAg+kFkCon\nHztfylCmU7xJgZXMS/hJ12n4IkyFmBTmfwCMVNE2+874VsHEgLaeOXS4VV4myPdp\nbl3q6nQYaacX6j/P/HVrE+8nfvzohpWc3ur/F1GKx8Y5E5FybjkVo4dm4HDuI0Bu\nyAC7zjBVcCmgg4XJMSM4Hlw983qNi81ut5yVIunj3xhrO/kk9jp+ZEwCNPUBMNur\nAgMBAAGjRTBDMCIGA1UdEQQbMBmCF2ZndGQtMTM3ODkyLTk5OTgtYXBwMDAxMB0G\nA1UdDgQWBBR/pc7QnCh5mWBov2eP+Q8uPPNfwzANBgkqhkiG9w0BAQUFAAOCAQEA\nIXF+WTSh/lDWN3C5XM1oXcmhmqh53H8CR9u0LtitnfHGOeNBgUnwJmI9gLOY4unh\nkqLEBaRmOmjE7fOfIroMQrA8UfP4kN3iWXsK5+TwHMpsSa2KJfgFXQpQIV1E2mEK\nGH/0SfBakkmY3H0Aj7tH0qp8or91Zy+XeLjhPV7U7WDXNQVEc8tvE4iU2WRwmqPu\n7hPICEPp3lIxpYAciLZCIiJuy5YSjqKAZogteEDmBYpp7mmU6OgWQRq1+KIWEQLl\ncKdDER/6/Bt9QQhtZ+AUFkJxlYEl9NETCLqQ//7+Yoy0oCxSgUfHjynnJYEsOgNc\nYIMJJu31CtipTKuUxLYeRQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=fgtd-137892-9998-app001"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://hig-test.blackboard.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-03.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-03.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-03.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-03.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-03.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-03.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-03.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-03.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-03.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;03"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;03"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-03.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-03.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJAPlFHKS4Gb/vMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wMy5sYWRvay51bXUuc2UwHhcNMTIwNjI5MTIwODA3WhcNMjIw\nNjI3MTIwODA3WjAhMR8wHQYDVQQDExZsYWRvazMtMDMubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA3ah5ehmINht8OmgX38/BIvlm\nz1njTjAKgpEX5jVpl2wzd5+S5+xBLLjVjePow/KrhdtqohschKyTh8Axu0lWaCfP\nB8RHa2ZhC4Rg4pQ6tmePL/KiGshP30CTmHd2rQZXFWLLwjOJZC+PfBOFl6hZmd7z\nYiFsUkgvebqTRqZL9bBFgg7OyacxbSKIR474C1ovObnJ8ro/EcFkVU2l/e6QixWR\nw/orVGYIUnBfG1ThnzE2b5DxqH/t4NBbKuf6LI/ldzKZaGyTwkQF1q7z0yzwzWpo\nBRMRD9CUftWzmKDwUcu1GH4BSiqXRKUHAkE3ZtDnSy5+ElQ7WhQhZ5HpXyeQMwID\nAQABo2swaTBIBgNVHREEQTA/ghZsYWRvazMtMDMubGFkb2sudW11LnNlhiVodHRw\nczovL2xhZG9rMy0wMy5sYWRvay51bXUuc2UvZ3VpLXNwMB0GA1UdDgQWBBRne1Xp\nEA2MWtH1uhd7IKhfx+4QqDANBgkqhkiG9w0BAQUFAAOCAQEAivdVwn1RFPCcbr6p\nLU/dmlhNii5kLwYP3kDsWuLW2MoYrvP2EpfxmNNatPXNZbZuUEWZXt5yH55iLMa2\nqrKr6BXjYqokCxyngchltd6Gv4GN0Fl7nnbSxfy/I7W8zqGZxfA72P4sgS+seX11\nNcNpFMV6o10QNJ6rgoO/LR4qAesMLbEl1BWNgyKkvCrOptvN24n0EiZy5U8tBOoT\nFqLiIetDB2M7PnLP7SjVhbVpn6u5+GAUx0qIXpX9LNHwQs047tUWijEDWSHaTtyv\nEg6T84xmStOZ2LpNTlFI8wnu2j8D1CrExsUpCOiuddPGp3zI7se2DGqXo9ZGe4tO\nOqxKbw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-03.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-03.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-03.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-03.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-03.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-03.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-03.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-03.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-03.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-03.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://connectis-sso.qa.federatenow.net/broker/sso/tpd",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:technicalsupport@connectis.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:technicalsupport@connectis.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://connectis-sso.qa.federatenow.net/broker/sso/tpd",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-05-19T12:36:02Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Connectis"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.connectis.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Connected Information Systems B.V."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "authn_requests_signed": "true",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID6zCCAtOgAwIBAgIJALX4Kq2P8A1MMA0GCSqGSIb3DQEBBQUAMIGLMQswCQYD\n\t\t\t\t\t\tVQQGEwJOTDEVMBMGA1UECAwMWnVpZCBIb2xsYW5kMRIwEAYDVQQHDAlSb3R0ZXJk\n\t\t\t\t\t\tYW0xEjAQBgNVBAoMCUNvbm5lY3RpczEfMB0GA1UECwwWRk9SIFRFU1QgUFVSUE9T\n\t\t\t\t\t\tRVMgT05MWTEcMBoGA1UEAwwTZWguYWNjLmNvbm5lY3Rpcy5ubDAeFw0xMzAxMDIx\n\t\t\t\t\t\tMDIzMTBaFw0xODAxMDIxMDIzMTBaMIGLMQswCQYDVQQGEwJOTDEVMBMGA1UECAwM\n\t\t\t\t\t\tWnVpZCBIb2xsYW5kMRIwEAYDVQQHDAlSb3R0ZXJkYW0xEjAQBgNVBAoMCUNvbm5l\n\t\t\t\t\t\tY3RpczEfMB0GA1UECwwWRk9SIFRFU1QgUFVSUE9TRVMgT05MWTEcMBoGA1UEAwwT\n\t\t\t\t\t\tZWguYWNjLmNvbm5lY3Rpcy5ubDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAMtjSnczA34cMYc8j5k8Rp0/Y1YizrPMtPjw1ClccygiLF/KoXy4A5vv6Ljz\n\t\t\t\t\t\tXARpdF6yWSGekgzcrfQZ/RxKtv5wJq7KnayHU73ajCW0GZEN38yn0X54+e4daO79\n\t\t\t\t\t\tVONFyGdpT5SPuRaXGxP/4YYH9Vn/+K9TfUffmICK/Gx0Ops3hywzpVvpcMEZtc9y\n\t\t\t\t\t\tCvVOu3L0P2QoYeHLBGFVoiwCMfA5/AvIfG6yL1wX8yHLYotlvpZFEXk4EMJ9dCqK\n\t\t\t\t\t\tdswcDz6p4GnSisC/89S35DDaCWDnGMB8wecWuEjZu+H/JWEhgjbJTjmctlSjoajE\n\t\t\t\t\t\tH8WFLsUxvZ3xjjkXfvaaYhEdaF8CAwEAAaNQME4wHQYDVR0OBBYEFI2ApVPf1bEv\n\t\t\t\t\t\t0ixBULEAK+SrT1XaMB8GA1UdIwQYMBaAFI2ApVPf1bEv0ixBULEAK+SrT1XaMAwG\n\t\t\t\t\t\tA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBACKYFOtONqcBiSJB6dewD7xH\n\t\t\t\t\t\tCvcvfbr26QDQKNJlrXG+HBz7wB4nyxsGOfgpvyWKa582pRPI2/rFq5X0jgdYw7mb\n\t\t\t\t\t\tHcVCYGZFf8/ijSI1fjkRr1LKMfSOWqQ5+REtLbCFBqKHyPyq1wsC535D+ktF04eL\n\t\t\t\t\t\tmmesG6/QBCfwfqhmuyaW35TBYNBb3HHELlYLGOOKuo83/5cUgoFJiBKblPRg69E+\n\t\t\t\t\t\tFgOARgihxdDzcTJIqD2bJExSkW8XFqn27Y1KhfCGIOpKZImfRIqxDmyWFtSecEzm\n\t\t\t\t\t\txMs+nAMoI6dUJf3swTToJIk4fFu1Ukk+jlyXtUnsN5VsjZHzGX0ueKCOSu0Cm/g="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://connectis-sso.qa.federatenow.net/broker/acs/tpd",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "2",
              "location": "https://connectis-sso.qa.federatenow.net/broker/acs/tpd",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "false"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.cliowebhost.co.uk/Patron/Stirling/entity",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Perkins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jennifer@cliosoftware.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jennifer"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Perkins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jennifer@cliosoftware.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jennifer"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.cliowebhost.co.uk/Patron/Stirling/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-10-28T12:56:10Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ClioWeb for University of Stirling"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://cliosoftware.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Clio Software UK Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCDCCAfSgAwIBAgIQY/Afradun5dG2rwUj4AANzAJBgUrDgMCHQUAMBsxGTAX\n\t\t\t\t\t\tBgNVBAMTEENsaW9TdGlybGluZzIwMTMwHhcNMTMwOTAzMDgyNDMxWhcNMjMwOTAz\n\t\t\t\t\t\tMDgyNDMwWjAbMRkwFwYDVQQDExBDbGlvU3RpcmxpbmcyMDEzMIIBIjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvG5RHaEtu4OXZip6APTjKWL0vy+WYJoVodIP\n\t\t\t\t\t\tyNRRO5oP1R9N09kOKo+3fHvnURA0W8guZIk9twGs/RdB4tNzD4aWgPmo7Ml1tVZw\n\t\t\t\t\t\teHZdwU2y87lSSkdM1/sZtY3Ju7ERoxdK3jCoIdnRSVx8Fm7WOtStpgdclT6V0fcZ\n\t\t\t\t\t\t3YQUuPONRpOdxivawPkUPL0c9i2Jx67kp35f63eBY/dPBON8p5Vo8BnZ70zqepUj\n\t\t\t\t\t\tcnXhG3PfE10lKASLRarQqGJjrdm/sGY44ChIHcKfSbUhonop6K9oh4hEKatBL1+p\n\t\t\t\t\t\txodbS0BaJEZ/fkgQrbyPLlgf5jDL80Ua7tcuVGm8ozi0Ls3CzQIDAQABo1AwTjBM\n\t\t\t\t\t\tBgNVHQEERTBDgBCQ/hClfq8r3PkbIADeLaxtoR0wGzEZMBcGA1UEAxMQQ2xpb1N0\n\t\t\t\t\t\taXJsaW5nMjAxM4IQY/Afradun5dG2rwUj4AANzAJBgUrDgMCHQUAA4IBAQAwe5Xx\n\t\t\t\t\t\tZrFE+rCI3Z2tfBX4oocgkgLD6weq29MqRcuhxBALpxeoKpT4bjjHzusLg/hzEyeQ\n\t\t\t\t\t\txbkZwu0HvXa230LnC9fpO3mjLHewLXDFEaZpfrOZvNa142RfMQU7iAQJfIrc42j8\n\t\t\t\t\t\trl7s17BVtYq+EzGgFgZm0YMBoL4SASS2QCoviwsGYHZmy/8h33jvHRMAB41OWjXZ\n\t\t\t\t\t\tWoaVaOm8sp/5AegAAcoIF33Tqv+fweHdrB4J/Q3d8+7vE8hWjTQ/HB+ZrOUig+Da\n\t\t\t\t\t\tVE+wnFJbmrR6M0zEPlKlhgEVZhDbCuu6qCHdnnby2yuNr6Kuv19Jad2cAZfMI+7U\n\t\t\t\t\t\tvCvcjHSOY6SmLIwA"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cliowebhost.co.uk/Patron/Stirling/Login2.aspx",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.beds.ac.uk/entity",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Haysom"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul.haysom@beds.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Haysom"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul.haysom@beds.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.beds.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-05-08T18:08:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEaTCCA1GgAwIBAgIQSzfaeKahBOK3I4on09FG0DANBgkqhkiG9w0BAQUFADA2\n\t\t\t\t\t\tMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n\t\t\t\t\t\tU1NMIENBMB4XDTE0MDQwOTAwMDAwMFoXDTE3MDQwODIzNTk1OVowPDEhMB8GA1UE\n\t\t\t\t\t\tCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRcwFQYDVQQDEw5pZHAuYmVkcy5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKetA8/6veT4+GRV\n\t\t\t\t\t\tuOGRULFxQkPXGXQ1V04ax3w9/xwgh60cCo/YnuVlcEjDkcSeXamwUp1lduMi8dRg\n\t\t\t\t\t\tCHH0wfD4vni2iacjSnnfO9rSsLchaGJgvUpW+NO/Byh77rFVE4iWz7j/P2oMaxWJ\n\t\t\t\t\t\t/mAxGcF/4SvrzSJpQ4Bvb3ERkT2IlOvS0RDJ2hpaFCH3QPSLbItg4zmg3gNigO/c\n\t\t\t\t\t\tfJFiM0l5ej3j8A9TM7rnsQkqCRYvVQ4Hx0cCo0T0NfNIqpd4qe02itjS8KisLM5K\n\t\t\t\t\t\txWAAsKxu7vm8MNDBwbz1fdrtU2y95rvba27iU0wsGvXMOW7AuAKcVghw8Kj3RSRN\n\t\t\t\t\t\tWjHQtzcCAwEAAaOCAWswggFnMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdXR+qQ\n\t\t\t\t\t\t47ntMB0GA1UdDgQWBBT8n949CVd+XA8RY2eIr6uEvqJKTzAOBgNVHQ8BAf8EBAMC\n\t\t\t\t\t\tBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIw\n\t\t\t\t\t\tIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0fBDMwMTAv\n\t\t\t\t\t\toC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcmww\n\t\t\t\t\t\tbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50ZXJl\n\t\t\t\t\t\tbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29jc3Au\n\t\t\t\t\t\tdGNzLnRlcmVuYS5vcmcwGQYDVR0RBBIwEIIOaWRwLmJlZHMuYWMudWswDQYJKoZI\n\t\t\t\t\t\thvcNAQEFBQADggEBAKV1I2UeqFfZJD9iJqVigp+RHtC4czWu83SSV9b/sNFlUp8U\n\t\t\t\t\t\tMPrEiFQyrKePjkpXOV0nampl2sfH+tlleaPJE6HQkU0fYXlPakWFn6V/4E9zoTuH\n\t\t\t\t\t\tezaXF+x9paTlrcjj46VCA/Ioo/DG7O1fg+Al7/NAofrMcDwEtuEbFoXesj1cAbxL\n\t\t\t\t\t\tAfI9EdCkiY/95rhoDk3F3B/NrdNPLsJwLw5R5kQpaVhSIEdiUaYZ50yLQzLtHLRF\n\t\t\t\t\t\t8EYzIAss513al942nZiH4RfHtOKUs5waxCaLb7QPH4mKUe9IK/Pg444YJsrEgaAO\n\t\t\t\t\t\t9QLVsNMkaE7Rl0xZfbp08NbjxGvR3pziJ0AFcS4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "beds.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.beds.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.beds.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib1.beds.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib1.beds.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib1.beds.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib1.beds.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.beds.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.beds.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "beds.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEaTCCA1GgAwIBAgIQSzfaeKahBOK3I4on09FG0DANBgkqhkiG9w0BAQUFADA2\n\t\t\t\t\t\tMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n\t\t\t\t\t\tU1NMIENBMB4XDTE0MDQwOTAwMDAwMFoXDTE3MDQwODIzNTk1OVowPDEhMB8GA1UE\n\t\t\t\t\t\tCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRcwFQYDVQQDEw5pZHAuYmVkcy5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKetA8/6veT4+GRV\n\t\t\t\t\t\tuOGRULFxQkPXGXQ1V04ax3w9/xwgh60cCo/YnuVlcEjDkcSeXamwUp1lduMi8dRg\n\t\t\t\t\t\tCHH0wfD4vni2iacjSnnfO9rSsLchaGJgvUpW+NO/Byh77rFVE4iWz7j/P2oMaxWJ\n\t\t\t\t\t\t/mAxGcF/4SvrzSJpQ4Bvb3ERkT2IlOvS0RDJ2hpaFCH3QPSLbItg4zmg3gNigO/c\n\t\t\t\t\t\tfJFiM0l5ej3j8A9TM7rnsQkqCRYvVQ4Hx0cCo0T0NfNIqpd4qe02itjS8KisLM5K\n\t\t\t\t\t\txWAAsKxu7vm8MNDBwbz1fdrtU2y95rvba27iU0wsGvXMOW7AuAKcVghw8Kj3RSRN\n\t\t\t\t\t\tWjHQtzcCAwEAAaOCAWswggFnMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdXR+qQ\n\t\t\t\t\t\t47ntMB0GA1UdDgQWBBT8n949CVd+XA8RY2eIr6uEvqJKTzAOBgNVHQ8BAf8EBAMC\n\t\t\t\t\t\tBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIw\n\t\t\t\t\t\tIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0fBDMwMTAv\n\t\t\t\t\t\toC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcmww\n\t\t\t\t\t\tbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50ZXJl\n\t\t\t\t\t\tbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29jc3Au\n\t\t\t\t\t\tdGNzLnRlcmVuYS5vcmcwGQYDVR0RBBIwEIIOaWRwLmJlZHMuYWMudWswDQYJKoZI\n\t\t\t\t\t\thvcNAQEFBQADggEBAKV1I2UeqFfZJD9iJqVigp+RHtC4czWu83SSV9b/sNFlUp8U\n\t\t\t\t\t\tMPrEiFQyrKePjkpXOV0nampl2sfH+tlleaPJE6HQkU0fYXlPakWFn6V/4E9zoTuH\n\t\t\t\t\t\tezaXF+x9paTlrcjj46VCA/Ioo/DG7O1fg+Al7/NAofrMcDwEtuEbFoXesj1cAbxL\n\t\t\t\t\t\tAfI9EdCkiY/95rhoDk3F3B/NrdNPLsJwLw5R5kQpaVhSIEdiUaYZ50yLQzLtHLRF\n\t\t\t\t\t\t8EYzIAss513al942nZiH4RfHtOKUs5waxCaLb7QPH4mKUe9IK/Pg444YJsrEgaAO\n\t\t\t\t\t\t9QLVsNMkaE7Rl0xZfbp08NbjxGvR3pziJ0AFcS4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Bedfordshire"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.beds.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Bedfordshire"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.calstatela.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "seng@calstatela.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sheryl Okuno"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dng3@cslanet.calstatela.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David Ng"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jason.solis@calstatela.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jason Solis"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mlee40@calstatela.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael Lee"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.calstatela.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.calstatela.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.calstatela.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFkDCCBHigAwIBAgIJAN84AoxNS7qCMA0GCSqGSIb3DQEBBQUAMIHfMQswCQYD\nVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEUMBIGA1UEBxMLTG9zIEFuZ2Vs\nZXMxMTAvBgNVBAoTKENhbGlmb3JuaWEgU3RhdGUgVW5pdmVyc2l0eSwgTG9zIEFu\nZ2VsZXMxKDAmBgNVBAsTH0luZm9ybWF0aW9uIFRlY2hub2xvZ3kgU2VydmljZXMx\nGzAZBgNVBAMTEmlkcC5jYWxzdGF0ZWxhLmVkdTErMCkGCSqGSIb3DQEJARYcbWFr\nb3RvLnRhbmFrYUBjYWxzdGF0ZWxhLmVkdTAeFw0xMDEyMTAxODAwMTJaFw0xMzEy\nMDkxODAwMTJaMIHfMQswCQYDVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEU\nMBIGA1UEBxMLTG9zIEFuZ2VsZXMxMTAvBgNVBAoTKENhbGlmb3JuaWEgU3RhdGUg\nVW5pdmVyc2l0eSwgTG9zIEFuZ2VsZXMxKDAmBgNVBAsTH0luZm9ybWF0aW9uIFRl\nY2hub2xvZ3kgU2VydmljZXMxGzAZBgNVBAMTEmlkcC5jYWxzdGF0ZWxhLmVkdTEr\nMCkGCSqGSIb3DQEJARYcbWFrb3RvLnRhbmFrYUBjYWxzdGF0ZWxhLmVkdTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMfSFCbth3fhrnbb7LKKIm3Gu81N\nwsXhIt4YYkvhTklVek8ET0+u8PRkBjWn7HI2mki/VNysE8mMJO/C/JjRM3CN7fFw\n+9KoDUO1NY4nS9PQdViReJw3PY0garTm0E8SfFjBQXeyNdcrN/8PvVoPfyjga23b\nQ9PAAKq1vTrhZ7xxCqxK0T2WvUjv+Bc1IkSNJ3a91hcaA77S65SaUBoZTZjngVgb\nBofYOHRDr22QWQ04y+jFmXVpwUReX3Aynb0Juf5Vdc2egZXR7fvudwTQcVoYzOQB\n8qtt4cdgXnzjLt3r5L0ddhikHQaN5bB5dD9OY8C6xyn+IB9MyB1Lf8oh7xUCAwEA\nAaOCAUswggFHMB0GA1UdDgQWBBQB7byhZ19tqtIdB0+29idldrJMOTCCARYGA1Ud\nIwSCAQ0wggEJgBQB7byhZ19tqtIdB0+29idldrJMOaGB5aSB4jCB3zELMAkGA1UE\nBhMCVVMxEzARBgNVBAgTCkNhbGlmb3JuaWExFDASBgNVBAcTC0xvcyBBbmdlbGVz\nMTEwLwYDVQQKEyhDYWxpZm9ybmlhIFN0YXRlIFVuaXZlcnNpdHksIExvcyBBbmdl\nbGVzMSgwJgYDVQQLEx9JbmZvcm1hdGlvbiBUZWNobm9sb2d5IFNlcnZpY2VzMRsw\nGQYDVQQDExJpZHAuY2Fsc3RhdGVsYS5lZHUxKzApBgkqhkiG9w0BCQEWHG1ha290\nby50YW5ha2FAY2Fsc3RhdGVsYS5lZHWCCQDfOAKMTUu6gjAMBgNVHRMEBTADAQH/\nMA0GCSqGSIb3DQEBBQUAA4IBAQCvGvoT2OXt+0p0UDImC+1JZr3G8WdH3B0eDtRM\n6PBg9r3sC/R5tff8rWbKquf1X7jLybuuclwrQhOz3mV96miiarGQtS4YSR8xaO/T\nuXxOCu/a3zMgYHHyCvHdJx9NUQ8NCNJ9h9EPg1Ectd91QqlWsw9RWs5ADuFoHjx8\nfkG6JS2f2VWBm21DqQBkddxT/NCj9Kia/FUwppyx2ceBYoWdGsKiEX6WA3lBI+N/\nNIlrOaf/+H8n2yV3uFO5ARjQVwY678a31gUq9CBwlapYYEUrGwj0dQeAAZyLEjVz\nFCK5DwJyRwWe486Q2eZYqETX7uSR1TXgtlr/PGbSvzsIXW7b"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "calstatela.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.calstatela.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.calstatela.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.calstatela.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.calstatela.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.calstatela.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.calstatela.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "calstatela.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "California State University, Los Angeles"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFkDCCBHigAwIBAgIJAN84AoxNS7qCMA0GCSqGSIb3DQEBBQUAMIHfMQswCQYD\nVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEUMBIGA1UEBxMLTG9zIEFuZ2Vs\nZXMxMTAvBgNVBAoTKENhbGlmb3JuaWEgU3RhdGUgVW5pdmVyc2l0eSwgTG9zIEFu\nZ2VsZXMxKDAmBgNVBAsTH0luZm9ybWF0aW9uIFRlY2hub2xvZ3kgU2VydmljZXMx\nGzAZBgNVBAMTEmlkcC5jYWxzdGF0ZWxhLmVkdTErMCkGCSqGSIb3DQEJARYcbWFr\nb3RvLnRhbmFrYUBjYWxzdGF0ZWxhLmVkdTAeFw0xMDEyMTAxODAwMTJaFw0xMzEy\nMDkxODAwMTJaMIHfMQswCQYDVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEU\nMBIGA1UEBxMLTG9zIEFuZ2VsZXMxMTAvBgNVBAoTKENhbGlmb3JuaWEgU3RhdGUg\nVW5pdmVyc2l0eSwgTG9zIEFuZ2VsZXMxKDAmBgNVBAsTH0luZm9ybWF0aW9uIFRl\nY2hub2xvZ3kgU2VydmljZXMxGzAZBgNVBAMTEmlkcC5jYWxzdGF0ZWxhLmVkdTEr\nMCkGCSqGSIb3DQEJARYcbWFrb3RvLnRhbmFrYUBjYWxzdGF0ZWxhLmVkdTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMfSFCbth3fhrnbb7LKKIm3Gu81N\nwsXhIt4YYkvhTklVek8ET0+u8PRkBjWn7HI2mki/VNysE8mMJO/C/JjRM3CN7fFw\n+9KoDUO1NY4nS9PQdViReJw3PY0garTm0E8SfFjBQXeyNdcrN/8PvVoPfyjga23b\nQ9PAAKq1vTrhZ7xxCqxK0T2WvUjv+Bc1IkSNJ3a91hcaA77S65SaUBoZTZjngVgb\nBofYOHRDr22QWQ04y+jFmXVpwUReX3Aynb0Juf5Vdc2egZXR7fvudwTQcVoYzOQB\n8qtt4cdgXnzjLt3r5L0ddhikHQaN5bB5dD9OY8C6xyn+IB9MyB1Lf8oh7xUCAwEA\nAaOCAUswggFHMB0GA1UdDgQWBBQB7byhZ19tqtIdB0+29idldrJMOTCCARYGA1Ud\nIwSCAQ0wggEJgBQB7byhZ19tqtIdB0+29idldrJMOaGB5aSB4jCB3zELMAkGA1UE\nBhMCVVMxEzARBgNVBAgTCkNhbGlmb3JuaWExFDASBgNVBAcTC0xvcyBBbmdlbGVz\nMTEwLwYDVQQKEyhDYWxpZm9ybmlhIFN0YXRlIFVuaXZlcnNpdHksIExvcyBBbmdl\nbGVzMSgwJgYDVQQLEx9JbmZvcm1hdGlvbiBUZWNobm9sb2d5IFNlcnZpY2VzMRsw\nGQYDVQQDExJpZHAuY2Fsc3RhdGVsYS5lZHUxKzApBgkqhkiG9w0BCQEWHG1ha290\nby50YW5ha2FAY2Fsc3RhdGVsYS5lZHWCCQDfOAKMTUu6gjAMBgNVHRMEBTADAQH/\nMA0GCSqGSIb3DQEBBQUAA4IBAQCvGvoT2OXt+0p0UDImC+1JZr3G8WdH3B0eDtRM\n6PBg9r3sC/R5tff8rWbKquf1X7jLybuuclwrQhOz3mV96miiarGQtS4YSR8xaO/T\nuXxOCu/a3zMgYHHyCvHdJx9NUQ8NCNJ9h9EPg1Ectd91QqlWsw9RWs5ADuFoHjx8\nfkG6JS2f2VWBm21DqQBkddxT/NCj9Kia/FUwppyx2ceBYoWdGsKiEX6WA3lBI+N/\nNIlrOaf/+H8n2yV3uFO5ARjQVwY678a31gUq9CBwlapYYEUrGwj0dQeAAZyLEjVz\nFCK5DwJyRwWe486Q2eZYqETX7uSR1TXgtlr/PGbSvzsIXW7b"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California State University, Los Angeles"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.calstatela.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California State University, Los Angeles"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.purplemash.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barnett"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sam@2simple.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sam"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barnett"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sam@2simple.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sam"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.purplemash.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "2Simple Software Limited: Purple Mash"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.2simple.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "2Simple Software Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.purplemash.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.purplemash.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.purplemash.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.purplemash.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.purplemash.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYjCCAkoCCQCm1vJwENC8ZzANBgkqhkiG9w0BAQsFADBzMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEXMBUGA1UECAwOR3JlYXRlciBMb25kb24xDzANBgNVBAcMBkxvbmRvbjEdMBsG\n\t\t\t\t\t\tA1UECgwUMlNpbXBsZSBTb2Z0d2FyZSBMdGQxGzAZBgNVBAMMEnd3dy5wdXJwbGVt\n\t\t\t\t\t\tYXNoLmNvbTAeFw0xNjAzMDcxNTI0MTlaFw0zNjAzMDIxNTI0MTlaMHMxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRcwFQYDVQQIDA5HcmVhdGVyIExvbmRvbjEPMA0GA1UEBwwGTG9uZG9u\n\t\t\t\t\t\tMR0wGwYDVQQKDBQyU2ltcGxlIFNvZnR3YXJlIEx0ZDEbMBkGA1UEAwwSd3d3LnB1\n\t\t\t\t\t\tcnBsZW1hc2guY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA6WYj\n\t\t\t\t\t\tiSCdGJOw7HD1JntQ9IIrCHjMg/uNprOTXbG/GdJGHxu8CMn2WVTyZMGYy03cx3/p\n\t\t\t\t\t\thTmiWloQ49PPvnizHbW/pW5DRF/7CoEjlgy25WHK+ALUGG7PzmgdzLn1cEd+iZ3H\n\t\t\t\t\t\tGYahRg32of3ixpTwKDMu8UwpJE1rd/iuhIRwElM6D2rTrh52Lt3zgiKmujo7RLY9\n\t\t\t\t\t\tBH+RApRQmZZxrAqQKAqR6eJ4nC+FL/FJZHYexBnWZuQ0CALdUurHuA/TzEAvoIe4\n\t\t\t\t\t\taVSCG3fFDtYUZDrgL4Ifkrniu9h/U5T+dtlBXOs05tJ/nVBnMilQ0TgaqN0QXjxb\n\t\t\t\t\t\tnDNE49tPKxj5W7N+FQIDAQABMA0GCSqGSIb3DQEBCwUAA4IBAQACyPLO/frONV+F\n\t\t\t\t\t\tE4gizkgaKP/x0hZmlkEO6Amf5OhvXswZZkISLLJX9xruBuVNlXQzLiJl5F70h3PL\n\t\t\t\t\t\t13Rwjm0NlEd9Szy2/FfqnWkciGB5UzJU8GENMORaMKmEKCrbjn4mOrdzorq0CcRQ\n\t\t\t\t\t\t2ZIky+2sewzLgmbVu0ewpItwmB4hP5d1hEygmCeFKJ0mxZbz0GrWOwUyiz4EUd7y\n\t\t\t\t\t\tsrQW+mX8iZzEp1nGd+Emf+d85kqoH1Ngbp0x2QyHkXJGjvlI0WINNMgBKv7eoSbS\n\t\t\t\t\t\tVl4pLKvsajvjwxWp7CqnoWRuvrvQvEeBN2V+sVcD+j+sspvxCIruAXMuFZJQVam4\n\t\t\t\t\t\tZ4RXYBzG"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.purplemash.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.purplemash.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.purplemash.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.purplemash.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.purplemash.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.purplemash.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.purplemash.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.purplemash.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.purplemash.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.purplemash.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://gul.gu.se/Shibboleth.sso/Metadata",
    {
      "entity_id": "https://gul.gu.se/Shibboleth.sso/Metadata",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "G\u00f6teborgs universitet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gu.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GU"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gul.gu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "gul-vas-2.it.gu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJALYbwahQyyIIMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEmd1bC12YXMtMi5pdC5ndS5zZTAeFw0xNDA0MDgxOTU4MTNaFw0yNDA0MDUx\nOTU4MTNaMB0xGzAZBgNVBAMTEmd1bC12YXMtMi5pdC5ndS5zZTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAO4HNuW9cvbXvO32s9g5gbPuzVpNUyBw80Sw\nuCJAMpXMBBRPyZArvjFlr62ZqfTBmmabPlXkMEUFt0oeHowaxFXdya2W6blyTfnL\n64sm4SEFPjEKrh4wbhuQNsW/xV0+49qvxObZKo/6mHlXvCvKJXxMGWBJuRskDiM7\nxV6qZBg9Y7a7FSqbq/2ENsvvKCrJ9sX83KszmOrFL2OvNXiKRL7nsaYVskU8zxwV\ngMZ6JRIK9bP48iZ/DNzVXL9BUaXz0Q9QXRMU1A7FutTRIZSripolGPK4bt5KgnWw\nviF5nAVp+614pLA+8hOV3SvG+j75YLFP8lzc2oy/o6az02Zf2dkCAwEAAaNAMD4w\nHQYDVR0RBBYwFIISZ3VsLXZhcy0yLml0Lmd1LnNlMB0GA1UdDgQWBBStqvU8e7JE\nt49WvWQDS4l78RLMvzANBgkqhkiG9w0BAQUFAAOCAQEAH6VPWqikKFA3d2daVKNd\nc6lKSFhikVHsuCwCqaKCwPwv8JSeAoJpaECf6y30F8oO/BYqT52ysJCViZ0SJkeV\n1B6W3mrJprkKcUXYHtMFw5xiREk8YtKXk2s6ILJ/qhGtACbn58J2UbXyMsU7QLDs\n82Enh/eyzIor62rd4L/Xar9Vfn1bDvi8adgEgjW4F8EgF8kgvSdcEBHkw7P4xg1z\nXigPY/3UZL0+3jurVuXrXLAg9pvpvAAlhyE1zpIx1+YuaBqXiz1SbgoZFEGciBkN\neL3wuo++huqzzBLsQtdaANbAUEnMDFcPOKT2x4/MCStbcNtz6e7VSVX2lU+wkeK3\now=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=gul-vas-2.it.gu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://gul.gu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayfa.efif.dk/kn/module.php/saml/sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayfa.efif.dk/kn/module.php/saml/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2012-08-23T14:24:59Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayfa.efif.dk/kn/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "knord.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "K\u00f8benhavn Nord"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Koebenhavn Nord"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "knord.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4DCCAcgCAQcwDQYJKoZIhvcNAQELBQAwNjE0MDIGA1UEAwwraHR0cHM6Ly93\nYXlmYS5lZmlmLmRrL2tuL21vZHVsZS5waHAvc2FtbC9zcDAeFw0xNTAxMDEwMDAw\nMDBaFw0yNTEyMzEyMzU5NTlaMDYxNDAyBgNVBAMMK2h0dHBzOi8vd2F5ZmEuZWZp\nZi5kay9rbi9tb2R1bGUucGhwL3NhbWwvc3AwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQDHiAwKahBTuI4Z+IJ1rgOeEiCCy3bR9QIe3BpCsejFCU5rSzkW\nANqVuc1PDfp0JdIZhrPXsmDJQMmidPCGPIDQKo+bk+af3+EUFS/I/+35sSBX2vf+\nh1DHvZV9jsznmpSVjp7HZ/WoPWBykWBJO0AOVmzB5zlaqkS36J76+wxerwdpuExV\nnYSNd73S+AyT/EZ+tXAO+6lQ8FL/YMlJnUkSaSqLSHFy01D2qBNmYRwBpCS6/dUZ\nyxi0t5j8ghKUD4BHOZVavn65J62cJdXiOcMRyUAIp57GXQrL63KtrjIcXddq+CZy\nZ5t37EdUOIz42joFcy73MFOntynlKEvOw1BJAgMBAAEwDQYJKoZIhvcNAQELBQAD\nggEBALgTLyya/yHVro/tIPfNU+aCylPsY4UjDYaHR2T7csGNcrNJXD2VXrmWariK\n+h6/5bjA9OhxTXfVlQiG4WIGHgPAK6qoF8kCt2tXodzOqy/miIsAdm7F7O6xHdBi\npiOli11I72zwQmgI2HyoLW16So5u91aJl2ZVl1AjTdLsa6kPYLS6T8Eaov3ykYiv\nAW7kxcXdFFjoWfxP3UO5f77rc/54KqKB8uB4v94Ykjl96PY+Wh4piBonIkOYztDf\nhJ03VFOV8IXAD3AF0UBCfS66vspXEQov+7pogdsNDIZs7f3RXdhraCbxqQ6o9vp3\noTQy5sOe4dSs2/n4/PlkBFwsHcE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "K\u00f8benhavn Nord"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Koebenhavn Nord"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.knord.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.knord.dk/in-english.html"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "K\u00f8benhavn Nord"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Koebenhavn Nord"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://take-shape-share.fenc.org.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "James"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:richard.james@adaptablelearning.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Porter"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ian.porter@adaptablelearning.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://take-shape-share.fenc.org.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-04-02T11:32:52Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Take-shape-share"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://take-shape-share.fenc.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Adaptable Learning Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/WAYF/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Take-shape-share"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4jCCAcqgAwIBAgIJANjHSyxzQmcZMA0GCSqGSIb3DQEBBQUAMBQxEjAQBgNV\n\t\t\t\t\t\tBAMTCXMxNTUzMjEwNDAeFw0xMTA3MTQyMDM5MTNaFw0yMTA3MTEyMDM5MTNaMBQx\n\t\t\t\t\t\tEjAQBgNVBAMTCXMxNTUzMjEwNDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBALahQjvkIC84CsDx3K7PooqAHW+QDmADL3p+5QNMs6Vb9hIu12BzjdVNBuEu\n\t\t\t\t\t\t2P2zNU5pP17IVdVImIkFlT2ZnpzHOfFqb2cWLPZqNJorp/ZQQaWV67O+bYRewIe6\n\t\t\t\t\t\tF25/b0cqH+0DcDlq/4kwdRfuhrCh9F0aNICcNRa51NWOAkfkJLxrLALvKFzqUGBr\n\t\t\t\t\t\t0p2c54HqXM4vLAdwWtGjG0dmRGf6Nai00ZChhmoyZz9sFaKAJmBR8kp85RhjQWwS\n\t\t\t\t\t\tv8SDmRDjTsLX3PiECR6aLVPA6msgalB/XS2D+0TPutL5RGHbmVcPikkierF29nfU\n\t\t\t\t\t\tTG1yQe1V1KxvlpAmJ1EoxuSbGK0CAwEAAaM3MDUwFAYDVR0RBA0wC4IJczE1NTMy\n\t\t\t\t\t\tMTA0MB0GA1UdDgQWBBT5mpvoe6jJ76xTkNcp5hc1CO86tTANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAAK+SJfnu3gCma3+qgp6SXvPJbnhyAHCJjxAiNo629/3huTeRGTfYxsJa\n\t\t\t\t\t\t0h61NTII8bvcbJoJB3XiLJnCqce66htzzbb/ujv2oFCsGxZqBOyizcpVlABSTB4J\n\t\t\t\t\t\t8XGCeKqvK3XSiiVhAn8NFtRYCVO6DZSVC+giIv3QpcPYYw7ht/wW5uApRvewwEdZ\n\t\t\t\t\t\t9dBzkeY5E55W+FwhhCCrueir8qzUss0qCfQApJctsGbC2vsxRow5wHQZZlZP7nyV\n\t\t\t\t\t\taKNTf017WLf8E/w+70rFWe08qZmLjJnhzKe/RFkQJf5jURb2RKzY72o6dr960FH7\n\t\t\t\t\t\tCThSkJwcMk7Kdl9gQTSxlOAxstLZBg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://take-shape-share.fenc.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://chronicle.bufvc.ac.uk/oa/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@cambridgeimaging.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CIS Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@cambridgeimaging.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CIS Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://chronicle.bufvc.ac.uk/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-11-25T15:46:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "British Universities Film & Video Council: Chronicle - BBC NI's TV News from the 60s and 70s"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://bufvc.ac.uk/aboutus/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "British Universities Film & Video Council"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID4zCCAsugAwIBAgIJAM107+XEFIGEMA0GCSqGSIb3DQEBBQUAMFQxMjAwBgNV\n\t\t\t\t\t\tBAoUKUJyaXRpc2ggVW5pdmVyc2l0aWVzIEZpbG0gJiBWaWRlbyBDb3VuY2lsMR4w\n\t\t\t\t\t\tHAYDVQQDExVjaHJvbmljbGUuYnVmdmMuYWMudWswHhcNMTExMTE4MTYxMzQzWhcN\n\t\t\t\t\t\tMjExMTE1MTYxMzQzWjBUMTIwMAYDVQQKFClCcml0aXNoIFVuaXZlcnNpdGllcyBG\n\t\t\t\t\t\taWxtICYgVmlkZW8gQ291bmNpbDEeMBwGA1UEAxMVY2hyb25pY2xlLmJ1ZnZjLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2+i+j9/++dpFcBX7\n\t\t\t\t\t\tBaQ/M4OWQaJgutSft+Dodcrd5hFSg9nT5BznoIB0Ip/CEXAs6k/RbMlfFRNwgMQe\n\t\t\t\t\t\t6X0fp8hjukr75WI4LiQBCp54axkuLW9ScUYl54xVoQ0QUzX+hZcYOKaY47BomBEN\n\t\t\t\t\t\t8yzi/VjuunSxLrxSiHcRrp0i6RCaCo1uqLFK3jAFFgwJfme9jrzYcUTFCUkgpj9I\n\t\t\t\t\t\tl67x4ufNkXjorsZ13f9JGTTVSCAYAaRRmqBleIULL2Wu2eDPTkqtIwoWJEHXw3BZ\n\t\t\t\t\t\t4WX57ezURxYihU1M1ng4+HuQxQ20wvRUV/LlYVueWzABD1njy/PVYBHT9Iwi+qcK\n\t\t\t\t\t\t4MCNAQIDAQABo4G3MIG0MB0GA1UdDgQWBBTVz59823vubr6Y9SOcECInWbD9tTCB\n\t\t\t\t\t\thAYDVR0jBH0we4AU1c+ffNt77m6+mPUjnBAiJ1mw/bWhWKRWMFQxMjAwBgNVBAoU\n\t\t\t\t\t\tKUJyaXRpc2ggVW5pdmVyc2l0aWVzIEZpbG0gJiBWaWRlbyBDb3VuY2lsMR4wHAYD\n\t\t\t\t\t\tVQQDExVjaHJvbmljbGUuYnVmdmMuYWMudWuCCQDNdO/lxBSBhDAMBgNVHRMEBTAD\n\t\t\t\t\t\tAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQDI0BREsN8bUqLFwYW8BPT4/E2WxOLIBuAt\n\t\t\t\t\t\twCdrGl2ehvsDGvyZS6eR4cXwA5joqCuHeDTBbCRlRwQ82P39i40Dy25l9SX1oGis\n\t\t\t\t\t\tKheHJLIs45pJNwgRhJgsmL664bTMjGiachvElN7hSuyT3Lv0hIKk4T4hR6AHJ5X1\n\t\t\t\t\t\t92/K0eWh1AqFPSajm/gEgASXulVnHVor5UH7O6bnTtedOwd+ymmlhyix6v83vx9J\n\t\t\t\t\t\tDrM3GM749leO2w6NozsLMmcdbKaPwCvxlO+QGFrd3dFSa9e+cuhEvxUidsIK50FB\n\t\t\t\t\t\tnexvkcwJaLImd7L56nkUt3AyXT+47jRHShQVLOJlYIFOehasKWwl"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID4zCCAsugAwIBAgIJAM107+XEFIGEMA0GCSqGSIb3DQEBBQUAMFQxMjAwBgNV\n\t\t\t\t\t\tBAoUKUJyaXRpc2ggVW5pdmVyc2l0aWVzIEZpbG0gJiBWaWRlbyBDb3VuY2lsMR4w\n\t\t\t\t\t\tHAYDVQQDExVjaHJvbmljbGUuYnVmdmMuYWMudWswHhcNMTExMTE4MTYxMzQzWhcN\n\t\t\t\t\t\tMjExMTE1MTYxMzQzWjBUMTIwMAYDVQQKFClCcml0aXNoIFVuaXZlcnNpdGllcyBG\n\t\t\t\t\t\taWxtICYgVmlkZW8gQ291bmNpbDEeMBwGA1UEAxMVY2hyb25pY2xlLmJ1ZnZjLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2+i+j9/++dpFcBX7\n\t\t\t\t\t\tBaQ/M4OWQaJgutSft+Dodcrd5hFSg9nT5BznoIB0Ip/CEXAs6k/RbMlfFRNwgMQe\n\t\t\t\t\t\t6X0fp8hjukr75WI4LiQBCp54axkuLW9ScUYl54xVoQ0QUzX+hZcYOKaY47BomBEN\n\t\t\t\t\t\t8yzi/VjuunSxLrxSiHcRrp0i6RCaCo1uqLFK3jAFFgwJfme9jrzYcUTFCUkgpj9I\n\t\t\t\t\t\tl67x4ufNkXjorsZ13f9JGTTVSCAYAaRRmqBleIULL2Wu2eDPTkqtIwoWJEHXw3BZ\n\t\t\t\t\t\t4WX57ezURxYihU1M1ng4+HuQxQ20wvRUV/LlYVueWzABD1njy/PVYBHT9Iwi+qcK\n\t\t\t\t\t\t4MCNAQIDAQABo4G3MIG0MB0GA1UdDgQWBBTVz59823vubr6Y9SOcECInWbD9tTCB\n\t\t\t\t\t\thAYDVR0jBH0we4AU1c+ffNt77m6+mPUjnBAiJ1mw/bWhWKRWMFQxMjAwBgNVBAoU\n\t\t\t\t\t\tKUJyaXRpc2ggVW5pdmVyc2l0aWVzIEZpbG0gJiBWaWRlbyBDb3VuY2lsMR4wHAYD\n\t\t\t\t\t\tVQQDExVjaHJvbmljbGUuYnVmdmMuYWMudWuCCQDNdO/lxBSBhDAMBgNVHRMEBTAD\n\t\t\t\t\t\tAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQDI0BREsN8bUqLFwYW8BPT4/E2WxOLIBuAt\n\t\t\t\t\t\twCdrGl2ehvsDGvyZS6eR4cXwA5joqCuHeDTBbCRlRwQ82P39i40Dy25l9SX1oGis\n\t\t\t\t\t\tKheHJLIs45pJNwgRhJgsmL664bTMjGiachvElN7hSuyT3Lv0hIKk4T4hR6AHJ5X1\n\t\t\t\t\t\t92/K0eWh1AqFPSajm/gEgASXulVnHVor5UH7O6bnTtedOwd+ymmlhyix6v83vx9J\n\t\t\t\t\t\tDrM3GM749leO2w6NozsLMmcdbKaPwCvxlO+QGFrd3dFSa9e+cuhEvxUidsIK50FB\n\t\t\t\t\t\tnexvkcwJaLImd7L56nkUt3AyXT+47jRHShQVLOJlYIFOehasKWwl"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "want_assertions_signed": "false",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://chronicle.bufvc.ac.uk/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://chronicle.bufvc.ac.uk/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://chronicle.bufvc.ac.uk/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://chronicle.bufvc.ac.uk/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://idp.ppke.hu/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Detrich Bertalan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:detrich.bertalan@it.ppke.hu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "P\u00e1sztor J\u00e1nos"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pasztor.janos@it.ppke.hu"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Zsombory G\u00e1bor"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:zsombory.gabor@it.ppke.hu"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ppke.hu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "urn:schac:homeOrganizationType:hu:university"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "ppke"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-edugain"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-idps"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "sotelib-vs-ppke"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:geant:niif.hu:eduid.hu:entity-attributes:processing-info",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "hu",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://metadata.eduid.hu/registration_policy_1_0.txt"
              }
            ],
            "registration_instant": "2013-08-01T07:17:19.807Z",
            "registration_authority": "http://eduid.hu",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ppke.hu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.ppke.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor"
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ppke.hu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ppke.hu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ppke.hu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ppke.hu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ppke.hu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ppke.hu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.225.109.0/24"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.48841,19.0784"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "description": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "P\u00e1zm\u00e1ny P\u00e9ter Katolikus Egyetem"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Pazmany Peter Catholic University"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.ppke.hu/logo.png",
                    "height": "86",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "86"
                  }
                ],
                "display_name": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PPKE - P\u00e1zm\u00e1ny P\u00e9ter Katolikus Egyetem"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PPKE - P\u00e1zm\u00e1ny P\u00e9ter Catholic University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ppke.hu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "login.ppke.hu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.ppke.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "P\u00e1zm\u00e1ny P\u00e9ter Katolikus Egyetem"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "P\u00e1zm\u00e1ny P\u00e9ter Catholic University"
          }
        ],
        "organization_url": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.itk.ppke.hu/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.en.itk.ppke.hu/"
          }
        ],
        "organization_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "P\u00e1zm\u00e1ny P\u00e9ter Katolikus Egyetem"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "P\u00e1zm\u00e1ny P\u00e9ter Catholic University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://gn-vho.grnet.gr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@grnet.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Greek Research and Technology Network"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "800-11-47638"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+30-2109569181"
            }
          ]
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@grnet.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Greek Research and Technology Network"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "800-11-47638"
            }
          ]
        }
      ],
      "entity_id": "https://gn-vho.grnet.gr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIJAJMOS4lZGZTGMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\n                            BAMTD2duLXZoby5ncm5ldC5ncjAeFw0xNDAzMDcxODI1MzNaFw0xOTAzMDYxODI1\n                            MzNaMBoxGDAWBgNVBAMTD2duLXZoby5ncm5ldC5ncjCCASIwDQYJKoZIhvcNAQEB\n                            BQADggEPADCCAQoCggEBAOh9S7NB2MuQqUBKOiEe05XHFCBBc9e6icfod97VFeug\n                            hdLsAZK/hpPAADzXQsKz2eHG3abRgxWUneQ7e8hSPCckGRG06FtbSI4zOitlx9id\n                            QHk1ah1vaVFLKiFdFhpqsE8Gjbb7FfA4cwXjMO4l8D4m3kFkKQk5x0Ok5EIumDlx\n                            RHPSRxIS6RsGE9y/xvCu+NNvc8zG6eSXrNLPgLHau3aNPY/NeYaV9UZg6pV8PlS4\n                            DbNLIg6U+rbYMBztRzfkHL5UTuykGwmECgKP7E/cajAS3siR6c7avkeMaqmdyCSt\n                            GB0JofKDSWEC+rIIMUafxM2JMpcmqDSe1a7gRij/Gk0CAwEAAaNlMGMwQgYDVR0R\n                            BDswOYIPZ24tdmhvLmdybmV0LmdyhiZodHRwczovL2duLXZoby5ncm5ldC5nci9p\n                            ZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUbS3VHThd6Vyhy9/Pki68p/j4ZRYwDQYJ\n                            KoZIhvcNAQEFBQADggEBAOMWzzekuxdAwdr8DY8tM6tCKjq/YRP70b9eKH3zwXWc\n                            XZZwcv57B7z1wwt/4eCLQai4bPIIAGnFJIr+LRV2hhy3HJZ/CtFs5LqYFP/OCaLa\n                            VbwyzBQMRwAy5Jbt7ikfc7P7BOPjQ1zQzTxkNUmWGXoTIkPJ4naSmNUV26WWSvA9\n                            15ZjygTLXMVwuOAFXhuBBU5AWfzfQa6nxlFUQ4NYw7ow4h73KWrVRRpXTV7U4g3s\n                            ytc1mR50M3dyL1uT7lpfSyTJ8fdzjSuw0xknlCY2rmOGq9RVPZwoz8ZP2xrVdcNW\n                            8Y/HvCvcXUMu/2w1Xei++WItO1eyS80x8+/VjQ7h+50="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gn-vho.grnet.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://gn-vho.grnet.gr:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://gn-vho.grnet.gr:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://gn-vho.grnet.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gn-vho.grnet.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://gn-vho.grnet.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://gn-vho.grnet.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://gn-vho.grnet.gr:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://gn-vho.grnet.gr:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gn-vho.grnet.gr"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.noc.grnet.gr/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "GRNET Virtual Home Organization (VHO) for G\u00c9ANT"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "\u0395\u03b9\u03ba\u03bf\u03bd\u03b9\u03ba\u03cc\u03c2 \u039f\u03b9\u03ba\u03b5\u03af\u03bf\u03c2 \u03a6\u03bf\u03c1\u03ad\u03b1\u03c2 (VHO) \u03c4\u03bf\u03c5 \u0395\u0394\u0395\u03a4 \u03b3\u03b9\u03b1 \u03c4\u03bf G\u00c9ANT"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "GRNET Virtual Home Organization (VHO) for G\u00c9ANT"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u0395\u03b9\u03ba\u03bf\u03bd\u03b9\u03ba\u03cc\u03c2 \u039f\u03b9\u03ba\u03b5\u03af\u03bf\u03c2 \u03a6\u03bf\u03c1\u03ad\u03b1\u03c2 (VHO) \u03c4\u03bf\u03c5 \u0395\u0394\u0395\u03a4 \u03b3\u03b9\u03b1 \u03c4\u03bf G\u00c9ANT"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIJAJMOS4lZGZTGMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\n                            BAMTD2duLXZoby5ncm5ldC5ncjAeFw0xNDAzMDcxODI1MzNaFw0xOTAzMDYxODI1\n                            MzNaMBoxGDAWBgNVBAMTD2duLXZoby5ncm5ldC5ncjCCASIwDQYJKoZIhvcNAQEB\n                            BQADggEPADCCAQoCggEBAOh9S7NB2MuQqUBKOiEe05XHFCBBc9e6icfod97VFeug\n                            hdLsAZK/hpPAADzXQsKz2eHG3abRgxWUneQ7e8hSPCckGRG06FtbSI4zOitlx9id\n                            QHk1ah1vaVFLKiFdFhpqsE8Gjbb7FfA4cwXjMO4l8D4m3kFkKQk5x0Ok5EIumDlx\n                            RHPSRxIS6RsGE9y/xvCu+NNvc8zG6eSXrNLPgLHau3aNPY/NeYaV9UZg6pV8PlS4\n                            DbNLIg6U+rbYMBztRzfkHL5UTuykGwmECgKP7E/cajAS3siR6c7avkeMaqmdyCSt\n                            GB0JofKDSWEC+rIIMUafxM2JMpcmqDSe1a7gRij/Gk0CAwEAAaNlMGMwQgYDVR0R\n                            BDswOYIPZ24tdmhvLmdybmV0LmdyhiZodHRwczovL2duLXZoby5ncm5ldC5nci9p\n                            ZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUbS3VHThd6Vyhy9/Pki68p/j4ZRYwDQYJ\n                            KoZIhvcNAQEFBQADggEBAOMWzzekuxdAwdr8DY8tM6tCKjq/YRP70b9eKH3zwXWc\n                            XZZwcv57B7z1wwt/4eCLQai4bPIIAGnFJIr+LRV2hhy3HJZ/CtFs5LqYFP/OCaLa\n                            VbwyzBQMRwAy5Jbt7ikfc7P7BOPjQ1zQzTxkNUmWGXoTIkPJ4naSmNUV26WWSvA9\n                            15ZjygTLXMVwuOAFXhuBBU5AWfzfQa6nxlFUQ4NYw7ow4h73KWrVRRpXTV7U4g3s\n                            ytc1mR50M3dyL1uT7lpfSyTJ8fdzjSuw0xknlCY2rmOGq9RVPZwoz8ZP2xrVdcNW\n                            8Y/HvCvcXUMu/2w1Xei++WItO1eyS80x8+/VjQ7h+50="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GRNET Virtual Home Organization (VHO) for G\u00c9ANT"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u0395\u03b9\u03ba\u03bf\u03bd\u03b9\u03ba\u03cc\u03c2 \u039f\u03b9\u03ba\u03b5\u03af\u03bf\u03c2 \u03a6\u03bf\u03c1\u03ad\u03b1\u03c2 (VHO) \u03c4\u03bf\u03c5 \u0395\u0394\u0395\u03a4 \u03b3\u03b9\u03b1 \u03c4\u03bf G\u00c9ANT"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.noc.grnet.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GRNET Virtual Home Organization (VHO) for G\u00c9ANT"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u0395\u03b9\u03ba\u03bf\u03bd\u03b9\u03ba\u03cc\u03c2 \u039f\u03b9\u03ba\u03b5\u03af\u03bf\u03c2 \u03a6\u03bf\u03c1\u03ad\u03b1\u03c2 (VHO) \u03c4\u03bf\u03c5 \u0395\u0394\u0395\u03a4 \u03b3\u03b9\u03b1 \u03c4\u03bf G\u00c9ANT"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.snc.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webmaster@centralnottingham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gareth"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webmaster@centralnottingham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gareth"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.snc.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-05-17T13:55:33Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAILTn2HBBdNo1ahq8UPWTUXgGC1eMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBgxFjAUBgNVBAMTDWlkcC5zbmMuYWMudWswHhcNMTIwMjEwMTE0NDQzWhcN\n\t\t\t\t\t\tMzIwMjEwMTE0NDQzWjAYMRYwFAYDVQQDEw1pZHAuc25jLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqey/f0AHmuYflfyRldet5x7ft9mN5GU5\n\t\t\t\t\t\tMAFLmVDlTKAVAlAZgD+knrt7Vr+NE8YhNL7t5N7rMMxLsoJ7gW5qo4Fl4ihZSdC8\n\t\t\t\t\t\t0c8lPPjAzG4ol2P60vmL4bsON1NPFFnEDTfPWmSdIGnZ1Yu4LdsPbxupm7iRU3qQ\n\t\t\t\t\t\t+NZBrCXjdTNkApY7VqhNW693ulLSS/ERjYrbwuhe4R1EQN8UJByWokocpEZg+PHr\n\t\t\t\t\t\t/f32B2mAd5M40kifSxzeq7Yh/473ZqyYiMRMJ2S/rYcXOJjJXIJggG/0o8RzW3iz\n\t\t\t\t\t\tNckUMLLlIn6czkGR7goW9/PFrH+npAnqCtvpY02361Y00JIspKiegwIDAQABo2Ew\n\t\t\t\t\t\tXzA+BgNVHREENzA1gg1pZHAuc25jLmFjLnVrhiRodHRwczovL2lkcC5zbmMuYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFHYJ9wHah0MigR+hhOovfPwsk+J2\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQCBlYR/bb8P28PLzbfeDHF6LmK+wllNCUaMsbRq\n\t\t\t\t\t\t8cMzNDh9qf/86HEZf2RnkpjR87u9q22m2aI5DufDpB9G8fowVZff4aY9eiu8XcH+\n\t\t\t\t\t\toLp7qxk/TNFJEP/OvzmTGJgNKxiWmYqYawe/6K3TTk3j1XSUpT5do5LAxjAIrZHq\n\t\t\t\t\t\tz+6OMn63/26rIyKDi3yMgiaagge7tBzzPgGBHAwmijQNybso009X0Tv0g29oyq9Z\n\t\t\t\t\t\tuWqgokIPrf+ZsLcolDoA0Bc/toNjwVNsA3Kcx8Umq/A2bbS68WxUymINL90Dd4rl\n\t\t\t\t\t\t/MOmOshdOUiRjf0TvUvtbBqWQ2YfQdTu4yXa1EifVkd7tzIg"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "snc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.snc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.snc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.snc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.snc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.snc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.snc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.snc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.snc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "snc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAILTn2HBBdNo1ahq8UPWTUXgGC1eMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBgxFjAUBgNVBAMTDWlkcC5zbmMuYWMudWswHhcNMTIwMjEwMTE0NDQzWhcN\n\t\t\t\t\t\tMzIwMjEwMTE0NDQzWjAYMRYwFAYDVQQDEw1pZHAuc25jLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqey/f0AHmuYflfyRldet5x7ft9mN5GU5\n\t\t\t\t\t\tMAFLmVDlTKAVAlAZgD+knrt7Vr+NE8YhNL7t5N7rMMxLsoJ7gW5qo4Fl4ihZSdC8\n\t\t\t\t\t\t0c8lPPjAzG4ol2P60vmL4bsON1NPFFnEDTfPWmSdIGnZ1Yu4LdsPbxupm7iRU3qQ\n\t\t\t\t\t\t+NZBrCXjdTNkApY7VqhNW693ulLSS/ERjYrbwuhe4R1EQN8UJByWokocpEZg+PHr\n\t\t\t\t\t\t/f32B2mAd5M40kifSxzeq7Yh/473ZqyYiMRMJ2S/rYcXOJjJXIJggG/0o8RzW3iz\n\t\t\t\t\t\tNckUMLLlIn6czkGR7goW9/PFrH+npAnqCtvpY02361Y00JIspKiegwIDAQABo2Ew\n\t\t\t\t\t\tXzA+BgNVHREENzA1gg1pZHAuc25jLmFjLnVrhiRodHRwczovL2lkcC5zbmMuYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFHYJ9wHah0MigR+hhOovfPwsk+J2\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQCBlYR/bb8P28PLzbfeDHF6LmK+wllNCUaMsbRq\n\t\t\t\t\t\t8cMzNDh9qf/86HEZf2RnkpjR87u9q22m2aI5DufDpB9G8fowVZff4aY9eiu8XcH+\n\t\t\t\t\t\toLp7qxk/TNFJEP/OvzmTGJgNKxiWmYqYawe/6K3TTk3j1XSUpT5do5LAxjAIrZHq\n\t\t\t\t\t\tz+6OMn63/26rIyKDi3yMgiaagge7tBzzPgGBHAwmijQNybso009X0Tv0g29oyq9Z\n\t\t\t\t\t\tuWqgokIPrf+ZsLcolDoA0Bc/toNjwVNsA3Kcx8Umq/A2bbS68WxUymINL90Dd4rl\n\t\t\t\t\t\t/MOmOshdOUiRjf0TvUvtbBqWQ2YfQdTu4yXa1EifVkd7tzIg"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Central College Nottingham"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://idp.snc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Central College Nottingham"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://meetingtools-dev.app.nordu.net/saml2/sp/metadata",
    {
      "entity_id": "https://meetingtools-dev.app.nordu.net/saml2/sp/metadata",
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Johansson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "leifj@nordu.net"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "NORDUnet"
          },
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Leif"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUNet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://meetingtools-dev.app.nordu.net/saml2/sp/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEujCCA6KgAwIBAgIQLINqZJFs8l1wYd2J2IBMTjANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEyMDIyOTAwMDAwMFoXDTE1MDIyODIzNTk1OVowgZUxCzAJBgNV\nBAYTAkRLMQowCAYDVQQREwEuMQowCAYDVQQIEwEuMQswCQYDVQQHEwIuLjEZMBcG\nA1UECRMQREsgMjk3MCBIb3JzaG9sbTEVMBMGA1UECRMMQWdlcm4gQWxsZSAzMRUw\nEwYDVQQKEwxOT1JEVW5ldCBBL1MxGDAWBgNVBAMUDyouYXBwLm5vcmR1Lm5ldDCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJkBbj0ZJsjuirO6tN9rbRhE\n5PfQKfjrwMf5lp1a05DHlJcxsv2JZGPszkOA260D8gouWfjk3DJQIIJJgELfn5yP\nL4zwKArBDpsttTXW+DFmhfECbkemWV571ErDHMVC9JUD39uLhE1bAoYFxAeJGr14\nmg/N5YdnsuSTGOfVfC+XuhA3CgylcGBIWoXHPbPlUJk3VWVeNnYjO+nLlKPjhSSq\nmRVhmVhEwREiRPgbKyMEEoFpdmSzuNWcBMtVKt4FTLa0cjx3/rIn77imztcXRDSN\nT6GwXaG5pjy+7E602epC4t5hbj6pxzrC7mpyIQXdYjKboPgaKQ+E7bv+OqJNG3sC\nAwEAAaOCAWIwggFeMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdXR+qQ47ntMB0G\nA1UdDgQWBBT0F6Szj83YxTlMGIIIf3I9jdTedjAOBgNVHQ8BAf8EBAMCBaAwDAYD\nVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwGAYDVR0g\nBBEwDzANBgsrBgEEAbIxAQICHTA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3Js\nLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8w\nNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NM\nQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAa\nBgNVHREEEzARgg8qLmFwcC5ub3JkdS5uZXQwDQYJKoZIhvcNAQEFBQADggEBADMQ\nbc0dPVC1SlyOxDf90hN9sDKw92YdVtsUNFfs9MYivZK7KI5+qEQStpAvXkrBUNfd\ngM9wqL9ea9BDDmBcn5lYyjPBgGJBeLLkcyBbZ56JbcBAxIncKKFw6r5M3j7tMcth\nf06K4cm7ngUg80ZEYK00ioAyFle56qPfZ5UM25QFzV38DGvusLl5H1bTtpz1ijh7\nkO/ehJVo4K64KVCbjOr1bavp665TtcIQX2qoPsnTZY30gQ/X/K2UJQSUE5Qc+o19\nBkvvVT5jNYdeLZHXbC6X4kXYNhFKZaz9nURgfaFQIeIEu/zmsIM8tcwLjZyF1veH\nwXXiBDXS3PNHXQnnpys="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://meetingtools-dev.app.nordu.net/saml2/sp/acs/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "meetingtools"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://dev2.dariah.eu/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Schl\u00f6r"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:bernd.schloer@sub.uni-goettingen.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bernd"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:register@dariah.eu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dariah"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dev2.dariah.eu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2014-04-11T07:19:21Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Gesellschaft f\u00fcr wissenschaftliche Datenverarbeitung mbH"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Gesellschaft f\u00fcr wissenschaftliche Datenverarbeitung mbH"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gwdg.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gwdg.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e112"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e112"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev2.dariah.eu/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev2.dariah.eu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev2.dariah.eu/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev2.dariah.eu/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dev2.dariah.eu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.dariah.eu/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.dariah.eu/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DARIAH Wiki"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DARIAH Wiki"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "DARIAH-DE Wiki"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "DARIAH-DE Wiki"
                  }
                ],
                "logo": [
                  {
                    "text": "https://ldap-dariah.esc.rzg.mpg.de/images/DARIAH_flower_icon.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://ldap-dariah.esc.rzg.mpg.de/images/DARIAH_flower.png",
                    "height": "154",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "160"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://de.dariah.eu/ServicePrivacyPolicy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "wiki.de.dariah.eu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGJDCCBQygAwIBAgIHGFSsIT9ZfjANBgkqhkiG9w0BAQsFADCBrjELMAkGA1UE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\ncQL+qVl7t4VhX8zr2JqD+T8b2OQCrG9GoF+4kwJhvS9K0d4wrLB33Q=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=wiki.de.dariah.eu,O=Georg-August-Universitaet Goettingen,L=Goettingen,ST=Niedersachsen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "wiki.de.dariah.eu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGJDCCBQygAwIBAgIHGFSsIT9ZfjANBgkqhkiG9w0BAQsFADCBrjELMAkGA1UE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\ncQL+qVl7t4VhX8zr2JqD+T8b2OQCrG9GoF+4kwJhvS9K0d4wrLB33Q=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=wiki.de.dariah.eu,O=Georg-August-Universitaet Goettingen,L=Goettingen,ST=Niedersachsen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev2.dariah.eu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dev2.dariah.eu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev2.dariah.eu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dev2.dariah.eu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dev2.dariah.eu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dev2.dariah.eu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wiki.dariah.eu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wiki.de.dariah.eu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "DARIAH Wiki"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "DARIAH Wiki"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "DARIAH-DE Wiki"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "DARIAH-DE Wiki"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.scng.si/idp/20130321",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Harej"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:janko.harej@tsc.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Janko"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pipan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Egon.Pipan@tsc.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Egon"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:podpora@scng.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Harej"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:janko.harej@tsc.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Janko"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Podbr\u0161\u010dek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:milanp@scng.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Milan"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Harej"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:janko.harej@tsc.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Janko"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bo\u017ei\u010d"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:martin.bozic@scng.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Podbr\u0161\u010dek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:milanp@scng.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Milan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Podbrscek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:milan.podbrscek@tsc.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Milan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bo\u017ei\u010d"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:martin.bozic@scng.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cimerman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:gregor.cimerman@guest.arnes.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gregor"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.scng.si/idp/20130321",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_general.pdf"
              },
              {
                "lang": "sl",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_splosni_pogoji.pdf"
              }
            ],
            "registration_instant": "2015-04-09T10:04:08Z",
            "registration_authority": "http://aai.arnes.si",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.scng.si/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.scng.si/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "scng.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tsc.si"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.scng.si/en/"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.scng.si"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for organization Campus Nova Gorica"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ponudnik identitet organizacije Kampus Nova Gorica"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "259",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "200"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Campus Nova Gorica"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kampus Nova Gorica"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u0160OLSKI CENTER NOVA GORICA"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u0160OLSKI CENTER NOVA GORICA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.scng.si/en/"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.scng.si"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u0160OLSKI CENTER NOVA GORICA"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u0160OLSKI CENTER NOVA GORICA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.dir.garr.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:system.support@garr.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.dir.garr.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2010-09-30T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUMJUKlH8ou/Aqe5RpN9dGZSep/CQwDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPaWRwLmRpci5nYXJyLml0MB4XDTExMTEyMTEwNDY1NloX\nDTMxMTEyMTEwNDY1NlowGjEYMBYGA1UEAxMPaWRwLmRpci5nYXJyLml0MIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtQSmT31kE2g6itpnCjcLrFBCUL04\nLsMioxbBFbCFsMn3vgHOubmhpwuNOUBYhl8MkSIGjoAcYCbDc4hDSucQMSx1fgvF\nX/S2QfJr7Bu6mNxzt9RqMoXWnuqkKKZYZw+DjITqzZp3g2+lB3i3b9x1jOh4AhSe\nOoWoVyXx/x+EQS9WJ55GEw/fKi70GtrrKI5wu4D/z+bigZG5TOg3A3o197mLt0ns\njwSd51WdtbZ+AccwyTOyQgFCqwRxszQEvqIt2wyNYt0AOcYi2jRUlpc2jnikytXN\n9hsNZPT0Y9Yuxi5IVRxSIkdeIs9eGOxrJqxg6FWwIdFHpNyF9MVjx4eZewIDAQAB\no2UwYzBCBgNVHREEOzA5gg9pZHAuZGlyLmdhcnIuaXSGJmh0dHBzOi8vaWRwLmRp\nci5nYXJyLml0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRybtrE0ndZvt7hHlAA\n+e035msGLzANBgkqhkiG9w0BAQUFAAOCAQEAWFusaIXa/wOcsEEvKRA83mFVulM/\nR0lA/D+Zm0LH1SxVEprX7/Iv001U1M5c6ySFWHgR6v7CIHHVpNF+aMr1kNw4U2wc\nXMWli2Htykpd8sgrjx7Eg4+3WITxupXwxbvxU86orNntPcJCASVcDVbrBReC6mZ2\nlxawzxIGWbSVbKo24lUcklBeoMKiG8Itw2/ouzjcmdw3defNBMlZ9akWdFSK1z58\npm4pftMyNdlh91nMxDa0caZ8+7fZcTPs0bFQdivu3vdL1+OcwlAmcloilD54xfiV\n5vGMEoxK1AfQhXgis+ZYJ2VRydbeSS0gEohRmR/53LIOjBfZ6VnKy71yew=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "garr.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.dir.garr.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.dir.garr.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.dir.garr.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.dir.garr.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.dir.garr.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.dir.garr.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.dir.garr.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.dir.garr.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "garr.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://login.dir.garr.it/IdPSupportPage/index.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://login.dir.garr.it/IdPSupportPage/index.html"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for GARR staff"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per il personale GARR"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://login.dir.garr.it/IdPSupportPage/index.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://login.dir.garr.it/IdPSupportPage/index.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "GARR IdP"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "GARR IdP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUMJUKlH8ou/Aqe5RpN9dGZSep/CQwDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPaWRwLmRpci5nYXJyLml0MB4XDTExMTEyMTEwNDY1NloX\nDTMxMTEyMTEwNDY1NlowGjEYMBYGA1UEAxMPaWRwLmRpci5nYXJyLml0MIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtQSmT31kE2g6itpnCjcLrFBCUL04\nLsMioxbBFbCFsMn3vgHOubmhpwuNOUBYhl8MkSIGjoAcYCbDc4hDSucQMSx1fgvF\nX/S2QfJr7Bu6mNxzt9RqMoXWnuqkKKZYZw+DjITqzZp3g2+lB3i3b9x1jOh4AhSe\nOoWoVyXx/x+EQS9WJ55GEw/fKi70GtrrKI5wu4D/z+bigZG5TOg3A3o197mLt0ns\njwSd51WdtbZ+AccwyTOyQgFCqwRxszQEvqIt2wyNYt0AOcYi2jRUlpc2jnikytXN\n9hsNZPT0Y9Yuxi5IVRxSIkdeIs9eGOxrJqxg6FWwIdFHpNyF9MVjx4eZewIDAQAB\no2UwYzBCBgNVHREEOzA5gg9pZHAuZGlyLmdhcnIuaXSGJmh0dHBzOi8vaWRwLmRp\nci5nYXJyLml0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRybtrE0ndZvt7hHlAA\n+e035msGLzANBgkqhkiG9w0BAQUFAAOCAQEAWFusaIXa/wOcsEEvKRA83mFVulM/\nR0lA/D+Zm0LH1SxVEprX7/Iv001U1M5c6ySFWHgR6v7CIHHVpNF+aMr1kNw4U2wc\nXMWli2Htykpd8sgrjx7Eg4+3WITxupXwxbvxU86orNntPcJCASVcDVbrBReC6mZ2\nlxawzxIGWbSVbKo24lUcklBeoMKiG8Itw2/ouzjcmdw3defNBMlZ9akWdFSK1z58\npm4pftMyNdlh91nMxDa0caZ8+7fZcTPs0bFQdivu3vdL1+OcwlAmcloilD54xfiV\n5vGMEoxK1AfQhXgis+ZYJ2VRydbeSS0gEohRmR/53LIOjBfZ6VnKy71yew=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GARR"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GARR"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.garr.it/b/eng"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.garr.it"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GARR"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GARR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso.nikhef.nl/sso/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.nikhef.nl/sso/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2013-11-18T00:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/9b3c7c0e251cbaa2fe441bf93e1e07bc",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nikhef.nl"
              },
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Nikhef"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Nikhef - samenwerkingsverband Stichting voor Fundamenteel Onderzoek der Materie, Universiteit van Amsterdam, Vrije Universiteit Amsterdam, Universiteit Utrecht, en Radboud Universiteit Nijmegen"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/nikhef.png",
                    "height": "48",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Nikhef"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Nikhef"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Nikhef"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.nikhef.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Nikhef - samenwerkingsverband Stichting voor Fundamenteel Onderzoek der Materie, Universiteit van Amsterdam, Vrije Universiteit Amsterdam, Universiteit Utrecht, en Radboud Universiteit Nijmegen"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dspace.jorum.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@jorum.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jorum Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mimas-shib-tech@listserv.manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mimas Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dspace.jorum.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-07-16T17:01:08Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The University of Manchester: Jorum"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://mimas.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Manchester"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vm-jorum-live.mimas.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://content.resourceshare.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dashboard.jorum.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://window.jorum.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dspace.jorum.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "4"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vm-jorum-live.mimas.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://content.resourceshare.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dashboard.jorum.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://window.jorum.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dspace.jorum.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://vm-jorum-live.mimas.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://content.resourceshare.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dashboard.jorum.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://window.jorum.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "4"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dspace.jorum.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "5"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Through Jorum, you can find and share open learning and teaching resources."
                  }
                ],
                "logo": [
                  {
                    "text": "https://census.mimas.ac.uk/jorum_logo_blue20mm.gif",
                    "height": "236",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "236"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Jorum"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFTCCAf2gAwIBAgIJAJbPuHXi0UDYMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXZtLWpvcnVtLWxpdmUwHhcNMTQwNDE2MTIyNDI0WhcNMjQwNDEzMTIyNDI0\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw12bS1qb3J1bS1saXZlMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAvlVUs6QM5xdt/Ri2V+fwBQvsXpOyZhZWC4wd5KeFxg4atgW4\n\t\t\t\t\t\tjN64Lp4YU8KM+tABhiJ5GNhscmXFG9T7AhQN+f0Egg++dhx2n5L82v1D8wif1FGw\n\t\t\t\t\t\tfHMS+JaDFhCfQWaxKzi0C+DMUaB/lqOObX5mV+oBZAadpHroDXuGu13tZixE4Hod\n\t\t\t\t\t\tyORv3NSPHBFkn5Lmx9Hv8PntBqR2PEVpicEaokJtH8S4mXNcY1QEY8D7FlN1BHvR\n\t\t\t\t\t\tirMl/JCDZTV5gw2axLFuGeholiqsZwKZvXRTXy9WYoqfxEio5r4pSctSM9ounb0H\n\t\t\t\t\t\t4ILOUI9xMIiGf/jHD1OrHhWNwd63LzuBYC3RsQIDAQABo2IwYDA/BgNVHREEODA2\n\t\t\t\t\t\tgg12bS1qb3J1bS1saXZlhiVodHRwczovL2RzcGFjZS5qb3J1bS5hYy51ay9zaGli\n\t\t\t\t\t\tYm9sZXRoMB0GA1UdDgQWBBTgE6iCbBgMAYLkrgLLpsJoDsFYGzANBgkqhkiG9w0B\n\t\t\t\t\t\tAQUFAAOCAQEAg9kbdbOQ3PAeGUhokP5PUJeB3wp0IPGWK6d9TijrW2/ArFiGlJtT\n\t\t\t\t\t\t1bri8JBAesX7ufonRR5MOXukpz9DHqhJxqcoE1RfJ+xvoZbvCuP+WdxPg/ya7/tZ\n\t\t\t\t\t\toiWM+mj+Y8lA35dptThCE3yW4c4n3YXwwZEgaYgmTsNODOD/6JrbNNj9/LS6xKyE\n\t\t\t\t\t\t0oFQi38QenBFAmRz7GQjCfMg7upZZE1Rbq7+l0GNLltBwo+xCjvBZ7C3zBkb+SrI\n\t\t\t\t\t\t2tydmwzbAnZl+iHmbcvRjZdCZfYk/9lYuc6xSA2OJMkad9w/h/jUZdtYTXN/blQR\n\t\t\t\t\t\tRv/EwHdvI+8G8Vuf/3+KmHHcv17aOEeuhA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vm-jorum-live.mimas.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vm-jorum-live.mimas.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vm-jorum-live.mimas.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vm-jorum-live.mimas.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vm-jorum-live.mimas.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vm-jorum-live.mimas.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://content.resourceshare.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://content.resourceshare.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://content.resourceshare.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://content.resourceshare.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://content.resourceshare.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://content.resourceshare.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dashboard.jorum.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dashboard.jorum.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dashboard.jorum.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dashboard.jorum.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dashboard.jorum.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dashboard.jorum.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://window.jorum.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "18"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://window.jorum.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "19"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://window.jorum.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "20"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://window.jorum.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "21"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://window.jorum.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "22"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://window.jorum.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "23"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dspace.jorum.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "24"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dspace.jorum.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "25"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dspace.jorum.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "26"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dspace.jorum.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "27"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dspace.jorum.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "28"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dspace.jorum.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "29"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib.u-paris10.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Driss Bouzekhrout"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "driss@u-paris10.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ga\u00ebl Merlin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "gmerlin@u-paris10.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.u-paris10.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-04-30T10:12:46Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.u-paris10.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.u-paris10.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.u-paris10.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "u-paris10.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.u-paris10.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAAAAAA6mKC9AAAACXBIWXMAAABIAAAASABGyWs+AAAACXZwQWcAAAAQAAAAEABcxq3DAAAAQUlEQVQY04WOMQ4AMAgC+f9L3XkAjWnaqAwOmngoAlBRSsjOUmgTTSdgZPeQeWjZSQ81PQa5OdrVIC+Hyo/4JP0OTEq5NtQeSrYAAAAldEVYdGRhdGU6Y3JlYXRlADIwMTUtMDctMjBUMTA6NDk6NDgrMDI6MDBjnYKrAAAAJXRFWHRkYXRlOm1vZGlmeQAyMDE1LTA3LTIwVDEwOjQ5OjQ4KzAyOjAwEsA6FwAAAABJRU5ErkJggg==",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 Paris Ouest Nanterre La D\u00e9fense"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 Paris Ouest Nanterre La D\u00e9fense"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEbzCCA1egAwIBAgIQZbrrSlxkQhTabmBhnkMIcjANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQyOTAwMDAwMFoXDTE3MDQyODIzNTk1OVowPzEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRowGAYDVQQDExFzaGliLnUtcGFy\naXMxMC5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOXQot32/G4U\n65ArzPTHDzV0pukloeif+NPsD1UJ2jRxzVXdalcqbxIo50XubnqASgfJI8quCcQI\nUivML6Pid61W+G1xaFDFH3oqv4rUz+3cvl+e3rk/7EOxv6mCIhsagERX6/7tPG6Q\nnhy5yUAmnPXVG+N5c8+VD0tDnL3GY7kUFIl6EK0kYObmdpX8jJZeQ4LmPBGxIAWX\nzonq0y2/2MDAMiiX4qVmTJphw0LpxILXBcP8ODsSu9EIA01iC0hqr0ZJaGnmm9jF\ne5GR856RaR5IYoWDhJ2B5rA0gnAp1ORkDwxW22SISQeWLE6XFV3Zee+7aQBP6qWo\nGYqJMGQgo4ECAwEAAaOCAW4wggFqMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdX\nR+qQ47ntMB0GA1UdDgQWBBQUr2hjbMrOoM0u5PrMn5ks6PmoKzAOBgNVHQ8BAf8E\nBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUH\nAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0fBDMw\nMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5j\ncmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50\nZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29j\nc3AudGNzLnRlcmVuYS5vcmcwHAYDVR0RBBUwE4IRc2hpYi51LXBhcmlzMTAuZnIw\nDQYJKoZIhvcNAQEFBQADggEBAHvXqPlH0S0iV2DZuBMgkVjm0FojB9jefcIojoP+\nW5v120m9tvbtWJmE+xOKQi2y+Zct/SWFDKcV+otWus9O0IyfoZcXHwPmPntlhNkD\nNmIWXzwJnDXnnoc0TG2edyNMmtuQMNIjeDSsnCDbspTfymBdnIYKuuuPLy2hSH+V\nwC8FqLmFxsFhnsy4AYicdZyv2zf5e3zIFbaIqJOunr+K1ovMan9M+B+pme5Da7n9\nHmJ60tKDP/4kWNMI1ciPuZ+tFjQFDjbCZTGEL9fcx2+FpHFBc3rLBFqnU4wTr8g+\ntX8DeAKftA5fK5bves4MG9LRLqWMkHmYHZ40TOv95xpE40k="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 Paris Ouest Nanterre La D\u00e9fense"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.u-paris10.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 Paris Ouest Nanterre La D\u00e9fense"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://aai-login.ehb-schweiz.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41 31 910 38 38"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "EHB"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@ehb-schweiz.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAI"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41 44 268 15 05"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@switch.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SWITCHaai"
          }
        }
      ],
      "entity_id": "https://aai-login.ehb-schweiz.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2016-04-04T08:50:31Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIJAJ3M6RXWA//7MA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\nBAMTGGFhaS1sb2dpbi5laGItc2Nod2Vpei5jaDAeFw0xNDAyMTkwODU4NDNaFw0x\nNzAyMTgwODU4NDNaMCMxITAfBgNVBAMTGGFhaS1sb2dpbi5laGItc2Nod2Vpei5j\naDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANAN2avTSONQyVmUrout\niUiLIOr76jMCW6TZ48uvUHt0D+GxPmbkE5lMxVpmTvBxsMd687o6IqFsqMw3pSzt\nhyJ/Zl+T7HCANhPKKUQTNd1X/OX6L1QAi6r88dgcZtlM7RYRwoj8fJ+EFk6WhJuJ\n74UcJHKYx0U9dYY2B25ld+GM1Ah0NikNf2pE+Hw2J0l+O37QpG7aI6GzqYYCkD3V\nqI5BvMkK5EzFZI1FBNYcahBsHyIrP7c+GLTJsBEbBvzbxN/GX8zT7Em1KCpNllu4\nDEqk3f8ZjWJFFJlcgHVKF+DUxswr7PoU/QhH1yMcy4+CHP138kCoOJdhfAN7dEtf\n7M8CAwEAAaN3MHUwVAYDVR0RBE0wS4IYYWFpLWxvZ2luLmVoYi1zY2h3ZWl6LmNo\nhi9odHRwczovL2FhaS1sb2dpbi5laGItc2Nod2Vpei5jaC9pZHAvc2hpYmJvbGV0\naDAdBgNVHQ4EFgQUhierWG+h39Wt/g62bByZw6xwTU4wDQYJKoZIhvcNAQEFBQAD\nggEBAIJofpvKjzSqGnON+rSXn94cs4ubAkuOQEn/XjnoJByMAFXWGcoEK9O8bFfE\nRDAeY/JqRUf72oToSEnOW25EtHZI+76H6Vss0PQ2OG4xfndgjIJeWkkR1nnSVrnh\nYRbHTwUna9v06DXYR4C6cwOEc/AyWLL7cdHb0cnydLAaNxgF7JYrPvMtGxCgoQtm\nrzLxebDkJ/9NyB0ChJh1MiYoHgo4DqnMGNAFg8wKEoRjbTAvR+/urdtomR+DEhXF\n6q5pVoS+6mcH5JbAAaMlP3IMdqMtlXQLZfrrIki4oK1oKmG47Im25K9sucNtCmmk\nSMtMXUOPoo2ywvrbXUtGDDHFJYE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ehb-schweiz.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-login.ehb-schweiz.ch/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-login.ehb-schweiz.ch/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aai-login.ehb-schweiz.ch/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai-login.ehb-schweiz.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai-login.ehb-schweiz.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ehb-schweiz.ch"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ehb-schweiz.ch"
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ehb-schweiz.ch"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ehb-schweiz.ch"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ehb-schweiz.ch"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Das eidgen\u00f6ssische Hochschulinstitut f\u00fcr Berufsbildung"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Swiss Federal Institute for Vocational Education and Training"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Institut f\u00e9d\u00e9ral des hautes \u00e9tudes en formation professionnelle"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Istituto Universitario Federale per la Formazione Professionale"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "29",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EHB / IFFP / IUFFP - Das eidgen\u00f6ssische Hochschulinstitut f\u00fcr Berufsbildung"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SFIVET - Swiss Federal Institute for Vocational Education and Training"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EHB / IFFP / IUFFP - Institut f\u00e9d\u00e9ral des hautes \u00e9tudes en formation professionnelle"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EHB / IFFP / IUFFP - Istituto Universitario Federale per la Formazione Professionale"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "ehb-schweiz.ch"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "iffp-suisse.ch"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "iuffp-svizzera.ch"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIJAJ3M6RXWA//7MA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\nBAMTGGFhaS1sb2dpbi5laGItc2Nod2Vpei5jaDAeFw0xNDAyMTkwODU4NDNaFw0x\nNzAyMTgwODU4NDNaMCMxITAfBgNVBAMTGGFhaS1sb2dpbi5laGItc2Nod2Vpei5j\naDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANAN2avTSONQyVmUrout\niUiLIOr76jMCW6TZ48uvUHt0D+GxPmbkE5lMxVpmTvBxsMd687o6IqFsqMw3pSzt\nhyJ/Zl+T7HCANhPKKUQTNd1X/OX6L1QAi6r88dgcZtlM7RYRwoj8fJ+EFk6WhJuJ\n74UcJHKYx0U9dYY2B25ld+GM1Ah0NikNf2pE+Hw2J0l+O37QpG7aI6GzqYYCkD3V\nqI5BvMkK5EzFZI1FBNYcahBsHyIrP7c+GLTJsBEbBvzbxN/GX8zT7Em1KCpNllu4\nDEqk3f8ZjWJFFJlcgHVKF+DUxswr7PoU/QhH1yMcy4+CHP138kCoOJdhfAN7dEtf\n7M8CAwEAAaN3MHUwVAYDVR0RBE0wS4IYYWFpLWxvZ2luLmVoYi1zY2h3ZWl6LmNo\nhi9odHRwczovL2FhaS1sb2dpbi5laGItc2Nod2Vpei5jaC9pZHAvc2hpYmJvbGV0\naDAdBgNVHQ4EFgQUhierWG+h39Wt/g62bByZw6xwTU4wDQYJKoZIhvcNAQEFBQAD\nggEBAIJofpvKjzSqGnON+rSXn94cs4ubAkuOQEn/XjnoJByMAFXWGcoEK9O8bFfE\nRDAeY/JqRUf72oToSEnOW25EtHZI+76H6Vss0PQ2OG4xfndgjIJeWkkR1nnSVrnh\nYRbHTwUna9v06DXYR4C6cwOEc/AyWLL7cdHb0cnydLAaNxgF7JYrPvMtGxCgoQtm\nrzLxebDkJ/9NyB0ChJh1MiYoHgo4DqnMGNAFg8wKEoRjbTAvR+/urdtomR+DEhXF\n6q5pVoS+6mcH5JbAAaMlP3IMdqMtlXQLZfrrIki4oK1oKmG47Im25K9sucNtCmmk\nSMtMXUOPoo2ywvrbXUtGDDHFJYE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "error_url": "http://support.ehb-schweiz.ch"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EHB / IFFP / IUFFP - Das eidgen\u00f6ssische Hochschulinstitut f\u00fcr Berufsbildung"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SFIVET - Swiss Federal Institute for Vocational Education and Training"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EHB / IFFP / IUFFP - Institut f\u00e9d\u00e9ral des hautes \u00e9tudes en formation professionnelle"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EHB / IFFP / IUFFP - Istituto Universitario Federale per la Formazione Professionale"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ehb-schweiz.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ehb-schweiz.ch/"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ehb-schweiz.ch/"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ehb-schweiz.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ehb-schweiz.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://identity.istat.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Supporto Tecnico"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@istat.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://identity.istat.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2009-12-31T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUGtRU3zo/2OMlhNaUyGcCUcx93HowDQYJKoZIhvcNAQEF\nBQAwHDEaMBgGA1UEAxMRaWRlbnRpdHkuaXN0YXQuaXQwHhcNMTEwMjI0MTEyMTIx\nWhcNMzEwMjI0MTEyMTIxWjAcMRowGAYDVQQDExFpZGVudGl0eS5pc3RhdC5pdDCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMuRDh3nQ52K48KChGDuTuRN\n/DUGcOruszmQXShTktPdfLd5sw15vVKsW1Nenwyoda5c2NUkyE1JfIOBvmbntzg+\ncoCAT5/QKsZymsBgRpOKCbzrXDK3oBO1ptkflLXb91M9lrNN06fhhiduJS4wmAUU\nhAhAV3xRurswE5DSah1I8NmwwbIN5Us4uDKxWoXEn6Z6Y2ugT/ZygbhvjCELu+Ht\nhHggctKBY5bqHbvgf72SWCl6tesRpE8/2HtCXgNeDDyLdVTGZoTa9Ni0vXVcTKuW\n0wlT0LC4Awo44FpBVzsOyGFIJ9S96MV3gzrC88Z4gFkYqeTsEQ7gk7kZuDryLOsC\nAwEAAaNpMGcwRgYDVR0RBD8wPYIRaWRlbnRpdHkuaXN0YXQuaXSGKGh0dHBzOi8v\naWRlbnRpdHkuaXN0YXQuaXQvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFLcpT4bm\nslGxKZUp7NmUOpBoP4ORMA0GCSqGSIb3DQEBBQUAA4IBAQBLCO43R7UyOAycOGPk\nXys3D3GVpLUw51Yr9BRLN16cJkqjRNwOPP1Cyro07i+DK9dp2OQqPDA5XMQy06Ws\nx1spOeR0hbkUTsrSTQVIcg9qoXnL6gDOALsCqB1GXnpp9yDK+HrJoYfRSFEU6GP9\nliKdSZe4QD78Y+MnMLjOtEwRp8fLy5zh0tpKBLDoln1GW+WhAtPCRdAWSr7dZhko\nv430rOfzsqysrxY0NvApAJe4ioA0/kgeJYYPg48F8Tykda2xgBNXaB9gdTR4FyB6\n3t2yL9i9sqXCq4uRlQqUXGzVQuFUX/BxU+Coph5YPhkn3snHBJWKTzpA0ZMwbq1X\nTly+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "istat.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://identity.istat.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://identity.istat.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://identity.istat.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://identity.istat.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://identity.istat.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://identity.istat.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://identity.istat.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://identity.istat.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "istat.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.istat.it/it/informazioni/per-i-ricercatori/accesso-ai-servizi-web"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.istat.it/en/information/researchers"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ISTAT - Italian National Institute of Statistics"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ISTAT - Istituto Nazionale di Statistica"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for ISTAT users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti ISTAT"
                  }
                ],
                "logo": [
                  {
                    "text": "https://identity-ext.istat.it/img/Logo_Istat80.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "207"
                  },
                  {
                    "text": "https://identity-ext.istat.it/img/Logo_Istat16.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "55"
                  },
                  {
                    "text": "https://identity-ext.istat.it/img/Logo_Istat16.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "55"
                  },
                  {
                    "text": "https://identity-ext.istat.it/img/Logo_Istat80.png",
                    "lang": "it",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "207"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://identity.istat.it/idp/informativa.jsp"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUGtRU3zo/2OMlhNaUyGcCUcx93HowDQYJKoZIhvcNAQEF\nBQAwHDEaMBgGA1UEAxMRaWRlbnRpdHkuaXN0YXQuaXQwHhcNMTEwMjI0MTEyMTIx\nWhcNMzEwMjI0MTEyMTIxWjAcMRowGAYDVQQDExFpZGVudGl0eS5pc3RhdC5pdDCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMuRDh3nQ52K48KChGDuTuRN\n/DUGcOruszmQXShTktPdfLd5sw15vVKsW1Nenwyoda5c2NUkyE1JfIOBvmbntzg+\ncoCAT5/QKsZymsBgRpOKCbzrXDK3oBO1ptkflLXb91M9lrNN06fhhiduJS4wmAUU\nhAhAV3xRurswE5DSah1I8NmwwbIN5Us4uDKxWoXEn6Z6Y2ugT/ZygbhvjCELu+Ht\nhHggctKBY5bqHbvgf72SWCl6tesRpE8/2HtCXgNeDDyLdVTGZoTa9Ni0vXVcTKuW\n0wlT0LC4Awo44FpBVzsOyGFIJ9S96MV3gzrC88Z4gFkYqeTsEQ7gk7kZuDryLOsC\nAwEAAaNpMGcwRgYDVR0RBD8wPYIRaWRlbnRpdHkuaXN0YXQuaXSGKGh0dHBzOi8v\naWRlbnRpdHkuaXN0YXQuaXQvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFLcpT4bm\nslGxKZUp7NmUOpBoP4ORMA0GCSqGSIb3DQEBBQUAA4IBAQBLCO43R7UyOAycOGPk\nXys3D3GVpLUw51Yr9BRLN16cJkqjRNwOPP1Cyro07i+DK9dp2OQqPDA5XMQy06Ws\nx1spOeR0hbkUTsrSTQVIcg9qoXnL6gDOALsCqB1GXnpp9yDK+HrJoYfRSFEU6GP9\nliKdSZe4QD78Y+MnMLjOtEwRp8fLy5zh0tpKBLDoln1GW+WhAtPCRdAWSr7dZhko\nv430rOfzsqysrxY0NvApAJe4ioA0/kgeJYYPg48F8Tykda2xgBNXaB9gdTR4FyB6\n3t2yL9i9sqXCq4uRlQqUXGzVQuFUX/BxU+Coph5YPhkn3snHBJWKTzpA0ZMwbq1X\nTly+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ISTAT"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ISTAT"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.istat.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.istat.it/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ISTAT - Istituto Nazionale di Statistica"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ISTAT - Italian National Institute of Statistics"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.karger.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gindensperger"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:n.gindensperger@karger.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nicolas"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hofer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:r.hofer@karger.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roland"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.karger.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-02-21T10:43:07Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Karger Publishers"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.karger.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "S. Karger AG"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.karger.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.karger.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.karger.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.karger.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.karger.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.karger.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.karger.com/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.karger.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.karger.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.karger.com/Shibboleth.sso/UKWAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.karger.com/Shibboleth.sso/dfn-aai",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.karger.com/Shibboleth.sso/dfn-aai",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.karger.com/Shibboleth.sso/gakunin-japan",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.karger.com/Shibboleth.sso/gakunin-japan",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIJAIcP5l5M0JUtMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\n\t\t\t\t\t\tBAMTDnd3dy5rYXJnZXIuY29tMB4XDTE1MDUyMjA5MzAyNFoXDTE4MDUyMjA5MzAy\n\t\t\t\t\t\tNFowGTEXMBUGA1UEAxMOd3d3Lmthcmdlci5jb20wggEiMA0GCSqGSIb3DQEBAQUA\n\t\t\t\t\t\tA4IBDwAwggEKAoIBAQCw4obBIw1EOG4VMPuUvNgbiAwUgTh6sGHvz81LPsB3yE2t\n\t\t\t\t\t\thixSIMxj18+TsDtesVllLJOgTROLMa3XRFlUIUcI7bm4Lv9lrwru3eEJKRKEWSO0\n\t\t\t\t\t\tsyYhFiWdo5G10W7RaNJ5KhNmROo9PUqTIoItJXPGPWzRiRY0gXpzZTJTatzJeh7U\n\t\t\t\t\t\tsEO5O2WIQV1v9WXk38q0CeYH72eI7vqXQJMsv6OXr2X2xCwFfpl1LoQxMAao9tGg\n\t\t\t\t\t\tSr+/Pyo1wWEZiy/GNZX6gK+QIzQhAd9SltSC9wdRt0DMwanXcUxkTFXtSTDSudIB\n\t\t\t\t\t\tFGbD1AkkRllVucmoUqWmzut/wgzD0L8GNzHVqqXtAgMBAAGjXzBdMDwGA1UdEQQ1\n\t\t\t\t\t\tMDOCDnd3dy5rYXJnZXIuY29thiFodHRwczovL3d3dy5rYXJnZXIuY29tL3NoaWJi\n\t\t\t\t\t\tb2xldGgwHQYDVR0OBBYEFNMyL7o+N69sGXXRJMn4O24/yKZdMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQBCSvw1+tIAUZSxTqarmKVxUJi5DZeDV3aqRQq0IJWjIljmYj+UfPaf\n\t\t\t\t\t\tK+/7llfev3DK+gQ2G4EIuUToLxxzQEtwpcaebr91WQwxMYYixaAl38nSaNYMY7P1\n\t\t\t\t\t\t8r+QmB6tYVLN+U1qmgb1FViFGb3HlFJsNUjbSXMOmHYZ6Fs+g2LKryFT3ezv0o16\n\t\t\t\t\t\t/Z9iuT6NnJsi5UAHRiIKAa9BnvRMIogQaJChPwkORUqIEz6GCAf3HXw/Ds2P04M1\n\t\t\t\t\t\tqKmFCc7jKOnls4+t+QmcmxilUL72Hf+dbbB6iCpRLPnaWUxwzrVkL5vEaGHCDVmF\n\t\t\t\t\t\t3rcGxr9Zgf8PmN55LOJrZyh7DG4MCL+F"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.karger.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.karger.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.karger.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.karger.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.karger.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.karger.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.karger.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.karger.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.karger.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.karger.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://clarino.uib.no/",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Meurer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:clarino-tech@uib.no"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "de Smedt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:clarino@uib.no"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Koenraad"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Meurer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:clarino-tech@uib.no"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://clarino.uib.no/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.feide.no/files/feide/metadata-registration-practice-statement.pdf"
              }
            ],
            "registration_instant": "2013-08-20T06:55:04Z",
            "registration_authority": "http://feide.no/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "no",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universitetet i Bergen"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Bergen"
          }
        ],
        "organization_url": [
          {
            "lang": "no",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uib.no"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uib.no"
          }
        ],
        "organization_name": [
          {
            "lang": "no",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universitetet i Bergen"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Bergen"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://clarino.uib.no/feide/single-logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://clarino.uib.no/feide/single-login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://clarino.uib.no/feide/single-login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Norwegian research infrastructure for language data and services, linked to the CLARIN initiative."
                  },
                  {
                    "lang": "no",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Norsk forskningsinfrastruktur for spr\u00e5kdata og -tjenester, knyttet til CLARIN-initiativet."
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Norwegische Forschungsinfrastruktur f\u00fcr Sprachdaten und Dienste im Rahmen der CLARIN-Initiative."
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Norja tutkimusinfrastruktuurin kielen tietojen ja palvelujen, jotka liittyv\u00e4t CLARIN aloitetta."
                  }
                ],
                "logo": [
                  {
                    "text": "https://clarino.uib.no/images/clarino_duo-180.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "180"
                  },
                  {
                    "text": "https://clarino.uib.no/images/clarino_duo-296.png",
                    "height": "106",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "296"
                  },
                  {
                    "text": "https://clarino.uib.no/images/clarino_duo-460.png",
                    "height": "165",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "460"
                  },
                  {
                    "text": "https://clarino.uib.no/images/clarino_duo-740.png",
                    "height": "231",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "740"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://clarino.uib.no/iness/page?page-id=privacy_policy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Clarino, UiB"
                  },
                  {
                    "lang": "no",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Clarino, UiB"
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Clarino, UiB"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Clarino, UiB"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://clarino.uib.no/feide/assertion-consumer",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Clarino, UiB"
                },
                {
                  "lang": "no",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Clarino, UiB"
                },
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Clarino, UiB"
                },
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Clarino, UiB"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Norwegian research infrastructure for language data and services, linked to the CLARIN initiative."
                },
                {
                  "lang": "no",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Norsk forskningsinfrastruktur for spr\u00e5kdata og -tjenester, knyttet til CLARIN-initiativet."
                },
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Norwegische Forschungsinfrastruktur f\u00fcr Sprachdaten und Dienste im Rahmen der CLARIN-Initiative."
                },
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Norja tutkimusinfrastruktuurin kielen tietojen ja palvelujen, jotka liittyv\u00e4t CLARIN aloitetta."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "o",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.digitaltheatreplus.com",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ware"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@digitaltheatre.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jonathan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Britton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@vualto.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Carly"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.digitaltheatreplus.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-04-20T14:56:14Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Digital Theatre Plus"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.digitaltheatreplus.com/about-us"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Digital Theatre.com Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.digitaltheatreplus.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.digitaltheatreplus.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.digitaltheatreplus.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.digitaltheatreplus.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.digitaltheatreplus.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.digitaltheatreplus.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "logo": [
                  {
                    "text": "https://digitaltheatreplus.com/sites/all/themes/digitaltheatreplus/images/logo.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "104"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Digital Theatre Plus"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSzCCAjOgAwIBAgIJAIF+/2SALpqQMA0GCSqGSIb3DQEBBQUAMDcxNTAzBgNV\n\t\t\t\t\t\tBAMTLGlwLTEwLTIxMC0xMzAtMTg1LmV1LXdlc3QtMS5jb21wdXRlLmludGVybmFs\n\t\t\t\t\t\tMB4XDTE1MDMwNTE2NTAzM1oXDTI1MDMwMjE2NTAzM1owNzE1MDMGA1UEAxMsaXAt\n\t\t\t\t\t\tMTAtMjEwLTEzMC0xODUuZXUtd2VzdC0xLmNvbXB1dGUuaW50ZXJuYWwwggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDUhOG8fAf1z+P4MxfipVuLI7gGaTbn\n\t\t\t\t\t\tXRjaqUcvn3q2RfG7uFflGdgTNPESECxFlRhQB9t8r6kP73HpmlDWAb1cK0iTfbVX\n\t\t\t\t\t\tYzKQRZJZuYyk6dTR8Q+ipKA9VwzWCQC4HtFUxrGJJPqUesLUSxmPjwsjQzOdQPVQ\n\t\t\t\t\t\tjB17OYwNSi5lCehWi6kyRpBNmPbB9Vjvx0PtaEe9OFoFOz93hBT6E7rnK6WJ1OSx\n\t\t\t\t\t\tATS6uWOtIwJIBfc1gCtX3L0OLFIEjBXTfoUDhfOJg/VTdudTVDbdy9sI/y9oa1CM\n\t\t\t\t\t\toV5dmFGEmNiCJ+WyVnt0ItkoQ9j1ZT+bw/FVJXFTRSDhDL9NlNsdFz03AgMBAAGj\n\t\t\t\t\t\tWjBYMDcGA1UdEQQwMC6CLGlwLTEwLTIxMC0xMzAtMTg1LmV1LXdlc3QtMS5jb21w\n\t\t\t\t\t\tdXRlLmludGVybmFsMB0GA1UdDgQWBBSfagScxn6u6P0+nvmQwcSLk2XrdDANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAlfdHL72URS71sqrZUfUiUWKHcJU1cfkO2Ekl/zhgRPrS\n\t\t\t\t\t\t7FgP1HUYc9mRbceXJYqq38SSKDPANt3dIj+qeauUh7CNDSTm8pPmjrTaGYZCmOvV\n\t\t\t\t\t\tSTobyosM7a+CJgZvE9Ys7tVlsbainrET0agTjUWOUE3LOvBgUqPUkbbE8QIgmRa2\n\t\t\t\t\t\t62dtMf95WBmt6OJkXmLcBwUVK+1NsOfGN4cg6ekrKqNU4+FobK6Vet2jY6cfLWET\n\t\t\t\t\t\tfYj5FNoRpffRMQ9+MNEm/aK+SFpy1nXtc1XtD1sEqtnLGiIQMUhgEtvnas82T1f1\n\t\t\t\t\t\trxodZ8fzQWvmeZ7qOiheeiTxu5Fwylj1xVBJ7suMMQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.digitaltheatreplus.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.digitaltheatreplus.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.digitaltheatreplus.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.digitaltheatreplus.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.digitaltheatreplus.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.digitaltheatreplus.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.csusb.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jtorner@csusb.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Javier Torner"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "slin@csusb.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sunny Lin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jmacdone@csusb.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James Macdonell"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lenora@csusb.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lenora Rogers"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.csusb.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.csusb.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.csusb.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFkzCCBHugAwIBAgIJAPhN/M4Uk+9nMA0GCSqGSIb3DQEBBQUAMIHgMQswCQYD\nVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEXMBUGA1UEBxMOU2FuIEJlcm5h\ncmRpbm8xNDAyBgNVBAoTK0NhbGlmb3JuaWEgU3RhdGUgVW5pdmVyc2l0eSwgU2Fu\nIEJlcm5hcmRpbm8xKjAoBgNVBAsTIUFkbWluaXN0cmF0aXZlIENvbXB1dGluZyBT\nZXJ2aWNlczEWMBQGA1UEAxMNaWRwLmNzdXNiLmVkdTEpMCcGCSqGSIb3DQEJARYa\naWRlbnRpdHktbWFuYWdlckBjc3VzYi5lZHUwHhcNMTIxMTE0MjI0MDExWhcNMzIx\nMTE0MjI0MDExWjCB4DELMAkGA1UEBhMCVVMxEzARBgNVBAgTCkNhbGlmb3JuaWEx\nFzAVBgNVBAcTDlNhbiBCZXJuYXJkaW5vMTQwMgYDVQQKEytDYWxpZm9ybmlhIFN0\nYXRlIFVuaXZlcnNpdHksIFNhbiBCZXJuYXJkaW5vMSowKAYDVQQLEyFBZG1pbmlz\ndHJhdGl2ZSBDb21wdXRpbmcgU2VydmljZXMxFjAUBgNVBAMTDWlkcC5jc3VzYi5l\nZHUxKTAnBgkqhkiG9w0BCQEWGmlkZW50aXR5LW1hbmFnZXJAY3N1c2IuZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAwASlG0zGEhefU6EcBIVgws1b\nNQv5xBQVw36JiG39KaG3gZIfI1yfLCeb+mzVsa2QKIGYI21wORqPZY7u6x/3OXJY\nZW/1yUmiLAjrL6WkbUBiCORHTH7J051K2eSLaVs6MkgZg1udSfp3mdtmdw3vH0WU\nF5dPndb9FFlFGtqV5ijebO82ZuH2nWrLyBGIQBqOvBg4YGsofHM497ya97ft12Ys\nhGzrOsTnAMvqKbCFSbs2YqCf7iZU2DRHpNUAL81naXXNPUYyMKRKg9IUzmxYeURb\nfhI9yKBjMi7Ofy/KKc9N7AkEkw+4afQi1fdg1raoasxwP3xG62T1GtOvKxMpHwID\nAQABo4IBTDCCAUgwHQYDVR0OBBYEFLttuA7qJP91mlhzWHiqhgjhQExZMIIBFwYD\nVR0jBIIBDjCCAQqAFLttuA7qJP91mlhzWHiqhgjhQExZoYHmpIHjMIHgMQswCQYD\nVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEXMBUGA1UEBxMOU2FuIEJlcm5h\ncmRpbm8xNDAyBgNVBAoTK0NhbGlmb3JuaWEgU3RhdGUgVW5pdmVyc2l0eSwgU2Fu\nIEJlcm5hcmRpbm8xKjAoBgNVBAsTIUFkbWluaXN0cmF0aXZlIENvbXB1dGluZyBT\nZXJ2aWNlczEWMBQGA1UEAxMNaWRwLmNzdXNiLmVkdTEpMCcGCSqGSIb3DQEJARYa\naWRlbnRpdHktbWFuYWdlckBjc3VzYi5lZHWCCQD4TfzOFJPvZzAMBgNVHRMEBTAD\nAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBp8IvcE30f2QPx1Bkh1e1H/+oTLN/IlrSb\n+mpztwDX/2RBk0ScKtkOWpA3nJlByEZYA7vJtpDXY36RlLXM7CGWxTJ5g7izpLnE\n9A4XyoMAvYB+i3mOPI9ZtrL3+Wh8cBe7rAAoMDa8n2h0wdLIV12fYYJFwIW0fg72\njuBt2YirtWhAUY+HR7ApLdlvKKg+gTLxX2YOToR6645jofAzpXXWynvhRyd76W/6\npT7OwkmgJuWT3ilNr4cBTgzYppu+5OftV+9J6h/5BKs+ovA5VpgYx5EymV1WuEdO\nCgPX+7AgL/9d4y21rvonsHXhSYZ+t5WcwEQI8J4uaWuNeLPDSUFJ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csusb.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://iam.csusb.edu/incommon/incommonpop.pdf"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.csusb.edu/banner/Content/images/csusb_logo.gif",
                    "lang": "en",
                    "height": "90",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "217"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://iam.csusb.edu/incommon/incommonpop.pdf"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "California State University, San Bernardino"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California State University, San Bernardino"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csusb.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California State University, San Bernardino"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-04.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-04.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;04"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;04"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-04.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-04.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAL3TXy/wwu+RMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wNC5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTM0MzE0WhcNMjQx\nMDA0MTM0MzE0WjAhMR8wHQYDVQQDExZsYWRvazMtMDQubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzH1KJxI0E4cqpUL1IkUo8d85\n7ApTkh9nye8PEwXbhDKPa7hc0n+Kx3S47TxMoBqurFeXizCcH0sbpMr1z+HozfgE\nENm3RlVjiGQ0wtHYbYv+cdw7rmnf09l1OtG1qqpbeAKyouKd8s0BU6lC3lvRCKmi\nJX+1VX1/YOts3FFlmrs/Pcl035joPzPJIFIIJpr2KPMItqOJLuyQkPohKKM3j8js\n1jicg6MrKWWaVd0BNAUacAUN991KjVW05Q3+QWVgNfhTifTHLcS7Bl0V5TujRTPR\ng4UvFm1y5a18Q5/97aB9IirlZVAAhGnrQlLcSy3Uap0UhM/T1nD5OVn/5797BwID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMDQubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0wNC5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUPPx6zb2rYA7RRQos62PossCqg10wDQYJKoZIhvcNAQEFBQADggEB\nAETFnez41ZpCRZN2iCR1m7X2EK6qWOdiqB2VtAVyxmLHwUk0Odj6/56T2S7+EDCW\nfNhDVQ05fUcKCzK1dhW9l8kdLAMMK8/didPsqwOkv6vOdcPd1qOEiJcjViLkxZGz\nIvmTagde6ULzGzcMsuADFudN3YvVFr6CLmurYT33R1r0NNFxr8+d2RgwvfwvFRYw\nRqJJ+t3s5iLH4GJCSdH73Vwv0uf1xXlCJe6VTC9oYBFxZU3/gQY8/KwZgwqw5+bc\nMC2cthlcSY/kqOuqomLXDUSf/O098apNa7DKrLHOdnOsaDZBqT07RDutNo/d97o6\nNl/wC4jydXm9h5ZdZLZm55Q="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-04.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.croydon.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.croydon.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/croydon.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/croydon.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "croydon.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Croydon College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.croydon.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayf.ibc.dk/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayf.ibc.dk/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2010-08-17T14:05:34Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayf.ibc.dk/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ibc.dk"
              },
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "International Business College"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "International Business College"
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "International Business College"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "International Business College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "ibc.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdwCAQcwDQYJKoZIhvcNAQELBQAwQDE+MDwGA1UEAww1aHR0cHM6Ly93\nYXlmLmliYy5kay9zaW1wbGVzYW1sL3NhbWwyL2lkcC9tZXRhZGF0YS5waHAwHhcN\nMTUwMTAxMDAwMDAwWhcNMjUxMjMxMjM1OTU5WjBAMT4wPAYDVQQDDDVodHRwczov\nL3dheWYuaWJjLmRrL3NpbXBsZXNhbWwvc2FtbDIvaWRwL21ldGFkYXRhLnBocDCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMeIDApqEFO4jhn4gnWuA54S\nIILLdtH1Ah7cGkKx6MUJTmtLORYA2pW5zU8N+nQl0hmGs9eyYMlAyaJ08IY8gNAq\nj5uT5p/f4RQVL8j/7fmxIFfa9/6HUMe9lX2OzOealJWOnsdn9ag9YHKRYEk7QA5W\nbMHnOVqqRLfonvr7DF6vB2m4TFWdhI13vdL4DJP8Rn61cA77qVDwUv9gyUmdSRJp\nKotIcXLTUPaoE2ZhHAGkJLr91RnLGLS3mPyCEpQPgEc5lVq+frknrZwl1eI5wxHJ\nQAinnsZdCsvrcq2uMhxd12r4JnJnm3fsR1Q4jPjaOgVzLvcwU6e3KeUoS87DUEkC\nAwEAATANBgkqhkiG9w0BAQsFAAOCAQEATFSZECgZgCcWTz3iL11Ii+xE8j72mwGG\ntKbHJoCcHhHSnDdOqKrZWGvoMQGKX4qJVXqGjiKQbxLwy0Sdyii9/YELr4SnhDDz\ndU28ZjvdBcUMCXoCqir30c5MT6YbxAe0aCvaIrnMz3b4VNkrQzrWZM4K3ohm1rKU\ncs8J9fcPKijsZNcpQpxNhe9phVc1kUNn9xNTG1eW0f6WdoXsoKz8Jz0QfFrKkDQW\nfxDMnDXCEVeGDaSfpKS59rujNM6pWzUKYjZQiokpUDvikcroFe8BbdhqDwndle76\n57ym2ClZO01259oFVr22gvnX43lKZW7tfsM8i+0ol/wrBPb4BPMfzA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "International Business College"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "International Business College"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ibc.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ibc.dk"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "International Business College"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "International Business College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://gitlab.in2p3.fr/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "webmaster@in2p3.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://gitlab.in2p3.fr/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-10-07T17:38:15Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/collaboratif"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/community"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CNRS"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dsi.cnrs.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CNRS"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://gitlab.in2p3.fr/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Git collaborative hosting intended for IN2P3 staff and their associates."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "H\u00e9bergement git collaboratif \u00e0 l'usage des personnels IN2P3 et de leurs collaborateurs."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://gitlab.in2p3.fr/about/privacy.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IN2P3 - Gitlab"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IN2P3 - Gitlab"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEDCCAfigAwIBAgIJAN4P422/DAqiMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2dpdGxhYi5pbjJwMy5mcjAeFw0xNDEwMTcwOTAyMjZaFw0yNDEwMTQwOTAy\nMjZaMBoxGDAWBgNVBAMTD2dpdGxhYi5pbjJwMy5mcjCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBALc/8+ereTIUyTcBF7sxZGfRdkl2qGOav3hWPPkrRQd6\nwVsgTFS1IrjSAM+v8SUZXCQmEuCiK11RR4hiGo7jt/mHcorD0I5N/b8PHsYLiBVX\n+rw29uP31ufcvKRKgga0KzYFOjer090e0YNt/h2ybPDJWOCSOsOmfYSgiWuVAq2X\nBnEyswPm9t/TvxQLH+UEFwweyNqVi59XxFICfIBqCJ7O+NfEI+x8uNfr++sjkYVJ\nYybukhEftB8pUDC4iBT+S31YT8vO+u1WMakuETm4N2t6Vi1oCzdTwExfDFeT9ptH\nZbEkyQ6jK+kVmxYx3jeWZAPlT4yTfLDqEyoJ2d1J1skCAwEAAaNZMFcwNgYDVR0R\nBC8wLYIPZ2l0bGFiLmluMnAzLmZyhhpodHRwczovL2dpdGxhYi5pbjJwMy5mci9z\ncDAdBgNVHQ4EFgQUubCjI0lAVt2nFgU1JGBhOPkiAr8wDQYJKoZIhvcNAQEFBQAD\nggEBAKzgpHdu8MHO6AmnA6fgbXWLXj+CIcLRGj9yzsyJanRkH1PLetl8QHqcFFDI\n23CYC6DctR6BsjqBW2vFD2sXOqznbp7/yEtkGGjNbFyPrUf9HsDYbUwXPeSF2dbF\nytVhSgqHurk+LzuoWQtr5ZaidBiv4+G8RtwvMhxM1jvwSng6waF1IpEemDzAubAL\negooHKMFutA/QLDwwxnNkVFYY0smKOyPGnpTqe2UMDi7k3UB4LqhckWHqZZdBKA7\nnLSPF5+mIbnSL49lmtebY1RDsJOGi17cgKdExkh5+GLBm+A7FWj+uIEE5Rw9tFqW\niFJVpavS2JG8mIKKAznQiZvqphE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEDCCAfigAwIBAgIJAN4P422/DAqiMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2dpdGxhYi5pbjJwMy5mcjAeFw0xNDEwMTcwOTAyMjZaFw0yNDEwMTQwOTAy\nMjZaMBoxGDAWBgNVBAMTD2dpdGxhYi5pbjJwMy5mcjCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBALc/8+ereTIUyTcBF7sxZGfRdkl2qGOav3hWPPkrRQd6\nwVsgTFS1IrjSAM+v8SUZXCQmEuCiK11RR4hiGo7jt/mHcorD0I5N/b8PHsYLiBVX\n+rw29uP31ufcvKRKgga0KzYFOjer090e0YNt/h2ybPDJWOCSOsOmfYSgiWuVAq2X\nBnEyswPm9t/TvxQLH+UEFwweyNqVi59XxFICfIBqCJ7O+NfEI+x8uNfr++sjkYVJ\nYybukhEftB8pUDC4iBT+S31YT8vO+u1WMakuETm4N2t6Vi1oCzdTwExfDFeT9ptH\nZbEkyQ6jK+kVmxYx3jeWZAPlT4yTfLDqEyoJ2d1J1skCAwEAAaNZMFcwNgYDVR0R\nBC8wLYIPZ2l0bGFiLmluMnAzLmZyhhpodHRwczovL2dpdGxhYi5pbjJwMy5mci9z\ncDAdBgNVHQ4EFgQUubCjI0lAVt2nFgU1JGBhOPkiAr8wDQYJKoZIhvcNAQEFBQAD\nggEBAKzgpHdu8MHO6AmnA6fgbXWLXj+CIcLRGj9yzsyJanRkH1PLetl8QHqcFFDI\n23CYC6DctR6BsjqBW2vFD2sXOqznbp7/yEtkGGjNbFyPrUf9HsDYbUwXPeSF2dbF\nytVhSgqHurk+LzuoWQtr5ZaidBiv4+G8RtwvMhxM1jvwSng6waF1IpEemDzAubAL\negooHKMFutA/QLDwwxnNkVFYY0smKOyPGnpTqe2UMDi7k3UB4LqhckWHqZZdBKA7\nnLSPF5+mIbnSL49lmtebY1RDsJOGi17cgKdExkh5+GLBm+A7FWj+uIEE5Rw9tFqW\niFJVpavS2JG8mIKKAznQiZvqphE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gitlab.in2p3.fr/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://gitlab.in2p3.fr/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "IN2P3 - Gitlab"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "IN2P3 - Gitlab"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "H\u00e9bergement git collaboratif \u00e0 l'usage des personnels IN2P3 et de leurs collaborateurs."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Git collaborative hosting intended for IN2P3 staff and their associates."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "uid",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://antimoine.insa-strasbourg.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lahsen BOUZID"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lahsen.bouzid@insa-strasbourg.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Simon SCHERRER"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "simon.scherrer@insa-strasbourg.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://antimoine.insa-strasbourg.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-02-11T08:44:08Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://antimoine.insa-strasbourg.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://antimoine.insa-strasbourg.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://antimoine.insa-strasbourg.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "insa-strasbourg.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.insa-strasbourg.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INSA Strasbourg"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INSA Strasbourg"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDXDCCAkSgAwIBAgIVAKI+qiqDCk9wTTqn7OVAoZrvj/CpMA0GCSqGSIb3DQEB\nBQUAMCcxJTAjBgNVBAMTHGFudGltb2luZS5pbnNhLXN0cmFzYm91cmcuZnIwHhcN\nMTQwMTEzMTAzOTU4WhcNMzQwMTEzMTAzOTU4WjAnMSUwIwYDVQQDExxhbnRpbW9p\nbmUuaW5zYS1zdHJhc2JvdXJnLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\nCgKCAQEAtuM8lRjlVjjmrHq9VtguaOMQL+Wd99BiOs56kL3Mbctg1FwH69LYThCW\n6dOz6WJg/jU/naF7jEikXKc71xGyu7Ph7Iqa9S5hoXXAT8u/0q2nZDeTOraJqKe1\nFMF2RzXhEEMyQO3CiKNK9b+tbKoNZS7FQCixMZklWZPt4EcEKd6jyRq1WYX3dpnb\nr9I/aCdhtK/PGvGe5gKTDoTR2HKyWKJTc/obf8x/vlYIEwiaGgdlqI2KiBE0x48n\nzQdP6XVi3T8ZWbnkLmCfgJtP2C8PtEJuwDRAy0Z9N4DSwvxn5YCVYgBLSi0TLa10\nB/lUqqBezZrTrA9p9Lt8JtGXW5YGHwIDAQABo38wfTBcBgNVHREEVTBTghxhbnRp\nbW9pbmUuaW5zYS1zdHJhc2JvdXJnLmZyhjNodHRwczovL2FudGltb2luZS5pbnNh\nLXN0cmFzYm91cmcuZnIvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFLFkjPZUc9JY\nqrWjldJ/iGGkKAt4MA0GCSqGSIb3DQEBBQUAA4IBAQBSk/wU1mRn4VF2ifmy261K\nDK7uX+t1H1hh8S38fKSFU7HoNXJTV3vQnmBOpYIGC1gtvmb+qjqpNtikU2zO84Gq\nQ0bXHxYF2d9RUP89mKaFxE5uNcXFmlOA3ChZY3pMT5zwAPI/T60tGrex7zci7OLn\nJDAQj/q4Yk9ejx6JTFggQSCCVh+oV/SDIMd2p5AY6H3mto3b6XCk7Lssa8a/D30k\npEkZnhTKdN82eRyynuOR7UDU4tasV4d7Mi/j53f5ihnRcsvwh/pYodjoVYY8cEcZ\nJLnAXYF8coSwh8UN4D/0NHsvTuSOFQc85hGrqacMsvxiQiw9mv01AX5+A5YLEbVQ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INSA Strasbourg"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.insa-strasbourg.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INSA Strasbourg"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://cpauth.icos-cp.eu/saml/cpauth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mirzov"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:oleg.mirzov@nateko.lu.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Oleg"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cpauth.icos-cp.eu/saml/cpauth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Carbon Portal"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://icos-cp.eu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ICOS Carbon Portal"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://cpauth.icos-cp.eu/saml/login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Single Sign On for services of ICOS Carbon Portal. Maintained by the Carbon Portal team at Physical Geography department (nateko.lu.se)."
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Single Sign On tj\u00e4nst f\u00f6r ICOS Kolportalen. Hanteras av Carbon Portal teamet p\u00e5 INES (nateko.lu.se)."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://cpauth.icos-cp.eu/saml/privacyStatement"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Carbon Portal authentication service"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kolportalens autentiseringstj\u00e4nst"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "cpauth.icos-cp.eu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEJzCCAw+gAwIBAgIJANC3VWNs7fbTMA0GCSqGSIb3DQEBCwUAMIGpMQswCQYD\nVQQGEwJTRTERMA8GA1UECAwIU2vDg8KlbmUxDTALBgNVBAcMBEx1bmQxGzAZBgNV\nBAoMEklDT1MgQ2FyYm9uIFBvcnRhbDEfMB0GA1UECwwWQXV0aGVudGljYXRpb24g\nU2VydmljZTEaMBgGA1UEAwwRY3BhdXRoLmljb3MtY3AuZXUxHjAcBgkqhkiG9w0B\nCQEWD2luZm9AaWNvcy1jcC5ldTAeFw0xNTAyMDUxMjI0MzZaFw0yNTAyMDIxMjI0\nMzZaMIGpMQswCQYDVQQGEwJTRTERMA8GA1UECAwIU2vDg8KlbmUxDTALBgNVBAcM\nBEx1bmQxGzAZBgNVBAoMEklDT1MgQ2FyYm9uIFBvcnRhbDEfMB0GA1UECwwWQXV0\naGVudGljYXRpb24gU2VydmljZTEaMBgGA1UEAwwRY3BhdXRoLmljb3MtY3AuZXUx\nHjAcBgkqhkiG9w0BCQEWD2luZm9AaWNvcy1jcC5ldTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAM2QN1jaZJeuPAH+4sVMZKk7vg4JIbUuTMKk0+KIAg5M\nXiVsRiEUjY+LtIncrvA/kf2CIySI0WkbwZMjcDd03hNj4kLWhuyxfOCwDO6DsUbG\nMbyI6HIYWXJp5ljfEEFgtMqT3dDtD5vwq8h4Zy20ukxOoIokKczrAvn4JjkMsj6Z\n0CEAFBC29o4E8PWQbUBgvt6Z+2ao+RHMLD7nZVBx98Occ9KfnYnDDd9Oi1XFe009\nzaSbcqY2RpN8I9hcW/KQf3KnGW5xZ5dr4rhGklCkYr+h0W3xKu+hin8bk91t1Dkr\ngaKl/N7M3Oof3k+7ZBlwaV97es5InWCeNgDxCGkBRNsCAwEAAaNQME4wHQYDVR0O\nBBYEFDcD7MVudooGaNRYqXBYqQi3VzGxMB8GA1UdIwQYMBaAFDcD7MVudooGaNRY\nqXBYqQi3VzGxMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQELBQADggEBABS02eZS\nweXGMJ2fEIy2JH0VhCbjuX/rz+8Hfh9LjzNb3QwKHuwP83yvPqRulV9FYmvOoK8T\nfMou5aW0mZ+QgJNKOrxY5vFxUq6pn3OiYbBu3m1C9ajbU/nx2evzt4+qUwTfHFb+\nZgXpOtmxRekFzVvGZ18BSPJKwAAqqZ11X7skT/NwEAhbgplVPv9WkDmDzqNvHqQJ\nnyRgD2ZqUPU9nEOjGy0gI07dciVcYZQ+CiZeSECIWgQwjDEBDuwMCVAZA6gfdz6C\nKJuN+RUSKPEcxPxle1MiB4MU0ei5X4xUbvLWKn9Ok7TOXg2BpnMAv6eON1wVo0Aa\nD265cqy6Le/toVg="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=cpauth.icos-cp.eu"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://cpauth.icos-cp.eu/saml/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ICOS Carbon Portal"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp-cafe.unifal-mg.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Vitor Renato Alves de Brito"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vitorrenato.brito@unifal-mg.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-cafe.unifal-mg.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEGDCCAwACAQAwDQYJKoZIhvcNAQEFBQAwgdExNDAyBgNVBAoTK1VOSUZBTC1N\nRyAtIFVuaXZlcnNpZGFkZSBGZWRlcmFsIGRlIEFsZmVuYXMxDDAKBgNVBAsTA05U\nSTExMC8GCSqGSIb3DQEJARYidml0b3JyZW5hdG8uYnJpdG9AdW5pZmFsLW1nLmVk\ndS5icjEQMA4GA1UEBxMHQWxmZW5hczEVMBMGA1UECBMMTWluYXMgR2VyYWlzMQsw\nCQYDVQQGEwJCUjEiMCAGA1UEAxMZaWRwLWNhZmUudW5pZmFsLW1nLmVkdS5icjAe\nFw0xNTExMTAxMzEyMzFaFw0xODExMDkxMzEyMzFaMIHRMTQwMgYDVQQKEytVTklG\nQUwtTUcgLSBVbml2ZXJzaWRhZGUgRmVkZXJhbCBkZSBBbGZlbmFzMQwwCgYDVQQL\nEwNOVEkxMTAvBgkqhkiG9w0BCQEWInZpdG9ycmVuYXRvLmJyaXRvQHVuaWZhbC1t\nZy5lZHUuYnIxEDAOBgNVBAcTB0FsZmVuYXMxFTATBgNVBAgTDE1pbmFzIEdlcmFp\nczELMAkGA1UEBhMCQlIxIjAgBgNVBAMTGWlkcC1jYWZlLnVuaWZhbC1tZy5lZHUu\nYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDDHBmgEisSEqnrWP7U\nKIUbVr6klpzrEU2bueirFMtyrqEp8n2myYi68o0QCk9gtj9Bk6cT3fxwfE6fixhb\nW8WTliqaKe0/+rz2A3wGZ3zTR1DerRJ/Oc3aVRCXaovdk2mUeXiStWbWvoHRmIOt\nS3VTvrGMT6hFJ9j4CT8Mu2+dZ77IxII1QOuB4ui2ABot6c2aNoypTHopXKsU3G+c\n6Iod814xXVYKKnvRuim9TeONMAHKtLnusyuDaYk+++o6Af/qVZjwYSZKPde1bCVD\ni4UfO7l0FGGI9yoD3/IdrqkvzkS/sixHnpSIRgsCXj/KxrbNKtY+03uB+XRTvloH\n+7L/AgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAJZafiLaJuJpPb+GAuIDNNf4BAN1\nq2DRKlH1IxdFrqnmpZPLP5UTTZ2BFzMGI6E4rTMbb9E69MFhKsWAC7dIY01wHBZ2\nV1DGt2Af2VDRny+NiGqjihJmP1hJA8kTE86VlS6dOU91EU99od1mzJdGaaRXg9wz\n46ZRsH5xJzABJ9sRPnjgBzJg346xE4qvp0VRcsRxr78dJ+6x6Gi20Tu2LPI1dxan\n7ni2jUR59dSzUWfKKEyYc44UOjRFNws6mK/3/Avjb8WpF4YC4JRzDFOj03WcT1a3\nMcxgODrwkCJuUli5WfbD8W2H7cFcjk11QDnZ0nSJLw4xciRMLvZs0yIUtc4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-cafe.unifal-mg.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-cafe.unifal-mg.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-cafe.unifal-mg.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-cafe.unifal-mg.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-cafe.unifal-mg.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-cafe.unifal-mg.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-cafe.unifal-mg.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-cafe.unifal-mg.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unifal-mg.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unifal-mg.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNIFAL-MG - Universidade Federal de Alfenas"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNIFAL-MG - Universidade Federal de Alfenas"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNIFAL-MG - Universidade Federal de Alfenas"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNIFAL-MG - Universidade Federal de Alfenas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEGDCCAwACAQAwDQYJKoZIhvcNAQEFBQAwgdExNDAyBgNVBAoTK1VOSUZBTC1N\nRyAtIFVuaXZlcnNpZGFkZSBGZWRlcmFsIGRlIEFsZmVuYXMxDDAKBgNVBAsTA05U\nSTExMC8GCSqGSIb3DQEJARYidml0b3JyZW5hdG8uYnJpdG9AdW5pZmFsLW1nLmVk\ndS5icjEQMA4GA1UEBxMHQWxmZW5hczEVMBMGA1UECBMMTWluYXMgR2VyYWlzMQsw\nCQYDVQQGEwJCUjEiMCAGA1UEAxMZaWRwLWNhZmUudW5pZmFsLW1nLmVkdS5icjAe\nFw0xNTExMTAxMzEyMzFaFw0xODExMDkxMzEyMzFaMIHRMTQwMgYDVQQKEytVTklG\nQUwtTUcgLSBVbml2ZXJzaWRhZGUgRmVkZXJhbCBkZSBBbGZlbmFzMQwwCgYDVQQL\nEwNOVEkxMTAvBgkqhkiG9w0BCQEWInZpdG9ycmVuYXRvLmJyaXRvQHVuaWZhbC1t\nZy5lZHUuYnIxEDAOBgNVBAcTB0FsZmVuYXMxFTATBgNVBAgTDE1pbmFzIEdlcmFp\nczELMAkGA1UEBhMCQlIxIjAgBgNVBAMTGWlkcC1jYWZlLnVuaWZhbC1tZy5lZHUu\nYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDDHBmgEisSEqnrWP7U\nKIUbVr6klpzrEU2bueirFMtyrqEp8n2myYi68o0QCk9gtj9Bk6cT3fxwfE6fixhb\nW8WTliqaKe0/+rz2A3wGZ3zTR1DerRJ/Oc3aVRCXaovdk2mUeXiStWbWvoHRmIOt\nS3VTvrGMT6hFJ9j4CT8Mu2+dZ77IxII1QOuB4ui2ABot6c2aNoypTHopXKsU3G+c\n6Iod814xXVYKKnvRuim9TeONMAHKtLnusyuDaYk+++o6Af/qVZjwYSZKPde1bCVD\ni4UfO7l0FGGI9yoD3/IdrqkvzkS/sixHnpSIRgsCXj/KxrbNKtY+03uB+XRTvloH\n+7L/AgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAJZafiLaJuJpPb+GAuIDNNf4BAN1\nq2DRKlH1IxdFrqnmpZPLP5UTTZ2BFzMGI6E4rTMbb9E69MFhKsWAC7dIY01wHBZ2\nV1DGt2Af2VDRny+NiGqjihJmP1hJA8kTE86VlS6dOU91EU99od1mzJdGaaRXg9wz\n46ZRsH5xJzABJ9sRPnjgBzJg346xE4qvp0VRcsRxr78dJ+6x6Gi20Tu2LPI1dxan\n7ni2jUR59dSzUWfKKEyYc44UOjRFNws6mK/3/Avjb8WpF4YC4JRzDFOj03WcT1a3\nMcxgODrwkCJuUli5WfbD8W2H7cFcjk11QDnZ0nSJLw4xciRMLvZs0yIUtc4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNIFAL-MG - Universidade Federal de Alfenas"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNIFAL-MG - Universidade Federal de Alfenas"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unifal-mg.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unifal-mg.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNIFAL-MG - Universidade Federal de Alfenas"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNIFAL-MG - Universidade Federal de Alfenas"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibidp.syr.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "clhoalcr@syr.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Cynthia Hoalcraft"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sleonard@syr.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve Leonard"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kjfallon@syr.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kelly Fallon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibidp.syr.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.syr.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.syr.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUVVcomBH8KzJQ9YGnfZRbSd7sVU4wDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPc2hpYmlkcC5zeXIuZWR1MB4XDTEzMDMyNjEyMDMwM1oX\nDTMzMDMyNjEyMDMwM1owGjEYMBYGA1UEAxMPc2hpYmlkcC5zeXIuZWR1MIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnXRD/fcJFieSaqGw8BVPDNtxCf8R\nj+g8VCkN5fD8bMpFo/aPBoxMAsHstvsdxUZVNy66rarz63Yo79lgCG66APGIx0TK\nUFfFTKx/rWHWfMn2k4/mJydQrxElJfGmiJySXZcqprLIjLxk+kfhH24I4eewnuq5\nilgdx9PXl0ZVzOg3klOQKV4xvlgmSpUcuY18ziA5NO9CH+uaXg4rj4poqNu/w58O\njweoQALZiissFa1W6aIiwJswq/XIbTLcxSWc+QhcOIq7c8eAbKRL7i51sZMAYFOd\ngjlAHw8UcSkm9ibah6p3lFYgHbVQ98f5+fQGhJcHbmjaqr1cOj4Mm1weCwIDAQAB\no2UwYzBCBgNVHREEOzA5gg9zaGliaWRwLnN5ci5lZHWGJmh0dHBzOi8vc2hpYmlk\ncC5zeXIuZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRfOAeHe266XIh5TjMW\nVrQ7WVWzvDANBgkqhkiG9w0BAQUFAAOCAQEAOBXMtSTx1Q9DRC8jU5AJX4tB7XML\nGynS/IT2cxHtRHt5bpukveikqh+vokQf3Vq09pUk8HMXqBvdhPIhIt4wTFapdQwy\nrcuH6S22woObDp/piQegOJ85tZO/0vq6oMfwU03o6y9wcZAKpQp+2uWIaVJszXWs\nTRgUSKBwLA0z3ual+MQ5FDr+flqoThn4OFHxXxjyp4MBd2o5eyMGyCiZ0JH+s0Hc\n5WVUMo7am2UIynA+j+rhpm5rQhTXjkEA1lTHtqDOnALwKzGsXh5trle0tBcs1B1M\n2fzviLyo4jkmqs5KbWl2c5jut2uUl8jmJ6588cy0BHKiiJOwd/+bFTJF8Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "syr.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.syr.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.syr.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibidp.syr.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.syr.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.syr.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.syr.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "syr.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Syracuse University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUVVcomBH8KzJQ9YGnfZRbSd7sVU4wDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPc2hpYmlkcC5zeXIuZWR1MB4XDTEzMDMyNjEyMDMwM1oX\nDTMzMDMyNjEyMDMwM1owGjEYMBYGA1UEAxMPc2hpYmlkcC5zeXIuZWR1MIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnXRD/fcJFieSaqGw8BVPDNtxCf8R\nj+g8VCkN5fD8bMpFo/aPBoxMAsHstvsdxUZVNy66rarz63Yo79lgCG66APGIx0TK\nUFfFTKx/rWHWfMn2k4/mJydQrxElJfGmiJySXZcqprLIjLxk+kfhH24I4eewnuq5\nilgdx9PXl0ZVzOg3klOQKV4xvlgmSpUcuY18ziA5NO9CH+uaXg4rj4poqNu/w58O\njweoQALZiissFa1W6aIiwJswq/XIbTLcxSWc+QhcOIq7c8eAbKRL7i51sZMAYFOd\ngjlAHw8UcSkm9ibah6p3lFYgHbVQ98f5+fQGhJcHbmjaqr1cOj4Mm1weCwIDAQAB\no2UwYzBCBgNVHREEOzA5gg9zaGliaWRwLnN5ci5lZHWGJmh0dHBzOi8vc2hpYmlk\ncC5zeXIuZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRfOAeHe266XIh5TjMW\nVrQ7WVWzvDANBgkqhkiG9w0BAQUFAAOCAQEAOBXMtSTx1Q9DRC8jU5AJX4tB7XML\nGynS/IT2cxHtRHt5bpukveikqh+vokQf3Vq09pUk8HMXqBvdhPIhIt4wTFapdQwy\nrcuH6S22woObDp/piQegOJ85tZO/0vq6oMfwU03o6y9wcZAKpQp+2uWIaVJszXWs\nTRgUSKBwLA0z3ual+MQ5FDr+flqoThn4OFHxXxjyp4MBd2o5eyMGyCiZ0JH+s0Hc\n5WVUMo7am2UIynA+j+rhpm5rQhTXjkEA1lTHtqDOnALwKzGsXh5trle0tBcs1B1M\n2fzviLyo4jkmqs5KbWl2c5jut2uUl8jmJ6588cy0BHKiiJOwd/+bFTJF8Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Syracuse University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.syr.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Syracuse University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ilearn.totton.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dawson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mdawson@totton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dawson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mdawson@totton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ilearn.totton.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-06-01T17:28:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Totton College VLE"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.totton.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Totton College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ilearn.totton.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ilearn.totton.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ilearn.totton.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ilearn.totton.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ilearn.totton.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJAKZfsG5cBfubMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\n\t\t\t\t\t\tBAMTE3NoaWJzcC50b3R0b24uYWMudWswHhcNMTQwNjI0MTIyODU1WhcNMjQwNjIx\n\t\t\t\t\t\tMTIyODU1WjAeMRwwGgYDVQQDExNzaGlic3AudG90dG9uLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA4r2sMGbQOo1P+H+R+IRVJtyP81kg4jv2\n\t\t\t\t\t\t4md08AELOr0UFsgzwQ0Ejod5MY70oz1XLiujGfvQ+1yk/OQ/Rz+o5Ar2/VmpWOS3\n\t\t\t\t\t\ta/P05oZRH18yfqpCGxXTtvvN2aVbMnYwZcolRY0aSGqcqrhVLulIk9HTf8kqmOXk\n\t\t\t\t\t\t4JSw8kabjRd5odtmv8Szo+eZWloqicmfRV/JBOPXdqOwSSuDxDC4ZjqkYNLJiWMh\n\t\t\t\t\t\tzZClrfLIk0W0Rm/FEw9RmB8+7WjjsoYxzqYxn+77IepTz0lkmbpBmB5wv7Fp3RLz\n\t\t\t\t\t\tPows0/Wo0DEjS7kGy5pujzUfsoiNA6ejhQKqByn68s1vXIREkoejZwIDAQABo0Ew\n\t\t\t\t\t\tPzAeBgNVHREEFzAVghNzaGlic3AudG90dG9uLmFjLnVrMB0GA1UdDgQWBBTgyST3\n\t\t\t\t\t\ttKkSHSntzkqR9Iign/WxOTANBgkqhkiG9w0BAQUFAAOCAQEAIoqUB14Nq9Hdw0pp\n\t\t\t\t\t\tFK2l+iYeUaubP2+Bnm2EOSrwjPYZeHaM6bjyq2IRwLQwaO4i67udbYRx6uraZyDG\n\t\t\t\t\t\tulR+N9+l5as0z75gzpqjUkHxVEt+8iZzAkRhjfBOe0n88scgxi1do4N7EDeM+umZ\n\t\t\t\t\t\tclbVLUcDZ6+cEaHyWYIm4ejvZ/Mc51gUoNxVwSBEz7uTkmzXTy3tg2E0HT+LGffK\n\t\t\t\t\t\tSOPe3ZVNxH82t0GT9eVPwABja8T2aWcFkZufeD9skb4vu+7QsfSlGFfS95q/Pa3m\n\t\t\t\t\t\tEulAkrbXTYFy8Xg91X4za6NQ7jydmP3aaPyE0GqqMcbHLq/Gm+qsjG/dHsviHPjQ\n\t\t\t\t\t\tv2u+Ew=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ilearn.totton.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ilearn.totton.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ilearn.totton.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ilearn.totton.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ilearn.totton.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ilearn.totton.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ilearn.totton.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ilearn.totton.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ilearn.totton.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ilearn.totton.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ctksfc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ctksfc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/ctksfc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/ctksfc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ctksfc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Christ the King VI Form College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ctksfc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.reuna.cl/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operaciones@reuna.cl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "REUNA NOC"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lara"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cofre@reuna.cl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alejandro"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.reuna.cl/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "es",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://cofre.reuna.cl/index.php/es/reglas-federacion"
              }
            ],
            "registration_instant": "2012-01-01T00:00:00Z",
            "registration_authority": "http://cofre.reuna.cl",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAMgGajMxYcuCX0BjnEL1yGAy4iHvMA0GCSqGSIb3DQEB BQUAMBcxFTATBgNVBAMTDGlkcC5yZXVuYS5jbDAeFw0xMTExMjkxNjA3MjJaFw0z MTExMjkxNjA3MjJaMBcxFTATBgNVBAMTDGlkcC5yZXVuYS5jbDCCASIwDQYJKoZI hvcNAQEBBQADggEPADCCAQoCggEBAI1sVrn6YL3ric9ZdLHAMumsbxnB/nMk/8Qm pyV+0io8aygQ/tFz3spUbuRbo8y5spj60kyod1037mQc/MbHsEkSlWN7Mssx/+uE 6wPaJFHZ0SGx+wlJC41k7jty7r2/72l3NhZJo5L6sDQuUz30PKYbcpANIPxo+LE6 lgbGYoJTkKpOfnFCoI+GLXKLrJU5Dyu084iq+Xu4Z9qssEkck/FccimMoGvFBt4T LTNSz2AuLcK+H4/thu+TrNkKqH881zZHqqcjTApFNMWd+XMaQ/rUnToKRMqtREBU bUCFQIthnEvvuTZXXbx7LwTMQ7m6xjyU5BUAGGywFHlq1HI76QECAwEAAaNfMF0w PAYDVR0RBDUwM4IMaWRwLnJldW5hLmNshiNodHRwczovL2lkcC5yZXVuYS5jbC9p ZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUsmYmPyA4OX063eSXo0a8l2n13oUwDQYJ KoZIhvcNAQEFBQADggEBAHABa/rRLuijB1iSCWCcKx2hxAjUQswnZWCkEoxKExbB kxcDEKIB9EjIGMtyZasmiZwfqxZB83+EuaUqqow8Ztc4+2HSo61zwXkAT6qq3UMR f6O1UG9P2hb+4JejmjbH+Cl0AnaZGEapFQD3tnNlYtiv4JMmCHjrB5lt1aOkXTgX fEfClN1s9KYi6m7dTrEDmEyz3ua2QlwB/mOzTxQiWWX3ERwgsj8QDQ078U/X619h i2RT2URIEGnc0EleBMFqvGFjoZzobqlNjgataFzLccu0RKf6MRFfLjjgx/9iGvZa BlWcNruQPt+UBJhIBmEmwcJotRH49VLn8PyDPGBea1M="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "reuna.cl"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.reuna.cl:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.reuna.cl:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.reuna.cl/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.reuna.cl/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.reuna.cl/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.reuna.cl/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.reuna.cl:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.reuna.cl:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "reuna.cl"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.reuna.cl"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.reuna.cl"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "REUNA"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "REUNA"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "REUNA"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "REUNA"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAMgGajMxYcuCX0BjnEL1yGAy4iHvMA0GCSqGSIb3DQEB BQUAMBcxFTATBgNVBAMTDGlkcC5yZXVuYS5jbDAeFw0xMTExMjkxNjA3MjJaFw0z MTExMjkxNjA3MjJaMBcxFTATBgNVBAMTDGlkcC5yZXVuYS5jbDCCASIwDQYJKoZI hvcNAQEBBQADggEPADCCAQoCggEBAI1sVrn6YL3ric9ZdLHAMumsbxnB/nMk/8Qm pyV+0io8aygQ/tFz3spUbuRbo8y5spj60kyod1037mQc/MbHsEkSlWN7Mssx/+uE 6wPaJFHZ0SGx+wlJC41k7jty7r2/72l3NhZJo5L6sDQuUz30PKYbcpANIPxo+LE6 lgbGYoJTkKpOfnFCoI+GLXKLrJU5Dyu084iq+Xu4Z9qssEkck/FccimMoGvFBt4T LTNSz2AuLcK+H4/thu+TrNkKqH881zZHqqcjTApFNMWd+XMaQ/rUnToKRMqtREBU bUCFQIthnEvvuTZXXbx7LwTMQ7m6xjyU5BUAGGywFHlq1HI76QECAwEAAaNfMF0w PAYDVR0RBDUwM4IMaWRwLnJldW5hLmNshiNodHRwczovL2lkcC5yZXVuYS5jbC9p ZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUsmYmPyA4OX063eSXo0a8l2n13oUwDQYJ KoZIhvcNAQEFBQADggEBAHABa/rRLuijB1iSCWCcKx2hxAjUQswnZWCkEoxKExbB kxcDEKIB9EjIGMtyZasmiZwfqxZB83+EuaUqqow8Ztc4+2HSo61zwXkAT6qq3UMR f6O1UG9P2hb+4JejmjbH+Cl0AnaZGEapFQD3tnNlYtiv4JMmCHjrB5lt1aOkXTgX fEfClN1s9KYi6m7dTrEDmEyz3ua2QlwB/mOzTxQiWWX3ERwgsj8QDQ078U/X619h i2RT2URIEGnc0EleBMFqvGFjoZzobqlNjgataFzLccu0RKf6MRFfLjjgx/9iGvZa BlWcNruQPt+UBJhIBmEmwcJotRH49VLn8PyDPGBea1M="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "REUNA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.reuna.cl"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "REUNA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://groupes.renater.fr/sympa",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "listmaster@groupes.renater.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://groupes.renater.fr/sympa",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-02-01T11:45:56Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/collaboratif"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/national"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GIP RENATER"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.renater.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GIP RENATER"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://groupes.renater.fr/sympa"
                  }
                ],
                "description": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Universalistes est le service de groupware de RENATER.\n\nIl permet aux utilisateurs de cr\u00e9er des groupes disposant des outils suivants :\n- liste de diffusion\n- wiki\n- prise de rendez-vous\n- sondage"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RENATER - Universalistes"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RENATER - Universalistes"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICoTCCAgqgAwIBAgIJAPdDY8XfnR75MA0GCSqGSIb3DQEBBQUAMEAxCzAJBgNV\nBAYTAkZSMRQwEgYDVQQKEwtHSVAgUkVOQVRFUjEbMBkGA1UEAxMSZ3JvdXBlcy5y\nZW5hdGVyLmZyMB4XDTEyMDQwNDE1MTc1MloXDTMyMDMzMDE1MTc1MlowQDELMAkG\nA1UEBhMCRlIxFDASBgNVBAoTC0dJUCBSRU5BVEVSMRswGQYDVQQDExJncm91cGVz\nLnJlbmF0ZXIuZnIwgZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGBAJGMhk8cQ8Ti\ng+xtLGz5Acg0KpRBndgzMvN4Tp1NAkh+C8+zUfFfiAErA4L7h1P1eeP34z9hXMVH\nBAKdOluSsMRpXeuFsFvw1H2wVrPdrAYWL4HEnhvvmHtUyt7r2+w0AMcoYmYovpJy\nYuLS05aTNRx/NqCaHENcJWjNePy1I7dVAgMBAAGjgaIwgZ8wHQYDVR0OBBYEFGln\nRkCGn5XLH3Pc4q5jx0ysRGN2MHAGA1UdIwRpMGeAFGlnRkCGn5XLH3Pc4q5jx0ys\nRGN2oUSkQjBAMQswCQYDVQQGEwJGUjEUMBIGA1UEChMLR0lQIFJFTkFURVIxGzAZ\nBgNVBAMTEmdyb3VwZXMucmVuYXRlci5mcoIJAPdDY8XfnR75MAwGA1UdEwQFMAMB\nAf8wDQYJKoZIhvcNAQEFBQADgYEALwdiWiyOmhGyozhBa+lT0i+JFKpLJzQUilqI\nBixcuiH/bClNPNA0Rr3gNOlzl5uMxz0s1Dfp+M0mjf1+AgQ5i7Vu3vG2bh10xR9t\nslMraAvScqJOYoi798luASiH/LBBFUXHbPx4zk+JxNDTfXhat6OmWzi/Xld6nRry\ntRX99iQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICoTCCAgqgAwIBAgIJAPdDY8XfnR75MA0GCSqGSIb3DQEBBQUAMEAxCzAJBgNV\nBAYTAkZSMRQwEgYDVQQKEwtHSVAgUkVOQVRFUjEbMBkGA1UEAxMSZ3JvdXBlcy5y\nZW5hdGVyLmZyMB4XDTEyMDQwNDE1MTc1MloXDTMyMDMzMDE1MTc1MlowQDELMAkG\nA1UEBhMCRlIxFDASBgNVBAoTC0dJUCBSRU5BVEVSMRswGQYDVQQDExJncm91cGVz\nLnJlbmF0ZXIuZnIwgZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGBAJGMhk8cQ8Ti\ng+xtLGz5Acg0KpRBndgzMvN4Tp1NAkh+C8+zUfFfiAErA4L7h1P1eeP34z9hXMVH\nBAKdOluSsMRpXeuFsFvw1H2wVrPdrAYWL4HEnhvvmHtUyt7r2+w0AMcoYmYovpJy\nYuLS05aTNRx/NqCaHENcJWjNePy1I7dVAgMBAAGjgaIwgZ8wHQYDVR0OBBYEFGln\nRkCGn5XLH3Pc4q5jx0ysRGN2MHAGA1UdIwRpMGeAFGlnRkCGn5XLH3Pc4q5jx0ys\nRGN2oUSkQjBAMQswCQYDVQQGEwJGUjEUMBIGA1UEChMLR0lQIFJFTkFURVIxGzAZ\nBgNVBAMTEmdyb3VwZXMucmVuYXRlci5mcoIJAPdDY8XfnR75MAwGA1UdEwQFMAMB\nAf8wDQYJKoZIhvcNAQEFBQADgYEALwdiWiyOmhGyozhBa+lT0i+JFKpLJzQUilqI\nBixcuiH/bClNPNA0Rr3gNOlzl5uMxz0s1Dfp+M0mjf1+AgQ5i7Vu3vG2bh10xR9t\nslMraAvScqJOYoi798luASiH/LBBFUXHbPx4zk+JxNDTfXhat6OmWzi/Xld6nRry\ntRX99iQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICjzCCAfigAwIBAgIJANzMu0IV83S0MA0GCSqGSIb3DQEBBQUAMDoxCzAJBgNV\nBAYTAkZSMRAwDgYDVQQKEwdSRU5BVEVSMRkwFwYDVQQDExBiYWJlbC5yZW5hdGVy\nLmZyMB4XDTEyMDEzMTEwNDY1M1oXDTMyMDEyNjEwNDY1M1owOjELMAkGA1UEBhMC\nRlIxEDAOBgNVBAoTB1JFTkFURVIxGTAXBgNVBAMTEGJhYmVsLnJlbmF0ZXIuZnIw\ngZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGBAORAbR40lHI9l3gICzBcydh2DdAW\nvAVzjyyDvhpaMUkAfYEp6lHOfqOC6f1JsGiu3bfWoZqTf1knW+95xnvuMiJAMY8C\n5P0hRgPIkiejYC7igm0JHAeFTya4hzY+ZJKkC/PY6mKZVzWfdBeLZhYozqXiG6Wt\n0x79EYxPbwqNRsxVAgMBAAGjgZwwgZkwHQYDVR0OBBYEFPSl1AwmOjcQTd/nF+F6\nrzkg2/SUMGoGA1UdIwRjMGGAFPSl1AwmOjcQTd/nF+F6rzkg2/SUoT6kPDA6MQsw\nCQYDVQQGEwJGUjEQMA4GA1UEChMHUkVOQVRFUjEZMBcGA1UEAxMQYmFiZWwucmVu\nYXRlci5mcoIJANzMu0IV83S0MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQAD\ngYEAbA8HBZTvGmi1mANKgPKlknYAT9olC6wHuCZI5UHYxaoRv6lY6LA8BjeyFPWy\nxQ9lTeD31gYHQRlu9NxaKFTnay58By/PAkdRzZfpohXFCj2gTX2Vnd/of0F5+4mS\nOcnzyMjo+f3ngAPx/LMg/pxM21R1GzpaZeyz9ErgUvc8MJs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://groupes.renater.fr/sympa/sso_login/federation_cru/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://groupes.renater.fr/sympa/sso_login/federation_cru/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "RENATER - Universalistes"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Universalistes est le service de groupware de RENATER.\n\nIl permet aux utilisateurs de cr\u00e9er des groupes disposant des outils suivants :\n- liste de diffusion\n- wiki\n- prise de rendez-vous\n- sondage"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.weston.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it.helpdesk@weston.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "I.T. Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hofgartner"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Jon.Hofgartner@weston.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.weston.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-01-30T13:30:39Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAPcnzcVGLzEqHB1pMsO1kGPh7IV9MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBsxGTAXBgNVBAMTEGlkcC53ZXN0b24uYWMudWswHhcNMTMwMTE2MTcxMzUy\n\t\t\t\t\t\tWhcNMzMwMTE2MTcxMzUyWjAbMRkwFwYDVQQDExBpZHAud2VzdG9uLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqznc6D9m1YX+EyNAeRfFBVD9\n\t\t\t\t\t\tAyf15/t1kpP4A05WfmENLz+FdM1Kk2bnCrRsjcsO3n++ua/vKouHThHYa8IdFady\n\t\t\t\t\t\tnyC9M/PYDA5hkEwtWG+D32U0+NCwq0ZfDx3sd/BdfBkJHTyebM/yqy4EJRn764Wi\n\t\t\t\t\t\tD9ORI4V6e2q5WbS/u+ujwkfDGOuThsKAAxlnW/fUk+EXjCDoYs8N+ar4GYhKD+w0\n\t\t\t\t\t\th6FVl7NPQ1T1loxstFB47wVCxNloTmBZc8w/6zPPiIaFKVA+/ROQAmDcWbvbA5u6\n\t\t\t\t\t\t4iZhTieGXw8DRim+iqKlrrWpq7CE3IbtC14YXPRQsg8EdT912QOVCkoI+ETd+wID\n\t\t\t\t\t\tAQABo2cwZTBEBgNVHREEPTA7ghBpZHAud2VzdG9uLmFjLnVrhidodHRwczovL2lk\n\t\t\t\t\t\tcC53ZXN0b24uYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFOCbusYezUEQ\n\t\t\t\t\t\tN+uyvBFAD7q+sQtKMA0GCSqGSIb3DQEBBQUAA4IBAQBRLQicI1ilCyx9sQODb0nj\n\t\t\t\t\t\tsd3Za1CHPTweNw1iIWflTEZl3s6qP1caJqmWu38gSqSsJFG9pdGhOOxjPTX9qp/H\n\t\t\t\t\t\t5oqjKIzGmvow5e8rIGUkH1Wy9Xku4U0fcIl8jCH41SumJiBskxNBwrGOQ7ek/pqQ\n\t\t\t\t\t\t7zi0xyckQPto/EzHVKNgLjtOMCzoQTCSc6VuydsvpseiS8PhVz7mE1wObvoXmYzI\n\t\t\t\t\t\tVUPiI5aeGWruZIRk4zgGQEuX9xCofV/Wf0k6yKkV1t5si9aXs66rsGgZLcj5PVD8\n\t\t\t\t\t\ts0O78Bd48FWN4zeRq+RXI1eqpkYlnD07i0S4ICliPBBe0CmFxplfScWzMKVyUip9"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "weston.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.weston.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.weston.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.weston.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.weston.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.weston.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.weston.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.weston.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.weston.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "weston.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAPcnzcVGLzEqHB1pMsO1kGPh7IV9MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBsxGTAXBgNVBAMTEGlkcC53ZXN0b24uYWMudWswHhcNMTMwMTE2MTcxMzUy\n\t\t\t\t\t\tWhcNMzMwMTE2MTcxMzUyWjAbMRkwFwYDVQQDExBpZHAud2VzdG9uLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqznc6D9m1YX+EyNAeRfFBVD9\n\t\t\t\t\t\tAyf15/t1kpP4A05WfmENLz+FdM1Kk2bnCrRsjcsO3n++ua/vKouHThHYa8IdFady\n\t\t\t\t\t\tnyC9M/PYDA5hkEwtWG+D32U0+NCwq0ZfDx3sd/BdfBkJHTyebM/yqy4EJRn764Wi\n\t\t\t\t\t\tD9ORI4V6e2q5WbS/u+ujwkfDGOuThsKAAxlnW/fUk+EXjCDoYs8N+ar4GYhKD+w0\n\t\t\t\t\t\th6FVl7NPQ1T1loxstFB47wVCxNloTmBZc8w/6zPPiIaFKVA+/ROQAmDcWbvbA5u6\n\t\t\t\t\t\t4iZhTieGXw8DRim+iqKlrrWpq7CE3IbtC14YXPRQsg8EdT912QOVCkoI+ETd+wID\n\t\t\t\t\t\tAQABo2cwZTBEBgNVHREEPTA7ghBpZHAud2VzdG9uLmFjLnVrhidodHRwczovL2lk\n\t\t\t\t\t\tcC53ZXN0b24uYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFOCbusYezUEQ\n\t\t\t\t\t\tN+uyvBFAD7q+sQtKMA0GCSqGSIb3DQEBBQUAA4IBAQBRLQicI1ilCyx9sQODb0nj\n\t\t\t\t\t\tsd3Za1CHPTweNw1iIWflTEZl3s6qP1caJqmWu38gSqSsJFG9pdGhOOxjPTX9qp/H\n\t\t\t\t\t\t5oqjKIzGmvow5e8rIGUkH1Wy9Xku4U0fcIl8jCH41SumJiBskxNBwrGOQ7ek/pqQ\n\t\t\t\t\t\t7zi0xyckQPto/EzHVKNgLjtOMCzoQTCSc6VuydsvpseiS8PhVz7mE1wObvoXmYzI\n\t\t\t\t\t\tVUPiI5aeGWruZIRk4zgGQEuX9xCofV/Wf0k6yKkV1t5si9aXs66rsGgZLcj5PVD8\n\t\t\t\t\t\ts0O78Bd48FWN4zeRq+RXI1eqpkYlnD07i0S4ICliPBBe0CmFxplfScWzMKVyUip9"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Weston College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.weston.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Weston College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ibot.cas.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Van\u00ed\u010dek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vanicekp@utia.cas.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ibot.cas.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2014-12-19T14:43:02Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/avcr"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAMxsLpF35rXDQbU29hCvQ9ID+RqhMA0GCSqGSIb3DQEB\nBQUAMBoxGDAWBgNVBAMTD2lkcC5pYm90LmNhcy5jejAeFw0xNDEyMTUwOTM3MDha\nFw0zNDEyMTUwOTM3MDhaMBoxGDAWBgNVBAMTD2lkcC5pYm90LmNhcy5jejCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKZdXo8BHNDZSJzRLQkKNyg8YnqR\n0MXjl0gFyZXl3FM5MLIZsyBogGpcFf7H0cnOzplcCSxpk5M3yRGKMfX6cjZvoWu1\nA/E9z6NXKte5efB2i/jKYzv6fxujZgRmxuvIilXZMrkXmLEOGCbhmpWy021OD4Vk\nKmtZ+zc1YXDXczPG5ssskhLwP9iVD9jdlL6PBE0+u3f0r+aVnOghDKJj2EnlIua0\njMDQjDAnIcXWYrSPxF2kmOnOYzI8RWvQkIhXLfNLTl//mjKp78WONO30x6A9jbCe\nwb0dsBAsm8JcB3cAHY4wm/DfFW8ns/SpYVc+SDi5BiVlsctsj2AxJXYz/6MCAwEA\nAaNlMGMwQgYDVR0RBDswOYIPaWRwLmlib3QuY2FzLmN6hiZodHRwczovL2lkcC5p\nYm90LmNhcy5jei9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUNB2G4Wu/pmGzpULg\nqY4Gut3/lYcwDQYJKoZIhvcNAQEFBQADggEBAHWmscEAOQ5tG96tRVZC8VCDUQmI\n8bnnnjbF4llfmJfMOSdkfmSE1A+0sMNbE3zT8jY2TXmBMU3YdyzNDyEG0YGRvghW\n3KpaMEzUJsbkOhWnDTaL6VJqATD/YAJlTgOdkeXbu3V2KJnNB5lj7Tb0QPq/krWU\n/by0EpeS+7FueQ22MAI++DSUBv91SXFGMW/TMnb+/+dE50bV+GV4aCKPew4w8OH0\nZalqvP5zKZTaT9xbJbh0K+UDgR8nmrd6QTZnFSoylnbX1O+zEyCagZlQQwEDTIVj\ntTzd0Evm3OfMvzbrxeZcRq8rWk2hWbjtw0GbhBkQm41WEgKL+580ax3w65o="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ibot.cas.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ibot.cas.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ibot.cas.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ibot.cas.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ibot.cas.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ibot.cas.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ibot.cas.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ibot.cas.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ibot.cas.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ibot.cas.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ibot.cas.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ibot.cas.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ibot.cas.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ibot.cas.cz/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ibot.cas.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider IBOT AV CR employees."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance B\u00da AV \u010cR"
                  }
                ],
                "logo": [
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-bu-44.png",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "123"
                  },
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-bu-284.png",
                    "height": "284",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "796"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institut of Botany ASCR"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Botanick\u00fd \u00fastav AV \u010cR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAMxsLpF35rXDQbU29hCvQ9ID+RqhMA0GCSqGSIb3DQEB\nBQUAMBoxGDAWBgNVBAMTD2lkcC5pYm90LmNhcy5jejAeFw0xNDEyMTUwOTM3MDha\nFw0zNDEyMTUwOTM3MDhaMBoxGDAWBgNVBAMTD2lkcC5pYm90LmNhcy5jejCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKZdXo8BHNDZSJzRLQkKNyg8YnqR\n0MXjl0gFyZXl3FM5MLIZsyBogGpcFf7H0cnOzplcCSxpk5M3yRGKMfX6cjZvoWu1\nA/E9z6NXKte5efB2i/jKYzv6fxujZgRmxuvIilXZMrkXmLEOGCbhmpWy021OD4Vk\nKmtZ+zc1YXDXczPG5ssskhLwP9iVD9jdlL6PBE0+u3f0r+aVnOghDKJj2EnlIua0\njMDQjDAnIcXWYrSPxF2kmOnOYzI8RWvQkIhXLfNLTl//mjKp78WONO30x6A9jbCe\nwb0dsBAsm8JcB3cAHY4wm/DfFW8ns/SpYVc+SDi5BiVlsctsj2AxJXYz/6MCAwEA\nAaNlMGMwQgYDVR0RBDswOYIPaWRwLmlib3QuY2FzLmN6hiZodHRwczovL2lkcC5p\nYm90LmNhcy5jei9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUNB2G4Wu/pmGzpULg\nqY4Gut3/lYcwDQYJKoZIhvcNAQEFBQADggEBAHWmscEAOQ5tG96tRVZC8VCDUQmI\n8bnnnjbF4llfmJfMOSdkfmSE1A+0sMNbE3zT8jY2TXmBMU3YdyzNDyEG0YGRvghW\n3KpaMEzUJsbkOhWnDTaL6VJqATD/YAJlTgOdkeXbu3V2KJnNB5lj7Tb0QPq/krWU\n/by0EpeS+7FueQ22MAI++DSUBv91SXFGMW/TMnb+/+dE50bV+GV4aCKPew4w8OH0\nZalqvP5zKZTaT9xbJbh0K+UDgR8nmrd6QTZnFSoylnbX1O+zEyCagZlQQwEDTIVj\ntTzd0Evm3OfMvzbrxeZcRq8rWk2hWbjtw0GbhBkQm41WEgKL+580ax3w65o="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institut of Botany ASCR"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Botanick\u00fd \u00fastav AV \u010cR, v. v. i."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ibot.cas.cz/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ibot.cas.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institut of Botany ASCR"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Botanick\u00fd \u00fastav AV \u010cR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://test.collectionsmanager.is.ed.ac.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:information.systems@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Information Systems"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lddt@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Library Digital Development Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test.collectionsmanager.is.ed.ac.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-08-15T13:32:44Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Edinburgh Collections Manager Test"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://test.collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.collectionsmanager.is.ed.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.collectionsmanager.is.ed.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Test DSpace installation for managing the University\n\t\t\t\t\tof Edinburgh collection level descriptions and collection items."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Edinburgh Collections Manager Test"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJANfNVj1DnlqLMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\n\t\t\t\t\t\tBAMTG2xhYy1yZXBvLXRlc3QxMS5pcy5lZC5hYy51azAeFw0xNDA3MDcwOTE1NTha\n\t\t\t\t\t\tFw0yNDA3MDQwOTE1NThaMCYxJDAiBgNVBAMTG2xhYy1yZXBvLXRlc3QxMS5pcy5l\n\t\t\t\t\t\tZC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJfz6S/b9yYq\n\t\t\t\t\t\tQ/6HeUwaCKwKAJIUuTHj08JTHUWG+75rGMlyqkewe0UZOH9bpa+nNQB5vB8vJCYr\n\t\t\t\t\t\tNDwJzWouBRzei3S54Jg5m3VYo+8iIhR6RxjpgI4tLi5KMt1KKiZxz30bdeC0Qm5m\n\t\t\t\t\t\tk/7/Hzh4H0ipKsfTZpDLA5RjkFrX8YtYQlybcTp/HF6TkEoHtAuMlhctusu+6IbF\n\t\t\t\t\t\tiYqC4cuZdBR+8AkkhZp2R8sLeNFnEtmbm3m9cGzAGhWwWKSxw3VAidLc196KlAgY\n\t\t\t\t\t\tY7OAstjjvTdnLifVmmTDPpyqNN2Grp6KY1CY8grw7HhyFrELgiDedO06lJ2RR9FA\n\t\t\t\t\t\tZkkAc8V1ty8CAwEAAaNJMEcwJgYDVR0RBB8wHYIbbGFjLXJlcG8tdGVzdDExLmlz\n\t\t\t\t\t\tLmVkLmFjLnVrMB0GA1UdDgQWBBQpo+/VuRtYu86j3rJaR52JzNwJIDANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAkEI1AVUowgMd+6N75DXgFvRCaHmzuQ2dUjA8d5WkCxa908W5\n\t\t\t\t\t\t73P3ByJE/gIM0F868bmKjp1qmoNvDnTE7BjQaxwpBwO5EY8Ae1tYyZmVD+tDxcHI\n\t\t\t\t\t\t1ydgtONpYW8dR565/96MAlaZTRhi0fJZkkMkTAiyDv5KwsfmXHvfw0JFeOugobuK\n\t\t\t\t\t\t3QHRD2XfDvsOwuxQbGkkN+NSd4+UZqcnp9hgtWtJHWKOnqyNinhpCNosRVO+CpU4\n\t\t\t\t\t\t4nY9Dg5OwBp5mrZBQp4YLIznVWFaUUz/LilBSy+/c2hbHU6PxEuPuICmkjBtCK++\n\t\t\t\t\t\tIMaAEqSt8zXvVR4i6AWj28qMBpSYddx6Pr5SFw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://test.collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://test.collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://test.collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://test.collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://papi.kfki.hu/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "KFKI AAI"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@kfki.hu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "KFKI AAI"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@kfki.hu"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "KFKI AAI"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@kfki.hu"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://papi.kfki.hu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "urn:schac:homeOrganizationType:hu:nren"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "kfki"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-edugain"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-idps"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:geant:niif.hu:eduid.hu:entity-attributes:processing-info",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "hu",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://metadata.eduid.hu/registration_policy_1_0.txt"
              }
            ],
            "registration_instant": "2013-08-01T07:17:19.807Z",
            "registration_authority": "http://eduid.hu",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://papi.kfki.hu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "papi.kfki.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "papi.kfki.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor"
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://papi.kfki.hu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://papi.kfki.hu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://papi.kfki.hu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://papi.kfki.hu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "148.6.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:738:5001::/48"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.48945,18.9497"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "description": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "MTA Wigner Fizikai Kutat\u00f3k\u00f6zpont"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "WIGNER Research Centre for Physics"
                  }
                ],
                "display_name": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "MTA Wigner Fizikai Kutat\u00f3k\u00f6zpont"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WIGNER Research Centre for Physics"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kfki.hu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mail.kfki.hu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sunserv.kfki.hu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rmki.kfki.hu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aeki.kfki.hu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iki.kfki.hu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mfa.kfki.hu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "szfki.hu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wigner.mta.hu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "energia.mta.hu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ttk.mta.hu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "papi.kfki.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "papi.kfki.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MTA Wigner Fizikai Kutat\u00f3k\u00f6zpont"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Central Research Institute for Physics of the Hungarian Academy of Sciences"
          }
        ],
        "organization_url": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kfki.hu/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kfki.hu/indexeng.html"
          }
        ],
        "organization_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "MTA Wigner Fizikai Kutat\u00f3k\u00f6zpont"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Central Research Institute for Physics of the Hungarian Academy of Sciences"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://emrex.its.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://emrex.its.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://emrex.its.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://emrex.its.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://emrex.its.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://emrex.its.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://emrex.its.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://emrex.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://emrex.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "EMREX-projektet st\u00c3\u00b6djer EU:s m\u00c3\u00a5l f\u00c3\u00b6r 2020 att 20% av h\u00c3\u00b6gskolestuderande ska kunna vara mobila under studietiden."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The EMREX project addresses the EU 2020 target that 20% of higher education students should be mobile during their studies."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EMREX produktionsmilj\u00c3\u00b6"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EMREX production site"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "emrex.its.umu.se"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://emrex.its.umu.se/gui-sp"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJAMIUlWJ7xFZzMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGVtcmV4Lml0cy51bXUuc2UwHhcNMTUxMTA1MTQ1MzU5WhcNMjUxMTAyMTQ1\nMzU5WjAbMRkwFwYDVQQDExBlbXJleC5pdHMudW11LnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAu6IPSODdnS66qRsCbLYbc3i8U6tFUmCQ4Z5Ijg/n\n/yYiz0tg/1D7LCxh0ta3p8wF9MxDYh9nhviIU78uMV98NrX75EwF4D+9nW3XXero\ntRHiTlO7hY6CroLIefOsH9ISt0kIKT/mUI1L8ndBvBfCQvyzYEOy9PeOuru2QTg+\ndmDF9OCQPaBcoeoi+3zYLIO6OOAUutip4rnQuznOv8ddveP1HEjrei0XDBrCbIfJ\n0VzCJQdkW0vcIfXT5xwTOJcFYy6b4RPX3JSwENRrClMrunenPte+M5W1YJKCCi4I\nR900EiIufvuv+ZL2Jkklirley+uFnh9knSLIRM98Yy1j5wIDAQABo18wXTA8BgNV\nHREENTAzghBlbXJleC5pdHMudW11LnNlhh9odHRwczovL2VtcmV4Lml0cy51bXUu\nc2UvZ3VpLXNwMB0GA1UdDgQWBBRjTacbXCeuIkCrckKzgf8py2XPYzANBgkqhkiG\n9w0BAQUFAAOCAQEAdYdVEF1mEVnotpfzcrFXkmTsX+UwEXaePE2ZGbxHqSGPQ1mS\n1cWAIupgcxE2/pefCrWKIF+VDWQmVFWcALoQuWQMsya0SC2C5gnxzYQq1L6gkx8R\nHbVhdUuEJ38NPuWCQ3OFrEvdnlAx4NztXp2Gn2ItIeiEl3fLdGB8c/nRh0b09bY4\n1v7OnyOxAouCRGotnyHyd9aTwTVpBhG6LK2LYiA2v90c0fH24+BX4x5hrm54ysG0\nPHSmQco4ELsIfXuqrlyE3kVGajZ1BFwpp0gMGETRZE8nBZzPk0bgwq+hyfNIV2ZL\nuE4uozMTr+nt5X5/0Un+8KCKmppjT10d59uveg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=emrex.its.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://emrex.its.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://emrex.its.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://emrex.its.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://emrex.its.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://emrex.its.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://emrex.its.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://emrex.its.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://emrex.its.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://emrex.its.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idpcnous.cnous.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "equipe.systeme@cnous.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idpcnous.cnous.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-02-07T10:05:15Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idpcnous.cnous.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idpcnous.cnous.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idpcnous.cnous.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cnous.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.cnous.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CNOUS Personnels"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CNOUS Personnels"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEgzCCA2ugAwIBAgIRAN+fTxO99oLKFyV67Q3f9oUwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xMzAxMzAwMDAwMDBaFw0xNjAxMzAyMzU5NTlaMFwxCzAJBgNV\nBAYTAkZSMTEwLwYDVQQKEyhDRU5UIE5BVElPTkFMIERFUyBPRVVWUkVTIFVOSVZF\nUlNJVEFJUkVTMRowGAYDVQQDExFpZHBjbm91cy5jbm91cy5mcjCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAKmDZI9ioaT/upYky/FUoSsDM+ro/CmIlUQx\n878APgpaDBjBE9fDmQ2CYUcrOza6RSSfQPLxI6C6M0bRMSI73qFfipZyaBASRJlU\nK/Ksi2zE99N3+9/C44RoC5GecIw06Dh/XJAmMzMBmZC8DozWzyGqxxUvqjzmS5/X\nNPYUCIio0lATxdxn69AVMAmq13w5FTnQ5szxOs/32NHdhjC1e47i63fiuD0nfbzO\nMjPDGAP3fovPs5WCz6fboVIMvsBQmpJgAYN56OyihdcoDHjN99PeB9m4W8cbt278\n+Vy8FPJai04ewnk9ZV41d7FBQcmJjiLSo1N4Bv6gbwPSuP7dKFECAwEAAaOCAWQw\nggFgMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBSi\n79FoH7qArry8MfcXBjuww+bjoTAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIw\nADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwGAYDVR0gBBEwDzANBgsr\nBgEEAbIxAQICHTA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJl\nbmEub3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUH\nMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYG\nCCsGAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAcBgNVHREEFTAT\nghFpZHBjbm91cy5jbm91cy5mcjANBgkqhkiG9w0BAQUFAAOCAQEAUuPcmzXpxblf\nR0qTWKRTxfQQuH8NxLhQkpsHoARXU3DUKcpNrLkAgio1RAqJpm6S/qLssBxdFPqQ\nUFtI/C45HwIpk+X9gKFYfms5j/cX04y9+6zGJNX/rbQeLuDBmy8Ezak6ANQh0pFc\n4y8Om1X8GZuUdGxc5kN/lTiR87rRtD9Z+JX27C/dCtcvmM240w12EqNP9SsSzd4c\nGgtSQhKmeEnFDu1WDJo3hEgmJ1vual3s2T/+yDWswMdXVdsSVV6gjwMVCMLmhmEQ\nBYCUKfQUTVt7q7XD2d4Jc9DujMUsEUM+narQH37dQbMFli95mGkeqq+Eui33KuHN\njwAZiSN1rg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CNOUS Personnels"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cnous.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CNOUS Personnels"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ukidp.uky.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jawalk00@uky.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Walker"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "wayne@uky.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Wayne Beech"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jawalk00@uky.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Walker"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ukidp.uky.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://ukidp.uky.edu:9443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ukidp.uky.edu:9443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSjCCAjICCQCbrmikPdHPmzANBgkqhkiG9w0BAQUFADBnMRYwFAYDVQQDEw11\na2lkcC51a3kuZWR1MR8wHQYDVQQKExZVbml2ZXJzaXR5IG9mIEtlbnR1Y2t5MQsw\nCQYDVQQGEwJVUzELMAkGA1UECBMCS1kxEjAQBgNVBAcTCUxleGluZ3RvbjAeFw0x\nMTEwMTgxOTQ5NDRaFw0xMjEwMTcxOTQ5NDRaMGcxFjAUBgNVBAMTDXVraWRwLnVr\neS5lZHUxHzAdBgNVBAoTFlVuaXZlcnNpdHkgb2YgS2VudHVja3kxCzAJBgNVBAYT\nAlVTMQswCQYDVQQIEwJLWTESMBAGA1UEBxMJTGV4aW5ndG9uMIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuYHS3PVzqPi6R8aou7xDDuqhi73Y2k2yqKDD\nFWKdyqcPeoMlKf6/TchKimrJMiuXiJJ/353v+00vndl390M4jQFCjfnpVAGewWH3\nXpKTC7+IoKTS8DYYc8ofLqR05HBBz4gUVn0RXA3eH0QsZqR6htVA1pT2L4B/2CHV\neTBp03pCJMo4bF53cBGre8MCSjOhLl2Iq07HrYwju/bNon3VfhqYOIXI2Gx4qd8z\nszw727AuS140fQFjQD4JadKrFP989fOn+VmnZwQMXissSjPMZ4Oce9F1ceeeml7I\nmQa2skWbp5bXzkLnSBmHDr9H8gDxLpguU0cpCPgOlnMCF+4N+QIDAQABMA0GCSqG\nSIb3DQEBBQUAA4IBAQAGJzVURioGPWyaR1NjXPRZV89Y+1Qu2RWHcUongEmbykUb\nE/dr45XPn0iJcacgrjbwmC4sizo4SRwcTyWZlPIY5yaBvbLbuCIKd+V2Ll6ykl9T\nt2Va6IWJyVn22tIc2T+SAEKRo7WxCPTcB7wGJwW7pBWwFvmBIq+bUuc2cwvVWtqK\nAWXHsaU1qI+pSG4EN8MlJVkO93wRFhJGNpSVdRjit2C2S46V7Gg14HDXpLpp3k6d\nc2LrI/F/p1VjQqgbgZE7Y8hUuksnfEeeZqDRv8n7MntEMrynjbbmBRO6YfBIbZ5V\nupCqaFotaUmUrD4IbUB9DCJyhwZjpuU/YoCeYg7K"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDqDCCApACCQDtzdVegR7Y/zANBgkqhkiG9w0BAQUFADCBlTELMAkGA1UEBhMC\nVVMxCzAJBgNVBAgMAktZMRIwEAYDVQQHDAlMZXhpbmd0b24xHzAdBgNVBAoMFlVu\naXZlcnNpdHkgb2YgS2VudHVja3kxCzAJBgNVBAsMAklUMRYwFAYDVQQDDA11a2lk\ncC51a3kuZWR1MR8wHQYJKoZIhvcNAQkBFhBqYXdhbGswMEB1a3kuZWR1MB4XDTEy\nMTAxNTE0MzM1NVoXDTIxMDMwNzE0MzM1NVowgZUxCzAJBgNVBAYTAlVTMQswCQYD\nVQQIDAJLWTESMBAGA1UEBwwJTGV4aW5ndG9uMR8wHQYDVQQKDBZVbml2ZXJzaXR5\nIG9mIEtlbnR1Y2t5MQswCQYDVQQLDAJJVDEWMBQGA1UEAwwNdWtpZHAudWt5LmVk\ndTEfMB0GCSqGSIb3DQEJARYQamF3YWxrMDBAdWt5LmVkdTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAMCF53VOH8KGjVgxCas6voNq091YpgaCWxhfQ+1y\nn8hnoqdJWiOA7oqW73KVtTjrG74iNrYGpGyPVBDP0IN+HSXj6ra1bBMARSO3hn8P\nDdpPs6yvpLIrUD3teoZKm/HuhSCi5bpe466jfCClgske05aHj1qEnZ0j3Q0OioXa\nDjVHTBaq66cmTd5Rr+r94EJkcqujjM4/57dS0FhnxBksemWM5ZHj766ATBSlO1y6\nU6WKCuh0074sspohYP6PiZsjYc6sVDDzf1LE476BQg9kUiYGXjMvLHeOXve7ECRE\n13zOz8uWeMD4wx4AWiQ5GYypaUWE9nWJL3QXOPJ1J3WEZ7UCAwEAATANBgkqhkiG\n9w0BAQUFAAOCAQEATeUZ3tjwRUENWsc2D6vlTDcfo8Zz9a3cbu0WTGOcLXOR5PFl\npnnGpKvkDV//B8TpA1aQxTyjANV9EnSul3yCvopysjbNnwmsd288aKr4v6hqMX+w\nsc9B+OMfUS9u0p7pTA73hpYmOHDk+VCPC3ZSYrvIvT9zm332VCNnoqDN4DrbQK/6\n00+8wbfEOWfVr7r8WpJtAi9Up7/M3QUAZzmt1yYQcDdSMmIj/TTbOyj37l/0Amut\nQ4jR1hdvy5T77bf3frtxPzIJpQbjX5qhcybHEl3gaNVJdKSiQHLSF7EQLEp8CIHD\nYbij4JvaKAm1MP0F8i+qaBH7yflJh6G8J297aw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uky.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://ukidp.uky.edu:443/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ukidp.uky.edu:443/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ukidp.uky.edu:443/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ukidp.uky.edu:443/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://ukidp.uky.edu:9443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ukidp.uky.edu:9443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uky.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Kentucky"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSjCCAjICCQCbrmikPdHPmzANBgkqhkiG9w0BAQUFADBnMRYwFAYDVQQDEw11\na2lkcC51a3kuZWR1MR8wHQYDVQQKExZVbml2ZXJzaXR5IG9mIEtlbnR1Y2t5MQsw\nCQYDVQQGEwJVUzELMAkGA1UECBMCS1kxEjAQBgNVBAcTCUxleGluZ3RvbjAeFw0x\nMTEwMTgxOTQ5NDRaFw0xMjEwMTcxOTQ5NDRaMGcxFjAUBgNVBAMTDXVraWRwLnVr\neS5lZHUxHzAdBgNVBAoTFlVuaXZlcnNpdHkgb2YgS2VudHVja3kxCzAJBgNVBAYT\nAlVTMQswCQYDVQQIEwJLWTESMBAGA1UEBxMJTGV4aW5ndG9uMIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuYHS3PVzqPi6R8aou7xDDuqhi73Y2k2yqKDD\nFWKdyqcPeoMlKf6/TchKimrJMiuXiJJ/353v+00vndl390M4jQFCjfnpVAGewWH3\nXpKTC7+IoKTS8DYYc8ofLqR05HBBz4gUVn0RXA3eH0QsZqR6htVA1pT2L4B/2CHV\neTBp03pCJMo4bF53cBGre8MCSjOhLl2Iq07HrYwju/bNon3VfhqYOIXI2Gx4qd8z\nszw727AuS140fQFjQD4JadKrFP989fOn+VmnZwQMXissSjPMZ4Oce9F1ceeeml7I\nmQa2skWbp5bXzkLnSBmHDr9H8gDxLpguU0cpCPgOlnMCF+4N+QIDAQABMA0GCSqG\nSIb3DQEBBQUAA4IBAQAGJzVURioGPWyaR1NjXPRZV89Y+1Qu2RWHcUongEmbykUb\nE/dr45XPn0iJcacgrjbwmC4sizo4SRwcTyWZlPIY5yaBvbLbuCIKd+V2Ll6ykl9T\nt2Va6IWJyVn22tIc2T+SAEKRo7WxCPTcB7wGJwW7pBWwFvmBIq+bUuc2cwvVWtqK\nAWXHsaU1qI+pSG4EN8MlJVkO93wRFhJGNpSVdRjit2C2S46V7Gg14HDXpLpp3k6d\nc2LrI/F/p1VjQqgbgZE7Y8hUuksnfEeeZqDRv8n7MntEMrynjbbmBRO6YfBIbZ5V\nupCqaFotaUmUrD4IbUB9DCJyhwZjpuU/YoCeYg7K"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDqDCCApACCQDtzdVegR7Y/zANBgkqhkiG9w0BAQUFADCBlTELMAkGA1UEBhMC\nVVMxCzAJBgNVBAgMAktZMRIwEAYDVQQHDAlMZXhpbmd0b24xHzAdBgNVBAoMFlVu\naXZlcnNpdHkgb2YgS2VudHVja3kxCzAJBgNVBAsMAklUMRYwFAYDVQQDDA11a2lk\ncC51a3kuZWR1MR8wHQYJKoZIhvcNAQkBFhBqYXdhbGswMEB1a3kuZWR1MB4XDTEy\nMTAxNTE0MzM1NVoXDTIxMDMwNzE0MzM1NVowgZUxCzAJBgNVBAYTAlVTMQswCQYD\nVQQIDAJLWTESMBAGA1UEBwwJTGV4aW5ndG9uMR8wHQYDVQQKDBZVbml2ZXJzaXR5\nIG9mIEtlbnR1Y2t5MQswCQYDVQQLDAJJVDEWMBQGA1UEAwwNdWtpZHAudWt5LmVk\ndTEfMB0GCSqGSIb3DQEJARYQamF3YWxrMDBAdWt5LmVkdTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAMCF53VOH8KGjVgxCas6voNq091YpgaCWxhfQ+1y\nn8hnoqdJWiOA7oqW73KVtTjrG74iNrYGpGyPVBDP0IN+HSXj6ra1bBMARSO3hn8P\nDdpPs6yvpLIrUD3teoZKm/HuhSCi5bpe466jfCClgske05aHj1qEnZ0j3Q0OioXa\nDjVHTBaq66cmTd5Rr+r94EJkcqujjM4/57dS0FhnxBksemWM5ZHj766ATBSlO1y6\nU6WKCuh0074sspohYP6PiZsjYc6sVDDzf1LE476BQg9kUiYGXjMvLHeOXve7ECRE\n13zOz8uWeMD4wx4AWiQ5GYypaUWE9nWJL3QXOPJ1J3WEZ7UCAwEAATANBgkqhkiG\n9w0BAQUFAAOCAQEATeUZ3tjwRUENWsc2D6vlTDcfo8Zz9a3cbu0WTGOcLXOR5PFl\npnnGpKvkDV//B8TpA1aQxTyjANV9EnSul3yCvopysjbNnwmsd288aKr4v6hqMX+w\nsc9B+OMfUS9u0p7pTA73hpYmOHDk+VCPC3ZSYrvIvT9zm332VCNnoqDN4DrbQK/6\n00+8wbfEOWfVr7r8WpJtAi9Up7/M3QUAZzmt1yYQcDdSMmIj/TTbOyj37l/0Amut\nQ4jR1hdvy5T77bf3frtxPzIJpQbjX5qhcybHEl3gaNVJdKSiQHLSF7EQLEp8CIHD\nYbij4JvaKAm1MP0F8i+qaBH7yflJh6G8J297aw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Kentucky"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uky.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Kentucky"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.swansea-union.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.swansea-union.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-08-23T10:48:58Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swansea University Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.swansea-union.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.swansea-union.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.swansea-union.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.swansea-union.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.swansea-union.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.swansea-union.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.swansea-union.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.swansea-union.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.swansea-union.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.swansea-union.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.swansea-union.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.swansea-union.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.swansea-union.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.swansea-union.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.euppublishing.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.euppublishing.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Atypon Systems: Edinburgh University Press"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.euppublishing.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDrzCCApegAwIBAgIJAPbC/ThktAkhMA0GCSqGSIb3DQEBBQUAMIGWMQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEUMBIGA1UEBxMLU2FudGEgQ2xh\n\t\t\t\t\t\tcmExHTAbBgNVBAoTFEF0eXBvbiBTeXN0ZW1zLCBJbmMuMR0wGwYDVQQLExRBdHlw\n\t\t\t\t\t\tb24gU3lzdGVtcywgSW5jLjEeMBwGA1UEAxMVd3d3LmV1cHB1Ymxpc2hpbmcuY29t\n\t\t\t\t\t\tMB4XDTA5MTEyNTE5MzUxMFoXDTE5MTEyMzE5MzUxMFowgZYxCzAJBgNVBAYTAlVT\n\t\t\t\t\t\tMRMwEQYDVQQIEwpDYWxpZm9ybmlhMRQwEgYDVQQHEwtTYW50YSBDbGFyYTEdMBsG\n\t\t\t\t\t\tA1UEChMUQXR5cG9uIFN5c3RlbXMsIEluYy4xHTAbBgNVBAsTFEF0eXBvbiBTeXN0\n\t\t\t\t\t\tZW1zLCBJbmMuMR4wHAYDVQQDExV3d3cuZXVwcHVibGlzaGluZy5jb20wggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCwvbPrKwrgbolzvuT5ru6f90JUh/P9\n\t\t\t\t\t\tRK+DggKww8r/wmfAi2HDRa51Lcpjp4UosVnV4RjTVBS7G73lRIpbkt29EANAIxLo\n\t\t\t\t\t\tWA/9RgTv4JO3bu0hxrHEkWsX3LCeAOGGAnOO24k3OCKEUeVssm+4u0x4/zKB541Z\n\t\t\t\t\t\tSE8nexXu/PnHZHSgZP4+hQ8D19fRmLLtqaI67SKGuZob60St/JqCgf1/UFFRTmBl\n\t\t\t\t\t\tb8mnre1n6jsl7uTfCh0WEmI9xr7DkVb+z2FxfIzSt4F4atC5ZVvME3lRTvuu0VRZ\n\t\t\t\t\t\tnAnNd+vv1pP7ybRwhroUzRDBUUzLDrc6gRKQAug20gmOy8iculZyjB1xAgMBAAEw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAKX2oU8Q6150mQ5dCH1RFyX3qDYcPTlDOB/uGxHa\n\t\t\t\t\t\t6IPeF2iPF+xh3aZQ6x3qHafDSPREVMELDdDdk+FuS08fOyGoEwX/tr04uKYex8FG\n\t\t\t\t\t\tIxB49UbcuG7QcHlj3aV4RY1u2oztIO/4LUpqCyXrtICSK4JHuXjPdPgwvSlPspig\n\t\t\t\t\t\tyC4ZlUrZ78JZXVOAbXqtaylM7bIvnDhcz+4mwYyijXgRSEygf5XTU87rkZxcvTWv\n\t\t\t\t\t\tehQLiW/fDXfKCHtt3GjXNnU6xGbOtG6XilUD7a/Z5Pm4BhuanO04bmO84Q733a5r\n\t\t\t\t\t\tTParqfMsNJY958o6cyuiHcpuhFjvsp7qkLi/kmTaOk1r6Pc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.euppublishing.com/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.euppublishing.com/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.euppublishing.com/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://junebug.mcc.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "marc.smith@mcc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marc Smith"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://junebug.mcc.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://junebug.mcc.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://junebug.mcc.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://junebug.mcc.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://junebug.mcc.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://junebug.mcc.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mcc.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mott Community College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAPBoW9t0fielvd212h1N5MgEuZUVMA0GCSqGSIb3DQEB\nBQUAMBoxGDAWBgNVBAMTD2p1bmVidWcubWNjLmVkdTAeFw0xMzA1MTYxNTE2MzRa\nFw0zMzA1MTYxNTE2MzRaMBoxGDAWBgNVBAMTD2p1bmVidWcubWNjLmVkdTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ2vmGgtRF4UfZ30ySXHKJ0CMEKV\n2AZkaiXbkN3E08Xr+QvTL7mIzflvoXUN12IAMkCUHnbPzgKVePSxjY3OI/5e48vh\nqd9araq4pB4dII2kCDc5duZ4MoBeX2ZlAc5Bpg+Cn24wtpwqHu4U3fUEWzgNNnnc\nNeyDyC3cYISciggCA62a26wdE42tW6uEibhA5JeuVSgPjbE/fMUPJjY8mjUkGhk8\nWuxtL8P+kWixPk7FFaFMYIaij0J4/Ql6/zkkR95fPqLpSANHgJlzJXrDNxmXUh8E\n4jlnaOxNVs6IAvcEx5UPuI4/1zVGRb2hVX7uXbw/rQYAq3JVD2onFI99I9UCAwEA\nAaNlMGMwQgYDVR0RBDswOYIPanVuZWJ1Zy5tY2MuZWR1hiZodHRwczovL2p1bmVi\ndWcubWNjLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUBclBgSQJE3DPmZEc\nGsnVOIDkzlkwDQYJKoZIhvcNAQEFBQADggEBAEc3/eqA6ogjGSn/+hd9aYmPShFO\nmED1osTk3Yns6oZ3A9TRMAco0I54SjPTkP6vy9urwHTJI6JV7b/wIk9s9DZlwFS9\nlxK6z0u9Q8863SHhdaIHgzmqfnZFO5aDm/L2z2rdAJi6RMmLgfHT/z9AqSOeEewK\nXz2Xa12ODXqbT6o7v6IB6FPP30mM8pbeH5hONcXg1wubBDVBq06YNpWpLtBRP0uM\n6Als7GmwG6Kzt8d09co99CPLCwDmGPgS/LVCL0XixRn6tmlTmf8ljSFwYEqPBiIP\nTI96HuGWzFL4Q5mXqWBbH1c2guyGQH9+31AtSqhqEPSf+nUwZmK5nB2wbBA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mott Community College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mcc.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Mott Community College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idem-idp.ilc.cnr.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Enea"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@ilc.cnr.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alessandro"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Del Gratta"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@ilc.cnr.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Riccardo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@ilc.cnr.it"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idem-idp.ilc.cnr.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2010-09-13T13:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUXkyFgauxs3Gvhmwuh/SlNXsNSc0wDQYJKoZIhvcNAQEF\nBQAwHjEcMBoGA1UEAxMTaWRlbS1pZHAuaWxjLmNuci5pdDAeFw0wOTA0MTcxNTM5\nMzlaFw0yOTA0MTcxNTM5MzlaMB4xHDAaBgNVBAMTE2lkZW0taWRwLmlsYy5jbnIu\naXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCldH2pporkbRUOfzYX\nWk0eARcI/cJeLA1IoAG/UY0fqsWvcNeL5XpJfd/0k6dUW6Rs/FxJ4TMqpwlo8wzX\n8FPHOX4LgZyMyhTL4iSt+aQGL/hkUPhljKblOTNHFZb/wd0K0wAU2qpTHhkMxQw2\naQNf9jwWF3RJZjfKa3vyXzJJiwp/w2ZRGdX3DX3tLVDqMGZKjn9nSKJ/0RGq3moT\n3XmDi58xnro1YOo5XeTfwoXwNoj/OQEkC09xE7ziXWgSm6X9I2WQz3qeCeTkQz6X\nlrs8EcBXk13A+nRiCvh4EakvkkvR0MndmgjGU4SviQOBC3lW8bHrnZ2umeAydA/d\nKHIhAgMBAAGjbTBrMEoGA1UdEQRDMEGCE2lkZW0taWRwLmlsYy5jbnIuaXSGKmh0\ndHBzOi8vaWRlbS1pZHAuaWxjLmNuci5pdC9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4E\nFgQUolK5cLQOplyydlyGGibaknSuMpwwDQYJKoZIhvcNAQEFBQADggEBADf3UkpS\nn1jL36PgbCKtDRkzdsOZybkaDixZw1zZ/AFX7cfJ0E/9/jveXzbIxF1VxHbZvQtl\nwoq3TK2t3R3sr9BN+uF0C/fMXYfwKxTUVwm9z/QxkXrzZWbfrMvLlZaaE4HyeLTk\nVP1W/JE/J2pT9ohGd0qYMoecrcQJRuiSSnb0wXEZqHFROcirBcvtoitOtESU1JQ6\n5eYHD7pnBG2EiQK5oPXh2U1qphgYCliTuWz4PNv5KtQuBJmH3TBeWj8Ku1V/FVdz\nKB5CmOx6J8t5wNaPfSwzWnk1WWNCfw9mSGWS5deY4w9NCNaGTJLA78MOMuvh7uKh\n4oS/xrwwW80e7RU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ilc.cnr.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idem-idp.ilc.cnr.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idem-idp.ilc.cnr.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idem-idp.ilc.cnr.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idem-idp.ilc.cnr.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idem-idp.ilc.cnr.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idem-idp.ilc.cnr.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idem-idp.ilc.cnr.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idem-idp.ilc.cnr.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ilc.cnr.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ilc.cnr.it/en/content/idem-federation"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ilc.cnr.it/it/content/federazione-idem"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CNR Institute for Computational Linguistics \"Antonio Zampolli\""
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CNR Istituto di Linguistica Computazionale \"Antonio Zampolli\""
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for CNR Institute for Computational Linguistics \"Antonio Zampolli\" users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti di CNR Istituto di Linguistica Computazionale \"Antonio Zampolli\""
                  }
                ],
                "logo": [
                  {
                    "text": "https://webmail.ilc.cnr.it/ILC_Logo_IDEM_16x16.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://webmail.ilc.cnr.it/ILC_Logo_IDEM_16x16.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://webmail.ilc.cnr.it/ILC_Logo_IDEM_80x60.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://webmail.ilc.cnr.it/ILC_Logo_IDEM_80x60.png",
                    "lang": "it",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.ilc.cnr.it/en/content/idem-federation-privacy"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.ilc.cnr.it/it/content/privacy-federazione-idem"
                  }
                ]
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:43.718450,10.421310"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUXkyFgauxs3Gvhmwuh/SlNXsNSc0wDQYJKoZIhvcNAQEF\nBQAwHjEcMBoGA1UEAxMTaWRlbS1pZHAuaWxjLmNuci5pdDAeFw0wOTA0MTcxNTM5\nMzlaFw0yOTA0MTcxNTM5MzlaMB4xHDAaBgNVBAMTE2lkZW0taWRwLmlsYy5jbnIu\naXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCldH2pporkbRUOfzYX\nWk0eARcI/cJeLA1IoAG/UY0fqsWvcNeL5XpJfd/0k6dUW6Rs/FxJ4TMqpwlo8wzX\n8FPHOX4LgZyMyhTL4iSt+aQGL/hkUPhljKblOTNHFZb/wd0K0wAU2qpTHhkMxQw2\naQNf9jwWF3RJZjfKa3vyXzJJiwp/w2ZRGdX3DX3tLVDqMGZKjn9nSKJ/0RGq3moT\n3XmDi58xnro1YOo5XeTfwoXwNoj/OQEkC09xE7ziXWgSm6X9I2WQz3qeCeTkQz6X\nlrs8EcBXk13A+nRiCvh4EakvkkvR0MndmgjGU4SviQOBC3lW8bHrnZ2umeAydA/d\nKHIhAgMBAAGjbTBrMEoGA1UdEQRDMEGCE2lkZW0taWRwLmlsYy5jbnIuaXSGKmh0\ndHBzOi8vaWRlbS1pZHAuaWxjLmNuci5pdC9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4E\nFgQUolK5cLQOplyydlyGGibaknSuMpwwDQYJKoZIhvcNAQEFBQADggEBADf3UkpS\nn1jL36PgbCKtDRkzdsOZybkaDixZw1zZ/AFX7cfJ0E/9/jveXzbIxF1VxHbZvQtl\nwoq3TK2t3R3sr9BN+uF0C/fMXYfwKxTUVwm9z/QxkXrzZWbfrMvLlZaaE4HyeLTk\nVP1W/JE/J2pT9ohGd0qYMoecrcQJRuiSSnb0wXEZqHFROcirBcvtoitOtESU1JQ6\n5eYHD7pnBG2EiQK5oPXh2U1qphgYCliTuWz4PNv5KtQuBJmH3TBeWj8Ku1V/FVdz\nKB5CmOx6J8t5wNaPfSwzWnk1WWNCfw9mSGWS5deY4w9NCNaGTJLA78MOMuvh7uKh\n4oS/xrwwW80e7RU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CNR Istituto di Linguistica Computazionale \"Antonio Zampolli\""
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CNR Institute for Computational Linguistics \"Antonio Zampolli\""
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ilc.cnr.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ilc.cnr.it/en"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consiglio Nazionale delle Ricerche (CNR)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National Research Council (CNR)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://webkonto.student.hig.se/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 26 648880"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ITsupport"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "itsupport@hig.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University of G\u00e4vle"
          }
        }
      ],
      "entity_id": "https://webkonto.student.hig.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of G\u00e4vle"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hig.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of G\u00e4vle"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://webkonto.student.hig.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://webkonto.student.hig.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webkonto.student.hig.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://webkonto.student.hig.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://webkonto.student.hig.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://webkonto.student.hig.se"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://webkonto.student.hig.se"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "As a new user you use this service to activate your university user account. You can also use this service to reset your password for your user account after the account activation."
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Denna tj\u00e4nst anv\u00e4nds f\u00f6r att du som ny vid h\u00f6gskolan ska kunna aktivera ditt anv\u00e4ndarkonto vid h\u00f6gskolan. Om du redan har ett aktivt konto kan du s\u00e4tta ett nytt l\u00f6senord om du gl\u00f6mt bort det."
                  }
                ],
                "logo": [
                  {
                    "text": "https://webkonto.student.hig.se/img/cencolor-50.gif",
                    "height": "45",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "https://webkonto.student.hig.se/img/cenfarg-50.gif",
                    "lang": "sv",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "H\u00f6gskolan i G\u00e4vle user account activation and password reset"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "H\u00f6gskolan i G\u00e4vle kontoaktivering och l\u00f6senords\u00e5terst\u00e4llning"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "webkonto.student.hig.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAJCdWHtvPxegMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF3dlYmtvbnRvLnN0dWRlbnQuaGlnLnNlMB4XDTE0MDcwNzEzMTEzOVoXDTI0\nMDcwNDEzMTEzOVowIjEgMB4GA1UEAxMXd2Via29udG8uc3R1ZGVudC5oaWcuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDbkbdp5Rw9feN2s2I8bpcr\nArByM7/xhG/vDJvdskG2P/gozR7dqLN5Q3ODTEsHrBIU1zy0WmrPObk5ogSQ0i99\nSa8i7+vclR95X9NdwGcMli0Jy9hdid0F3LV7f2KG52YNklZAs6P+PhxecZc4x34U\nKJcHaoAEgCnoR4Tu4IR91NabcY5TzobCpz0tM4Qm/zzHlIgx3nTrobiKywhIqIXR\nbnN28Dk8KXOYbB4hfmWxNokZX5VEuHl3f6PKrdqjVYQZSpIeJBwBs3qdEzzZpRcv\nN52cuR13Au1r5eVCiEcHbenCpVHFgKztVIOk5SRz7msLlTaYkaiZ2fpQ0prERJCF\nAgMBAAGjRTBDMCIGA1UdEQQbMBmCF3dlYmtvbnRvLnN0dWRlbnQuaGlnLnNlMB0G\nA1UdDgQWBBT8xqnN4yH+pGC5O7K+gc0SOpKDSDANBgkqhkiG9w0BAQUFAAOCAQEA\np12s+XQqxWHubEcQ+mrx4yhu/J3TT2nv7fG7nJlhNR+06ikaw5m19R/aY2d84/7Z\nSUezzhxHW0iUykuQL2SQ4/vdAc41cUpluDlYDnTRkrprvgOqAM3AkwoNrwzzJQMf\nuo1eWld/TfwoP1KgG6MwufHtbLRziu7O8hsBV3ID8gMFZ/D+FXbaJ0ZVv/iBCgOL\nPIv2AxIMG0AemRDJdyIX8aVz0J7wlqxJ2Kp+626GIA5V2gs5PyB2z/qX4Mpxx4qb\nD5ukg37gzDnhX0VZuLvt9UDX+1NsQaja8PDzhKJSBVkoJalI8WlmYL/VtMsi6QsQ\nmj3ToMT9Iz7u97ghHaP7FQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=webkonto.student.hig.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://webkonto.student.hig.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://webkonto.student.hig.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webkonto.student.hig.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://webkonto.student.hig.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webkonto.student.hig.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://webkonto.student.hig.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://webkonto.student.hig.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://webkonto.student.hig.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://webkonto.student.hig.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.jwatch.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.jwatch.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2014-01-16T18:17:08Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Journal Watch"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jwatch.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HighWire Press, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.highwire.org/applications/jnlwatch/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.highwire.org/applications/jnlwatch/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIJAMTRVlqTJ11lMA0GCSqGSIb3DQEBBQUAMIG+MQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBD\n\t\t\t\t\t\taXR5MRcwFQYDVQQKEw5IaWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUx\n\t\t\t\t\t\tIDAeBgNVBAMTF3NoaWJib2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkB\n\t\t\t\t\t\tFiZzaGliYm9sZXRoLWFkbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTAeFw0xNDA0\n\t\t\t\t\t\tMTUxOTQzMDNaFw0yNDA0MTIxOTQzMDNaMIG+MQswCQYDVQQGEwJVUzETMBEGA1UE\n\t\t\t\t\t\tCBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBDaXR5MRcwFQYDVQQKEw5I\n\t\t\t\t\t\taWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUxIDAeBgNVBAMTF3NoaWJi\n\t\t\t\t\t\tb2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkBFiZzaGliYm9sZXRoLWFk\n\t\t\t\t\t\tbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALPB99M9iWjentrddY/rLgzKn1X0j4Ao191iyiowBBt/r/pmn2oz\n\t\t\t\t\t\tfrbONkkTVBB++mNtiufK6jyKnBM5mffPOkXHRo+K1DQec7TvpQ1PmLv/BpBgPrr9\n\t\t\t\t\t\tldViOSUnYJuB0IgJVV8oylgeH2Ay0XRkNPlBUjBA2fUPWVpXcvFe+aD2tLdVR9uO\n\t\t\t\t\t\tXvfTMxAEGqzxTU+OxO6pW2sBXNBmGvZQ0TRyovQh5+pTURY/lm0V/iWvRmRe51WE\n\t\t\t\t\t\tO/nhYyvRuMmNj8EL38o10S9TXuCkVzY00hK5cclaFge7gz/tfjmadVVcbe8xCVxc\n\t\t\t\t\t\tnb1lhmt1kH2XtKvU5hyZMTO+VUfXQvqcQyECAwEAAaN7MHkwCQYDVR0TBAIwADAs\n\t\t\t\t\t\tBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYD\n\t\t\t\t\t\tVR0OBBYEFJpUZq/XaW9/bPvjffkxX0IDvuPiMB8GA1UdIwQYMBaAFJpUZq/XaW9/\n\t\t\t\t\t\tbPvjffkxX0IDvuPiMA0GCSqGSIb3DQEBBQUAA4IBAQCq/FF56ZB1cL3KbniEJP99\n\t\t\t\t\t\tU9wTD6KpOrWxvqNbUSV1cefLf5cYHonOjy6oAJSSBSNuP7U5Q//0tXtkvlJoqGUY\n\t\t\t\t\t\tvqngmeg9wLZ/Fla3tXcDdTj0n1F+NZOx9vBDacIk0Ua4aHXDA4bdytzkV1QyZDRq\n\t\t\t\t\t\tQ8vq7RoQ8E5IF7Cll+kt2dZXQk8o6Qp3w2ppoMRtYdKOQassqn+V1MYcMPgdxZkS\n\t\t\t\t\t\tDrcgzktR/JMb5OmPrp4mSy1OWDGrFvUIigsLBPZV9tw1f7y42lnbmQas3RCS30yr\n\t\t\t\t\t\tCtUPT/PQDkCdBRViGmmMkYwjdaOTiHOJveWtrVXu8vLvO36pqFF4Kft0pgqlfvAE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.highwire.org/applications/jnlwatch/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.highwire.org/applications/jnlwatch/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.highwire.org/applications/jnlwatch/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.highwire.org/applications/jnlwatch/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.cti.gr/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+30-2610960319"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kokolakis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kokolakis@cti.gr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Giorgos"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@cti.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "CTI \"Diophantus\""
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+30-2610690300"
            }
          ]
        }
      ],
      "entity_id": "https://idp.cti.gr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAPDB3O4Jt71/WaU2UiNReDy9dbsIMA0GCSqGSIb3DQEB\n                            CwUAMBUxEzARBgNVBAMMCmlkcC5jdGkuZ3IwHhcNMTUxMDI3MTgwNzE5WhcNMzUx\n                            MDI3MTcwNzE5WjAVMRMwEQYDVQQDDAppZHAuY3RpLmdyMIIBIjANBgkqhkiG9w0B\n                            AQEFAAOCAQ8AMIIBCgKCAQEAtcmw8xHKAYVkFPvvb9wOelVxKiOj8UhmEadhBS5K\n                            HKSW6yUDmRM1fSZRC4qYzwLlcCUVIxxjWHqaxJh+jmqFAl1HgkRfZfst1LlBfhFe\n                            oPpIFg/8++WCDi97/9UA9R6QxslxDCfQO6Pm4AZbXJyd+ihWPW2UB2vmsrbM1cII\n                            t49nFbjAF8XTiF+mYGtyxFCGnjNwLE/KeoBWmC1XebZDA2VjEBW43Q8cGmTgzfbh\n                            +njsMVsDHFfx5DzPMUgdIvKW++EJCj/Sgi/xxI9Rtyd/wDClIcWocnOFQQ7a2Ego\n                            N7LQmPp/WBKTDeZQ7xcT8hzU38Rys8o1aKnw10tpGbo88wIDAQABo1swWTAdBgNV\n                            HQ4EFgQUa/1IvZV5VVEpl5dqjg+8VQZLxN0wOAYDVR0RBDEwL4IKaWRwLmN0aS5n\n                            coYhaHR0cHM6Ly9pZHAuY3RpLmdyL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\n                            CwUAA4IBAQCDj/Q4Y9wJ8Ao81kfngAPdCeVKhoiT9lFZeJRBUFZXwSvdZa76CXnb\n                            RBcroGskxN+FdBCtXbnHFRWzY4NAiCItk41HHkf9sW1DeYoA2v11VFGdSCwMh4hq\n                            AyI+5OnH4gG2GZa1A2U/IRDGryG/PejE3KJjc06UKtszSPsgCLIn8BWUvfVZoP4v\n                            G85dA66o50DcG9OKY8l1QON6IcrsWVqlTaMSGYMu2tHsXeN7wZakHUz/jbhKqA/E\n                            CKL20oxVcOZjco6xEjM6oaiHI4dDr9wO9lF3TA+DcWSdRrCprSPalVzVn8HmUhOc\n                            K/B20docwc7tKIOQGaEpjo2lmbquG/ib"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAKCs+DufmEJRT/Iei5Y37ZP32r4sMA0GCSqGSIb3DQEB\n                            CwUAMBUxEzARBgNVBAMMCmlkcC5jdGkuZ3IwHhcNMTUxMDI3MTgwNzE2WhcNMzUx\n                            MDI3MTcwNzE2WjAVMRMwEQYDVQQDDAppZHAuY3RpLmdyMIIBIjANBgkqhkiG9w0B\n                            AQEFAAOCAQ8AMIIBCgKCAQEA3/Sl3y8hjZ0PnfIyr/OnxNtJQaLdH3YbKnqJIc/r\n                            /zgcYgOQp1abbZa+QEECx9KSSaQUzM+M1PS3k8SS/A7xRRXr2KaUyCMTEcZXeeEw\n                            0PG8++SbZcgYIqOEJl2w6AX7gy/RLiIalqlfJBFVe6677pigTi4QgSNFTelzx4Ul\n                            mtlypAHXTLzTJUCarlxEQ61HdBvFg9tUuKDPKHGe8OJMsszfBkcw8FXNrnTAGLcy\n                            T5moao+qw4BnPLL2TmxIbRYJ9TfTLmVXJ3/5/g0RWvJ+4/k6IxOoAlZPbHVFP0UQ\n                            dNgcqDvI2GEgNnOWhqL/5R/Sk60VP+txj96U7fAhSUGTAwIDAQABo1swWTAdBgNV\n                            HQ4EFgQU+p3GP2Ho/99FAqc0Zrf3RhityqIwOAYDVR0RBDEwL4IKaWRwLmN0aS5n\n                            coYhaHR0cHM6Ly9pZHAuY3RpLmdyL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\n                            CwUAA4IBAQAPtqj6FtNvluE3YnnwzAPdDF2/yUHpH+Z7y9o5YWyyhqGUevXh1sJ3\n                            VWM9HHjGZvCSvBHFL9UwolQYuj59LT2InnwzDO2Hypl6uP805Fqz5yaFAzCLt1eI\n                            +AMc8xozRUROqQbRm0/qJ+jIACWqcWkShBckqI6c0K6EZvBjmqi0cRuQMoq32fGJ\n                            RxmX9FlIgBD/UBb9djP5GYZTqwF+SY/ZNrXGSdn9eNfQffLhvRj4Z4IaShG1E7xZ\n                            aZOQwUGSYAxOQ1t5ECcLon8toelZ4gPCBd65HRt9DRiHH3llPX0bhTLgEWJoJGXD\n                            32KKXNIN34sD1e3mqloO1Xq0z6x8OgHD"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEzCCAfugAwIBAgIUSKHnO5Jifa6uUWyYYBAzykF1pmcwDQYJKoZIhvcNAQEL\n                            BQAwFTETMBEGA1UEAwwKaWRwLmN0aS5ncjAeFw0xNTEwMjcxODA3MThaFw0zNTEw\n                            MjcxNzA3MThaMBUxEzARBgNVBAMMCmlkcC5jdGkuZ3IwggEiMA0GCSqGSIb3DQEB\n                            AQUAA4IBDwAwggEKAoIBAQCZAFgMwehKNSh+awk9loDhabToZbjuua3mShc7OW5k\n                            5nb4SpIOVwasJ54bY9UH1Y1+qS8Hd+xIUGGqs7U5ONRhRRqQ7CubqNoNF5zpKHbI\n                            +sBNfelcwEc8FaxGMcwKuu53sMwIvdlWEU0/AiPjYOAZpqYtmggUPSnnlaxkYF7e\n                            ctT8swrgJb0KotcyvxWmh2aB1YH01A0bb99acIo8Pjmj+0llABRGsZ5xxA8LgsoI\n                            UziyMdbzPnfcuhGa7aJXFCs8InJj4aXu/QXATIfP12+8e2vPJltFSOL5XIWpXa3O\n                            jKW7wUlWBqZxUO1d6j8jPJYFsjgDZCRnXw5oU0VsQkMDAgMBAAGjWzBZMB0GA1Ud\n                            DgQWBBTACXTvIIdNP2fzze/sSnbZrsbiszA4BgNVHREEMTAvggppZHAuY3RpLmdy\n                            hiFodHRwczovL2lkcC5jdGkuZ3IvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEL\n                            BQADggEBAF16I4lbJsZl6wtWs4E+C0e4td1FwsdNtOLKZ/C3ZYi3/2RWcVs3gfzJ\n                            76wu5AHrtcfYwRjuZkVD3sDQca579qF84js3wSvT27uxqZYU6WfGHwHGjkMoo/WR\n                            6ZTa6Aa58KRJTnAIAMCfY1Bbo76CFcAG8IZoRisJ7PATnvPvOD4RqVy2c7XmW5dn\n                            lvItaLcyG46QbGp8OUnooTYGq6wlTU2LSEfJvt/1BeSS+VzFEF5+434+mFqjC320\n                            laQD5tUeCkThxG23v8VCVdAFOwPnewoxqrD/Wyv6O7d/JF7nddS4f42XGxpQjReM\n                            XKRoBZLikxPeZrLAGknFeSzOJHc13hU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cti.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cti.gr/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cti.gr/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.cti.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cti.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.cti.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cti.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cti.gr/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cti.gr/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cti.gr"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Computer Technology Institute and Press \"Diophantus\""
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "\u0399\u03bd\u03c3\u03c4\u03b9\u03c4\u03bf\u03cd\u03c4\u03bf \u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03af\u03b1\u03c2 \u03a5\u03c0\u03bf\u03bb\u03bf\u03b3\u03b9\u03c3\u03c4\u03ce\u03bd \u03ba\u03b1\u03b9 \u0395\u03ba\u03b4\u03cc\u03c3\u03b5\u03c9\u03bd \"\u0394\u03b9\u03cc\u03c6\u03b1\u03bd\u03c4\u03bf\u03c2\""
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.cti.gr/cti_en_logo_80x71.png",
                    "lang": "en",
                    "height": "71",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "87"
                  },
                  {
                    "text": "https://idp.cti.gr/cti_en_logo_80x71.png",
                    "lang": "el",
                    "height": "71",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "87"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CTI \"Diophantus\""
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u0399\u03a4\u03a5\u0395 \"\u0394\u03b9\u03cc\u03c6\u03b1\u03bd\u03c4\u03bf\u03c2\""
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "cti.gr"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:38.291031,21.796414"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "150.140.0.0/17"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAPDB3O4Jt71/WaU2UiNReDy9dbsIMA0GCSqGSIb3DQEB\n                            CwUAMBUxEzARBgNVBAMMCmlkcC5jdGkuZ3IwHhcNMTUxMDI3MTgwNzE5WhcNMzUx\n                            MDI3MTcwNzE5WjAVMRMwEQYDVQQDDAppZHAuY3RpLmdyMIIBIjANBgkqhkiG9w0B\n                            AQEFAAOCAQ8AMIIBCgKCAQEAtcmw8xHKAYVkFPvvb9wOelVxKiOj8UhmEadhBS5K\n                            HKSW6yUDmRM1fSZRC4qYzwLlcCUVIxxjWHqaxJh+jmqFAl1HgkRfZfst1LlBfhFe\n                            oPpIFg/8++WCDi97/9UA9R6QxslxDCfQO6Pm4AZbXJyd+ihWPW2UB2vmsrbM1cII\n                            t49nFbjAF8XTiF+mYGtyxFCGnjNwLE/KeoBWmC1XebZDA2VjEBW43Q8cGmTgzfbh\n                            +njsMVsDHFfx5DzPMUgdIvKW++EJCj/Sgi/xxI9Rtyd/wDClIcWocnOFQQ7a2Ego\n                            N7LQmPp/WBKTDeZQ7xcT8hzU38Rys8o1aKnw10tpGbo88wIDAQABo1swWTAdBgNV\n                            HQ4EFgQUa/1IvZV5VVEpl5dqjg+8VQZLxN0wOAYDVR0RBDEwL4IKaWRwLmN0aS5n\n                            coYhaHR0cHM6Ly9pZHAuY3RpLmdyL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\n                            CwUAA4IBAQCDj/Q4Y9wJ8Ao81kfngAPdCeVKhoiT9lFZeJRBUFZXwSvdZa76CXnb\n                            RBcroGskxN+FdBCtXbnHFRWzY4NAiCItk41HHkf9sW1DeYoA2v11VFGdSCwMh4hq\n                            AyI+5OnH4gG2GZa1A2U/IRDGryG/PejE3KJjc06UKtszSPsgCLIn8BWUvfVZoP4v\n                            G85dA66o50DcG9OKY8l1QON6IcrsWVqlTaMSGYMu2tHsXeN7wZakHUz/jbhKqA/E\n                            CKL20oxVcOZjco6xEjM6oaiHI4dDr9wO9lF3TA+DcWSdRrCprSPalVzVn8HmUhOc\n                            K/B20docwc7tKIOQGaEpjo2lmbquG/ib"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAKCs+DufmEJRT/Iei5Y37ZP32r4sMA0GCSqGSIb3DQEB\n                            CwUAMBUxEzARBgNVBAMMCmlkcC5jdGkuZ3IwHhcNMTUxMDI3MTgwNzE2WhcNMzUx\n                            MDI3MTcwNzE2WjAVMRMwEQYDVQQDDAppZHAuY3RpLmdyMIIBIjANBgkqhkiG9w0B\n                            AQEFAAOCAQ8AMIIBCgKCAQEA3/Sl3y8hjZ0PnfIyr/OnxNtJQaLdH3YbKnqJIc/r\n                            /zgcYgOQp1abbZa+QEECx9KSSaQUzM+M1PS3k8SS/A7xRRXr2KaUyCMTEcZXeeEw\n                            0PG8++SbZcgYIqOEJl2w6AX7gy/RLiIalqlfJBFVe6677pigTi4QgSNFTelzx4Ul\n                            mtlypAHXTLzTJUCarlxEQ61HdBvFg9tUuKDPKHGe8OJMsszfBkcw8FXNrnTAGLcy\n                            T5moao+qw4BnPLL2TmxIbRYJ9TfTLmVXJ3/5/g0RWvJ+4/k6IxOoAlZPbHVFP0UQ\n                            dNgcqDvI2GEgNnOWhqL/5R/Sk60VP+txj96U7fAhSUGTAwIDAQABo1swWTAdBgNV\n                            HQ4EFgQU+p3GP2Ho/99FAqc0Zrf3RhityqIwOAYDVR0RBDEwL4IKaWRwLmN0aS5n\n                            coYhaHR0cHM6Ly9pZHAuY3RpLmdyL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\n                            CwUAA4IBAQAPtqj6FtNvluE3YnnwzAPdDF2/yUHpH+Z7y9o5YWyyhqGUevXh1sJ3\n                            VWM9HHjGZvCSvBHFL9UwolQYuj59LT2InnwzDO2Hypl6uP805Fqz5yaFAzCLt1eI\n                            +AMc8xozRUROqQbRm0/qJ+jIACWqcWkShBckqI6c0K6EZvBjmqi0cRuQMoq32fGJ\n                            RxmX9FlIgBD/UBb9djP5GYZTqwF+SY/ZNrXGSdn9eNfQffLhvRj4Z4IaShG1E7xZ\n                            aZOQwUGSYAxOQ1t5ECcLon8toelZ4gPCBd65HRt9DRiHH3llPX0bhTLgEWJoJGXD\n                            32KKXNIN34sD1e3mqloO1Xq0z6x8OgHD"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEzCCAfugAwIBAgIUSKHnO5Jifa6uUWyYYBAzykF1pmcwDQYJKoZIhvcNAQEL\n                            BQAwFTETMBEGA1UEAwwKaWRwLmN0aS5ncjAeFw0xNTEwMjcxODA3MThaFw0zNTEw\n                            MjcxNzA3MThaMBUxEzARBgNVBAMMCmlkcC5jdGkuZ3IwggEiMA0GCSqGSIb3DQEB\n                            AQUAA4IBDwAwggEKAoIBAQCZAFgMwehKNSh+awk9loDhabToZbjuua3mShc7OW5k\n                            5nb4SpIOVwasJ54bY9UH1Y1+qS8Hd+xIUGGqs7U5ONRhRRqQ7CubqNoNF5zpKHbI\n                            +sBNfelcwEc8FaxGMcwKuu53sMwIvdlWEU0/AiPjYOAZpqYtmggUPSnnlaxkYF7e\n                            ctT8swrgJb0KotcyvxWmh2aB1YH01A0bb99acIo8Pjmj+0llABRGsZ5xxA8LgsoI\n                            UziyMdbzPnfcuhGa7aJXFCs8InJj4aXu/QXATIfP12+8e2vPJltFSOL5XIWpXa3O\n                            jKW7wUlWBqZxUO1d6j8jPJYFsjgDZCRnXw5oU0VsQkMDAgMBAAGjWzBZMB0GA1Ud\n                            DgQWBBTACXTvIIdNP2fzze/sSnbZrsbiszA4BgNVHREEMTAvggppZHAuY3RpLmdy\n                            hiFodHRwczovL2lkcC5jdGkuZ3IvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEL\n                            BQADggEBAF16I4lbJsZl6wtWs4E+C0e4td1FwsdNtOLKZ/C3ZYi3/2RWcVs3gfzJ\n                            76wu5AHrtcfYwRjuZkVD3sDQca579qF84js3wSvT27uxqZYU6WfGHwHGjkMoo/WR\n                            6ZTa6Aa58KRJTnAIAMCfY1Bbo76CFcAG8IZoRisJ7PATnvPvOD4RqVy2c7XmW5dn\n                            lvItaLcyG46QbGp8OUnooTYGq6wlTU2LSEfJvt/1BeSS+VzFEF5+434+mFqjC320\n                            laQD5tUeCkThxG23v8VCVdAFOwPnewoxqrD/Wyv6O7d/JF7nddS4f42XGxpQjReM\n                            XKRoBZLikxPeZrLAGknFeSzOJHc13hU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Computer Technology Institute and Press \"Diophantus\""
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u0399\u03bd\u03c3\u03c4\u03b9\u03c4\u03bf\u03cd\u03c4\u03bf \u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03af\u03b1\u03c2 \u03a5\u03c0\u03bf\u03bb\u03bf\u03b3\u03b9\u03c3\u03c4\u03ce\u03bd \u03ba\u03b1\u03b9 \u0395\u03ba\u03b4\u03cc\u03c3\u03b5\u03c9\u03bd \"\u0394\u03b9\u03cc\u03c6\u03b1\u03bd\u03c4\u03bf\u03c2\""
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cti.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cti.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Computer Technology Institute and Press \"Diophantus\""
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u0399\u03bd\u03c3\u03c4\u03b9\u03c4\u03bf\u03cd\u03c4\u03bf \u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03af\u03b1\u03c2 \u03a5\u03c0\u03bf\u03bb\u03bf\u03b3\u03b9\u03c3\u03c4\u03ce\u03bd \u03ba\u03b1\u03b9 \u0395\u03ba\u03b4\u03cc\u03c3\u03b5\u03c9\u03bd \"\u0394\u03b9\u03cc\u03c6\u03b1\u03bd\u03c4\u03bf\u03c2\""
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.brooklands.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wright"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:vicky.wright@brooklands.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Vicky"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pachnanda"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:roy.pachnanda@brooklands.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roy"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.brooklands.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-06-13T13:27:34Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUXTHSnL92ioEhfn9CpPYcgVRrCm0wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAxMUaWRwLmJyb29rbGFuZHMuYWMudWswHhcNMTQwNTI4MTM1\n\t\t\t\t\t\tOTQ3WhcNMzQwNTI4MTM1OTQ3WjAfMR0wGwYDVQQDExRpZHAuYnJvb2tsYW5kcy5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK52gpxhDNJWpaRz\n\t\t\t\t\t\trgnCHXO9t7IgexRTKM3V2IPmsj/kVRGcnYjCrD9BI54sjWuYuNtknVmvu4XSc6pq\n\t\t\t\t\t\tqQyK5mQKqfBuenloi/RtOuOzdspu7DnQ85WDaln6Enhtxr0D/ZsUEZwBupltWVv9\n\t\t\t\t\t\t9REW2YFliMNir7g/uW3BDmAMjOpkbi8ee5zG7TbBzyIOYZqTo0evLF2u2BRY54HL\n\t\t\t\t\t\tCBKxSfNXmglhD8IHvj0Z7fbWMKODuZQ4ZKdy0UTxVFyrshcZXV2Qx7NGAnPgIRLA\n\t\t\t\t\t\tVOD4Q+NyeV4lJZ5d6n/Jz9Aja4QaERIVum5nN8Y0lg2lYRZLJjEr39EepGWXPgQk\n\t\t\t\t\t\t+clOFysCAwEAAaNvMG0wTAYDVR0RBEUwQ4IUaWRwLmJyb29rbGFuZHMuYWMudWuG\n\t\t\t\t\t\tK2h0dHBzOi8vaWRwLmJyb29rbGFuZHMuYWMudWsvaWRwL3NoaWJib2xldGgwHQYD\n\t\t\t\t\t\tVR0OBBYEFJUptrrUSg7zjWY1J4ZMTmZIsuFPMA0GCSqGSIb3DQEBBQUAA4IBAQCZ\n\t\t\t\t\t\t0U77Z4Eqi/I+xBREEDxCkLzqb3wPGIcOQ7S1K12/mtFOnTSM0v4N/OGBtQZOtPjp\n\t\t\t\t\t\tCr2TRcibo93Cs3RW3NaDsARpeluuZmJWrIGnRnKustgGmqqfHFSpYfD8kcWZHiRr\n\t\t\t\t\t\tSs1wyDGmprH2xyySRH0mSAwwz9tFYT+k31PI52hiP3n0zJh9SC3p3nWyGEsj6lMW\n\t\t\t\t\t\t93ledG58FkdklzARJiruUuAYZwAxCER7VdxCjb+Do6YSu5cNdXIk8ZH8AQsigAp6\n\t\t\t\t\t\t558y9UPG4tE2GRueRJyjyH+6orKixPCF4f2DHJ+wKqITQ8n1xfpTFcvDw/Zo0GZL\n\t\t\t\t\t\tu4XG40SUQeuZ0sZZHe+V"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brooklands.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.brooklands.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.brooklands.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.brooklands.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.brooklands.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.brooklands.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.brooklands.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.brooklands.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.brooklands.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.brooklands.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.brooklands.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.brooklands.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brooklands.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUXTHSnL92ioEhfn9CpPYcgVRrCm0wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAxMUaWRwLmJyb29rbGFuZHMuYWMudWswHhcNMTQwNTI4MTM1\n\t\t\t\t\t\tOTQ3WhcNMzQwNTI4MTM1OTQ3WjAfMR0wGwYDVQQDExRpZHAuYnJvb2tsYW5kcy5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK52gpxhDNJWpaRz\n\t\t\t\t\t\trgnCHXO9t7IgexRTKM3V2IPmsj/kVRGcnYjCrD9BI54sjWuYuNtknVmvu4XSc6pq\n\t\t\t\t\t\tqQyK5mQKqfBuenloi/RtOuOzdspu7DnQ85WDaln6Enhtxr0D/ZsUEZwBupltWVv9\n\t\t\t\t\t\t9REW2YFliMNir7g/uW3BDmAMjOpkbi8ee5zG7TbBzyIOYZqTo0evLF2u2BRY54HL\n\t\t\t\t\t\tCBKxSfNXmglhD8IHvj0Z7fbWMKODuZQ4ZKdy0UTxVFyrshcZXV2Qx7NGAnPgIRLA\n\t\t\t\t\t\tVOD4Q+NyeV4lJZ5d6n/Jz9Aja4QaERIVum5nN8Y0lg2lYRZLJjEr39EepGWXPgQk\n\t\t\t\t\t\t+clOFysCAwEAAaNvMG0wTAYDVR0RBEUwQ4IUaWRwLmJyb29rbGFuZHMuYWMudWuG\n\t\t\t\t\t\tK2h0dHBzOi8vaWRwLmJyb29rbGFuZHMuYWMudWsvaWRwL3NoaWJib2xldGgwHQYD\n\t\t\t\t\t\tVR0OBBYEFJUptrrUSg7zjWY1J4ZMTmZIsuFPMA0GCSqGSIb3DQEBBQUAA4IBAQCZ\n\t\t\t\t\t\t0U77Z4Eqi/I+xBREEDxCkLzqb3wPGIcOQ7S1K12/mtFOnTSM0v4N/OGBtQZOtPjp\n\t\t\t\t\t\tCr2TRcibo93Cs3RW3NaDsARpeluuZmJWrIGnRnKustgGmqqfHFSpYfD8kcWZHiRr\n\t\t\t\t\t\tSs1wyDGmprH2xyySRH0mSAwwz9tFYT+k31PI52hiP3n0zJh9SC3p3nWyGEsj6lMW\n\t\t\t\t\t\t93ledG58FkdklzARJiruUuAYZwAxCER7VdxCjb+Do6YSu5cNdXIk8ZH8AQsigAp6\n\t\t\t\t\t\t558y9UPG4tE2GRueRJyjyH+6orKixPCF4f2DHJ+wKqITQ8n1xfpTFcvDw/Zo0GZL\n\t\t\t\t\t\tu4XG40SUQeuZ0sZZHe+V"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Brooklands College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.brooklands.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Brooklands College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dep.software2.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Heath"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ryan.heath@software2.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ryan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Heath"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ryan.heath@software2.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ryan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dep.software2.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-06-12T14:12:13Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Software2 Software eDistribution Service"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.software2.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Software2 Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dep.software2.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dep.software2.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dep.software2.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dep.software2.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dep.software2.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dep.software2.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dep.software2.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIJALhZQuIuYjGPMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\n\t\t\t\t\t\tBAMTE2RlcC5zb2Z0d2FyZTIuY28udWswHhcNMTIwNjExMTIyNTQ2WhcNMjIwNjA5\n\t\t\t\t\t\tMTIyNTQ2WjAeMRwwGgYDVQQDExNkZXAuc29mdHdhcmUyLmNvLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAz6rllkkIBrtqI9VLg4L1DFyORCK+5vPW\n\t\t\t\t\t\tC62r7KVT6u7MrrJfmKLrIOsyuA3gS7dhqjYWS8/JUcc+oRn5jkEPZAlg6veNIAwr\n\t\t\t\t\t\tcO1xTfNhO+6P1hl/sj3SJWW/UXtqCmJlCEd7MbwmUl12PBqXpzXIuAdctfOXv6gN\n\t\t\t\t\t\t1nDZOKbCcComoWqP7Q5VjhDa/iSUnIA89UC4L4zdEiHwm2avGWcYYQRovGcb2Q3n\n\t\t\t\t\t\tvVGMJCiKGZrpZdjK84VALygF2xon8gIuoNoSC2Moxshpz0tX2G3RUOmQeY9A1/g2\n\t\t\t\t\t\t/S5SImzk1K2GTnEUHqP3SfNBKLkWrHssefeugawuQSy9M6rFyucpCwIDAQABo2kw\n\t\t\t\t\t\tZzBGBgNVHREEPzA9ghNkZXAuc29mdHdhcmUyLmNvLnVrhiZodHRwczovL2RlcC5z\n\t\t\t\t\t\tb2Z0d2FyZTIuY28udWsvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUyNMP5j8ncGpyHluN\n\t\t\t\t\t\t5S/3YEzjLREwDQYJKoZIhvcNAQEFBQADggEBAB5cn4wiopEayjYJ+8gO94iZ79PN\n\t\t\t\t\t\tc3wOX55rdkxUpjzSQ5AmYOvL/oAhnc0RxHl1b0IKk6HaQE6P5Y0j6cMZgPf5EcLq\n\t\t\t\t\t\tqctUZu48RP/XZtbGUGhSZiIb0GZA5n+rgReDJVo4edti8m5igXfVAyIjXKN4dk+B\n\t\t\t\t\t\tKs+tGJWmSvgusX/uVyyAtmEuleiGZQ0vetsLKJ8oZuKwCIpOYFM6tUYsNd1S+GOs\n\t\t\t\t\t\t+65oVPVsOglAT+uLTXZ4e9HBQMjYNdbtYNqDQ4+zhU6J8hfZxSM4KuO/GpRdCRkE\n\t\t\t\t\t\tozWdui8KYHLFyd5pK5kGN7XKv9GwxzWcV/4hfiAY0UAqZqqdZWFNuKYTaWM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dep.software2.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dep.software2.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dep.software2.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dep.software2.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dep.software2.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dep.software2.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ukmyms01-zone02.smg-uk.com/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Potts"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:douglas.potts@thomsonreuters.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Doug"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Halford"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:andrew.halford@thomsonreuters.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andy"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ukmyms01-zone02.smg-uk.com/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_instant": "2014-04-02T10:29:39Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDcTCCAlmgAwIBAgIUHY8B0tLuriNFq39X7sA2Pna5FmwwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwLDEqMCgGA1UEAxMhdWtteS1vcmFia3Rlc3QtMDEudGxyLnRob21zb24uY29t\n\t\t\t\t\t\tMB4XDTE0MDIwNjE1MjcxOFoXDTM0MDIwNjE1MjcxOFowLDEqMCgGA1UEAxMhdWtt\n\t\t\t\t\t\teS1vcmFia3Rlc3QtMDEudGxyLnRob21zb24uY29tMIIBIjANBgkqhkiG9w0BAQEF\n\t\t\t\t\t\tAAOCAQ8AMIIBCgKCAQEA2sDwDbm2t6Jc0L89Mj3GXl9RaTsEwCCJ2UNBppGmmc06\n\t\t\t\t\t\t4oucpILb2Yd6KqBsKBaYC0ue3tlwkdyPlDMR/6+E+dJi478+dMb8mX2URLlILIln\n\t\t\t\t\t\tQyWZkf6tp1q1F7rSK7DG4A5jF6nt6WxJlWDp6pOPcM7vkaPcRGw4PyAlgq6E8klo\n\t\t\t\t\t\tnoiX4AOIkOfi+11uJii9LqWk9XdwtrIzDd/El2uGkgcLLnwzpWDV2A0tKAEy8WHR\n\t\t\t\t\t\tUWsotnzmCYfIBMal6o/5fJ7k3KYEOzF90WpYuf7InFGUEzl86rJRWNZtY1h7jepS\n\t\t\t\t\t\totzMbzn7Q5Ljc4MYjbXG4BmCw2JC7XCkjKQy7TuNbQIDAQABo4GKMIGHMGYGA1Ud\n\t\t\t\t\t\tEQRfMF2CIXVrbXktb3JhYmt0ZXN0LTAxLnRsci50aG9tc29uLmNvbYY4aHR0cHM6\n\t\t\t\t\t\tLy91a215LW9yYWJrdGVzdC0wMS50bHIudGhvbXNvbi5jb20vaWRwL3NoaWJib2xl\n\t\t\t\t\t\tdGgwHQYDVR0OBBYEFGnD/uW9bTDxa7yN/FtkfYvhMESnMA0GCSqGSIb3DQEBBQUA\n\t\t\t\t\t\tA4IBAQAV1L5ji+TIyn+BZr94DQOb6pkHAdFgceuq8YxBJoW9oKNJwC9K6lQp0Wus\n\t\t\t\t\t\tq5J4RlIErH3M+q8txtm1J5oH2C9KxPOw1Htw8KSKQfT5LD98HVETMdOGCmmtX5IO\n\t\t\t\t\t\tGLiegJTiXazfmecTi9xi1pVOfVLn97uCY7TK5I0YFDkFN2Whf4GNXY8w9iDGCyN8\n\t\t\t\t\t\t4c6mJD3kCkjWv06ITX/OgTGpHDPobiNu4aEQpMokmw7fE8ff+fBLIEhKQ7y+Zovz\n\t\t\t\t\t\tveOmrduNCjLZY6Ve2poxgw+eIfGsnRLYkz7ak7h/7BYNhUYz48cGPnHOb2+B9J0M\n\t\t\t\t\t\tMUfe/9b/hNW/YTMa9+4MQNOEkWHO"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "thomson.com"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://ukmy-orabktest-01.tlr.thomson.com:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ukmy-orabktest-01.tlr.thomson.com:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ukmy-orabktest-01.tlr.thomson.com/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ukmy-orabktest-01.tlr.thomson.com/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ukmy-orabktest-01.tlr.thomson.com:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://ukmy-orabktest-01.tlr.thomson.com/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ukmy-orabktest-01.tlr.thomson.com/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ukmy-orabktest-01.tlr.thomson.com/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ukmy-orabktest-01.tlr.thomson.com/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://ukmy-orabktest-01.tlr.thomson.com:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ukmy-orabktest-01.tlr.thomson.com:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "thomson.com"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDcTCCAlmgAwIBAgIUHY8B0tLuriNFq39X7sA2Pna5FmwwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwLDEqMCgGA1UEAxMhdWtteS1vcmFia3Rlc3QtMDEudGxyLnRob21zb24uY29t\n\t\t\t\t\t\tMB4XDTE0MDIwNjE1MjcxOFoXDTM0MDIwNjE1MjcxOFowLDEqMCgGA1UEAxMhdWtt\n\t\t\t\t\t\teS1vcmFia3Rlc3QtMDEudGxyLnRob21zb24uY29tMIIBIjANBgkqhkiG9w0BAQEF\n\t\t\t\t\t\tAAOCAQ8AMIIBCgKCAQEA2sDwDbm2t6Jc0L89Mj3GXl9RaTsEwCCJ2UNBppGmmc06\n\t\t\t\t\t\t4oucpILb2Yd6KqBsKBaYC0ue3tlwkdyPlDMR/6+E+dJi478+dMb8mX2URLlILIln\n\t\t\t\t\t\tQyWZkf6tp1q1F7rSK7DG4A5jF6nt6WxJlWDp6pOPcM7vkaPcRGw4PyAlgq6E8klo\n\t\t\t\t\t\tnoiX4AOIkOfi+11uJii9LqWk9XdwtrIzDd/El2uGkgcLLnwzpWDV2A0tKAEy8WHR\n\t\t\t\t\t\tUWsotnzmCYfIBMal6o/5fJ7k3KYEOzF90WpYuf7InFGUEzl86rJRWNZtY1h7jepS\n\t\t\t\t\t\totzMbzn7Q5Ljc4MYjbXG4BmCw2JC7XCkjKQy7TuNbQIDAQABo4GKMIGHMGYGA1Ud\n\t\t\t\t\t\tEQRfMF2CIXVrbXktb3JhYmt0ZXN0LTAxLnRsci50aG9tc29uLmNvbYY4aHR0cHM6\n\t\t\t\t\t\tLy91a215LW9yYWJrdGVzdC0wMS50bHIudGhvbXNvbi5jb20vaWRwL3NoaWJib2xl\n\t\t\t\t\t\tdGgwHQYDVR0OBBYEFGnD/uW9bTDxa7yN/FtkfYvhMESnMA0GCSqGSIb3DQEBBQUA\n\t\t\t\t\t\tA4IBAQAV1L5ji+TIyn+BZr94DQOb6pkHAdFgceuq8YxBJoW9oKNJwC9K6lQp0Wus\n\t\t\t\t\t\tq5J4RlIErH3M+q8txtm1J5oH2C9KxPOw1Htw8KSKQfT5LD98HVETMdOGCmmtX5IO\n\t\t\t\t\t\tGLiegJTiXazfmecTi9xi1pVOfVLn97uCY7TK5I0YFDkFN2Whf4GNXY8w9iDGCyN8\n\t\t\t\t\t\t4c6mJD3kCkjWv06ITX/OgTGpHDPobiNu4aEQpMokmw7fE8ff+fBLIEhKQ7y+Zovz\n\t\t\t\t\t\tveOmrduNCjLZY6Ve2poxgw+eIfGsnRLYkz7ak7h/7BYNhUYz48cGPnHOb2+B9J0M\n\t\t\t\t\t\tMUfe/9b/hNW/YTMa9+4MQNOEkWHO"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Westlaw UK Test IdP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.westlaw.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Thomson Reuters (Professional) UK Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.nss.udel.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "blue@udel.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Fraser S. Gutteridge"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mrau@udel.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Melvin Rau"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "grim@udel.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Daniel J. Grim"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.nss.udel.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.nss.udel.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.nss.udel.edu/idp/profile/Shibboleth/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.nss.udel.edu/idp/profile/Shibboleth/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.nss.udel.edu/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.nss.udel.edu/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "udel.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Delaware"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAPzSSqG9t2K8y1dCX8zWxR+XUXrCMA0GCSqGSIb3DQEB\nBQUAMCIxIDAeBgNVBAMTF3NoaWJib2xldGgubnNzLnVkZWwuZWR1MB4XDTEzMDQy\nNDE1NDg0MFoXDTMzMDQyNDE1NDg0MFowIjEgMB4GA1UEAxMXc2hpYmJvbGV0aC5u\nc3MudWRlbC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCLYSWS\n8lZ7mSNu60m35msFGjoEx1C4gRvy9liQ5XScHKYtbqu6JryJTogYUWGBdQ4Am7vb\nZqyTM9rdfBVX7tzbWAIdMaUhf9ORHVN0ElDk9qwW5irFzsotoeHVDEK6TrzUDws9\n/wkERk9p2Tm7hy+8sWhOx3Ybq7TkA2I4zS5f0QGFQZnYob1/zU9tdPWkjMf5H99g\nnDNCVqqk8pKZJIF2E3dt9IQBYDmTsffk563k8CV0784xiBaVXC5i3+Uh4E4mLBaq\ng0T+BQ5tHR40GolAq4Ia+hfXrcHGTcYT+Mfl6skMCBFwLK0sF24RFAQzD+L/jH+M\nDnTwx7JKiXqIdNS7AgMBAAGjdTBzMFIGA1UdEQRLMEmCF3NoaWJib2xldGgubnNz\nLnVkZWwuZWR1hi5odHRwczovL3NoaWJib2xldGgubnNzLnVkZWwuZWR1L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBSUTIwR8Sy0NgXoq72J1QRVBOkC2jANBgkqhkiG\n9w0BAQUFAAOCAQEAJoZ9nOxRVwuYF2rM6CjSBVwRIlkv8GFRNhl4Rxevz4Sl9lX9\ngvJyJnchy+6F3UYh0QRgjiu8SKa05/8qdElac8OEpaYHrf3ZZE8Dl8o6CibW1Lkq\nIsAXbYLiZDlhxw7Z+cQm0gaE84p+m219iWGf9HGdIUwGEBEL9JLKwBFjPU55WGhC\n6ytIRSKVqxoPPuhcSJI758WWv/wsmH7F/8flH1pqsumE7FLgKRJBB94TFXk6Ajts\nxyo7IcIbdxUsuGPY55IdcAN2cTNO+ONuzLgf2gtj+Byrw4YQPj5fp6rMFNXUkNMf\nEWrgTL1D4S1H5wyY2qBla9ba8P2/PZC0bGK4Xg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://shibboleth.nss.udel.edu/idp/shibboleth/error"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Delaware"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.udel.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Delaware"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://elixir.mf.uni-lj.si/sp/201506181025",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "\u0160uput"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dusan.suput@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Du\u0161an"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:elixir@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sen\u010dar"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:damijan.sencar@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Damijan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hudomalj"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:emil.hudomalj@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Emil"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lesko\u0161ek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:brane.leskosek@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Branimir"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pesko"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jure.pesko@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jure"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sen\u010dar"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:damijan.sencar@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Damijan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://elixir.mf.uni-lj.si/sp/201506181025",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_general.pdf"
              },
              {
                "lang": "sl",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_splosni_pogoji.pdf"
              }
            ],
            "registration_instant": "2015-06-22T11:06:27Z",
            "registration_authority": "http://aai.arnes.si",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Univerza v Ljubljani Medicinska fakulteta"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Univerza v Ljubljani Medicinska fakulteta"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://elixir.mf-uni-lj.si"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://elixir.mf-uni-lj.si"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Univerza v Ljubljani Medicinska fakulteta"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Univerza v Ljubljani Medicinska fakulteta"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://elixir.mf-uni-lj.si"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://elixir.mf-uni-lj.si"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ELIXIR eLearning platform"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ELIXIR eLearning platform"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "93",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "150"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ELIXIR eLearning platform"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ELIXIR eLearning platform"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "elixir.mf.uni-lj.si"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=elixir.mf.uni-lj.si,L=Ljubljana,C=SI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ELIXIR eLearning platform"
                },
                {
                  "lang": "sl",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ELIXIR eLearning platform"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "ELIXIR eLearning platform"
                },
                {
                  "lang": "sl",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "ELIXIR eLearning platform"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "name": "sn",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name": "givenName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name": "mail",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name": "eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.colegsirgar.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@colegsirgar.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Palmer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:simon.palmer@colegsirgar.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.colegsirgar.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-04-22T15:44:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUcXEex5qLM9Uo7l8DfFXeVTtBhmYwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwIDEeMBwGA1UEAxMVaWRwLmNvbGVnc2lyZ2FyLmFjLnVrMB4XDTE0MDQwOTEw\n\t\t\t\t\t\tNDI0NloXDTM0MDQwOTEwNDI0NlowIDEeMBwGA1UEAxMVaWRwLmNvbGVnc2lyZ2Fy\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAn/fhd3ZpIGbd\n\t\t\t\t\t\tCclJAt2vSNKAbIjElHCPeNqFHaf1N876DrQKCBl3a9jll6k0IqqM4Fuc5x8WqBhv\n\t\t\t\t\t\tf7gQHqnsq+9omih0daOpaAJlB9mxeJEthQVB2R/C8JYAJK5akNIc84tDJqI4wSM9\n\t\t\t\t\t\t5dl9CftHSdd/tj/+63RLotEYsStKsnCS1jxm5qNiVfUdn08xIOp1NieF1zRTrdNU\n\t\t\t\t\t\tjvgI/91Q/3kgz81nGcmd2XWO4MIdPEpdxSiHriBpTuWPd/phN9uaCCYrc1SBkcG1\n\t\t\t\t\t\tSOMgvuUxlRvbUeDamHEtLvfJ4n7Os4UmJtjp/yGBdoLyhRl3aiEd34gPG6fdKOib\n\t\t\t\t\t\t1yQqxKRz1wIDAQABo3EwbzBOBgNVHREERzBFghVpZHAuY29sZWdzaXJnYXIuYWMu\n\t\t\t\t\t\tdWuGLGh0dHBzOi8vaWRwLmNvbGVnc2lyZ2FyLmFjLnVrL2lkcC9zaGliYm9sZXRo\n\t\t\t\t\t\tMB0GA1UdDgQWBBSJsyRsmK01s/7klVm/PRh/sgHQujANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEALQtvoB83wkiziavm5rKms3q465cEno7Ze85297sTez3VVUSjuCg+yfZhN/Eh\n\t\t\t\t\t\tuBBPX2/eE44d51DHWMb9hWcKGAvBpWFOIFMgUY4xMpFRpSEtlNr0GHUb58sgcBAS\n\t\t\t\t\t\tAVDTrhhRKC9mNMA0yXI1NlX8QetQbeTR9H6XEOHWiyuf8mZ8BvA3mqZ6I1Uhb4EM\n\t\t\t\t\t\t8PPEnYnz4zaL0xBKYuc6sUqmQthnnSK2n9YtXaM76xysgu38wGRLV5GmxM8vm+6P\n\t\t\t\t\t\tT963ybvq+9CIZ0qvUFn/ammOGusgWgvc5IK51/Fjo1fYX9fDQCUK+3AXku3r/Hvs\n\t\t\t\t\t\twH9HtsMk6cu5RM+dfunpIVkgHg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "colegsirgar.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.colegsirgar.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.colegsirgar.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.colegsirgar.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.colegsirgar.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.colegsirgar.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.colegsirgar.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.colegsirgar.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.colegsirgar.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "colegsirgar.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUcXEex5qLM9Uo7l8DfFXeVTtBhmYwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwIDEeMBwGA1UEAxMVaWRwLmNvbGVnc2lyZ2FyLmFjLnVrMB4XDTE0MDQwOTEw\n\t\t\t\t\t\tNDI0NloXDTM0MDQwOTEwNDI0NlowIDEeMBwGA1UEAxMVaWRwLmNvbGVnc2lyZ2Fy\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAn/fhd3ZpIGbd\n\t\t\t\t\t\tCclJAt2vSNKAbIjElHCPeNqFHaf1N876DrQKCBl3a9jll6k0IqqM4Fuc5x8WqBhv\n\t\t\t\t\t\tf7gQHqnsq+9omih0daOpaAJlB9mxeJEthQVB2R/C8JYAJK5akNIc84tDJqI4wSM9\n\t\t\t\t\t\t5dl9CftHSdd/tj/+63RLotEYsStKsnCS1jxm5qNiVfUdn08xIOp1NieF1zRTrdNU\n\t\t\t\t\t\tjvgI/91Q/3kgz81nGcmd2XWO4MIdPEpdxSiHriBpTuWPd/phN9uaCCYrc1SBkcG1\n\t\t\t\t\t\tSOMgvuUxlRvbUeDamHEtLvfJ4n7Os4UmJtjp/yGBdoLyhRl3aiEd34gPG6fdKOib\n\t\t\t\t\t\t1yQqxKRz1wIDAQABo3EwbzBOBgNVHREERzBFghVpZHAuY29sZWdzaXJnYXIuYWMu\n\t\t\t\t\t\tdWuGLGh0dHBzOi8vaWRwLmNvbGVnc2lyZ2FyLmFjLnVrL2lkcC9zaGliYm9sZXRo\n\t\t\t\t\t\tMB0GA1UdDgQWBBSJsyRsmK01s/7klVm/PRh/sgHQujANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEALQtvoB83wkiziavm5rKms3q465cEno7Ze85297sTez3VVUSjuCg+yfZhN/Eh\n\t\t\t\t\t\tuBBPX2/eE44d51DHWMb9hWcKGAvBpWFOIFMgUY4xMpFRpSEtlNr0GHUb58sgcBAS\n\t\t\t\t\t\tAVDTrhhRKC9mNMA0yXI1NlX8QetQbeTR9H6XEOHWiyuf8mZ8BvA3mqZ6I1Uhb4EM\n\t\t\t\t\t\t8PPEnYnz4zaL0xBKYuc6sUqmQthnnSK2n9YtXaM76xysgu38wGRLV5GmxM8vm+6P\n\t\t\t\t\t\tT963ybvq+9CIZ0qvUFn/ammOGusgWgvc5IK51/Fjo1fYX9fDQCUK+3AXku3r/Hvs\n\t\t\t\t\t\twH9HtsMk6cu5RM+dfunpIVkgHg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Coleg Sir Gar"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.colegsirgar.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Coleg Sir Gar"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.umaber.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.umaber.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-10-25T14:42:08Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Aberystwyth University Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.umaber.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.umaber.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.umaber.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.umaber.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.umaber.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.umaber.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.umaber.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.umaber.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.umaber.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.umaber.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.umaber.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.umaber.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.umaber.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.umaber.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://community.ja.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:web-submit@ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Login Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:web-submit@ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://community.ja.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-02-14T17:37:40Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Janet Community"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ja.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "JISC Collections and Janet Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://community.ja.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://community.ja.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://community.ja.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://community.ja.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://community.jisc.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://community.jisc.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://community.jisc.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://community.jisc.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://community.ja.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://community.jisc.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://community.ja.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://community.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://community.ja.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://community.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The community driven, social business, support, and information website for Janet products and services."
                  }
                ],
                "logo": [
                  {
                    "text": "https://community.ja.net/sites/all/themes/janetbootstrap/logo_500x227.png",
                    "height": "227",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "500"
                  },
                  {
                    "text": "https://community.ja.net/sites/all/themes/janetbootstrap/logo_240x109.png",
                    "height": "109",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "240"
                  },
                  {
                    "text": "https://community.ja.net/sites/all/themes/janetbootstrap/logo_100x45.png",
                    "height": "45",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  },
                  {
                    "text": "https://community.ja.net/sites/all/themes/janetbootstrap/logo_75x75.png",
                    "height": "75",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "75"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The Janet Community"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAK3QNCbDRJQ8MA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEGNvbW11bml0eS5qYS5uZXQwHhcNMTIwMjEwMTEyMzUzWhcNMjIwMjA3MTEy\n\t\t\t\t\t\tMzUzWjAbMRkwFwYDVQQDExBjb21tdW5pdHkuamEubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAw39KjoNd8jwDOrw9GjxK6BGgk6YqR9CRd0YVbtlp\n\t\t\t\t\t\tKfpai5oueTqApoBfwQYiGQWloLbtCk6GG6j8YRpvlwrlOjoOR0+gUvz0yp+q6igx\n\t\t\t\t\t\to6lgJU2zzWWrTbt+oT9BGhFyYUj2EMbLkX8VWzyebKr3kS8ioVZlLjQ3ZWJcHa8Z\n\t\t\t\t\t\tDx7EVFEb/w/tEeIZP5ytz4/j5OLUA2oJzEO2U07dMsVTkpKVdQwatG5REgPrbC6B\n\t\t\t\t\t\t+/QZOoURlABAav3m0v4++spVgYbzVJSRbQ1v5sxwVSGuSS0JoY4YADG7mxMv2e69\n\t\t\t\t\t\tPkThTkxO36boOpZe1NJxrwKJXHSg8UoroG2iW4Rz/7OWhQIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghBjb21tdW5pdHkuamEubmV0MB0GA1UdDgQWBBTMN93e5HUiaDJVqZ8F\n\t\t\t\t\t\t9SsogJ0U9DANBgkqhkiG9w0BAQUFAAOCAQEAKTkm2So0rhPk13AB436H0YnSVC24\n\t\t\t\t\t\tbraQWHHqQQOFMrszM/2ThzPnsYQXqKmX9kgCBy7yfufZiLhkYMSU61lGSeWdhVo5\n\t\t\t\t\t\tv3bVshCenq42mWNM5LE0B5VPCY8WeM9dx7r36FfQRdjXtr85rE3a1ZYNwuu9ZsCS\n\t\t\t\t\t\t+YO2x3amxRkdmkfCs0hxwu0QOkAjL0fACG0i6fnEYcwWS8ZIawKxYLKe1ktyG5uq\n\t\t\t\t\t\tPuhVktg4i0oQ8Uk2GlzgvAClfrZqNSi48BTWrKX4GA5zgEhf8HcBaBQhr5q6ONZi\n\t\t\t\t\t\t0B+wkoo8xl+IxAjKKhkoQxl+Bl9d/rxHOgvMGe/C+83bJ204rfCMdLgGzA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://community.ja.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://community.ja.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://community.ja.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://community.ja.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://community.ja.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://community.ja.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://community.jisc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://community.jisc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://community.jisc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://community.jisc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://community.jisc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://community.jisc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.farnborough.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pollard"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apollard@farnborough.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pollard"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apollard@farnborough.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.farnborough.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-02-23T16:06:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.farnborough.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.farnborough.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "farnboroughsfc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDcDCCAligAwIBAgIIL2mEl0oUtHAwDQYJKoZIhvcNAQEFBQAwTzErMCkGA1UE\n\t\t\t\t\t\tCgwiVGhlIFNpeHRoIEZvcm0gQ29sbGVnZSBGYXJuYm9yb3VnaDEgMB4GA1UEAwwX\n\t\t\t\t\t\tbG9naW4uZmFybmJvcm91Z2guYWMudWswHhcNMTMwMjA4MTU0NDEwWhcNMjMwMjA4\n\t\t\t\t\t\tMTU0NDEwWjBPMSswKQYDVQQKDCJUaGUgU2l4dGggRm9ybSBDb2xsZWdlIEZhcm5i\n\t\t\t\t\t\tb3JvdWdoMSAwHgYDVQQDDBdsb2dpbi5mYXJuYm9yb3VnaC5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMRVMpKY0pRwd8ia8sEN5DpxKvSIBmxq\n\t\t\t\t\t\tBuK/7SOhA5zQvifhWPOezXNxBBEaSmnt7/5H/TRdVOcyO6drd+spmqlZ0RrciBOL\n\t\t\t\t\t\tASbaU42liQfwUq3MRreefgFxaoio8DDN3VPtb5M/U2WR0bTduCBV2EaoODHKHtuD\n\t\t\t\t\t\tM2NJsEYs4qHUiTR5Hnzr4Yweg+TUACHnrYfL3V+C79cTdkYbvEESdx4kavVPDRIr\n\t\t\t\t\t\tm1j6nH7iKWvJR2AECI19WeRyIbTFMqQIYvHqIcCjf1KC/U1sq3gOkxEULDoxo0iV\n\t\t\t\t\t\t+cHgTj17D83ytp5bZMTv9CNznRvtQy3jR5A3kPeEHWT2QZRPnFrwnC0CAwEAAaNQ\n\t\t\t\t\t\tME4wHQYDVR0OBBYEFPfWxt/apKNnKbzYtLQ0V1yHWa+uMB8GA1UdIwQYMBaAFPfW\n\t\t\t\t\t\txt/apKNnKbzYtLQ0V1yHWa+uMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAH4/t3tZRL+l9A5KQPO4gvJNuDwzBOjcH6mAg2ShAjx3PQhC98zN1u5lzQGs\n\t\t\t\t\t\tb01J4jMZoXM+k3zJU8TNKxm7fKK2/lVE2HtI5Bl7IrFJ/Tdl2n6pbCkRX78ZrDXo\n\t\t\t\t\t\tnOkdd31uvbwIHurMBxe0mVEhyrZ+VXr5u8XBnnHgANOU6hzQrwTJsXEmHDLjytbw\n\t\t\t\t\t\thFQ66uuWGMtgbHjRhZ6r8xn04af3JCFY+WToDjTAgeGGU7D4qa59j0aGyy4D3raP\n\t\t\t\t\t\thQZM94Sfx+/GBTyMsBHnXGmwzQcPF+50REkOgz4NRihK849CiSBV4Il3geGvpWzm\n\t\t\t\t\t\tXV1TX8+5LwiT8F8J8CFKgoB2RnI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Sixth Form College Farnborough"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.farnborough.ac.uk"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Sixth Form College, Farnborough"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ehess.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "admin@ehess.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ehess.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-07-12T16:19:22Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ehess.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ehess.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ehess.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ehess.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ehess.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EHESS"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EHESS"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVALeCOqpROd3E1etW0cL7TxFT+Z3rMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDGlkcC5laGVzcy5mcjAeFw0xMTA3MjUxMDMxNThaFw0z\nMTA3MjUxMDMxNThaMBcxFTATBgNVBAMTDGlkcC5laGVzcy5mcjCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALomrxhDCkuM+MNokRhVvEkg095vk1wsvflA\nwYfTuhsVSW13bZVHcOHTjILhWiHOVz8RZVXy6vOmEEWXl2KWn9Tvovh/Sey2rRe/\n/svsSpIUKgnU2tC3rC41XJ5V/mIJUoSPhcQCKCx5t4CV4xG5eNa4rYJxsJDDUviA\nPd+jKkiVMUEvDJ4Qt4o/scjjuUGUrKJ1/EmMqZfG2HO7Xqkg5j8z6n1U6KpOXUb0\nkMhL9SKCiWZX9iYt810mkOlx7TNJlAENOqlGybAnMjEY85rJ/LbEnpgTyWEmNEPc\n1BCN84l4VVEJc7F2WxDjtFMG7YQwjWdUIJbVz/dHHvJQgxIoSrUCAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMaWRwLmVoZXNzLmZyhiNodHRwczovL2lkcC5laGVzcy5mci9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUL5PgjhSfsllLhl0wF9vbNDc9PpgwDQYJ\nKoZIhvcNAQEFBQADggEBAKARW3uivnFto2JRaKGtnqcaDO5dS3RKj7uf/eIaU/Uq\nFm3PADZE5gVTUcwlILrDmci0202/Boo03srZ0RCvSZ6HxjZM5gsPGZ0D2SiMf8b3\nUVSLt38rXXyd6Xm0kXvBP2ZsFlRkzanI0G8pa3wOslVGEZccBKY4dmRToIm7cQeB\nOQdqKV2rfZSK5DN7cE5VeUlRfPOqcsYagK5PT0+JiKdBuJTnBFUub+SPLIW+pygx\nftIG5eTG0zs+8JFROXmVnoVTk6dKHOcL4Ze1HNgC/RQGLQCyY5HY7IjlllWsTteF\nuq8R4YH10wMLWAk+39fV4VIZwj+rc6KKXaPjcpXt+RE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EHESS"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ehess.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "EHESS"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:usf.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "epierce@usf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Eric Pierce"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rwsmith@usf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Randy Smith"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@usf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "USF IT HelpDesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "security@usf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Office of Information Security"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "urn:mace:incommon:usf.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.usf.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.usf.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.usf.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFLTCCBBWgAwIBAgIJANCZEr8p39EUMA0GCSqGSIb3DQEBBQUAMIG/MQswCQYD\nVQQGEwJVUzEQMA4GA1UECBMHRmxvcmlkYTEOMAwGA1UEBxMFVGFtcGExJDAiBgNV\nBAoTG1VuaXZlcnNpdHkgb2YgU291dGggRmxvcmlkYTEfMB0GA1UECxMWSW5mb3Jt\nYXRpb24gVGVjaG5vbG9neTEbMBkGA1UEAxMSc2hpYmJvbGV0aC51c2YuZWR1MSow\nKAYJKoZIhvcNAQkBFhtjaW1zLXRlY2gtY29yZUBtYWlsLnVzZi5lZHUwHhcNMTEw\nNzI2MTQ0MTExWhcNMjEwNzIzMTQ0MTExWjCBvzELMAkGA1UEBhMCVVMxEDAOBgNV\nBAgTB0Zsb3JpZGExDjAMBgNVBAcTBVRhbXBhMSQwIgYDVQQKExtVbml2ZXJzaXR5\nIG9mIFNvdXRoIEZsb3JpZGExHzAdBgNVBAsTFkluZm9ybWF0aW9uIFRlY2hub2xv\nZ3kxGzAZBgNVBAMTEnNoaWJib2xldGgudXNmLmVkdTEqMCgGCSqGSIb3DQEJARYb\nY2ltcy10ZWNoLWNvcmVAbWFpbC51c2YuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAvzI2REpueqDJpnzHBKBiTzJjmotztSUBLnj3nQP1FIO2puJB\nTpg2KbWU8xgmgp0Mpn5TaAiUSG6QbAdKoNzqrGh6iXemYePA1nT+PZWgUG4x/GC+\nH7SBpw3B0h4iKrHZuS2bQfsK1WPf4QLyNVVxcFcl3GXVvZ7dGAMDCoesK94D9bPq\nhLe3vZflU0xTZrRWYIQAQX2OEjsWdZTgwNXfb2LXVn6j3mNHDsUf57qKTdFxMAzb\n778aoF2mcYedYR6WZBbBOrFctlXyEwfkTYctYN+rsGzndFrnQdfU11xLOT/pGLd9\n0ddARSUZde+IF1lff4IVk6tKIcwaTjkltIVmyQIDAQABo4IBKDCCASQwHQYDVR0O\nBBYEFO0Ld280QBsZ1lZjPWkBu9SfKVVLMIH0BgNVHSMEgewwgemAFO0Ld280QBsZ\n1lZjPWkBu9SfKVVLoYHFpIHCMIG/MQswCQYDVQQGEwJVUzEQMA4GA1UECBMHRmxv\ncmlkYTEOMAwGA1UEBxMFVGFtcGExJDAiBgNVBAoTG1VuaXZlcnNpdHkgb2YgU291\ndGggRmxvcmlkYTEfMB0GA1UECxMWSW5mb3JtYXRpb24gVGVjaG5vbG9neTEbMBkG\nA1UEAxMSc2hpYmJvbGV0aC51c2YuZWR1MSowKAYJKoZIhvcNAQkBFhtjaW1zLXRl\nY2gtY29yZUBtYWlsLnVzZi5lZHWCCQDQmRK/Kd/RFDAMBgNVHRMEBTADAQH/MA0G\nCSqGSIb3DQEBBQUAA4IBAQBTBRwLvzb+Fij+VKbA6Erof/eIHeHEdYZSpY0I1Ah7\n4HVc0MkF3ILdvId6FnIYBqMEtpGX7O6t73CFBCZ2xcICX5ceYXb6c07Pg5EJ66dM\nLN7JaWKEX1hOuzDaSabspKshnPdjU06jyMkF0DvZ8+hmD8U9VCFbs/VpRP33J/bE\naynShAHxIbud5Uy/4h6MNDtc56sScEqBUb4D7Xm14Kg15keCBxUvumoUxdD/ykrg\nccGf3bUq48WwGSuikV1OjN+buvlSmWlZYDKzuU2Azdvezk5BK/mEEHxZJIdTWbpd\nwHRSBfdWykar3yfWl3v3l4C3ARmBsVmmqD2lXRtpfZtO"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "usf.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.usf.edu"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is the Shibboleth Identity Provider for the University of South Florida"
                  }
                ],
                "logo": [
                  {
                    "text": "https://cdn.usf.edu/themes/sun-globe/global/1.0.0/images/header/banner/banner-logo.png",
                    "lang": "en",
                    "height": "47",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "316"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of South Florida"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of South Florida"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.usf.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of South Florida"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:cru.fr:federation:univ-rouen.fr",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "systeme@univ-rouen.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:cru.fr:federation:univ-rouen.fr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-05-20T15:48:10Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univ-rouen.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univ-rouen.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.univ-rouen.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-rouen.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-rouen.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Rouen"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Rouen"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUWvf6hiSiI4KjS/n+xqAFPbKt2r0wDQYJKoZIhvcNAQEF\nBQAwHDEaMBgGA1UEAxMRaWRwLnVuaXYtcm91ZW4uZnIwHhcNMTEwNTE3MDk1NTQz\nWhcNMzEwNTE3MDk1NTQzWjAcMRowGAYDVQQDExFpZHAudW5pdi1yb3Vlbi5mcjCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIxi7qpcaAsjhQquoELWUEsz\nPZGyg/5lT6KAAfryX17brdK0cQytLZXyqCOsCSYDi8T3dJwrEKUfzMqf4Rvxhzve\nfFB6fz22+RkLHezLuywNpICo3qBntqY9ZiIgBV4X2AS6jt5Szbm18qSL5xoxQ+DA\n93WKffpCeE9eELWRnu5RKxXam10JBUEMfLxEY+e8ToOcoAU8n/nC7ytE8ReXwcWh\n/eqyt3Usf+MwG6qAPNvRvG3quKEcF+7fbpU4RmZz+na49OLoLhoHCyWHdmmL4lIw\nU2jRo+7IjD3DJMG3pUjqnKbsLrhyk4McwuN4TCiC2KhKWGFSnzXcjNfcYZsK3MsC\nAwEAAaNpMGcwRgYDVR0RBD8wPYIRaWRwLnVuaXYtcm91ZW4uZnKGKGh0dHBzOi8v\naWRwLnVuaXYtcm91ZW4uZnIvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFJZ4dOPm\nrji8bFb79aNq2VybCh8RMA0GCSqGSIb3DQEBBQUAA4IBAQADYQEXRdgzmhCNw3RI\n4NCayLgtaaCdwG/sYEzxXss5CQ2t8jRn1yQpXxoGSwtROZM/w/L8gtWjSpUSB8av\ncKdAZBRB5ojESTkd28/tv3jtA1bjt6OeZwjsCr0RRMBN2A12t4BLfSG7VAKGyE+B\ndQ8p2l7xN23XN9sIAxJNcxtK7w85Or6Y8C9iwApqhMihTLWLQPQGSM1pRUKHTInI\nXgsbhADqatOXXzkizis9PK9Tf8jFSl9Hcye3gJrgYnn3F7qxvMGzm1KqmsAG3Xnr\nyxCa3HYJJd9oze0GYQ3AyxViyin1T4daHyQVMRlC4rjCpVd2f0gp6zX37uF8/i4z\njf6+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Rouen"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-rouen.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Rouen"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.midchesh.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Thomas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sthomas@midchesh.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Thomas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sthomas@midchesh.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.midchesh.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-06-21T16:28:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDXDCCAkQCCQCXDevqC5AIhDANBgkqhkiG9w0BAQUFADBwMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjERMA8GA1UECBMIQ2hlc2hpcmUxEjAQBgNVBAcTCU5vcnRod2ljaDEdMBsGA1UE\n\t\t\t\t\t\tChMUTWlkIENoZXNoaXJlIENvbGxlZ2UxGzAZBgNVBAMTEmlkcC5taWRjaGVzaC5h\n\t\t\t\t\t\tYy51azAeFw0xNDA1MTQwODU2MjVaFw0zNDA1MDkwODU2MjVaMHAxCzAJBgNVBAYT\n\t\t\t\t\t\tAkdCMREwDwYDVQQIEwhDaGVzaGlyZTESMBAGA1UEBxMJTm9ydGh3aWNoMR0wGwYD\n\t\t\t\t\t\tVQQKExRNaWQgQ2hlc2hpcmUgQ29sbGVnZTEbMBkGA1UEAxMSaWRwLm1pZGNoZXNo\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqbxJrYoAOBdU\n\t\t\t\t\t\t+iG+bIRN1EmtO8tg2omFBwPiiKVCocKYf3uxTsO9kr+875s0ZJZvoVaR16D9lgEF\n\t\t\t\t\t\t691uxz6N9W7hFexw13oE75JedD+bQH88ZKlheW1azplTEJNlAvMvDeOVKmI3wCcq\n\t\t\t\t\t\t7jOtsHhiWJ1RN+/3KPRxQ14iJ7wiifANCagqwYGmeC1eVtPPE1g7cpjYzjIpYqZg\n\t\t\t\t\t\tCBbZvIi11eIBIw0ufnL79suIcrPn/7luCu2fFq4ZbIh6SjVd5JK/N2AFiIWmu4D/\n\t\t\t\t\t\tYXh/plKwR6jdv5F+P07hYjyEIJMJ27yGD32MLH1mMGEqy65k8dexsfyYgezaYaRy\n\t\t\t\t\t\tA3inGW0MxwIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQAi5kjMMZzt42rjO82CmxXs\n\t\t\t\t\t\te8wlOz0ScY8eHgO8SKPYxg2CAxoTuOPCqX95V0zioLAqXyrVJxo+Z2FcFFdtWU8V\n\t\t\t\t\t\t2NC6uoHaN7zLP3sYS1ledVY6PXcJrzb6bNJskL6vXHKuV1Hbj7h6eRYgx14wcADD\n\t\t\t\t\t\tCn5HknNl7VgMwQ0XKPBJEbGQNLeNCoUdWgmb71yDHDcmnsEhl726eUE2rKYldxD3\n\t\t\t\t\t\tHLD4x1Fd+jxUSLr+LVnXDBiGYnzJvghKLS67rv40kH2ozEqUVVZ5WgKfNQeDQ/L8\n\t\t\t\t\t\t41sdGgX3jERpyhfgZbJH7UihB+MQ+vsRb/BkjH1T0iSvtJE45npvq1FBrYw4soJO"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "midchesh.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.midchesh.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.midchesh.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.midchesh.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.midchesh.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.midchesh.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.midchesh.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.midchesh.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.midchesh.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "midchesh.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDXDCCAkQCCQCXDevqC5AIhDANBgkqhkiG9w0BAQUFADBwMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjERMA8GA1UECBMIQ2hlc2hpcmUxEjAQBgNVBAcTCU5vcnRod2ljaDEdMBsGA1UE\n\t\t\t\t\t\tChMUTWlkIENoZXNoaXJlIENvbGxlZ2UxGzAZBgNVBAMTEmlkcC5taWRjaGVzaC5h\n\t\t\t\t\t\tYy51azAeFw0xNDA1MTQwODU2MjVaFw0zNDA1MDkwODU2MjVaMHAxCzAJBgNVBAYT\n\t\t\t\t\t\tAkdCMREwDwYDVQQIEwhDaGVzaGlyZTESMBAGA1UEBxMJTm9ydGh3aWNoMR0wGwYD\n\t\t\t\t\t\tVQQKExRNaWQgQ2hlc2hpcmUgQ29sbGVnZTEbMBkGA1UEAxMSaWRwLm1pZGNoZXNo\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqbxJrYoAOBdU\n\t\t\t\t\t\t+iG+bIRN1EmtO8tg2omFBwPiiKVCocKYf3uxTsO9kr+875s0ZJZvoVaR16D9lgEF\n\t\t\t\t\t\t691uxz6N9W7hFexw13oE75JedD+bQH88ZKlheW1azplTEJNlAvMvDeOVKmI3wCcq\n\t\t\t\t\t\t7jOtsHhiWJ1RN+/3KPRxQ14iJ7wiifANCagqwYGmeC1eVtPPE1g7cpjYzjIpYqZg\n\t\t\t\t\t\tCBbZvIi11eIBIw0ufnL79suIcrPn/7luCu2fFq4ZbIh6SjVd5JK/N2AFiIWmu4D/\n\t\t\t\t\t\tYXh/plKwR6jdv5F+P07hYjyEIJMJ27yGD32MLH1mMGEqy65k8dexsfyYgezaYaRy\n\t\t\t\t\t\tA3inGW0MxwIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQAi5kjMMZzt42rjO82CmxXs\n\t\t\t\t\t\te8wlOz0ScY8eHgO8SKPYxg2CAxoTuOPCqX95V0zioLAqXyrVJxo+Z2FcFFdtWU8V\n\t\t\t\t\t\t2NC6uoHaN7zLP3sYS1ledVY6PXcJrzb6bNJskL6vXHKuV1Hbj7h6eRYgx14wcADD\n\t\t\t\t\t\tCn5HknNl7VgMwQ0XKPBJEbGQNLeNCoUdWgmb71yDHDcmnsEhl726eUE2rKYldxD3\n\t\t\t\t\t\tHLD4x1Fd+jxUSLr+LVnXDBiGYnzJvghKLS67rv40kH2ozEqUVVZ5WgKfNQeDQ/L8\n\t\t\t\t\t\t41sdGgX3jERpyhfgZbJH7UihB+MQ+vsRb/BkjH1T0iSvtJE45npvq1FBrYw4soJO"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mid Cheshire College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.midchesh.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Mid-Cheshire College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.rsc-uat.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:internet_services@rsc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Internet Services"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:internet_services@rsc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Internet Services"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.rsc-uat.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-06-14T12:34:32Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Royal Society of Chemistry Test System"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rsc.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Royal Society of Chemistry"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.rsc-uat.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.rsc-uat.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.rsc-uat.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.rsc-uat.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.rsc-uat.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib.rsc-uat.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shib.rsc-uat.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAIdMRZNoOlUKMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHNoaWIucnNjLXVhdC5vcmcwHhcNMTMwNjEzMTUxMTA3WhcNMjMwNjExMTUx\n\t\t\t\t\t\tMTA3WjAbMRkwFwYDVQQDExBzaGliLnJzYy11YXQub3JnMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAvCYfBRJznhtFJ6ObF/CZd2L+NfFHkc3Xc1Hq8ahf\n\t\t\t\t\t\tB3OjIWGT86P11rSBoqgKAKjc/paf3H8fqbieWcl23zFYZt2p5Tgn/N+0gWEDqU3E\n\t\t\t\t\t\tFElv3BkG1qDm6dzASfUe2d6UmywWxA8o755qiR61EyW44t8zBnMlP3zz/4D/c30c\n\t\t\t\t\t\t60pE6ey7vjYo/OSUU1NtJKiSnRVul4ojisBcyQBqTEA+rSz3tdY5tDahZs0ETY15\n\t\t\t\t\t\tOulSEeIgAJ+jyixna5hG88LujxTLfP8eJ5c44bB6tlj+zxX6t2NffbJvmbGA7tsO\n\t\t\t\t\t\tm9HNLaEYpIkvB85FcFU0okDKvEVb0oCi9bxV1G1KnwW5pQIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghBzaGliLnJzYy11YXQub3JnMB0GA1UdDgQWBBStPkn6a3WJboUaFzSW\n\t\t\t\t\t\t4gO3/fZFDTANBgkqhkiG9w0BAQUFAAOCAQEAC63PW0yGjrWEiHKCIPHQJfekHD1/\n\t\t\t\t\t\tEVXsk3Acjv9Hi6oCgMc3aWPvOwdL6CaeiX4VHGkVtiTWpSaG/6UbsjMVF9sdG4PD\n\t\t\t\t\t\t/DsYKjsjVj3+72zIpVhSrKQt5tbl0fvgaZWLjiCTua1NI+Iw2BSI1C6NCgguvpP8\n\t\t\t\t\t\tLKnz7yF0ck8omkoQVuAEUEJcniWzdaxXPeU53/4LeWti2tH7240yH3gjNeN3J09v\n\t\t\t\t\t\t/rfTDcT7i58eKalUZtWL7XvKZ+kp5ziyyWnjqRyLUbrWaBXOlBsyZkrhu4i+XwHl\n\t\t\t\t\t\tE9Z+U+Ne35q+J2NuQ3Z3TXADXkPmz5i2O87MoZcKhdcm1EoZdpi3iUJAgA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.rsc-uat.org/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.rsc-uat.org/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.rsc-uat.org/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.rsc-uat.org/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.rsc-uat.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.rsc-uat.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.rsc-uat.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shib.rsc-uat.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shib.rsc-uat.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shib.rsc-uat.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/orphanage.wayf.dk",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/orphanage.wayf.dk",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2010-08-17T13:41:26Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/orphanage.wayf.dk/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "orphanage.wayf.dk"
              },
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "WAYF Orphanage"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "WAYF Orphanage"
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WAYF Orphanage"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WAYF Orphanage"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "orphanage.wayf.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICvDCCAaQCAQcwDQYJKoZIhvcNAQELBQAwJDEiMCAGA1UEAwwZaHR0cHM6Ly9v\ncnBoYW5hZ2Uud2F5Zi5kazAeFw0xNTAxMDEwMDAwMDBaFw0yNTEyMzEyMzU5NTla\nMCQxIjAgBgNVBAMMGWh0dHBzOi8vb3JwaGFuYWdlLndheWYuZGswggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDHiAwKahBTuI4Z+IJ1rgOeEiCCy3bR9QIe\n3BpCsejFCU5rSzkWANqVuc1PDfp0JdIZhrPXsmDJQMmidPCGPIDQKo+bk+af3+EU\nFS/I/+35sSBX2vf+h1DHvZV9jsznmpSVjp7HZ/WoPWBykWBJO0AOVmzB5zlaqkS3\n6J76+wxerwdpuExVnYSNd73S+AyT/EZ+tXAO+6lQ8FL/YMlJnUkSaSqLSHFy01D2\nqBNmYRwBpCS6/dUZyxi0t5j8ghKUD4BHOZVavn65J62cJdXiOcMRyUAIp57GXQrL\n63KtrjIcXddq+CZyZ5t37EdUOIz42joFcy73MFOntynlKEvOw1BJAgMBAAEwDQYJ\nKoZIhvcNAQELBQADggEBABx+HHsDGyCHtfGNTudzmFRXilr0ay16wRgaLnsCTk3M\nHM2yOputyK+odkVdeIFQ+DnHvWcMOJDiXigiWbNVnN8qaFSHKCJ21Vj5peRpHY6a\nmtoI7FLHoi7t2w9+wmYW20Q4uEc75HrPkmbCn2wSAKDpZ9aBp7oS2KExU58DaLMn\nuxIsjo0ZuT1coH5F8+Pbz763uSbrA7S/c49K8/BZlFStp1419pB4FS+D8mX+ggeq\nQ2kElthI7N5bxzc5JrWQJJG8Vze/g3jvVr8m7p+FEpRjK22WPhfFtwislkYdDfUx\nI81cWocYw/rsAD2kW5C5T1nMZBlgoYk/+yXoXXGHuEI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "WAYF Orphanage"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "WAYF Orphanage"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://wayf.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://wayf.dk/index.php/en"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "WAYF Orphanage"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "WAYF Orphanage"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://g-shib.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jacinto"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ajacinto@getech.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adi"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Baker"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rbaker@getech.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://g-shib.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-14T13:07:29Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Getech Web Portal"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.getech.co.uk/education.aspx/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Getech Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://g-shib.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://g-shib.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://g-shib.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://g-shib.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://g-shib.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://g-shib.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://g-shib.org/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://g-shib.org/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://g-shib.org/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Online access to the Getech web portal for your institution"
                  }
                ],
                "logo": [
                  {
                    "text": "https://g-shib.org/getech-logo-350x116.png",
                    "height": "116",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Getech Web Portal"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJALy05c5DqQOEMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\n\t\t\t\t\t\tBAMTFGVsZWN0cmEuZ2V0ZWNoLmNvLnVrMB4XDTE1MDIxMDE2NTA0N1oXDTI1MDIw\n\t\t\t\t\t\tNzE2NTA0N1owHzEdMBsGA1UEAxMUZWxlY3RyYS5nZXRlY2guY28udWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDECYfU4npJYfA6SQ9+d7i7LaPfExSD\n\t\t\t\t\t\t9v77LVDlH2gC0qntSpR/bqGfk20V0GnIyfrPowdp73tDkPp3cZAVkL6yZc1AMfwm\n\t\t\t\t\t\t/vnaIdJvuxmZrsYkuvDVzfbjcVveaLKiPAxVnNGotqkYfrC55dbC4IbzWIWVmVEN\n\t\t\t\t\t\toWb3x0lGcK+/gihriel1l7x9XH8mMjxKRPDLpt5byLHTiFAiPfW8ueYT6fyd4jJa\n\t\t\t\t\t\tX/Y4GcaXWSC/phVpKpDddo7Ed9PP05kzCB7nfapB2dB9ha9xiT9tR/o3hMpIUIfi\n\t\t\t\t\t\tcWMao2HvJU2A629/fO4nCIkvzSbG39ORX5MZ1OZTkD9sk8uLHohKCugjAgMBAAGj\n\t\t\t\t\t\tQjBAMB8GA1UdEQQYMBaCFGVsZWN0cmEuZ2V0ZWNoLmNvLnVrMB0GA1UdDgQWBBT/\n\t\t\t\t\t\tWshLSzBgHfNYs8ysWr+Rr5eamTANBgkqhkiG9w0BAQUFAAOCAQEAr/uHuMELywZ5\n\t\t\t\t\t\tYNrGxjp+ETD/qXgWBsZiYkL4OCbS7YureuktsayK1jYaj7elcz3jsIfaLo4egyXP\n\t\t\t\t\t\t/GQC6ZcdgCAZ3tNDrwGxOFj6R87Vpb8CBSYqnVQ9eNldKC6+peJFJ2Px75m/9V4H\n\t\t\t\t\t\tGJWDv8Of8cTuGa1brZK/diQPIEYGrwh/sEsjlgHNR4ZcSn9buMLr+MXV6BoxQ7M2\n\t\t\t\t\t\t7o0e7Mz8IYWu8+Dte8pIxGqaE3V9YrWKhmlANU22E69hzeOlrq7tGFC5+g+FDLax\n\t\t\t\t\t\tloqofKby5z252dPlaTkYkOawOOXdiTvslDqSwwnC5ht6btuMShzG8jyiMhrRs44y\n\t\t\t\t\t\tPrf3a/9vGg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://g-shib.org/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://g-shib.org/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://g-shib.org/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://g-shib.org/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://g-shib.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://g-shib.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://g-shib.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://g-shib.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://g-shib.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://g-shib.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ucl.g-shib.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ucl.g-shib.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ucl.g-shib.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ucl.g-shib.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ucl.g-shib.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ucl.g-shib.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.havering-college.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.havering-college.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/havering-college.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/havering-college.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "havering-college.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Havering College of Further & Higher Education"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.havering-college.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.rcpch.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Overt Software"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Overt Software"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.rcpch.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-12-12T09:11:37Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUJdj239A2eY7O8uJt78R/EdkY8fwwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGjEYMBYGA1UEAwwPaWRwLnJjcGNoLmFjLnVrMB4XDTE0MTEyNTEwMTcxNloX\n\t\t\t\t\t\tDTM0MTEyNTEwMTcxNlowGjEYMBYGA1UEAwwPaWRwLnJjcGNoLmFjLnVrMIIBIjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAgoJ0GABGGYuw7iPiNmz6l9BMW72h\n\t\t\t\t\t\tAxzjzadeAAo/7ggPeBMnMtksqK5XQ0LhiEVBC+A3vvfqFC1L/cjPX633o5VTViJx\n\t\t\t\t\t\t2Mt2Wd0q2pF53+iLP8ii2WT1OoVY1HC4nryXAncBYAH7iszGUv/W/EIDt+4vrV0w\n\t\t\t\t\t\tAv8tOO9HXW8nSk3BV6n2BOlLJLverYTq+jqkAyMFm0Nd7iwnEoCh/9rIL9cmCtNk\n\t\t\t\t\t\to/or9T+1c4gb7d1s/r0Lsl8HH6PMzTkBKjoqnmKq8RArclzKTDcYpYokVxcYhyju\n\t\t\t\t\t\tCb+viq2gEX9Gs/RHMQrwKeId7/da9YCwtFXwS3xXB7a5s7QCimNlRkS9rQIDAQAB\n\t\t\t\t\t\to2UwYzAdBgNVHQ4EFgQUo9jZYx7yrwhezyDWPPXj011eI1gwQgYDVR0RBDswOYIP\n\t\t\t\t\t\taWRwLnJjcGNoLmFjLnVrhiZodHRwczovL2lkcC5yY3BjaC5hYy51ay9pZHAvc2hp\n\t\t\t\t\t\tYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAWGCG4+am620zp3knjynttbaB41rd\n\t\t\t\t\t\t4HCuHTqvCYDRkztJu/XxNtymxs2JPCT0+hqH5iHeNIQuufEVMrawJVrdNw45/LbQ\n\t\t\t\t\t\tRLSyRaOPyQ0kJygZEeomBEX/4ZadKewHm9ZNgyjRj9qD8cLflkrVqfnDoicxKKtS\n\t\t\t\t\t\t3ew+NPv3tX0raDfZMfq0MWQrFz9eP2qaeibtNO1xGh+Rp/seeG0MZRtCmtEpXGxf\n\t\t\t\t\t\tNxhnmRLKM0uOMAxtL2/DLfpCJ8w8a6of61Y6l9BqAD5+MYU8Ve4upV+4VGHIbkoB\n\t\t\t\t\t\tY3epTNgBJ8fJ+qQVJknINlO/fKJTQmAvap3uwSHeh0mt3tQxEtr1nPoX6A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rcpch.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.rcpch.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.rcpch.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.rcpch.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.rcpch.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.rcpch.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.rcpch.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.rcpch.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.rcpch.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.rcpch.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.rcpch.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.rcpch.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "logo": [
                  {
                    "text": "https://www.rcpch.ac.uk/sites/default/themes/rcpch/logo.png",
                    "height": "168",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "238"
                  },
                  {
                    "text": "https://www.rcpch.ac.uk/sites/default/themes/rcpch/favicon.ico",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Royal College of Paediatrics and Child Health"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rcpch.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUJdj239A2eY7O8uJt78R/EdkY8fwwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGjEYMBYGA1UEAwwPaWRwLnJjcGNoLmFjLnVrMB4XDTE0MTEyNTEwMTcxNloX\n\t\t\t\t\t\tDTM0MTEyNTEwMTcxNlowGjEYMBYGA1UEAwwPaWRwLnJjcGNoLmFjLnVrMIIBIjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAgoJ0GABGGYuw7iPiNmz6l9BMW72h\n\t\t\t\t\t\tAxzjzadeAAo/7ggPeBMnMtksqK5XQ0LhiEVBC+A3vvfqFC1L/cjPX633o5VTViJx\n\t\t\t\t\t\t2Mt2Wd0q2pF53+iLP8ii2WT1OoVY1HC4nryXAncBYAH7iszGUv/W/EIDt+4vrV0w\n\t\t\t\t\t\tAv8tOO9HXW8nSk3BV6n2BOlLJLverYTq+jqkAyMFm0Nd7iwnEoCh/9rIL9cmCtNk\n\t\t\t\t\t\to/or9T+1c4gb7d1s/r0Lsl8HH6PMzTkBKjoqnmKq8RArclzKTDcYpYokVxcYhyju\n\t\t\t\t\t\tCb+viq2gEX9Gs/RHMQrwKeId7/da9YCwtFXwS3xXB7a5s7QCimNlRkS9rQIDAQAB\n\t\t\t\t\t\to2UwYzAdBgNVHQ4EFgQUo9jZYx7yrwhezyDWPPXj011eI1gwQgYDVR0RBDswOYIP\n\t\t\t\t\t\taWRwLnJjcGNoLmFjLnVrhiZodHRwczovL2lkcC5yY3BjaC5hYy51ay9pZHAvc2hp\n\t\t\t\t\t\tYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAWGCG4+am620zp3knjynttbaB41rd\n\t\t\t\t\t\t4HCuHTqvCYDRkztJu/XxNtymxs2JPCT0+hqH5iHeNIQuufEVMrawJVrdNw45/LbQ\n\t\t\t\t\t\tRLSyRaOPyQ0kJygZEeomBEX/4ZadKewHm9ZNgyjRj9qD8cLflkrVqfnDoicxKKtS\n\t\t\t\t\t\t3ew+NPv3tX0raDfZMfq0MWQrFz9eP2qaeibtNO1xGh+Rp/seeG0MZRtCmtEpXGxf\n\t\t\t\t\t\tNxhnmRLKM0uOMAxtL2/DLfpCJ8w8a6of61Y6l9BqAD5+MYU8Ve4upV+4VGHIbkoB\n\t\t\t\t\t\tY3epTNgBJ8fJ+qQVJknINlO/fKJTQmAvap3uwSHeh0mt3tQxEtr1nPoX6A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Royal College of Paediatrics and Child Health"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rcpch.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Royal College of Paediatrics and Child Health"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.nkp.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kotrba"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Pavel.Kotrba@nkp.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pavel"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.nkp.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2010-09-15T15:29:31Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/library"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFZDCCBEygAwIBAgIQBX7gcQUh/KCJXiApMy1ANTANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMzAeFw0xNjAxMjUwMDAwMDBaFw0xOTAxMjkxMjAwMDBaMIGBMQswCQYDVQQG\nEwJDWjEPMA0GA1UECBMGUHJhZ3VlMRAwDgYDVQQHEwdQcmFoYSAxMTMwMQYDVQQK\nEypUaGUgTmF0aW9uYWwgTGlicmFyeSBvZiB0aGUgQ3plY2ggUmVwdWJsaWMxGjAY\nBgNVBAMTEXNoaWJib2xldGgubmtwLmN6MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEAxVz9glo7tIF0FV6n1PNww6xY1RXXH863lHNc2GIdZPHjjqjZLEuR\nY80rRawhlCtRhis0zfwnwlfFE5svgQzs2VhSS+858BJerWKkDhx2NkGOVAvhVpik\nk8+dslRxYAGh8zMbEfdJccZdpx397gaCLhHxbpbDxKlQK0Cv6nHhmv1gb1q/KOgN\npFDGPByjQQ6yZN5q0UQ1jYUtb/yoydt2hbtBFCE9/5ZoehK3Qr8GMkF36bL8yXxe\nzRXX3gK9rM5n2M/6bM86D+YHG40r4Q3XvQLdAPMMphr4b1C3sfkX8iGjolxgQEm8\nYfUYVXUFG4Qx5mxwJQPOaQj863wwn4EYGwIDAQABo4IB8jCCAe4wHwYDVR0jBBgw\nFoAUZ/2IIBQnmMcJ0iUZu+lREWN1UGIwHQYDVR0OBBYEFBXpVcpKQRux0SxErHIO\nSwZzsq16MEQGA1UdEQQ9MDuCEXNoaWJib2xldGgubmtwLmN6ghJzaGliYm9sZXRo\nMi5ua3AuY3qCEnNoaWJib2xldGgzLm5rcC5jejAOBgNVHQ8BAf8EBAMCBaAwHQYD\nVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMGsGA1UdHwRkMGIwL6AtoCuGKWh0\ndHA6Ly9jcmwzLmRpZ2ljZXJ0LmNvbS9URVJFTkFTU0xDQTMuY3JsMC+gLaArhilo\ndHRwOi8vY3JsNC5kaWdpY2VydC5jb20vVEVSRU5BU1NMQ0EzLmNybDBMBgNVHSAE\nRTBDMDcGCWCGSAGG/WwBATAqMCgGCCsGAQUFBwIBFhxodHRwczovL3d3dy5kaWdp\nY2VydC5jb20vQ1BTMAgGBmeBDAECAjBuBggrBgEFBQcBAQRiMGAwJAYIKwYBBQUH\nMAGGGGh0dHA6Ly9vY3NwLmRpZ2ljZXJ0LmNvbTA4BggrBgEFBQcwAoYsaHR0cDov\nL2NhY2VydHMuZGlnaWNlcnQuY29tL1RFUkVOQVNTTENBMy5jcnQwDAYDVR0TAQH/\nBAIwADANBgkqhkiG9w0BAQsFAAOCAQEAum1TFHVyw8j5ravnpSfedLc+na/GsxQE\nYPAGV4TV0zD69BgH0iQNkTsfjlGNYtj2/j8xpHX/8RIzBkJz4VxOO6bKt2ZhmACG\nmar3Z5kqYeBfWlEM2qFM2dI0IqA1fUlpzTUTug+vspf7RNKGkcZiGfChPDOSD1XN\nVeD3nbwewrypJ7FhDqn42y+FcN3rZJYmwM2WLOWEyAFY6/NGUs9UJand39hR9tcq\nUC1T4fjlKFOc+BRuahdBg15hm3eWR5Aa+23z6kePOezjf5vzBqPTVQWERwXECJlX\nn81sTHIJBu0U+KA0p2PUB/v3CW/lT0NBwOCCADwTtB98dddMxvzyTg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nkp.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.nkp.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.nkp.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.nkp.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.nkp.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.nkp.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.nkp.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.nkp.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.nkp.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nkp.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.en.nkp.cz/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.nkp.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for employees the National Library of the Czech Republic"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider pro zam\u011bstnance N\u00e1rodn\u00ed knihovnu \u010cesk\u00e9 republiky"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www2.eduid.cz/idp-loga/nkp.png",
                    "height": "472",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "500"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The National Library of the Czech Republic"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "N\u00e1rodn\u00ed knihovna \u010cesk\u00e9 republiky"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFZDCCBEygAwIBAgIQBX7gcQUh/KCJXiApMy1ANTANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMzAeFw0xNjAxMjUwMDAwMDBaFw0xOTAxMjkxMjAwMDBaMIGBMQswCQYDVQQG\nEwJDWjEPMA0GA1UECBMGUHJhZ3VlMRAwDgYDVQQHEwdQcmFoYSAxMTMwMQYDVQQK\nEypUaGUgTmF0aW9uYWwgTGlicmFyeSBvZiB0aGUgQ3plY2ggUmVwdWJsaWMxGjAY\nBgNVBAMTEXNoaWJib2xldGgubmtwLmN6MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEAxVz9glo7tIF0FV6n1PNww6xY1RXXH863lHNc2GIdZPHjjqjZLEuR\nY80rRawhlCtRhis0zfwnwlfFE5svgQzs2VhSS+858BJerWKkDhx2NkGOVAvhVpik\nk8+dslRxYAGh8zMbEfdJccZdpx397gaCLhHxbpbDxKlQK0Cv6nHhmv1gb1q/KOgN\npFDGPByjQQ6yZN5q0UQ1jYUtb/yoydt2hbtBFCE9/5ZoehK3Qr8GMkF36bL8yXxe\nzRXX3gK9rM5n2M/6bM86D+YHG40r4Q3XvQLdAPMMphr4b1C3sfkX8iGjolxgQEm8\nYfUYVXUFG4Qx5mxwJQPOaQj863wwn4EYGwIDAQABo4IB8jCCAe4wHwYDVR0jBBgw\nFoAUZ/2IIBQnmMcJ0iUZu+lREWN1UGIwHQYDVR0OBBYEFBXpVcpKQRux0SxErHIO\nSwZzsq16MEQGA1UdEQQ9MDuCEXNoaWJib2xldGgubmtwLmN6ghJzaGliYm9sZXRo\nMi5ua3AuY3qCEnNoaWJib2xldGgzLm5rcC5jejAOBgNVHQ8BAf8EBAMCBaAwHQYD\nVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMGsGA1UdHwRkMGIwL6AtoCuGKWh0\ndHA6Ly9jcmwzLmRpZ2ljZXJ0LmNvbS9URVJFTkFTU0xDQTMuY3JsMC+gLaArhilo\ndHRwOi8vY3JsNC5kaWdpY2VydC5jb20vVEVSRU5BU1NMQ0EzLmNybDBMBgNVHSAE\nRTBDMDcGCWCGSAGG/WwBATAqMCgGCCsGAQUFBwIBFhxodHRwczovL3d3dy5kaWdp\nY2VydC5jb20vQ1BTMAgGBmeBDAECAjBuBggrBgEFBQcBAQRiMGAwJAYIKwYBBQUH\nMAGGGGh0dHA6Ly9vY3NwLmRpZ2ljZXJ0LmNvbTA4BggrBgEFBQcwAoYsaHR0cDov\nL2NhY2VydHMuZGlnaWNlcnQuY29tL1RFUkVOQVNTTENBMy5jcnQwDAYDVR0TAQH/\nBAIwADANBgkqhkiG9w0BAQsFAAOCAQEAum1TFHVyw8j5ravnpSfedLc+na/GsxQE\nYPAGV4TV0zD69BgH0iQNkTsfjlGNYtj2/j8xpHX/8RIzBkJz4VxOO6bKt2ZhmACG\nmar3Z5kqYeBfWlEM2qFM2dI0IqA1fUlpzTUTug+vspf7RNKGkcZiGfChPDOSD1XN\nVeD3nbwewrypJ7FhDqn42y+FcN3rZJYmwM2WLOWEyAFY6/NGUs9UJand39hR9tcq\nUC1T4fjlKFOc+BRuahdBg15hm3eWR5Aa+23z6kePOezjf5vzBqPTVQWERwXECJlX\nn81sTHIJBu0U+KA0p2PUB/v3CW/lT0NBwOCCADwTtB98dddMxvzyTg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The National Library of the Czech Republic"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "N\u00e1rodn\u00ed knihovna \u010cesk\u00e9 republiky"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.en.nkp.cz/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nkp.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The National Library of the Czech Republic"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "N\u00e1rodn\u00ed knihovna \u010cesk\u00e9 republiky"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://siaiap08.univali.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Marcio Luiz Ota"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "admin@univali.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://siaiap08.univali.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0DCCArgCAQAwDQYJKoZIhvcNAQEFBQAwga0xJzAlBgNVBAoTHlVuaXZlcnNp\nZGFkZSBkbyBWYWxlIGRvIEl0YWphaTEMMAoGA1UECxMDR1RJMR8wHQYJKoZIhvcN\nAQkBFhBhZG1pbkB1bml2YWxpLmJyMQ8wDQYDVQQHEwZJdGFqYWkxFzAVBgNVBAgT\nDlNhbnRhIENhdGFyaW5hMQswCQYDVQQGEwJCUjEcMBoGA1UEAxMTc2lhaWFwMDgu\ndW5pdmFsaS5icjAeFw0xNDA0MTcxMjMzNTdaFw0xOTA0MTYxMjMzNTdaMIGtMScw\nJQYDVQQKEx5Vbml2ZXJzaWRhZGUgZG8gVmFsZSBkbyBJdGFqYWkxDDAKBgNVBAsT\nA0dUSTEfMB0GCSqGSIb3DQEJARYQYWRtaW5AdW5pdmFsaS5icjEPMA0GA1UEBxMG\nSXRhamFpMRcwFQYDVQQIEw5TYW50YSBDYXRhcmluYTELMAkGA1UEBhMCQlIxHDAa\nBgNVBAMTE3NpYWlhcDA4LnVuaXZhbGkuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQC0j73uQz7HKNv3mF/UfQ4qiCC/A1o8QwYJGhvyT7Ie9DQUP1UL\nyxF4hSYQ/Xtla7Bm0E3iJBZkcJDZ9k6xOhIwMrWa7reWzDzqUCdzbb0DtvSqiR1e\niDiHfS0kjS482IBaBsO9hYOueRm8FlrAe8JBEVWaild1/9o3OazFb6Nnm97tbuW0\nkLHeAjM5z5Q2HDaAPH4mw78ctdZrQgLgdwKn71EPIrD2Dw00Bz/1Ndvx1KJPUFxB\nhDHT0cMTQ3imeWptocy65Tq7q2xpBwtkWjJqGMLYoGVbr4+aBq8CahoW+8zMrlqo\naVNU9398awtGiLuFKQRQzwoYOOAy9CoDlcJHAgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBAByTETZ7kpMiPJvt/zy+0q5ClKYda3WpqLpaTwnLl359k72A0KSYrZn6siv6\nGcSrTzlf5X+gEH1rFqySh+JYfIUo/xS2CYJC9zbtuCXiJKuzuXBgR69aPlzBP5kG\nqXMP3r2nGYCZhoVdtONZR7i1V9tzhjEziRi8FTj0RMxxE01pNYd34mp82tRxZsFk\n+dmRQQjNfM5zWaEosG94oV1X+QP06y4AER/kTVZKh1TJOPzHvY/fG8QheEKOHO1j\nxEaJyWk8Zd0mumri/3t63hxIHiILLh+rYK+0qYV/5SF51Qb6a+V93w0FfR0X+vbF\nbDtUbUIh3bPnDHUI9So2aC1i27Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univali.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://siaiap08.univali.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://siaiap08.univali.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://siaiap08.univali.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://siaiap08.univali.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://siaiap08.univali.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://siaiap08.univali.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://siaiap08.univali.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://siaiap08.univali.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univali.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univali.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univali.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNIVALI - Universidade do Vale do Itajai"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNIVALI - Universidade do Vale do Itajai"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNIVALI - Universidade do Vale do Itajai"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNIVALI - Universidade do Vale do Itajai"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0DCCArgCAQAwDQYJKoZIhvcNAQEFBQAwga0xJzAlBgNVBAoTHlVuaXZlcnNp\nZGFkZSBkbyBWYWxlIGRvIEl0YWphaTEMMAoGA1UECxMDR1RJMR8wHQYJKoZIhvcN\nAQkBFhBhZG1pbkB1bml2YWxpLmJyMQ8wDQYDVQQHEwZJdGFqYWkxFzAVBgNVBAgT\nDlNhbnRhIENhdGFyaW5hMQswCQYDVQQGEwJCUjEcMBoGA1UEAxMTc2lhaWFwMDgu\ndW5pdmFsaS5icjAeFw0xNDA0MTcxMjMzNTdaFw0xOTA0MTYxMjMzNTdaMIGtMScw\nJQYDVQQKEx5Vbml2ZXJzaWRhZGUgZG8gVmFsZSBkbyBJdGFqYWkxDDAKBgNVBAsT\nA0dUSTEfMB0GCSqGSIb3DQEJARYQYWRtaW5AdW5pdmFsaS5icjEPMA0GA1UEBxMG\nSXRhamFpMRcwFQYDVQQIEw5TYW50YSBDYXRhcmluYTELMAkGA1UEBhMCQlIxHDAa\nBgNVBAMTE3NpYWlhcDA4LnVuaXZhbGkuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQC0j73uQz7HKNv3mF/UfQ4qiCC/A1o8QwYJGhvyT7Ie9DQUP1UL\nyxF4hSYQ/Xtla7Bm0E3iJBZkcJDZ9k6xOhIwMrWa7reWzDzqUCdzbb0DtvSqiR1e\niDiHfS0kjS482IBaBsO9hYOueRm8FlrAe8JBEVWaild1/9o3OazFb6Nnm97tbuW0\nkLHeAjM5z5Q2HDaAPH4mw78ctdZrQgLgdwKn71EPIrD2Dw00Bz/1Ndvx1KJPUFxB\nhDHT0cMTQ3imeWptocy65Tq7q2xpBwtkWjJqGMLYoGVbr4+aBq8CahoW+8zMrlqo\naVNU9398awtGiLuFKQRQzwoYOOAy9CoDlcJHAgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBAByTETZ7kpMiPJvt/zy+0q5ClKYda3WpqLpaTwnLl359k72A0KSYrZn6siv6\nGcSrTzlf5X+gEH1rFqySh+JYfIUo/xS2CYJC9zbtuCXiJKuzuXBgR69aPlzBP5kG\nqXMP3r2nGYCZhoVdtONZR7i1V9tzhjEziRi8FTj0RMxxE01pNYd34mp82tRxZsFk\n+dmRQQjNfM5zWaEosG94oV1X+QP06y4AER/kTVZKh1TJOPzHvY/fG8QheEKOHO1j\nxEaJyWk8Zd0mumri/3t63hxIHiILLh+rYK+0qYV/5SF51Qb6a+V93w0FfR0X+vbF\nbDtUbUIh3bPnDHUI9So2aC1i27Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNIVALI - Universidade do Vale do Itajai"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNIVALI - Universidade do Vale do Itajai"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univali.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univali.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNIVALI - Universidade do Vale do Itajai"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNIVALI - Universidade do Vale do Itajai"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://elibrary.worldbank.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso-support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "sso-support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso-tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "sso-tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://elibrary.worldbank.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-10-25T15:34:28Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The World Bank eLibrary"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://elibrary.worldbank.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIJAI5LIjhAEpIhMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\n\t\t\t\t\t\tBAMTFmVsaWJyYXJ5LndvcmxkYmFuay5vcmcwHhcNMTMwOTE3MDA1MDQwWhcNMjMw\n\t\t\t\t\t\tOTE1MDA1MDQwWjAhMR8wHQYDVQQDExZlbGlicmFyeS53b3JsZGJhbmsub3JnMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA3S7w37V6m/GqIL1LGWuPeQKw\n\t\t\t\t\t\t1FL3uCT8+q6+0OervJkZgHCJJ++CYHdSNF9Jb4UjVGWv2sSxTgg5P3eNxUVh5R0g\n\t\t\t\t\t\thySv7X/aK9t0LVqQiSsLyLD253BZG85FYZMsNDiuv1Xfl7TL/QQy+B6hTxz8Wgxx\n\t\t\t\t\t\tlQXIyE8FEZGqdw40gPgwfPQIBMoN9lg4n9vzxSm76eaz6+tWvdmNDarieQWzVJfS\n\t\t\t\t\t\tVY5ag5yJaP+eed6cg/el7JYR5GKKRYg7NdfK+bxboweqp2Dt/wBZJRGuU6eP9hEb\n\t\t\t\t\t\t0nw/C0s+DctACkwaFedLMKqtFL1oDvQ5yH2tdo0HlHb0lMDtgBUUSwwG+nnqHwID\n\t\t\t\t\t\tAQABo28wbTBMBgNVHREERTBDghZlbGlicmFyeS53b3JsZGJhbmsub3JnhilodHRw\n\t\t\t\t\t\tczovL2VsaWJyYXJ5LndvcmxkYmFuay5vcmcvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n\t\t\t\t\t\tE/UPyX8ixQSfN/glJWMYTjzp0qwwDQYJKoZIhvcNAQEFBQADggEBANUr3Z6lfY5F\n\t\t\t\t\t\thFtckOlFEmhIqflcg1l97HvZjNOuN6oyDELHUQPuwNLePhvw3g/9nlLiGHUKsOSx\n\t\t\t\t\t\tsJUg2pnhKTYSv9uRZKLnOBlCGYcUCq8ujZbeumMeQkpvNPS9uOXPhk5uVXb7Fpbz\n\t\t\t\t\t\tidO7RtqcE3SBE2HvAoabnSQEjcfqGgzkAAWHZJleNUcTVLmJXQ0TiCKjbnHAVhw+\n\t\t\t\t\t\tiuGKiF0alO/SBU25m6KejfGVie/MMQ8jXzXME7dsrLbHkbzmhgDvt0F/MCBYo3Uu\n\t\t\t\t\t\t4bnQnWMrou+VPRJp4eaUHXVBGBahrzgLvCm4VwljY9141+R58jaaV44VwntYJnIe\n\t\t\t\t\t\tnkzg8bDWiJo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://elibrary.worldbank.org/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://elibrary.worldbank.org/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://elibrary.worldbank.org/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.portal.ted.is.ed.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:is.helpline@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-certs@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Application Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.portal.ted.is.ed.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-03-08T10:00:17Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Edinburgh: Scientia Syllabus Plus Enterprise - Live Environment"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.portal.ted.is.ed.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.portal.ted.is.ed.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJAMszihLucz6hMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\n\t\t\t\t\t\tBAMTE3NhdC1lcC1rYjEuZWQuYWMudWswHhcNMTIwMzA1MTY1NjMyWhcNMjIwMzAz\n\t\t\t\t\t\tMTY1NjMyWjAeMRwwGgYDVQQDExNzYXQtZXAta2IxLmVkLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzQOJ96cEk18YvMHn0Dg71j6V1PUt2gNr\n\t\t\t\t\t\t932yD1ZmnFawDcB8bIvvVadllB0L0Ww2VnKh6x2dsn03366QGvT8jjEBqz/2Djni\n\t\t\t\t\t\t6ym0g5H1Ql6ttdmihP7fV1TUE0gS3bMKw+s/axerzqYCD7Q6m1gY8p0eAPNN4oP+\n\t\t\t\t\t\tT5u88GsOYmNa13w9NqXceCmGvA9SJFD/dQQWC9G5pQs3umqpKFjLvclZcKy9Gj2Q\n\t\t\t\t\t\tb3LdGY/QMjSEJ24aH6xA8X6VKDc7ByzDk2IC2b4UEgVBBC3Y+50J4b3UdcS1ZU3P\n\t\t\t\t\t\tb61GuEZ4FT5ber4zAfPjdPM1Q+6j+lbex76Lp03FU+RTJRUztSSoSwIDAQABo0Ew\n\t\t\t\t\t\tPzAeBgNVHREEFzAVghNzYXQtZXAta2IxLmVkLmFjLnVrMB0GA1UdDgQWBBR/ayuV\n\t\t\t\t\t\tLIFWwzUssHpUcvMr/ZS4QjANBgkqhkiG9w0BAQUFAAOCAQEAgdp151G2iRytTqdG\n\t\t\t\t\t\t9BavSjFEcL23m8sW8RN/RvR/yZKuuLGVYIePgl2VMT9FrGy1GX4OxsApkhm2E5a6\n\t\t\t\t\t\tjMelTpnm3qUwjryEWVVLSGMLP9mi49xzSOrU7pK7FseyxJP+loRJ5hO1laJIVS/u\n\t\t\t\t\t\tWpNzjYn7QG+jHk5Eh3A3K6KlxZJmZTCBLXhOHzYXY8BBhEhtdDsFY+tPfiw+twVO\n\t\t\t\t\t\tMonDchFnqWwDwsypFdPb5PcjtnLig1XXQCyVDkzGmqtNLMmu6d56Waox71G/KaMO\n\t\t\t\t\t\tnkS4wUZn15n5mdKZrScA2RbVMiQ5oqO5GHbC0Hnx1zmz/qnM0Eek7TeQGIi02dBv\n\t\t\t\t\t\thv3Y4Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.portal.ted.is.ed.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.portal.ted.is.ed.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.portal.ted.is.ed.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.portal.ted.is.ed.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.portal.ted.is.ed.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.portal.ted.is.ed.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sso.fau.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "fau.us@fau.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Florida Atlantic University Support Services"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rresnick@fau.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rhian Resnick"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "frodrig6@fau.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Frank Rodriguez"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.fau.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.fau.edu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.fau.edu:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.fau.edu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso.fau.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.fau.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.fau.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.fau.edu:443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.fau.edu:443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fau.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.fau.edu/oit/accounts/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Florida Atlantic University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Florida Atlantic Test IDP"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.fau.edu/images/shibboleth.png",
                    "lang": "en",
                    "height": "150",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "150"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.fau.edu/oit/accounts/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAPXvW42xKsbM/hd7Kz3NbFQcB2eYMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC3Nzby5mYXUuZWR1MB4XDTEyMDYwMjIwMDUxNFoXDTMy\nMDYwMjIwMDUxNFowFjEUMBIGA1UEAxMLc3NvLmZhdS5lZHUwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDKSEyeGUqxBlVwKg3HMQSX+CSEngA3t10bE4Ks\n+dNLQuBT8dG/2BW0ByoLuY26OUjE/pD/8AfpP96NXninzQl0x6pVm5BPpQC4Ds2m\nVrXjGqOpPddaL/DCxp/MOOuOhsfr4oeIh1wlypMnTey3Q1Ew0Qrn253IUn8VufDW\nMIb0CHGfGOajen0muPHcumuDjqVJm/06ID1h0dygTeTizxY5LfvpmEZYxtuVP4ns\nVTt9qZxRUK92AWGiRPW95ezzNIhNzGSgFk/y0ctdK87Q69Og+kE9Cf8PJVcDjRKB\nkHwWhEVpR/9wXD9VnIOKdXHR2wNb0MNrxxKUWGuhZ0iJINl1AgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC3Nzby5mYXUuZWR1hiJodHRwczovL3Nzby5mYXUuZWR1L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBQpo7vIce0XZ8XgsfkQMH6fElF7gzANBgkqhkiG\n9w0BAQUFAAOCAQEArw1nkMaS7/56SOkCmSf9dha9iyCXTrLOYi8Mrlc12Q479+sI\neddtX47ShJhlUqXlIvZi/HLPMUHoyG5zIwTzD9a+o9nc4+dC9TTL64lcCiDkAPyB\njC8zkXMjZogLu2qiSBUdaaAYr1RswiNpUgJEdnl7FxeFUFD1TZ7yFsjOzgLC6W4W\nNVUVQWYfRbQOFizPJBtA+QdWDB/tHnMgOm+jjgwVXupex20rdV6vVq/sKTzE1tCn\nSy7y61N6qVJjnmbH4IdFnrQib4jc16mOWBob8JUD/nSozArIjurFPIBCZWtfkqhb\n8RgOqewQBP/7Gw84rIidKEycldMKMkP7EtKyeQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://wordpress.fau.edu/irm"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Florida Atlantic University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fau.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Florida Atlantic University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.rvc.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Shearer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ashearer@rvc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alison"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Shearer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ashearer@rvc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alison"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.rvc.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-09-04T14:01:49Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.rvc.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.rvc.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rvc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIIBIqWvTgzVRkwDQYJKoZIhvcNAQEFBQAwOzEhMB8GA1UE\n\t\t\t\t\t\tCgwYUm95YWwgVmV0ZXJpbmFyeSBDb2xsZWdlMRYwFAYDVQQDDA1pZHAucnZjLmFj\n\t\t\t\t\t\tLnVrMB4XDTEyMDgxMzE0MzUyNloXDTIyMDgxMzE0MzUyNlowOzEhMB8GA1UECgwY\n\t\t\t\t\t\tUm95YWwgVmV0ZXJpbmFyeSBDb2xsZWdlMRYwFAYDVQQDDA1pZHAucnZjLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAiKaZ4qU3nGrCoSb9sRkt\n\t\t\t\t\t\tk/X+131piJUW54UzIR1KPYpQNJgzImdApDSiS4AS60riPIC63PgE/DQg/F2jJRW+\n\t\t\t\t\t\tS5Sey9Ov20zHIDvKnLJGNC562o+AJ9ycvstXK4fWxRDQTTcUxs0bBiLxgbA1rjNe\n\t\t\t\t\t\tnw0/yP0EBEc59EhEszgV1B7lQ99AbxXaW3v7cpdsHd3m1+RAaNbnF34XI/SBs4dE\n\t\t\t\t\t\tbqMH6+5vaBj7d25Qh+O56g/nFK+Za/GrywK8OYJETCCmKTJaDX2KrSWr8GhhCvpH\n\t\t\t\t\t\t+nxY9AgN8wBF2nC35/0UvHLISvPjHXpCplEqHQ0xHHDsRsv7IVP92a4nimfidNK2\n\t\t\t\t\t\t8QIDAQABo1AwTjAdBgNVHQ4EFgQUE+HRdHMYPXdEVqlkV13ulYgAJDUwHwYDVR0j\n\t\t\t\t\t\tBBgwFoAUE+HRdHMYPXdEVqlkV13ulYgAJDUwDAYDVR0TBAUwAwEB/zANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAD1RaAUKsoucwIWhuX/fXoKvn989YfmBONOGxXJJMLtG9S0/F\n\t\t\t\t\t\tTRYEPKT0BaKmQvha1NH1Foeo0Qr5PsCyWWA3hUWeNHOwvcBRedzqicf6aYHXRNCB\n\t\t\t\t\t\t97YK7WEgUNmbzwxiURun+hBNuBKGQgIfJ960HCHt1JneI8rz8I2d0KN9Y5NrUrBB\n\t\t\t\t\t\tC9E7CL5PvOVAk5ryPt9nnqUH8+lpiWGBftZv45dh0UjsCIkJa4e0eUUQzJo57agJ\n\t\t\t\t\t\tnk0Yl612TV8ifddkDqmIV6C7iExDA5vZp7VxagIbt7GF8c8ER2nmfp9RKB7Kv8ci\n\t\t\t\t\t\thh4lW/+CyvCPkKidV/SU/saCVq78gF2/0QF16w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIIBIqWvTgzVRkwDQYJKoZIhvcNAQEFBQAwOzEhMB8GA1UE\n\t\t\t\t\t\tCgwYUm95YWwgVmV0ZXJpbmFyeSBDb2xsZWdlMRYwFAYDVQQDDA1pZHAucnZjLmFj\n\t\t\t\t\t\tLnVrMB4XDTEyMDgxMzE0MzUyNloXDTIyMDgxMzE0MzUyNlowOzEhMB8GA1UECgwY\n\t\t\t\t\t\tUm95YWwgVmV0ZXJpbmFyeSBDb2xsZWdlMRYwFAYDVQQDDA1pZHAucnZjLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAiKaZ4qU3nGrCoSb9sRkt\n\t\t\t\t\t\tk/X+131piJUW54UzIR1KPYpQNJgzImdApDSiS4AS60riPIC63PgE/DQg/F2jJRW+\n\t\t\t\t\t\tS5Sey9Ov20zHIDvKnLJGNC562o+AJ9ycvstXK4fWxRDQTTcUxs0bBiLxgbA1rjNe\n\t\t\t\t\t\tnw0/yP0EBEc59EhEszgV1B7lQ99AbxXaW3v7cpdsHd3m1+RAaNbnF34XI/SBs4dE\n\t\t\t\t\t\tbqMH6+5vaBj7d25Qh+O56g/nFK+Za/GrywK8OYJETCCmKTJaDX2KrSWr8GhhCvpH\n\t\t\t\t\t\t+nxY9AgN8wBF2nC35/0UvHLISvPjHXpCplEqHQ0xHHDsRsv7IVP92a4nimfidNK2\n\t\t\t\t\t\t8QIDAQABo1AwTjAdBgNVHQ4EFgQUE+HRdHMYPXdEVqlkV13ulYgAJDUwHwYDVR0j\n\t\t\t\t\t\tBBgwFoAUE+HRdHMYPXdEVqlkV13ulYgAJDUwDAYDVR0TBAUwAwEB/zANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAD1RaAUKsoucwIWhuX/fXoKvn989YfmBONOGxXJJMLtG9S0/F\n\t\t\t\t\t\tTRYEPKT0BaKmQvha1NH1Foeo0Qr5PsCyWWA3hUWeNHOwvcBRedzqicf6aYHXRNCB\n\t\t\t\t\t\t97YK7WEgUNmbzwxiURun+hBNuBKGQgIfJ960HCHt1JneI8rz8I2d0KN9Y5NrUrBB\n\t\t\t\t\t\tC9E7CL5PvOVAk5ryPt9nnqUH8+lpiWGBftZv45dh0UjsCIkJa4e0eUUQzJo57agJ\n\t\t\t\t\t\tnk0Yl612TV8ifddkDqmIV6C7iExDA5vZp7VxagIbt7GF8c8ER2nmfp9RKB7Kv8ci\n\t\t\t\t\t\thh4lW/+CyvCPkKidV/SU/saCVq78gF2/0QF16w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Royal Veterinary College: OpenAthens LA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rvc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Royal Veterinary College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-02.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-02.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-02.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-02.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-02.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-02.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-02.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-02.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-02.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;02"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;02"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-02.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-02.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJALj7Nl5UzAxYMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wMi5sYWRvay51bXUuc2UwHhcNMTQxMDA2MDc1MTMyWhcNMjQx\nMDAzMDc1MTMyWjAhMR8wHQYDVQQDExZsYWRvazMtMDIubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA6QZLrV2v1EAjGi7qFqomDDF2\nlECHcdR0agTowzMaG+xwY2up2aZCMsuLBGFTaRxKUASnkU7GABejW/iuWwVa77oP\n6rBH5g0Gv9abpnvXVI1/ZtLj4XWfL8l7tU7nAIvu/Yrp4WStRUdEs4XfIo63/uH+\nkiQn/S2+MpcJJTFvFf6z1NUOGMDKnCuuGzwgcZzSw9PAkKBKwSoTZnHTp9jpK1st\nJ3/yJS6BiFL8IXGn1zZdPCSawGUbKv4AUqLtFvCal5VRUVqgCzyy2/8C9s5aHIx1\nnhCUXN1TNZ6MJ4LloQYMizQ4fDI15a7L5ti0N518X3g5PHmBxg5dXk52o1k9BwID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMDIubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0wMi5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUzNkoe/PfihG1DgUmSmY+vQlkX5gwDQYJKoZIhvcNAQEFBQADggEB\nADcGrCqMm3M8QlV3l5JAl5nMRFAQs4rFhvu8ruAl2PJWZWHQywn8iNpCyN7tVCP2\n+RxP7Im8oopZ3ziLlMwTrEYFH8PPrdjUik+oSm5O5JHvqbI4+HH1XOa7igPxSxct\nIZl9GY/t/3nMWWb4DBitYOSwL35a7ntfUdXNwfgKVCAIWp8p8LoWeTDD4TUHis0w\njUKo59MnfwPUm0RVXbrtiTrNUu+RiGNzrAhc5n7g4ZI2JhmQ5Q/A8pEGn6Zy6Ct2\nfsgw6Oh1LOHpmDXNRh7Tsh2kHxa9+bHJNFAhVZC3MN5zF2+oNbImOdjMH6XtjOnf\nV2U1emX7Cc8OvH12y7nKZu0="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-02.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-02.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-02.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-02.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-02.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-02.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-02.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-02.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-02.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-02.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://jabber.nordu.net/shibboleth",
    {
      "entity_id": "https://jabber.nordu.net/shibboleth",
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jabber.nordu.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://jabber.nordu.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jabber.nordu.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://jabber.nordu.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Jabber at NORDUnet"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Jabber at NORDUnet"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://jabber.nordu.net/Shibboleth.sso/DS/nordu.net",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "jabber.nordu.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAMdBcIFfKqNcMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGphYmJlci5ub3JkdS5uZXQwHhcNMTEwNDE1MDkxNDQ2WhcNMjEwNDEyMDkx\nNDQ2WjAbMRkwFwYDVQQDExBqYWJiZXIubm9yZHUubmV0MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAuf/UhI1cEEWM1EVJNLJLxNQAjgcU1Ed4rWubB9iu\nZPmmpDnXMPJ/PiTAoi58iqzs28M6CN3mVqwP/PlMyt/N1toIu0VSd9R9czXyEmII\nJgBiEJ4CWbLdbhaLoCGeBEyKCob4ZdpHnV/+9o3Vx2kFo6frFg/SY4ryi1hXomcp\nhR5iTpo4H5pYDqFquvlJ0fxPmPBhqZpCeLhJBPGjTrS6rrEnkUYh3iKOywboOMIN\nyVdNhUcV5PPSM3+e0McIquAfRumRacVfhe+qvofEuTlWbTSPQLQymBfBMaDUDYjH\nWK6+jGjLAHB8Y9PPvwM/ecRSb6vckKfpu/Y/+arsn/7ihwIDAQABoz4wPDAbBgNV\nHREEFDASghBqYWJiZXIubm9yZHUubmV0MB0GA1UdDgQWBBTpbrmNDAbzimHpvfgR\nXi9+6vC1GDANBgkqhkiG9w0BAQUFAAOCAQEAFa/NGDqdgxvqkqss0m4SLCa2omxV\nopoYV2zwA7wjPqlPPi4M20i2LysFyqwrPHmOKH0wcAWiB4+d8XN8UmsLrVODmrJN\nBD07pGaDP6jamTtHOr4Enj25pJ/0Fe5hZeLJ3ppFebgq6TfrTd41qIwmC0KMClay\nK0rTtqshk+nKb89Re3xutEU9D7r+EaoHIa9rw1bTz6UmkFZ5ovjfV3htogb8xNt9\n2kQbxgdjl0QkFTf2sURB+4El0oUnXdOZiqQS5hqjEtZDJ6NlDvtW7OtH/SE2PAyn\nzvTzeciRKJ9UNf9ibAJGF7jz/GP5r+yUgizdV0wyikyUa8VNyrSeExBUVg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=jabber.nordu.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "jabber.nordu.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAMdBcIFfKqNcMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGphYmJlci5ub3JkdS5uZXQwHhcNMTEwNDE1MDkxNDQ2WhcNMjEwNDEyMDkx\nNDQ2WjAbMRkwFwYDVQQDExBqYWJiZXIubm9yZHUubmV0MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAuf/UhI1cEEWM1EVJNLJLxNQAjgcU1Ed4rWubB9iu\nZPmmpDnXMPJ/PiTAoi58iqzs28M6CN3mVqwP/PlMyt/N1toIu0VSd9R9czXyEmII\nJgBiEJ4CWbLdbhaLoCGeBEyKCob4ZdpHnV/+9o3Vx2kFo6frFg/SY4ryi1hXomcp\nhR5iTpo4H5pYDqFquvlJ0fxPmPBhqZpCeLhJBPGjTrS6rrEnkUYh3iKOywboOMIN\nyVdNhUcV5PPSM3+e0McIquAfRumRacVfhe+qvofEuTlWbTSPQLQymBfBMaDUDYjH\nWK6+jGjLAHB8Y9PPvwM/ecRSb6vckKfpu/Y/+arsn/7ihwIDAQABoz4wPDAbBgNV\nHREEFDASghBqYWJiZXIubm9yZHUubmV0MB0GA1UdDgQWBBTpbrmNDAbzimHpvfgR\nXi9+6vC1GDANBgkqhkiG9w0BAQUFAAOCAQEAFa/NGDqdgxvqkqss0m4SLCa2omxV\nopoYV2zwA7wjPqlPPi4M20i2LysFyqwrPHmOKH0wcAWiB4+d8XN8UmsLrVODmrJN\nBD07pGaDP6jamTtHOr4Enj25pJ/0Fe5hZeLJ3ppFebgq6TfrTd41qIwmC0KMClay\nK0rTtqshk+nKb89Re3xutEU9D7r+EaoHIa9rw1bTz6UmkFZ5ovjfV3htogb8xNt9\n2kQbxgdjl0QkFTf2sURB+4El0oUnXdOZiqQS5hqjEtZDJ6NlDvtW7OtH/SE2PAyn\nzvTzeciRKJ9UNf9ibAJGF7jz/GP5r+yUgizdV0wyikyUa8VNyrSeExBUVg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=jabber.nordu.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jabber.nordu.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://jabber.nordu.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jabber.nordu.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://jabber.nordu.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jabber.nordu.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://jabber.nordu.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://jabber.nordu.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://jabber.nordu.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://jabber.nordu.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://jabber.nordu.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.gyc.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.gyc.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/gyc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/gyc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gyc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Great Yarmouth College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gyc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://yorksso.simitive.com",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dolby"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chris.dolby@simitive.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dolby"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chris.dolby@simitive.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://yorksso.simitive.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-01-12T16:42:26Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Simitive"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.simitive.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Simitive Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://yorksso.simitive.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://yorksso.simitive.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://yorksso.simitive.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://yorksso.simitive.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://yorksso.simitive.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "authn_requests_signed": "1",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://yorksso.simitive.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://yorksso.simitive.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLTCCAhWgAwIBAgIJAOTSwr6sbvhpMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGGxpdmUtbm9kZS0xLnNpbWl0aXZlLmNvbTAeFw0xNjAxMTExMTE2MTBaFw0y\n\t\t\t\t\t\tNjAxMDgxMTE2MTBaMCMxITAfBgNVBAMTGGxpdmUtbm9kZS0xLnNpbWl0aXZlLmNv\n\t\t\t\t\t\tbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKGsx/7NE5Qog50Otb0Z\n\t\t\t\t\t\ts2YDk4zMy/hhLhNVfLbk6IkaTUgmiu875uUVoa4jPwx8MNMU8RYUfL2Nq6yr/Cma\n\t\t\t\t\t\tFb/FN+b1znHag21vECzMRgN8NZRALToal8NhwAx+se4zi0XgXixHsutBlSKRVkyu\n\t\t\t\t\t\tEAT2vxvn8WnQgM7tThR9v7MWjDBFGskFeo9QIfmEhWfdVy/4N3/K4AzxyDrw7lPK\n\t\t\t\t\t\thCsoFU3NPKRclFMP4czcC4R7pKUqxco8f15ix2k559MgmVNyC57Pm1CUSNtiJIuU\n\t\t\t\t\t\to5ut27e8WJTcOADGqcozQagUg00IOYjmonYH2MFXG96ajrv/Za040XzOLG1gUU0W\n\t\t\t\t\t\tn5kCAwEAAaNkMGIwQQYDVR0RBDowOIIYbGl2ZS1ub2RlLTEuc2ltaXRpdmUuY29t\n\t\t\t\t\t\thhxodHRwczovL3lvcmtzc28uc2ltaXRpdmUuY29tMB0GA1UdDgQWBBSZ/yGeLuMe\n\t\t\t\t\t\t1oX26TmwFqdwoMC+2jANBgkqhkiG9w0BAQUFAAOCAQEAmNNQvS8/4KmjqT1dVOPz\n\t\t\t\t\t\toB3150olMxcPjfUfrBKi8ws0L2tM3fcUPbpkhSpv3YywD09XCTpLYz4KNe7JNLbe\n\t\t\t\t\t\tzdxMQCpq4PlJEFhXvvGsf3GKoH1IUEVWlq/pAf4NfZaerhiLN1T5TiPCoK8Tola9\n\t\t\t\t\t\tRpk1z1gaOYuOSQ5JRQ7R7ixcQq2SLOj6x/uOYtfKgi6OqhH3NVX98r3TJ/iBSdmM\n\t\t\t\t\t\tUvUYWEDBPYFFs9LghtcgVPnABNwRqXOJfg4abC6ihJNGWQj+nJ0L6HY3HqVhWVZ8\n\t\t\t\t\t\tqvHZtI187EMIPMJz9NR6XzLLqN66sgeUT0nu+X3QgE0z/dQfKN5kKr5bN4KFb+52\n\t\t\t\t\t\tMg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://yorksso.simitive.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://yorksso.simitive.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://yorksso.simitive.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://yorksso.simitive.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://yorksso.simitive.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://yorksso.simitive.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol"
        }
      ]
    }
  ],
  [
    "https://sso.canterbury.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it-service@canterbury.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Service"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:linux.admins@canterbury.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Linux Admins"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.canterbury.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-06-30T14:23:11Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVANaQnCAp0hjyfB+AlIzHFLa2I9EvMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB8xHTAbBgNVBAMTFHNzby5jYW50ZXJidXJ5LmFjLnVrMB4XDTEzMDcyNjE0\n\t\t\t\t\t\tMzQ0M1oXDTE2MDcyNjE0MzQ0M1owHzEdMBsGA1UEAxMUc3NvLmNhbnRlcmJ1cnku\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCG4ddRgNHZrvt1\n\t\t\t\t\t\tZe2wElTfmo2+Y6Euo2vVDPt2Kmu4vwmPrr0BiafQA7NevLFPckE6sP4fjeZnoBR8\n\t\t\t\t\t\tMSZpSzHiZpf//hEp0ZUFf37SBC+A04H64jnKvDxYSDihgNCpA3lAcLFYj8H/nFWS\n\t\t\t\t\t\tRfhkKam8edfcETOqtivj3U/imXFYyFH7X5KPPSXTnVxgpX7fao+ik31OHqUl4NLn\n\t\t\t\t\t\tyvLUMkASk442Cl7y67V6Yc38EXw+OHrAJ3FXpD+lgkLn9LMfspJxI0EQhYDRAO3Q\n\t\t\t\t\t\tV5RIhGcxOtkOnO9+FW9gHrktVLT2MwN3tpxpPR0Al8om1O0V7MUkgI9gZ/otWG3v\n\t\t\t\t\t\tSjJEK3khAgMBAAGjbzBtMEwGA1UdEQRFMEOCFHNzby5jYW50ZXJidXJ5LmFjLnVr\n\t\t\t\t\t\thitodHRwczovL3Nzby5jYW50ZXJidXJ5LmFjLnVrL2lkcC9zaGliYm9sZXRoMB0G\n\t\t\t\t\t\tA1UdDgQWBBRg/rITiyhdF1j8oOHSiproLSNiVjANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tgEWjXuYQwxt0yzpzh4n8PYs22B8aH+jwo5lqiUPSAXQck809YBtpS7oYVclQPdTg\n\t\t\t\t\t\tcZ0W0Zbh6+V6qqtvDWUnmZwKLdgPKcnC1wXxJxMPGrK2EjB/6CJAg6fn20e4bqX7\n\t\t\t\t\t\tt70GW49LMiyQjQHApdt5Z0RNk3oBpZ3u/8/AyOHg3BWkXtFUis3zbgXs6bnNEgfT\n\t\t\t\t\t\tIIi1oNlZMFDw/BwO4G3SwGbxZfqXaFDQEWL9th1ECitGs1G3jBVjwW/9rOb6ojuL\n\t\t\t\t\t\tPYL0JTTUP85r329JLjGzXs6PXn82UejbdGBhC/qZMKdqZilqQuniwLfcO2nIsWn5\n\t\t\t\t\t\tPmiYgLtxTZqsx6k7bEWZMw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "canterbury.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.canterbury.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.canterbury.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.canterbury.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.canterbury.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.canterbury.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso.canterbury.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.canterbury.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sso.canterbury.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.canterbury.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.canterbury.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.canterbury.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "canterbury.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://www.canterbury.ac.uk/SiteElements/images/cccu-logo-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://www.canterbury.ac.uk/SiteElements/images/cccu-logo-80x60.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Canterbury Christ Church University (test)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVANaQnCAp0hjyfB+AlIzHFLa2I9EvMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB8xHTAbBgNVBAMTFHNzby5jYW50ZXJidXJ5LmFjLnVrMB4XDTEzMDcyNjE0\n\t\t\t\t\t\tMzQ0M1oXDTE2MDcyNjE0MzQ0M1owHzEdMBsGA1UEAxMUc3NvLmNhbnRlcmJ1cnku\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCG4ddRgNHZrvt1\n\t\t\t\t\t\tZe2wElTfmo2+Y6Euo2vVDPt2Kmu4vwmPrr0BiafQA7NevLFPckE6sP4fjeZnoBR8\n\t\t\t\t\t\tMSZpSzHiZpf//hEp0ZUFf37SBC+A04H64jnKvDxYSDihgNCpA3lAcLFYj8H/nFWS\n\t\t\t\t\t\tRfhkKam8edfcETOqtivj3U/imXFYyFH7X5KPPSXTnVxgpX7fao+ik31OHqUl4NLn\n\t\t\t\t\t\tyvLUMkASk442Cl7y67V6Yc38EXw+OHrAJ3FXpD+lgkLn9LMfspJxI0EQhYDRAO3Q\n\t\t\t\t\t\tV5RIhGcxOtkOnO9+FW9gHrktVLT2MwN3tpxpPR0Al8om1O0V7MUkgI9gZ/otWG3v\n\t\t\t\t\t\tSjJEK3khAgMBAAGjbzBtMEwGA1UdEQRFMEOCFHNzby5jYW50ZXJidXJ5LmFjLnVr\n\t\t\t\t\t\thitodHRwczovL3Nzby5jYW50ZXJidXJ5LmFjLnVrL2lkcC9zaGliYm9sZXRoMB0G\n\t\t\t\t\t\tA1UdDgQWBBRg/rITiyhdF1j8oOHSiproLSNiVjANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tgEWjXuYQwxt0yzpzh4n8PYs22B8aH+jwo5lqiUPSAXQck809YBtpS7oYVclQPdTg\n\t\t\t\t\t\tcZ0W0Zbh6+V6qqtvDWUnmZwKLdgPKcnC1wXxJxMPGrK2EjB/6CJAg6fn20e4bqX7\n\t\t\t\t\t\tt70GW49LMiyQjQHApdt5Z0RNk3oBpZ3u/8/AyOHg3BWkXtFUis3zbgXs6bnNEgfT\n\t\t\t\t\t\tIIi1oNlZMFDw/BwO4G3SwGbxZfqXaFDQEWL9th1ECitGs1G3jBVjwW/9rOb6ojuL\n\t\t\t\t\t\tPYL0JTTUP85r329JLjGzXs6PXn82UejbdGBhC/qZMKdqZilqQuniwLfcO2nIsWn5\n\t\t\t\t\t\tPmiYgLtxTZqsx6k7bEWZMw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Canterbury Christ Church University (test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.canterbury.ac.uk/support/computing-services/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Canterbury Christ Church University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://bobnational.net/saml/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@cambridgeimaging.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CIS Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@cambridgeimaging.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CIS Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bobnational.net/saml/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2009-08-27T18:06:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "British Universities Film & Video Council: BoB National"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://bufvc.ac.uk/tvandradio/bob"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "British Universities Film & Video Council"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://bobnational.net/saml/module.php/saml/sp/saml2-logout.php/imagenweb",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDlDCCAnygAwIBAgIJANdrdMaQXWYoMA0GCSqGSIb3DQEBBQUAMDoxHjAcBgNV\n\t\t\t\t\t\tBAoTFUJvQiBOYXRpb25hbCBXZWIgU2l0ZTEYMBYGA1UEAxMPYm9ibmF0aW9uYWwu\n\t\t\t\t\t\tbmV0MB4XDTEyMDgxNjEyMTgzNFoXDTIyMDgxNDEyMTgzNFowOjEeMBwGA1UEChMV\n\t\t\t\t\t\tQm9CIE5hdGlvbmFsIFdlYiBTaXRlMRgwFgYDVQQDEw9ib2JuYXRpb25hbC5uZXQw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQChVywMjnHBsEhfSHdWDwQy\n\t\t\t\t\t\t4DJsfa3XdcYXf5TdNDAgDjuNnvNIsupLaatPNUsoLCywjEjR0a5xQkDx8SocntS4\n\t\t\t\t\t\tueA5aLQM2J/WvFu8w/I26VMqu3oOTi9D7FH4rhSLWpmEt42lCwyxgBrcoUlMSYcf\n\t\t\t\t\t\t2dD66YqmI6qWiLhjukU49Qhu5L7q4eN3MZUWQ1RlHhq8a8i2E3+e5hUxaMmR0R+t\n\t\t\t\t\t\tmnJUw2UhX7YaTVhTx/nKbevyGMQkyv7XgLa2JNe3+n+dyUsECNE+VLF7uwRPWHEp\n\t\t\t\t\t\t/Gis0qTNn5yT1uu7Hx15UiqqitnWvHGlmLasEiC8UMlvjg06LdhyeBdAH84e7SGD\n\t\t\t\t\t\tAgMBAAGjgZwwgZkwHQYDVR0OBBYEFLGc2FzkYAkjc5LCl9IhxPOXdAi/MGoGA1Ud\n\t\t\t\t\t\tIwRjMGGAFLGc2FzkYAkjc5LCl9IhxPOXdAi/oT6kPDA6MR4wHAYDVQQKExVCb0Ig\n\t\t\t\t\t\tTmF0aW9uYWwgV2ViIFNpdGUxGDAWBgNVBAMTD2JvYm5hdGlvbmFsLm5ldIIJANdr\n\t\t\t\t\t\tdMaQXWYoMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAEzPhy3e0E05\n\t\t\t\t\t\tZwvsLtV0yUQv2NH8Y62CKhfWRoBMvVyVgEhIpl65RdMMpD0YniivY+d9cl+ObVEP\n\t\t\t\t\t\tkFxJsBr86NUPHAA12qHf/QR9cGZAsQhQ8XFrCE3sWgCNlBxTOoE5pqwKTMxymDZD\n\t\t\t\t\t\trVMhRugvRv/VMVEv4py+98nu5KQedUVqkuYz7eG+GZlFJXHuqeMq3eXGVhW5UEcC\n\t\t\t\t\t\tQWZjg8Usw8plmmXjPv6yiSxhwIQcFWVIe+/gU1b2F9H05k07ttptx49ahYji+mNj\n\t\t\t\t\t\tfg+nv0Kg3/TODGxPdpgp4EISAkK+5Mxrat9/qpYjW59wZIrpoWu/IQodmLzxFi31\n\t\t\t\t\t\tD51oPHcAyxM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDlDCCAnygAwIBAgIJANdrdMaQXWYoMA0GCSqGSIb3DQEBBQUAMDoxHjAcBgNV\n\t\t\t\t\t\tBAoTFUJvQiBOYXRpb25hbCBXZWIgU2l0ZTEYMBYGA1UEAxMPYm9ibmF0aW9uYWwu\n\t\t\t\t\t\tbmV0MB4XDTEyMDgxNjEyMTgzNFoXDTIyMDgxNDEyMTgzNFowOjEeMBwGA1UEChMV\n\t\t\t\t\t\tQm9CIE5hdGlvbmFsIFdlYiBTaXRlMRgwFgYDVQQDEw9ib2JuYXRpb25hbC5uZXQw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQChVywMjnHBsEhfSHdWDwQy\n\t\t\t\t\t\t4DJsfa3XdcYXf5TdNDAgDjuNnvNIsupLaatPNUsoLCywjEjR0a5xQkDx8SocntS4\n\t\t\t\t\t\tueA5aLQM2J/WvFu8w/I26VMqu3oOTi9D7FH4rhSLWpmEt42lCwyxgBrcoUlMSYcf\n\t\t\t\t\t\t2dD66YqmI6qWiLhjukU49Qhu5L7q4eN3MZUWQ1RlHhq8a8i2E3+e5hUxaMmR0R+t\n\t\t\t\t\t\tmnJUw2UhX7YaTVhTx/nKbevyGMQkyv7XgLa2JNe3+n+dyUsECNE+VLF7uwRPWHEp\n\t\t\t\t\t\t/Gis0qTNn5yT1uu7Hx15UiqqitnWvHGlmLasEiC8UMlvjg06LdhyeBdAH84e7SGD\n\t\t\t\t\t\tAgMBAAGjgZwwgZkwHQYDVR0OBBYEFLGc2FzkYAkjc5LCl9IhxPOXdAi/MGoGA1Ud\n\t\t\t\t\t\tIwRjMGGAFLGc2FzkYAkjc5LCl9IhxPOXdAi/oT6kPDA6MR4wHAYDVQQKExVCb0Ig\n\t\t\t\t\t\tTmF0aW9uYWwgV2ViIFNpdGUxGDAWBgNVBAMTD2JvYm5hdGlvbmFsLm5ldIIJANdr\n\t\t\t\t\t\tdMaQXWYoMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAEzPhy3e0E05\n\t\t\t\t\t\tZwvsLtV0yUQv2NH8Y62CKhfWRoBMvVyVgEhIpl65RdMMpD0YniivY+d9cl+ObVEP\n\t\t\t\t\t\tkFxJsBr86NUPHAA12qHf/QR9cGZAsQhQ8XFrCE3sWgCNlBxTOoE5pqwKTMxymDZD\n\t\t\t\t\t\trVMhRugvRv/VMVEv4py+98nu5KQedUVqkuYz7eG+GZlFJXHuqeMq3eXGVhW5UEcC\n\t\t\t\t\t\tQWZjg8Usw8plmmXjPv6yiSxhwIQcFWVIe+/gU1b2F9H05k07ttptx49ahYji+mNj\n\t\t\t\t\t\tfg+nv0Kg3/TODGxPdpgp4EISAkK+5Mxrat9/qpYjW59wZIrpoWu/IQodmLzxFi31\n\t\t\t\t\t\tD51oPHcAyxM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bobnational.net/saml/module.php/saml/sp/saml2-acs.php/imagenweb",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://bobnational.net/saml/module.php/saml/sp/saml1-acs.php/imagenweb",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bobnational.net/saml/module.php/saml/sp/saml2-acs.php/imagenweb",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://bobnational.net/saml/module.php/saml/sp/saml1-acs.php/imagenweb/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "BoB National"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shh.pingpong.se/Shibboleth.sso/Metadata",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://shh.pingpong.se/Shibboleth.sso/Metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shh.pingpong.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shh.pingpong.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shh.pingpong.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shh.pingpong.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shh.pingpong.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "L\u00e4rplattformen PING PONG vid Sophiahemmet h\u00f6gskola."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The learning platform PING PONG at Sophiahemmet University."
                  }
                ],
                "logo": [
                  {
                    "text": "https://shh.pingpong.se/login/pingpong-logo-168x50.png",
                    "height": "168",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "https://shh.pingpong.se/login/pingpong-logo-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PING PONG vid Sophiahemmet h\u00f6gskola"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PING PONG at Sophiahemmet University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shh.pingpong.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shh.pingpong.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://lillaedet.pingpong.se/shibboleth"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "lillaedet.pingpong.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJAMNpqZY0cUukMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\nBAMTFWxpbGxhZWRldC5waW5ncG9uZy5zZTAeFw0xMjAxMTgxMDU4MjZaFw0yMjAx\nMTUxMDU4MjZaMCAxHjAcBgNVBAMTFWxpbGxhZWRldC5waW5ncG9uZy5zZTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM8GQM1LnsvyXPnZh9ZlWhG3gkJB\n0H8I7kkVO017B7AmQvFingsCaIHBFnglKRyTml5lw5My4NGi9QVWLSd5IIoDD9Is\nuRR5tEU0+G6eyxQy08MZMB0XwamC+8BsU/0rOc5zmA+iAS3LDZO4m+gLOwWYorbg\na6ViHplIrOUOBeUT1j4D3MJs5LBpJ/Ruvf4sAzP/eA8uCr7Wo13Geq+8lJodV917\nD+/KbGbOHZMkhCb9iCZpdJVvnVGWWuQbYMfAxaRcGkIMKZOcFiseCJ1tUlrb9YFD\nWuPcF7kFr0nzGmqVyqFd7zedMNzIEyBVlEa3YwcwxQSlopVf9FBm5FNGi88CAwEA\nAaNtMGswSgYDVR0RBEMwQYIVbGlsbGFlZGV0LnBpbmdwb25nLnNlhihodHRwczov\nL2xpbGxhZWRldC5waW5ncG9uZy5zZS9zaGliYm9sZXRoMB0GA1UdDgQWBBQS1rOl\nmFqPheIlLCkc2f6dkjPjGDANBgkqhkiG9w0BAQUFAAOCAQEAYJ+J6GqQXCjnDI4j\njeT1SSEpDmEgH4JtaJbth2Ymz1lw8DAwF51aXK+9ylY239V2tQ7cVYdYdeNLsK8S\ni8WGFEPepAJevRES3TbZmBkx63vg6KFtONBFa4FiDAHv7Ja7fGPC/jo4+7V+174j\nwdfS6g4c1YW8xMNOHgdAbeMVk365DD3vYv796T6m9oaZfp41fOkvQ2Ly7lD1P53d\nkYPtN92O/M+IGG8b3FF4UQ3tTnC8N9D6YF18X5GK+W1tSQfZ7jAf3sAK9yrXuZv2\nAyhVkxRiEnLD4tvVDNFseCCzGAomlzCuOU2QY5TyK6VbtwKvxZvUc6GQF5y7h1aN\nUIZtDw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=lillaedet.pingpong.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shh.pingpong.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shh.pingpong.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shh.pingpong.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ua.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "smontgomery@ua.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Scott Montgomery"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "deborah.crocker@ua.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Deborah Crocker"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "itsd@ua.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ua.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ua.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ua.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEzCCAfugAwIBAgIUNKqQ00OfQ884NNxZ/Wqg64utm9owDQYJKoZIhvcNAQEF\nBQAwFTETMBEGA1UEAxMKaWRwLnVhLmVkdTAeFw0xMjA3MDIxNTMyMTJaFw0zMjA3\nMDIxNTMyMTJaMBUxEzARBgNVBAMTCmlkcC51YS5lZHUwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQCgoODiUmYmlR2YZDWPOQKKuhgrc5oBzLINbtQJ7M1P\nLJBCjRaXVkKKgWpSGkHyQesv9V0IVJ8lUxviekpcKdlQ2FRlHyVPO4F94QOIdpIV\nBCKQkZRIL/Z4uup+YRBK/0ZsuEivRTnfW+xQKE+VUs2El8u63G735l7tYWgn2Ve2\nTWPWPzUEdZrxkDQsms1pPf40q8qTRPMz9AlsiIJ7Jkpmc9mKu+lsjHDk5xrCQ2Ix\nZNpxFtfCCvh2QmUvG6RQDQ9OIpQTpL4Mkr2desYwLq5YXP3RGaCOR78jN/zw2hW/\n4lh3OuYyhK1BhwZzkVFrmrDqT2pqklaQiumzKZA/DPKTAgMBAAGjWzBZMDgGA1Ud\nEQQxMC+CCmlkcC51YS5lZHWGIWh0dHBzOi8vaWRwLnVhLmVkdS9pZHAvc2hpYmJv\nbGV0aDAdBgNVHQ4EFgQU5PpJtXNlAssOyOO4UTVGluFuAhUwDQYJKoZIhvcNAQEF\nBQADggEBABPzuZZunphE/zVhwqafhEQui2yK/liaJF8RgmEYoKHbXDLsSweQ6gpb\naoJ4sJqOppySR8tSTojuGVleRis8138xTtRzYsCsUVeQ7EZ79DJ9W9xep3aAXy6G\nEX6VVWfCSj2KSS4vR8/YtSzclUkOQwK1A/poO2na6PMpOaFzPHEHpT73OLjj+f40\nettjvwSjTCvHNQWQawfSg8q0w+CnTxZ3hfAGR77zOFwzBbrxIBY9g16VOUSbP464\n6izLFjrXdfUARACZIkv+rigqMZou8Fj7VvBp8Wu1f0pzVQYwkgU+nl8INuYKYELW\n3NhJFAodlwbRHKZc0vyCH8RmluU4KoE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ua.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ua.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ua.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ua.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ua.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ua.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ua.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ua.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Alabama, The"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEzCCAfugAwIBAgIUNKqQ00OfQ884NNxZ/Wqg64utm9owDQYJKoZIhvcNAQEF\nBQAwFTETMBEGA1UEAxMKaWRwLnVhLmVkdTAeFw0xMjA3MDIxNTMyMTJaFw0zMjA3\nMDIxNTMyMTJaMBUxEzARBgNVBAMTCmlkcC51YS5lZHUwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQCgoODiUmYmlR2YZDWPOQKKuhgrc5oBzLINbtQJ7M1P\nLJBCjRaXVkKKgWpSGkHyQesv9V0IVJ8lUxviekpcKdlQ2FRlHyVPO4F94QOIdpIV\nBCKQkZRIL/Z4uup+YRBK/0ZsuEivRTnfW+xQKE+VUs2El8u63G735l7tYWgn2Ve2\nTWPWPzUEdZrxkDQsms1pPf40q8qTRPMz9AlsiIJ7Jkpmc9mKu+lsjHDk5xrCQ2Ix\nZNpxFtfCCvh2QmUvG6RQDQ9OIpQTpL4Mkr2desYwLq5YXP3RGaCOR78jN/zw2hW/\n4lh3OuYyhK1BhwZzkVFrmrDqT2pqklaQiumzKZA/DPKTAgMBAAGjWzBZMDgGA1Ud\nEQQxMC+CCmlkcC51YS5lZHWGIWh0dHBzOi8vaWRwLnVhLmVkdS9pZHAvc2hpYmJv\nbGV0aDAdBgNVHQ4EFgQU5PpJtXNlAssOyOO4UTVGluFuAhUwDQYJKoZIhvcNAQEF\nBQADggEBABPzuZZunphE/zVhwqafhEQui2yK/liaJF8RgmEYoKHbXDLsSweQ6gpb\naoJ4sJqOppySR8tSTojuGVleRis8138xTtRzYsCsUVeQ7EZ79DJ9W9xep3aAXy6G\nEX6VVWfCSj2KSS4vR8/YtSzclUkOQwK1A/poO2na6PMpOaFzPHEHpT73OLjj+f40\nettjvwSjTCvHNQWQawfSg8q0w+CnTxZ3hfAGR77zOFwzBbrxIBY9g16VOUSbP464\n6izLFjrXdfUARACZIkv+rigqMZou8Fj7VvBp8Wu1f0pzVQYwkgU+nl8INuYKYELW\n3NhJFAodlwbRHKZc0vyCH8RmluU4KoE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Alabama, The"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ua.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Alabama, The"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.cranfield.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Haynes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:j.haynes@cranfield.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jonathan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Caines"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Kenneth.Caines@Cranfield.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kenneth"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Haynes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:j.haynes@cranfield.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jonathan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.cranfield.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEeDCCA2CgAwIBAgIJAMVh01FmcQItMA0GCSqGSIb3DQEBBQUAMIG8MQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEVMBMGA1UECBMMQmVkZm9yZHNoaXJlMRIwEAYDVQQHEwlDcmFuZmll\n\t\t\t\t\t\tbGQxHTAbBgNVBAoTFENyYW5maWVsZCBVbml2ZXJzaXR5MRYwFAYDVQQLEw1JVCBE\n\t\t\t\t\t\tZXBhcnRtZW50MSMwIQYDVQQDExpzaGliYm9sZXRoLmNyYW5maWVsZC5hYy51azEm\n\t\t\t\t\t\tMCQGCSqGSIb3DQEJARYXc3lzdGVtc0BjcmFuZmllbGQuYWMudWswHhcNMTIwODE1\n\t\t\t\t\t\tMTQzNDAyWhcNMjIwODEzMTQzNDAyWjCBvDELMAkGA1UEBhMCR0IxFTATBgNVBAgT\n\t\t\t\t\t\tDEJlZGZvcmRzaGlyZTESMBAGA1UEBxMJQ3JhbmZpZWxkMR0wGwYDVQQKExRDcmFu\n\t\t\t\t\t\tZmllbGQgVW5pdmVyc2l0eTEWMBQGA1UECxMNSVQgRGVwYXJ0bWVudDEjMCEGA1UE\n\t\t\t\t\t\tAxMac2hpYmJvbGV0aC5jcmFuZmllbGQuYWMudWsxJjAkBgkqhkiG9w0BCQEWF3N5\n\t\t\t\t\t\tc3RlbXNAY3JhbmZpZWxkLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEArQKTDHzFCgeJlA5Ihl8bKlVKmOvvTb9hzAEVRKaJJV7SEhzGEfVMdy48\n\t\t\t\t\t\tMAYvF7MxGmSFmDlUQGIEdQIaV+4GKikmArV5HvQijm/REkyChWhv6cqbWrweWg2k\n\t\t\t\t\t\tIxwvLwYDy6e3tqfyGoGODstlqT6Paacu0y/WGi6XqczrVqr6pFITc0qfGopqOxTO\n\t\t\t\t\t\tS8VTCbucP5T85NDuG2g58TRYAEwX6UX5Lpzl22HRrQxm9yBxydzF9eidb9N2QLFJ\n\t\t\t\t\t\tfsl9nAWzAcf1wIfJr2IQwjeNUG+971To0nToQwT8wUm//IhiXqcynbWOCuIgWCnr\n\t\t\t\t\t\tNpMhzqaVgo7MrJ5hJusDN6aWxaN8wwIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCG\n\t\t\t\t\t\tSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4E\n\t\t\t\t\t\tFgQUJR+QfdHNcDVCRxPsYFyKxIATcAAwHwYDVR0jBBgwFoAUJR+QfdHNcDVCRxPs\n\t\t\t\t\t\tYFyKxIATcAAwDQYJKoZIhvcNAQEFBQADggEBAIKd+Q/1umHnB0U4yJMmz60kXEn2\n\t\t\t\t\t\t4V7hWArz9KGhwKLcHKM3lMdMzvFIdXDXVp0XWeorzD0fboFtOpIN8+Lmgo5la3rR\n\t\t\t\t\t\tP5NozQTzlC6ga8zKBjhjaELLhiTBKJ5KWpe/xF1qY6qSO1Id35gjx9zOnsT5Xdkz\n\t\t\t\t\t\tjJZspa0idepzJcotgx/YCQvfz6LGQpK7yx4lzKJyLXC0vLGjK3ZHPBVgfVlvFEpm\n\t\t\t\t\t\tSakTjEGtEtO+tk8yoI8HXHjsWa1M/Fu0e1n8vAu8Af2Aqlelq39loO7SmrCzYPJ1\n\t\t\t\t\t\tAxewsjzk+IZbXd39dF6YzYNvWn7+yy/My9TwHaGSTywPR+yJ0NcOJ40PyQo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cranfield.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.cranfield.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.cranfield.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.cranfield.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.cranfield.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.cranfield.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.cranfield.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.cranfield.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.cranfield.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cranfield.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEeDCCA2CgAwIBAgIJAMVh01FmcQItMA0GCSqGSIb3DQEBBQUAMIG8MQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEVMBMGA1UECBMMQmVkZm9yZHNoaXJlMRIwEAYDVQQHEwlDcmFuZmll\n\t\t\t\t\t\tbGQxHTAbBgNVBAoTFENyYW5maWVsZCBVbml2ZXJzaXR5MRYwFAYDVQQLEw1JVCBE\n\t\t\t\t\t\tZXBhcnRtZW50MSMwIQYDVQQDExpzaGliYm9sZXRoLmNyYW5maWVsZC5hYy51azEm\n\t\t\t\t\t\tMCQGCSqGSIb3DQEJARYXc3lzdGVtc0BjcmFuZmllbGQuYWMudWswHhcNMTIwODE1\n\t\t\t\t\t\tMTQzNDAyWhcNMjIwODEzMTQzNDAyWjCBvDELMAkGA1UEBhMCR0IxFTATBgNVBAgT\n\t\t\t\t\t\tDEJlZGZvcmRzaGlyZTESMBAGA1UEBxMJQ3JhbmZpZWxkMR0wGwYDVQQKExRDcmFu\n\t\t\t\t\t\tZmllbGQgVW5pdmVyc2l0eTEWMBQGA1UECxMNSVQgRGVwYXJ0bWVudDEjMCEGA1UE\n\t\t\t\t\t\tAxMac2hpYmJvbGV0aC5jcmFuZmllbGQuYWMudWsxJjAkBgkqhkiG9w0BCQEWF3N5\n\t\t\t\t\t\tc3RlbXNAY3JhbmZpZWxkLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEArQKTDHzFCgeJlA5Ihl8bKlVKmOvvTb9hzAEVRKaJJV7SEhzGEfVMdy48\n\t\t\t\t\t\tMAYvF7MxGmSFmDlUQGIEdQIaV+4GKikmArV5HvQijm/REkyChWhv6cqbWrweWg2k\n\t\t\t\t\t\tIxwvLwYDy6e3tqfyGoGODstlqT6Paacu0y/WGi6XqczrVqr6pFITc0qfGopqOxTO\n\t\t\t\t\t\tS8VTCbucP5T85NDuG2g58TRYAEwX6UX5Lpzl22HRrQxm9yBxydzF9eidb9N2QLFJ\n\t\t\t\t\t\tfsl9nAWzAcf1wIfJr2IQwjeNUG+971To0nToQwT8wUm//IhiXqcynbWOCuIgWCnr\n\t\t\t\t\t\tNpMhzqaVgo7MrJ5hJusDN6aWxaN8wwIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCG\n\t\t\t\t\t\tSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4E\n\t\t\t\t\t\tFgQUJR+QfdHNcDVCRxPsYFyKxIATcAAwHwYDVR0jBBgwFoAUJR+QfdHNcDVCRxPs\n\t\t\t\t\t\tYFyKxIATcAAwDQYJKoZIhvcNAQEFBQADggEBAIKd+Q/1umHnB0U4yJMmz60kXEn2\n\t\t\t\t\t\t4V7hWArz9KGhwKLcHKM3lMdMzvFIdXDXVp0XWeorzD0fboFtOpIN8+Lmgo5la3rR\n\t\t\t\t\t\tP5NozQTzlC6ga8zKBjhjaELLhiTBKJ5KWpe/xF1qY6qSO1Id35gjx9zOnsT5Xdkz\n\t\t\t\t\t\tjJZspa0idepzJcotgx/YCQvfz6LGQpK7yx4lzKJyLXC0vLGjK3ZHPBVgfVlvFEpm\n\t\t\t\t\t\tSakTjEGtEtO+tk8yoI8HXHjsWa1M/Fu0e1n8vAu8Af2Aqlelq39loO7SmrCzYPJ1\n\t\t\t\t\t\tAxewsjzk+IZbXd39dF6YzYNvWn7+yy/My9TwHaGSTywPR+yJ0NcOJ40PyQo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cranfield University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cranfield.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cranfield University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://karma.cines.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "krasinski@cines.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://karma.cines.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2016-02-19T09:38:24Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://karma.cines.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://karma.cines.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://karma.cines.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cines.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.cines.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CINES IDP"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CINES IDP"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CINES"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CINES"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUIUg5/YXCbKUqS49yhXNkA/d6yuYwDQYJKoZIhvcNAQEL\nBQAwGTEXMBUGA1UEAwwOa2FybWEuY2luZXMuZnIwHhcNMTYwMTI1MTM0NDQ4WhcN\nMzYwMTI1MTM0NDQ4WjAZMRcwFQYDVQQDDA5rYXJtYS5jaW5lcy5mcjCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBANu54BvbX+5/D7tuP1dCztjUVn/MHbC/\nfu9dFJgFPk6pURS9SfvKbio9VMHMDTeC+GzgFcRw1dqAf+hjphc+sf8numngcCRM\nOJ2j0yuDGcToHN588U0GrDCJhJTacZSGdqkRuURHV1/2OFXov7Ns5VSIt+1MZSek\ncahtA0hXQaufRCJxxSrxbsx+8OUH54ZBDCRSofjBw3AZ+BK3WnXD/Vp1pJZLkY3G\nXsEYdQ3mcNNxpJIFYqt3RAcTnbzB+MgMdakVlq1rU/Ww2UAsRsy0MFJJgyXvnRCX\nUtweOP6lwgDP8aQip11F26b6SqXROWDrbIDRDvWVdEcy/v5lEdCauekCAwEAAaNj\nMGEwHQYDVR0OBBYEFLZhF7Wvl1v2+XeXM+Sr33VT2K1aMEAGA1UdEQQ5MDeCDmth\ncm1hLmNpbmVzLmZyhiVodHRwczovL2thcm1hLmNpbmVzLmZyL2lkcC9zaGliYm9s\nZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQA4QtOAQ0fJXi+AJEtTKsmV2FxQAhexk3xw\nCBZ1C16f6FkO8gDzNwOiYQ2JZvjKoPweaYIaAz4JrPC0CoqHtYe64D/Q3A3VXp63\nPgG568uVvKcKA+/H5Ne+XxfJ1dM/3nFAHPG+KEMaS28HT0a3PSP8YgMlMdm4yuT8\n35iAOjGhQNbFFk0cEBW7QZNoKvPQb6iTpivnj+/cszl88WddRnnQ4MKmhMWSxyeg\ntcvxNWnLsewMI+3jLvujDxbAPUpP7Fb40MqNum9B2ItoZ/eJDZoMJFj30rAnv3Ao\nzjGWswXH8rAJppsF/BSPLm652s9rwwoC1cib/3d/NNALEla2aWlP"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CINES"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.cines.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CINES"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:udayton.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibadmin@udayton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth IdP Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibadmin@udayton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth IdP Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@udayton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UDit Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "itriskmgmt@udayton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Risk Management Officer"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "urn:mace:incommon:udayton.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.udayton.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.udayton.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibidp.udayton.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.udayton.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.udayton.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.udayton.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "udayton.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.udayton.edu/udit/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Dayton"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Dayton Shibboleth IdP"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www-secure.udayton.edu/_udayton/images/logo/redbluep1.gif",
                    "lang": "en",
                    "height": "288",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "290"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.udayton.edu/udit/service_level_resources/policies/index.php"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUM/VS7xvn6O7+NovKwSxpIjkhzhkwDQYJKoZIhvcNAQEF\nBQAwHjEcMBoGA1UEAxMTc2hpYmlkcC51ZGF5dG9uLmVkdTAeFw0xMzA5MTAxOTE1\nNTlaFw0zMzA5MTAxOTE1NTlaMB4xHDAaBgNVBAMTE3NoaWJpZHAudWRheXRvbi5l\nZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCFNXC0nnErPACwgzs7\nhNLJw5jS0oxeOvFLVE2mB28WpsEIJhi18vzBdXDgdFCtFg0gI5tHkLm4av4chvWu\n3AA5uVg2CnDKz0j+Pf/1zj+WimaVbGp2eropwcL6EE492M+y4Zy9Y/86DPtkpAvL\niYf66+gHlYD3v6fOQ4CMOSq0/iDuuMNYMmKYjLpWSCZDfAKuRJDcjmX3jm/ntOLA\nGU2EDroOD2PxkPPDm8oivCCHzCwXqrMxYtS96IHzQswlq3jUQY6UIFyVlfJ7CTi2\nAGKsf7eNoELwEou+qCfeO/lprI8D+ZkF6P9S+EtdRI816I5hW1+etQ+SgezeuuLm\nG44dAgMBAAGjbTBrMEoGA1UdEQRDMEGCE3NoaWJpZHAudWRheXRvbi5lZHWGKmh0\ndHBzOi8vc2hpYmlkcC51ZGF5dG9uLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4E\nFgQUTC2xjWDPuJi+4XmfZOjBlJjY5CkwDQYJKoZIhvcNAQEFBQADggEBAEOmvD/n\nsv7qh/6PAzc6L0ETGjGNJ38xU5AVJ77Qnxg39KXc3859zZOsZfv7cyxZg1yb7Zb+\nYLI5IeummkWFPVoHKVseN5g9g5LOkTG1oO8/t+ecf+5HbZe22ShtkHV4W+ZU9+Dd\nF7opRWRtJ58D4QQtrUqLS9wEeh6RSluLRWRhZ8ysYTdOs4bxu16ca2mXNEWAgOUs\nWHxpQxkAhiunKbvp6PYT1xuRJShnCfDdOaN6ZPEYN3xdt7BGnEQFLSld6vVPuA9P\nQ7nJdbEtqUixvYf8kOt5p7yu0hN1P9Il6KGK4accYZcZwz5iraHYwL/rakWeSrWe\ntxASPQkR5yOUfss="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDbjCCAlYCCQCKKt3UaF/nmjANBgkqhkiG9w0BAQUFADB5MQswCQYDVQQGEwJV\nUzENMAsGA1UECBMET2hpbzEPMA0GA1UEBxMGRGF5dG9uMR0wGwYDVQQKExRVbml2\nZXJzaXR5IG9mIERheXRvbjENMAsGA1UECxMEVURpdDEcMBoGA1UEAxMTc2hpYmlk\ncC51ZGF5dG9uLmVkdTAeFw0xMDA5MjExNTEwNTJaFw0xMzA5MjAxNTEwNTJaMHkx\nCzAJBgNVBAYTAlVTMQ0wCwYDVQQIEwRPaGlvMQ8wDQYDVQQHEwZEYXl0b24xHTAb\nBgNVBAoTFFVuaXZlcnNpdHkgb2YgRGF5dG9uMQ0wCwYDVQQLEwRVRGl0MRwwGgYD\nVQQDExNzaGliaWRwLnVkYXl0b24uZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEAlMbLot/GWCWmA3Rkewmm+8wOk0Wb+Apl1ykjT+95tmcjYQUw9l9z\nMSp0tAJGoUSd0MzEphSPuV+nUwO2G0SbC7p93KNhMeT+Z/K05z8fhXycJmFj9MWe\ndTM9kXKQVds57cTa5zoZov5/lf25P6s3XO4Wk/oR1LlQXRIeO/kgubOeUh8oMhVk\nsl+bY19GqS0fBLsP16F/TN+uM1icSdMiFS1sH5b4QEsWHaSSQfh4lX2DK9lCLWes\n9lmOWiwwYC4nnRkjgXTVlGD9G2oE+iBhTM/BWPR9K9sC0iNc+6SPU9505BymCnF7\nZGCpjpHoEgEKpmQbUzgjrfO097sUZqebgwIDAQABMA0GCSqGSIb3DQEBBQUAA4IB\nAQCOReA51O+wYztvqxT4Y0N6zHeACRe4Rcky4Pufe58y3zLw0VRBO9WII1bPa6i0\nUgO1eGBysskHgG2UqU56CRLymbv9173riEQazX05s1ov5Q1UjbDmag736PS0l06G\nyTsH/lTbUFzoZAvsaFbYOV8pgYHMUyVyt229S2fdd4fEPtd5/Zy6SbcpPDccn11m\nMjJUYy7Ehrs3mBO0IBMCUL/HJ7SpoOEO17naZM8tk47nJDD6it3y6ZL3VFpOWAB5\nVMdHiRS3spxAs7ucmCKjy6zIxBvHjkTYHqaU0BpA2CBCPaBEJURAVlsWxpR30rwa\nd9zo8/mEfl59OrJ1rbki2xP1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "http://www.udayton.edu/udit/"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Dayton"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.udayton.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Dayton"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://2013.qmplus.qmul.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:its-aa@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Academic Applications"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:moodle-support@ulcc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Moodle Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:its-aa@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Academic Applications"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://2013.qmplus.qmul.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-06-30T09:30:34Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Queen Mary and Westfield College : 2013 Archive service QMPlus"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qmul.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Queen Mary and Westfield College, University of London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://2013.qmplus.qmul.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://2013.qmplus.qmul.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJAPF6LFlIA32CMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\n\t\t\t\t\t\tBAMTFjIwMTMucW1wbHVzLnFtdWwuYWMudWswHhcNMTQwNjI1MTAzNDEyWhcNMjQw\n\t\t\t\t\t\tNjIyMTAzNDEyWjAhMR8wHQYDVQQDExYyMDEzLnFtcGx1cy5xbXVsLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAw6/lcGM+dX3Di5zb59Vgc9Nk\n\t\t\t\t\t\tpua1wWdwr4a0f/r7OIpzAy9eAJyTh/OSOZ1OOBfnqUfyyyQDKYNEo/647esD2BsS\n\t\t\t\t\t\tpcTVNI0gyiL5RDgrYWKUyHYR0ABfWE7dcH8C3dqqvA+p1Gw5919DhqJ5bGjid9aJ\n\t\t\t\t\t\tFJcAIybDhEhLGPsrrleHYVJTvORhr5Nx9JSUPGOBbPrvnan6e4WDgF+0Ag9F2tqR\n\t\t\t\t\t\tEw1k3AAfcEQoJ1zYW30lpPvAcCcPXq0S0KMt7tyTCj8QwBzTL4grtUDrxHlNDGge\n\t\t\t\t\t\tmh8y4mNRqovf6BaFtiw7qDR6bMb6zSMMQslba1elMPcKDsHpjVFrUyuSLaQrLQID\n\t\t\t\t\t\tAQABo0QwQjAhBgNVHREEGjAYghYyMDEzLnFtcGx1cy5xbXVsLmFjLnVrMB0GA1Ud\n\t\t\t\t\t\tDgQWBBT4f7ZeBIp8yxs6bHP+sIwzrWqgCDANBgkqhkiG9w0BAQUFAAOCAQEAo17z\n\t\t\t\t\t\ts4xG2srq3DBGYf6AIjAnbFmdHwcJ+LlZ1iubB4mA6p/UhgmFo7VRQuguLCOu7ODN\n\t\t\t\t\t\tl+hl7Dwrqlm5EFXy/wZ1U4PKFwubjcWRpdwTacucVE7gsJ89Fc+biQF9gx+wfbF9\n\t\t\t\t\t\tivhUzzOPK7uduFxzmkiVqBUMay2jzHk4PKavzUKYwyMJq67oEkgzAVqMhsrSY06Q\n\t\t\t\t\t\tNXPEera7rHya4c+6acbmYPyzDIUPNe9AfBEkqiyIT2XoMtE+bJGEIyrhE1Guir4W\n\t\t\t\t\t\twW1DKXTMp8Y/c74joFVC0Eu3ZDdzGDLbkZRrYbH4868mcA+zAVLXWXpHVD62XXQX\n\t\t\t\t\t\td9OOKeCgcXtItuvjoQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://2013.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://2013.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://2013.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://2013.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://2013.qmplus.qmul.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://2013.qmplus.qmul.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://uat-bod-gui.geant.net/autobahn-gui",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it@geant.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "G\u00c9ANT IT"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it@geant.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "G\u00c9ANT IT"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://uat-bod-gui.geant.net/autobahn-gui",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-09-19T16:01:38Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "G\u00c9ANT Limited"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dante.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "G\u00c9ANT Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "response_location": "https://uat-bod-gui.geant.net/autobahn-gui/saml/LogoutServiceHTTPRedirectResponse",
              "location": "https://uat-bod-gui.geant.net/autobahn-gui/saml/LogoutServiceHTTPRedirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "A Portal that can be used to access the BoD service for requesting circuit reservations, tracking their status and for administrative operation"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "BoD Portal"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMjCCAhqgAwIBAgIJAMEuy+eDkc/OMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\n\t\t\t\t\t\tBAMTFXVhdC1ib2QtZ3VpLmdlYW50Lm5ldDAeFw0xNDA0MTExNTEwMTRaFw0xNzA0\n\t\t\t\t\t\tMTExNTEwMTRaMCAxHjAcBgNVBAMTFXVhdC1ib2QtZ3VpLmdlYW50Lm5ldDCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL9lmeNqQLqsIvz+9wIHTQ01unef\n\t\t\t\t\t\tzHS+ydVbDDdDAt9+GbKGtQMzkEKdDCQP/OVR4oFJoy26YZO2wC3LcgfcYsZn2RNV\n\t\t\t\t\t\t9de4Y/Wyov/LOulVAtxiPBkcMuBpdDiyeHc04dI29BDAk4A9b/oh2DRLOSOr0X6n\n\t\t\t\t\t\tSxYlVdoRqlsNlvt5P94O5Y+iywszr+fSWkg4wXnBbhU5wz8WiMajAhwSUv/WihTn\n\t\t\t\t\t\t0kjbBPCC/oB9X4rInBWPavZlq/vLT+Xs90c/ouu+uDC2xtGopR9mk/tZZUw6VT+w\n\t\t\t\t\t\tx6TOgSPPVBONVYcVn068Ea8L0fIDvKJUglVOhNnLo4SikRNP6Q6o+vSz5LsCAwEA\n\t\t\t\t\t\tAaNvMG0wTAYDVR0RBEUwQ4IVdWF0LWJvZC1ndWkuZ2VhbnQubmV0hipodHRwczov\n\t\t\t\t\t\tL3VhdC1ib2QtZ3VpLmdlYW50Lm5ldC9hdXRvYmFobi1ndWkwHQYDVR0OBBYEFDx7\n\t\t\t\t\t\twMI5VKSZDqbH18/emvgkpgogMA0GCSqGSIb3DQEBBQUAA4IBAQCxq8PPlNcMoFdK\n\t\t\t\t\t\tBCMG8N+ZxA540tGHaaiEdBWutqQ29csBJn/c2BKdcP1P+A71lQKQrDOQUIZ0DHTi\n\t\t\t\t\t\tKyVVjDeavoVZndhGLZuviHK4CJU7uON15fEzz2mu3tBm1H2i7bVDjG3Quh/TAar7\n\t\t\t\t\t\tVnGDY6tHLG2vktHHIsXWxidajHIilI8XF14wC+Eoe8nt9ot2xJ0GxYzKcgu6wYUc\n\t\t\t\t\t\tJTse+N5A0mRv40kor80ySUbJ+U4CrvelDlpaj+PmlcR5k4aSQ05prZnjWViRpQo+\n\t\t\t\t\t\tqayfadpzImYfGj+E07YDQHoTy4kj2u8mVk5VLlC/zpAZ5E6lz8Sf5+ESYL3TYcAa\n\t\t\t\t\t\txYkpdcr0"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMjCCAhqgAwIBAgIJAMEuy+eDkc/OMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\n\t\t\t\t\t\tBAMTFXVhdC1ib2QtZ3VpLmdlYW50Lm5ldDAeFw0xNDA0MTExNTEwMTRaFw0xNzA0\n\t\t\t\t\t\tMTExNTEwMTRaMCAxHjAcBgNVBAMTFXVhdC1ib2QtZ3VpLmdlYW50Lm5ldDCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL9lmeNqQLqsIvz+9wIHTQ01unef\n\t\t\t\t\t\tzHS+ydVbDDdDAt9+GbKGtQMzkEKdDCQP/OVR4oFJoy26YZO2wC3LcgfcYsZn2RNV\n\t\t\t\t\t\t9de4Y/Wyov/LOulVAtxiPBkcMuBpdDiyeHc04dI29BDAk4A9b/oh2DRLOSOr0X6n\n\t\t\t\t\t\tSxYlVdoRqlsNlvt5P94O5Y+iywszr+fSWkg4wXnBbhU5wz8WiMajAhwSUv/WihTn\n\t\t\t\t\t\t0kjbBPCC/oB9X4rInBWPavZlq/vLT+Xs90c/ouu+uDC2xtGopR9mk/tZZUw6VT+w\n\t\t\t\t\t\tx6TOgSPPVBONVYcVn068Ea8L0fIDvKJUglVOhNnLo4SikRNP6Q6o+vSz5LsCAwEA\n\t\t\t\t\t\tAaNvMG0wTAYDVR0RBEUwQ4IVdWF0LWJvZC1ndWkuZ2VhbnQubmV0hipodHRwczov\n\t\t\t\t\t\tL3VhdC1ib2QtZ3VpLmdlYW50Lm5ldC9hdXRvYmFobi1ndWkwHQYDVR0OBBYEFDx7\n\t\t\t\t\t\twMI5VKSZDqbH18/emvgkpgogMA0GCSqGSIb3DQEBBQUAA4IBAQCxq8PPlNcMoFdK\n\t\t\t\t\t\tBCMG8N+ZxA540tGHaaiEdBWutqQ29csBJn/c2BKdcP1P+A71lQKQrDOQUIZ0DHTi\n\t\t\t\t\t\tKyVVjDeavoVZndhGLZuviHK4CJU7uON15fEzz2mu3tBm1H2i7bVDjG3Quh/TAar7\n\t\t\t\t\t\tVnGDY6tHLG2vktHHIsXWxidajHIilI8XF14wC+Eoe8nt9ot2xJ0GxYzKcgu6wYUc\n\t\t\t\t\t\tJTse+N5A0mRv40kor80ySUbJ+U4CrvelDlpaj+PmlcR5k4aSQ05prZnjWViRpQo+\n\t\t\t\t\t\tqayfadpzImYfGj+E07YDQHoTy4kj2u8mVk5VLlC/zpAZ5E6lz8Sf5+ESYL3TYcAa\n\t\t\t\t\t\txYkpdcr0"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://uat-bod-gui.geant.net/autobahn-gui/saml/SAMLAssertionConsumer",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uat-bod-gui.geant.net/autobahn-gui/saml/SAMLAssertionConsumer",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "BoD Portal"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "A Portal that can be used to access the BoD service for requesting circuit reservations, tracking their status and for administrative operation"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.kdg.be/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk-ict@kdg.be"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dienst ICT"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.kdg.be/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://federation.belnet.be/files/Belnet-metadata-registration-practice-statement.txt"
              }
            ],
            "registration_instant": "2012-03-27T12:00:00Z",
            "registration_authority": "http://federation.belnet.be/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAPGgGOPxkWRQN27VjuZmpvCjmnizMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMMCmlkcC5rZGcuYmUwHhcNMTQwODI1MDkwMzMxWhcNMzQw\nODI1MDkwMzMxWjAVMRMwEQYDVQQDDAppZHAua2RnLmJlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAlmhFinjjac992YuR8BS07MxfWNReYJe+lmhRozRo\nmtptX2VcrTUHKEMhQES1XRsT8EBA/Ib0NkkD8Liw1MvmbZ8GXhBnZ/2wV/KBv8yN\n6YmMb5+1Ss+WwrKQcgarF5RjS7fD7TxjQcxvDrBo43z93aZeImqB/ZRjDb/JZ30y\nDliyUAjEpVt+9BIwTLPmvJkL4kVUBMcqCSO3dFns4Blov7Dm8nURo5C/F3g3CSmw\n6hOi2KdW3EamPcV9ZJ0D5BMBM40Bo3Ko2HGOcxvhKZap6MSIP4lKlWE8RNGXehGY\nP1SOTUQIBekv7rbjRAftcQcSFIeJVX5UUDfHAzDEly5iEQIDAQABo1swWTAdBgNV\nHQ4EFgQUpZDuzFNVGzknO9+UHMTlPr9V/I0wOAYDVR0RBDEwL4IKaWRwLmtkZy5i\nZYYhaHR0cHM6Ly9pZHAua2RnLmJlL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\nBQUAA4IBAQBHT0WU2xpqxQlrM5pzEA+6ddq+7M/84eGyzj3L7WRs/RNmtwrxKlv2\nafRgZsMTMBA60AUQz5sBwK5GkIvg+ZYwBl8mGTQYY6/Um3EUqB3SzsHFgIE85NHG\nlR4h7WT9Yb2qPgUWCBkz/UfrphGhje7NUzrCJGJoKPsm6uSNyl804Q1KrWwV1WFM\neEswby9HNRf2RuAKiVAtSDP1MvLO6wEMTQAgwyBjSb9C8iYdUHUk7ARNz9vBIx55\nDip0z/sGPBLF+QVmQdY1y0uMawVy9FJp/OzRAQ97PGZrRx9BnuVgQP5qjtLZV+Sg\nWwKI1yjSjIyoht8aBaNNdlNtFLfcf2q3"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kdg.be"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.kdg.be:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.kdg.be:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.kdg.be/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.kdg.be/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.kdg.be:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.kdg.be/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.kdg.be/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.kdg.be/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.kdg.be/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.kdg.be:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.kdg.be:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kdg.be"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Karel de Grote-Hogeschool, Katholieke Hogeschool Antwerpen"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,\ ",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "250"
                  },
                  {
                    "text": "data:image/png;base64,\ ",
                    "height": "75",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "75"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Karel de Grote-Hogeschool"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "kdg.be"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.2198900,4.4034600"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.154.64/26"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.71.0/26"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.191.182.128/25"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:06a8:0540::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAPGgGOPxkWRQN27VjuZmpvCjmnizMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMMCmlkcC5rZGcuYmUwHhcNMTQwODI1MDkwMzMxWhcNMzQw\nODI1MDkwMzMxWjAVMRMwEQYDVQQDDAppZHAua2RnLmJlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAlmhFinjjac992YuR8BS07MxfWNReYJe+lmhRozRo\nmtptX2VcrTUHKEMhQES1XRsT8EBA/Ib0NkkD8Liw1MvmbZ8GXhBnZ/2wV/KBv8yN\n6YmMb5+1Ss+WwrKQcgarF5RjS7fD7TxjQcxvDrBo43z93aZeImqB/ZRjDb/JZ30y\nDliyUAjEpVt+9BIwTLPmvJkL4kVUBMcqCSO3dFns4Blov7Dm8nURo5C/F3g3CSmw\n6hOi2KdW3EamPcV9ZJ0D5BMBM40Bo3Ko2HGOcxvhKZap6MSIP4lKlWE8RNGXehGY\nP1SOTUQIBekv7rbjRAftcQcSFIeJVX5UUDfHAzDEly5iEQIDAQABo1swWTAdBgNV\nHQ4EFgQUpZDuzFNVGzknO9+UHMTlPr9V/I0wOAYDVR0RBDEwL4IKaWRwLmtkZy5i\nZYYhaHR0cHM6Ly9pZHAua2RnLmJlL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\nBQUAA4IBAQBHT0WU2xpqxQlrM5pzEA+6ddq+7M/84eGyzj3L7WRs/RNmtwrxKlv2\nafRgZsMTMBA60AUQz5sBwK5GkIvg+ZYwBl8mGTQYY6/Um3EUqB3SzsHFgIE85NHG\nlR4h7WT9Yb2qPgUWCBkz/UfrphGhje7NUzrCJGJoKPsm6uSNyl804Q1KrWwV1WFM\neEswby9HNRf2RuAKiVAtSDP1MvLO6wEMTQAgwyBjSb9C8iYdUHUk7ARNz9vBIx55\nDip0z/sGPBLF+QVmQdY1y0uMawVy9FJp/OzRAQ97PGZrRx9BnuVgQP5qjtLZV+Sg\nWwKI1yjSjIyoht8aBaNNdlNtFLfcf2q3"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Karel de Grote-Hogeschool"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kdg.be"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "KdG"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idptoo.osu.cz/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Vixie"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "eduid@osu.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alice"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idptoo.osu.cz/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2011-03-21T14:50:41Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/university"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idptoo.osu.cz/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idptoo.osu.cz/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idptoo.osu.cz/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idptoo.osu.cz/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idptoo.osu.cz/simplesaml/saml2/idp/ArtifactResolutionService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osu.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.osu.cz/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.osu.eu/"
                  }
                ],
                "description": [
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro Ostravskou univerzitu v Ostrav\u011b"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for University of Ostrava"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idptoo.osu.cz/simplesaml/logo_ou.png",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "133"
                  }
                ],
                "display_name": [
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ostravsk\u00e1 univerzita v Ostrav\u011b"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Ostrava"
                  },
                  {
                    "lang": "la",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universitas Ostraviensis"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Ostrava"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ostravsk\u00e1 univerzita v Ostrav\u011b"
          },
          {
            "lang": "la",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universitas Ostraviensis"
          }
        ],
        "organization_url": [
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.osu.cz/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.osu.eu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Ostrava"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ostravsk\u00e1 univerzita v Ostrav\u011b"
          },
          {
            "lang": "la",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universitas Ostraviensis"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ludicris.lub.lu.se/Shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Holoshka"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "david.holoshka@ub.lu.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ludicris.lub.lu.se/Shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://ludicris.lub.lu.se/admin/saml/SingleLogout/alias/pure",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "http://ludicris.lub.lu.se/admin/saml/SingleLogout/alias/pure",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "http://ludicris.lub.lu.se/admin/saml/SingleLogout/alias/pure",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Uppdaterat forsknings information system"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Current research information system"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lucris test"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lucris test"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEETCCAvmgAwIBAgIJAIw2INOkQuPLMA0GCSqGSIb3DQEBCwUAMIGeMQswCQYDVQQGEwJzZTEO\nMAwGA1UECAwFc2thbmUxDTALBgNVBAcMBGx1bmQxGDAWBgNVBAoMD0x1bmQgVW5pdmVyc2l0eTEb\nMBkGA1UECwwSVW5pdmVyc2l0eSBMaWJyYXJ5MREwDwYDVQQDDAhsdWRpY3JpczEmMCQGCSqGSIb3\nDQEJARYXZGF2aWQuaG9sb3Noa2FAdWIubHUuc2UwHhcNMTUxMTA5MDk0OTQ5WhcNMTcxMDI5MDk0\nOTQ5WjCBnjELMAkGA1UEBhMCc2UxDjAMBgNVBAgMBXNrYW5lMQ0wCwYDVQQHDARsdW5kMRgwFgYD\nVQQKDA9MdW5kIFVuaXZlcnNpdHkxGzAZBgNVBAsMElVuaXZlcnNpdHkgTGlicmFyeTERMA8GA1UE\nAwwIbHVkaWNyaXMxJjAkBgkqhkiG9w0BCQEWF2RhdmlkLmhvbG9zaGthQHViLmx1LnNlMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvEdl2vqOVz1qy8S13/9CqYXp2VyrTz+LtIFZf5H/\n45Inzd0I1EMeDPZsW3CNfEmkJMlQzlwH35mQNPFwEL9hsk26I27WRfBc5Md1dviE3zPb54LQfRJP\nZDaAqP+7fJ2jEUzomJWrO1qUZ08ikMRlZAg/RqkXsf/+yWFhD99n32jwMfWUz4/TW7/hcQnglQTm\nx6iYah6YiQzHAcKDG15eenCzbQEuiYx3jU5mvXR/t2EEYNV3j/QpsS9HRz+2pJNHKBzZJmt6JinG\nTNuknCxqeHLVca5MJXC+TWXBEaQU4ec4BZ1QpnHXvfJ/fPjLm4mFAC/s3kDYBPBLV5N51+c6eQID\nAQABo1AwTjAdBgNVHQ4EFgQU4mr68BYrn/ePlI3AzlErLjyV+w8wHwYDVR0jBBgwFoAU4mr68BYr\nn/ePlI3AzlErLjyV+w8wDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAQEASF2PhO6m5GQE\nDaKfV4Urtilp1Ru2hctQX+mhE16JGTHcFWYjO298Y8OmUV1845tUAU+Bgv4DHSWYqUtwutxuNLOL\ngI5cNJs+aCq5/opE4Ele2fcHZ3uvpOU6IrZAG1bu2rheW7KamW88CE5QQ1vWCaGHxdYw1cKyvxoD\n8R4AfsDq0caHuWC8HBozWj2v7F8MlKxQjhPdukYkfQJ8JbHmCQ4HMdgC2f1+s1E1EAVR9zRPHTaB\nqIpjIsKQTnr0tI/EteQ0mJ0T4V5pNp0aJfH+H/RFlDBimI/W3x0fGQg9Xy7ZzkmQvwjCdQFVZRPA\nuuNxKggJPJhRph8bitha6sR6EQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEETCCAvmgAwIBAgIJAIw2INOkQuPLMA0GCSqGSIb3DQEBCwUAMIGeMQswCQYDVQQGEwJzZTEO\nMAwGA1UECAwFc2thbmUxDTALBgNVBAcMBGx1bmQxGDAWBgNVBAoMD0x1bmQgVW5pdmVyc2l0eTEb\nMBkGA1UECwwSVW5pdmVyc2l0eSBMaWJyYXJ5MREwDwYDVQQDDAhsdWRpY3JpczEmMCQGCSqGSIb3\nDQEJARYXZGF2aWQuaG9sb3Noa2FAdWIubHUuc2UwHhcNMTUxMTA5MDk0OTQ5WhcNMTcxMDI5MDk0\nOTQ5WjCBnjELMAkGA1UEBhMCc2UxDjAMBgNVBAgMBXNrYW5lMQ0wCwYDVQQHDARsdW5kMRgwFgYD\nVQQKDA9MdW5kIFVuaXZlcnNpdHkxGzAZBgNVBAsMElVuaXZlcnNpdHkgTGlicmFyeTERMA8GA1UE\nAwwIbHVkaWNyaXMxJjAkBgkqhkiG9w0BCQEWF2RhdmlkLmhvbG9zaGthQHViLmx1LnNlMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvEdl2vqOVz1qy8S13/9CqYXp2VyrTz+LtIFZf5H/\n45Inzd0I1EMeDPZsW3CNfEmkJMlQzlwH35mQNPFwEL9hsk26I27WRfBc5Md1dviE3zPb54LQfRJP\nZDaAqP+7fJ2jEUzomJWrO1qUZ08ikMRlZAg/RqkXsf/+yWFhD99n32jwMfWUz4/TW7/hcQnglQTm\nx6iYah6YiQzHAcKDG15eenCzbQEuiYx3jU5mvXR/t2EEYNV3j/QpsS9HRz+2pJNHKBzZJmt6JinG\nTNuknCxqeHLVca5MJXC+TWXBEaQU4ec4BZ1QpnHXvfJ/fPjLm4mFAC/s3kDYBPBLV5N51+c6eQID\nAQABo1AwTjAdBgNVHQ4EFgQU4mr68BYrn/ePlI3AzlErLjyV+w8wHwYDVR0jBBgwFoAU4mr68BYr\nn/ePlI3AzlErLjyV+w8wDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAQEASF2PhO6m5GQE\nDaKfV4Urtilp1Ru2hctQX+mhE16JGTHcFWYjO298Y8OmUV1845tUAU+Bgv4DHSWYqUtwutxuNLOL\ngI5cNJs+aCq5/opE4Ele2fcHZ3uvpOU6IrZAG1bu2rheW7KamW88CE5QQ1vWCaGHxdYw1cKyvxoD\n8R4AfsDq0caHuWC8HBozWj2v7F8MlKxQjhPdukYkfQJ8JbHmCQ4HMdgC2f1+s1E1EAVR9zRPHTaB\nqIpjIsKQTnr0tI/EteQ0mJ0T4V5pNp0aJfH+H/RFlDBimI/W3x0fGQg9Xy7ZzkmQvwjCdQFVZRPA\nuuNxKggJPJhRph8bitha6sR6EQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "http://ludicris.lub.lu.se/admin/saml/SSO/alias/pure",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "http://ludicris.lub.lu.se/admin/saml/SSO/alias/pure",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://tc-web-02.groupgti.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:targetconnect.support@groupgti.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TARGETconnect Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Masters"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chris.masters@groupgti.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://tc-web-02.groupgti.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GTI: TARGETconnect Web2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.groupgti.com/home/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GTI Media Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEXjCCA0agAwIBAgIJAJEc5gsxNUbCMA0GCSqGSIb3DQEBBQUAMIGvMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEUMBIGA1UECBMLT3hmb3Jkc2hpcmUxFDASBgNVBAcTC1dhbGxpbmdm\n\t\t\t\t\t\tb3JkMRYwFAYDVQQKEw1HVEkgTWVkaWEgTHRkMTIwMAYDVQQDEylodHRwczovL3Rj\n\t\t\t\t\t\tLXdlYi0wMi5ncm91cGd0aS5uZXQvc2hpYmJvbGV0aDEoMCYGCSqGSIb3DQEJARYZ\n\t\t\t\t\t\tY2hyaXMubWFzdGVyc0Bncm91cHRpLmNvbTAeFw0xMDA5MjMyMTA4NTRaFw0yMDA5\n\t\t\t\t\t\tMjAyMTA4NTRaMIGvMQswCQYDVQQGEwJHQjEUMBIGA1UECBMLT3hmb3Jkc2hpcmUx\n\t\t\t\t\t\tFDASBgNVBAcTC1dhbGxpbmdmb3JkMRYwFAYDVQQKEw1HVEkgTWVkaWEgTHRkMTIw\n\t\t\t\t\t\tMAYDVQQDEylodHRwczovL3RjLXdlYi0wMi5ncm91cGd0aS5uZXQvc2hpYmJvbGV0\n\t\t\t\t\t\taDEoMCYGCSqGSIb3DQEJARYZY2hyaXMubWFzdGVyc0Bncm91cHRpLmNvbTCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANw+KqJVLy3RpCE6Szd2C/G3rLKO\n\t\t\t\t\t\tu1BWzqGTcFrLxElc5zMQccTeYSQY42/BrQSjY8Oan7A7ilLI6M/83mNxTFcxOpUf\n\t\t\t\t\t\tVPzajRcBnOTzUGWG7AzHn04jfYbCHozt7ek11VHoxWHGkZa1kykb+5Y1es8lKeDj\n\t\t\t\t\t\toxE82a2sRxpEQJWiJeer4S1CR8rd7AdZtxVm4CzJyfRb/eVCQAK+2aoTcyLc9fKC\n\t\t\t\t\t\tiCOLMxX/Ld+y60m3qpxqOAFeNqk+ehtAy5dakXBL9VwNyeQ1ZHgQcnh/NVJ4N3Y3\n\t\t\t\t\t\tr6tDPRHgML54s7nMz5XDewBhGjrtjvrTWYBP1Q8DTf2neLqdky+WsA63qa0CAwEA\n\t\t\t\t\t\tAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0\n\t\t\t\t\t\tZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFOC1VfX8Qxzl8vzm0SuSJ+DPl6MSMB8G\n\t\t\t\t\t\tA1UdIwQYMBaAFOC1VfX8Qxzl8vzm0SuSJ+DPl6MSMA0GCSqGSIb3DQEBBQUAA4IB\n\t\t\t\t\t\tAQC0qyxzOV6UHVavg5wVHdx9j3d1e7zmChtGPKErHz3Hovjg209dhHIooP7UqkE/\n\t\t\t\t\t\t0c4WbGEsny+Pwv6M3EAr+utRj4pjRnpglwaWygJ+cFtY29+D0g6oDLzJZy+pcgXI\n\t\t\t\t\t\tlkOjkFTGcwGAnLbVB3uEg+PTglpRVCXz4bhXpZzPzZmxsdSe/8vQF9zaNv2AIOrl\n\t\t\t\t\t\tt2r1GTl2jt/3Bg+hJvPeBCkIBHh5sNgL0UWtNMBK/j6Me0xJCkEL/IWQpHfvLKcA\n\t\t\t\t\t\tkAjByRAB/7Jw+b2CkaFGfozXh4W2ALsg7F3noW0S77LHMAcnuWEozfjc7QA8w8jV\n\t\t\t\t\t\tOij+zsSTj3QSvhRz5A2Dqv1F"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEXjCCA0agAwIBAgIJAJEc5gsxNUbCMA0GCSqGSIb3DQEBBQUAMIGvMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEUMBIGA1UECBMLT3hmb3Jkc2hpcmUxFDASBgNVBAcTC1dhbGxpbmdm\n\t\t\t\t\t\tb3JkMRYwFAYDVQQKEw1HVEkgTWVkaWEgTHRkMTIwMAYDVQQDEylodHRwczovL3Rj\n\t\t\t\t\t\tLXdlYi0wMi5ncm91cGd0aS5uZXQvc2hpYmJvbGV0aDEoMCYGCSqGSIb3DQEJARYZ\n\t\t\t\t\t\tY2hyaXMubWFzdGVyc0Bncm91cHRpLmNvbTAeFw0xMDA5MjMyMTA4NTRaFw0yMDA5\n\t\t\t\t\t\tMjAyMTA4NTRaMIGvMQswCQYDVQQGEwJHQjEUMBIGA1UECBMLT3hmb3Jkc2hpcmUx\n\t\t\t\t\t\tFDASBgNVBAcTC1dhbGxpbmdmb3JkMRYwFAYDVQQKEw1HVEkgTWVkaWEgTHRkMTIw\n\t\t\t\t\t\tMAYDVQQDEylodHRwczovL3RjLXdlYi0wMi5ncm91cGd0aS5uZXQvc2hpYmJvbGV0\n\t\t\t\t\t\taDEoMCYGCSqGSIb3DQEJARYZY2hyaXMubWFzdGVyc0Bncm91cHRpLmNvbTCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANw+KqJVLy3RpCE6Szd2C/G3rLKO\n\t\t\t\t\t\tu1BWzqGTcFrLxElc5zMQccTeYSQY42/BrQSjY8Oan7A7ilLI6M/83mNxTFcxOpUf\n\t\t\t\t\t\tVPzajRcBnOTzUGWG7AzHn04jfYbCHozt7ek11VHoxWHGkZa1kykb+5Y1es8lKeDj\n\t\t\t\t\t\toxE82a2sRxpEQJWiJeer4S1CR8rd7AdZtxVm4CzJyfRb/eVCQAK+2aoTcyLc9fKC\n\t\t\t\t\t\tiCOLMxX/Ld+y60m3qpxqOAFeNqk+ehtAy5dakXBL9VwNyeQ1ZHgQcnh/NVJ4N3Y3\n\t\t\t\t\t\tr6tDPRHgML54s7nMz5XDewBhGjrtjvrTWYBP1Q8DTf2neLqdky+WsA63qa0CAwEA\n\t\t\t\t\t\tAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0\n\t\t\t\t\t\tZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFOC1VfX8Qxzl8vzm0SuSJ+DPl6MSMB8G\n\t\t\t\t\t\tA1UdIwQYMBaAFOC1VfX8Qxzl8vzm0SuSJ+DPl6MSMA0GCSqGSIb3DQEBBQUAA4IB\n\t\t\t\t\t\tAQC0qyxzOV6UHVavg5wVHdx9j3d1e7zmChtGPKErHz3Hovjg209dhHIooP7UqkE/\n\t\t\t\t\t\t0c4WbGEsny+Pwv6M3EAr+utRj4pjRnpglwaWygJ+cFtY29+D0g6oDLzJZy+pcgXI\n\t\t\t\t\t\tlkOjkFTGcwGAnLbVB3uEg+PTglpRVCXz4bhXpZzPzZmxsdSe/8vQF9zaNv2AIOrl\n\t\t\t\t\t\tt2r1GTl2jt/3Bg+hJvPeBCkIBHh5sNgL0UWtNMBK/j6Me0xJCkEL/IWQpHfvLKcA\n\t\t\t\t\t\tkAjByRAB/7Jw+b2CkaFGfozXh4W2ALsg7F3noW0S77LHMAcnuWEozfjc7QA8w8jV\n\t\t\t\t\t\tOij+zsSTj3QSvhRz5A2Dqv1F"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://saml2.targetconnect.net/samlengine/shibb/acs",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://saml2.targetconnect.net/samlengine/s2/wbsso/acs",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://saml2.targetconnect.net/samlengine/s2/wbsso/acs",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.unimc.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Reda"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:csia.sistemi@unimc.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Massimo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Principi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:csia.sistemi@unimc.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marco"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.unimc.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2014-04-22T12:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAIEgUNZ2kbCrw2zNqYwgIJCvedDSMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDGlkcC51bmltYy5pdDAeFw0xMzA0MDExNjAxNDZaFw0z\nMzA0MDExNjAxNDZaMBcxFTATBgNVBAMTDGlkcC51bmltYy5pdDCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAJtks8bJInpYW8j049YMBTWfGRfkMgTPQ2fI\nT1TLbkZ+zSTvm+hgBdeyY0g0EkpC7MmkrcigKc+BWdXaaeBHWh1extz08cVtcNEH\n52vTw9asy2cXh/EFd0Br1zc9j0dEXLhnCVNHI6Vi7F7oTlsAb2Xt7/iQuWjT/cKM\nEiqt+qVSgdtRsRCD6RJLlINGeunjFDizUymDxtt1ZB5mU1DlpC4cynImG0jI3DsK\nh0MhjeYSWLn9giA7j7hOTSqJuZddv/Y+YOWrMScV1jfiu1uMN2DllOjapt7DUsxi\nbgtrc7Vig5o/ZVqLd4zI8lHsrqKUCDQBO9EviQq98bMbqqTCq/MCAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMaWRwLnVuaW1jLml0hiNodHRwczovL2lkcC51bmltYy5pdC9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU1nYOH/vCkNVmfvhCYkLSRhlGZR0wDQYJ\nKoZIhvcNAQEFBQADggEBAFmIBImjvlX9VF4e/qYv/rvTILMUskF6rC8BTSYzIdLk\nwX4H6k+AUkTWkdEBkvJyvcIAg8eZqc2TH7CSu4PjYu/p+A8Uum841EY0GngIeQg/\nzeF//LRySr7iMMGcB5JmjYdeOa50DtbWAdns7BR8UNBUFYv9CR9iknmcEbtkZylK\nH/9RF3Xv7HxDNRzUuFOx0AiVdbUvQNo801Jd0SBwK7JIoYrTGM0OdxlP8VgmixZd\nyLZqGcGeMxdBisF78411jjMh+H3rDzmt8W7FkTJI0svAn3THDqBaYJqyPnfJSrab\ngakI/LbrmYc1DoncD0v9+M8RyFpzxx+5hDmhAjeucuU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unimc.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unimc.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unimc.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.unimc.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unimc.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.unimc.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unimc.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unimc.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unimc.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unimc.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://login.unimc.it/login/new/guida-garr-idem-en.php"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://login.unimc.it/login/new/guida-garr-idem.php"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Macerata."
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universita' di Macerata"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for University of Macerata users (Students, Teachers, and Employees)"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider per gli utenti dell'Universita' degli Studi di Macerata (Studenti, Docenti, Personale Tecnico)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.unimc.it/login/new/images/logo-unimc-idem-garr-16x16.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://login.unimc.it/login/new/images/logo-unimc-idem-garr-16x16.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://login.unimc.it/login/new/images/logo-unimc-idem-garr-80x60.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://login.unimc.it/login/new/images/logo-unimc-idem-garr-80x60.png",
                    "lang": "it",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.unimc.it/en/privacy-policy"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.unimc.it/it/privacy-policy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAIEgUNZ2kbCrw2zNqYwgIJCvedDSMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDGlkcC51bmltYy5pdDAeFw0xMzA0MDExNjAxNDZaFw0z\nMzA0MDExNjAxNDZaMBcxFTATBgNVBAMTDGlkcC51bmltYy5pdDCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAJtks8bJInpYW8j049YMBTWfGRfkMgTPQ2fI\nT1TLbkZ+zSTvm+hgBdeyY0g0EkpC7MmkrcigKc+BWdXaaeBHWh1extz08cVtcNEH\n52vTw9asy2cXh/EFd0Br1zc9j0dEXLhnCVNHI6Vi7F7oTlsAb2Xt7/iQuWjT/cKM\nEiqt+qVSgdtRsRCD6RJLlINGeunjFDizUymDxtt1ZB5mU1DlpC4cynImG0jI3DsK\nh0MhjeYSWLn9giA7j7hOTSqJuZddv/Y+YOWrMScV1jfiu1uMN2DllOjapt7DUsxi\nbgtrc7Vig5o/ZVqLd4zI8lHsrqKUCDQBO9EviQq98bMbqqTCq/MCAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMaWRwLnVuaW1jLml0hiNodHRwczovL2lkcC51bmltYy5pdC9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU1nYOH/vCkNVmfvhCYkLSRhlGZR0wDQYJ\nKoZIhvcNAQEFBQADggEBAFmIBImjvlX9VF4e/qYv/rvTILMUskF6rC8BTSYzIdLk\nwX4H6k+AUkTWkdEBkvJyvcIAg8eZqc2TH7CSu4PjYu/p+A8Uum841EY0GngIeQg/\nzeF//LRySr7iMMGcB5JmjYdeOa50DtbWAdns7BR8UNBUFYv9CR9iknmcEbtkZylK\nH/9RF3Xv7HxDNRzUuFOx0AiVdbUvQNo801Jd0SBwK7JIoYrTGM0OdxlP8VgmixZd\nyLZqGcGeMxdBisF78411jjMh+H3rDzmt8W7FkTJI0svAn3THDqBaYJqyPnfJSrab\ngakI/LbrmYc1DoncD0v9+M8RyFpzxx+5hDmhAjeucuU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Macerata"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 degli Studi di Macerata"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unimc.it/en"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unimc.it/it"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Macerata"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli Studi di Macerata"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://classes.myplace.strath.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Todd"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:iain.todd@strath.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Iain"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Todd"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:iain.todd@strath.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Iain"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://classes.myplace.strath.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-12-02T18:00:31Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Strathclyde Myplace"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.strath.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Strathclyde"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://classes.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://classes.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://classes.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://classes.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://classes.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://classes.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://classes.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://classes.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://classes.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJAI/TDhOS3dc1MA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\n\t\t\t\t\t\tBAMTDm1vby1jbGFzc2VzLWxiMB4XDTE1MTExMjEwMTQwNloXDTI1MTEwOTEwMTQw\n\t\t\t\t\t\tNlowGTEXMBUGA1UEAxMObW9vLWNsYXNzZXMtbGIwggEiMA0GCSqGSIb3DQEBAQUA\n\t\t\t\t\t\tA4IBDwAwggEKAoIBAQCiQjSMU7aYPhkwbkjJ0t8AfNkfeAzgyVe0ZbSpkw4fLqmS\n\t\t\t\t\t\tROAXMtdrU6JqQndlMK+RBlSNuKyfHPn2viDddXfqNA1JQWyDeuM62vCulqBsN74C\n\t\t\t\t\t\tC8uIPFYmnKBQONMVu9GSquZDb5Cdqc/Pud/wAuhAG8oNzwSj3jlekU23jVay8M3C\n\t\t\t\t\t\ti49Nx+QCq9DuLh7+lkHv5p0EOKJU6tRqP+JAs7kKjx9zDDW1InjeLFfHmNOW3XLp\n\t\t\t\t\t\tYOLmD5a1yxv8qwFu9DnRO12Erhij9ijDh201sLqqtV/SIBdkmL+kfz2S3b3+knXh\n\t\t\t\t\t\t17rqiDr/9b2FwOxL9DYLHiUDOCAiMOWd6C0TD1xLAgMBAAGjPDA6MBkGA1UdEQQS\n\t\t\t\t\t\tMBCCDm1vby1jbGFzc2VzLWxiMB0GA1UdDgQWBBQ+bhjHHFhU8uMBmalBud5HmLbe\n\t\t\t\t\t\tTzANBgkqhkiG9w0BAQUFAAOCAQEAStly/iwK52fpJVCSfR0u92+4A/51dVxiEv6P\n\t\t\t\t\t\tenqNiwujaSxtTQnlH+Y5qwuDjh55b7NgSEFVgsHyLBeM8p7VbsrGqU3v7Yz4x1KR\n\t\t\t\t\t\tHEvYldz2QVH87unSWfcGyq9Wl4vVDfoJ9vKXyS3aoK7UFTlMtbwExmpPMPo0lU57\n\t\t\t\t\t\t6XmMNdAdj29oXQtYoC9VaD12NNM+u+ex/mkgJwzTwlRwrYjAfulEwsSQvVtuttW8\n\t\t\t\t\t\t8Qw4P3vEY3d8wyVoFtNST/8PnwpjwEIP5qN6rKdZzLIcd19N2IoJnm6u5yCq1PKQ\n\t\t\t\t\t\tQXE46akAojltN9BLFBqsWd+YtEdHZF5xbAw5O4zJ5m6SLr0VIg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://classes.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://classes.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://classes.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://classes.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://classes.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://classes.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://classes.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://classes.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://classes.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://classes.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://staging.researchmonitor.euromonitor.com/web/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wiehan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Jurgen.wiehan@euromonitor.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "J\u00fcrgen"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wiehan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Jurgen.wiehan@euromonitor.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "J\u00fcrgen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://staging.researchmonitor.euromonitor.com/web/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-09-03T15:13:02Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Research Monitor (Staging) - Euromonitor International"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.euromonitor.com/contact.aspx"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Euromonitor International plc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIJAK7CyN11IEtLMA0GCSqGSIb3DQEBBQUAMEgxFDASBgNV\n\t\t\t\t\t\tBAoTC0V1cm9tb25pdG9yMTAwLgYDVQQDEydzdGFnaW5nLnJlc2VhcmNobW9uaXRv\n\t\t\t\t\t\tci5ldXJvbW9uaXRvci5jb20wHhcNMTMwOTEzMDcxNTIyWhcNMjMwOTExMDcxNTIy\n\t\t\t\t\t\tWjBIMRQwEgYDVQQKEwtFdXJvbW9uaXRvcjEwMC4GA1UEAxMnc3RhZ2luZy5yZXNl\n\t\t\t\t\t\tYXJjaG1vbml0b3IuZXVyb21vbml0b3IuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAp2d1o2RyIodtFfrHj1W4RWAcGF8sUjEdZv7Gcc0Z62CKIAzO\n\t\t\t\t\t\tymxC+b6UmqZAZdFzkzNDvJ4L7SPzi+jh9aeahZepejALQD1HxhUqQNE6hQdJfIxl\n\t\t\t\t\t\tnXXYRl7qdt12aASDSImpI+pnlEJERKGsQ7TGcWyHUBmGExbdSAQTCXcQbSzTrf8M\n\t\t\t\t\t\tqiU2mR8+NwQ59nNsIw2NmKgUaFH1G4b16Qg6sjIOBc9Qvi3T8aNJLTlWBlsc0S34\n\t\t\t\t\t\tNUhQ244bfbjDXBohORWcedO5rvVOf/jq1Zuqp2VcQjxH5mzdSwKcgaPA3Bi33kHL\n\t\t\t\t\t\tRbwfnjU81MRwnMTYn/vL+qImma+pbZmbZUBSVwIDAQABo4GqMIGnMB0GA1UdDgQW\n\t\t\t\t\t\tBBSRbu5R+jct73Fwv5E5tG05aqZk/DB4BgNVHSMEcTBvgBSRbu5R+jct73Fwv5E5\n\t\t\t\t\t\ttG05aqZk/KFMpEowSDEUMBIGA1UEChMLRXVyb21vbml0b3IxMDAuBgNVBAMTJ3N0\n\t\t\t\t\t\tYWdpbmcucmVzZWFyY2htb25pdG9yLmV1cm9tb25pdG9yLmNvbYIJAK7CyN11IEtL\n\t\t\t\t\t\tMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAHZcvly0zk2OsvuHpMFC\n\t\t\t\t\t\tds+Xmwp1NseFEB0VONywfd9lC004TmB0oCSRn7SN7fyMOBYbOsUwWM8WBUAmsY+F\n\t\t\t\t\t\tKQw9MEaNxWONzEGa7ihBtkPHWE8OoxvAnoSNK6z2ZZjzh1NE/4znsxAwEAGKZryU\n\t\t\t\t\t\tV016lBsKTqT6eRKQnV0m9IztJHZlAHRfTpNPI7cmzQssRjI+gj5GuaexhP5wr/3u\n\t\t\t\t\t\t50IQrpoNjYPhA9Cm9ayYSsI8noy8x8QmuBoSjTHM3pN+WHbpbfa+lPCijyu3nof/\n\t\t\t\t\t\tMEtQ0lp7WfwA2jm+nn0iJpl7MSyJGpmBOyr0TvV0G+UPTYmDmWQ/6wNHbnoC5uXY\n\t\t\t\t\t\t970="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIJAK7CyN11IEtLMA0GCSqGSIb3DQEBBQUAMEgxFDASBgNV\n\t\t\t\t\t\tBAoTC0V1cm9tb25pdG9yMTAwLgYDVQQDEydzdGFnaW5nLnJlc2VhcmNobW9uaXRv\n\t\t\t\t\t\tci5ldXJvbW9uaXRvci5jb20wHhcNMTMwOTEzMDcxNTIyWhcNMjMwOTExMDcxNTIy\n\t\t\t\t\t\tWjBIMRQwEgYDVQQKEwtFdXJvbW9uaXRvcjEwMC4GA1UEAxMnc3RhZ2luZy5yZXNl\n\t\t\t\t\t\tYXJjaG1vbml0b3IuZXVyb21vbml0b3IuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAp2d1o2RyIodtFfrHj1W4RWAcGF8sUjEdZv7Gcc0Z62CKIAzO\n\t\t\t\t\t\tymxC+b6UmqZAZdFzkzNDvJ4L7SPzi+jh9aeahZepejALQD1HxhUqQNE6hQdJfIxl\n\t\t\t\t\t\tnXXYRl7qdt12aASDSImpI+pnlEJERKGsQ7TGcWyHUBmGExbdSAQTCXcQbSzTrf8M\n\t\t\t\t\t\tqiU2mR8+NwQ59nNsIw2NmKgUaFH1G4b16Qg6sjIOBc9Qvi3T8aNJLTlWBlsc0S34\n\t\t\t\t\t\tNUhQ244bfbjDXBohORWcedO5rvVOf/jq1Zuqp2VcQjxH5mzdSwKcgaPA3Bi33kHL\n\t\t\t\t\t\tRbwfnjU81MRwnMTYn/vL+qImma+pbZmbZUBSVwIDAQABo4GqMIGnMB0GA1UdDgQW\n\t\t\t\t\t\tBBSRbu5R+jct73Fwv5E5tG05aqZk/DB4BgNVHSMEcTBvgBSRbu5R+jct73Fwv5E5\n\t\t\t\t\t\ttG05aqZk/KFMpEowSDEUMBIGA1UEChMLRXVyb21vbml0b3IxMDAuBgNVBAMTJ3N0\n\t\t\t\t\t\tYWdpbmcucmVzZWFyY2htb25pdG9yLmV1cm9tb25pdG9yLmNvbYIJAK7CyN11IEtL\n\t\t\t\t\t\tMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAHZcvly0zk2OsvuHpMFC\n\t\t\t\t\t\tds+Xmwp1NseFEB0VONywfd9lC004TmB0oCSRn7SN7fyMOBYbOsUwWM8WBUAmsY+F\n\t\t\t\t\t\tKQw9MEaNxWONzEGa7ihBtkPHWE8OoxvAnoSNK6z2ZZjzh1NE/4znsxAwEAGKZryU\n\t\t\t\t\t\tV016lBsKTqT6eRKQnV0m9IztJHZlAHRfTpNPI7cmzQssRjI+gj5GuaexhP5wr/3u\n\t\t\t\t\t\t50IQrpoNjYPhA9Cm9ayYSsI8noy8x8QmuBoSjTHM3pN+WHbpbfa+lPCijyu3nof/\n\t\t\t\t\t\tMEtQ0lp7WfwA2jm+nn0iJpl7MSyJGpmBOyr0TvV0G+UPTYmDmWQ/6wNHbnoC5uXY\n\t\t\t\t\t\t970="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "want_assertions_signed": "false",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://staging.researchmonitor.euromonitor.com/web/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://staging.researchmonitor.euromonitor.com/web/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://staging.researchmonitor.euromonitor.com/web/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://staging.researchmonitor.euromonitor.com/web/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://ladok3-demo-05.its.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-demo-05.its.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;demo-05"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;demo-05"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-demo-05.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-demo-05.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIJAJbNz2Ut6PxqMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\nBAMTG2xhZG9rMy1kZW1vLTA1LmxhZG9rLnVtdS5zZTAeFw0xNDEwMDcxNDQ3MTRa\nFw0yNDEwMDQxNDQ3MTRaMCYxJDAiBgNVBAMTG2xhZG9rMy1kZW1vLTA1LmxhZG9r\nLnVtdS5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJbIXoy1e4DO\nhBNnvCRv/k7Av6fxBYikDOzLQKJbtibVP9POw4fECon7c3GRiyB7lBUSPrWLkVM5\ntad4QzjFCzK+t+Wv2VBnDb22+jTPM1epyfEg619hbhujr54iFRCoZkbbDA5yQg7/\nxQsjUZT9jMZoFfKOb8AwwOtd6yUhpQmFxRyMUDgRYqOFBqu65V0zSiYuAr93e5IS\nFUDkwvDjuQP8AOf4bfvZLFepkYPELSLN9mw0+FMyWQd9LnyvKPqG32r95CpIp2ks\nf6V8uXiiLE+ZGB2WzyF4pNhyUH2nNVWIhdsOV6x4/td8oae0rAxLOcNJO2zmU44S\ngqY8LjrEc+cCAwEAAaOBgzCBgDBfBgNVHREEWDBWghtsYWRvazMtZGVtby0wNS5s\nYWRvay51bXUuc2WGN2h0dHBzOi8vbGFkb2szLWRlbW8tMDUubGFkb2sudW11LnNl\nL3N0dWRlbnQtZnJvbnRlbmQtc3AwHQYDVR0OBBYEFAzHqhqAykN2wf7NNTovucpa\nHy8TMA0GCSqGSIb3DQEBBQUAA4IBAQAFAyn+Snc7l6KHh2kDtnpUOCfKbNtx9ALu\ngnh6ltcDDZHoxq0jQNIbQNGqzdot8esoPYntY8IWSsUjZS7SxFw5x5l+/JGIrBP6\nj+zHauVcWgXgChfR2OL+CwFh979lXZniUsjVHXBhE8LxWs3IXpOmCAxY0f2txi6S\nC7InYFK8vlTWsgGvZY4gV7RjTwP8K5OkBrg/rtd3DQa67kQRmu8kAXaJboPabTUv\nETztMh0s9VwEVBPMUKyTETLvUVEnKijUC3XFHn6QB7dKc4K0MEseDwHklMHD+a4+\nXVpEXBWCzSEzde1b1UN1OpTum2X30RmEij8IrqvSnV9rX8RXu9zA"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-demo-05.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-demo-05.its.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://webauth.shib.lsu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "security@lsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Technical"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "security@lsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Administrator"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://webauth.shib.lsu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://webauth.shib.lsu.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://webauth.shib.lsu.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEYTCCA0mgAwIBAgIJAKzhFxTleiexMA0GCSqGSIb3DQEBBQUAMIHGMQswCQYD\nVQQGEwJVUzESMBAGA1UECAwJTG91aXNpYW5hMRQwEgYDVQQHDAtCYXRvbiBSb3Vn\nZTEjMCEGA1UECgwaTG91aXNpYW5hIFN0YXRlIFVuaXZlcnNpdHkxKDAmBgNVBAsM\nH0luZm9ybWF0aW9uIFRlY2hub2xvZ3kgU2VydmljZXMxHTAbBgNVBAMMFHdlYmF1\ndGguc2hpYi5sc3UuZWR1MR8wHQYJKoZIhvcNAQkBFhBzZWN1cml0eUBsc3UuZWR1\nMB4XDTEzMDcwMTE4MzkxM1oXDTMzMDYyNjE4MzkxM1owgcYxCzAJBgNVBAYTAlVT\nMRIwEAYDVQQIDAlMb3Vpc2lhbmExFDASBgNVBAcMC0JhdG9uIFJvdWdlMSMwIQYD\nVQQKDBpMb3Vpc2lhbmEgU3RhdGUgVW5pdmVyc2l0eTEoMCYGA1UECwwfSW5mb3Jt\nYXRpb24gVGVjaG5vbG9neSBTZXJ2aWNlczEdMBsGA1UEAwwUd2ViYXV0aC5zaGli\nLmxzdS5lZHUxHzAdBgkqhkiG9w0BCQEWEHNlY3VyaXR5QGxzdS5lZHUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDP/xaAZ7yLrGIwwJaGBy6iybvV2pfF\nsoOk4fQm/Rza527jYq3kNpuQdAIWzeoJku28qIqrSS3GLf14wdxSNN9rRYd7UhkY\nNzeCxidwjVANbEgM6zsD71Q+c9DM5N9HMQ2a4LZfeKdIs92sBII/3b/4y7jmpiww\nCAMlgH8xP3greb2JkU0Pbi3HA3f+Y3SH/ckNx5gbpeuCdv7rl48Y73Hfx3DVxVQm\ntsvBG0NZIkBRBtyXY2TxYQVPoKKiq3+MhKZna3TfkkExhbuY3a4QGIR0g5Ctk3fJ\nJxdVfoXx0sJJBttPgmdpwa3JNKNaC3AGJL3TbAT9fap099se5iafMtI9AgMBAAGj\nUDBOMB0GA1UdDgQWBBSX6BSJUkoRiDlEBiO4cKLpt7w3FTAfBgNVHSMEGDAWgBSX\n6BSJUkoRiDlEBiO4cKLpt7w3FTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUA\nA4IBAQAhaErPoyFvAiSq91jfbg/UK+YjyJNAW4CLjFJlyMLqAkFJrEZKEfAcbxqr\nrsOZt2fqDaDyDcRvZl82CqSZx8SZ75idjblJLlzY8d2N59QZTubLKRYxNsrxvBkY\np+tcc6zkAkh2QQdC4JPheKICpsxt1xytFHBT32CAfU2kyyzo5/ajjSzfFo8/o5Bf\nWcZP9FLd6yFxgEMSNhWYDcL+HAe4PFH9N98MhugSnQwaybJhdG8J0ig18S+9vSil\nuh8s0yON8U0+JjL/iuXv+hjwOUWvGFjFBaoIwwWpcciNJALoQy9gI7RqFd7QHJIi\nm4gMSZsHCXLYo9JbH1WYKEqJJDdZ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lsu.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://webauth.shib.lsu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webauth.shib.lsu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://webauth.shib.lsu.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://webauth.shib.lsu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://webauth.shib.lsu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://webauth.shib.lsu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lsu.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://webauth.shib.lsu.edu/shibboleth/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://webauth.shib.lsu.edu/shibboleth/images/lsulogo.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "200"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.lsu.edu/itpolicy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Louisiana State University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEYTCCA0mgAwIBAgIJAKzhFxTleiexMA0GCSqGSIb3DQEBBQUAMIHGMQswCQYD\nVQQGEwJVUzESMBAGA1UECAwJTG91aXNpYW5hMRQwEgYDVQQHDAtCYXRvbiBSb3Vn\nZTEjMCEGA1UECgwaTG91aXNpYW5hIFN0YXRlIFVuaXZlcnNpdHkxKDAmBgNVBAsM\nH0luZm9ybWF0aW9uIFRlY2hub2xvZ3kgU2VydmljZXMxHTAbBgNVBAMMFHdlYmF1\ndGguc2hpYi5sc3UuZWR1MR8wHQYJKoZIhvcNAQkBFhBzZWN1cml0eUBsc3UuZWR1\nMB4XDTEzMDcwMTE4MzkxM1oXDTMzMDYyNjE4MzkxM1owgcYxCzAJBgNVBAYTAlVT\nMRIwEAYDVQQIDAlMb3Vpc2lhbmExFDASBgNVBAcMC0JhdG9uIFJvdWdlMSMwIQYD\nVQQKDBpMb3Vpc2lhbmEgU3RhdGUgVW5pdmVyc2l0eTEoMCYGA1UECwwfSW5mb3Jt\nYXRpb24gVGVjaG5vbG9neSBTZXJ2aWNlczEdMBsGA1UEAwwUd2ViYXV0aC5zaGli\nLmxzdS5lZHUxHzAdBgkqhkiG9w0BCQEWEHNlY3VyaXR5QGxzdS5lZHUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDP/xaAZ7yLrGIwwJaGBy6iybvV2pfF\nsoOk4fQm/Rza527jYq3kNpuQdAIWzeoJku28qIqrSS3GLf14wdxSNN9rRYd7UhkY\nNzeCxidwjVANbEgM6zsD71Q+c9DM5N9HMQ2a4LZfeKdIs92sBII/3b/4y7jmpiww\nCAMlgH8xP3greb2JkU0Pbi3HA3f+Y3SH/ckNx5gbpeuCdv7rl48Y73Hfx3DVxVQm\ntsvBG0NZIkBRBtyXY2TxYQVPoKKiq3+MhKZna3TfkkExhbuY3a4QGIR0g5Ctk3fJ\nJxdVfoXx0sJJBttPgmdpwa3JNKNaC3AGJL3TbAT9fap099se5iafMtI9AgMBAAGj\nUDBOMB0GA1UdDgQWBBSX6BSJUkoRiDlEBiO4cKLpt7w3FTAfBgNVHSMEGDAWgBSX\n6BSJUkoRiDlEBiO4cKLpt7w3FTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUA\nA4IBAQAhaErPoyFvAiSq91jfbg/UK+YjyJNAW4CLjFJlyMLqAkFJrEZKEfAcbxqr\nrsOZt2fqDaDyDcRvZl82CqSZx8SZ75idjblJLlzY8d2N59QZTubLKRYxNsrxvBkY\np+tcc6zkAkh2QQdC4JPheKICpsxt1xytFHBT32CAfU2kyyzo5/ajjSzfFo8/o5Bf\nWcZP9FLd6yFxgEMSNhWYDcL+HAe4PFH9N98MhugSnQwaybJhdG8J0ig18S+9vSil\nuh8s0yON8U0+JjL/iuXv+hjwOUWvGFjFBaoIwwWpcciNJALoQy9gI7RqFd7QHJIi\nm4gMSZsHCXLYo9JbH1WYKEqJJDdZ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "http://www.lsu.edu/404.shtml"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Louisiana State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lsu.edu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Louisiana State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp2.hig.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 26 648500"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Network Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nat@hig.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University of G\u00e4vle (Alumni)"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 26 648500"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Network Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nat@hig.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University of G\u00e4vle (Alumni)"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 26 648500"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@hig.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University of G\u00e4vle (Alumni)"
          }
        }
      ],
      "entity_id": "https://idp2.hig.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUaqsj1o+jLwRHcAiw/jp5mMglxLUwDQYJKoZIhvcNAQEF\nBQAwFjEUMBIGA1UEAxMLaWRwMi5oaWcuc2UwHhcNMTEwMjA4MTUxOTIyWhcNMzEw\nMjA4MTUxOTIyWjAWMRQwEgYDVQQDEwtpZHAyLmhpZy5zZTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAJ4NMnKvGahwhiZDXxwLfT0oeF/rB72jAVBF9Um9\nExFcSJ/8yb6o0knwpY/uQgFppiUgAvcDKeKN9rBZRq+//jL+8CowII7eOFuR5h+s\nyzAn6YIcPcSx8QBK3lDb+dIwJ7aEnXlgt5tEZneTL0IILXu2zquGRm3rH7YhCHIM\n9v51sjnjd8MXujpG0yIFre3DovnBs4i68ZhoDg7QtvxUz3w/2GTZN+AUB3BA0u12\nFNtJ1n2f/fZwxnJnBCPm2sENAYYKB7/43TJtZazf5ZYA80J9wdQWrdWyve5S+FSZ\nAdLdcdrMZB5c8g6lwPWBRluFjEAbMZMj3AlYpLf2Ybn9yKUCAwEAAaNdMFswOgYD\nVR0RBDMwMYILaWRwMi5oaWcuc2WGImh0dHBzOi8vaWRwMi5oaWcuc2UvaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFCrv7yyvoIy+UhKGYDIB1kTI5T1eMA0GCSqGSIb3\nDQEBBQUAA4IBAQBEXm+ozOM0JC9Fx2QLbYwFbZ5gsBUm2liprjQ1cj65Z+z3w2fs\nhxouOOEyTGuP61J5O29nDDChcWNXMlUyv+HG1nndJ4vsPmhUEYsMNAZwZZ+JoD5g\noEekdgF8avmF0KNfZc+qMOGUz4qrrmMZ6w4F21xba2fFdfSQrubk1F2D/U0ZKw6A\nNYTerCYAEcAVG7c8Eh/5fQXjpf1pZDV1mtPQPnIlF/R6jXgINXDmFOMd0Ei4/C2H\nFC8se9RzTAIwV0P7WorYzwt95Xa9K8DDeLxjheJ3inQR07CD2unOV67Sp5YEfM61\naaB0gTNGMOhF/MSYfiM8SNzVxiYnaE8rwQZK"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hig.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.hig.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.hig.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp2.hig.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.hig.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp2.hig.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2.hig.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.hig.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.hig.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hig.se"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r alumni vid H\u00f6gskolan i G\u00e4vle."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The University of G\u00e4vle Identity Provider is used by alumni at the university."
                  }
                ],
                "logo": [
                  {
                    "text": "https://webkonto.student.hig.se/head/loggaengelska.png",
                    "height": "94",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "83"
                  },
                  {
                    "text": "https://webkonto.student.hig.se/head/logga3.png",
                    "lang": "sv",
                    "height": "94",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "83"
                  },
                  {
                    "text": "https://webkonto.student.hig.se/head/loggaengelska.png",
                    "lang": "en",
                    "height": "94",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "83"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "H\u00f6gskolan i G\u00e4vle (Alumni)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of G\u00e4vle (Alumni)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUaqsj1o+jLwRHcAiw/jp5mMglxLUwDQYJKoZIhvcNAQEF\nBQAwFjEUMBIGA1UEAxMLaWRwMi5oaWcuc2UwHhcNMTEwMjA4MTUxOTIyWhcNMzEw\nMjA4MTUxOTIyWjAWMRQwEgYDVQQDEwtpZHAyLmhpZy5zZTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAJ4NMnKvGahwhiZDXxwLfT0oeF/rB72jAVBF9Um9\nExFcSJ/8yb6o0knwpY/uQgFppiUgAvcDKeKN9rBZRq+//jL+8CowII7eOFuR5h+s\nyzAn6YIcPcSx8QBK3lDb+dIwJ7aEnXlgt5tEZneTL0IILXu2zquGRm3rH7YhCHIM\n9v51sjnjd8MXujpG0yIFre3DovnBs4i68ZhoDg7QtvxUz3w/2GTZN+AUB3BA0u12\nFNtJ1n2f/fZwxnJnBCPm2sENAYYKB7/43TJtZazf5ZYA80J9wdQWrdWyve5S+FSZ\nAdLdcdrMZB5c8g6lwPWBRluFjEAbMZMj3AlYpLf2Ybn9yKUCAwEAAaNdMFswOgYD\nVR0RBDMwMYILaWRwMi5oaWcuc2WGImh0dHBzOi8vaWRwMi5oaWcuc2UvaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFCrv7yyvoIy+UhKGYDIB1kTI5T1eMA0GCSqGSIb3\nDQEBBQUAA4IBAQBEXm+ozOM0JC9Fx2QLbYwFbZ5gsBUm2liprjQ1cj65Z+z3w2fs\nhxouOOEyTGuP61J5O29nDDChcWNXMlUyv+HG1nndJ4vsPmhUEYsMNAZwZZ+JoD5g\noEekdgF8avmF0KNfZc+qMOGUz4qrrmMZ6w4F21xba2fFdfSQrubk1F2D/U0ZKw6A\nNYTerCYAEcAVG7c8Eh/5fQXjpf1pZDV1mtPQPnIlF/R6jXgINXDmFOMd0Ei4/C2H\nFC8se9RzTAIwV0P7WorYzwt95Xa9K8DDeLxjheJ3inQR07CD2unOV67Sp5YEfM61\naaB0gTNGMOhF/MSYfiM8SNzVxiYnaE8rwQZK"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "H\u00f6gskolan i G\u00e4vle (Alumni)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of G\u00e4vle (Alumni)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hig.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HIGALUMNI"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://account-test.unit.liu.se/shibboleth-sp",
    {
      "entity_id": "https://account-test.unit.liu.se/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://account-test.unit.liu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://account-test.unit.liu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://account-test.unit.liu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://account-test.unit.liu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "hydracenter-test"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAIvqrDdZ31ugMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGh5ZHJhY2VudGVyLXRlc3QwHhcNMDkxMDI5MTMyOTU3WhcNMTkxMDI3MTMy\nOTU3WjAbMRkwFwYDVQQDExBoeWRyYWNlbnRlci10ZXN0MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA74C0BefO5DyInVmyDdbhqSegG/CF1xFOfmfrP7+u\neV5kYs9D1j+kK8o1ZCefmB7VK4Gr7GGTDExcD8XJloEes6ijx3jaUc9LE+y11ReC\njNNcpwk9JJ3NadIzIu9o7/On39l0GTDH473xbrI55i3SYmoBQqqFvHGHyJnEEO5K\nhlRssy3SNFBt1jfWqpHDX9ocoAIlUKivIYZwZjg6aGRxvRCZ0gVU8AFLBr4XcwRf\nt5nizTs3/VqmHrD6ICru2phHRN2tc2NgCEkatPs7rshfn5rZTuML08zmMVVgjcR1\n5lzaGE+GkL3BSHj6grIaR43Qom2l/eD2yil9JC4jfI6pLQIDAQABoz4wPDAbBgNV\nHREEFDASghBoeWRyYWNlbnRlci10ZXN0MB0GA1UdDgQWBBS2/zfSiV0VTt5wxprv\nDOiejU8O1TANBgkqhkiG9w0BAQUFAAOCAQEAn86tJFlHPE/zwsRzcYp5Dk6SwpzG\nUYhYt6eAc+8Z6gioJsyM8MD0SfwF5iFdVo88Jm2K55npbgzBj34Uxi4vIItAYpSr\njympe4FMjW6MTOqN6vJtws1U3bn976VvflPr1d4rMoqTxAYue3S/zQ8Y179MvBrr\nF0Bc+PJrsIP4MfYN3b98OAn8kxzGSy1AU6vx/gi+SOQNh3c3kQ0HABhdGBOwmJS3\ne4QPMkOZh0KWHSZZBRc8wDpEwsXHD8q8Ag63Qz0l7DRIQnGkJyQb18ylBbg3fLEW\nfiiVqOsqvroKvOIwKEjtUzxaFg2kDWlXia4AQctOto28G9ftYkXqGxPFgA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=hydracenter-test"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "hydracenter-test"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAIvqrDdZ31ugMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGh5ZHJhY2VudGVyLXRlc3QwHhcNMDkxMDI5MTMyOTU3WhcNMTkxMDI3MTMy\nOTU3WjAbMRkwFwYDVQQDExBoeWRyYWNlbnRlci10ZXN0MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA74C0BefO5DyInVmyDdbhqSegG/CF1xFOfmfrP7+u\neV5kYs9D1j+kK8o1ZCefmB7VK4Gr7GGTDExcD8XJloEes6ijx3jaUc9LE+y11ReC\njNNcpwk9JJ3NadIzIu9o7/On39l0GTDH473xbrI55i3SYmoBQqqFvHGHyJnEEO5K\nhlRssy3SNFBt1jfWqpHDX9ocoAIlUKivIYZwZjg6aGRxvRCZ0gVU8AFLBr4XcwRf\nt5nizTs3/VqmHrD6ICru2phHRN2tc2NgCEkatPs7rshfn5rZTuML08zmMVVgjcR1\n5lzaGE+GkL3BSHj6grIaR43Qom2l/eD2yil9JC4jfI6pLQIDAQABoz4wPDAbBgNV\nHREEFDASghBoeWRyYWNlbnRlci10ZXN0MB0GA1UdDgQWBBS2/zfSiV0VTt5wxprv\nDOiejU8O1TANBgkqhkiG9w0BAQUFAAOCAQEAn86tJFlHPE/zwsRzcYp5Dk6SwpzG\nUYhYt6eAc+8Z6gioJsyM8MD0SfwF5iFdVo88Jm2K55npbgzBj34Uxi4vIItAYpSr\njympe4FMjW6MTOqN6vJtws1U3bn976VvflPr1d4rMoqTxAYue3S/zQ8Y179MvBrr\nF0Bc+PJrsIP4MfYN3b98OAn8kxzGSy1AU6vx/gi+SOQNh3c3kQ0HABhdGBOwmJS3\ne4QPMkOZh0KWHSZZBRc8wDpEwsXHD8q8Ag63Qz0l7DRIQnGkJyQb18ylBbg3fLEW\nfiiVqOsqvroKvOIwKEjtUzxaFg2kDWlXia4AQctOto28G9ftYkXqGxPFgA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=hydracenter-test"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://account-test.unit.liu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://account-test.unit.liu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://account-test.unit.liu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://account-test.unit.liu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://account-test.unit.liu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://account-test.unit.liu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://account-test.unit.liu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://account-test.unit.liu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://account-test.unit.liu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://account-test.unit.liu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://attribute-viewer.aai.switch.ch/interfederation-test/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41 44 268 15 05"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@switch.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAI"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41 44 268 15 05"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@switch.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAI"
          }
        }
      ],
      "entity_id": "https://attribute-viewer.aai.switch.ch/interfederation-test/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2015-11-23T07:39:52Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "friendly_name": "swissEduPersonHomeOrganization",
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "switch.ch"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:2.16.756.1.2.5.1.1.4",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "friendly_name": "swissEduPersonHomeOrganizationType",
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "others"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:2.16.756.1.2.5.1.1.5",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SWITCH"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SWITCH"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SWITCH"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SWITCH"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.switch.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.switch.ch/"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.switch.ch/"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.switch.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "switch.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://attribute-viewer.aai.switch.ch/interfederation-test/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "AAI Viewer Interfederation Test"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service is used to test the interfederation readiness of SWITCHaai Identity Providers."
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://attribute-viewer.aai.switch.ch/interfederation-test/privacy-statement.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDazCCAlOgAwIBAgIJAInsS/34xVwWMA0GCSqGSIb3DQEBBQUAMCkxJzAlBgNV\nBAMTHmF0dHJpYnV0ZS12aWV3ZXIuYWFpLnN3aXRjaC5jaDAeFw0xNDA1MTQxNDQ4\nMzVaFw0xNzA1MTMxNDQ4MzVaMCkxJzAlBgNVBAMTHmF0dHJpYnV0ZS12aWV3ZXIu\nYWFpLnN3aXRjaC5jaDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMYE\nfoYKQreiAh1ULU3g5YxUJeU3HHOk3AfWEKj2fQTA9UpPk2GIlXapEoAnbE4qpOoO\n+LR4HEijEXlOdB8DIFIr+7r/lp0yIqM4rF9PIw+yz+bvUgnjLzAy+38QmQsrW1Zn\nxoJs+2tZ0JQ3HZMlGQsDXfJvhfwl5awgbyyKFq5BCIVI8NYqBsj8dbToh/cKJK5L\n7LyPxcU4nqQEgWBLD4ZOdcbTvjRb4EQuMeZL22iYPKIhk+7kLBO3riPP4QZiI8Kv\nbNeLjwbYXCEJ3GfWdIgIwEireu4f4gP6r1ZSegflyYyi4A4XFm56BF9gdyTsjp2Y\nvYAXlQLTMlJPsanyLdUCAwEAAaOBlTCBkjBxBgNVHREEajBogh5hdHRyaWJ1dGUt\ndmlld2VyLmFhaS5zd2l0Y2guY2iGRmh0dHBzOi8vYXR0cmlidXRlLXZpZXdlci5h\nYWkuc3dpdGNoLmNoL2ludGVyZmVkZXJhdGlvbi10ZXN0L3NoaWJib2xldGgwHQYD\nVR0OBBYEFKtMQ76UJ2imKPdoMOiGDQ7EgSfQMA0GCSqGSIb3DQEBBQUAA4IBAQB6\nlHFWlu87yTXTUpr5DTOcaXgsXqaguQBve9QWj39sylbbdNe7qlhfrkP4J4Y1Ye8G\ncQMM3yvHPOqX2yVIwc9lf/mwyhS3EYKS9A6xlGZBfWVAwIV193Lqyj9JgQAFsZV9\ni0w4/AIfJPTTPNNvBoXyLSGNjiDgddcOPbFpvcXmc2huQgafnpPUpHRvzftSqQct\niJHJIIW6oKr6j3x3iEdvfCgxvjC97Cz2eSxYbaGrO2eBoqWZd46bgtCXE3ODksGX\nDfJWmpOBDWhAdKUZ7CAl9fCH4ztaREeTDK6z0WU3U3T8Q8BBV/jbFeav+tOqMhNH\njCyyjtF4f+udUgUZm2Jt"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://attribute-viewer.aai.switch.ch/interfederation-test/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://attribute-viewer.aai.switch.ch/interfederation-test/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://attribute-viewer.aai.switch.ch/interfederation-test/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://attribute-viewer.aai.switch.ch/interfederation-test/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://attribute-viewer.aai.switch.ch/interfederation-test/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://attribute-viewer.aai.switch.ch/interfederation-test/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "error_url": "http://www.switch.ch/aai/support/help",
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "AAI Viewer Interfederation Test"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This service is used to test the interfederation readiness of SWITCHaai Identity Providers."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "commonName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonUniqueId",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.13",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganizationType",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://tullbommen.arcada.fi/simplesaml/",
    {
      "entity_id": "https://tullbommen.arcada.fi/simplesaml/",
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "true",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://tullbommen.arcada.fi/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://tullbommen.arcada.fi/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "arcada.fi"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Arcada"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Arcada"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Arcada"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "kalmar"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "finland"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "tags",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEozCCA4ugAwIBAgIRAOWRAGRILHyCj7dbQ3yN0xIwDQYJKoZIhvcNAQELBQAw\nZDELMAkGA1UEBhMCTkwxFjAUBgNVBAgTDU5vb3JkLUhvbGxhbmQxEjAQBgNVBAcT\nCUFtc3RlcmRhbTEPMA0GA1UEChMGVEVSRU5BMRgwFgYDVQQDEw9URVJFTkEgU1NM\nIENBIDIwHhcNMTQxMjA0MDAwMDAwWhcNMTcxMjAzMjM1OTU5WjBCMSEwHwYDVQQL\nExhEb21haW4gQ29udHJvbCBWYWxpZGF0ZWQxHTAbBgNVBAMTFHR1bGxib21tZW4u\nYXJjYWRhLmZpMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1Af5oqZO\n2J/9MkGva6UNwDBpkdPf+OZAScaLOp0vXQmz2fnn8tHTZ73Bf4Vwm7252Fx4gGSY\nNU4wRTiTuo3jzaZc7PKA1iJOQVf2Glq5ys2Z7muupuHX3hSKi15065Z0d2wazfRj\nnUgx3TBLkyJ7ZvtjlZ6SVJ1S0wbBY6hnJ1iErJOw8UlrySSOXIq2sEPkSt8nl0Eo\n4P1V6VkGFU2oS3vd/FWmey1NnC3jSdDtoqb+SxFzOZi1+ykmyPv2kjnV4vtFnQ+0\n4WM64xtXFsCFvGMFNSDSGbtcDr83Pq+C8iIseMBWiiKETh4hq/3TG8YM/aDmgpGi\n5dmXSuDh9odZ/wIDAQABo4IBcDCCAWwwHwYDVR0jBBgwFoAUW9CKHJoyW+C13ZZU\nG+GGKLD9tr0wHQYDVR0OBBYEFGMNeN6Z/1YWvIk9Rg+nDVA9+mcWMA4GA1UdDwEB\n/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEF\nBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8E\nMzAxMC+gLaArhilodHRwOi8vY3JsLnVzZXJ0cnVzdC5jb20vVEVSRU5BU1NMQ0Ey\nLmNybDBsBggrBgEFBQcBAQRgMF4wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudXNl\ncnRydXN0LmNvbS9URVJFTkFTU0xDQTIuY3J0MCUGCCsGAQUFBzABhhlodHRwOi8v\nb2NzcC51c2VydHJ1c3QuY29tMB8GA1UdEQQYMBaCFHR1bGxib21tZW4uYXJjYWRh\nLmZpMA0GCSqGSIb3DQEBCwUAA4IBAQAk1YzeOKp7uAkEPFE90ExWsuDGxVR8DAOw\nEt/pp/dWVBqvy7lUWkC+JwIsmNU61+ADZh+CZgmdAzqzAPjE4NReqEa9w2RgphQ8\n4OXKGqxx7xYJHHm5yfz8rLqzz4X+rAqia061WqBmEvx4ePAy3q09oWAEiuqJEcKW\nZ5xWsNghOvCYljMLfST6mSrPA9qIThSzoXHMnB9AxIFEMXz1Gi5in3SVE7czm1ei\n4IatI2LngeztYUnYm41tho/bp8qRKGDcKJ3uksyUbP7o/7QoH+hK+LY2St/tFAJ1\nOJYC37T/7JogZgQ+4XlDpdQhXO22zYLGBBABmMUlbEwgyPv+B8Ts"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Finnberg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:haka.admin@arcada.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Fredrik"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sjoberg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:haka@arcada.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hannelius"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:haka.technical@arcada.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Harald"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Arcada"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Arcada"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Arcada"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.arcada.fi/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.arcada.fi/"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.arcada.fi/"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Arcada"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Arcada"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Arcada"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor"
    }
  ],
  [
    "https://idp.sparsholt.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.sparsholt.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/sparsholt.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/sparsholt.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sparsholt.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Sparsholt College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sparsholt.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dev.play.bth.se",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:saml_admin@kaltura.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dev.play.bth.se",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "BTH (DEV)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://dev.play.bth.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "BTH (DEV)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev.play.bth.se/user/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Blekinge Institute of Technology\u2019s streaming service."
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Blekinge Tekniska H\u00f6gskolas play tj\u00e4nst"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Blekinge Institute of Technology\u2019s Play service"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Blekinge Tekniska H\u00f6gskolas Play tj\u00e4nst"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.play.bth.se/user/authenticate",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://o-las.net/simplesaml",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Zapach"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:marek@essentialskillz.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marek"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Zapach"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:marek@essentialskillz.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marek"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://o-las.net/simplesaml",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-02-15T15:01:20Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "O-LAS"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.essentialskillz.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RiskWize Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://o-las.net/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEjDCCA3SgAwIBAgIJAOlTCyllHsJlMA0GCSqGSIb3DQEBBQUAMIGKMQswCQYD\n\t\t\t\t\t\tVQQGEwJJRTEPMA0GA1UECBMGR2Fsd2F5MQ8wDQYDVQQHEwZHYWx3YXkxGTAXBgNV\n\t\t\t\t\t\tBAoTEFJpc2tXaXplIExpbWl0ZWQxEjAQBgNVBAMTCW8tbGFzLm5ldDEqMCgGCSqG\n\t\t\t\t\t\tSIb3DQEJARYbc3VwcG9ydEBlc3NlbnRpYWxza2lsbHouY29tMB4XDTEzMDIxNTEy\n\t\t\t\t\t\tMTMzOVoXDTIzMDIxMzEyMTMzOVowgYoxCzAJBgNVBAYTAklFMQ8wDQYDVQQIEwZH\n\t\t\t\t\t\tYWx3YXkxDzANBgNVBAcTBkdhbHdheTEZMBcGA1UEChMQUmlza1dpemUgTGltaXRl\n\t\t\t\t\t\tZDESMBAGA1UEAxMJby1sYXMubmV0MSowKAYJKoZIhvcNAQkBFhtzdXBwb3J0QGVz\n\t\t\t\t\t\tc2VudGlhbHNraWxsei5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCzBw8unrlJzrEx1ScoRXbGY38ubsh1jyFdOs1uvgiDNNG+KLc9Pjwre65KTnDY\n\t\t\t\t\t\thyu+EvFdD9AVoYPRttD9zqCeD19I1TIy22idIRriJGcX0SCs3Dq8w2N+FJoyy2p1\n\t\t\t\t\t\tG+47j4CY85Qzf797shUA/eTapnFbuQruS2PiLrx1uSx3HEIXNSYj0HyxUP7Cx8Ru\n\t\t\t\t\t\tMROnYnLtqceX2TzZDbA+1T+rhxIxsiSRG+UJRuHuOqsP0ysaIh9bYunTJRIp5eZB\n\t\t\t\t\t\tUdlxKEn8/vHKO1Q7j3PG7semIP48HLI741F4xHwnb7juU/L5jBc/mDUUuYcJO7PO\n\t\t\t\t\t\tdwJUBre6uvZCTsvQuH1nsVY9AgMBAAGjgfIwge8wHQYDVR0OBBYEFKzwDC8hO6M7\n\t\t\t\t\t\thPFSjiLQNoTwe8l3MIG/BgNVHSMEgbcwgbSAFKzwDC8hO6M7hPFSjiLQNoTwe8l3\n\t\t\t\t\t\toYGQpIGNMIGKMQswCQYDVQQGEwJJRTEPMA0GA1UECBMGR2Fsd2F5MQ8wDQYDVQQH\n\t\t\t\t\t\tEwZHYWx3YXkxGTAXBgNVBAoTEFJpc2tXaXplIExpbWl0ZWQxEjAQBgNVBAMTCW8t\n\t\t\t\t\t\tbGFzLm5ldDEqMCgGCSqGSIb3DQEJARYbc3VwcG9ydEBlc3NlbnRpYWxza2lsbHou\n\t\t\t\t\t\tY29tggkA6VMLKWUewmUwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tPI2idOloyeT1CbmfwW8PYhiV2G/HfA2/y/vwQ4C8XP6fvhbY9g9YmRI3lC7CbJjS\n\t\t\t\t\t\tfVYbyWr4Nxc7ZHrpJAfTN2ZvkF08wKldoB5fY72G50tLekoDobhwoW9LXPS9aqeG\n\t\t\t\t\t\txtl8wKCKoPT+59pMroQtEfdm656QOXGcoERNOzFpa6OwHX8x11TjQ3PiDCGNCpxU\n\t\t\t\t\t\tkaa2zts1SP2Y2bsCzqpD78gA+QvpBnnjljTXqQtl9TVtY/0+5ht4Qh/Jg8VYSYYy\n\t\t\t\t\t\tYbpAsVOhDShM+eAqbrq+C3FwyX8CUJOg98Nx5B9dKaywc5KWhvCjyeEr1sNF9YGk\n\t\t\t\t\t\t3w5WoLhEjWbRMnhM//Ygow=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEjDCCA3SgAwIBAgIJAOlTCyllHsJlMA0GCSqGSIb3DQEBBQUAMIGKMQswCQYD\n\t\t\t\t\t\tVQQGEwJJRTEPMA0GA1UECBMGR2Fsd2F5MQ8wDQYDVQQHEwZHYWx3YXkxGTAXBgNV\n\t\t\t\t\t\tBAoTEFJpc2tXaXplIExpbWl0ZWQxEjAQBgNVBAMTCW8tbGFzLm5ldDEqMCgGCSqG\n\t\t\t\t\t\tSIb3DQEJARYbc3VwcG9ydEBlc3NlbnRpYWxza2lsbHouY29tMB4XDTEzMDIxNTEy\n\t\t\t\t\t\tMTMzOVoXDTIzMDIxMzEyMTMzOVowgYoxCzAJBgNVBAYTAklFMQ8wDQYDVQQIEwZH\n\t\t\t\t\t\tYWx3YXkxDzANBgNVBAcTBkdhbHdheTEZMBcGA1UEChMQUmlza1dpemUgTGltaXRl\n\t\t\t\t\t\tZDESMBAGA1UEAxMJby1sYXMubmV0MSowKAYJKoZIhvcNAQkBFhtzdXBwb3J0QGVz\n\t\t\t\t\t\tc2VudGlhbHNraWxsei5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCzBw8unrlJzrEx1ScoRXbGY38ubsh1jyFdOs1uvgiDNNG+KLc9Pjwre65KTnDY\n\t\t\t\t\t\thyu+EvFdD9AVoYPRttD9zqCeD19I1TIy22idIRriJGcX0SCs3Dq8w2N+FJoyy2p1\n\t\t\t\t\t\tG+47j4CY85Qzf797shUA/eTapnFbuQruS2PiLrx1uSx3HEIXNSYj0HyxUP7Cx8Ru\n\t\t\t\t\t\tMROnYnLtqceX2TzZDbA+1T+rhxIxsiSRG+UJRuHuOqsP0ysaIh9bYunTJRIp5eZB\n\t\t\t\t\t\tUdlxKEn8/vHKO1Q7j3PG7semIP48HLI741F4xHwnb7juU/L5jBc/mDUUuYcJO7PO\n\t\t\t\t\t\tdwJUBre6uvZCTsvQuH1nsVY9AgMBAAGjgfIwge8wHQYDVR0OBBYEFKzwDC8hO6M7\n\t\t\t\t\t\thPFSjiLQNoTwe8l3MIG/BgNVHSMEgbcwgbSAFKzwDC8hO6M7hPFSjiLQNoTwe8l3\n\t\t\t\t\t\toYGQpIGNMIGKMQswCQYDVQQGEwJJRTEPMA0GA1UECBMGR2Fsd2F5MQ8wDQYDVQQH\n\t\t\t\t\t\tEwZHYWx3YXkxGTAXBgNVBAoTEFJpc2tXaXplIExpbWl0ZWQxEjAQBgNVBAMTCW8t\n\t\t\t\t\t\tbGFzLm5ldDEqMCgGCSqGSIb3DQEJARYbc3VwcG9ydEBlc3NlbnRpYWxza2lsbHou\n\t\t\t\t\t\tY29tggkA6VMLKWUewmUwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tPI2idOloyeT1CbmfwW8PYhiV2G/HfA2/y/vwQ4C8XP6fvhbY9g9YmRI3lC7CbJjS\n\t\t\t\t\t\tfVYbyWr4Nxc7ZHrpJAfTN2ZvkF08wKldoB5fY72G50tLekoDobhwoW9LXPS9aqeG\n\t\t\t\t\t\txtl8wKCKoPT+59pMroQtEfdm656QOXGcoERNOzFpa6OwHX8x11TjQ3PiDCGNCpxU\n\t\t\t\t\t\tkaa2zts1SP2Y2bsCzqpD78gA+QvpBnnjljTXqQtl9TVtY/0+5ht4Qh/Jg8VYSYYy\n\t\t\t\t\t\tYbpAsVOhDShM+eAqbrq+C3FwyX8CUJOg98Nx5B9dKaywc5KWhvCjyeEr1sNF9YGk\n\t\t\t\t\t\t3w5WoLhEjWbRMnhM//Ygow=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://o-las.net/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://o-las.net/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://o-las.net/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://o-las.net/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://adfs20.hva.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs20.hva.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-03-25T12:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/03466f0351c4c98ad0e435706253d05f",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hogeschool van Amsterdam"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hogeschool van Amsterdam"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/hva.jpg",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "266"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hogeschool van Amsterdam"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hogeschool van Amsterdam"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hogeschool van Amsterdam"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hogeschool van Amsterdam"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hva.nl/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hva.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hogeschool van Amsterdam"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hogeschool van Amsterdam"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.solihullsfc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.solihullsfc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/solihullsfc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/solihullsfc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "solihullsfc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Sixth Form College, Solihull"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.solihullsfc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.test.semantico.net/shibboleth2",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:test-shibboleth-support@semantico.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:test-shibboleth-support@semantico.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.test.semantico.net/shibboleth2",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVAIyYxXXjcwpmMCFZpfaDBhgqPRVKMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCExHzAdBgNVBAMTFmlkcC50ZXN0LnNlbWFudGljby5uZXQwHhcNMTIxMjE3\n\t\t\t\t\t\tMTIxMzA0WhcNMzIxMjE3MTIxMzA0WjAhMR8wHQYDVQQDExZpZHAudGVzdC5zZW1h\n\t\t\t\t\t\tbnRpY28ubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApqXUhIix\n\t\t\t\t\t\tl94UCWt56LwlvrqQBi2qQhOaEjxRYnbqg9SNBlaeCVNN2vxKqHpgxLKdLMtmCQmJ\n\t\t\t\t\t\tnovNH9qwFfJTzmRPgsLElsJzlObP9fHlh9u21+ZToIuI5ghGXG52Fhf1gdIeN7cH\n\t\t\t\t\t\tPzFN1E4Pb0Dh3DOxnzLMXDimOwmwRKOAWa2E7UgD42vLRPzz4IeFx0w+EPkNmv/C\n\t\t\t\t\t\tbTpTDR0kJGNBxoQVS6KQlU95b9dl+as7swAGIQhU7R7Tn9jVXzJJLdZ84I/dl9ju\n\t\t\t\t\t\tZNpNaki0f9egOEHraJp731AHzgFoVKfS11OXVx2FiM1MTgU7tv7XjhALnZf3tbAr\n\t\t\t\t\t\tYEgIe6ww/hFDLQIDAQABo3MwcTBQBgNVHREESTBHghZpZHAudGVzdC5zZW1hbnRp\n\t\t\t\t\t\tY28ubmV0hi1odHRwczovL2lkcC50ZXN0LnNlbWFudGljby5uZXQvaWRwL3NoaWJi\n\t\t\t\t\t\tb2xldGgwHQYDVR0OBBYEFBtPXbpEivzVVqYPddt3JNbHfq/gMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQB8/Fu1WxCyj/zaqWfJe1fjU/qwyG8YcECR/F6h55EbvlrKFAauD5mA\n\t\t\t\t\t\t1N/ssSvcnC73mtFhgjYkaUf+ztpGAzI8pT7o/h/YSER3My6xfNssJPRtl3lDnByq\n\t\t\t\t\t\tQhoY+/pYb9AE5TOcSFE/tiW8cjf+HEOLj6ggwpwACbgdIZhB6tkPPEYwGLM7iztZ\n\t\t\t\t\t\tRZ5dyGsxLqMUNkAQe31ODYum1CmZSvca3dQ36v3Uh9JPY7NpPKtPajTWa3EOnolD\n\t\t\t\t\t\tVs90fU3mVYcbKg96GRsKinrEORtN8bFhXVTTV385hPcoU+HA7FrAz+EnEWVSTISm\n\t\t\t\t\t\tjZeiXwxR2EOo28vKTTG7Ytp8H4ueb9NI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "semantico.net"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.test.semantico.net:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.test.semantico.net:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.test.semantico.net/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.test.semantico.net/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.test.semantico.net/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.test.semantico.net/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.test.semantico.net:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.test.semantico.net:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "semantico.net"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVAIyYxXXjcwpmMCFZpfaDBhgqPRVKMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCExHzAdBgNVBAMTFmlkcC50ZXN0LnNlbWFudGljby5uZXQwHhcNMTIxMjE3\n\t\t\t\t\t\tMTIxMzA0WhcNMzIxMjE3MTIxMzA0WjAhMR8wHQYDVQQDExZpZHAudGVzdC5zZW1h\n\t\t\t\t\t\tbnRpY28ubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApqXUhIix\n\t\t\t\t\t\tl94UCWt56LwlvrqQBi2qQhOaEjxRYnbqg9SNBlaeCVNN2vxKqHpgxLKdLMtmCQmJ\n\t\t\t\t\t\tnovNH9qwFfJTzmRPgsLElsJzlObP9fHlh9u21+ZToIuI5ghGXG52Fhf1gdIeN7cH\n\t\t\t\t\t\tPzFN1E4Pb0Dh3DOxnzLMXDimOwmwRKOAWa2E7UgD42vLRPzz4IeFx0w+EPkNmv/C\n\t\t\t\t\t\tbTpTDR0kJGNBxoQVS6KQlU95b9dl+as7swAGIQhU7R7Tn9jVXzJJLdZ84I/dl9ju\n\t\t\t\t\t\tZNpNaki0f9egOEHraJp731AHzgFoVKfS11OXVx2FiM1MTgU7tv7XjhALnZf3tbAr\n\t\t\t\t\t\tYEgIe6ww/hFDLQIDAQABo3MwcTBQBgNVHREESTBHghZpZHAudGVzdC5zZW1hbnRp\n\t\t\t\t\t\tY28ubmV0hi1odHRwczovL2lkcC50ZXN0LnNlbWFudGljby5uZXQvaWRwL3NoaWJi\n\t\t\t\t\t\tb2xldGgwHQYDVR0OBBYEFBtPXbpEivzVVqYPddt3JNbHfq/gMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQB8/Fu1WxCyj/zaqWfJe1fjU/qwyG8YcECR/F6h55EbvlrKFAauD5mA\n\t\t\t\t\t\t1N/ssSvcnC73mtFhgjYkaUf+ztpGAzI8pT7o/h/YSER3My6xfNssJPRtl3lDnByq\n\t\t\t\t\t\tQhoY+/pYb9AE5TOcSFE/tiW8cjf+HEOLj6ggwpwACbgdIZhB6tkPPEYwGLM7iztZ\n\t\t\t\t\t\tRZ5dyGsxLqMUNkAQe31ODYum1CmZSvca3dQ36v3Uh9JPY7NpPKtPajTWa3EOnolD\n\t\t\t\t\t\tVs90fU3mVYcbKg96GRsKinrEORtN8bFhXVTTV385hPcoU+HA7FrAz+EnEWVSTISm\n\t\t\t\t\t\tjZeiXwxR2EOo28vKTTG7Ytp8H4ueb9NI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Semantico Federation Test IdP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.semantico.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Semantico Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.pct.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mrae@pct.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike Rae"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "robert.belles@pct.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert Belles"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mrae@pct.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike Rae"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.pct.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.pct.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.pct.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.pct.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.pct.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.pct.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pct.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://idp.pct.edu/idp/images/pctlogo-mobile.png",
                    "lang": "en",
                    "height": "69",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Pennsylvania College of Technology"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAPXmOxKE87b9Gpy8v4ZkBQZyM5s7MA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2lkcC5wY3QuZWR1MB4XDTEzMTExMzE0NDAxNFoXDTMz\nMTExMzE0NDAxNFowFjEUMBIGA1UEAxMLaWRwLnBjdC5lZHUwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCN2mGb9Z9WEqbuUCnqfcBuI/GnafhX4G6X0/VR\nkL/LqeE8w8yI9le8K9XzSgX03x6gxwYgWQD1AjazDEj22TblQPWhMtSCGnc7NOwp\n1Rqdnjx/126lOZuBJgNrn8MNQicSGTHDERAVSDkRI35MZLgY9IP0RlQwZ3/qUNN8\nAMjt4SNdYsMCpxu7tJ544F5gogiQqXQMGJGd28j0g74XPjAvbL5uCJZXp4boYcsz\nIRV8tmzZS9VVEsjW/X6Uu7O9zuyLvsQw3CzgVF9bD2W0DI10MtyZFA7GAp1BvdZX\nnkHofviJ/nJ8EgY+t+ptpSSV+cBAOCq10EAvq77g+McjUWR1AgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2lkcC5wY3QuZWR1hiJodHRwczovL2lkcC5wY3QuZWR1L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBQpWKgSLUBAg5gMotsUjTSITgXm+jANBgkqhkiG\n9w0BAQUFAAOCAQEAHy/IIAzOMJDen3jlxWATz3MnlouOdlHQRu2nFWnyOjSRzHY1\n+yQjs557VN+gauVq3rh0Vsh/R3D/YhSHnsYmdw34TLPzF1NTb4/I96wxo84ls6Om\nMvJ43Hya/8HEsBfkcNIozAABsdmMBC3I6JOpdQekRO/oiaBQx9ckmpmf2VAvZ7hn\npKpuJzdJRb15tTfBN9wL2vlohxJs9So5LyX/u3iTxe0f2HilfWP7prEwvvp5665W\nXZjl65JBgM51Vdxba40Gv6eyRaCM5SvD+3CD7CdAM/tBrFxYiLawxq0qJWr5G/DT\nYwq4xGOo7ofdpFvfetqvGHrsBuQv2gyG/y7Aew=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Pennsylvania College of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.pct.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Pennsylvania College of Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.es.net/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dhiva@es.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dhiva Muruganantham"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "trouble@es.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ESnet Operations"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.es.net/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.es.net/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.es.net/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.es.net/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.es.net/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.es.net/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "es.net"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Energy Sciences Network"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.es.net/assets/Logos/ESnetFinalRGB.jpg",
                    "lang": "en",
                    "height": "22",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "72"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ESnet"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAO4b4WF67Uq3LsXyIhUEBd7dB/JoMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC5lcy5uZXQwHhcNMTExMjEzMjMwNTM4WhcNMzEx\nMjEzMjMwNTM4WjAVMRMwEQYDVQQDEwppZHAuZXMubmV0MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAi2esIvvexX85muTD8yzJF9InJ8NwysxfxyWDDLco\n1G4ypEPN6121TbKotdF83keigjRsK/+jsq1VyMJeUW6kXlZ9N6Xzet8Zt/uxBamB\nQ2iipdNwDJtLty3zEtGbsQywYkZSfBm7Dse2cB8+GZTBeJUXN3BGetKFUX/IM7RE\n3y5j0c/Oem+Gd7HvZLVSNsy4CvBnPhs3w2mhJkh4FFbOdPMnQSP2/hQt0hAVfhzr\nbA8IKI2dv/f5nlOJd/6X1uM2IfgSG3M1dp+AIcD4Frdl65T9eyTKHBIxh8Sng1Lf\nlf6C4yiFq4KvKOYB0byGGEo4SGQKsXnxWPzw9te02K5xuwIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAuZXMubmV0hiFodHRwczovL2lkcC5lcy5uZXQvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFKWAyXCw7X2OjsdUocqtpHTLbasKMA0GCSqGSIb3DQEB\nBQUAA4IBAQBPsEx37NAmxr6zUpMCu7SKdVaf8r9ppieqQxbHBVVxVsQ5IX7IY1AB\nqcUzMVY0m5Hnp4GbU0xkuiRqUNrlsp+n52MosJwPiWkO0m9ljN0Dn8kkRExJq/bS\nd6W45OX283biF1VpolxwQKvNNJdIliLexfiFnwxTGMT5OzQzQ8qX/Jr31DmT5y91\nlVH5KPTu0rxTbbtx75SaPJ9FXmiHFe25kZd+hyZs/XB8ExN58jukXygMUOUgIuRP\nsb1TR90+G0WLUJlIxr1SeRpeHFUWcHkEmss3FIwgJrRVwfSQxwQgTRFRELJInRQI\nnciX8msJNoIgdL+nElSBTZ1kUT569c8d"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idp.es.net/idp/error.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ESnet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.es.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ESnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.ltscotland.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wilson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:graham.wilson@educationscotland.gov.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Graham"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wilson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:graham.wilson@educationscotland.gov.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Graham"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.ltscotland.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2012-05-28T13:32:50Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Education Scotland"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.educationscotland.gov.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Education Scotland"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.educationscotland.gov.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.educationscotland.gov.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.educationscotland.gov.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.educationscotland.gov.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.educationscotland.gov.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.educationscotland.gov.uk/Shibboleth.sso/WAYF/Glow",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEjCCAfqgAwIBAgIJAMFVcb/xT28pMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\n\t\t\t\t\t\tBAMTGWx0c2Utd2ViMDEubHRzY290bGFuZC5jb20wHhcNMTAwNDA2MTEwODMzWhcN\n\t\t\t\t\t\tMjAwNDAzMTEwODMzWjAkMSIwIAYDVQQDExlsdHNlLXdlYjAxLmx0c2NvdGxhbmQu\n\t\t\t\t\t\tY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0cNyCYPET1vjazeG\n\t\t\t\t\t\toTDedpNCEKqceFny1kyLJRwdu8D76/4Y/U9G0lLcWo25xFwnu8bBYP0Wx1ARelQH\n\t\t\t\t\t\tVnZK8iiauUMKeu1N6Pq/4zRXUQzI5+SCEKfGGh4IqV4W1eid0WET30PdziNo8s5q\n\t\t\t\t\t\t0A6kp4FIKYD5EKZwVALe57/b2tAFFyf37jxZTZxvrLWJDUdC4lwK32hbormk3Pi9\n\t\t\t\t\t\tqKwOUlxYgkKcwxVWbUGHWpUI1DWfpvqsRObQTCXbPfbtBWtdrRRwIlHQjY+Ns0Hk\n\t\t\t\t\t\tAu8xKXLEFllu1t0XCJ7fTimJ0XwiqGh7sLcQnc2W63hZOkKHgESjVHEIUjH1pZaZ\n\t\t\t\t\t\tVLEbIQIDAQABo0cwRTAkBgNVHREEHTAbghlsdHNlLXdlYjAxLmx0c2NvdGxhbmQu\n\t\t\t\t\t\tY29tMB0GA1UdDgQWBBQs0eoj0gCKFhGV81jjIuGRu7jYRjANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAfIQzlxcJDwFgeghBOThTNYlWWrTg9sBGX2ScJrTdpZ2YCBVCiqJzvHbs\n\t\t\t\t\t\tCVVm/wxXg6RszMl6jZJUMCZo+uCFRjP/VVaZYdHxGOYwz2U68gUeO41dlF7MlC++\n\t\t\t\t\t\t/dIuKK+XXRyrM49hwdDZS14mQTkor6Kt8zpabLtn6FCpr8tDEtXuFn28PiyWyxq3\n\t\t\t\t\t\tJimO/CV4gydrnNg2iGkZHHP46dkIvi0mIqMVv8OTwqgSdpe1i/HldGZ5IWGdouIZ\n\t\t\t\t\t\tYJH+7toasSbjwqMusDEt0GMuMM0QqM8SFsTaAp7rBjnepE2gYVTK+RGloI+CCVoD\n\t\t\t\t\t\t2XXgRAd0fVakFAhtv93JvF7VW3e5TA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.educationscotland.gov.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.educationscotland.gov.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.educationscotland.gov.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.educationscotland.gov.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.educationscotland.gov.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.educationscotland.gov.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.educationscotland.gov.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.educationscotland.gov.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.educationscotland.gov.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.educationscotland.gov.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ulapland.fi/idp/shibboleth",
    {
      "entity_id": "https://idp.ulapland.fi/idp/shibboleth",
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "true",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ulapland.fi/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ulapland.fi"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Lapland"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lapplands universitet"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lapin yliopisto"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "kalmar"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "finland"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "tags",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGMzCCBRugAwIBAgIQDlN1F2qvSlzflb1TYXqosTANBgkqhkiG9w0BAQsFADBk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\nXEWPAbsxwQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hangasluoma"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:arto.hangasluoma@ulapland.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Arto"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Matasaho"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:esa.matasaho@ulapland.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Esa"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hangasluoma"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:arto.hangasluoma@ulapland.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Arto"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kupari"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:iikka.kupari@ulapland.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Iikka"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lapin yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Lapland"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lapplands universitet"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ulapland.fi"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ulapland.fi"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ulapland.fi"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Lapin yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Lapland"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Lapplands universitet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor"
    }
  ],
  [
    "https://idp.princeton.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "steven@princeton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven Niedzwiecki"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sdp@princeton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Security and Data Protection"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.princeton.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.princeton.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.princeton.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUMfmaP7flCY4+d5Gnju4bntgM57wwDQYJKoZIhvcNAQEF\nBQAwHDEaMBgGA1UEAxMRaWRwLnByaW5jZXRvbi5lZHUwHhcNMDkxMDMwMTI1MTM5\nWhcNMjkxMDMwMTI1MTM5WjAcMRowGAYDVQQDExFpZHAucHJpbmNldG9uLmVkdTCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJE0moHwKJGyg9z94dvN0HCB\nklHGPvRdIB0nvzAJxo9KaF81zFaqHpvprwNEoB3Pfy18hIbtnDSv/sV/j6pnKnBw\nXXsf7QJOOF81klkGHZh4C9VnjUL5ok9Ahx1zPgaLcCgvZeGRG7DiRPnOgxVzuwoB\nWFnEWBCoLaqcZUl2njnawRB+LXt8mO+HPhsMO8c7ASJ50hF/l9cGaCs3ucEcwp9d\nFoxSiVy2TMyatszHTHZknaqVyqR+WNCxE/Jpcwfi1oq6k3V5T372GE8WTKclgvpg\nIYV8ISROBHpVlYz9v3N0nnpOn+Io6zuUOS3YNmuX52vaSciaYNoPcmBxYMEG2jcC\nAwEAAaNpMGcwRgYDVR0RBD8wPYIRaWRwLnByaW5jZXRvbi5lZHWGKGh0dHBzOi8v\naWRwLnByaW5jZXRvbi5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFPQsLxgr\nW14zmCfogqfOscaIPOtoMA0GCSqGSIb3DQEBBQUAA4IBAQAqkhYwrjjwi31OYkDK\njeKyss835BrdLVTqqEfssT3lvYW/SGyRMLCr2hS21p9zbt8dJO67C9RYEjJ/05p2\nKeo+ZQj3ehOP80/phxk0r+Je/fNdpO/HbQG9/DfcYp5sLUXk9koYrXrOHq6KnkVh\nrmikDRb9izfU9nDttB8hWGLiX0WhIvk9xkIAW5ueyL5QxcQmRYNcaT3BUpjkGiBu\nFEsLXa42F1nmdBDGrI2woHNEr2diujL5EOxqIsunquUXuu2dFuNtqA0HRK6wj32b\nfsZT9KwTEdLv/oAbgQ8zlVXErx54GJFg1ksGAJY3lsGY+XdvcUaKuVD2IWOrbCtP\nqZfT"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "princeton.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.princeton.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.princeton.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.princeton.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.princeton.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.princeton.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "princeton.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Princeton University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUMfmaP7flCY4+d5Gnju4bntgM57wwDQYJKoZIhvcNAQEF\nBQAwHDEaMBgGA1UEAxMRaWRwLnByaW5jZXRvbi5lZHUwHhcNMDkxMDMwMTI1MTM5\nWhcNMjkxMDMwMTI1MTM5WjAcMRowGAYDVQQDExFpZHAucHJpbmNldG9uLmVkdTCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJE0moHwKJGyg9z94dvN0HCB\nklHGPvRdIB0nvzAJxo9KaF81zFaqHpvprwNEoB3Pfy18hIbtnDSv/sV/j6pnKnBw\nXXsf7QJOOF81klkGHZh4C9VnjUL5ok9Ahx1zPgaLcCgvZeGRG7DiRPnOgxVzuwoB\nWFnEWBCoLaqcZUl2njnawRB+LXt8mO+HPhsMO8c7ASJ50hF/l9cGaCs3ucEcwp9d\nFoxSiVy2TMyatszHTHZknaqVyqR+WNCxE/Jpcwfi1oq6k3V5T372GE8WTKclgvpg\nIYV8ISROBHpVlYz9v3N0nnpOn+Io6zuUOS3YNmuX52vaSciaYNoPcmBxYMEG2jcC\nAwEAAaNpMGcwRgYDVR0RBD8wPYIRaWRwLnByaW5jZXRvbi5lZHWGKGh0dHBzOi8v\naWRwLnByaW5jZXRvbi5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFPQsLxgr\nW14zmCfogqfOscaIPOtoMA0GCSqGSIb3DQEBBQUAA4IBAQAqkhYwrjjwi31OYkDK\njeKyss835BrdLVTqqEfssT3lvYW/SGyRMLCr2hS21p9zbt8dJO67C9RYEjJ/05p2\nKeo+ZQj3ehOP80/phxk0r+Je/fNdpO/HbQG9/DfcYp5sLUXk9koYrXrOHq6KnkVh\nrmikDRb9izfU9nDttB8hWGLiX0WhIvk9xkIAW5ueyL5QxcQmRYNcaT3BUpjkGiBu\nFEsLXa42F1nmdBDGrI2woHNEr2diujL5EOxqIsunquUXuu2dFuNtqA0HRK6wj32b\nfsZT9KwTEdLv/oAbgQ8zlVXErx54GJFg1ksGAJY3lsGY+XdvcUaKuVD2IWOrbCtP\nqZfT"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Princeton University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.princeton.edu/index.shtml"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Princeton University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.kirkleescollege.ac.uk/entity",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lim"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:slim@kirkleescollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sam"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lim"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:slim@kirkleescollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sam"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.kirkleescollege.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-09-19T15:38:46.844016Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp3.kirkleescollege.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp3.kirkleescollege.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp3.kirkleescollege.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp3.kirkleescollege.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp3.kirkleescollege.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp3.kirkleescollege.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kirkleescollege.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://www.kirkleescollege.ac.uk/wp-content/uploads/2015/06/kcLogo.png",
                    "height": "67",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "137"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kirklees College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUPzSZlLFegyJ/xf53eryEDjcKM9EwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwJTEjMCEGA1UEAwwaaWRwMy5raXJrbGVlc2NvbGxlZ2UuYWMudWswHhcNMTYw\n\t\t\t\t\t\tMzAzMTAxODQ3WhcNMzYwMzAzMTAxODQ3WjAlMSMwIQYDVQQDDBppZHAzLmtpcmts\n\t\t\t\t\t\tZWVzY29sbGVnZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAKFBdTJWYZwbKzqpd8kbX4j1SX+EN2WBSYWvgYJLQFFkwMcxKjPzEJUPoR3aMu5T\n\t\t\t\t\t\toTEm+oTERSALbbddvE7pnXSqYOWK446LwsyeFLKF8h7xYreM85yPmorsFAaaTUuI\n\t\t\t\t\t\twvx59BHDuSkiVZwwsm3+WB14Ahcg429whwNY9apF1udu5xE6BMF7I+QtUNJCDhz1\n\t\t\t\t\t\tvgVS41JfkQiwbNPZlvfe8S14s3bWOIwp9l+G2f8cRNH5Uf5y9ZuX2tB8eDAZ6cDT\n\t\t\t\t\t\tID6udXsErJSCbosX4uykvlnD6Djr+7TQNwJqVZFRNbWki/sl41GYuqvlM/A/u04H\n\t\t\t\t\t\tn2MCvHwjUQTtBrTpIZZXxpUCAwEAAaN7MHkwHQYDVR0OBBYEFLpm52vzFVDyJS4o\n\t\t\t\t\t\thPpCfXJG6n0jMFgGA1UdEQRRME+CGmlkcDMua2lya2xlZXNjb2xsZWdlLmFjLnVr\n\t\t\t\t\t\thjFodHRwczovL2lkcDMua2lya2xlZXNjb2xsZWdlLmFjLnVrL2lkcC9zaGliYm9s\n\t\t\t\t\t\tZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQBREprxYckkBIaZYmAYDei1C2pe23kl9exH\n\t\t\t\t\t\t4aWKmPNARm7o4Cy7dd3j3uwC8St+4qEKCpFQXy2Dat/WcXoXNYUqARRvF5yPNyo7\n\t\t\t\t\t\tzyIajiKzdHTKfb6fUAfStmRQ2f7iWVCB25A/e1vo3AnoJ3S0X7YBo8k6uR7Vh4Tv\n\t\t\t\t\t\tezlyLCERRgKTuhxVI2eZ6/pO7Nxfk+m6VznnRQY/uyOUdq5hYT8kR7IC8QEJN0uM\n\t\t\t\t\t\tJBwwLSL7JuEb/lyeuxXMQ0Uadl2f68HdgycsUKbGCRdskzL49x1MNcyqrT9e+FFM\n\t\t\t\t\t\tdgIVva94fIIj02YnTFHvjX1CIoHAh/0Tg/xMHLUeJyrCLp9i8iJG"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUd97fOFDggCwIB+n7K8vwH2yP6mUwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwJTEjMCEGA1UEAwwaaWRwMy5raXJrbGVlc2NvbGxlZ2UuYWMudWswHhcNMTYw\n\t\t\t\t\t\tMzAzMTAxODQ2WhcNMzYwMzAzMTAxODQ2WjAlMSMwIQYDVQQDDBppZHAzLmtpcmts\n\t\t\t\t\t\tZWVzY29sbGVnZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAOD7ENmi+diQEZsfujuo48nhfyIImo63I1dxn8DcDkMAwQu5Bp01bOIoB6fvJd6+\n\t\t\t\t\t\tyxUI5Ny7cH6BIkfoGC/4kc+9YaTmjdQ2Lqz5FFB6sZNx/zTK6ovTS0M855KFbTjx\n\t\t\t\t\t\tiaomSW/ZA4khQWLDpNf7kSbqRNYprwvB84ySF5IDhhy1j6uMsTTBzfWVswbq7ioo\n\t\t\t\t\t\tAxWHH/F1URF8Ke2zyJPZcVmESj6hb0kaJ65neFkdKdk1tePySVT1iiqTZXW+nbR1\n\t\t\t\t\t\tq+2JbC8CG0uzKn6uqcnBwsjMw/tHqnzL4yoXyHsg1bzNpN+Fhjvqxiqre+0VN01D\n\t\t\t\t\t\tqCZVnIGvcPPI1JQXtGBUgRECAwEAAaN7MHkwHQYDVR0OBBYEFHR4kkaJLgI7EJAa\n\t\t\t\t\t\tm+vQbnIupiAyMFgGA1UdEQRRME+CGmlkcDMua2lya2xlZXNjb2xsZWdlLmFjLnVr\n\t\t\t\t\t\thjFodHRwczovL2lkcDMua2lya2xlZXNjb2xsZWdlLmFjLnVrL2lkcC9zaGliYm9s\n\t\t\t\t\t\tZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQC6blnSTG9YG9r1kyqXwX46qtU/R3GDzZNQ\n\t\t\t\t\t\tpHSMzTZ5u5B6t3/UM9bIPlHtPS6hilFY5Hmr+VsPA0y0xAX6C35UiNAEk8U6LD4O\n\t\t\t\t\t\tAWvkqBQEMsoANTZa2g2hbpyEBdF2eTJZcxrSbDfrQ6zFRavwb1yeuFpp61CJEKNB\n\t\t\t\t\t\t002kcyWHo6I4ywgwvKjy0XeUjHakskUSkHz1/Vk/jCjOP7+BX5kptY0gbh/NLzri\n\t\t\t\t\t\tuLubDQXxFYEriQdqBU7xzKtZO8Uvh4bHSgbh2PlsHwNrn3Pz1j7HJUUinQjx11F1\n\t\t\t\t\t\tuXzeRs4SkLVanB/ZfQiRhdtDaRsNRrXMBWDLn/zeJiTcyusUtHtf"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIVAKB3QrzbWC6UDhYtgWKIpucJuo+aMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMCUxIzAhBgNVBAMMGmlkcDMua2lya2xlZXNjb2xsZWdlLmFjLnVrMB4XDTE2\n\t\t\t\t\t\tMDMwMzEwMTg0N1oXDTM2MDMwMzEwMTg0N1owJTEjMCEGA1UEAwwaaWRwMy5raXJr\n\t\t\t\t\t\tbGVlc2NvbGxlZ2UuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCBPFW/kyCkFVmfkrRrJYeZbtZZ+idr82BMiORf3wNIFRVe0Dzcgm3G9zdiI/tv\n\t\t\t\t\t\tY32ipWUS2msYQXXJ8CGU2GcgNjSCUUffGc/Mi5UbKXZsOZWshBavumBHELDahOKc\n\t\t\t\t\t\tF1V8msTgiKTdckuvkwjyLAokVDGWeZ1HBlDF1EBeKxPxDTnIeknlE4suuFPLHKkQ\n\t\t\t\t\t\tkCup+ncBh8ZODGInHHb57xonZKxubqZPRk6K3za6K6eW4uu7R6cigZDUmoNMi/QN\n\t\t\t\t\t\tSrFvyXG+5e+8OA6MbttCNreVto2AAm0cb7OWtLmYYCz95G4UtFRRzScFJWePbnGu\n\t\t\t\t\t\tKzYL080NVr+ugb/+ttkfbNG1AgMBAAGjezB5MB0GA1UdDgQWBBSJF8N8bCvvPNCu\n\t\t\t\t\t\tfB3kL4jFg8jIrDBYBgNVHREEUTBPghppZHAzLmtpcmtsZWVzY29sbGVnZS5hYy51\n\t\t\t\t\t\ta4YxaHR0cHM6Ly9pZHAzLmtpcmtsZWVzY29sbGVnZS5hYy51ay9pZHAvc2hpYmJv\n\t\t\t\t\t\tbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAAqmGm2DuWPXogXtQzwMy/eymOtwG1mKG\n\t\t\t\t\t\tFUBGI6RKzFBhv0IC0qnwzsJ931x/Y79e9usKreMxaWJinOm8IcKDUzyHBrtosmbi\n\t\t\t\t\t\tT+b3BxArTXDAWnKuel4OVuVUJnndfBcWvxJrGmj3ueb/S2EsbkmnwXMXawXFATV8\n\t\t\t\t\t\tIAdC/EErq8wNXbbRlkbeX+ibMsgHDMofY/WL0QmC+1kJO8KGoNPOje4aDYzvkCcs\n\t\t\t\t\t\tf/H76DoF7VcK7V5hujvHlb0P51EAA15gDfywo8GT3S8M5OrSYmFoL8p0/NrQ16lB\n\t\t\t\t\t\thRIYrS+7nU8Dmaso2COWvd0q91Gb0tAQx+Qamj5LcT+mdcQ636jf0g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Kirklees College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kirkleescollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Kirklees College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://scalear-saml.herokuapp.com",
    {
      "entity_id": "https://scalear-saml.herokuapp.com",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Scalable Learning"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "www.scalable-learning.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Scalable Learning"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.scalable-learning.com/home/about"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Scalable Learning"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Blended learning platform for interactive in-class and online education."
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Plattform f\u00f6r st\u00f6d av \"flipped classroom\" utbildning."
                  }
                ],
                "logo": [
                  {
                    "text": "https://scalear-saml.herokuapp.com/assets/logo-a66e557f3f93b4d5195033ba1a1527a3.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.scalable-learning.com/home/privacy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://scalear-saml.herokuapp.com/saml/consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://oa.pep-web.org/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pilkington"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:r.pilkington@ucl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rhiannon"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Shapiro"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:neil@scilab-inc.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Neil"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://oa.pep-web.org/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-03-18T14:56:21Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PEP Web"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.p-e-p.org/about.htm"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Psychoanalytic Electronic Publishing"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0DCCArigAwIBAgIJAKHVd8LSwH+3MA0GCSqGSIb3DQEBBQUAME4xMzAxBgNV\n\t\t\t\t\t\tBAoTKlBzeWNob2FuYWx5dGljIEVsZWN0cm9uaWMgUHVibGlzaGluZywgSW5jLjEX\n\t\t\t\t\t\tMBUGA1UEAxMOb2EucGVwLXdlYi5vcmcwHhcNMTIxMjEwMTUwNjI5WhcNMjIxMjA4\n\t\t\t\t\t\tMTUwNjI5WjBOMTMwMQYDVQQKEypQc3ljaG9hbmFseXRpYyBFbGVjdHJvbmljIFB1\n\t\t\t\t\t\tYmxpc2hpbmcsIEluYy4xFzAVBgNVBAMTDm9hLnBlcC13ZWIub3JnMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvxjOhHh3BRMA7mPHoLC5a5JrtjuFihOA\n\t\t\t\t\t\t5419SfkRPVg6l5WaH6J2KSbRsMp27NEk7AAwGfwsqMh2FYgmrelQQ3e69++VPnUe\n\t\t\t\t\t\tvD+/hyo5d97KueVlktu7T7qxewBJr31k6l//SZgKWhOvN8hvMGMtul2SUtob8x1w\n\t\t\t\t\t\twTv5bh6OCXE7AzJj7VXWLAVrzChuXo1r3xxC1GLi/NpCQLYwCsUVIfHByw2+omEF\n\t\t\t\t\t\tnA6wLRxTezFdKnGmrl0Zutw/acf19nCZZLD6N84Qorko3sON8qwm1+cnuJyyKeW1\n\t\t\t\t\t\tMtKbZuULd7MnePyCbH771qy33WZeOsRFi3QDrYJAfFpqAKFwM9W7MwIDAQABo4Gw\n\t\t\t\t\t\tMIGtMB0GA1UdDgQWBBStEHOsouCRTUqh8vj2LJ+XIL9R3TB+BgNVHSMEdzB1gBSt\n\t\t\t\t\t\tEHOsouCRTUqh8vj2LJ+XIL9R3aFSpFAwTjEzMDEGA1UEChMqUHN5Y2hvYW5hbHl0\n\t\t\t\t\t\taWMgRWxlY3Ryb25pYyBQdWJsaXNoaW5nLCBJbmMuMRcwFQYDVQQDEw5vYS5wZXAt\n\t\t\t\t\t\td2ViLm9yZ4IJAKHVd8LSwH+3MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAEaj7/jzs4v2do/oClsw9dhcIDbFLFQW2AIxM7Fkfk2BaDN1mxQGFNE1sMk+\n\t\t\t\t\t\tbi0B1Xqge7EZOEumtjpWDmJrxkZnIO0cyUDUAloo1vBnm4EcUlcJWptXbqh+Esgm\n\t\t\t\t\t\tXNg7/3xZYmafTSCLqI/JPkgWAoBtQNtmJLjmFLr9ypn4D90HD6jH0pf5MEQbEIG0\n\t\t\t\t\t\t3GPCgUTHBYi3HLtxWAZFhJU4hqNAik7h9/Ja4ekHPBymeb17XD9sR876/l1ofgUo\n\t\t\t\t\t\tfanT1syz+jLydfNwAmqKcs/VNut1JcwYN70lwRGAcjBZHRj6rIzKOMuv9btlx+OB\n\t\t\t\t\t\tsRYctPwxod3YO1J6Qb4Pac00EJE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0DCCArigAwIBAgIJAKHVd8LSwH+3MA0GCSqGSIb3DQEBBQUAME4xMzAxBgNV\n\t\t\t\t\t\tBAoTKlBzeWNob2FuYWx5dGljIEVsZWN0cm9uaWMgUHVibGlzaGluZywgSW5jLjEX\n\t\t\t\t\t\tMBUGA1UEAxMOb2EucGVwLXdlYi5vcmcwHhcNMTIxMjEwMTUwNjI5WhcNMjIxMjA4\n\t\t\t\t\t\tMTUwNjI5WjBOMTMwMQYDVQQKEypQc3ljaG9hbmFseXRpYyBFbGVjdHJvbmljIFB1\n\t\t\t\t\t\tYmxpc2hpbmcsIEluYy4xFzAVBgNVBAMTDm9hLnBlcC13ZWIub3JnMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvxjOhHh3BRMA7mPHoLC5a5JrtjuFihOA\n\t\t\t\t\t\t5419SfkRPVg6l5WaH6J2KSbRsMp27NEk7AAwGfwsqMh2FYgmrelQQ3e69++VPnUe\n\t\t\t\t\t\tvD+/hyo5d97KueVlktu7T7qxewBJr31k6l//SZgKWhOvN8hvMGMtul2SUtob8x1w\n\t\t\t\t\t\twTv5bh6OCXE7AzJj7VXWLAVrzChuXo1r3xxC1GLi/NpCQLYwCsUVIfHByw2+omEF\n\t\t\t\t\t\tnA6wLRxTezFdKnGmrl0Zutw/acf19nCZZLD6N84Qorko3sON8qwm1+cnuJyyKeW1\n\t\t\t\t\t\tMtKbZuULd7MnePyCbH771qy33WZeOsRFi3QDrYJAfFpqAKFwM9W7MwIDAQABo4Gw\n\t\t\t\t\t\tMIGtMB0GA1UdDgQWBBStEHOsouCRTUqh8vj2LJ+XIL9R3TB+BgNVHSMEdzB1gBSt\n\t\t\t\t\t\tEHOsouCRTUqh8vj2LJ+XIL9R3aFSpFAwTjEzMDEGA1UEChMqUHN5Y2hvYW5hbHl0\n\t\t\t\t\t\taWMgRWxlY3Ryb25pYyBQdWJsaXNoaW5nLCBJbmMuMRcwFQYDVQQDEw5vYS5wZXAt\n\t\t\t\t\t\td2ViLm9yZ4IJAKHVd8LSwH+3MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAEaj7/jzs4v2do/oClsw9dhcIDbFLFQW2AIxM7Fkfk2BaDN1mxQGFNE1sMk+\n\t\t\t\t\t\tbi0B1Xqge7EZOEumtjpWDmJrxkZnIO0cyUDUAloo1vBnm4EcUlcJWptXbqh+Esgm\n\t\t\t\t\t\tXNg7/3xZYmafTSCLqI/JPkgWAoBtQNtmJLjmFLr9ypn4D90HD6jH0pf5MEQbEIG0\n\t\t\t\t\t\t3GPCgUTHBYi3HLtxWAZFhJU4hqNAik7h9/Ja4ekHPBymeb17XD9sR876/l1ofgUo\n\t\t\t\t\t\tfanT1syz+jLydfNwAmqKcs/VNut1JcwYN70lwRGAcjBZHRj6rIzKOMuv9btlx+OB\n\t\t\t\t\t\tsRYctPwxod3YO1J6Qb4Pac00EJE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "want_assertions_signed": "false",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://oa.pep-web.org/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://oa.pep-web.org/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://oa.pep-web.org/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://oa.pep-web.org/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://dev.overtsoftware.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Beddows"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ed"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Beddows"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ed"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dev.overtsoftware.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2012-10-26T10:51:43Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Overt Software Solutions Ltd test SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.overtsoftware.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Overt Software Solutions Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.overtsoftware.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev.overtsoftware.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.overtsoftware.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.overtsoftware.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.overtsoftware.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.overtsoftware.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dev.overtsoftware.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Overt Software Solutions Ltd test SP"
                  }
                ],
                "logo": [
                  {
                    "text": "https://dev.overtsoftware.com/overt-logo-ukfed.png",
                    "height": "169",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Overt Software Solutions Ltd test SP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDiDCCAnACCQDQGWbiDKuX9zANBgkqhkiG9w0BAQUFADCBhTELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFzAVBgNVBAgMDldvcmNlc3RlcnNoaXJlMRYwFAYDVQQHDA1LaWRkZXJtaW5z\n\t\t\t\t\t\tdGVyMSUwIwYDVQQKDBxPdmVydCBTb2Z0d2FyZSBTb2x1dGlvbnMgTHRkMR4wHAYD\n\t\t\t\t\t\tVQQDDBVkZXYub3ZlcnRzb2Z0d2FyZS5jb20wHhcNMTIxMDI2MDk0MzQ4WhcNMzIx\n\t\t\t\t\t\tMDIxMDk0MzQ4WjCBhTELMAkGA1UEBhMCR0IxFzAVBgNVBAgMDldvcmNlc3RlcnNo\n\t\t\t\t\t\taXJlMRYwFAYDVQQHDA1LaWRkZXJtaW5zdGVyMSUwIwYDVQQKDBxPdmVydCBTb2Z0\n\t\t\t\t\t\td2FyZSBTb2x1dGlvbnMgTHRkMR4wHAYDVQQDDBVkZXYub3ZlcnRzb2Z0d2FyZS5j\n\t\t\t\t\t\tb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCpnaTvvvdx98eq58Uw\n\t\t\t\t\t\t/SZceVTD2oqKhemP63ftjDJbFSwzvldYtELChPyol5N2FTJicgTcNDUG8TaojI5O\n\t\t\t\t\t\thD4DEJ8hOeJMyVpvqcLJ08fACvdTeELNRrLm0S5/EbECpwkzCuylFfcW/g3bUyWQ\n\t\t\t\t\t\tYgqwh4QdvsHZGt8gpNekL8HHanSHZM6nuqEKmxf3lTyX8HvMUHNpJ+MipJkMwL2C\n\t\t\t\t\t\tE1t/PmptAma7eK7Fskf55YM+TEf+HDnFbUYEpyEJB5KJbDVPwz+MiClcFp3r96mr\n\t\t\t\t\t\t4utUYVvNI63d88P6YO2iPF9cuZ/aAFjYDpA5VeDPNC+OebtctnTijuBPIAOO9KJQ\n\t\t\t\t\t\txk/1AgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAB98gs+wZT9FXroh/WHhAa0DlSlB\n\t\t\t\t\t\tg+RnjvE0i+sph+SL5yDHurgVS3t7kwCfgsZnlaGNmE5mLXarIC0H4XhZyRyaelyi\n\t\t\t\t\t\tyZvjfQSjOOfG+cmWxFtyT85EzzIr1yXE9Ze03tkp03ryJKKyeNEyaUA185PhJ0Pd\n\t\t\t\t\t\tBmzOOThwLq2F59TOtMVq7Zfv7uxtgf9jHPquke/OYQLfv6SpYek4JqUQAZ8vSRe/\n\t\t\t\t\t\t7NwdnlukTdaDm+xbfscZdIjnSJ1vb6M2lFQXiSkSrlLhYLKejIioRAoelUMRQn1T\n\t\t\t\t\t\tN9PikIwIaLGqefV92Nl+5+iv2esjVQiGk+O4YPBeuyJJwag601rn0FaL5Qs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.overtsoftware.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dev.overtsoftware.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.overtsoftware.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dev.overtsoftware.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dev.overtsoftware.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dev.overtsoftware.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cafe.int.gov.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Luiz Dias"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "luiz.dias@int.gov.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.int.gov.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID5DCCAswCAQAwDQYJKoZIhvcNAQEFBQAwgbcxLzAtBgNVBAoTJklOVCAtIElu\nc3RpdHV0byBOYWNpb25hbCBkZSBUZWNub2xvZ2lhMTYwNAYDVQQLFC1ESVRJIC0g\nRGl2aXPDo28gZGUgVGVjbm9sb2dpYSBkYSBJbmZvcm1hw6fDo28xFzAVBgNVBAcT\nDlJpbyBkZSBKYW5laXJvMRcwFQYDVQQIEw5SaW8gZGUgSmFuZWlybzELMAkGA1UE\nBhMCQlIxDTALBgNVBAMTBGNhZmUwHhcNMTUxMDE0MTgwMTA4WhcNMTgxMDEzMTgw\nMTA4WjCBtzEvMC0GA1UEChMmSU5UIC0gSW5zdGl0dXRvIE5hY2lvbmFsIGRlIFRl\nY25vbG9naWExNjA0BgNVBAsULURJVEkgLSBEaXZpc8OjbyBkZSBUZWNub2xvZ2lh\nIGRhIEluZm9ybWHDp8OjbzEXMBUGA1UEBxMOUmlvIGRlIEphbmVpcm8xFzAVBgNV\nBAgTDlJpbyBkZSBKYW5laXJvMQswCQYDVQQGEwJCUjENMAsGA1UEAxMEY2FmZTCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMbrN61tI2RxMGEdoG7iFhjJ\nDBBdNhVUJl2p3SSuczWTa+HvbKWx7cF38QVnjBcxMaHZFbRNTwq/UCxHssMAzMVq\nzdOep2qwQ+u4cpkNijUG/u/hEWGUaTtMt2ClO+ONqcWN/sqE7ekCyAfBhEz60VXg\nYrDdEUe1+cpGEjdDlfMy0kOpP7mXya34hKkqyJH106YmjVyOlP8UEzH04K3rXPNp\nNZjwbzztaq9xYmYgta199vSCdmh04gAbJzWS+wABoNeDHYxoCao4gTJ8CmKPab1P\n/0tJ+WsSQ1/+g2O8FXkYCbCIt0E2aWE8V0eUf3SPGJEl/5+0WR4/3EtUqtPi/jMC\nAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAo92UA4/rxqefToQnm3ZlVJNgCYsjltwE\nHZAwm16mUAXjFljaqvDsysc2cvlsYKEvSUPwqcpa3k05L3hdW3dBE1l/AMoKuiTc\nkm2xRZq6zhG2D4YHPEpcH4/PVLMNYfTTN+Pie9wsugM3IgqagUXUdtS4eI8t3x0X\n+l8GAGHKRRDHjHBb+93iQJGITFNg0CJFaCvAa8kBBn2P5gbKohLhIHGfShG8719b\n0oRJ5a6b2L3wcMipz8W+tMc7Wi4o5QcW0WQvPyJl9B9KqzGthQOJIYigPx4iV2Va\nyhRwKkLgaS4ooMcUPBLDYoD7F3Yx2zKh9DiSWJBqj39lAR/+Bl00cA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gov.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.int.gov.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.int.gov.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.int.gov.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.int.gov.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.int.gov.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.int.gov.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.int.gov.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.int.gov.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gov.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.int.gov.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.int.gov.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "INT - Instituto Nacional de Tecnologia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "INT - Instituto Nacional de Tecnologia"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INT - Instituto Nacional de Tecnologia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INT - Instituto Nacional de Tecnologia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID5DCCAswCAQAwDQYJKoZIhvcNAQEFBQAwgbcxLzAtBgNVBAoTJklOVCAtIElu\nc3RpdHV0byBOYWNpb25hbCBkZSBUZWNub2xvZ2lhMTYwNAYDVQQLFC1ESVRJIC0g\nRGl2aXPDo28gZGUgVGVjbm9sb2dpYSBkYSBJbmZvcm1hw6fDo28xFzAVBgNVBAcT\nDlJpbyBkZSBKYW5laXJvMRcwFQYDVQQIEw5SaW8gZGUgSmFuZWlybzELMAkGA1UE\nBhMCQlIxDTALBgNVBAMTBGNhZmUwHhcNMTUxMDE0MTgwMTA4WhcNMTgxMDEzMTgw\nMTA4WjCBtzEvMC0GA1UEChMmSU5UIC0gSW5zdGl0dXRvIE5hY2lvbmFsIGRlIFRl\nY25vbG9naWExNjA0BgNVBAsULURJVEkgLSBEaXZpc8OjbyBkZSBUZWNub2xvZ2lh\nIGRhIEluZm9ybWHDp8OjbzEXMBUGA1UEBxMOUmlvIGRlIEphbmVpcm8xFzAVBgNV\nBAgTDlJpbyBkZSBKYW5laXJvMQswCQYDVQQGEwJCUjENMAsGA1UEAxMEY2FmZTCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMbrN61tI2RxMGEdoG7iFhjJ\nDBBdNhVUJl2p3SSuczWTa+HvbKWx7cF38QVnjBcxMaHZFbRNTwq/UCxHssMAzMVq\nzdOep2qwQ+u4cpkNijUG/u/hEWGUaTtMt2ClO+ONqcWN/sqE7ekCyAfBhEz60VXg\nYrDdEUe1+cpGEjdDlfMy0kOpP7mXya34hKkqyJH106YmjVyOlP8UEzH04K3rXPNp\nNZjwbzztaq9xYmYgta199vSCdmh04gAbJzWS+wABoNeDHYxoCao4gTJ8CmKPab1P\n/0tJ+WsSQ1/+g2O8FXkYCbCIt0E2aWE8V0eUf3SPGJEl/5+0WR4/3EtUqtPi/jMC\nAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAo92UA4/rxqefToQnm3ZlVJNgCYsjltwE\nHZAwm16mUAXjFljaqvDsysc2cvlsYKEvSUPwqcpa3k05L3hdW3dBE1l/AMoKuiTc\nkm2xRZq6zhG2D4YHPEpcH4/PVLMNYfTTN+Pie9wsugM3IgqagUXUdtS4eI8t3x0X\n+l8GAGHKRRDHjHBb+93iQJGITFNg0CJFaCvAa8kBBn2P5gbKohLhIHGfShG8719b\n0oRJ5a6b2L3wcMipz8W+tMc7Wi4o5QcW0WQvPyJl9B9KqzGthQOJIYigPx4iV2Va\nyhRwKkLgaS4ooMcUPBLDYoD7F3Yx2zKh9DiSWJBqj39lAR/+Bl00cA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INT - Instituto Nacional de Tecnologia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INT - Instituto Nacional de Tecnologia"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.int.gov.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.int.gov.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INT - Instituto Nacional de Tecnologia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INT - Instituto Nacional de Tecnologia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://swlite.sci-ware-customer.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SupportTeam@sci-ware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Application Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SupportTeam@sci-ware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Application Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://swlite.sci-ware-customer.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-06-06T13:31:57Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Science Warehouse ITE Environment"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sci-ware.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Science Warehouse Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://swlite.sci-ware-customer.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://swlite.sci-ware-customer.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://swlite.sci-ware-customer.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://swlite.sci-ware-customer.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://swlite.sci-ware-customer.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://swlite.sci-ware-customer.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://swlite.sci-ware-customer.com/Shibboleth.sso/LoginYSJ",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIJANYEwhA2kYlcMA0GCSqGSIb3DQEBBQUAMDYxNDAyBgNV\n\t\t\t\t\t\tBAMTK2lwLTEwLTEwNi0xNDUtMjguZXUtd2VzdC0xLmNvbXB1dGUuaW50ZXJuYWww\n\t\t\t\t\t\tHhcNMTQwNjA1MTQzMTMzWhcNMjQwNjAyMTQzMTMzWjA2MTQwMgYDVQQDEytpcC0x\n\t\t\t\t\t\tMC0xMDYtMTQ1LTI4LmV1LXdlc3QtMS5jb21wdXRlLmludGVybmFsMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA8kRUHv2zrb4I8y4hg/omB3v9EQ6F4ESW\n\t\t\t\t\t\tDjusedxQkitXVDgtVxAV8wuWC4wQwtZBuPIDDg+7W2kg9+KM2lYOBVCIOkr8EJNJ\n\t\t\t\t\t\thhw7CnjcZBIuLjK3UFMg57PEfOD9W7VcIs1fudzxkDr4y0OiyGavBegl9s6CvhNr\n\t\t\t\t\t\t43zMyARBj3CU94TdibghGU71zBYwy/qWQtOQyfVcLbm4TMbwHSBL/MchU/MFK1WU\n\t\t\t\t\t\tcQ7wHdeTAK6hfad67gVTK/ngSm5QgpnAYFMBWSQDnzDADw2R5LtIegWRaN0peK0R\n\t\t\t\t\t\tFKF1SZXxG/w1qv5AkpaWkWWpYguYx8xkSJ8HeBcmJ7fGX/XKHt7EQwIDAQABo1kw\n\t\t\t\t\t\tVzA2BgNVHREELzAtgitpcC0xMC0xMDYtMTQ1LTI4LmV1LXdlc3QtMS5jb21wdXRl\n\t\t\t\t\t\tLmludGVybmFsMB0GA1UdDgQWBBRI66bOTCIKQ2oTtVqtgb0oQHl0KjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAMnniDesVe1hg/OKv5lO9xym5i95Qh59LVqyoiWW2gdUMJpih\n\t\t\t\t\t\tCNVSz1MZfHpxs6VgApyzRdN4qFGOWFzVcHY1DmvyHuE4Y61Q70yzvG3FknwOt4Rs\n\t\t\t\t\t\tA5skq8J2TXz8L5o90io2HteEFo47rX92xH+zyyLRTuwjI4NpoDX5TB4GRLqvEvvn\n\t\t\t\t\t\tP0/oXOBETYlJqVK4OREqAyd+jVf7WpYSZDHCqgOWJ54MFvBd3vQp9gxTiCLdjTay\n\t\t\t\t\t\tYpbx1Yg1LWzRNl/NZHRL2Pag7RYbB13G+4m5i1Yni2EwmnRDc5GgI1FrVfpopH5B\n\t\t\t\t\t\t2lziDoipQufnV3DqtGQGUpN2BSVKkjXigpFeJg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://swlite.sci-ware-customer.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://swlite.sci-ware-customer.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://swlite.sci-ware-customer.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://swlite.sci-ware-customer.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://swlite.sci-ware-customer.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://swlite.sci-ware-customer.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://swlite.sci-ware-customer.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://swlite.sci-ware-customer.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://swlite.sci-ware-customer.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://swlite.sci-ware-customer.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp-ssbar.beniculturali.garr.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idpcloud-service@garr.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-ssbar.beniculturali.garr.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2014-09-23T06:04:04Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDajCCAlKgAwIBAgIVAK1w02d7b+IBhciTHgzqFmh3HoqaMA0GCSqGSIb3DQEB\nBQUAMCoxKDAmBgNVBAMTH2lkcC1zc2Jhci5iZW5pY3VsdHVyYWxpLmdhcnIuaXQw\nHhcNMTQwNTMwMDkwNjUxWhcNMzQwNTMwMDkwNjUxWjAqMSgwJgYDVQQDEx9pZHAt\nc3NiYXIuYmVuaWN1bHR1cmFsaS5nYXJyLml0MIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAtUyDEbuWYgBDLthfID5RiAaqAVV+VVSwK9JsbPyA0WEQG4mU\nwTwk9baImykOzOksmIgWY1XgBOy8jtI/fJ/9VBpz71paCkEjMQH7u6tHGuAVx6ZC\nQcWsSu1Iemktd2K8P+gWNUSW32GwRHOe8IrNVsuAQV0BnDvLKFnOyIaCSxJe1aCA\nmlobazivS7xvZ4fIKScfhmxX2vMcAogy6SlVrk5Nbz1g4ptLSMe2H6eP7pjp9Dw2\nJVCraHiCPlDUfLqKNANYLIcv03k8cY89NT0rEBS8ILawQCT5wdAj+toLOk7Dg9S9\nfc++QHWOnlI9eU6WBNIHnDxer2xep24CE7vHpwIDAQABo4GGMIGDMGIGA1UdEQRb\nMFmCH2lkcC1zc2Jhci5iZW5pY3VsdHVyYWxpLmdhcnIuaXSGNmh0dHBzOi8vaWRw\nLXNzYmFyLmJlbmljdWx0dXJhbGkuZ2Fyci5pdC9pZHAvc2hpYmJvbGV0aDAdBgNV\nHQ4EFgQU5OBUAd7iE3QPu87pd4OJ35n3xDwwDQYJKoZIhvcNAQEFBQADggEBAEtE\nEPZSrzpFbPHz65DWhxm6+FXDuRKYG9jwTabcikn4y19ykhauySmYUYfDE91vmKA/\ncJr4u720j9qvmZ/Z3pO6w8vD+SKrUHG5ez8m4ArGK35sYEEMA1JrW8oV6rcMk46x\nnL/TyhPinDLChZjlYEt5i4m2KlCipHc302KnbtLyjm8HsTAVkMxTibNCQHzI0m0B\nEmVP49peQFE/K1rZTi3f/z9I78UNUEz9SkbZBs4OBaFHd9RGtRuqD3lvWJchPJZ7\nD8mIA/RlAEXaL23Azho0dkiWphN6VkwqAW8btg6BPaeWCE8Z/EDZCinHXWyOE9is\n1UGZpgRi7oyzxW0d230="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "archeoroma.beniculturali.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-ssbar.beniculturali.garr.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-ssbar.beniculturali.garr.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-ssbar.beniculturali.garr.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-ssbar.beniculturali.garr.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-ssbar.beniculturali.garr.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-ssbar.beniculturali.garr.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-ssbar.beniculturali.garr.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-ssbar.beniculturali.garr.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "archeoroma.beniculturali.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://archeoroma.beniculturali.it/en/idem-info"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://archeoroma.beniculturali.it/idp/info"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SSCOL - Soprintendenza Speciale per il Colosseo"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SSCOL - Soprintendenza Speciale per il Colosseo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Soprintendenza Speciale per il Colosseo"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti della Soprintendenza Speciale per il Colosseo"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp-ssbar.beniculturali.garr.it/idp/images/institutionLogo-32x32_en.png",
                    "lang": "en",
                    "height": "32",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "32"
                  },
                  {
                    "text": "https://idp-ssbar.beniculturali.garr.it/idp/images/institutionLogo-160x120_en.png",
                    "lang": "en",
                    "height": "120",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "160"
                  },
                  {
                    "text": "https://idp-ssbar.beniculturali.garr.it/idp/images/institutionLogo-32x32_it.png",
                    "lang": "it",
                    "height": "32",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "32"
                  },
                  {
                    "text": "https://idp-ssbar.beniculturali.garr.it/idp/images/institutionLogo-160x120_it.png",
                    "lang": "it",
                    "height": "120",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "160"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://archeoroma.beniculturali.it/en/privacy-0"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://archeoroma.beniculturali.it/privacy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDajCCAlKgAwIBAgIVAK1w02d7b+IBhciTHgzqFmh3HoqaMA0GCSqGSIb3DQEB\nBQUAMCoxKDAmBgNVBAMTH2lkcC1zc2Jhci5iZW5pY3VsdHVyYWxpLmdhcnIuaXQw\nHhcNMTQwNTMwMDkwNjUxWhcNMzQwNTMwMDkwNjUxWjAqMSgwJgYDVQQDEx9pZHAt\nc3NiYXIuYmVuaWN1bHR1cmFsaS5nYXJyLml0MIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAtUyDEbuWYgBDLthfID5RiAaqAVV+VVSwK9JsbPyA0WEQG4mU\nwTwk9baImykOzOksmIgWY1XgBOy8jtI/fJ/9VBpz71paCkEjMQH7u6tHGuAVx6ZC\nQcWsSu1Iemktd2K8P+gWNUSW32GwRHOe8IrNVsuAQV0BnDvLKFnOyIaCSxJe1aCA\nmlobazivS7xvZ4fIKScfhmxX2vMcAogy6SlVrk5Nbz1g4ptLSMe2H6eP7pjp9Dw2\nJVCraHiCPlDUfLqKNANYLIcv03k8cY89NT0rEBS8ILawQCT5wdAj+toLOk7Dg9S9\nfc++QHWOnlI9eU6WBNIHnDxer2xep24CE7vHpwIDAQABo4GGMIGDMGIGA1UdEQRb\nMFmCH2lkcC1zc2Jhci5iZW5pY3VsdHVyYWxpLmdhcnIuaXSGNmh0dHBzOi8vaWRw\nLXNzYmFyLmJlbmljdWx0dXJhbGkuZ2Fyci5pdC9pZHAvc2hpYmJvbGV0aDAdBgNV\nHQ4EFgQU5OBUAd7iE3QPu87pd4OJ35n3xDwwDQYJKoZIhvcNAQEFBQADggEBAEtE\nEPZSrzpFbPHz65DWhxm6+FXDuRKYG9jwTabcikn4y19ykhauySmYUYfDE91vmKA/\ncJr4u720j9qvmZ/Z3pO6w8vD+SKrUHG5ez8m4ArGK35sYEEMA1JrW8oV6rcMk46x\nnL/TyhPinDLChZjlYEt5i4m2KlCipHc302KnbtLyjm8HsTAVkMxTibNCQHzI0m0B\nEmVP49peQFE/K1rZTi3f/z9I78UNUEz9SkbZBs4OBaFHd9RGtRuqD3lvWJchPJZ7\nD8mIA/RlAEXaL23Azho0dkiWphN6VkwqAW8btg6BPaeWCE8Z/EDZCinHXWyOE9is\n1UGZpgRi7oyzxW0d230="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SSCOL - Soprintendenza Speciale per il Colosseo"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SSCOL - Soprintendenza Speciale per il Colosseo"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://archeoroma.beniculturali.it/en"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://archeoroma.beniculturali.it"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SSCOL - Soprintendenza Speciale per il Colosseo"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SSCOL - Soprintendenza Speciale per il Colosseo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://upki.yamagata-u.ac.jp/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Networking and Computing Service Center"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sinet-admin@cc.yamagata-u.ac.jp"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://upki.yamagata-u.ac.jp/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.gakunin.jp/en-Join/"
              },
              {
                "lang": "ja",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.gakunin.jp/join/"
              }
            ],
            "registration_instant": "2009-11-05T00:00:00Z",
            "registration_authority": "https://www.gakunin.jp",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE/DCCA+SgAwIBAgIIfK4/rh+AlMUwDQYJKoZIhvcNAQELBQAwbTELMAkGA1UE\nBhMCSlAxEDAOBgNVBAcTB0FjYWRlbWUxKjAoBgNVBAoTIU5hdGlvbmFsIEluc3Rp\ndHV0ZSBvZiBJbmZvcm1hdGljczEgMB4GA1UEAxMXTklJIE9wZW4gRG9tYWluIENB\nIC0gRzQwHhcNMTUwNjI2MTExNzA0WhcNMTcwNzI2MTExNzA0WjCBjzELMAkGA1UE\nBhMCSlAxEDAOBgNVBAcTB0FjYWRlbWUxHDAaBgNVBAoTE1lhbWFnYXRhIFVuaXZl\ncnNpdHkxMDAuBgNVBAsTJ05ldHdvcmtpbmcgYW5kIENvbXB1dGluZyBTZXJ2aWNl\nIENlbnRlcjEeMBwGA1UEAxMVdXBraS55YW1hZ2F0YS11LmFjLmpwMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApGJaTuQQ7ArOVOiAngf9l4RbPzk5ztw/\nwD2QEI78cIEfjPN/djb5pgqUFq0qHMp+GkV4UB5muObCVd43zAn1PxdzoSlbE7RB\nJjIyLIuo0uK83pNx/rgDQZCwi8hi2Vp4RlAQZVnq69CosKwz/4qTQgGRmDcU1qlL\nIcKcMFgM6hz6MKQgrEUbLNfvLcJUml/8yku3TW5hu7dNOHzMHG8u8PbSjv1E1SVs\nteuWaLxsxb2dOgViMDgj09JTzTMEfp4h0okGXkvefInLECKVf+PSAXjwLYVQn72R\n19tru8k73CJFcJXNYjIuLE+hgQkRYtzgKbCwlTWq06tVL5Cm2lOEpwIDAQABo4IB\nezCCAXcwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMB8GA1UdIwQYMBaA\nFBkLbzkfMQM0X+TSQB835o3nYjl8MEoGA1UdHwRDMEEwP6A9oDuGOWh0dHA6Ly9y\nZXBvMS5zZWNvbXRydXN0Lm5ldC9zcHBjYS9uaWkvb2RjYTMvZnVsbGNybGc0LmNy\nbDAOBgNVHQ8BAf8EBAMCBaAwHQYDVR0OBBYEFFwPF1DdKRucPlNVo6OuEwDEsNvx\nMFoGA1UdIARTMFEwTwYMKwYBBAGB/AgDAgEBMD8wPQYIKwYBBQUHAgEWMWh0dHBz\nOi8vcmVwbzEuc2Vjb210cnVzdC5uZXQvc3BjcHAvY3BzL2luZGV4Lmh0bWwwPAYI\nKwYBBQUHAQEEMDAuMCwGCCsGAQUFBzABhiBodHRwOi8vbmlpZzQub2NzcC5zZWNv\nbXRydXN0Lm5ldDAgBgNVHREEGTAXghV1cGtpLnlhbWFnYXRhLXUuYWMuanAwDQYJ\nKoZIhvcNAQELBQADggEBAESvy42bUtXwWGWkvW7vddFsLIGjlEWWV0E79wXobVt0\nLKVm/JpdR0XmWWADe252JLzCvGGRRXBqXCAy3+9dshSsG508t5R6C1wMXf3jGHV9\nr9gv2PuEqtibPXM8FFe0ARmBWUWo3/Fgh/1aTwSKzTeAoX/vMVjJZXZTCB6xmyls\njHCqvp568dPYJo7bNRgDS5L8gcR79VDUQfvysZNgqgu4yBJN2QyloNfPbTEWI3BK\nF/SKL1HwtIO9yIFXUifLwqEx2U7H3WVQowe/avgAPVEHsCqAPAPv+OCEqJbjjtl5\n+u7BMTn7P17Ua/k7aQTIDQ9E9wMs7Fp4LBKUklinM9o="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "yamagata-u.ac.jp"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://upki.yamagata-u.ac.jp:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://upki.yamagata-u.ac.jp:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://upki.yamagata-u.ac.jp/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://upki.yamagata-u.ac.jp/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://upki.yamagata-u.ac.jp/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "yamagata-u.ac.jp"
              },
              {
                "display_name": [
                  {
                    "lang": "ja",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u5c71\u5f62\u5927\u5b66"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Yamagata University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE/DCCA+SgAwIBAgIIfK4/rh+AlMUwDQYJKoZIhvcNAQELBQAwbTELMAkGA1UE\nBhMCSlAxEDAOBgNVBAcTB0FjYWRlbWUxKjAoBgNVBAoTIU5hdGlvbmFsIEluc3Rp\ndHV0ZSBvZiBJbmZvcm1hdGljczEgMB4GA1UEAxMXTklJIE9wZW4gRG9tYWluIENB\nIC0gRzQwHhcNMTUwNjI2MTExNzA0WhcNMTcwNzI2MTExNzA0WjCBjzELMAkGA1UE\nBhMCSlAxEDAOBgNVBAcTB0FjYWRlbWUxHDAaBgNVBAoTE1lhbWFnYXRhIFVuaXZl\ncnNpdHkxMDAuBgNVBAsTJ05ldHdvcmtpbmcgYW5kIENvbXB1dGluZyBTZXJ2aWNl\nIENlbnRlcjEeMBwGA1UEAxMVdXBraS55YW1hZ2F0YS11LmFjLmpwMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApGJaTuQQ7ArOVOiAngf9l4RbPzk5ztw/\nwD2QEI78cIEfjPN/djb5pgqUFq0qHMp+GkV4UB5muObCVd43zAn1PxdzoSlbE7RB\nJjIyLIuo0uK83pNx/rgDQZCwi8hi2Vp4RlAQZVnq69CosKwz/4qTQgGRmDcU1qlL\nIcKcMFgM6hz6MKQgrEUbLNfvLcJUml/8yku3TW5hu7dNOHzMHG8u8PbSjv1E1SVs\nteuWaLxsxb2dOgViMDgj09JTzTMEfp4h0okGXkvefInLECKVf+PSAXjwLYVQn72R\n19tru8k73CJFcJXNYjIuLE+hgQkRYtzgKbCwlTWq06tVL5Cm2lOEpwIDAQABo4IB\nezCCAXcwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMB8GA1UdIwQYMBaA\nFBkLbzkfMQM0X+TSQB835o3nYjl8MEoGA1UdHwRDMEEwP6A9oDuGOWh0dHA6Ly9y\nZXBvMS5zZWNvbXRydXN0Lm5ldC9zcHBjYS9uaWkvb2RjYTMvZnVsbGNybGc0LmNy\nbDAOBgNVHQ8BAf8EBAMCBaAwHQYDVR0OBBYEFFwPF1DdKRucPlNVo6OuEwDEsNvx\nMFoGA1UdIARTMFEwTwYMKwYBBAGB/AgDAgEBMD8wPQYIKwYBBQUHAgEWMWh0dHBz\nOi8vcmVwbzEuc2Vjb210cnVzdC5uZXQvc3BjcHAvY3BzL2luZGV4Lmh0bWwwPAYI\nKwYBBQUHAQEEMDAuMCwGCCsGAQUFBzABhiBodHRwOi8vbmlpZzQub2NzcC5zZWNv\nbXRydXN0Lm5ldDAgBgNVHREEGTAXghV1cGtpLnlhbWFnYXRhLXUuYWMuanAwDQYJ\nKoZIhvcNAQELBQADggEBAESvy42bUtXwWGWkvW7vddFsLIGjlEWWV0E79wXobVt0\nLKVm/JpdR0XmWWADe252JLzCvGGRRXBqXCAy3+9dshSsG508t5R6C1wMXf3jGHV9\nr9gv2PuEqtibPXM8FFe0ARmBWUWo3/Fgh/1aTwSKzTeAoX/vMVjJZXZTCB6xmyls\njHCqvp568dPYJo7bNRgDS5L8gcR79VDUQfvysZNgqgu4yBJN2QyloNfPbTEWI3BK\nF/SKL1HwtIO9yIFXUifLwqEx2U7H3WVQowe/avgAPVEHsCqAPAPv+OCEqJbjjtl5\n+u7BMTn7P17Ua/k7aQTIDQ9E9wMs7Fp4LBKUklinM9o="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Yamagata University"
          },
          {
            "lang": "ja",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u5c71\u5f62\u5927\u5b66"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://kdwww.kj.yamagata-u.ac.jp/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Yamagata University"
          },
          {
            "lang": "ja",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u5c71\u5f62\u5927\u5b66"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.merit.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "it-ops@merit.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Operations"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.merit.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://merit-idp01.merit.edu/ssp/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://merit-idp01.merit.edu/ssp/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "merit.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Merit SSP IDP"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Merit Network, Inc."
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEEzCCAvugAwIBAgIJAJPTkMqcbv2AMA0GCSqGSIb3DQEBBQUAMIGfMQswCQYD\nVQQGEwJVUzELMAkGA1UECAwCTUkxEjAQBgNVBAcMCUFubiBBcmJvcjEWMBQGA1UE\nCgwNTWVyaXQgTmV0d29yazEWMBQGA1UECwwNSVQgT3BlcmF0aW9uczEeMBwGA1UE\nAwwVbWVyaXQtaWRwMDEubWVyaXQuZWR1MR8wHQYJKoZIhvcNAQkBFhBpdC1vcHNA\nbWVyaXQuZWR1MB4XDTEzMDQwNDIwMDcwNloXDTIzMDQwNDIwMDcwNlowgZ8xCzAJ\nBgNVBAYTAlVTMQswCQYDVQQIDAJNSTESMBAGA1UEBwwJQW5uIEFyYm9yMRYwFAYD\nVQQKDA1NZXJpdCBOZXR3b3JrMRYwFAYDVQQLDA1JVCBPcGVyYXRpb25zMR4wHAYD\nVQQDDBVtZXJpdC1pZHAwMS5tZXJpdC5lZHUxHzAdBgkqhkiG9w0BCQEWEGl0LW9w\nc0BtZXJpdC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCvogfB\nMdVIw5G3DNdBBV61/VpmqaX+yd/vsRrrQFk/zEfXBhhLgvPh5klFYUiljjibrgO0\nVRt+tQBdNVkZmZbpUN2dxbcFOT2QGX2XaFcCY2NvBLTqeEe/TpcEmuiN2HM3D5ot\nM1tNT/5ld4kAjJGm8PrKyq7jivO8IbBk2P9QsnD/5yd1MI2s0vqseGY4eMtTUY1f\nDfj9wZdNXx6Cuc89gHJ6JSWb5/I3m15AEq5cGkeE+FVfyAbOT6SN4o4jXhglOCzM\neekthNZ8z/vGyzdLKwVdkJwkmCpNJhgnTw2P8xvBo51oh79Bf4c/LNO2eqp33ZBw\nrUmunwNbIogOzvJZAgMBAAGjUDBOMB0GA1UdDgQWBBRkXrVfR6LT5Crhz8S0ndpp\nOJdU5jAfBgNVHSMEGDAWgBRkXrVfR6LT5Crhz8S0ndppOJdU5jAMBgNVHRMEBTAD\nAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCstZjbV0uJmAqToHBgTUxW1qekX4fxYOEL\nFxm8Tl5QNhRomQEWNpu04+eSM8WynMSh8GyS1S2lkRVOcaDQFgvY6PnUZYobTSzD\noG0SFXgE1Zbvnu56JcWrUKdDrSs0QIxjqTxHiq/jRhztxiExjCI9DFPc8ig/rbzk\n+qsk88XxLJ2e+n0icdXgROWYRTxHbOgsVuHVrbMUMhFxeqwA8UGAAErVW0UpBdxj\nUX42ZnYC7Be3Kknd87onuaSSWLyMQFGqoz0FiBdnH7r0V1s4NDuDawHHk4sMDZBl\nyW53IkO/bdDl7whtv2akTp37DPTKkdCRD0jz51PoJTqf0NaLo6qh"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Merit Network, Inc."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.merit.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Merit Network, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth2sp.jstor.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Larsen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:brian.larsen@ithaka.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brian"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Larsen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:brian.larsen@ithaka.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth2sp.jstor.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-09-16T08:54:29Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "JSTOR"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://about.jstor.org/about/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ithaka Harbors, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.jstor.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.jstor.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.jstor.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.jstor.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "JSTOR"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.jstor.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth2sp.jstor.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth2sp.jstor.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "JSTOR is a digital library of academic journals, books, and primary sources."
                  }
                ],
                "logo": [
                  {
                    "text": "https://jstorstatic.global.ssl.fastly.net/images/J_Logo_80x80px.png",
                    "height": "80",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://jstorstatic.global.ssl.fastly.net/images/J_Logo_16x16px.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "JSTOR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDwjCCAqqgAwIBAgIJAJgkGmQBfO0tMA0GCSqGSIb3DQEBBQUAMGcxCzAJBgNV\n\t\t\t\t\t\tBAYTAlVLMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIwEAYD\n\t\t\t\t\t\tVQQKEwlzZW1hbnRpY28xIDAeBgNVBAMTF3NoaWJib2xldGgyc3AuanN0b3Iub3Jn\n\t\t\t\t\t\tMB4XDTE1MDgyMDEwMjEyMVoXDTM1MDgxNTEwMjEyMVowZzELMAkGA1UEBhMCVUsx\n\t\t\t\t\t\tDzANBgNVBAgTBlN1c3NleDERMA8GA1UEBxMIQnJpZ2h0b24xEjAQBgNVBAoTCXNl\n\t\t\t\t\t\tbWFudGljbzEgMB4GA1UEAxMXc2hpYmJvbGV0aDJzcC5qc3Rvci5vcmcwggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDuvYnVYRRNnT700akTCLjMpeYMiybx\n\t\t\t\t\t\t+QDbBZUagVPJ7ozTXBSM6f+NgLBBa7BZ4/lSKH7y0DSP7xpu2IDZGDclwOse8tG7\n\t\t\t\t\t\trV+CgXJj7Kt7fRoJsk2KYmMPwD0KGJDw7MpZFb+2m1h3542QoJqQFxCHvPa4vas1\n\t\t\t\t\t\tLhxAcSSsLdFvlAYWPQliBISls1YitEbtCzLke26jYHrat1H79miprcrQ966zyEyb\n\t\t\t\t\t\tJIFAmtftHTuC+RhpOw6VS9y30GK5/i/iofj37lBQ83FNCsGnzgjLeJCMrQz1SYOI\n\t\t\t\t\t\tjGmsjKntUs0/lhEaES2OohGIIkqBZZ6A4ZzWWJqPhdeysluQ1mU+j+dVAgMBAAGj\n\t\t\t\t\t\tcTBvME4GA1UdEQRHMEWCF3NoaWJib2xldGgyc3AuanN0b3Iub3JnhipodHRwczov\n\t\t\t\t\t\tL3NoaWJib2xldGgyc3AuanN0b3Iub3JnL3NoaWJib2xldGgwHQYDVR0OBBYEFDtp\n\t\t\t\t\t\tFSMX6Vm2e+Corjd0Y86bkI7lMA0GCSqGSIb3DQEBBQUAA4IBAQDqCMPX1TR6E32T\n\t\t\t\t\t\tFYmhD1m/HOmugfYXj85rMWQmBzP8PoCVY3YylS8ludV2EQKaIueMRqQa/d4VXRGS\n\t\t\t\t\t\t5g7hQ9z3/G6MHpPD3a/gESN0+49poZ3W/fIV5lbH2osTTntZbKtZY/XEf712eCfw\n\t\t\t\t\t\t29shrnSLWosfsTI1kN1HqGS/ZpoeKP/jf2pMCfp1zsng0hcGaC+6FPQhAGz0FAOj\n\t\t\t\t\t\tURNA4uZ6QUwmUlAFRfw9HG25sZmsWl5Aq8DKa0sjbo3VPD/bAw919+cnuu0Yhtkm\n\t\t\t\t\t\tDhqQFdFGUhFvH+wuY366L7UhWBLqhLhERqJ4qBe06Qeg7JrAvK7fqPBWNTbDtEkI\n\t\t\t\t\t\tNNLmpeHL"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.jstor.org/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.jstor.org/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.jstor.org/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.jstor.org/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.jstor.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth2sp.jstor.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.jstor.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth2sp.jstor.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth2sp.jstor.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth2sp.jstor.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://access.procureweb.ac.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Skidmore"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nathan@procureweb.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nathan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wells"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:joe@procureweb.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Joe"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://access.procureweb.ac.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "JISC Services Management Company Ltd: JISC Procureweb"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.procureweb.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "JISC Services Management Company Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://access.procureweb.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://access.procureweb.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://access.procureweb.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://access.procureweb.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://access.procureweb.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://access.procureweb.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "JISC Procureweb, a procurement support service for the UK Higher and Further Education sectors"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.procureweb.ac.uk/images/Procureweb_Logo2.jpg",
                    "height": "128",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "233"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "JISC Services Management Company Ltd: JISC Procureweb"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJALUgGF9qVwMgMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\n\t\t\t\t\t\tBAMTFXAyazh3ZWIwMi5hZC5jZi5hYy51azAeFw0xMjAxMDgyMjExNTVaFw0yMjAx\n\t\t\t\t\t\tMDUyMjExNTVaMCAxHjAcBgNVBAMTFXAyazh3ZWIwMi5hZC5jZi5hYy51azCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKdar5W/cmwUfVkTxd7A+hTRpt6f\n\t\t\t\t\t\tCdfd++/ZeyGdBr49/t1T+zceln6arQYtbylxr/myZ5Lt2QdyFymwiaxmcIt46m9E\n\t\t\t\t\t\t428hqMeL2DWctMa0ZhxJ374dDasiRFFxUXLb8gq0X7rxo0IKynCoVCgqdefKzxzp\n\t\t\t\t\t\tI/fK4WlWY0jQ+OqIJ8Teulbu3807t4o09g2H6qS0AhYkRfZjVqBuqkg7t8lYd+yV\n\t\t\t\t\t\tiwbEBuhKpLVZ6w0tEjrMDma2kOiycvdKt+5rZ0rsgOTRfJLye8lQeBOU66edLJd1\n\t\t\t\t\t\tRxbm80loSvgE0T0JzUiVmwnyA4H/JRqKfUtlAQThfOaTGwkgFc1YOGUfPwMCAwEA\n\t\t\t\t\t\tAaNDMEEwIAYDVR0RBBkwF4IVcDJrOHdlYjAyLmFkLmNmLmFjLnVrMB0GA1UdDgQW\n\t\t\t\t\t\tBBRZEluMzvKX1J4CK2+K3V/K/FMvZjANBgkqhkiG9w0BAQUFAAOCAQEAUh2P7oiy\n\t\t\t\t\t\taNVsQc1ACkTQWKhfVFjVDSnS6POLwHOhRmEt6DnHbcNUFchQjw0WBAkzQnLed6FI\n\t\t\t\t\t\tZPbPzzohHqRiKTViIxfDbdl1E0iVdjDEV/WE0PzM4KbNsXWSSMkAU8hXsqZAvtMF\n\t\t\t\t\t\tpCFKNbAKLGG1JksIU57qgOe7cRU1FU3rGmXugZHZ//c/iZf+MeuKYx6sUzbI0xts\n\t\t\t\t\t\tuoudJ6z3NkV+KE9+m/i50kK8cKPdneTYAd6qZTIbwgwNusopNJb4oIp2Xx43r8jW\n\t\t\t\t\t\tFUk/hEL49V7l1jwcR2T49iaBVn1jfVs/0GJaEvDgWk+NcqV159JezhyejHnTnQv1\n\t\t\t\t\t\tBWKhfx7wG1mJNg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://access.procureweb.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://access.procureweb.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://access.procureweb.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://access.procureweb.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://access.procureweb.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://access.procureweb.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://identity.merthyr.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:IT.Servicedesk@merthyr.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jackson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:J.Jackson1@merthyr.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Watkins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:A.Watkins@merthyr.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://identity.merthyr.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-03-03T12:55:28Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://identity.merthyr.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://identity.merthyr.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://identity.merthyr.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://identity.merthyr.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://identity.merthyr.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://identity.merthyr.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "merthyr.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://identity.merthyr.ac.uk/idp/images/logo.png",
                    "height": "80",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The College Merthyr Tydfil"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVAPD1e21Xbsbc/ewgYYj9T3jdllMqMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMCExHzAdBgNVBAMMFmlkZW50aXR5Lm1lcnRoeXIuYWMudWswHhcNMTYwMjE4\n\t\t\t\t\t\tMDkxNTE3WhcNMzYwMjE4MDkxNTE3WjAhMR8wHQYDVQQDDBZpZGVudGl0eS5tZXJ0\n\t\t\t\t\t\taHlyLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkFA68D9C\n\t\t\t\t\t\tGyEoXtAL4UQyTxo2rE4KLx7iChrVnvuSg2akkz8L2IOKR0O39aBj4Q4cR3t6WO1q\n\t\t\t\t\t\tIOi46i8oh+rn6xmwfHxO9ylTaaPpvR3uKoi2zI19g9p6joS/wEmV7CZnDNI5nIMO\n\t\t\t\t\t\tqvpzQCSr7NiIq3M5MOqnkCwR6uQZAmWarLxiB3yWR8j6dGBbYFBuvyQv2IPQ3Wc+\n\t\t\t\t\t\tpweuRLH6L5xS1OL8wE4rNmOZfxDZceMc6Ohwd9VCBsbNs9avz2ZGMvzVjVfiujD/\n\t\t\t\t\t\tvzcBbvpqhEBAulWndJc81DwpZk45rEqPaFCKsOP+OOFI3Pi3fTUNTh0yKA0VJrIM\n\t\t\t\t\t\tJMlEzX+0b/15AQIDAQABo3MwcTAdBgNVHQ4EFgQU2QNK31sthu8cTxylOt9eyl6s\n\t\t\t\t\t\teoIwUAYDVR0RBEkwR4IWaWRlbnRpdHkubWVydGh5ci5hYy51a4YtaHR0cHM6Ly9p\n\t\t\t\t\t\tZGVudGl0eS5tZXJ0aHlyLmFjLnVrL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAA4IBAQBp6quFjjkEtCj7BoTsCDN91T+2253R2z8gZyH1fSsvS0wDZg8T7io8\n\t\t\t\t\t\tVHVxjR8bNyH6OVqZ9SsMoMs9tCoup2TJgLzEM90nkqqa2IBAbVV6r6uN5kZFRdZi\n\t\t\t\t\t\tHtIsmutD/3BcDuW3N5v+PGt/LRMCvBbgklwKmmdwfCzPkD5+xL0BwDJXKqVaQgss\n\t\t\t\t\t\tjEq1v1ZvUy8LYPmc4QgCM8LpPCzyA+nVzkiQj7aPgQ/Lq+4NC7A3QnN4xbW+4gUD\n\t\t\t\t\t\th6tZW61OSImXh4vVx25jBaSeil94bu4eTHX8NPGRSPWsJHjkSSMyj//E/Hb0nvUT\n\t\t\t\t\t\to4sOxqCOINYHaIz5vc4Hg+Cabyout4Zg"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUT3wLwUQdjtdrHC5Eh49xQf4S89AwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwITEfMB0GA1UEAwwWaWRlbnRpdHkubWVydGh5ci5hYy51azAeFw0xNjAyMTgw\n\t\t\t\t\t\tOTE1MTZaFw0zNjAyMTgwOTE1MTZaMCExHzAdBgNVBAMMFmlkZW50aXR5Lm1lcnRo\n\t\t\t\t\t\teXIuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCBTLE8kQLt\n\t\t\t\t\t\tBf7NCKq9Fi+fw12Mn2ft+HfqV207A/8AguTLrj257GB3Rs8OJynPhe2ak1PZcQ73\n\t\t\t\t\t\tf7ogAHkQw1IvNMbQpD34gztzT7t6E7mgPbo9cxQHjHpC0B1NhSsSF9y4TAl1D01N\n\t\t\t\t\t\tUy8ERw/S8+rBRaOw1Kvk8Lo9r3UCjkIFoJcO7w++5OMH5dudqtp45hreAjFfpBij\n\t\t\t\t\t\tebe3lUcv/uh6ArZ6HIV8OQ42ULUeZdrMwO+2XZ1Wfv+Zy8EcI0lZoBs/qLpzxYeE\n\t\t\t\t\t\t33OGrN9NVS34RVmaUCGsaJyach1+hReL9T4LGSiOacf8s10SST8jp1cQTrdm0fBA\n\t\t\t\t\t\tsFPQR6gQ15szAgMBAAGjczBxMB0GA1UdDgQWBBSQkjEM1nCGMBl+0HVAUgJop8SI\n\t\t\t\t\t\t+DBQBgNVHREESTBHghZpZGVudGl0eS5tZXJ0aHlyLmFjLnVrhi1odHRwczovL2lk\n\t\t\t\t\t\tZW50aXR5Lm1lcnRoeXIuYWMudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQADggEBAFQGnh3XNSVtymHiyK1m71cT1a7az4oTnu/EmOfP7w44G9IH7iP0Pist\n\t\t\t\t\t\tqOCfwumNrHxdZAHkbD8Q4M8HzY42C53+zVPHbBSqzmGs7O+ooyVvaCK9LH39H3rY\n\t\t\t\t\t\tRk4lt2LAUi+0ghf7qYQnoy6M1Qv1MlzAEodk+pM0HkmZXsrju6WURMAaPRZOrQcW\n\t\t\t\t\t\t5ySR5zDiFVwssJDprmdRGk2ql4srgeCo3WPPk3BT1bAMAihqFYezAxVULuLazYXU\n\t\t\t\t\t\trSjxVr67J+DjF3pC14TahR8ZsrDMw6w/Iz3Za0YQz7P/ZzdHsLmEEhHH3Bk1KXvY\n\t\t\t\t\t\tkPLAK20Qa90x4UjhW2sgzMV/s/7W1f8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVALriBK2Djfe+kurUI1ykFZQSYOVKMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMCExHzAdBgNVBAMMFmlkZW50aXR5Lm1lcnRoeXIuYWMudWswHhcNMTYwMjE4\n\t\t\t\t\t\tMDkxNTE2WhcNMzYwMjE4MDkxNTE2WjAhMR8wHQYDVQQDDBZpZGVudGl0eS5tZXJ0\n\t\t\t\t\t\taHlyLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAgEF1cPCi\n\t\t\t\t\t\t9AgItj/FC93AwDtj/XxOUunA+lhJ31WJpbKrOrVoTBVlauaLpGkwWBr2//dciuC3\n\t\t\t\t\t\tK3E/rfHfacwhIPJdBBB74nm3nf7bpjTC+IM5W2Gm3z7uMGQ7aIyfv45a21ibA2JG\n\t\t\t\t\t\tp1Q64oYhtpKXnORNppVCthPuRjhxyOtFbA00AaZbPPSn82QR5LPHv7xHNtiS/6DH\n\t\t\t\t\t\tpiD00fo+GLgHJCNFib4kQ7kdfT3S6qTepxV0rrGtd09IAIHxj7V1/WMYnKKr+e9c\n\t\t\t\t\t\tnzBXXpewai5i0+Spcy1Cr6dwPis8ruOsISPgFjZX9u4lb1UKRd0IEP2BD21F87eO\n\t\t\t\t\t\tc3qtdCdzw6sgowIDAQABo3MwcTAdBgNVHQ4EFgQUNy1OY2bKP80hPynTGllTVslH\n\t\t\t\t\t\t5cowUAYDVR0RBEkwR4IWaWRlbnRpdHkubWVydGh5ci5hYy51a4YtaHR0cHM6Ly9p\n\t\t\t\t\t\tZGVudGl0eS5tZXJ0aHlyLmFjLnVrL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAA4IBAQBm3uak51S7p2UZm3dHtFm2/g4G6hcfFmE7VmgIfK2d75J8LMIR6iZj\n\t\t\t\t\t\t9JDSafBqc90Jqlwyg5NjiJ0ePcW9y/3MQrF4duSdrBrE+oc++84zj03EcX8fDFVH\n\t\t\t\t\t\trLGCEbXNVT6xlBj1JssdZb78eVYq2gVKkBBKywCOqzGbGI4BqZfsmUcvhpPnsQaw\n\t\t\t\t\t\t5aCsq2hVZVrJS5A66S76knFf8Kly3NF7mS1Gurupa0GrkLoxLXOLYYFy5piYHCTT\n\t\t\t\t\t\twT1q733K59v8dHfRH77nQXgY92yKaFUyqdtoqALMqgtUiKmjMA5Q8zLDg5beDStM\n\t\t\t\t\t\t+GnV89LwIOI1mWeY2qsFeA8oFXy+49hn"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The College Merthyr Tydfil"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.merthyr.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Merthyr Tydfil College Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-p09.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-p09.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p09.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p09.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p09.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p09.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p09.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-p09.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-p09.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;p09"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;p09"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-p09.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-p09.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIJAIiAlJfuxj/NMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2xhZG9rMy1wMDkubGFkb2sudW11LnNlMB4XDTE1MDIwOTEwNDExN1oXDTI1\nMDIwNjEwNDExN1owIjEgMB4GA1UEAxMXbGFkb2szLXAwOS5sYWRvay51bXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDTaZbnPfqpmEX5MYOn68nB\nL78aKniv0Os+3xeWl0z5uGX7XBxmCW3cUP5DASujy4BdmrjPBlrxenRitXEupElE\nyWI4AbVTy9Sept7YMfHZl+pvcWEefzJidDJ58b+C6mTvxXBOM7TngABc7zhiVABn\nKs+npvtg70BdzkEdrnz9azF+LnKQ6bfO1r50Ac5R+mlVSX9W5lvE1KI9+PWRvQVB\nTbfcfjraxZqgvRrsTyyQyERGc7WNO1kD79yVdfUaEMIEyPQ2t5S+Bj6M90zGNOrP\nsV/I2GeiyPniCFh4lDrW/lDVuAUNn1JbmrchdD3Yhdf7ScwvUr1LoL7bF8Q4gv3/\nAgMBAAGjbTBrMEoGA1UdEQRDMEGCF2xhZG9rMy1wMDkubGFkb2sudW11LnNlhiZo\ndHRwczovL2xhZG9rMy1wMDkubGFkb2sudW11LnNlL2d1aS1zcDAdBgNVHQ4EFgQU\n5P39U96vogIEoiDHMnGlSUGrraowDQYJKoZIhvcNAQEFBQADggEBAKierMoatWOl\nAjDRhWI3RdVr1raWmvBF9jr3mMCTqJpg6BJPsRcZfVVP7pyrW7KwxYpO/KOgjj7u\nSiXxVhhVIn0I3fHuph7s0aKp0tuzhOLoKVFpx+TwvDn5cxH70vShSgtQVqHie40s\njQ4g5FN8x1+Gg+3NRaPnRV1ovU9KFqby459OkqwNUSnAFwKuUeBgM0hUaSYksxP4\nZBsDF3J6tuWJ/0Cq9wgpC5QEUv1ubfYeoEr+EZt5QPs9YzRn5W/wp34YeD7FVC57\nTCeJ826gy9aw8ndYfx861MJnmcNXv6S2RdEOOOXhEoilevMh/g6LenvBZQ6gcHRS\n8VPq0R3i6I8="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-p09.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p09.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p09.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p09.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p09.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p09.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p09.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-p09.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-p09.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-p09.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://adfs2.fontys.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs2.fontys.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-12-11T11:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/21e7ca4dead72cd88930d6972611baac",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Fontys Hogescholen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Fontys Hogescholen"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/fontys.png",
                    "height": "57",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "75"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Fontys Hogescholen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Fontys Hogescholen"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Fontys Hogescholen"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://fontys.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Fontys Hogescholen"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.oregonstate.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "iamteam@oregonstate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IAM Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "iamteam@oregonstate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IAM Team"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Information.SecurityOffice@oregonstate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Office of Information Security"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://login.oregonstate.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.oregonstate.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.oregonstate.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.oregonstate.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUEfvjo0YbOpCuYoilEkORPgg2kOEwDQYJKoZIhvcNAQEF\nBQAwIDEeMBwGA1UEAxMVbG9naW4ub3JlZ29uc3RhdGUuZWR1MB4XDTEyMTAxMjE5\nNDk1NloXDTMyMTAxMjE5NDk1NlowIDEeMBwGA1UEAxMVbG9naW4ub3JlZ29uc3Rh\ndGUuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAg9NvfUSFgi3N\ns7kiPBjUgBB5WOezJo4yGOaOR5H1AiKdbcWz7xXbK47AG8ysj0C1BZV0x7g0G1GI\nSMBn6rWU5nMMOn0/yoICt1aAlgrcCY4FkKnWUBi4H4Qzt16QGFT8hz3/BdD+/G+N\nV59hGEOIdwr5RVV+2ELLobeMEGQ5fyffc0DYvxq55gN7FvtgYWjLzRrLOC+9nhAU\nYlCi8HHyNkSqLVEX/rKBsURQrGUG/D/1EXlRrpA29LxBrcg91iQoRSH/78rs43WH\nVOra3IONWJxClt0wGLvyiGh8/Ty5zZbV4UYwYNeqOhHtFAnyqQ0kSXOqfHNMsCZB\nwcvYFND2ywIDAQABo3EwbzBOBgNVHREERzBFghVsb2dpbi5vcmVnb25zdGF0ZS5l\nZHWGLGh0dHBzOi8vbG9naW4ub3JlZ29uc3RhdGUuZWR1L2lkcC9zaGliYm9sZXRo\nMB0GA1UdDgQWBBSgIqH+urOXUrrM+yCzxSm8v5Jf4TANBgkqhkiG9w0BAQUFAAOC\nAQEANnnFrilv6DoifHhRTOZRtfuJFP/3x10kqrJqyGPd/GAiXiXfO6mEnmOiSlC3\n9K07KbOCt/qsoWoW0QQzZgB36CCyuKi7ZZ4zp5oUzQnqPTNPgdaBkj+mwngQ3hjr\nsxXJdu3UN4dUZ8OyDgTO1I3NsA7VYDewpA/DdfrAdisN0coEW7ppeU7BVHFNxBvS\nyfbBaXLdxVLWOh3nAAha2tXUr0FRbZU3rREOVBPKuamYWmGES7Q2WphbBwfOcghx\nCHcq133UmHyK8LQ6SbbyiTBBQuivbhPELucJzIeUoJ7U089J5huDBQendCNS534D\nHcsvwYzQX/yDdIlusEse97Zcnw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oregonstate.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://is.oregonstate.edu/it-infrastructure/iam/incommon-federation"
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.oregonstate.edu/images/osu-logo.png",
                    "lang": "en",
                    "height": "54",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "177"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Oregon State University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Oregon State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oregonstate.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Oregon State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://openathens.rave.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pho"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:a.pho@rave.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ann"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ahmad"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.ahmad@rave.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mario"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://openathens.rave.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-09-16T14:03:22Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://openathens.rave.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://openathens.rave.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rave.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIIGb+QLd2Xcf4wDQYJKoZIhvcNAQEFBQAwNzEVMBMGA1UE\n\t\t\t\t\t\tCgwMUmF2ZW5zYm91cm5lMR4wHAYDVQQDDBVvcGVuYXRoZW5zLnJhdmUuYWMudWsw\n\t\t\t\t\t\tHhcNMTMwNzIyMTYxMzA5WhcNMjMwNzIyMTYxMzA5WjA3MRUwEwYDVQQKDAxSYXZl\n\t\t\t\t\t\tbnNib3VybmUxHjAcBgNVBAMMFW9wZW5hdGhlbnMucmF2ZS5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM4X5KvF9EBh9l7DqAvG93KVmReRhEcW\n\t\t\t\t\t\tG8I9i8Uv+b5lFLQs6bWQBXp9hpEC+/AmlkP5NoI7SaDBXvCxu2PT7h2Gb0sM0IpF\n\t\t\t\t\t\tZCsWKpcAsJV0RVEaoCGXX95xBko/lyS3CAIRIs1QkUwx1PS9SV5SHif8AKDOWCxT\n\t\t\t\t\t\tykDNxeF3Sk8iQXBTsJ/soYm6qK7r44h+wqCxyAfStJC7IHbtziL1/XGY2LeZ4GZw\n\t\t\t\t\t\t0LeJmhnLdcZCnUrej/M6wQ6i9TlghMuLj+7XyW/wipOy+k7fr+vXvHwBItn3/Kii\n\t\t\t\t\t\t8aZ8NQMF5D6azrfiKhgEXGWHMPaqkKNYr7QVZpazA2pxE4tE53WkPH8CAwEAAaNQ\n\t\t\t\t\t\tME4wHQYDVR0OBBYEFMmSda3XmZAaZrHLPwDl/UJh7lCRMB8GA1UdIwQYMBaAFMmS\n\t\t\t\t\t\tda3XmZAaZrHLPwDl/UJh7lCRMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBACuMYIy6+tNV2P6o4SspyHtXfbml23xkuN/aFw2xNfCXI6I5vn/dU9PG9Geu\n\t\t\t\t\t\tECffsJck1qObzQXGXJX6B0vUFJxlF7c5qbF+CUyuxe243WVeAA9NSHo7XLqrHMUG\n\t\t\t\t\t\t8czKxdEynFvBsUE+8cwQ7K4jJfZC18BY8sGLDJFpENNMHxZAJdbyKbnDE3EbPN4e\n\t\t\t\t\t\tJeKhksTpDBV97dUf2Dd2AzFiJyOqTBDKKPM5Afl9SHD6+IDUEDxoclh3Jgyhc4wN\n\t\t\t\t\t\t8e1dIz+XZxix7ez2AMOrvFWbbKWn2XHfcNxnML9J7yu65sjsNrlGahBitwhyrCNE\n\t\t\t\t\t\t8Toby2o89ob4jbDqMjyd5yapsXs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIIGb+QLd2Xcf4wDQYJKoZIhvcNAQEFBQAwNzEVMBMGA1UE\n\t\t\t\t\t\tCgwMUmF2ZW5zYm91cm5lMR4wHAYDVQQDDBVvcGVuYXRoZW5zLnJhdmUuYWMudWsw\n\t\t\t\t\t\tHhcNMTMwNzIyMTYxMzA5WhcNMjMwNzIyMTYxMzA5WjA3MRUwEwYDVQQKDAxSYXZl\n\t\t\t\t\t\tbnNib3VybmUxHjAcBgNVBAMMFW9wZW5hdGhlbnMucmF2ZS5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM4X5KvF9EBh9l7DqAvG93KVmReRhEcW\n\t\t\t\t\t\tG8I9i8Uv+b5lFLQs6bWQBXp9hpEC+/AmlkP5NoI7SaDBXvCxu2PT7h2Gb0sM0IpF\n\t\t\t\t\t\tZCsWKpcAsJV0RVEaoCGXX95xBko/lyS3CAIRIs1QkUwx1PS9SV5SHif8AKDOWCxT\n\t\t\t\t\t\tykDNxeF3Sk8iQXBTsJ/soYm6qK7r44h+wqCxyAfStJC7IHbtziL1/XGY2LeZ4GZw\n\t\t\t\t\t\t0LeJmhnLdcZCnUrej/M6wQ6i9TlghMuLj+7XyW/wipOy+k7fr+vXvHwBItn3/Kii\n\t\t\t\t\t\t8aZ8NQMF5D6azrfiKhgEXGWHMPaqkKNYr7QVZpazA2pxE4tE53WkPH8CAwEAAaNQ\n\t\t\t\t\t\tME4wHQYDVR0OBBYEFMmSda3XmZAaZrHLPwDl/UJh7lCRMB8GA1UdIwQYMBaAFMmS\n\t\t\t\t\t\tda3XmZAaZrHLPwDl/UJh7lCRMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBACuMYIy6+tNV2P6o4SspyHtXfbml23xkuN/aFw2xNfCXI6I5vn/dU9PG9Geu\n\t\t\t\t\t\tECffsJck1qObzQXGXJX6B0vUFJxlF7c5qbF+CUyuxe243WVeAA9NSHo7XLqrHMUG\n\t\t\t\t\t\t8czKxdEynFvBsUE+8cwQ7K4jJfZC18BY8sGLDJFpENNMHxZAJdbyKbnDE3EbPN4e\n\t\t\t\t\t\tJeKhksTpDBV97dUf2Dd2AzFiJyOqTBDKKPM5Afl9SHD6+IDUEDxoclh3Jgyhc4wN\n\t\t\t\t\t\t8e1dIz+XZxix7ez2AMOrvFWbbKWn2XHfcNxnML9J7yu65sjsNrlGahBitwhyrCNE\n\t\t\t\t\t\t8Toby2o89ob4jbDqMjyd5yapsXs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ravensbourne"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ravensbourne.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ravensbourne"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://bfas.scran.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webadmins@rcahms.gov.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Scran/RCAHMS Web Admins"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webadmins@rcahms.gov.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Scran/RCAHMS Web Admins"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bfas.scran.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-03-14T15:42:43Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Books For All Scotland"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.booksforallscotland.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Scran Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.scran.ac.uk/bfas/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.scran.ac.uk/bfas/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.scran.ac.uk/bfas/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.scran.ac.uk/bfas/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.scran.ac.uk/bfas/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.scran.ac.uk/bfas/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.scran.ac.uk/bfas/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.scran.ac.uk/bfas/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.scran.ac.uk/bfas/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.scran.ac.uk/bfas/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Books for All Scotland provides accessible books to support pupils who have difficulty with ordinary printed text."
                  }
                ],
                "logo": [
                  {
                    "text": "https://shib.scran.ac.uk/images/logo-bfas.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "180"
                  },
                  {
                    "text": "https://shib.scran.ac.uk/images/icon-bfas.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Books for All Scotland"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.scran.ac.uk/bfas/Shibboleth.sso/DS/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.scran.ac.uk/bfas/Shibboleth.sso/DS/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.scran.ac.uk/bfas/Shibboleth.sso/WAYF/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.scran.ac.uk/bfas/Shibboleth.sso/glow",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib.scran.ac.uk/bfas/Shibboleth.sso/DS/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shib.scran.ac.uk/bfas/Shibboleth.sso/DS/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib.scran.ac.uk/bfas/Shibboleth.sso/WAYF/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib.scran.ac.uk/bfas/Shibboleth.sso/glow",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEpzCCA4+gAwIBAgIJAJr9uyuwy/Y2MA0GCSqGSIb3DQEBBQUAMIGTMQswCQYD\n\t\t\t\t\tVQQGEwJHQjERMA8GA1UECBMIU2NvdGxhbmQxEjAQBgNVBAcTCUVkaW5idXJnaDEP\n\t\t\t\t\tMA0GA1UEChMGUkNBSE1TMQ4wDAYDVQQLEwVTY3JhbjEWMBQGA1UEAwwNKi5zY3Jh\n\t\t\t\t\tbi5hYy51azEkMCIGCSqGSIb3DQEJARYVd2ViYWRtaW5zQHNjcmFuLmFjLnVrMB4X\n\t\t\t\t\tDTEwMDIyMjExNDU1OVoXDTIwMDIyMDExNDU1OVowgZMxCzAJBgNVBAYTAkdCMREw\n\t\t\t\t\tDwYDVQQIEwhTY290bGFuZDESMBAGA1UEBxMJRWRpbmJ1cmdoMQ8wDQYDVQQKEwZS\n\t\t\t\t\tQ0FITVMxDjAMBgNVBAsTBVNjcmFuMRYwFAYDVQQDDA0qLnNjcmFuLmFjLnVrMSQw\n\t\t\t\t\tIgYJKoZIhvcNAQkBFhV3ZWJhZG1pbnNAc2NyYW4uYWMudWswggEiMA0GCSqGSIb3\n\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDEywuow7F7KjwlfTa4vj/2QWvtexIy+OO0hWvn\n\t\t\t\t\tSJ8B3goDjqaC7Mv1fNJdxtZMl/kR6ZfMT86Xa2VfK47NOe14jJDgZxN/0lbwsLwb\n\t\t\t\t\tGyyxcZeDg0NCcv/jFKUiH6m2jSLkpSrSTHuUqRUhGpR0wcr3+HZjLZrpHI0FQ5EH\n\t\t\t\t\tcnkhg1fYwZ5Z6vth+0NhZt9HjWLrUtia4Bj0orj0MkUAKlGEBudrPsC/OITO9oUp\n\t\t\t\t\tpXV0PBi0hILJdbgeJXDFhxfcEpCczQlQgdx/KWD6q/6nSOmT9hNGMjkiprn/w/q1\n\t\t\t\t\tSsAMRqSfrWrR6q8hWTkWmNsm/c39bJFuMvkfkiOgvvBVqE3nAgMBAAGjgfswgfgw\n\t\t\t\t\tHQYDVR0OBBYEFG8UIQ7Hc9WHtlS6PKYYP/7RWNcrMIHIBgNVHSMEgcAwgb2AFG8U\n\t\t\t\t\tIQ7Hc9WHtlS6PKYYP/7RWNcroYGZpIGWMIGTMQswCQYDVQQGEwJHQjERMA8GA1UE\n\t\t\t\t\tCBMIU2NvdGxhbmQxEjAQBgNVBAcTCUVkaW5idXJnaDEPMA0GA1UEChMGUkNBSE1T\n\t\t\t\t\tMQ4wDAYDVQQLEwVTY3JhbjEWMBQGA1UEAwwNKi5zY3Jhbi5hYy51azEkMCIGCSqG\n\t\t\t\t\tSIb3DQEJARYVd2ViYWRtaW5zQHNjcmFuLmFjLnVrggkAmv27K7DL9jYwDAYDVR0T\n\t\t\t\t\tBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAWSSnSaVz28lDBISUNRmNJFwKvjo5\n\t\t\t\t\tnC4+WM7h6Tg9QbC/EYNCwkH7bOoEcCJs28jn0EwRfn4GUgc1LFkf9UYc3rJ+mihD\n\t\t\t\t\t+RZDHjaJSZDbQgZI55y8dpuYT8r70rCg+xtq1Iwv0NzcM+Q/3cEeiMlIXY6YFAAA\n\t\t\t\t\tDsp1/4NlItMUs6ZwAyMLjyIlSjIHjTVLI2bRTDlY4nUgZhqz4spvqDtnmq7PERUN\n\t\t\t\t\tLTUxK70J8DSNHEuzC8s+rTfXhsn01ZUKGDQqeFDO3TccF/x8iespeHPJO7uD/klz\n\t\t\t\t\tbjQPf6gJKSkRW/uiwoDLkt/CChMGLGbYpQcx/7RpyzUpN4u4PHLduf03kQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.scran.ac.uk/bfas/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.scran.ac.uk/bfas/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.scran.ac.uk/bfas/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.scran.ac.uk/bfas/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.scran.ac.uk/bfas/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.scran.ac.uk/bfas/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.scran.ac.uk/bfas/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.scran.ac.uk/bfas/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.scran.ac.uk/bfas/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.scran.ac.uk/bfas/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.scran.ac.uk/bfas/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.scran.ac.uk/bfas/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.scran.ac.uk/bfas/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.scran.ac.uk/bfas/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shib.scran.ac.uk/bfas/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shib.scran.ac.uk/bfas/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.scran.ac.uk/bfas/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shib.scran.ac.uk/bfas/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.scran.ac.uk/bfas/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.scran.ac.uk/bfas/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.unb.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dionisio Miziara"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dionisiojr@unb.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.unb.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID1jCCAr4CAQAwDQYJKoZIhvcNAQEFBQAwgbAxJzAlBgNVBAoTHlVOQiAtIFVu\naXZlcnNpZGFkZSBkZSBCcmFzaWxpYTEMMAoGA1UECxMDQ1BEMSAwHgYJKoZIhvcN\nAQkBFhFkaW9uaXNpb2pyQHVuYi5icjERMA8GA1UEBxMIQnJhc2lsaWExGTAXBgNV\nBAgTEERpc3RyaXRvIEZlZGVyYWwxCzAJBgNVBAYTAkJSMRowGAYDVQQDExFzaGli\nYm9sZXRoLnVuYi5icjAeFw0xNDA3MDEyMTUxMjJaFw0xNzA2MzAyMTUxMjJaMIGw\nMScwJQYDVQQKEx5VTkIgLSBVbml2ZXJzaWRhZGUgZGUgQnJhc2lsaWExDDAKBgNV\nBAsTA0NQRDEgMB4GCSqGSIb3DQEJARYRZGlvbmlzaW9qckB1bmIuYnIxETAPBgNV\nBAcTCEJyYXNpbGlhMRkwFwYDVQQIExBEaXN0cml0byBGZWRlcmFsMQswCQYDVQQG\nEwJCUjEaMBgGA1UEAxMRc2hpYmJvbGV0aC51bmIuYnIwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQDzc4RTYqDqObR8seN1H6eMRfhielgf2cd7of8T2n9h\nLZV6lakR193gP0qRj+SaZUNaDwoiPoDs4jH8C8a901DmE6QoTMDjg6LL+97swZb4\nlCsZRs5V4qIRNjQZ6nF3rgsEs/oNONQwTq0AQKIorYG5zC4oibwwwjYFan7oOszi\nMeohgrdZWl/bhlsEwWOlDaOpKlFxXYtHXskOSbf+3fvZvJArgq5S7PNuG1oBxvuJ\nXi5AzjHABYt3CziIawUtMS1dWojrnC+64WN3gf3ninVTt4k+xbqn2gZujdoAR/yn\n6JUYi3PZRU77H6xjCag+3+1kuKBx0EBFFdr85ZF8mauHAgMBAAEwDQYJKoZIhvcN\nAQEFBQADggEBAIW2/04fVCKbAv0BKaTdhj8HIG++0nmdA9PsDECgFyURwoh8M2nY\nrkViEKpFdl0s9+8wtj/cGhYVWru0g8Qm1Uo27pXElYIPgU4hm3988VopipwDT2DY\nxsxk+MdoP6KTRtSNJNKFMbuPYj/jr7n7MFJYiWgvOvZ/n/o4RSRHrGhOYVuYNeyn\n/ejprsKScl7RnhMg5dtMXt9qeGgIWW/heVImJJzDURNdsF4sDHD4qKhf3pDNRhHn\n99zu7PASZZerAxI9xXpDiD+of+jaX+uI2/zzap1sMVtlaInMICk/Sa1CL2tBGzY8\nMSmJeH91lUYBcieZYDOgno6WAgr1VoZ8Baw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unb.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.unb.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.unb.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.unb.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.unb.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.unb.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.unb.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.unb.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.unb.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unb.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unb.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unb.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNB - Universidade de Brasilia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNB - Universidade de Brasilia"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNB - Universidade de Brasilia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNB - Universidade de Brasilia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID1jCCAr4CAQAwDQYJKoZIhvcNAQEFBQAwgbAxJzAlBgNVBAoTHlVOQiAtIFVu\naXZlcnNpZGFkZSBkZSBCcmFzaWxpYTEMMAoGA1UECxMDQ1BEMSAwHgYJKoZIhvcN\nAQkBFhFkaW9uaXNpb2pyQHVuYi5icjERMA8GA1UEBxMIQnJhc2lsaWExGTAXBgNV\nBAgTEERpc3RyaXRvIEZlZGVyYWwxCzAJBgNVBAYTAkJSMRowGAYDVQQDExFzaGli\nYm9sZXRoLnVuYi5icjAeFw0xNDA3MDEyMTUxMjJaFw0xNzA2MzAyMTUxMjJaMIGw\nMScwJQYDVQQKEx5VTkIgLSBVbml2ZXJzaWRhZGUgZGUgQnJhc2lsaWExDDAKBgNV\nBAsTA0NQRDEgMB4GCSqGSIb3DQEJARYRZGlvbmlzaW9qckB1bmIuYnIxETAPBgNV\nBAcTCEJyYXNpbGlhMRkwFwYDVQQIExBEaXN0cml0byBGZWRlcmFsMQswCQYDVQQG\nEwJCUjEaMBgGA1UEAxMRc2hpYmJvbGV0aC51bmIuYnIwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQDzc4RTYqDqObR8seN1H6eMRfhielgf2cd7of8T2n9h\nLZV6lakR193gP0qRj+SaZUNaDwoiPoDs4jH8C8a901DmE6QoTMDjg6LL+97swZb4\nlCsZRs5V4qIRNjQZ6nF3rgsEs/oNONQwTq0AQKIorYG5zC4oibwwwjYFan7oOszi\nMeohgrdZWl/bhlsEwWOlDaOpKlFxXYtHXskOSbf+3fvZvJArgq5S7PNuG1oBxvuJ\nXi5AzjHABYt3CziIawUtMS1dWojrnC+64WN3gf3ninVTt4k+xbqn2gZujdoAR/yn\n6JUYi3PZRU77H6xjCag+3+1kuKBx0EBFFdr85ZF8mauHAgMBAAEwDQYJKoZIhvcN\nAQEFBQADggEBAIW2/04fVCKbAv0BKaTdhj8HIG++0nmdA9PsDECgFyURwoh8M2nY\nrkViEKpFdl0s9+8wtj/cGhYVWru0g8Qm1Uo27pXElYIPgU4hm3988VopipwDT2DY\nxsxk+MdoP6KTRtSNJNKFMbuPYj/jr7n7MFJYiWgvOvZ/n/o4RSRHrGhOYVuYNeyn\n/ejprsKScl7RnhMg5dtMXt9qeGgIWW/heVImJJzDURNdsF4sDHD4qKhf3pDNRhHn\n99zu7PASZZerAxI9xXpDiD+of+jaX+uI2/zzap1sMVtlaInMICk/Sa1CL2tBGzY8\nMSmJeH91lUYBcieZYDOgno6WAgr1VoZ8Baw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNB - Universidade de Brasilia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNB - Universidade de Brasilia"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unb.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unb.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNB - Universidade de Brasilia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNB - Universidade de Brasilia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.brightonsu.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.brightonsu.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-09-14T10:33:25Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Brighton Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.brightonsu.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.brightonsu.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.brightonsu.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.brightonsu.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.brightonsu.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.brightonsu.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.brightonsu.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.brightonsu.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.brightonsu.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.brightonsu.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.brightonsu.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.brightonsu.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.brightonsu.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.brightonsu.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cern.ch/login",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Service Desk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:service-desk@cern.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CERN"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Service Desk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:service-desk@cern.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CERN"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "computer.security@cern.ch"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Romain.Wartel@cern.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CERN Computer Security"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://cern.ch/login",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2014-07-29T13:17:52Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "friendly_name": "swissEduPersonHomeOrganization",
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "cern.ch"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:2.16.756.1.2.5.1.1.4",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "friendly_name": "swissEduPersonHomeOrganizationType",
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "others"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:2.16.756.1.2.5.1.1.5",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://refeds.org/sirtfi"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oasis:names:tc:SAML:attribute:assurance-certification",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.cern.ch/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.cern.ch/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.cern.ch/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.cern.ch/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cern.ch"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.cern.ch"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CERN Identity Provider"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAABPElEQVR42pVT21HDQAx0B5RACSkB25N/SqAEPs+ZfFACJaSElOAPrHwxQwmUkBKMdk+S5YRk4GYuj9NqT7vSNY2tbfl8aMvptRtk1D3/dTO5Kx+bbpi+mVzkGWT9Xh7bMr0bcMRZkxZyeIYPJPeDHDxYKwGhkeK7yLkd5C0IlJgEOATIAyBS8Fe3Oz1leUY2I1b/R/kK1rJ5M8gM0FwsVNUXORqeO0pZdMk537zSrOeUqt64LysCApz1JoHMRjCGZy7BAOMtAvNqbnfTC36HoTQNTt8h4K2Qp3G0Fl7Ak9QyLQ0GeWvSouNaJeMmk2Q6B8sQ8UADTgSgbpJbzIlXBmb3OXmqL/c79z37cNWprMmGJN4DNNeRrlNJbJrIMGnlOCqx0fXtmtmxO92K5DDpt46k4ftX8vKQ8Lgq5geGpVRM3R4TeQAAAABJRU5ErkJggg==",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CERN"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "cern.ch"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:46.23304,6.05528"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "128.141.0.0/16"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIIEjCCBfqgAwIBAgIKLYgjvQAAAAAAMDANBgkqhkiG9w0BAQsFADBRMRIwEAYK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\njdU9lus1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "extension_attributes": {
        "{http://www.w3.org/2001/XMLSchema-instance}schemaLocation": "urn:oasis:names:tc:SAML:2.0:metadata saml-schema-metadata-2.0.xsd urn:mace:shibboleth:metadata:1.0 shibboleth-metadata-1.0.xsd http://www.w3.org/2000/09/xmldsig# xmldsig-core-schema.xsd"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CERN"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cern.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "cern.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.cern.ch/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.cern.ch/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.cern.ch"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CERN Service Provider Proxy"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAABPElEQVR42pVT21HDQAx0B5RACSkB25N/SqAEPs+ZfFACJaSElOAPrHwxQwmUkBKMdk+S5YRk4GYuj9NqT7vSNY2tbfl8aMvptRtk1D3/dTO5Kx+bbpi+mVzkGWT9Xh7bMr0bcMRZkxZyeIYPJPeDHDxYKwGhkeK7yLkd5C0IlJgEOATIAyBS8Fe3Oz1leUY2I1b/R/kK1rJ5M8gM0FwsVNUXORqeO0pZdMk537zSrOeUqt64LysCApz1JoHMRjCGZy7BAOMtAvNqbnfTC36HoTQNTt8h4K2Qp3G0Fl7Ak9QyLQ0GeWvSouNaJeMmk2Q6B8sQ8UADTgSgbpJbzIlXBmb3OXmqL/c79z37cNWprMmGJN4DNNeRrlNJbJrIMGnlOCqx0fXtmtmxO92K5DDpt46k4ftX8vKQ8Lgq5geGpVRM3R4TeQAAAABJRU5ErkJggg==",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CERN Service Provider Proxy"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIIEjCCBfqgAwIBAgIKLYgjvQAAAAAAMDANBgkqhkiG9w0BAQsFADBRMRIwEAYK\nCZImiZPyLGQBGRYCY2gxFDASBgoJkiaJk/IsZAEZFgRjZXJuMSUwIwYDVQQDExxD\nRVJOIENlcnRpZmljYXRpb24gQXV0aG9yaXR5MB4XDTEzMTEwODA4Mzg1NVoXDTIz\nMDcyOTA5MTkzOFowVjESMBAGCgmSJomT8ixkARkWAmNoMRQwEgYKCZImiZPyLGQB\nGRYEY2VybjESMBAGA1UECxMJY29tcHV0ZXJzMRYwFAYDVQQDEw1sb2dpbi5jZXJu\nLmNoMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAp6t1C0SGlLddL2M+\nltffGioTnDT3eztOxlA9bAGuvB8/Rjym8en6+ET9boM02CyoR5Vpn8iElXVWccAE\nxPIQEq70D6LPe86vb+tYhuKPeLfuICN9Z0SMQ4f+57vk61Co1/uw/8kPvXlyd+Ai\n8Dsn/G0hpH67bBI9VOQKfpJqclcSJuSlUB5PJffvMUpr29B0eRx8LKFnIHbDILSu\n6nVbFLcadtWIjbYvoKorXg3J6urtkz+zEDeYMTvA6ZGOFf/Xy5eGtroSq9csSC97\n6tx+umKEPhXBA9AcpiCV9Cj5axN03Aaa+iTE36jpnjcd9d02dy5Q9jE2nUN6KXnB\n6qF6eQIDAQABo4ID5TCCA+EwPQYJKwYBBAGCNxUHBDAwLgYmKwYBBAGCNxUIg73Q\nCYLtjQ2G7Ysrgd71N4WA0GIehd2yb4Wu9TkCAWQCARkwHQYDVR0lBBYwFAYIKwYB\nBQUHAwIGCCsGAQUFBwMBMA4GA1UdDwEB/wQEAwIFoDBoBgNVHSAEYTBfMF0GCisG\nAQQBYAoEAQEwTzBNBggrBgEFBQcCARZBaHR0cDovL2NhLWRvY3MuY2Vybi5jaC9j\nYS1kb2NzL2NwLWNwcy9jZXJuLXRydXN0ZWQtY2EyLWNwLWNwcy5wZGYwJwYJKwYB\nBAGCNxUKBBowGDAKBggrBgEFBQcDAjAKBggrBgEFBQcDATAdBgNVHQ4EFgQUqtJc\nwUXasyM6sRaO5nCMFoFDenMwGAYDVR0RBBEwD4INbG9naW4uY2Vybi5jaDAfBgNV\nHSMEGDAWgBQdkBnqyM7MPI0UsUzZ7BTiYUADYTCCASoGA1UdHwSCASEwggEdMIIB\nGaCCARWgggERhkdodHRwOi8vY2FmaWxlcy5jZXJuLmNoL2NhZmlsZXMvY3JsL0NF\nUk4lMjBDZXJ0aWZpY2F0aW9uJTIwQXV0aG9yaXR5LmNybIaBxWxkYXA6Ly8vQ049\nQ0VSTiUyMENlcnRpZmljYXRpb24lMjBBdXRob3JpdHksQ049Q0VSTlBLSTA3LENO\nPUNEUCxDTj1QdWJsaWMlMjBLZXklMjBTZXJ2aWNlcyxDTj1TZXJ2aWNlcyxDTj1D\nb25maWd1cmF0aW9uLERDPWNlcm4sREM9Y2g/Y2VydGlmaWNhdGVSZXZvY2F0aW9u\nTGlzdD9iYXNlP29iamVjdENsYXNzPWNSTERpc3RyaWJ1dGlvblBvaW50MIIBVAYI\nKwYBBQUHAQEEggFGMIIBQjBcBggrBgEFBQcwAoZQaHR0cDovL2NhZmlsZXMuY2Vy\nbi5jaC9jYWZpbGVzL2NlcnRpZmljYXRlcy9DRVJOJTIwQ2VydGlmaWNhdGlvbiUy\nMEF1dGhvcml0eS5jcnQwgbsGCCsGAQUFBzAChoGubGRhcDovLy9DTj1DRVJOJTIw\nQ2VydGlmaWNhdGlvbiUyMEF1dGhvcml0eSxDTj1BSUEsQ049UHVibGljJTIwS2V5\nJTIwU2VydmljZXMsQ049U2VydmljZXMsQ049Q29uZmlndXJhdGlvbixEQz1jZXJu\nLERDPWNoP2NBQ2VydGlmaWNhdGU/YmFzZT9vYmplY3RDbGFzcz1jZXJ0aWZpY2F0\naW9uQXV0aG9yaXR5MCQGCCsGAQUFBzABhhhodHRwOi8vb2NzcC5jZXJuLmNoL29j\nc3AwDQYJKoZIhvcNAQELBQADggIBAGKZ3bknTCfNuh4TMaL3PuvBFjU8LQ5NKY9G\nLZvY2ibYMRk5Is6eWRgyUsy1UJRQdaQQPnnysqrGq8VRw/NIFotBBsA978/+jj7v\n4e5Kr4o8HvwAQNLBxNmF6XkDytpLL701FcNEGRqIsoIhNzihi2VBADLC9HxljEyP\nT52IR767TMk/+xTOqClceq3sq6WRD4m+xaWRUJyOhn+Pqr+wbhXIw4wzHC6X0hcL\nj8P9Povtm6VmKkN9JPuymMo/0+zSrUt2+TYfmbbEKYJSP0+sceQ76IKxxmSdKAr1\nqDNE8v+c3DvPM2PKmfivwaV2l44FdP8ulzqTgphkYcN1daa9Oc+qJeyu/eL7xWzk\n6Zq5R+jVrMlM0p1y2XczI7Hoc96TMOcbVnwgMcVqRM9p57VItn6XubYPR0C33i1y\nUZjkWbIfqEjq6Vev6lVgngOyzu+hqC/8SDyORA3dlF9aZOD13kPZdF/JRphHREQt\naRydAiYRlE/WHTvOcY52jujDftUR6oY0eWaWkwSHbX+kDFx8IlR8UtQCUgkGHBGw\nnOYLIGu7SRDGSfOBOiVhxKoHWVk/pL6eKY2SkmyOmmgO4JnQGg95qeAOMG/EQZt/\n2x8GAavUqGvYy9dPFwFf08678hQqkjNSuex7UD0ku8OP1QKvpP44l6vZhFc6A5Xq\njdU9lus1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.cern.ch/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.cern.ch/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "error_url": "http://cern.ch/serviceportal",
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CERN Service Provider Proxy"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "CERN Service Provider Proxy"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "swissEduPersonHomeOrganization",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.756.1.2.5.1.1.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "swissEduPersonHomeOrganizationType",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.756.1.2.5.1.1.5",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "swissEduPersonUniqueID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.756.1.2.5.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "commonName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganizationType",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://docuwiki-magic.cesnet.cz/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Prochazka"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "michalp@ics.muni.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michal"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://docuwiki-magic.cesnet.cz/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2016-02-03T19:28:02Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/sp-group/aa.cesnet.cz"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CESNET"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CESNET"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ces.net/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cesnet.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CESNET, a. l. e."
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CESNET, z. s. p. o."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://docuwiki-magic.cesnet.cz/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://docuwiki-magic.cesnet.cz/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://docuwiki-magic.cesnet.cz/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://docuwiki-magic.cesnet.cz/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://docuwiki-magic.cesnet.cz/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://docuwiki-magic.cesnet.cz/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://docuwiki-magic.cesnet.cz/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://docuwiki-magic.cesnet.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Dokuwiki instance for MAGIC attribute aggregation pilot"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Instance Dokuwiki pro pilot MAGICke atributuove agregace"
                  }
                ],
                "display_name": [
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Dokuwiki pro pilot projektu MAGIC"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Dokuwiki for MAGIC project pilot"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "docuwiki-magic.cesnet.cz"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFXTCCBEWgAwIBAgIQDysT+01XZjlPVKOpa3gTtjANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMzAeFw0xNjAxMjcwMDAwMDBaFw0xOTAxMzExMjAwMDBaMIGbMQswCQYDVQQG\nEwJDWjEdMBsGA1UECAwUSGxhdm7DrSBtxJtzdG8gUHJhaGExEDAOBgNVBAcTB1By\nYWhhIDYxODA2BgNVBAoML0NFU05FVCwgesOham1vdsOpIHNkcnXFvmVuw60gcHLD\noXZuaWNrw71jaCBvc29iMSEwHwYDVQQDExhkb2N1d2lraS1tYWdpYy5jZXNuZXQu\nY3owggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDFBSpLUudZ2y+IlVGC\ni92hyUDJxmzlbG9JX4aj12jGBdecuS5djc+nlmNmlRHmxq+MrJqpud552TCLtZ1/\n461rX/+e2aTQx2hLHtgwl9rbLlaUNdn2jsVEeAK8BTttPQtxEO74+Ugz1BcN0brI\niWPCHqjx13XcH6P0JLwgyC6SBCww8fFVy6OE5Q4EpzisBQP3f6BPSGZSvCCsXdTg\nSTccH0EG29DNcg1p9Fqu58pa3k3cTibmghg7aPFyIjgvNLjS+dr7mavGbJW/Z6cS\nfGRSilyFdVRBIg5k//LtxCtL6qdkZEiD1BZLzJbzPX7eh9HjNnzOqhaN8oVlBFO1\nxHexAgMBAAGjggHRMIIBzTAfBgNVHSMEGDAWgBRn/YggFCeYxwnSJRm76VERY3VQ\nYjAdBgNVHQ4EFgQUNiQHbvI3oHdzWmLxW4w/fCpId3swIwYDVR0RBBwwGoIYZG9j\ndXdpa2ktbWFnaWMuY2VzbmV0LmN6MA4GA1UdDwEB/wQEAwIFoDAdBgNVHSUEFjAU\nBggrBgEFBQcDAQYIKwYBBQUHAwIwawYDVR0fBGQwYjAvoC2gK4YpaHR0cDovL2Ny\nbDMuZGlnaWNlcnQuY29tL1RFUkVOQVNTTENBMy5jcmwwL6AtoCuGKWh0dHA6Ly9j\ncmw0LmRpZ2ljZXJ0LmNvbS9URVJFTkFTU0xDQTMuY3JsMEwGA1UdIARFMEMwNwYJ\nYIZIAYb9bAEBMCowKAYIKwYBBQUHAgEWHGh0dHBzOi8vd3d3LmRpZ2ljZXJ0LmNv\nbS9DUFMwCAYGZ4EMAQICMG4GCCsGAQUFBwEBBGIwYDAkBggrBgEFBQcwAYYYaHR0\ncDovL29jc3AuZGlnaWNlcnQuY29tMDgGCCsGAQUFBzAChixodHRwOi8vY2FjZXJ0\ncy5kaWdpY2VydC5jb20vVEVSRU5BU1NMQ0EzLmNydDAMBgNVHRMBAf8EAjAAMA0G\nCSqGSIb3DQEBCwUAA4IBAQBhHMYGEdhvbI/1qfhVeYm/SwwtyyxQiSv80XTnC9Gk\nh2YRTdGOM8h8zmFPRXxNVh5+HT4oMEYjyI1nB8460SHPVsy9XE0657q8rdiPZ/e2\nciR6kid8N60CRETBIomlvAUVPLePQYh4Ofcqa+mhqdlHUSLcCjdIWYz8ik9vA943\n4gM0wuhmRop8Cbcs3Rn2iT7etMa0UsLKbk9w7K1BxJaciDtr82VfHC+RSl45mKpT\npCiIRcBJVxaYQzySij8leaW6bv6TRa5WaDFYutM4EzGesF8HypMt+gejv3VtIggP\nWaTpvT6YRO1tysfkruFzBedsRBXhzMS4O1YKRiDiNsBr"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=docuwiki-magic.cesnet.cz,O=CESNET, z\\xC3\\xA1jmov\\xC3\\xA9 sdru\\xC5\\xBEen\\xC3\\xAD pr\\xC3\\xA1vnick\\xC3\\xBDch osob,L=Praha 6,ST=Hlavn\\xC3\\xAD m\\xC4\\x9Bsto Praha,C=CZ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://docuwiki-magic.cesnet.cz/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://docuwiki-magic.cesnet.cz/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://docuwiki-magic.cesnet.cz/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://docuwiki-magic.cesnet.cz/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://docuwiki-magic.cesnet.cz/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://docuwiki-magic.cesnet.cz/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://rellias.imodules.com/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rellias@imodules.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Raoul Ellias"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://rellias.imodules.com/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Imodules Software, Inc."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.imodules.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Imodules Software, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://relliascommerce.imodules.com/controls/login/AssertionConsumerService.aspx?sid=1325&gid=1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBDCCAeygAwIBAgIQzEDukSw9R5BHpxVmr1UwFjANBgkqhkiG9w0BAQQFADAX\nMRUwEwYDVQQDEwxpbW9kdWxlcy5jb20wHhcNMTQwNjEwMjExODU3WhcNMzQwNjEw\nMjExODU2WjAXMRUwEwYDVQQDEwxpbW9kdWxlcy5jb20wggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQDC5hlDfEQ7RoqQgtcZjOxN2FdUOMu4MI8hIeydiFDy\n1fT1t1jJHmFF5V4JDGpITIapK2caenljBcGl7CGC+Z6EXID8i0lxc7lLWOOrYkJb\n8PeuVOpbxTZfOxfkC3jf4IfLZPtBfDvWjYtVUPwDCpwLLE/GQzz6HySoMIcWAkQ9\nbPoAIITTRnDpo1f4J6nO81DKx0XjBVIbz6aTsF60pcXQzLJ69KGI5Jkh3DjmNbeq\nEXH6ENtq823q4JGXRrKvCPrTlt+79EI1p+ECSaRUx006raAYHktUTT2KY1oUlsuk\nqVA+LMmhX/+jF1fgOehHEurOiKQp2aGmeV4PnJ8pXKM9AgMBAAGjTDBKMEgGA1Ud\nAQRBMD+AEG94Y5yfOU4e+OzhpzVt1UyhGTAXMRUwEwYDVQQDEwxpbW9kdWxlcy5j\nb22CEMxA7pEsPUeQR6cVZq9VMBYwDQYJKoZIhvcNAQEEBQADggEBAFDDvIjK8eJO\nYjDqnY9DfzUEN6Vp80w3ZLhT/K49/McNbbGkt0bgg45MeJ78IxLdclTIhOEeHACN\nF71+XLb9PjRfISiB37V157w0nKF5MsMYU1dathFrVOzCIxvhERgoD4lMNtwZiKKH\nJ/xYeczpnHz5iFpoiCvsvPTP5sZqAKvf5ovpermVcLyqEPJJHvLHe+TbwdwTuGMS\npF2w1WQGpSgdbcxWWwmwpbeiF5ADI6UTS5txOfG0p8L2RTxgRJ6Nb7lNrelIEcup\n6nWHUla/60ENe+AN9qsqYh1vnknLi7kSMHwvtyzFQDHnXhwhLa9mkpsZVkeLEGsR\nMJlfQnuceWY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "rellias"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "urn:mace:incommon:ucr.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@ucr.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UCR Shibboleth Administrators"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@ucr.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UCR Shibboleth Administrators"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@ucr.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UCR Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:ucr.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.ucr.edu/shibboleth-idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.ucr.edu/shibboleth-idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.ucr.edu/shibboleth-idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.ucr.edu:8443/shibboleth-idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.ucr.edu/shibboleth-idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucr.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of California, Riverside"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEZTCCA02gAwIBAgIJALzIMRTIUwPtMA0GCSqGSIb3DQEBCwUAMIHIMQswCQYD\nVQQGEwJVUzETMBEGA1UECAwKQ2FsaWZvcm5pYTESMBAGA1UEBwwJUml2ZXJzaWRl\nMSswKQYDVQQKDCJVbml2ZXJzaXR5IG9mIENhbGlmb3JuaWEtUml2ZXJzaWRlMSUw\nIwYDVQQLDBxDb21wdXRpbmcgYW5kIENvbW11bmljYXRpb25zMRswGQYDVQQDDBJz\naGliYm9sZXRoLnVjci5lZHUxHzAdBgkqhkiG9w0BCQEWEHNlY3VyaXR5QHVjci5l\nZHUwHhcNMTUwOTA4MjAwNTI5WhcNMzUwOTA4MjAwNTI5WjCByDELMAkGA1UEBhMC\nVVMxEzARBgNVBAgMCkNhbGlmb3JuaWExEjAQBgNVBAcMCVJpdmVyc2lkZTErMCkG\nA1UECgwiVW5pdmVyc2l0eSBvZiBDYWxpZm9ybmlhLVJpdmVyc2lkZTElMCMGA1UE\nCwwcQ29tcHV0aW5nIGFuZCBDb21tdW5pY2F0aW9uczEbMBkGA1UEAwwSc2hpYmJv\nbGV0aC51Y3IuZWR1MR8wHQYJKoZIhvcNAQkBFhBzZWN1cml0eUB1Y3IuZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAyUB1AMri5IiVo6GySiX6rr9m\ncvaeDmJXBAoYKWKKPVYfCVmnEKZT/I57ptat6w93SjdUhH93KLIQxG0VHx2cI6+Y\nDrnPlaws8SxBTjlfrSd7qseJz9lfUVq3ON+ZFev8Oicgr+8dwdTx2ZGD10tGL0gH\nHZKSw9WQg6wRSiEblzsS6xtGhBl6iun8NN5oo1iX64BbWeZYmiuTH7ZBW7iPpZ66\nVoxzJmwLhVRsQoPHoyYSaPsv4sMbxffFWPRq8dbK5EnkNeskxpk5Lrbtluj0hO32\n7ukrQPCVUqmuFupxUHdI4QDvd/ReGNJP5kc+EcH3F1bbHVnIBF+PthgYhZ4m1QID\nAQABo1AwTjAdBgNVHQ4EFgQUMg83lOH2UbhQXQhVkwOmCPeGrkYwHwYDVR0jBBgw\nFoAUMg83lOH2UbhQXQhVkwOmCPeGrkYwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0B\nAQsFAAOCAQEAxQZKevQZ4iWqJEHUDhiB+A4jsbJCkv0CayM98Dppxr2nY/aO7tM2\nknqNV9LPEtIOlJmAVkXKaHKvMHunhx30ZiCP/cyTIamixfC1EkWa+HzYeMbVrGa2\ngSmXzPs40Kgi//xz7NdpzOqeAOTs93bc1t4POxMIW3RhOV4laPo1D8gfnPU++x8P\n/yhF4xmWiZ/ER/cwYhwMW8WyvvRXB8j1z18A9zjMmc14UHxXb9G4lKSqeDeCw0qR\n0pZ4Ba363uq9XWfUjRFlaixqMfE1b2jfjut1FbPLfzLvJ4EblJTkcGNw3DSdLB6w\n//p7tc4jkdSFr1zQgNUxNgjR4gh6fruSSg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of California, Riverside"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ucr.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of California, Riverside"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.univ-paris3.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "fed-admin@univ-paris3.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.univ-paris3.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2011-12-16T22:34:29Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univ-paris3.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univ-paris3.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.univ-paris3.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-paris3.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-paris3.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "All members of the Sorbonne Nouvelle - Paris 3 community: staff, students, library readers, alumni, staff from other institutions working locally, guests, etc."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Tous les membres de la communaut\u00e9 Sorbonne Nouvelle - Paris 3 : personnels, \u00e9tudiants, lecteurs des biblioth\u00e8ques, anciens \u00e9tudiants, personnels d'autres \u00e9tablissements travaillant dans l'universit\u00e9, invit\u00e9s, prestataires, anciens personnels gardant une activit\u00e9."
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University Paris 3 - Sorbonne Nouvelle"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Paris 3 - Sorbonne Nouvelle"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAMSFD1SXsksxsNe7dgs+bu0/1u4hMA0GCSqGSIb3DQEB\nBQUAMB0xGzAZBgNVBAMTEmlkcC51bml2LXBhcmlzMy5mcjAeFw0xMTEyMTUxNzE1\nMTZaFw0zMTEyMTUxNzE1MTZaMB0xGzAZBgNVBAMTEmlkcC51bml2LXBhcmlzMy5m\ncjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJjhxfTL8BVpjd1mzrxA\n7zmEcJk8ekFMaUfPm6HL1ScUyiun5Fm9JJQBHEuCSH/VEPrKLNrxz4lctcWWvCyI\nmDk63MLPCBlEZMV8hiFxZt2/VEo1OsQL5eKVDPNBRIwBK8d8CYw/xOWEaiYOvlZa\n7e5fvjQNti0pwWsdGi5jo029tCFkApIeSidl9p/L6C0NIIR58T6cZvShCIIV1rHi\n4MSEdw2iR7w2YE84ljfooVcRhUDSpxMA+ym7FlH6IJD24w4tRrB/oDyQqLQTzEXB\nyb6RhwrLKUFb3KVBKwrq9uTRpEZWIEpWkgbH4KSsPWEGBGXc6CtKhXtcjRFMNuu4\nhXcCAwEAAaNrMGkwSAYDVR0RBEEwP4ISaWRwLnVuaXYtcGFyaXMzLmZyhilodHRw\nczovL2lkcC51bml2LXBhcmlzMy5mci9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\nJ54xxsuDg3aueO3Q3HHJvMzmqUUwDQYJKoZIhvcNAQEFBQADggEBAI+TkGwGCEWZ\nuthkU8kUaUwop79gqH2yBzSw0OOkRZ3Q3OPg8Qv/s7zD+46gv1b5/YbbzYfvViEq\nS9TthYeos4lqSZJTMPIMnbcF8TX0dCtJ/IKy9JNxEetKzSHWdWgkkm/93onk1gPo\nK0JNyD1AlCipNrHSnNmYkDYUjNzuC2ltXFmqrzBYD4NxkZzXhcnrqd5zxKdI6tQy\nIBbAxUnoEmbTqImHVmF229LIlNphqKpuduDhOtSs+Szd2ZoooyRaSTu9SVMplJ4Y\nbZMYCQGSG0R+xeFXPOJHMRl0brK4iwveaUGTXC2yg8W/wLm9f4MVOKKRKrMTYHGY\nHKtGROgixJI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Paris 3 - Sorbonne Nouvelle"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-paris3.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Paris 3 - Sorbonne Nouvelle"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.colchsfc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.colchsfc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/colchsfc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/colchsfc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "colchsfc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Sixth Form College, Colchester"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.colchsfc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.bradfordcollege.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Duffy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:d.duffy@bradfordcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Deborah"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sayed"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:b.sayed@bradfordcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Belal"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.bradfordcollege.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-07-08T11:00:30Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFCjCCA/KgAwIBAgIJALdslILT05qQMA0GCSqGSIb3DQEBBQUAMIGlMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjESMBAGA1UECBMJWW9ya3NoaXJlMREwDwYDVQQHEwhCcmFkZm9yZDEZ\n\t\t\t\t\t\tMBcGA1UEChMQQnJhZGZvcmQgQ29sbGVnZTEpMCcGA1UEAxMgc2hpYmJvbGV0aC5i\n\t\t\t\t\t\tcmFkZm9yZGNvbGxlZ2UuYWMudWsxKTAnBgkqhkiG9w0BCQEWGnJvb3RAYnJhZGZv\n\t\t\t\t\t\tcmRjb2xsZWdlLmFjLnVrMB4XDTEzMTEwODEyMzI1OFoXDTIzMTEwNjEyMzI1OFow\n\t\t\t\t\t\tgaUxCzAJBgNVBAYTAkdCMRIwEAYDVQQIEwlZb3Jrc2hpcmUxETAPBgNVBAcTCEJy\n\t\t\t\t\t\tYWRmb3JkMRkwFwYDVQQKExBCcmFkZm9yZCBDb2xsZWdlMSkwJwYDVQQDEyBzaGli\n\t\t\t\t\t\tYm9sZXRoLmJyYWRmb3JkY29sbGVnZS5hYy51azEpMCcGCSqGSIb3DQEJARYacm9v\n\t\t\t\t\t\tdEBicmFkZm9yZGNvbGxlZ2UuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQCwYsDvkLqkCOFTHrZ3Er53jfoqYD9mq8d0KGt6BH/oaEhDf9LVLoTm\n\t\t\t\t\t\tzDgu0dSsDBxCyoIWcyV2snrQ1SjkRRKc7km1Cqlt3X1F7HJwCd9ocJRkWOkJLCyv\n\t\t\t\t\t\to0lMzO9Fv1PcjWHwnJmFQom7WTrZ5bqAOYmvPJF03Mfbg5pQcNXZqSz0F4r7wJpX\n\t\t\t\t\t\t4d0rU+sq2H27TDaIgwWZ2PU8vfLlYshctMv1b8h1wpyBwyLdidtov8yHXRjKuTmL\n\t\t\t\t\t\txYhHESz4j3Ji4bPY5Dry2mG+TVDbI8MKScdYxdIXaI51fwo5JtOv0mT3qAUD+RN+\n\t\t\t\t\t\tTAg7YXpwS6X6dlQqqJDu6AbgDzAImq47AgMBAAGjggE5MIIBNTAJBgNVHRMEAjAA\n\t\t\t\t\t\tMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAd\n\t\t\t\t\t\tBgNVHQ4EFgQUvwyrftHX/bc1Rrx58TEml80zNagwgdoGA1UdIwSB0jCBz4AUvwyr\n\t\t\t\t\t\tftHX/bc1Rrx58TEml80zNaihgaukgagwgaUxCzAJBgNVBAYTAkdCMRIwEAYDVQQI\n\t\t\t\t\t\tEwlZb3Jrc2hpcmUxETAPBgNVBAcTCEJyYWRmb3JkMRkwFwYDVQQKExBCcmFkZm9y\n\t\t\t\t\t\tZCBDb2xsZWdlMSkwJwYDVQQDEyBzaGliYm9sZXRoLmJyYWRmb3JkY29sbGVnZS5h\n\t\t\t\t\t\tYy51azEpMCcGCSqGSIb3DQEJARYacm9vdEBicmFkZm9yZGNvbGxlZ2UuYWMudWuC\n\t\t\t\t\t\tCQC3bJSC09OakDANBgkqhkiG9w0BAQUFAAOCAQEAQMSXezpcwMwJDj1eg9Y/I0gj\n\t\t\t\t\t\tArGP9oZIvPUX7l19e915ndg+eYaiDHNcjf+fMduiTS9SKd0HhGhki0FwLhbf//yX\n\t\t\t\t\t\t0YGKyeBEdV2lz9WjXZelGt45DuMLBtMB2TFWxXizW5KAObNvrtTW2nYQLaZ8LkD4\n\t\t\t\t\t\tyIPqH09eGC1qsTVOeHKlOT58VuXVL/UgKg4Qt09Tve327l1vkIoklaF62AX6cXKF\n\t\t\t\t\t\tKmEMreKHeMMbULtXfw1WAKyLveqxC2P6sm7r5RHmphlssqHzl6ga+5LWQMiQFUG2\n\t\t\t\t\t\tArKpUGwpk16lWUh1A+FJ7KMSP2BUQUp4NBku9sD8LUzMuey2zHMifjx3QxoFcQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bradfordcollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.bradfordcollege.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.bradfordcollege.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.bradfordcollege.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.bradfordcollege.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.bradfordcollege.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.bradfordcollege.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.bradfordcollege.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.bradfordcollege.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bradfordcollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFCjCCA/KgAwIBAgIJALdslILT05qQMA0GCSqGSIb3DQEBBQUAMIGlMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjESMBAGA1UECBMJWW9ya3NoaXJlMREwDwYDVQQHEwhCcmFkZm9yZDEZ\n\t\t\t\t\t\tMBcGA1UEChMQQnJhZGZvcmQgQ29sbGVnZTEpMCcGA1UEAxMgc2hpYmJvbGV0aC5i\n\t\t\t\t\t\tcmFkZm9yZGNvbGxlZ2UuYWMudWsxKTAnBgkqhkiG9w0BCQEWGnJvb3RAYnJhZGZv\n\t\t\t\t\t\tcmRjb2xsZWdlLmFjLnVrMB4XDTEzMTEwODEyMzI1OFoXDTIzMTEwNjEyMzI1OFow\n\t\t\t\t\t\tgaUxCzAJBgNVBAYTAkdCMRIwEAYDVQQIEwlZb3Jrc2hpcmUxETAPBgNVBAcTCEJy\n\t\t\t\t\t\tYWRmb3JkMRkwFwYDVQQKExBCcmFkZm9yZCBDb2xsZWdlMSkwJwYDVQQDEyBzaGli\n\t\t\t\t\t\tYm9sZXRoLmJyYWRmb3JkY29sbGVnZS5hYy51azEpMCcGCSqGSIb3DQEJARYacm9v\n\t\t\t\t\t\tdEBicmFkZm9yZGNvbGxlZ2UuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQCwYsDvkLqkCOFTHrZ3Er53jfoqYD9mq8d0KGt6BH/oaEhDf9LVLoTm\n\t\t\t\t\t\tzDgu0dSsDBxCyoIWcyV2snrQ1SjkRRKc7km1Cqlt3X1F7HJwCd9ocJRkWOkJLCyv\n\t\t\t\t\t\to0lMzO9Fv1PcjWHwnJmFQom7WTrZ5bqAOYmvPJF03Mfbg5pQcNXZqSz0F4r7wJpX\n\t\t\t\t\t\t4d0rU+sq2H27TDaIgwWZ2PU8vfLlYshctMv1b8h1wpyBwyLdidtov8yHXRjKuTmL\n\t\t\t\t\t\txYhHESz4j3Ji4bPY5Dry2mG+TVDbI8MKScdYxdIXaI51fwo5JtOv0mT3qAUD+RN+\n\t\t\t\t\t\tTAg7YXpwS6X6dlQqqJDu6AbgDzAImq47AgMBAAGjggE5MIIBNTAJBgNVHRMEAjAA\n\t\t\t\t\t\tMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAd\n\t\t\t\t\t\tBgNVHQ4EFgQUvwyrftHX/bc1Rrx58TEml80zNagwgdoGA1UdIwSB0jCBz4AUvwyr\n\t\t\t\t\t\tftHX/bc1Rrx58TEml80zNaihgaukgagwgaUxCzAJBgNVBAYTAkdCMRIwEAYDVQQI\n\t\t\t\t\t\tEwlZb3Jrc2hpcmUxETAPBgNVBAcTCEJyYWRmb3JkMRkwFwYDVQQKExBCcmFkZm9y\n\t\t\t\t\t\tZCBDb2xsZWdlMSkwJwYDVQQDEyBzaGliYm9sZXRoLmJyYWRmb3JkY29sbGVnZS5h\n\t\t\t\t\t\tYy51azEpMCcGCSqGSIb3DQEJARYacm9vdEBicmFkZm9yZGNvbGxlZ2UuYWMudWuC\n\t\t\t\t\t\tCQC3bJSC09OakDANBgkqhkiG9w0BAQUFAAOCAQEAQMSXezpcwMwJDj1eg9Y/I0gj\n\t\t\t\t\t\tArGP9oZIvPUX7l19e915ndg+eYaiDHNcjf+fMduiTS9SKd0HhGhki0FwLhbf//yX\n\t\t\t\t\t\t0YGKyeBEdV2lz9WjXZelGt45DuMLBtMB2TFWxXizW5KAObNvrtTW2nYQLaZ8LkD4\n\t\t\t\t\t\tyIPqH09eGC1qsTVOeHKlOT58VuXVL/UgKg4Qt09Tve327l1vkIoklaF62AX6cXKF\n\t\t\t\t\t\tKmEMreKHeMMbULtXfw1WAKyLveqxC2P6sm7r5RHmphlssqHzl6ga+5LWQMiQFUG2\n\t\t\t\t\t\tArKpUGwpk16lWUh1A+FJ7KMSP2BUQUp4NBku9sD8LUzMuey2zHMifjx3QxoFcQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bradford College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bradfordcollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Bradford College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://wayf.card.kilroy.eu/module.php/saml/sp/metadata.php/default-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2014-02-21T12:04:52Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute_value": [
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "kalmar"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "denmark"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "iceland"
              }
            ],
            "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
            "name": "tags",
            "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jesper@accedo.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Webmaster"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://wayf.card.kilroy.eu/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://wayf.card.kilroy.eu/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Form\u00e5let er at verificere at du er studerende."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The purpose is to verify that you are a student."
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ISIC \u2013 Student Verification Service"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ISIC \u2013 Student Verification Service"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wayf.card.kilroy.eu/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://wayf.card.kilroy.eu/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wayf.card.kilroy.eu/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Form\u00e5let er at verificere at du er studerende."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The purpose is to verify that you are a student."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ISIC \u2013 Student Verification Service"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ISIC \u2013 Student Verification Service"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrimaryAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.5",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://rems.elixir-finland.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mustonen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rems@csc.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Timo"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mustonen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rems@csc.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Timo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://rems.elixir-finland.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.csc.fi/english/institutions/haka/instructions/join/eduGAINRegistrationStatement/"
              }
            ],
            "registration_authority": "http://www.csc.fi/haka",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CSC - Tieteen tietotekniikan keskus Oy"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CSC - IT Center for Science Ltd."
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CSC - Tieteen tietotekniikan keskus Oy"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csc.fi"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csc.fi"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csc.fi"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CSC - Tieteen tietotekniikan keskus Oy"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CSC - IT Center for Science Ltd."
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CSC - Tieteen tietotekniikan keskus Oy"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://rems.elixir-finland.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "An ELIXIR service for applying for and managing access rights to datasets in the biomedical sciences."
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ELIXIRin aineistojen k\u00e4ytt\u00f6valtuuksien hallintaj\u00e4rjestelm\u00e4."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://rems.elixir-finland.org/privacy-policy"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://rems.elixir-finland.org/privacy-policy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "REMS ELIXIR"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "REMS ELIXIR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFfDCCBGSgAwIBAgIRAOOPBaozx9H6wmXnbZDrqlYwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDA0MDkwMDAwMDBaFw0xNzA0MDgyMzU5NTlaMEUxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEgMB4GA1UEAxMXcmVtcy5lbGl4\naXItZmlubGFuZC5vcmcwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQDE\nPmEMb9faLtRJlg+4uDV6K9hy3F0rBS/qhD5Gx9+4r3XLUGif6nX+zwErh+nQCqNS\ntujxdFOGALGsM5j6EvUJUyAvgQkoPq/z4GiRymexQeJkg3mQlRJ8rC0eRNfmdMo6\nKwE14GC0Y3aEJnxYbnArBcR2xb5qYM4nXE/2k3Tm6gRHasj2fK2CxbROilD42Dmd\nfj+zPx1kl0qOAZCKfhGNf36nt5VT9Hf39Y0xEBIDKKclAhMm8F9kfy6iDW9wi7yb\n6cNqSgZhe3kJ0SSWidFJVkHbdlxEII5bqlDflEiabxpt1bZk3BCfB66IH+gPOsES\n2wQTIzxeBDn0b++Misf5joU1wP26vhWNV6ZTQWtAqKKg9fXTWyqGGNNGpAZDaO+K\nObS/EucGN7eDHmvLVpaRIN7RZHHbcMR3Irb9GPb7ICApjcrDiugl3tyTlZiznkpW\n5oL5+yZgc7wBGIGLV7r4ZcGFljJ0hq6+TviclrE/0DQVbHe51iM7nAkRlEdVF9Uc\nsliaHiswU1dhul14qXTNGi4dPUIkFW47Hy050O4ZqK9Bx7/WDhqm//oWt7mmNeW9\nQ7or0YK6btf+8IzuuC7GcGzHI8vhB1aV74wiRoHeegDwVpID+k3iWsZpLHYviCz6\nVm6D2XZGznbw31YBJJhEVT/zz0nTv+DFY84ezBmmBwIDAQABo4IBdDCCAXAwHwYD\nVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFNKSOwZ7HEKk\nM5/M4lFidibAuVwcMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1Ud\nJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEB\nAgIdMAgGBmeBDAECATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50\nZXJlbmEub3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYB\nBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0\nMCYGCCsGAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAiBgNVHREE\nGzAZghdyZW1zLmVsaXhpci1maW5sYW5kLm9yZzANBgkqhkiG9w0BAQUFAAOCAQEA\nSGEF/c7aUAjf57SVtsoZqNkrR8YwBEEu99mKvQlvT6qLdIjNdq4bOYsCIHS+MAmv\nnhJyuiMY+Q4FK+jUsX+Emltk7aii37PAMlHSCpgo7OGDK0c6gdg7FYBuWj20HA6n\nFBgU9FD4sHqSKPEDOitsVTb1Vb1PYLYNaLpJnK70WS/vNCK/mZsy4qWeoxSBIUry\nrlnCOtELPe7YWkB3fAbmzI3FVfHrtb73vAJ6hfbOfuzVwfuEAU4U3+V175fktpw5\nRKcIVJFGa06KaJwT75b637GEuqs/YUdjCJU3uDk/eUnxO8ZZvA7gvxNQXAQBQ0oG\nvzJQyIviY90sJo1Cisoynw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://rems.elixir-finland.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "ELIXIRin aineistojen kayttovaltuuksien hallintajarjestelma."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "An ELIXIR service for applying for and managing access rights to datasets in the biomedical sciences."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "REMS ELIXIR"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "REMS ELIXIR"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "cn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganizationType",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idpv3.lu.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Swahn"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:eskil.swahn@ldc.lu.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Eskil"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Silverup"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:johan.silverup@ldc.lu.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Johan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "LU Servicedesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@lu.se"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idpv3.lu.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al2"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oasis:names:tc:SAML:attribute:assurance-certification",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idpv3.lu.se/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idpv3.lu.se/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idpv3.lu.se:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idpv3.lu.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idpv3.lu.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idpv3.lu.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idpv3.lu.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idpv3.lu.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lu.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.lu.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.lunduniversity.lu.se"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lunds universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lund University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identitetstj\u00e4nst f\u00f6r anst\u00e4llda och studenter vid Lunds universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for employees and students at Lund University"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idpv3.lu.se/idp/images/LU_swe_logo_450px.jpg",
                    "lang": "sv",
                    "height": "78",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "450"
                  },
                  {
                    "text": "https://idpv3.lu.se/idp/images/LU_eng_logo_382px.jpg",
                    "lang": "en",
                    "height": "78",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "382"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://lucat.blogg.lu.se/anvandarvillkor-personuppgifter/hantering-av-personuppgifter"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://lucat.blogg.lu.se/anvandarvillkor-personuppgifter/acceptable-use-policy"
                  }
                ]
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "lu.se"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "lth.se"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.235.0.0/16"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUD4RyhLFIuNZ5O77xXaRFLYeZgJAwDQYJKoZIhvcNAQEL\nBQAwFjEUMBIGA1UEAwwLaWRwdjMubHUuc2UwHhcNMTYwMjIyMDc1NDA2WhcNMzYw\nMjIyMDc1NDA2WjAWMRQwEgYDVQQDDAtpZHB2My5sdS5zZTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAJlUtfZBGTW2+XOD2UgwN/KFkrfoyaDrc/CJ9DnG\nrDjHJjlN2Fey7rB3sexvyM6RfLpxkOX7LKcwKBDq3Rjh0IyGUyEjolPls8vlPORz\nWyLGJ/JkXSRYFnOniQxeqfL2Xjo53Hk0yOFUh6gLiRSxla+EueOHwIeXkXhpTYz5\nK8O7lXwmGhS1+kd4HJZFOB8YOYDqaxMHOvcAJH01Khwe6HB0x/0MQ3LTMF0YusHv\nOb+WjFNGZs5qX7KJcQLEhrzgBhyFVLdKX024+JREzMB7AhNrysuh+h9tLC0oUVPF\n0y0Xf+L18dCH92UamqR3IOC7k+hytZ6QqMnKIq8whXzrpeECAwEAAaNdMFswHQYD\nVR0OBBYEFFADTOECG3DC6WFR7tlcnx9pcn0oMDoGA1UdEQQzMDGCC2lkcHYzLmx1\nLnNlhiJodHRwczovL2lkcHYzLmx1LnNlL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3\nDQEBCwUAA4IBAQAKSwpkEGkZmQPyB22U3bSWcI/QpZlOzNvWMaGaFvwmI+Vn4GS7\ngaPW03B7Pnk71MaPnWXzbDOWvKVMhtkNJiZNSldPqwqt2RnR7SS+af2XbQDqJS0n\nWb4jgXaO25MLslWrOIeuUn4nfeO5JrUDialovqlN4Om8rn6JPao4wGEiqts3HeAB\nxCsMdAMr8CrJMoK+1sBIgfIr8nBuIo3SvXAsHd6ts0xYVqgeYM6qPg97qiHytJvU\nRkaCJ5ca0ZutSetcL3mkXdHIl+5S9zhgcs3hOLA6v7Yqsd+lWA8Jqh4wbBXixpGu\ncGOFP9UH1ptYCE+azH3kJ0N00MmrXdZgH323"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAOAJRp4FcZsN0Apk6n6NJRREV+6VMA0GCSqGSIb3DQEB\nCwUAMBYxFDASBgNVBAMMC2lkcHYzLmx1LnNlMB4XDTE2MDIyMjA3NTQwNVoXDTM2\nMDIyMjA3NTQwNVowFjEUMBIGA1UEAwwLaWRwdjMubHUuc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCrPl5u1sQ/6/O9SZFlQHOIxewNK1HpNe9ZSXp+\n91pIlOLiJb16R5rH4KFLzFr6XEghwyNreduL4NSHwnS208rU0UHGnPFK58e4WSUY\n4P5RJSipDAGY1oIIrL4kBrpM50Gwhyxj42xXTq9evG2RsyyeLaPSJePlLtotPt2o\n41RBvW1vzYNcXb7JgSx8s5px6jdtjm+BtWgZtscFomSqSGWFm3/TLo+gntvG4/xT\no1K9zlDuqfbHIMjD0t8wI4BYX3Wd7pXYNf6i0oXtOpS/9Khae4/orA9d1+8xadHM\nXID2Jk0OdvfEeuTbs5AlUyDlvQgc5nUZUVRvKwqtSSv8pbZdAgMBAAGjXTBbMB0G\nA1UdDgQWBBSxffHocHR0RA65Wd8uRplMXh4VFzA6BgNVHREEMzAxggtpZHB2My5s\ndS5zZYYiaHR0cHM6Ly9pZHB2My5sdS5zZS9pZHAvc2hpYmJvbGV0aDANBgkqhkiG\n9w0BAQsFAAOCAQEARk9ha/w5IQs1qKygFTFsCAWkrpAhnOVMeXWCPG+7yzYliCQv\nXX2shOz7RlQpZT+3uyDSWgJ+Z2xdISsThXbDfnMJnU5bbUXSgUy+CYkXjx8lI5b+\nRoLi7bzycPuGIFcOjUzfZxjM5mDxpVUmGP9e3cnosNUAI0iqt34nQwusx+jRZqOi\nHEa8UnjwOtglHEiRxQwyildnenAuXn37ZEe1n9jLiMAzPRFVxIrnuSyalUSyvGc2\n6c9Aozb+3ozGufmWcuVc6wZeZtGdHYRT3N1uVBN2agzRNrlhcuP/gDDjhFHlFMDs\n4YT1j/q6c6UU7MANv5mTzc3hL5MSrvj4CCpVgA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUauI49n1u/B9z1f0b/KUMu1vDD3EwDQYJKoZIhvcNAQEL\nBQAwFjEUMBIGA1UEAwwLaWRwdjMubHUuc2UwHhcNMTYwMjIyMDc1NDA1WhcNMzYw\nMjIyMDc1NDA1WjAWMRQwEgYDVQQDDAtpZHB2My5sdS5zZTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBALNlmrTcOU72uwaA3T0pe1avdrzmjEH+Yq9fhbvz\nJbm8jorNVJot4nLTwXrE8zubuVyndPNYda69SKFW/H2sdsPl6nXiMQv0p3Izw1Ee\nbz4zwWbvSVu7D9ohvwWR5MtV0a5sGkQW8oylyHMS8mwtp+HPEO66D8NDracxZ7/p\nkRobp16SXnsq/jekkFpph5AHsJjRTsX93vB2eFZ5+g2Yx1JloGHuSxQvkgFUktek\nXf2i6NZYj1Vgr21woVvO6YoErrqrfjtD5ul/MlWD7V8BNZA1I89huTLBMqbFtT/R\nq3vjkHiFDgzyiOSrH6KwcYWdJuNHVISHOOYJil8Gl2eYj5UCAwEAAaNdMFswHQYD\nVR0OBBYEFAOF0q/Lew4bO5kzUKLTi4sKfi6PMDoGA1UdEQQzMDGCC2lkcHYzLmx1\nLnNlhiJodHRwczovL2lkcHYzLmx1LnNlL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3\nDQEBCwUAA4IBAQCwGnCjGcIYhmoKwhcyHmEI2npMZ0zUMUjLxcpY8OjJFXGDUi9j\nfJlhja02L7O/kiRdVadhlIqpi5g3aNwoNyVxLbriiToDNIIm0ixrBMGWoUj9WYe6\nrA86XwGeATly1iQu9EVWH+nCBYs+MLogsB9qtA/2vd4nCM9jNGe9+PhC+p84l3nK\n2E3SR1RhRynJzC+hpoO5KARTw9ymeeMt4FM8lFXhL3rbUJq/Dl3deU0U6xCzyPDh\nKE7aiSxYsHeCrgDI13bWgb/5xaYBMwJLDYj/KTIrtThku/WU8kDgEZtjcfCWCMiJ\n9rjFqJ/gXzCEj4IVOIWKvE1TswY/c0hymlJ3"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lunds universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lund University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lu.se/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LU"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://agw-sparknet.utu.fi",
    {
      "entity_id": "https://agw-sparknet.utu.fi",
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Niemi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hakajasen@utu.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mikko"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Niemi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hakajasen@utu.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mikko"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Turun yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Turku"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u00c5bo universitet"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utu.fi/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utu.fi/"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utu.fi/"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Turun yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Turku"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u00c5bo universitet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEczCCA1ugAwIBAgIQOWGPWke4DcPypq61jxi5UzANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDcxMDAwMDAwMFoXDTE3MDcwOTIzNTk1OVowQTEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRwwGgYDVQQDExNhZ3ctc3Bhcmtu\nZXQudXR1LmZpMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvw38LEvp\ndjnLwfGCyajCi1K1HPSphIC7giATYbMuYWQzp1e74nlM7MYm0rM/Czv7KjV2bvqA\nCb0BGylc4JaISlab2ZFw1geHye/x5AF0kpyhVLwOg+zciExR7rNjrj1bVoO6zh+d\nx3LI+8w3stbS6be+fq/VWM/q34+3WGYQY0MY51W6A3Q9CgsOUrj02KNi/mUIrexH\nXuIPSmPe9Iko17DwOaRa4zdaXs67HuzCwXqn4iEsLxLJhb50SJs4ZxpXNY5ICtZg\nMaRhhVDgd8Eb5UfbkNSo5UmhYT31I1dPf3RubXRL3N21FftxRDPuVr//STBV5n1v\n7cHxhNXBVS+ZkQIDAQABo4IBcDCCAWwwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsr\nN1dH6pDjue0wHQYDVR0OBBYEFKQCEfwC/cdgSYAfdae2dUQzjho6MA4GA1UdDwEB\n/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEF\nBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8E\nMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENB\nLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNz\nLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8v\nb2NzcC50Y3MudGVyZW5hLm9yZzAeBgNVHREEFzAVghNhZ3ctc3BhcmtuZXQudXR1\nLmZpMA0GCSqGSIb3DQEBBQUAA4IBAQApc0jVKsilWfjGxVMut0c7nn0tDMh30lGZ\n4PXpc6u8+HY4jGJccPLNEOA9ECqQBnxKcqN+xxvRI/XiiFOS6G/a/MaEPyYhQvcg\nfoDsvA5LzyQyxLmf/yhYQbIBxhb1nVH1NOwsbwJWotYn0A/wFkWVYUGYxILmfu0Z\n8gg0SwCNooAwlQLG0wvbROgDYXqkomPuflWNeDSJl48OsAnRVnspMmqTdc3UFH8E\n+IPl4VMqhboXM0LB9u97ubaAdR+2A3bws+wqC+GbdlUsHOrWV/BqNFcSjznn3Q/r\n6r8ROTllHa97gLvSaSYorIAj0//d8l5k7DU/afiUTXiX4/9rKRDy"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://agw-common.sparknet.fi/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "2",
              "location": "https://agw-common.sparknet.fi/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "false"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Sparknet, Turun yliopiston langaton verkko"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Sparknet, Wireless network of University of Turku"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Turun yliopiston SparkNet"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "University of Turku SparkNet"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://duo.emerson.edu/dag/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Francis_Frain@emerson.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Francis Frain"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "bryce_riner@emerson.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bryce Riner"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://duo.emerson.edu/dag/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://duo.emerson.edu/dag/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://duo.emerson.edu/dag/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "emerson.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Emerson College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEMTCCAxmgAwIBAgIJAKN0/KN2I4U9MA0GCSqGSIb3DQEBBQUAMIGuMQswCQYD\nVQQGEwJVUzEWMBQGA1UECAwNTWFzc2FjaHVzZXR0czEPMA0GA1UEBwwGQm9zdG9u\nMRgwFgYDVQQKDA9FbWVyc29uIENvbGxlZ2UxHzAdBgNVBAsMFkluZm9ybWF0aW9u\nIFRlY2hub2xvZ3kxGjAYBgNVBAMMEWxvZ2luLmVtZXJzb24uZWR1MR8wHQYJKoZI\nhvcNAQkBFhByb290QGVtZXJzb24uZWR1MB4XDTE0MDQwMjE5NDgwOVoXDTI0MDQw\nMTE5NDgwOVowga4xCzAJBgNVBAYTAlVTMRYwFAYDVQQIDA1NYXNzYWNodXNldHRz\nMQ8wDQYDVQQHDAZCb3N0b24xGDAWBgNVBAoMD0VtZXJzb24gQ29sbGVnZTEfMB0G\nA1UECwwWSW5mb3JtYXRpb24gVGVjaG5vbG9neTEaMBgGA1UEAwwRbG9naW4uZW1l\ncnNvbi5lZHUxHzAdBgkqhkiG9w0BCQEWEHJvb3RAZW1lcnNvbi5lZHUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC3qJbjTbnDdz4MlwuTXhmzog3R5p47\n5BL7eUX9Q6pj/tM807iaKpXlSgakVnDa38o1+Du/1DGEfZ9MhTE9E4yeztuNbFJV\nO9ScKdk6a6hZDIW1YUnWIZrW9v52usKS5Cqs8bmHUCCcFx8jZWnmaS6c6rWkGxSN\n9Kq6AmzClGXID2jubZcEmGPcFjR4Tg4W6Dche3CTZfLHDYRDXxUZ3qpcNVVhcFSx\nvCkDNr0U9ZGsw1V/kHd9dnGvonhezaJDTiDhUI1xyw/qnQdWsqnrFfMDMmdaRq/O\nnHXJ7X+H6eZ0wvluz4IBt4r07LcXBn7yvZTRlVBdDThol++6XFjWJVuxAgMBAAGj\nUDBOMB0GA1UdDgQWBBT6TymEH+rN7J/JGdpM7JeW+38OhDAfBgNVHSMEGDAWgBT6\nTymEH+rN7J/JGdpM7JeW+38OhDAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUA\nA4IBAQCMgG0EPvRcyDfcGnUYJmIgiYV8WVg3gILPUQ5T6tPcHJxgvfIcqFigAgWI\n6A/5rD3m5bVGcj+GfOZ4icDvj5Lftd6uAsu+JTXxGfxMJwoqIozx2hLL73usS21V\nrZRxatE0IT3F2oWz0eytE82OMCfvwBCBk71IkWN0orTTyrbYGZhvxJWVRtxUvfZ+\nLEa73Iu/Zg51/frqYYHoBjsX5rVT3H3rBhJqrlHjLS9Fw2Pay/TxAwp5FPC6zmCK\nXYfrkS9wsWKpmuK5J1Xlup8MqqwguX3zRaIFfYUW1c8bLkP7HCA1YTb7pImqBE8Y\nfRerJbNBdbk8AnS/5GdSLL1oSuHK"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Emerson College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.emerson.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Emerson College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:mit.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "touchstone-support@mit.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Touchstone Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:mit.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.mit.edu:8444/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.mit.edu:8444/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6DCCAdCgAwIBAgIJAOOuZYuBUH2jMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC2lkcC5taXQuZWR1MB4XDTEzMTAyMTE5NDczNloXDTMzMTAxNjE5NDczNlow\nFjEUMBIGA1UEAxMLaWRwLm1pdC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQDD3t7oBvx5KMmA4+EEQWK421Jt8HsBYMsaUWAiIQVldTlre3rt51Jg\ndN93adYAMvo6LUr3v7jpT8tUsgV0bDD4MsoK5SAlOWh6tQuR172do1KbDi4VT3Gp\nILJjTqRUjlLEtfCa4/NNQy+ZFXEXIYWoFsfK0J3Q8xCVNdSfNpd3KjlkKshkGsjY\nOMoHJLt8GQB9n7yJX+qZvxJGhiPQJZB5uNx/9omNbvqAF2Hl6b06u7NTPh/Jkvf4\nGGtttjNaWRfcQm1xVbYCCOlpCiTVI6AxCtCy2XqhZmcnY2zk9h2Q/W9lcJ+if1xV\nvMkaId+EBTJW3DI/zvBm0Q/OJTxIwUfzAgMBAAGjOTA3MBYGA1UdEQQPMA2CC2lk\ncC5taXQuZWR1MB0GA1UdDgQWBBRK6tEdA/6T67CMwyWlBEE7cvYaFjANBgkqhkiG\n9w0BAQUFAAOCAQEAUVOL/W1RRrRDm6k4Wtf39jCtHa7gyutt5fHguXUa6nrThRhu\nISEmiQLqK4hVCiIiarZMuyxosdAwFKSGKaunpBFmqI7NcqzskpdRnMIZ0FLQsRJF\nvY6F6S2ou2Yl0UYonX2eVqzWtIR6jd4CqsQdixf5ZE2eQ6o6QICEpjDgMPK/EAKA\nCsVjcBbQw+YbSkmf30ebRTSzIYMhaGETQuf75xD/Ww0mM3njm79Ophg5Y7I9Ryud\nMdDQwsxAS7ECH7vLyu8V/HIfaPkOWYzKKKW5d4E1/X67J2XmTICT7PdxSd5ZKoB5\njdqBxPVYM+C1V02QZFDb7TkTDEICzUnr/VBZ+A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mit.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.mit.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.mit.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.mit.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mit.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Massachusetts Institute of Technology"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6DCCAdCgAwIBAgIJAOOuZYuBUH2jMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC2lkcC5taXQuZWR1MB4XDTEzMTAyMTE5NDczNloXDTMzMTAxNjE5NDczNlow\nFjEUMBIGA1UEAxMLaWRwLm1pdC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQDD3t7oBvx5KMmA4+EEQWK421Jt8HsBYMsaUWAiIQVldTlre3rt51Jg\ndN93adYAMvo6LUr3v7jpT8tUsgV0bDD4MsoK5SAlOWh6tQuR172do1KbDi4VT3Gp\nILJjTqRUjlLEtfCa4/NNQy+ZFXEXIYWoFsfK0J3Q8xCVNdSfNpd3KjlkKshkGsjY\nOMoHJLt8GQB9n7yJX+qZvxJGhiPQJZB5uNx/9omNbvqAF2Hl6b06u7NTPh/Jkvf4\nGGtttjNaWRfcQm1xVbYCCOlpCiTVI6AxCtCy2XqhZmcnY2zk9h2Q/W9lcJ+if1xV\nvMkaId+EBTJW3DI/zvBm0Q/OJTxIwUfzAgMBAAGjOTA3MBYGA1UdEQQPMA2CC2lk\ncC5taXQuZWR1MB0GA1UdDgQWBBRK6tEdA/6T67CMwyWlBEE7cvYaFjANBgkqhkiG\n9w0BAQUFAAOCAQEAUVOL/W1RRrRDm6k4Wtf39jCtHa7gyutt5fHguXUa6nrThRhu\nISEmiQLqK4hVCiIiarZMuyxosdAwFKSGKaunpBFmqI7NcqzskpdRnMIZ0FLQsRJF\nvY6F6S2ou2Yl0UYonX2eVqzWtIR6jd4CqsQdixf5ZE2eQ6o6QICEpjDgMPK/EAKA\nCsVjcBbQw+YbSkmf30ebRTSzIYMhaGETQuf75xD/Ww0mM3njm79Ophg5Y7I9Ryud\nMdDQwsxAS7ECH7vLyu8V/HIfaPkOWYzKKKW5d4E1/X67J2XmTICT7PdxSd5ZKoB5\njdqBxPVYM+C1V02QZFDb7TkTDEICzUnr/VBZ+A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "error_url": "https://idp.mit.edu/help.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Massachusetts Institute of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://web.mit.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Massachusetts Institute of Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://doccom.iml.unibe.ch/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Adrian"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:adrian.michel@iml.unibe.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michel"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41 031 631 58 53"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Axel"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sysadmin@iml.unibe.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hahn"
          }
        }
      ],
      "entity_id": "https://doccom.iml.unibe.ch/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2014-09-08T10:55:32Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "friendly_name": "swissEduPersonHomeOrganization",
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "unibe.ch"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:2.16.756.1.2.5.1.1.4",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "friendly_name": "swissEduPersonHomeOrganizationType",
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "university"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:2.16.756.1.2.5.1.1.5",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e4t Bern"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e4t Bern"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unibe.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unibe.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "unibe.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "DOCCOM Deutsch, Institut f\u00fcr medezinische Lehre, Universit\u00e4t Bern"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "DOCCOM German, Institute for medical Education, University Bern"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://doccom.iml.unibe.ch/Customizing/global/agreement/privacypolicy_en.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DOCCOM  Deutsch Universit\u00e4t Bern"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DOCCOM  German University Bern"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIJAMU8stHHiSQ3MA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE2RvY2NvbS5pbWwudW5pYmUuY2gwHhcNMTQwNDEwMDc1NzI5WhcNMTcwNDA5\nMDc1NzI5WjAeMRwwGgYDVQQDExNkb2Njb20uaW1sLnVuaWJlLmNoMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA081f+9+P/zwCwB/xPFLGYr/Olry6Ald8\n/VCcXHiO9V9OAezmSzMRfILyPLcpKZNl4rKmy3vcc67UzuJ+xA0SgzrsyqsOmxJc\neAnPh58vkrhTooaP6JyXSV9rvrxA01m6TZMFjFJmljZ+5kmixjZ4F+zY9eBsXTXD\nutznEzh0DP1Ds6pL+eYeFezHlSSke4OhWDNVvCUSR3wE4IyImhc0afNhm7g8TOOm\nv/XavhPEw7xJBk40ivm9as/VjEe/Hu52C6McfJAUH2dyyG29jgqsFuMRDJd2zaU5\n1H+2Oxn7qLilqJ0nnbRck2RL5A2z/nOt8X4pBT6g4nBfrj+2zFA+PQIDAQABo2kw\nZzBGBgNVHREEPzA9ghNkb2Njb20uaW1sLnVuaWJlLmNohiZodHRwczovL2RvY2Nv\nbS5pbWwudW5pYmUuY2gvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUIDmYnT2lN75n/KwN\nhAKm76KxX8swDQYJKoZIhvcNAQEFBQADggEBAJBf6iPfVq31qU4vL420UVjKdmMu\nlHAknUBiQgTiUsySUaAVPnPJcpzxlxKRBSd0s0/DbJQYmbCEEbGPZ6i2eLTMSocb\nkSy7D8uh0ZNtOAiTfeWc+76of+BHlXlq027rN5amd21nV4cdXmXMBuMyCidh4iNV\nzMKI709D+kxZvkCdIUlDM1TWd1v8aVViHnxNrlQ54wDFP4jRB9uDHAxUjtFfbdIL\nHpeGPZUR5zOfAiIl+zASdutD9TQVu20kr+/xSJybhXINXLj+r+x4P9xS8eYTQkLJ\nFLSCieH5zHtHuRj8cSafaBgJoQvFTOkZoD8D8N9CcCIKBUQleyBNpRBIfc0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://doccom.iml.unibe.ch/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://doccom.iml.unibe.ch/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://doccom.iml.unibe.ch/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "DOCCOM  Deutsch Universit\u00e4t Bern"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "DOCCOM  German University Bern"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "DOCCOM Deutsch, Institut f\u00fcr medezinische Lehre, Universit\u00e4t Bern"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "DOCCOM German, Institute for medical Education, University Bern"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "commonName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganizationType",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://aai-logon.hcmr.gr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Vavilis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pvavilis@hcmr.gr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Panagiotis"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Vavilis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pvavilis@hcmr.gr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Panagiotis"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://aai-logon.hcmr.gr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIULnKvBVfvx4pFAdGQBdGm6Lb4EQQwDQYJKoZIhvcNAQEF\n                            BQAwHDEaMBgGA1UEAxMRYWFpLWxvZ29uLmhjbXIuZ3IwHhcNMTIxMjA5MTEwNDEw\n                            WhcNMTUxMjA5MTEwNDEwWjAcMRowGAYDVQQDExFhYWktbG9nb24uaGNtci5ncjCC\n                            ASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJcDqKAThNSrdiyAQEOQNFXx\n                            aLxbGKj4P4j4Y1XUJyHCKnEg4m+0fRi1rkrRcKwxdryU+nMtNcyJO/XHMP9d615d\n                            PQLIK1GAeVjJHu4S4giWgYxMX95xTTuFMB8+YvskdcErkuRBAQOwCHlfDvlyqLKs\n                            2PrXLRDwQltgT94pCME8X6LZHTXn+OGdvvoZAr3VBpGMn0Qu6ksw3SqH14oC1khC\n                            uIaz1VpXFUHCGPeSCuFvk4eoPT9kMhtz5pEI8uS5ofuh69JcqHUcgtG5QKui1x6n\n                            zPXzG/q4DiWWxqPd8cD6/ebzsHcTg/LWI1Snzrxh9u4ux+7ScWdZAAkjA57WfSUC\n                            AwEAAaNpMGcwRgYDVR0RBD8wPYIRYWFpLWxvZ29uLmhjbXIuZ3KGKGh0dHBzOi8v\n                            YWFpLWxvZ29uLmhjbXIuZ3IvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFGCy9HAU\n                            oi0n/AKB1LwEBIxVFVYhMA0GCSqGSIb3DQEBBQUAA4IBAQAH2cLcPk3v+kubT2hM\n                            t26yI9Wy0pi/+dWEm/xg7nQqg/WcnPFo82q3bmmFK+Xsn5d8gDsUNG2xSbKVtDzO\n                            YubM8wmLli0f8lR5Xnt+o+6wDuCSTJU8K19InuEnwh0tfWyzNWN2iQP27vWmbfcw\n                            8zd4Ww9eGzxJseh26ne5ImdNYAzapNnUyBkZNywtFbFThvMwV7HGEriavDuLwEud\n                            mRw31/Vem41dmYeChS8oEoLJnhRyqG1vwkmOK2uUqAnyl/IQERGvNTM4G8ieXH4R\n                            Nvy8wByLa8lCOpKnjqaxzqucQw/iGF1zIc0/z5uaXSFOoITg3EFTrXvePTpm6muF\n                            589s"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hcmr.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-logon.hcmr.gr:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-logon.hcmr.gr:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aai-logon.hcmr.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai-logon.hcmr.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aai-logon.hcmr.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai-logon.hcmr.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-logon.hcmr.gr:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-logon.hcmr.gr:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hcmr.gr"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.hcmr.gr/"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.hcmr.gr/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.her.hcmr.gr/mdui_hcmr_logo_125x54.png",
                    "height": "54",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "125"
                  },
                  {
                    "text": "https://idp.her.hcmr.gr/mdui_hcmr_logo_65x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "65"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hellenic Centre for Marine Research"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u0395\u03bb\u03bb\u03b7\u03bd\u03b9\u03ba\u03cc \u039a\u03ad\u03bd\u03c4\u03c1\u03bf \u0398\u03b1\u03bb\u03b1\u03c3\u03c3\u03af\u03c9\u03bd \u0395\u03c1\u03b5\u03c5\u03bd\u03ce\u03bd"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "hcmr.gr"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "ath.hcmr.gr"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "her.hcmr.gr"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:37.733456,23.904153"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:35.332358,25.282459"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.251.36.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "83.212.249.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "83.212.250.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.135.166.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:648:2350::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIULnKvBVfvx4pFAdGQBdGm6Lb4EQQwDQYJKoZIhvcNAQEF\n                            BQAwHDEaMBgGA1UEAxMRYWFpLWxvZ29uLmhjbXIuZ3IwHhcNMTIxMjA5MTEwNDEw\n                            WhcNMTUxMjA5MTEwNDEwWjAcMRowGAYDVQQDExFhYWktbG9nb24uaGNtci5ncjCC\n                            ASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJcDqKAThNSrdiyAQEOQNFXx\n                            aLxbGKj4P4j4Y1XUJyHCKnEg4m+0fRi1rkrRcKwxdryU+nMtNcyJO/XHMP9d615d\n                            PQLIK1GAeVjJHu4S4giWgYxMX95xTTuFMB8+YvskdcErkuRBAQOwCHlfDvlyqLKs\n                            2PrXLRDwQltgT94pCME8X6LZHTXn+OGdvvoZAr3VBpGMn0Qu6ksw3SqH14oC1khC\n                            uIaz1VpXFUHCGPeSCuFvk4eoPT9kMhtz5pEI8uS5ofuh69JcqHUcgtG5QKui1x6n\n                            zPXzG/q4DiWWxqPd8cD6/ebzsHcTg/LWI1Snzrxh9u4ux+7ScWdZAAkjA57WfSUC\n                            AwEAAaNpMGcwRgYDVR0RBD8wPYIRYWFpLWxvZ29uLmhjbXIuZ3KGKGh0dHBzOi8v\n                            YWFpLWxvZ29uLmhjbXIuZ3IvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFGCy9HAU\n                            oi0n/AKB1LwEBIxVFVYhMA0GCSqGSIb3DQEBBQUAA4IBAQAH2cLcPk3v+kubT2hM\n                            t26yI9Wy0pi/+dWEm/xg7nQqg/WcnPFo82q3bmmFK+Xsn5d8gDsUNG2xSbKVtDzO\n                            YubM8wmLli0f8lR5Xnt+o+6wDuCSTJU8K19InuEnwh0tfWyzNWN2iQP27vWmbfcw\n                            8zd4Ww9eGzxJseh26ne5ImdNYAzapNnUyBkZNywtFbFThvMwV7HGEriavDuLwEud\n                            mRw31/Vem41dmYeChS8oEoLJnhRyqG1vwkmOK2uUqAnyl/IQERGvNTM4G8ieXH4R\n                            Nvy8wByLa8lCOpKnjqaxzqucQw/iGF1zIc0/z5uaXSFOoITg3EFTrXvePTpm6muF\n                            589s"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hellenic Centre for Marine Research"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u0395\u03bb\u03bb\u03b7\u03bd\u03b9\u03ba\u03cc \u039a\u03ad\u03bd\u03c4\u03c1\u03bf \u0398\u03b1\u03bb\u03b1\u03c3\u03c3\u03af\u03c9\u03bd \u0395\u03c1\u03b5\u03c5\u03bd\u03ce\u03bd"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hcmr.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hcmr.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hellenic Centre for Marine Research"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u0395\u03bb\u03bb\u03b7\u03bd\u03b9\u03ba\u03cc \u039a\u03ad\u03bd\u03c4\u03c1\u03bf \u0398\u03b1\u03bb\u03b1\u03c3\u03c3\u03af\u03c9\u03bd \u0395\u03c1\u03b5\u03c5\u03bd\u03ce\u03bd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://bath.topdesk.net/tas/secure/login/verify",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webmaster@bath.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Webmaster"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Phillips"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:R.I.Phillips@bath.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bath.topdesk.net/tas/secure/login/verify",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-01-05T10:45:31Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Bath: TOPdesk"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://bath.topdesk.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Bath"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZzCCAk+gAwIBAgIJANWWq1QV/xKBMA0GCSqGSIb3DQEBCwUAMCsxDTALBgNV\n\t\t\t\t\t\tBAMTBGJhdGgxDTALBgNVBAoTBGJhdGgxCzAJBgNVBAYTAlVLMB4XDTE2MDEwNDA5\n\t\t\t\t\t\tNTEzNVoXDTI2MDEwMTA5NTEzNVowKzENMAsGA1UEAxMEYmF0aDENMAsGA1UEChME\n\t\t\t\t\t\tYmF0aDELMAkGA1UEBhMCVUswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCpzYSz8kSXfb/nupnsKs4/PHqHmvUwX5wCjmeNmxn/JW54cJ1uX/TyZkjuqFYh\n\t\t\t\t\t\t9rU30nUeHtgSmvvsm1GP5+BCZx4n7hj6t3BH48o6GWVrrMIQxhU7p0PNbkF9XWJg\n\t\t\t\t\t\tNCe9Ful4EmeY6NcH5NDVlPD2deEOZRXmRFSPIS2DM/mrkB+jaZF4fMuzVJxfQZ+y\n\t\t\t\t\t\teOzNtTgUz39hoZNwl/Z2sEQvU9G46yDgY5H4GNq9ZkFDZBRpNDTWGLaW2EfUU3lY\n\t\t\t\t\t\tm/uVbFl8cxPUb6H03yKcF7k6mUAR1RDRVakOB7O1W3JD0biaKZvvF6YlgjrYUXYB\n\t\t\t\t\t\ttVBs0RwjzLJF44qemoEu85a/AgMBAAGjgY0wgYowHQYDVR0OBBYEFDtwsBxvk/YY\n\t\t\t\t\t\tDKUGR+SuduMslh8/MFsGA1UdIwRUMFKAFDtwsBxvk/YYDKUGR+SuduMslh8/oS+k\n\t\t\t\t\t\tLTArMQ0wCwYDVQQDEwRiYXRoMQ0wCwYDVQQKEwRiYXRoMQswCQYDVQQGEwJVS4IJ\n\t\t\t\t\t\tANWWq1QV/xKBMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQELBQADggEBAJ1s6Agj\n\t\t\t\t\t\te84yW6UZHvgSHIcLaKz8v4GbSfKVq3ZZe1jnzyp1QLtNKN0YAjP+LGDcJ+bPrCDR\n\t\t\t\t\t\tXp3/uaEfYLAMJoEyMOykat9ExragejLKtRaIzp9PiOIGTLjMjecGlRMtuWrkm2vb\n\t\t\t\t\t\trTBjexjv91sMIabJqwxJPaXUJS8WfgNeRLR7EPCn5KUsV5aI4Zkx+FwVebh0Khqd\n\t\t\t\t\t\toNoOaIYxOFBqS9CTkRuwE9TmOqGpu9xD5TIbFF+MgQd6/Y9LP/od8Cjvu72GU9kJ\n\t\t\t\t\t\tsp5En2U7NONIqsFmbU9O4k1Lki5JHWmBGX5DsGkoHVj8XyuAbgNaNqQDvWw0TOw6\n\t\t\t\t\t\tPxgmfYEjY2kiDdg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZzCCAk+gAwIBAgIJANWWq1QV/xKBMA0GCSqGSIb3DQEBCwUAMCsxDTALBgNV\n\t\t\t\t\t\tBAMTBGJhdGgxDTALBgNVBAoTBGJhdGgxCzAJBgNVBAYTAlVLMB4XDTE2MDEwNDA5\n\t\t\t\t\t\tNTEzNVoXDTI2MDEwMTA5NTEzNVowKzENMAsGA1UEAxMEYmF0aDENMAsGA1UEChME\n\t\t\t\t\t\tYmF0aDELMAkGA1UEBhMCVUswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCpzYSz8kSXfb/nupnsKs4/PHqHmvUwX5wCjmeNmxn/JW54cJ1uX/TyZkjuqFYh\n\t\t\t\t\t\t9rU30nUeHtgSmvvsm1GP5+BCZx4n7hj6t3BH48o6GWVrrMIQxhU7p0PNbkF9XWJg\n\t\t\t\t\t\tNCe9Ful4EmeY6NcH5NDVlPD2deEOZRXmRFSPIS2DM/mrkB+jaZF4fMuzVJxfQZ+y\n\t\t\t\t\t\teOzNtTgUz39hoZNwl/Z2sEQvU9G46yDgY5H4GNq9ZkFDZBRpNDTWGLaW2EfUU3lY\n\t\t\t\t\t\tm/uVbFl8cxPUb6H03yKcF7k6mUAR1RDRVakOB7O1W3JD0biaKZvvF6YlgjrYUXYB\n\t\t\t\t\t\ttVBs0RwjzLJF44qemoEu85a/AgMBAAGjgY0wgYowHQYDVR0OBBYEFDtwsBxvk/YY\n\t\t\t\t\t\tDKUGR+SuduMslh8/MFsGA1UdIwRUMFKAFDtwsBxvk/YYDKUGR+SuduMslh8/oS+k\n\t\t\t\t\t\tLTArMQ0wCwYDVQQDEwRiYXRoMQ0wCwYDVQQKEwRiYXRoMQswCQYDVQQGEwJVS4IJ\n\t\t\t\t\t\tANWWq1QV/xKBMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQELBQADggEBAJ1s6Agj\n\t\t\t\t\t\te84yW6UZHvgSHIcLaKz8v4GbSfKVq3ZZe1jnzyp1QLtNKN0YAjP+LGDcJ+bPrCDR\n\t\t\t\t\t\tXp3/uaEfYLAMJoEyMOykat9ExragejLKtRaIzp9PiOIGTLjMjecGlRMtuWrkm2vb\n\t\t\t\t\t\trTBjexjv91sMIabJqwxJPaXUJS8WfgNeRLR7EPCn5KUsV5aI4Zkx+FwVebh0Khqd\n\t\t\t\t\t\toNoOaIYxOFBqS9CTkRuwE9TmOqGpu9xD5TIbFF+MgQd6/Y9LP/od8Cjvu72GU9kJ\n\t\t\t\t\t\tsp5En2U7NONIqsFmbU9O4k1Lki5JHWmBGX5DsGkoHVj8XyuAbgNaNqQDvWw0TOw6\n\t\t\t\t\t\tPxgmfYEjY2kiDdg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bath.topdesk.net/tas/secure/login/verify",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://download.portal.chalmers.se/shibboleth",
    {
      "entity_id": "https://download.portal.chalmers.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJALWMAnfoeEVTMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\nBAMTG2Rvd25sb2FkLnBvcnRhbC5jaGFsbWVycy5zZTAeFw0xMzAyMTMwODUxMjla\nFw0yMzAyMTEwODUxMjlaMCYxJDAiBgNVBAMTG2Rvd25sb2FkLnBvcnRhbC5jaGFs\nbWVycy5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAPbG9acyl2gu\nWdBwDx/r2gP4VufkHGiGheTy8jutaG+KjEcw1+0gbXR7j5q0ikaNki1tRaFmSpnZ\nDotWPOF5ZEsp8MI24NoIijkZTPhVVqRrq4FkZT/L2z6MXUpSXcVLgdxoRX9SSVgv\ncs522ZRTQe6WplkNU3oLKP+gkZl9ukdiFgLQNgeyEphRjN2Ec7OWLepizbotZdu8\n69gmzqHLbNZLiugcBpwIbQO5FkDbxSSdmGOyUWRjcHswJRYo2MMFhrbYYVUIiK1u\nY0wcfRdARkfsbbPG5w8hv4DjEJ2JZ+ofBnfnA6ESn/XEOQ9CAsQ2NbJjUj4rfT88\nEuaGtA/9PqkCAwEAAaNJMEcwJgYDVR0RBB8wHYIbZG93bmxvYWQucG9ydGFsLmNo\nYWxtZXJzLnNlMB0GA1UdDgQWBBQba5syq555BkfQhoVoklnnfDhStDANBgkqhkiG\n9w0BAQUFAAOCAQEAO75ObgCaN++7fT0Y1B7XiEQ2p8oNmND5BedRV9TahI8+zykh\n3j8HSTgEXqGK6DFER9SE7tCxtx3sEytVSpE2pEnqWxWKoU491kZGqWGOm6oSDEWT\n8dMpbx9Z/ZBBo5JdvYDI5Q7MvWIf7+aAhTTcFdQAWqLxje21c3Hpl9zWQ0I9H1p3\nmlThPPb5z+XmLaeAQ6Ux+abiWO+DODJZsidLX3/Aaz86RujVnqk95vY9QxUtynIF\nBfKJHhQBqFivpHyPMnT3y6+UtDE4vfTqLWp5UZoXpKsf/Zo/7+5RQhzlPSxQT0+4\n+//vS+QQnFOG6SANEuSxYURni+8Zk25O5yQlDg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://download.portal.chalmers.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://download.portal.chalmers.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://download.portal.chalmers.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://download.portal.chalmers.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.collyers.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@collyers.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Collyer\u2019s ITSupport"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@collyers.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Collyer\u2019s ITSupport"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.collyers.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-04-14T14:42:57Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAIwzwFahDGtgvAo3yaV1wQYu8pOQMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB0xGzAZBgNVBAMMEmlkcC5jb2xseWVycy5hYy51azAeFw0xNTAyMTcxNTEy\n\t\t\t\t\t\tNDZaFw0zNTAyMTcxNTEyNDZaMB0xGzAZBgNVBAMMEmlkcC5jb2xseWVycy5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ+XQJl+LmxYFS/8qM6M\n\t\t\t\t\t\tYlN5KF1IhUO1Sf6Sg1XYYFs231/UQqojXVnQcP3g+mDSglFbw6kFptZs/Tiv7Sat\n\t\t\t\t\t\to2uWv5DyF0Y0PiRN3j9YDFu3ggOiqK37njPDmtvHBIo5+8AeCvdFdTDvs3peOzKp\n\t\t\t\t\t\t9wnAOe5PVhyEycBMovFH2ggt7lxmXT59u46L6/wvAqVpDsRC8C6jGhFIv6Pn0+9m\n\t\t\t\t\t\tHw+oLMyUOcOFwYMKFG6++h+jP8dkI8FsPBwYP6haznb2dTv8hNE5Bqju7ipWOywp\n\t\t\t\t\t\tjgCgbqOk6l71E+NNN90SK4qVXfg1APBy4m6XuA31mR/F5ag4r2n9Kj1Jpb+EqjrL\n\t\t\t\t\t\tcR0CAwEAAaNrMGkwHQYDVR0OBBYEFBY0Byns90tm8csaG6KelyGNOJx0MEgGA1Ud\n\t\t\t\t\t\tEQRBMD+CEmlkcC5jb2xseWVycy5hYy51a4YpaHR0cHM6Ly9pZHAuY29sbHllcnMu\n\t\t\t\t\t\tYWMudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEFBQADggEBAA5gxgF7Q0mh\n\t\t\t\t\t\tEQavO9p8RQFpfB2lgU6odilbt0283w9L4TUh0iDt+t83qDmoyAuj85viSWQ7iPhS\n\t\t\t\t\t\tsj/1xUH2lxUorvdTnC3TGWvMBKWpVVLzbw06jJ1moaOBKx7CxIEBDY8HYsE0L/6N\n\t\t\t\t\t\tYbOEtaSWxbBJ/QpJUJKihWoP6mmDZV/SP64jUmbqaW+IL4m3aMz2iS3Vu9whRTDL\n\t\t\t\t\t\t6b4EPlUXtzxwSNJraFJuBgWt3UpJfTa3ZsWAcSbT1hv82EG3v8rQosvsfChG9m3g\n\t\t\t\t\t\tQ06WBiCxhbesDgUD9FtbRVYKYB6LSnEm8sPJXfLFI2LuvxHY0uz27MaBgb86NUQj\n\t\t\t\t\t\t6CN0OPho9gU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "collyers.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.collyers.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.collyers.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.collyers.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.collyers.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.collyers.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.collyers.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.collyers.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.collyers.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.collyers.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.collyers.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.collyers.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "collyers.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAIwzwFahDGtgvAo3yaV1wQYu8pOQMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB0xGzAZBgNVBAMMEmlkcC5jb2xseWVycy5hYy51azAeFw0xNTAyMTcxNTEy\n\t\t\t\t\t\tNDZaFw0zNTAyMTcxNTEyNDZaMB0xGzAZBgNVBAMMEmlkcC5jb2xseWVycy5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ+XQJl+LmxYFS/8qM6M\n\t\t\t\t\t\tYlN5KF1IhUO1Sf6Sg1XYYFs231/UQqojXVnQcP3g+mDSglFbw6kFptZs/Tiv7Sat\n\t\t\t\t\t\to2uWv5DyF0Y0PiRN3j9YDFu3ggOiqK37njPDmtvHBIo5+8AeCvdFdTDvs3peOzKp\n\t\t\t\t\t\t9wnAOe5PVhyEycBMovFH2ggt7lxmXT59u46L6/wvAqVpDsRC8C6jGhFIv6Pn0+9m\n\t\t\t\t\t\tHw+oLMyUOcOFwYMKFG6++h+jP8dkI8FsPBwYP6haznb2dTv8hNE5Bqju7ipWOywp\n\t\t\t\t\t\tjgCgbqOk6l71E+NNN90SK4qVXfg1APBy4m6XuA31mR/F5ag4r2n9Kj1Jpb+EqjrL\n\t\t\t\t\t\tcR0CAwEAAaNrMGkwHQYDVR0OBBYEFBY0Byns90tm8csaG6KelyGNOJx0MEgGA1Ud\n\t\t\t\t\t\tEQRBMD+CEmlkcC5jb2xseWVycy5hYy51a4YpaHR0cHM6Ly9pZHAuY29sbHllcnMu\n\t\t\t\t\t\tYWMudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEFBQADggEBAA5gxgF7Q0mh\n\t\t\t\t\t\tEQavO9p8RQFpfB2lgU6odilbt0283w9L4TUh0iDt+t83qDmoyAuj85viSWQ7iPhS\n\t\t\t\t\t\tsj/1xUH2lxUorvdTnC3TGWvMBKWpVVLzbw06jJ1moaOBKx7CxIEBDY8HYsE0L/6N\n\t\t\t\t\t\tYbOEtaSWxbBJ/QpJUJKihWoP6mmDZV/SP64jUmbqaW+IL4m3aMz2iS3Vu9whRTDL\n\t\t\t\t\t\t6b4EPlUXtzxwSNJraFJuBgWt3UpJfTa3ZsWAcSbT1hv82EG3v8rQosvsfChG9m3g\n\t\t\t\t\t\tQ06WBiCxhbesDgUD9FtbRVYKYB6LSnEm8sPJXfLFI2LuvxHY0uz27MaBgb86NUQj\n\t\t\t\t\t\t6CN0OPho9gU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The College of Richard Collyer"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.collyers.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "College of Richard Collyer"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-25.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-25.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-25.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-25.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-25.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-25.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-25.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-25.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-25.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;25"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;25"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-25.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-25.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJAO8+GiRRVU4MMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0yNS5sYWRvay51bXUuc2UwHhcNMTQwOTAxMTQ0NTUzWhcNMjQw\nODI5MTQ0NTUzWjAhMR8wHQYDVQQDExZsYWRvazMtMjUubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsYp5lB2+Qk39xASKZ5eJrbIP\ntzwK7fI829RLtFJlsMNtUw5vKzydiNvBMH0c+G8T86F+GABNnNLnAtlMo8BAWZVR\nr4TryKuzEBKx2pNaxaztoT6xcgZfzoT5cHnysl1aWSYRTbtsw6usxpcwzoNurN1b\n2RrtzU1A4WnuGwpSFPHaWzwE9/aDUveiinLTVO0k/rRSfawNAVaa4jMTLxLZEuZH\n0vdU2GpD1mVXOrB/vvHN2ECSBX0G7+VmzrsZ3U+PtXjIRc+T3KceB6v9tDMoD1mX\ng7LbA5CL5Czj76pZCtlcNAkO63GgVl2qDLN/0okQ+b8Y1ELDlLDc4XhANPzZyQID\nAQABo2swaTBIBgNVHREEQTA/ghZsYWRvazMtMjUubGFkb2sudW11LnNlhiVodHRw\nczovL2xhZG9rMy0yNS5sYWRvay51bXUuc2UvZ3VpLXNwMB0GA1UdDgQWBBRIa5ZF\nQfPkW2FbfiBP1i2hcLy0hDANBgkqhkiG9w0BAQUFAAOCAQEAE5KgnH6pJb8TnKja\nNDY1R1NWlxztrwpdQJqFdcZqIUfuvwWxCdnb8tCjtbZb2R62x4/GHGW5k1zWoAjH\nN/fwCqnPp10d3F7Oir8cyrPWC72K2qYdiAAHJVo6DwW+8TQO7PFeGRP9pqgpsfpM\nVPXaMWsa2EvHW/YZGuGpcE3niOa6szO1FXf+qtoiLKj/l/7WQMjkokg7JECIKyv3\npQDPvNNmXHPw4ypID5+54hX/NlLnqeg074qTbNuopxn7QtP469iIDvh0HkfHpkbO\neUMFBlR6ph6e/XvuoaZcKYVyLGXP+zSU8iWQNoNbASeCNGmlCV9vphxygV6FzVxh\nIqy6Mg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-25.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-25.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-25.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-25.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-25.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-25.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-25.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-25.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-25.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-25.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://biblio.bo.cnr.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tugnoli"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:biblio-idem@area.bo.cnr.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alessandro"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mangiaracina"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:biblio-idem@area.bo.cnr.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Silvana"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://biblio.bo.cnr.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2009-12-31T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID9DCCAtwCCQDDKKmEOwqI4DANBgkqhkiG9w0BAQUFADCBuzELMAkGA1UEBhMC\nSVQxEDAOBgNVBAcTB0JvbG9nbmExDjAMBgNVBAgTBUl0YWx5MSwwKgYDVQQKEyND\nTlIgLSBBcmVhIGRlbGxhIFJpY2VyY2EgZGkgQm9sb2duYTETMBEGA1UECxMKQmli\nbGlvdGVjYTEeMBwGA1UEAxMVYmlibGlvLXNlcnYuYm8uY25yLml0MScwJQYJKoZI\nhvcNAQkBFhhhLnR1Z25vbGlAYXJlYS5iby5jbnIuaXQwHhcNMTYwMzMwMDgyMDI3\nWhcNNDYwMzIzMDgyMDI3WjCBuzELMAkGA1UEBhMCSVQxEDAOBgNVBAcTB0JvbG9n\nbmExDjAMBgNVBAgTBUl0YWx5MSwwKgYDVQQKEyNDTlIgLSBBcmVhIGRlbGxhIFJp\nY2VyY2EgZGkgQm9sb2duYTETMBEGA1UECxMKQmlibGlvdGVjYTEeMBwGA1UEAxMV\nYmlibGlvLXNlcnYuYm8uY25yLml0MScwJQYJKoZIhvcNAQkBFhhhLnR1Z25vbGlA\nYXJlYS5iby5jbnIuaXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC5\nSv5rRfMx/i+VbaR6FmuPGHqcJJ9V+IfbYNVu+/p6qOg+pFwqg5ZuaF674aQ1dczN\nhVgJOEG7p3TjUAGAqX46iURqX0bXVkOzwLKfXLhfqAKPr9eMSoWz6RAk0/IAQaZT\n58XEHpwTBxLqgDrH5M6gMNfXg7wY+iBsvhNakVp8Sw9vW7KiVT/fQSNu3EDSP0pB\niqJOtUErupGBk8SdBvc1mI9ue5QkakcjsqnKdLI6cQ9jHIn4bUSBMmL3Q4b9q/0A\n/PlY4ZX29HzhGCJ8KrhpRzMjSf5CY317RSQNE9bI8KBkdng1ll8H47L7QM7Hig2P\nC5htmoaJA4Qx8omwc8uNAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBACsPRjQctB8Z\n4IM9iJnImqaOYamRDiRJuSTlEZ/dB2mmRf4UsQIBk6nyQY1/cGxamq6SWKUli1fR\n9NthLGYth+CKGV7CbrLYSRWleKTpJ2SKMG9AvtrgavY6ca6AxL6p3yckM71Eonx1\nBB0TdrYQKHiUhbbB9kXMXJNWC/fcd7comscB918uh0GynoYxXSowdnGl+OSZerti\nD69Oez5fVQ4PDv1iV3Uqd8zcUqxfsa9zX2UL4pnmHMANxFeWI4+om7rTFC0btcKQ\nIwD0Nf/pB+PAFyLHQPBrEjofpdriNJFDiDjW/+4yPxwnlQcMwXpBy4fK21gZCBqu\nLdV4oWGgz10="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "biblio.bo.cnr.it"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ira.inaf.it"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iasfbo.inaf.it"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bo.imm.cnr.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://biblio.bo.cnr.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://biblio.bo.cnr.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://biblio.bo.cnr.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://biblio.bo.cnr.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://biblio.bo.cnr.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://biblio.bo.cnr.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://biblio.bo.cnr.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://biblio.bo.cnr.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "biblio.bo.cnr.it"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ira.inaf.it"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iasfbo.inaf.it"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bo.imm.cnr.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://biblio.bo.cnr.it/info.php?inc=idem"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://biblio.bo.cnr.it"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for CNR Bologna Research Area users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti del CNR Area della Ricerca di Bologna"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://biblio.bo.cnr.it/informativa.php"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CNR Bologna Research Area"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CNR Area della Ricerca di Bologna"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID9DCCAtwCCQDDKKmEOwqI4DANBgkqhkiG9w0BAQUFADCBuzELMAkGA1UEBhMC\nSVQxEDAOBgNVBAcTB0JvbG9nbmExDjAMBgNVBAgTBUl0YWx5MSwwKgYDVQQKEyND\nTlIgLSBBcmVhIGRlbGxhIFJpY2VyY2EgZGkgQm9sb2duYTETMBEGA1UECxMKQmli\nbGlvdGVjYTEeMBwGA1UEAxMVYmlibGlvLXNlcnYuYm8uY25yLml0MScwJQYJKoZI\nhvcNAQkBFhhhLnR1Z25vbGlAYXJlYS5iby5jbnIuaXQwHhcNMTYwMzMwMDgyMDI3\nWhcNNDYwMzIzMDgyMDI3WjCBuzELMAkGA1UEBhMCSVQxEDAOBgNVBAcTB0JvbG9n\nbmExDjAMBgNVBAgTBUl0YWx5MSwwKgYDVQQKEyNDTlIgLSBBcmVhIGRlbGxhIFJp\nY2VyY2EgZGkgQm9sb2duYTETMBEGA1UECxMKQmlibGlvdGVjYTEeMBwGA1UEAxMV\nYmlibGlvLXNlcnYuYm8uY25yLml0MScwJQYJKoZIhvcNAQkBFhhhLnR1Z25vbGlA\nYXJlYS5iby5jbnIuaXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC5\nSv5rRfMx/i+VbaR6FmuPGHqcJJ9V+IfbYNVu+/p6qOg+pFwqg5ZuaF674aQ1dczN\nhVgJOEG7p3TjUAGAqX46iURqX0bXVkOzwLKfXLhfqAKPr9eMSoWz6RAk0/IAQaZT\n58XEHpwTBxLqgDrH5M6gMNfXg7wY+iBsvhNakVp8Sw9vW7KiVT/fQSNu3EDSP0pB\niqJOtUErupGBk8SdBvc1mI9ue5QkakcjsqnKdLI6cQ9jHIn4bUSBMmL3Q4b9q/0A\n/PlY4ZX29HzhGCJ8KrhpRzMjSf5CY317RSQNE9bI8KBkdng1ll8H47L7QM7Hig2P\nC5htmoaJA4Qx8omwc8uNAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBACsPRjQctB8Z\n4IM9iJnImqaOYamRDiRJuSTlEZ/dB2mmRf4UsQIBk6nyQY1/cGxamq6SWKUli1fR\n9NthLGYth+CKGV7CbrLYSRWleKTpJ2SKMG9AvtrgavY6ca6AxL6p3yckM71Eonx1\nBB0TdrYQKHiUhbbB9kXMXJNWC/fcd7comscB918uh0GynoYxXSowdnGl+OSZerti\nD69Oez5fVQ4PDv1iV3Uqd8zcUqxfsa9zX2UL4pnmHMANxFeWI4+om7rTFC0btcKQ\nIwD0Nf/pB+PAFyLHQPBrEjofpdriNJFDiDjW/+4yPxwnlQcMwXpBy4fK21gZCBqu\nLdV4oWGgz10="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CNR Area della Ricerca di Bologna"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CNR Bologna Research Area"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://biblio.bo.cnr.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://biblio.bo.cnr.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consiglio Nazionale delle Ricerche (CNR)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National Research Council (CNR)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://bath-test.topdesk.net/tas/public/login/verify",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webmaster@bath.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Webmaster"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Phillips"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:R.I.Phillips@bath.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bath-test.topdesk.net/tas/public/login/verify",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-11-18T13:16:40Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Bath: TOPdesk (test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://bath.topdesk.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Bath"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "logo": [
                  {
                    "text": "https://auth.bath.ac.uk/images/mdui-logo-trans.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "159"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Bath: TOPdesk (test)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDfzCCAmegAwIBAgIJAMZFjLdaD8wQMA0GCSqGSIb3DQEBCwUAMDMxETAPBgNV\n\t\t\t\t\t\tBAMTCGJhdGh0ZXN0MREwDwYDVQQKEwhiYXRodGVzdDELMAkGA1UEBhMCVUswHhcN\n\t\t\t\t\t\tMTUxMTEzMTQ0OTI5WhcNMjUxMTEwMTQ0OTI5WjAzMREwDwYDVQQDEwhiYXRodGVz\n\t\t\t\t\t\tdDERMA8GA1UEChMIYmF0aHRlc3QxCzAJBgNVBAYTAlVLMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEA2eOkEdenoY3OwPOZZU1DtIMo16b64qnpkdoXXnLe\n\t\t\t\t\t\tOKS50XKF+6LJWm28XxDBGGbQzXTby5X368RJ+B4q6Ji11Zw4EJ+fM0y9ovspEJR8\n\t\t\t\t\t\tLpMkmzPIQS70B+7gCnAVmxm5St+oxfYuBsJMB3a5HlPn/4g/wJwjQvZhQ3BZHvHN\n\t\t\t\t\t\tzhJPv7ksxTsZX4jGbD68LzpdSgY+8S0c/v3oUig2PdGsvXZquLFwpMC+iQPJoK34\n\t\t\t\t\t\tHeUkG+2/qsZUpgT3mEGDZsEE68weU93LZWfvn6pepRnaIUjZ2wrMl135SgabQEfc\n\t\t\t\t\t\t7sm3aB33DjMu+IhrNwZrMyvhW+fYKYGDONgKlr/W5E+RtQIDAQABo4GVMIGSMB0G\n\t\t\t\t\t\tA1UdDgQWBBT1y7zA1qIDRDT+FdYJRTFWvgHWDzBjBgNVHSMEXDBagBT1y7zA1qID\n\t\t\t\t\t\tRDT+FdYJRTFWvgHWD6E3pDUwMzERMA8GA1UEAxMIYmF0aHRlc3QxETAPBgNVBAoT\n\t\t\t\t\t\tCGJhdGh0ZXN0MQswCQYDVQQGEwJVS4IJAMZFjLdaD8wQMAwGA1UdEwQFMAMBAf8w\n\t\t\t\t\t\tDQYJKoZIhvcNAQELBQADggEBABqS87n8Qycc2qXzFbMHkFoYxNT8+Y9MI63giai5\n\t\t\t\t\t\tr33rbnfAY3P9+TN3KGTvZnjE8pgiy4HEZ0C1R95izlGcgFR4k/ksymgFRH4+/rDX\n\t\t\t\t\t\tMxq9xCcijwj+V1RQYbA9U4poKeXbv6dBosnk/GGgFDPDeK97HK7xwZ3Mq9d2bQ2v\n\t\t\t\t\t\t7hXQ+vgQFZp6OX+Iteh1/xMG8BgTNUOmlLb1xVlfecfULpptEvmnW/aQpqTqJQPj\n\t\t\t\t\t\tnMK3+jbybpCqVJ+zUbHvaENv7FV629EFZrXBHdVG7DVQyMZlKtAzmal8ifenH/sb\n\t\t\t\t\t\toSq/hb5S3hmWKzG5Z1crLVsWOwpD1aVjD0sjz25jJU8NKUs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDfzCCAmegAwIBAgIJAMZFjLdaD8wQMA0GCSqGSIb3DQEBCwUAMDMxETAPBgNV\n\t\t\t\t\t\tBAMTCGJhdGh0ZXN0MREwDwYDVQQKEwhiYXRodGVzdDELMAkGA1UEBhMCVUswHhcN\n\t\t\t\t\t\tMTUxMTEzMTQ0OTI5WhcNMjUxMTEwMTQ0OTI5WjAzMREwDwYDVQQDEwhiYXRodGVz\n\t\t\t\t\t\tdDERMA8GA1UEChMIYmF0aHRlc3QxCzAJBgNVBAYTAlVLMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEA2eOkEdenoY3OwPOZZU1DtIMo16b64qnpkdoXXnLe\n\t\t\t\t\t\tOKS50XKF+6LJWm28XxDBGGbQzXTby5X368RJ+B4q6Ji11Zw4EJ+fM0y9ovspEJR8\n\t\t\t\t\t\tLpMkmzPIQS70B+7gCnAVmxm5St+oxfYuBsJMB3a5HlPn/4g/wJwjQvZhQ3BZHvHN\n\t\t\t\t\t\tzhJPv7ksxTsZX4jGbD68LzpdSgY+8S0c/v3oUig2PdGsvXZquLFwpMC+iQPJoK34\n\t\t\t\t\t\tHeUkG+2/qsZUpgT3mEGDZsEE68weU93LZWfvn6pepRnaIUjZ2wrMl135SgabQEfc\n\t\t\t\t\t\t7sm3aB33DjMu+IhrNwZrMyvhW+fYKYGDONgKlr/W5E+RtQIDAQABo4GVMIGSMB0G\n\t\t\t\t\t\tA1UdDgQWBBT1y7zA1qIDRDT+FdYJRTFWvgHWDzBjBgNVHSMEXDBagBT1y7zA1qID\n\t\t\t\t\t\tRDT+FdYJRTFWvgHWD6E3pDUwMzERMA8GA1UEAxMIYmF0aHRlc3QxETAPBgNVBAoT\n\t\t\t\t\t\tCGJhdGh0ZXN0MQswCQYDVQQGEwJVS4IJAMZFjLdaD8wQMAwGA1UdEwQFMAMBAf8w\n\t\t\t\t\t\tDQYJKoZIhvcNAQELBQADggEBABqS87n8Qycc2qXzFbMHkFoYxNT8+Y9MI63giai5\n\t\t\t\t\t\tr33rbnfAY3P9+TN3KGTvZnjE8pgiy4HEZ0C1R95izlGcgFR4k/ksymgFRH4+/rDX\n\t\t\t\t\t\tMxq9xCcijwj+V1RQYbA9U4poKeXbv6dBosnk/GGgFDPDeK97HK7xwZ3Mq9d2bQ2v\n\t\t\t\t\t\t7hXQ+vgQFZp6OX+Iteh1/xMG8BgTNUOmlLb1xVlfecfULpptEvmnW/aQpqTqJQPj\n\t\t\t\t\t\tnMK3+jbybpCqVJ+zUbHvaENv7FV629EFZrXBHdVG7DVQyMZlKtAzmal8ifenH/sb\n\t\t\t\t\t\toSq/hb5S3hmWKzG5Z1crLVsWOwpD1aVjD0sjz25jJU8NKUs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bath-test.topdesk.net/tas/public/login/verify",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://shib2.swmed.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Peter.Smith@UTSouthwestern.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Peter Smith"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib2.swmed.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib2.swmed.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib2.swmed.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib2.swmed.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib2.swmed.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib2.swmed.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utsouthwestern.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Logon service for The University of Texas Southwestern Medical Center"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idm.utsystem.edu/images/utswmc-logo.jpg",
                    "lang": "en",
                    "height": "103",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "75"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Texas Southwestern Medical Center at Dallas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGkTCCBHmgAwIBAgIJANAN4Fnb5GaDMA0GCSqGSIb3DQEBBQUAMIHeMQswCQYD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\n+3mYgUw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "http://www.utsouthwestern.edu/about-us/administrative-offices/information-resources/index.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Texas Southwestern Medical Center at Dallas"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www3.utsouthwestern.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Texas Southwestern Medical Center at Dallas"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.bioone.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.bioone.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Atypon Systems: BioOne"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bioone.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDoTCCAomgAwIBAgIJAJjXSA+eCVerMA0GCSqGSIb3DQEBBQUAMIGPMQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEUMBIGA1UEBxMLU2FudGEgQ2xh\n\t\t\t\t\t\tcmExHTAbBgNVBAoTFEF0eXBvbiBTeXN0ZW1zLCBJbmMuMR0wGwYDVQQLExRBdHlw\n\t\t\t\t\t\tb24gU3lzdGVtcywgSW5jLjEXMBUGA1UEAxMOd3d3LmJpb29uZS5vcmcwHhcNMTAx\n\t\t\t\t\t\tMDIyMDAyOTE1WhcNMjAxMDE5MDAyOTE1WjCBjzELMAkGA1UEBhMCVVMxEzARBgNV\n\t\t\t\t\t\tBAgTCkNhbGlmb3JuaWExFDASBgNVBAcTC1NhbnRhIENsYXJhMR0wGwYDVQQKExRB\n\t\t\t\t\t\tdHlwb24gU3lzdGVtcywgSW5jLjEdMBsGA1UECxMUQXR5cG9uIFN5c3RlbXMsIElu\n\t\t\t\t\t\tYy4xFzAVBgNVBAMTDnd3dy5iaW9vbmUub3JnMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAq9l9fHkQV6d18ZBMtv1oAsyV2spBF4o5FCta4jLiVrcx6TAh\n\t\t\t\t\t\teY+1djxN0smEpiflND9YyncINW/QxTr4VkJaRrURGalwPYUnEDMbUeDCZGdjmuHn\n\t\t\t\t\t\tijesTi34lBnjz8FeIIoB/1YlCSVffVxxOLw6AhVDuBixH+n1MK3AvMaV7+6k7iar\n\t\t\t\t\t\t59570440WqpQMpWVJm+a1EgyS4WF5SjW8PI3VDfrJCC76Qg6YCKXhdO56sFZ8fOe\n\t\t\t\t\t\tm+6nUdkZRSUEDZ6jG9nF2rFKdxrlTCEpVXrSViiuAGrwcNXxIF07M/cdW4gh2J1n\n\t\t\t\t\t\tanOVWYhax9gL0PPXptkCjQxiJKK8oKF/qU5YvQIDAQABMA0GCSqGSIb3DQEBBQUA\n\t\t\t\t\t\tA4IBAQCXFBWSkhl6SXKrjBTJGR2Ed7QdRhhZJFgglA0NZJ0eGHE0tTmF34Htgr+D\n\t\t\t\t\t\trjxXukFop7y+zuEg51CCNExeiIn8boC6/Bi1N5wnXKgBxejuF5WTRqua7PehfcUk\n\t\t\t\t\t\tsAcyQfiT42U4qL/Y5cCVvVjyjOn4vB9QInt6w0t2JB0KhdkTlzHPFGNhIr6JielL\n\t\t\t\t\t\tOysB8mqF8SvNWTA8FXtsoj/xMzTZmOhbEr6LWeCRsATxTEnfts9XKrnvr6QvLzOp\n\t\t\t\t\t\toznstpE1RBJHa+apJ8N1d+K2N9Ki2S2GYGl2g9Z82UGSvirtJTnZY6TANrYKFKnd\n\t\t\t\t\t\tWjtPYywjxsAyOSn7irW8nyLDn8sA"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.bioone.org/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.bioone.org/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.bioone.org/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ccad.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ccad.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/ccad.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/ccad.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ccad.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cleveland College of Art and Design"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ccad.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.cans.org.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Muthu"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:emil@webstarsltd.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Emil"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Muthu"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:emil@webstarsltd.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Emil"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.cans.org.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-08-03T14:04:29Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Citizens Advice Notes Service Trust: Legal Information"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cans.org.uk/libraries-public/about"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Citizens Advice Notes Service Trust"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cans.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.cans.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cans.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cans.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cans.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "authn_requests_signed": "1",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.cans.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.cans.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIJALDeNSvqu4X6MA0GCSqGSIb3DQEBBQUAMDMxMTAvBgNV\n\t\t\t\t\t\tBAMTKHdlYnN0YXJzLWNhbnMuc2VydmVycy5yYmwtbWVyLm1pc3AuY28udWswHhcN\n\t\t\t\t\t\tMTEwNzI1MjAyMjI2WhcNMjEwNzIyMjAyMjI2WjAzMTEwLwYDVQQDEyh3ZWJzdGFy\n\t\t\t\t\t\tcy1jYW5zLnNlcnZlcnMucmJsLW1lci5taXNwLmNvLnVrMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEA0UhAljwZVOdU7bOCYe+ZQrhWqePftNspOCkP0HP7\n\t\t\t\t\t\tr0++0yD+HQUaAHEU1drhm8tXlNfKoFTHlBk6w9fbC45auasz093CgjNNYO5jsgZ4\n\t\t\t\t\t\tE7IQ59PaGlDSE80jKugD0+ZQGAsSQEzTDlOX8yKJ8hbbbAf1zuaIznH8u3kc8RkB\n\t\t\t\t\t\tHCXPLWAxCcqgKLh4188SeeZXUewn8uNqR6GGgdOcaPmLdrgKLJ/+mDPtkLAB6pvm\n\t\t\t\t\t\tTQYGdwkHbVnggtCUk8GPQHHJ3HnrY6hGTxm/bkVeABXeVXZAKPTAgOk5UFzqUwLR\n\t\t\t\t\t\tXd7W89PavWoYNlG2Uhq8X/n3h9+9XA6ldR4tSSN5e38HswIDAQABo1YwVDAzBgNV\n\t\t\t\t\t\tHREELDAqgih3ZWJzdGFycy1jYW5zLnNlcnZlcnMucmJsLW1lci5taXNwLmNvLnVr\n\t\t\t\t\t\tMB0GA1UdDgQWBBTqtW8nIPlLZA2OyhfmRhZW5jR/mjANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEApfwxvHulgw7+D+XvhgxEoViwpHd6Z8JhWgnsbt0JiRwDwWEzhhsM9QEF4gZM\n\t\t\t\t\t\t5ZdL56yL3ATZ4j5uFiZcBF2Kv2yOufbI2OkBM6rjV4+NBFReAGS0ugZs49SZ5V1U\n\t\t\t\t\t\tXBxeX5vL1uuHjzJbvvwQr4ton7p4qeSO6duJkiCI5XIPrf4NXodla711SuM3q+L4\n\t\t\t\t\t\tzLpI8uIaKJwCnsIMeJm0pj2zojM7SVOPUYEtpAuxb6gBSeSB9IYttVjKn0USpthC\n\t\t\t\t\t\t0WyK0Tt3t/i0LHeIbcaOpcPdnjr/x7Dg8/9X1DRfpJMDK5UogWENLgN9fz0SdqDp\n\t\t\t\t\t\tubozEJC8LUak3g0570yFN0h++A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cans.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.cans.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cans.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.cans.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.cans.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.cans.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol"
        }
      ]
    }
  ],
  [
    "https://idp.wit.ie/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mc Grath"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:amcgrath@wit.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Aidan"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cluney"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pcluney@wit.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pat"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dowling"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tdowling@wit.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Thomas"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "WIT Computer Services"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:computerservices@wit.ie"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.wit.ie/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2010-11-22T00:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.wit.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.wit.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.wit.ie/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wit.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.wit.ie/about_wit"
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/wit.png",
                    "height": "101",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "150"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Waterford Institute of Technology"
                  },
                  {
                    "lang": "ga",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institi\u00faid Teicneola\u00edochta Port L\u00e1irge"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:52.24602,-7.13992"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAP8av6UsfKq9co3H42qLy3deHv3LMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC53aXQuaWUwHhcNMDkxMDE0MTQwMTA1WhcNMjkx\nMDE0MTQwMTA1WjAVMRMwEQYDVQQDEwppZHAud2l0LmllMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAhrE9L82QkOHB6nfZb2LNn/olkgLX6EordeY6V9BC\n2CnVf18N0WxD+br+w5yX+q7BQLxOC7+FaB3huqFCyDL9kP66Y4sxH+6oRjaxtOv3\nnkC/4QZhitR6Ol2RcdwdB5GZzo+FrQF/OfTbSf2XZ0K0CAza4Bc1BTJiSvWbtymA\ntkB5c4FKGxFjzRHVZd73vyUd66Qxai79ifbIa+ujxhbaZz5TKtR6cZv1DoeB1/ol\n6zBFHFB7s3XHZq+kn3TGrEXHP1zQonigaT7BxPCogO4X5+t4TI2m+T67ZWNAf82J\nXzK/sUmyUO7iQ2dlTjuUL/jEAtuXYNcF35e7Z20jpu+PEQIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAud2l0LmllhiFodHRwczovL2lkcC53aXQuaWUvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFKbxKrmJg2gV90gpwMIhjKT4587hMA0GCSqGSIb3DQEB\nBQUAA4IBAQAf8thi+05KHldde/0cPmQObTTfhTq1blAMlrgRVCCF3fYVJkCcmoF8\nB+2PZKzilES9rWOEFBgvKM0f+zWZEjdQ8+yUtOmMcBDr2UMpcez5dJQnXKsE5R2W\nh70L7iMmMVY7SiXpj0EbdH5DDikG0PfTozDCFE1/Ej2jHtfpkx550/ndhbAhhdOG\nxNsj+b7mIOWYzHeBZaNA4RMlPOb+e6AVp486SM7Un99Q01M0YKKCywrSCfhgxc9l\nayulS2yPVLivhbaHyblQHkuxzZHevAs/NRztnJDJJ/V+puOejSvO+0WyvA1YUzTJ\nect1+KwnR20CjNdGxfXwubzEODFApQ2J"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Waterford Institute of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wit.ie/about_wit"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Waterford Institute of Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shidp.glam.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@southwales.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Services Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sewell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kevin.sewell@southwales.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kevin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shidp.glam.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAOq/2C/MoDMaYd36KL3bSPyQItVzMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBsxGTAXBgNVBAMTEHNoaWRwLmdsYW0uYWMudWswHhcNMTIxMTIxMTA1NTE0\n\t\t\t\t\t\tWhcNMzIxMTIxMTA1NTE0WjAbMRkwFwYDVQQDExBzaGlkcC5nbGFtLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtnzmaVL9I3yNiqKniGKG1pRF\n\t\t\t\t\t\tWeRejOpNJia1Y7wGxD4WjiMyVMf3nhRGLFDtQgVxB0xFbkzuxRmcZxRb+YiPR/Dy\n\t\t\t\t\t\tP4ASQJ2QgOpWj7YUMk48nEq1G3A747bWVzwiRBs1XXN2BT4dvhgYXfTxiFKVWOdv\n\t\t\t\t\t\tffGOixfNfmF2+y9KSQ138izkIewG1ZL4e+OB0zRe182rAr0w9mchZb7+VAV5BW6q\n\t\t\t\t\t\ttVLekPky+WDA4FWHI2CFC/9NyGnzmEqxQczdSF/b5qCHm0HUTV2AO415wAc2yyKH\n\t\t\t\t\t\tXVgeCx4TahSrh9/08xAySDYZIY96CkNOahNjN6FG0iBAC0lGgxWX5nTB+PBt+QID\n\t\t\t\t\t\tAQABo2cwZTBEBgNVHREEPTA7ghBzaGlkcC5nbGFtLmFjLnVrhidodHRwczovL3No\n\t\t\t\t\t\taWRwLmdsYW0uYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFL6PJ9Ijs6+h\n\t\t\t\t\t\tr6RavogHch1LNQ+JMA0GCSqGSIb3DQEBBQUAA4IBAQAjwbTW6ulWDIbwoJl0bs2S\n\t\t\t\t\t\t+akVMUNN5/y03Uy87vMs+x/C+8H5qKb77zCcT0ey5qtXWjxrguKzyskEiGiIN7zu\n\t\t\t\t\t\tMwaAbQFWRXyWfyanR182Ff15emFrETH9QTprRp/XYIjs5VmL6rUHtVyRrFq5tTAw\n\t\t\t\t\t\tfVxnP0tcwpKoAcs4TUvGFokcY0RHjxutrYKXKA2T9/kJXkqXcYJII8LAe0QOJ6Qx\n\t\t\t\t\t\tAWjHb1nOc8EIMekqmGuiQMmvBnp86qHn2Dpm4bioErd4401iF+mHfpTdaLEu0YUr\n\t\t\t\t\t\twhThODhFpFOM7D3ct8xJhHG1lK+wwqGzn32PVvxKlXGAVr42J1ejVDKdRXA2rCtY"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "glam.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shidp.glam.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shidp.glam.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shidp.glam.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shidp.glam.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shidp.glam.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shidp.glam.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shidp.glam.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shidp.glam.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "glam.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAOq/2C/MoDMaYd36KL3bSPyQItVzMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBsxGTAXBgNVBAMTEHNoaWRwLmdsYW0uYWMudWswHhcNMTIxMTIxMTA1NTE0\n\t\t\t\t\t\tWhcNMzIxMTIxMTA1NTE0WjAbMRkwFwYDVQQDExBzaGlkcC5nbGFtLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtnzmaVL9I3yNiqKniGKG1pRF\n\t\t\t\t\t\tWeRejOpNJia1Y7wGxD4WjiMyVMf3nhRGLFDtQgVxB0xFbkzuxRmcZxRb+YiPR/Dy\n\t\t\t\t\t\tP4ASQJ2QgOpWj7YUMk48nEq1G3A747bWVzwiRBs1XXN2BT4dvhgYXfTxiFKVWOdv\n\t\t\t\t\t\tffGOixfNfmF2+y9KSQ138izkIewG1ZL4e+OB0zRe182rAr0w9mchZb7+VAV5BW6q\n\t\t\t\t\t\ttVLekPky+WDA4FWHI2CFC/9NyGnzmEqxQczdSF/b5qCHm0HUTV2AO415wAc2yyKH\n\t\t\t\t\t\tXVgeCx4TahSrh9/08xAySDYZIY96CkNOahNjN6FG0iBAC0lGgxWX5nTB+PBt+QID\n\t\t\t\t\t\tAQABo2cwZTBEBgNVHREEPTA7ghBzaGlkcC5nbGFtLmFjLnVrhidodHRwczovL3No\n\t\t\t\t\t\taWRwLmdsYW0uYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFL6PJ9Ijs6+h\n\t\t\t\t\t\tr6RavogHch1LNQ+JMA0GCSqGSIb3DQEBBQUAA4IBAQAjwbTW6ulWDIbwoJl0bs2S\n\t\t\t\t\t\t+akVMUNN5/y03Uy87vMs+x/C+8H5qKb77zCcT0ey5qtXWjxrguKzyskEiGiIN7zu\n\t\t\t\t\t\tMwaAbQFWRXyWfyanR182Ff15emFrETH9QTprRp/XYIjs5VmL6rUHtVyRrFq5tTAw\n\t\t\t\t\t\tfVxnP0tcwpKoAcs4TUvGFokcY0RHjxutrYKXKA2T9/kJXkqXcYJII8LAe0QOJ6Qx\n\t\t\t\t\t\tAWjHb1nOc8EIMekqmGuiQMmvBnp86qHn2Dpm4bioErd4401iF+mHfpTdaLEu0YUr\n\t\t\t\t\t\twhThODhFpFOM7D3ct8xJhHG1lK+wwqGzn32PVvxKlXGAVr42J1ejVDKdRXA2rCtY"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of South Wales"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.glam.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of South Wales"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso-ukfed.angdev.com/simplesaml/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Grant"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:help@aluminati.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Emily"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Garner"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:roger@aluminati.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roger"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso-ukfed.angdev.com/simplesaml/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-11-02T14:43:37Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Aluminati Engagement Portal (Dev)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aluminati.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Aluminati Network Group Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso-ukfed.angdev.com/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Aluminati Engagement Portal (Dev)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE0zCCA7ugAwIBAgIJAI9tj6IHmTuYMA0GCSqGSIb3DQEBBQUAMIGhMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEQMA4GA1UECBMHU3VmZm9sazESMBAGA1UEBxMJTmV3bWFya2V0MSQw\n\t\t\t\t\t\tIgYDVQQKExtBbHVtaW5hdGkgTmV0d29yayBHcm91cCBMdGQxHTAbBgNVBAMTFHNz\n\t\t\t\t\t\tby11a2ZlZC5hbmdkZXYuY29tMScwJQYJKoZIhvcNAQkBFhhwb3N0bWFzdGVyQGFs\n\t\t\t\t\t\tdW1pbmF0aS5uZXQwHhcNMTUxMTAyMTMwNzAzWhcNMjUxMTAxMTMwNzAzWjCBoTEL\n\t\t\t\t\t\tMAkGA1UEBhMCR0IxEDAOBgNVBAgTB1N1ZmZvbGsxEjAQBgNVBAcTCU5ld21hcmtl\n\t\t\t\t\t\tdDEkMCIGA1UEChMbQWx1bWluYXRpIE5ldHdvcmsgR3JvdXAgTHRkMR0wGwYDVQQD\n\t\t\t\t\t\tExRzc28tdWtmZWQuYW5nZGV2LmNvbTEnMCUGCSqGSIb3DQEJARYYcG9zdG1hc3Rl\n\t\t\t\t\t\tckBhbHVtaW5hdGkubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tuZ3sg8LNh276Gxz1fiYkQ9ENHNZosCnpklSscs5fYWr1huads4l3IE2enTDJ/VKM\n\t\t\t\t\t\tkIWtjDuq/EIs7tQtRphsR1zwMtFCg5dKDSwLEIyk6FEH4vouYwRSVmPYh+zvQlPI\n\t\t\t\t\t\tqadMp3lYsFUcyy2zUbGNSqOSLLaGzEEogihxm3zhPsLafiP4sECNLQ10qoOHgflS\n\t\t\t\t\t\tyhXkxOQHIIOk01Qishi74opjtxvJGesfrOyTmf4UF/fQS0fIiDKDpT72+haFUksO\n\t\t\t\t\t\tOaM4SJ1/JJPAAN9/+HsUsVTsfk4a+X89US4F30TAtwDHfcYKi3tDIC6IY1Hf1Rcs\n\t\t\t\t\t\tKmZtSeUkZVT3lsVlOhvIcwIDAQABo4IBCjCCAQYwHQYDVR0OBBYEFHrH1l9rGVqt\n\t\t\t\t\t\tgopdiAtWLJXrYQRWMIHWBgNVHSMEgc4wgcuAFHrH1l9rGVqtgopdiAtWLJXrYQRW\n\t\t\t\t\t\toYGnpIGkMIGhMQswCQYDVQQGEwJHQjEQMA4GA1UECBMHU3VmZm9sazESMBAGA1UE\n\t\t\t\t\t\tBxMJTmV3bWFya2V0MSQwIgYDVQQKExtBbHVtaW5hdGkgTmV0d29yayBHcm91cCBM\n\t\t\t\t\t\tdGQxHTAbBgNVBAMTFHNzby11a2ZlZC5hbmdkZXYuY29tMScwJQYJKoZIhvcNAQkB\n\t\t\t\t\t\tFhhwb3N0bWFzdGVyQGFsdW1pbmF0aS5uZXSCCQCPbY+iB5k7mDAMBgNVHRMEBTAD\n\t\t\t\t\t\tAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBMNi3aujogjGwWmyNITPCGf+p/x5G0JSpe\n\t\t\t\t\t\tg47Au5pdKSCABlXBE+O4JWSPENtETFAEgirLyjt/pyPM3wBUuK22A4YID9ZSWkKh\n\t\t\t\t\t\tKGxmpqcFNfYycFVEm6yLspDSYZpsvO6n+aFfN2YSOZwg9wSwkDmYd5zbW2AZk21d\n\t\t\t\t\t\tdMf8w+pSo/RU1GgSb9y5LwwipMJ/GrPI1ifCWvgXVFWXkJYya1do5BIh7yZ33Gna\n\t\t\t\t\t\tM/Ph+msHdZ8pexkctO10JpmiXk3mhKiEmq5QsoVPbifRK4MSm8l9aCcItsOzFzPE\n\t\t\t\t\t\tSP/Ojg/mfRnlJrCIKN6VuP8hAAJfn5OHrTSYqDwMwGj9zZ6NdXAG"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE0zCCA7ugAwIBAgIJAI9tj6IHmTuYMA0GCSqGSIb3DQEBBQUAMIGhMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEQMA4GA1UECBMHU3VmZm9sazESMBAGA1UEBxMJTmV3bWFya2V0MSQw\n\t\t\t\t\t\tIgYDVQQKExtBbHVtaW5hdGkgTmV0d29yayBHcm91cCBMdGQxHTAbBgNVBAMTFHNz\n\t\t\t\t\t\tby11a2ZlZC5hbmdkZXYuY29tMScwJQYJKoZIhvcNAQkBFhhwb3N0bWFzdGVyQGFs\n\t\t\t\t\t\tdW1pbmF0aS5uZXQwHhcNMTUxMTAyMTMwNzAzWhcNMjUxMTAxMTMwNzAzWjCBoTEL\n\t\t\t\t\t\tMAkGA1UEBhMCR0IxEDAOBgNVBAgTB1N1ZmZvbGsxEjAQBgNVBAcTCU5ld21hcmtl\n\t\t\t\t\t\tdDEkMCIGA1UEChMbQWx1bWluYXRpIE5ldHdvcmsgR3JvdXAgTHRkMR0wGwYDVQQD\n\t\t\t\t\t\tExRzc28tdWtmZWQuYW5nZGV2LmNvbTEnMCUGCSqGSIb3DQEJARYYcG9zdG1hc3Rl\n\t\t\t\t\t\tckBhbHVtaW5hdGkubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tuZ3sg8LNh276Gxz1fiYkQ9ENHNZosCnpklSscs5fYWr1huads4l3IE2enTDJ/VKM\n\t\t\t\t\t\tkIWtjDuq/EIs7tQtRphsR1zwMtFCg5dKDSwLEIyk6FEH4vouYwRSVmPYh+zvQlPI\n\t\t\t\t\t\tqadMp3lYsFUcyy2zUbGNSqOSLLaGzEEogihxm3zhPsLafiP4sECNLQ10qoOHgflS\n\t\t\t\t\t\tyhXkxOQHIIOk01Qishi74opjtxvJGesfrOyTmf4UF/fQS0fIiDKDpT72+haFUksO\n\t\t\t\t\t\tOaM4SJ1/JJPAAN9/+HsUsVTsfk4a+X89US4F30TAtwDHfcYKi3tDIC6IY1Hf1Rcs\n\t\t\t\t\t\tKmZtSeUkZVT3lsVlOhvIcwIDAQABo4IBCjCCAQYwHQYDVR0OBBYEFHrH1l9rGVqt\n\t\t\t\t\t\tgopdiAtWLJXrYQRWMIHWBgNVHSMEgc4wgcuAFHrH1l9rGVqtgopdiAtWLJXrYQRW\n\t\t\t\t\t\toYGnpIGkMIGhMQswCQYDVQQGEwJHQjEQMA4GA1UECBMHU3VmZm9sazESMBAGA1UE\n\t\t\t\t\t\tBxMJTmV3bWFya2V0MSQwIgYDVQQKExtBbHVtaW5hdGkgTmV0d29yayBHcm91cCBM\n\t\t\t\t\t\tdGQxHTAbBgNVBAMTFHNzby11a2ZlZC5hbmdkZXYuY29tMScwJQYJKoZIhvcNAQkB\n\t\t\t\t\t\tFhhwb3N0bWFzdGVyQGFsdW1pbmF0aS5uZXSCCQCPbY+iB5k7mDAMBgNVHRMEBTAD\n\t\t\t\t\t\tAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBMNi3aujogjGwWmyNITPCGf+p/x5G0JSpe\n\t\t\t\t\t\tg47Au5pdKSCABlXBE+O4JWSPENtETFAEgirLyjt/pyPM3wBUuK22A4YID9ZSWkKh\n\t\t\t\t\t\tKGxmpqcFNfYycFVEm6yLspDSYZpsvO6n+aFfN2YSOZwg9wSwkDmYd5zbW2AZk21d\n\t\t\t\t\t\tdMf8w+pSo/RU1GgSb9y5LwwipMJ/GrPI1ifCWvgXVFWXkJYya1do5BIh7yZ33Gna\n\t\t\t\t\t\tM/Ph+msHdZ8pexkctO10JpmiXk3mhKiEmq5QsoVPbifRK4MSm8l9aCcItsOzFzPE\n\t\t\t\t\t\tSP/Ojg/mfRnlJrCIKN6VuP8hAAJfn5OHrTSYqDwMwGj9zZ6NdXAG"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso-ukfed.angdev.com/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sso-ukfed.angdev.com/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sso-ukfed.angdev.com/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sso-ukfed.angdev.com/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://activate.du.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://activate.du.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://activate.du.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://activate.du.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://activate.du.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://activate.du.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://activate.du.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://activate.du.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://activate.du.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hantering av elektronisk identitet vid H\u00f6gskolan Dalarna"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Electronic identity administration at Dalarna University"
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.du.se/duse-logo-sv.png",
                    "height": "146",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Elektronisk Identitet H\u00f6gskolan Dalarna"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Electronic Identity Dalarna University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "activate-test.du.se"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://activate-test.du.se/shibboleth"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIJAOqmPw5SlcqvMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE2FjdGl2YXRlLXRlc3QuZHUuc2UwHhcNMTQwMzMxMjAzNjM0WhcNMjQwMzI4\nMjAzNjM0WjAeMRwwGgYDVQQDExNhY3RpdmF0ZS10ZXN0LmR1LnNlMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAx2TO4hwDNpXFQ5Hyn9GFuZh5P+0SFLxh\nhhfV+6bh7rilmaJQInmUO8Uh9yylRBHvb/xwEi73/Rr6cIbLzEvC4SZmYyFYXB+3\noTtU1ms5c+kZ3PP2IabRJjM4LNYH+d+JClMkahjVk5rr1jO14u54EUM5xAtIEbZU\nJuZ+KWRiDbHZR8vMCDOPr5oqtlRFKtbZjxkC6VTXgEvDPEhLQm5x/Q/6iAAu80+l\nsaaPLPmy5oE/tq0YiWGsR7prnwuRCR8VlKggEe70GPxGsd4SSc0cSucS1N69W3MA\nlgXOeWpjN31aCqNAIfQTa/VmKh/oIlnMn7lkXtXvC2unZU6JTzsdJwIDAQABo2kw\nZzBGBgNVHREEPzA9ghNhY3RpdmF0ZS10ZXN0LmR1LnNlhiZodHRwczovL2FjdGl2\nYXRlLXRlc3QuZHUuc2Uvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUi4hiheuUBeYxHmow\nadFeZt+TenwwDQYJKoZIhvcNAQEFBQADggEBAF+MHTTRxvcsRDSF+kIx5O5K5/OM\nLKUUvnhgLt8mPNstc2LREwiIhbYTp5pLZgo6mhSeMqNanOXGqSwUBqhd6a299IXz\nOJTh4FKFWt48Hx5EU2bOncyBjp6f7/IIHMsxJMj/8WvkVdALUfCV5MpTEKk5Wlad\ncj3VvNKP/3THIp1srQXP1JHeZ39Sej9tnqUWEt80Dl8DG8bILI4VjDx3lS4OqxLV\nqb/n+Wv3Fk7R4OnXVOYa1p9kCe/duFqtDOpQa3so6HLaB2baXjpxq4n9wwJ+rrng\n3gu23RwDXFo5h9bpfziaNT5vFBUo4AtRktWfVrhV3ECQFS53m/BrLOkJ5ZI="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=activate-test.du.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://activate.du.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://activate.du.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://activate.du.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://activate.du.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://activate.du.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.identity.uoguelph.ca/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ideas@uoguelph.ca"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Identity Services"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.identity.uoguelph.ca/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2015-08-21T16:10:00Z",
            "registration_authority": "http://www.canarie.ca",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDyjCCArICCQCluLVINlzKvzANBgkqhkiG9w0BAQUFADCBpjELMAkGA1UEBhMC\nQ0ExEDAOBgNVBAgTB09udGFyaW8xDzANBgNVBAcTBkd1ZWxwaDEdMBsGA1UEChMU\nVW5pdmVyc2l0eSBvZiBHdWVscGgxDDAKBgNVBAsTA0NDUzEhMB8GA1UEAxMYaWRw\nLmlkZW50aXR5LnVvZ3VlbHBoLmNhMSQwIgYJKoZIhvcNAQkBFhU1ODg4OGhlbHBA\ndW9ndWVscGguY2EwHhcNMTMwMzE4MjAyODA4WhcNMjAwMzE2MjAyODA4WjCBpjEL\nMAkGA1UEBhMCQ0ExEDAOBgNVBAgTB09udGFyaW8xDzANBgNVBAcTBkd1ZWxwaDEd\nMBsGA1UEChMUVW5pdmVyc2l0eSBvZiBHdWVscGgxDDAKBgNVBAsTA0NDUzEhMB8G\nA1UEAxMYaWRwLmlkZW50aXR5LnVvZ3VlbHBoLmNhMSQwIgYJKoZIhvcNAQkBFhU1\nODg4OGhlbHBAdW9ndWVscGguY2EwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQCf2JJF02xujFYTQAlusr9DOOj9Ks7NgzdHoqxTNYDBvlOOsVZjix0SrkNj\nKfxM/HpPnuN5g4ZpEIkzDB+Hws7RaQC1x6VwR7KdwU9ccCY2uVQy1Yae4xnkbI7y\nc5pPVdjFgq6Rgcmq/x9oU69QdVDHv2vFKr+5zo98WvCV1vSu4TBbNAHpzjF4ebEY\nFqBlCTK5adWPdAv3chinpl39wrAPWcdMm2gNM5J4CieeOXdDV3OTbBRjRWJ6JvX0\nV5uYuW1J5K8CEmrYCvLstZDQZo/yP/SHrRTKrsWSwTuxgJ8QF+ZelOJoV9l0eOsU\nVtVpZfglEMd6vxaCK7lrQxAsoPrDAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAH81\n9z02E4SEiLC8MQnGM09a0FpRhL84wN1qX05isEXxdpzWXCAfxFF6/scuLlSaDJ0j\n941kQhb0vyi+ZMX7FkbDBCDYN9FW92qkhJSo5NbB5w/lZzrFYc9t89l+pHlnebFn\n1ndTWqqA989f9FNoJo/FXY+uiTwbs5caDOiMh0ieglYsv5smHi5BlFJ094NWOB/F\nDKwJwmEkoo0CP9dlI7f618eVybyTmpybxqQ7ZViFD4udvfCjl0j7LzUfefyyyWnO\n8cyvzuy5JWgN0W3dzew7FVx7KDCitI7MVkB7xgjQhYelVv5GJOVER69yU18Svzxn\na3M+PZV0yTaCYYLgfmI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uoguelph.ca"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.identity.uoguelph.ca:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.identity.uoguelph.ca:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.identity.uoguelph.ca/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.identity.uoguelph.ca/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.identity.uoguelph.ca/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.identity.uoguelph.ca/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.identity.uoguelph.ca:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.identity.uoguelph.ca:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uoguelph.ca"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uoguelph.ca/"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDyjCCArICCQCluLVINlzKvzANBgkqhkiG9w0BAQUFADCBpjELMAkGA1UEBhMC\nQ0ExEDAOBgNVBAgTB09udGFyaW8xDzANBgNVBAcTBkd1ZWxwaDEdMBsGA1UEChMU\nVW5pdmVyc2l0eSBvZiBHdWVscGgxDDAKBgNVBAsTA0NDUzEhMB8GA1UEAxMYaWRw\nLmlkZW50aXR5LnVvZ3VlbHBoLmNhMSQwIgYJKoZIhvcNAQkBFhU1ODg4OGhlbHBA\ndW9ndWVscGguY2EwHhcNMTMwMzE4MjAyODA4WhcNMjAwMzE2MjAyODA4WjCBpjEL\nMAkGA1UEBhMCQ0ExEDAOBgNVBAgTB09udGFyaW8xDzANBgNVBAcTBkd1ZWxwaDEd\nMBsGA1UEChMUVW5pdmVyc2l0eSBvZiBHdWVscGgxDDAKBgNVBAsTA0NDUzEhMB8G\nA1UEAxMYaWRwLmlkZW50aXR5LnVvZ3VlbHBoLmNhMSQwIgYJKoZIhvcNAQkBFhU1\nODg4OGhlbHBAdW9ndWVscGguY2EwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQCf2JJF02xujFYTQAlusr9DOOj9Ks7NgzdHoqxTNYDBvlOOsVZjix0SrkNj\nKfxM/HpPnuN5g4ZpEIkzDB+Hws7RaQC1x6VwR7KdwU9ccCY2uVQy1Yae4xnkbI7y\nc5pPVdjFgq6Rgcmq/x9oU69QdVDHv2vFKr+5zo98WvCV1vSu4TBbNAHpzjF4ebEY\nFqBlCTK5adWPdAv3chinpl39wrAPWcdMm2gNM5J4CieeOXdDV3OTbBRjRWJ6JvX0\nV5uYuW1J5K8CEmrYCvLstZDQZo/yP/SHrRTKrsWSwTuxgJ8QF+ZelOJoV9l0eOsU\nVtVpZfglEMd6vxaCK7lrQxAsoPrDAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAH81\n9z02E4SEiLC8MQnGM09a0FpRhL84wN1qX05isEXxdpzWXCAfxFF6/scuLlSaDJ0j\n941kQhb0vyi+ZMX7FkbDBCDYN9FW92qkhJSo5NbB5w/lZzrFYc9t89l+pHlnebFn\n1ndTWqqA989f9FNoJo/FXY+uiTwbs5caDOiMh0ieglYsv5smHi5BlFJ094NWOB/F\nDKwJwmEkoo0CP9dlI7f618eVybyTmpybxqQ7ZViFD4udvfCjl0j7LzUfefyyyWnO\n8cyvzuy5JWgN0W3dzew7FVx7KDCitI7MVkB7xgjQhYelVv5GJOVER69yU18Svzxn\na3M+PZV0yTaCYYLgfmI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Guelph"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uoguelph.ca/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Guelph"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.greatplains.net/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kate@greatplains.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kate Adams"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "HancockDC@missouri.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Denis Hancock"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "greg@greatplains.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Greg Monaco"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.greatplains.net/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.greatplains.net:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.greatplains.net:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUFkE64moFaIhXMDCjOYF/pXt+myEwDQYJKoZIhvcNAQEF\nBQAwHjEcMBoGA1UEAxMTaWRwLmdyZWF0cGxhaW5zLm5ldDAeFw0xMjA4MjgxODA4\nMTVaFw0zMjA4MjgxODA4MTVaMB4xHDAaBgNVBAMTE2lkcC5ncmVhdHBsYWlucy5u\nZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDCJb1/fIoXiV9S24Zs\nKIBkZXWFGg4CFofLrt+Ofqe3KScPgrSuOaAIRGFV6H45ffjpxH2O7MegQEfS0T82\nYL6i9fGIBKDelhUaGpQr2lXy0YpxtMuS/U3TgWlj+MQhF5PT9e2hstc1x0zNLPdd\nnLyMuros0Zgqpmx7JgxdLD3WyCpErfYQUL1tOL0L+gZz+Q3hDzj9thZOBbktG9yW\nFYCS10g/2bpF4i+vn0o5sn95Zn2N2KXzn4PyzpRknA3o9g/mL3LVXEj/ZUPMt1xQ\nOGO8e4ipbp9FiSSdcLbRaoangRmTZdr7b3O6Lez1W5oAKHO3XIQ46pXByPevVeQv\ntl1HAgMBAAGjbTBrMEoGA1UdEQRDMEGCE2lkcC5ncmVhdHBsYWlucy5uZXSGKmh0\ndHBzOi8vaWRwLmdyZWF0cGxhaW5zLm5ldC9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4E\nFgQUXYulMzBC7goBszw85WRWDuitUnkwDQYJKoZIhvcNAQEFBQADggEBAFjokVaL\nMFLCkRElu52HjU12YPMOkrFX9i7swTbu5Z+YN8Y1GfN7R0frH5kBB8X3U6bdg/aJ\nZoS8iF/dJR8wGZoU3br8wVLYm7iQOtyxGr1AHuzu0/DfO/P12a/Xnz8AL3ObfUtU\nwuuKwiCIZiXJ66nN4FN77K2Sh1l8Jdm+CvDdJnA7royifENjXYIx/PcM6xx5tH1a\nnLo/T26nCpBMgsgy02vDr7mrjW7MlTONGkyFO3nSv8rkdDMM+55YG8j+JwsMZLij\nO9bdKwzjyxN8V1LdoKcQnW6pgSNaw7TXudUNyLDr7WhXLny2RmDpVgljo7HYm6wH\nUgsT6cj2ibjVHHo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "greatplains.net"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.greatplains.net/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.greatplains.net/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.greatplains.net/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.greatplains.net:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.greatplains.net:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "greatplains.net"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "GPN (Great Plains Network)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUFkE64moFaIhXMDCjOYF/pXt+myEwDQYJKoZIhvcNAQEF\nBQAwHjEcMBoGA1UEAxMTaWRwLmdyZWF0cGxhaW5zLm5ldDAeFw0xMjA4MjgxODA4\nMTVaFw0zMjA4MjgxODA4MTVaMB4xHDAaBgNVBAMTE2lkcC5ncmVhdHBsYWlucy5u\nZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDCJb1/fIoXiV9S24Zs\nKIBkZXWFGg4CFofLrt+Ofqe3KScPgrSuOaAIRGFV6H45ffjpxH2O7MegQEfS0T82\nYL6i9fGIBKDelhUaGpQr2lXy0YpxtMuS/U3TgWlj+MQhF5PT9e2hstc1x0zNLPdd\nnLyMuros0Zgqpmx7JgxdLD3WyCpErfYQUL1tOL0L+gZz+Q3hDzj9thZOBbktG9yW\nFYCS10g/2bpF4i+vn0o5sn95Zn2N2KXzn4PyzpRknA3o9g/mL3LVXEj/ZUPMt1xQ\nOGO8e4ipbp9FiSSdcLbRaoangRmTZdr7b3O6Lez1W5oAKHO3XIQ46pXByPevVeQv\ntl1HAgMBAAGjbTBrMEoGA1UdEQRDMEGCE2lkcC5ncmVhdHBsYWlucy5uZXSGKmh0\ndHBzOi8vaWRwLmdyZWF0cGxhaW5zLm5ldC9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4E\nFgQUXYulMzBC7goBszw85WRWDuitUnkwDQYJKoZIhvcNAQEFBQADggEBAFjokVaL\nMFLCkRElu52HjU12YPMOkrFX9i7swTbu5Z+YN8Y1GfN7R0frH5kBB8X3U6bdg/aJ\nZoS8iF/dJR8wGZoU3br8wVLYm7iQOtyxGr1AHuzu0/DfO/P12a/Xnz8AL3ObfUtU\nwuuKwiCIZiXJ66nN4FN77K2Sh1l8Jdm+CvDdJnA7royifENjXYIx/PcM6xx5tH1a\nnLo/T26nCpBMgsgy02vDr7mrjW7MlTONGkyFO3nSv8rkdDMM+55YG8j+JwsMZLij\nO9bdKwzjyxN8V1LdoKcQnW6pgSNaw7TXudUNyLDr7WhXLny2RmDpVgljo7HYm6wH\nUgsT6cj2ibjVHHo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idp.greatplains.net/idp-errorURL.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GPN (Great Plains Network)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.greatplains.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GPN (Great Plains Network)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dev.emeraldinsight.com/entity",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wood"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rwood@emeraldinsight.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rob"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Parkin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lparkin@emeraldinsight.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Laurence"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dev.emeraldinsight.com/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-05-09T12:25:06Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Emerald Group Publishing Ltd: Emerald Development Site"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://dev.emeraldinsight.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Emerald Group Publishing Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.emeraldinsight.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev.emeraldinsight.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.emeraldinsight.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.emeraldinsight.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "1",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/DS/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/DS/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/DS/Kalmar2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/DS/Kalmar2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/DS/Wayf",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/DS/Wayf",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/WAYF/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/TestShib",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/wayf-test",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/dfn-test",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/dfn-test2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/abu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/asc",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/aru",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/asu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/bsu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/bmu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/blc",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/bfc",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/brc",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/bru",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/bnu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/cac",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/chc",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/cmj",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/cru",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/dmu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/doc",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/enu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/icl",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/kiu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/lsbu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/mmu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/nec",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/ncn",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/nrc",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/nou",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/ntu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/qmu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/qmul",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/rgu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/rou",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/shu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/ssu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/shu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/tvu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/uls",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/umi",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/urhb",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/uab",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/uad",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/ube",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/ubi",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/ubr",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/ubri",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/uco",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/ucu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/ugl",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/uglo",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/ulo",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/uma",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/unut",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/uno",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/upo",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/ure",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/uso",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/usa",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/ust",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/ustr",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/ute",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/ual",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/uwi",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/uwne",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/uwtsd",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/uwa",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/uwe",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/uyo",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/wac",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/wel",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.emeraldinsight.com/Shibboleth.sso/auth/wcc",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.emeraldinsight.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSzCCAjOgAwIBAgIJAPL5yXP0XbhAMA0GCSqGSIb3DQEBBQUAMCoxKDAmBgNV\n\t\t\t\t\t\tBAMTH2VtLWwxLXJoLXVhdC5lbWVyYWxkaW5zaWdodC5jb20wHhcNMTEwNTA1MDc1\n\t\t\t\t\t\tMjEyWhcNMjEwNTAyMDc1MjEyWjAqMSgwJgYDVQQDEx9lbS1sMS1yaC11YXQuZW1l\n\t\t\t\t\t\tcmFsZGluc2lnaHQuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\t1cPpwOpncLWxjS6YxesBuUjX7wyxMf01E7nIcYbdxYYiINMnd2j4Mi3uzdG8qqbp\n\t\t\t\t\t\tINCMvPIgzL2827k28SktsY3AftMAYsAiBDzhFwcUce4mrK3QxofpP+aoH3/oswlZ\n\t\t\t\t\t\tur3rxHLJYWy/0aO9NqJvd9M5hh2K8L4TlD/FvedqRfrFuviNXoXzC5WqoSGxuT4R\n\t\t\t\t\t\tgMP1ChbxzcWvJbhkdHuX/TrDH7lq+NUflJHjXDNsBYO0Ko9IPx9GTwfo0tNth9Ym\n\t\t\t\t\t\t4PZfz6VY5nl4zlDxMktwcOI9ofzAtjAi2MUTDw9YnETqME9I9ums57ke84HCMXSW\n\t\t\t\t\t\t0ToxuMcWkyjGsb2TEi4jqwIDAQABo3QwcjBRBgNVHREESjBIgh9lbS1sMS1yaC11\n\t\t\t\t\t\tYXQuZW1lcmFsZGluc2lnaHQuY29thiVodHRwczovL2Rldi5lbWVyYWxkaW5zaWdo\n\t\t\t\t\t\tdC5jb20vZW50aXR5MB0GA1UdDgQWBBSZx0zhhju5QWnvVBzwzb1HMBk2tTANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAbw4E1yg5C8G5wWcWqPi/c8gG2kIyYdUtAoMxoVrF0NCe\n\t\t\t\t\t\tx0YZUDMLIhUNdHKh1RZMbgKG19pTqUmEjPhfE9VXwfsSIv9QrJiJ2zFH7LbnA7bh\n\t\t\t\t\t\tqnGVhPzee8x88rpS19GcxYitMzifqMxJ7K2bC2++kN87Z5niseL2nSYntB7EmwJp\n\t\t\t\t\t\tEvutgzIJJoH7Xg8KieuPVJKaia1RHpcA4QAeuWPgyZ2Ez+zuszlq2650KCXgQreL\n\t\t\t\t\t\tm0sivyuWv7TZVl8D+cLucd23bwknQLioqhhpdwmXrpcKyRHPaRrf3iznD/cHd0Ps\n\t\t\t\t\t\tlHVWGtQ0Nh/tJIKoMcDif+nTn+Hm4+au0NFb1pX40A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.emeraldinsight.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev.emeraldinsight.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.emeraldinsight.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.emeraldinsight.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.emeraldinsight.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dev.emeraldinsight.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.emeraldinsight.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dev.emeraldinsight.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dev.emeraldinsight.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dev.emeraldinsight.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth2sp.brillonline.nl/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:brill-shibboleth-support@semantico.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:brill-shibboleth-support@semantico.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth2sp.brillonline.nl/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Semantico Limited: Brill Shibboleth 2 SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.brill.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Semantico Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.brillonline.nl/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.brillonline.nl/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.brillonline.nl/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.brillonline.nl/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.brillonline.nl/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID1jCCAr6gAwIBAgIJANySKK7sPqq+MA0GCSqGSIb3DQEBBQUAMGwxCzAJBgNV\n\t\t\t\t\t\tBAYTAlVLMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIwEAYD\n\t\t\t\t\t\tVQQKEwlzZW1hbnRpY28xJTAjBgNVBAMTHHNoaWJib2xldGgyc3AuYnJpbGxvbmxp\n\t\t\t\t\t\tbmUubmwwHhcNMTUwNzMwMTAzNDI5WhcNMzUwNzI1MTAzNDI5WjBsMQswCQYDVQQG\n\t\t\t\t\t\tEwJVSzEPMA0GA1UECBMGU3Vzc2V4MREwDwYDVQQHEwhCcmlnaHRvbjESMBAGA1UE\n\t\t\t\t\t\tChMJc2VtYW50aWNvMSUwIwYDVQQDExxzaGliYm9sZXRoMnNwLmJyaWxsb25saW5l\n\t\t\t\t\t\tLm5sMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzDGthKGzhqlGBQcB\n\t\t\t\t\t\tu9c2+gPZvoL8QcIfYuz7gyMi1hs4ZQEK/mNwiM2wSbMcG44yvXPcDFSYiKmPtykJ\n\t\t\t\t\t\tGXRMlSS2Q9O5F5eOnZU40sl4s6Va2oK6SyKA0RnFKwt9svLjHbmMbobQEB4hRdNX\n\t\t\t\t\t\tJu9YHL+ql33rAhCdmnDuBmtfPvgu0V6uqb1x5yXShYQdXwD0o6gaBXcxIfDZfCqw\n\t\t\t\t\t\tZLeV9XmdRAX5viX2tBp2B6CNT4uPPyhIdVJ6P299xfMwrkKD8+OxzgPn9wYxzq0J\n\t\t\t\t\t\tvd7WwKFD4Z6waUHTbU2KLVcaCmEZz19K9xofDon1pi+GLUrQawf82mQKGHAhH8Jw\n\t\t\t\t\t\t+L2tkwIDAQABo3sweTBYBgNVHREEUTBPghxzaGliYm9sZXRoMnNwLmJyaWxsb25s\n\t\t\t\t\t\taW5lLm5shi9odHRwczovL3NoaWJib2xldGgyc3AuYnJpbGxvbmxpbmUubmwvc2hp\n\t\t\t\t\t\tYmJvbGV0aDAdBgNVHQ4EFgQUyOAI3XrlGiIPV0Tofnyk2xSjn1IwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAHyrsIjUUcOSIc5+zVKRH59MFbEjeYMPomEeJmFOxojwDlSbhZ4b\n\t\t\t\t\t\t2K2iTcCXlY8rtuuYLrWTLGyhJW+xWGRAJFJwD6F6WHJFEklMYeIAmlXKzCJJKuJn\n\t\t\t\t\t\trFzPjibYq2YafhbKn5N8k2QUJKOIhgg4FAWsGXLrcR/7W0LJCg5l2fPyDH/KbRzP\n\t\t\t\t\t\tOgBYciKv5fbMr+vSM8LYJ9zAKYWsyg3yo6Hrf8RQKsn0ptaSOqJZf0W4mGlH3Ug5\n\t\t\t\t\t\tGUyHWM3Hk/NPMuV49u+GU/beegr/XVyLUTMj1EyxCPpXr5bShe1sZ73TVQ51b6am\n\t\t\t\t\t\tuVOG89dvf99DIrLXGx9zxyM6HTWXTmaT/9A="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.brillonline.nl/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.brillonline.nl/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.brillonline.nl/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.brillonline.nl/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.brillonline.nl/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth2sp.brillonline.nl/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.brillonline.nl/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth2sp.brillonline.nl/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth2sp.brillonline.nl/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth2sp.brillonline.nl/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.bath.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webmaster@bath.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Webmaster"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Phillips"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:R.I.Phillips@bath.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.bath.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2007-09-21T13:17:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAOqBrGCnJlQiSzyI6NPPnvws1tCfMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBoxGDAWBgNVBAMTD2F1dGguYmF0aC5hYy51azAeFw0xMTA4MTYwNjM1MjVa\n\t\t\t\t\t\tFw0zMTA4MTYwNjM1MjVaMBoxGDAWBgNVBAMTD2F1dGguYmF0aC5hYy51azCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL95cyOywpJXBzn8efSdlNIJQiZi\n\t\t\t\t\t\tdNagu7t8YjInzqARwzB/7Ii2QHNkYVbOHeYuRdlQGeSS350NdHV7Cyn4IhurrEUW\n\t\t\t\t\t\tNG9JFQ1knyw2O6A8ZkoT6QE5XBt1j/aQi9emY8id3vcIdZCWFVRBVjEZ6BR58ne9\n\t\t\t\t\t\t5FGMVVusGfHgtayt3MoJvQUcl7m7bP+mvNwPL/wXBWmvg83g3Ngi6B4R3uHY0kkL\n\t\t\t\t\t\thSsYJEkoX91cv7RAspKYDjtuhdrvoywcwltwD7GDs+e6wXAdMyVgMRNq2ACK+age\n\t\t\t\t\t\tIQCWZ3o/1cd0RFAVCwmUOzGd4jFmqaWneQFK+DqFyOxTW3LO3zLZ3xq22RsCAwEA\n\t\t\t\t\t\tAaNlMGMwQgYDVR0RBDswOYIPYXV0aC5iYXRoLmFjLnVrhiZodHRwczovL2F1dGgu\n\t\t\t\t\t\tYmF0aC5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUMBAXgoXqNZufAstd\n\t\t\t\t\t\tXJjQBDQka9wwDQYJKoZIhvcNAQEFBQADggEBAJlY93MwsogYvqEA32y+uhe516tb\n\t\t\t\t\t\tVpnagIQ6EdPfZlibvHM5RQy1sYdSXkg5aab1aBP05yaA/S23DARAQocbBUGvmM3q\n\t\t\t\t\t\t2Kv/r6XoGZxWZp1d0iIRnDnRBcY/KlGqzoHGOpEp06wgbUSSrYQAgLMcZat7lER7\n\t\t\t\t\t\tTRrqZ6mwhHVpiJkRsZWTshVZEw0Mz44NoeADcM2Ao6U+h6oc9CCJmBguXdPFH+ti\n\t\t\t\t\t\tgc9lPrivWMfMU64EedcDvakTkW8wPne4BklOmYPecOG6k/CW8F27k0T7nuJKKa41\n\t\t\t\t\t\twVJCyjIVKbGuDsEITTV/TE4sTDQCvRXjKF3enji4c0Ap3MBGaCBo/FDYXAI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bath.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://auth.bath.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://auth.bath.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://auth.bath.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.bath.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://auth.bath.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.bath.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://auth.bath.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://auth.bath.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bath.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://auth.bath.ac.uk/images/mdui-logo-trans.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "159"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Bath"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAOqBrGCnJlQiSzyI6NPPnvws1tCfMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBoxGDAWBgNVBAMTD2F1dGguYmF0aC5hYy51azAeFw0xMTA4MTYwNjM1MjVa\n\t\t\t\t\t\tFw0zMTA4MTYwNjM1MjVaMBoxGDAWBgNVBAMTD2F1dGguYmF0aC5hYy51azCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL95cyOywpJXBzn8efSdlNIJQiZi\n\t\t\t\t\t\tdNagu7t8YjInzqARwzB/7Ii2QHNkYVbOHeYuRdlQGeSS350NdHV7Cyn4IhurrEUW\n\t\t\t\t\t\tNG9JFQ1knyw2O6A8ZkoT6QE5XBt1j/aQi9emY8id3vcIdZCWFVRBVjEZ6BR58ne9\n\t\t\t\t\t\t5FGMVVusGfHgtayt3MoJvQUcl7m7bP+mvNwPL/wXBWmvg83g3Ngi6B4R3uHY0kkL\n\t\t\t\t\t\thSsYJEkoX91cv7RAspKYDjtuhdrvoywcwltwD7GDs+e6wXAdMyVgMRNq2ACK+age\n\t\t\t\t\t\tIQCWZ3o/1cd0RFAVCwmUOzGd4jFmqaWneQFK+DqFyOxTW3LO3zLZ3xq22RsCAwEA\n\t\t\t\t\t\tAaNlMGMwQgYDVR0RBDswOYIPYXV0aC5iYXRoLmFjLnVrhiZodHRwczovL2F1dGgu\n\t\t\t\t\t\tYmF0aC5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUMBAXgoXqNZufAstd\n\t\t\t\t\t\tXJjQBDQka9wwDQYJKoZIhvcNAQEFBQADggEBAJlY93MwsogYvqEA32y+uhe516tb\n\t\t\t\t\t\tVpnagIQ6EdPfZlibvHM5RQy1sYdSXkg5aab1aBP05yaA/S23DARAQocbBUGvmM3q\n\t\t\t\t\t\t2Kv/r6XoGZxWZp1d0iIRnDnRBcY/KlGqzoHGOpEp06wgbUSSrYQAgLMcZat7lER7\n\t\t\t\t\t\tTRrqZ6mwhHVpiJkRsZWTshVZEw0Mz44NoeADcM2Ao6U+h6oc9CCJmBguXdPFH+ti\n\t\t\t\t\t\tgc9lPrivWMfMU64EedcDvakTkW8wPne4BklOmYPecOG6k/CW8F27k0T7nuJKKa41\n\t\t\t\t\t\twVJCyjIVKbGuDsEITTV/TE4sTDQCvRXjKF3enji4c0Ap3MBGaCBo/FDYXAI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Bath"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bath.ac.uk/bucs/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Bath"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://clarin.oeaw.ac.at/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "\u017b\u00f3\u0142tak"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mateusz.zoltak@oeaw.ac.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mateusz"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Durco"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:matej.durco@oeaw.ac.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matej"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "M\u00f6rth"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:karlheinz.moerth@oeaw.ac.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Karlheinz"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Office"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:acdh-tech@oeaw.ac.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ACDH"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@oeaw.ac.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Akademie-Rechenzentrum"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://clarin.oeaw.ac.at/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://eduid.at/policy/mdrps-20140606"
              }
            ],
            "registration_instant": "2014-01-23T16:00:00Z",
            "registration_authority": "http://eduid.at",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u00d6sterreichisches Zentrum f\u00fcr Digitale Geisteswissenschaften der \u00d6sterreichischen Akademie der Wissenschaften (ACDH-AW)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Austrian Centre for Digital Humanities of the Austrian Academy of Sciences (ACDH-AW)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://acdh.oeaw.ac.at/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u00d6sterreichische Akademie der Wissenschaften"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Austrian Academy of Sciences"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://clarin.oeaw.ac.at/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://clarin.oeaw.ac.at/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://clarin.oeaw.ac.at/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://clarin.oeaw.ac.at/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://clarin.oeaw.ac.at/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://clarin.oeaw.ac.at/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://clarin.oeaw.ac.at/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://acdh.oeaw.ac.at"
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://acdh.oeaw.ac.at"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ACDH-AW Services for Digital Humanities"
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ACDH-AW Dienste f\u00fcr Digitale Geisteswissenschaften"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Various services provided by the Austrian Centre for Digital Humanities of the Austrian Academy of Sciences (ACDH-AW) (primarily in the context of the CLARIN initiative)."
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Verschiedene Dienste des \u00f6sterreichischen Zentrums f\u00fcr Digitale Geisteswissenschaften der \u00d6sterreichischen Akademie der Wissenschaften (ACDH-AW) (prim\u00e4r im Rahmen der CLARIN-Initiative)."
                  }
                ],
                "logo": [
                  {
                    "text": "https://clarin.oeaw.ac.at/sites/clarin.oeaw.ac.at/files/ccv_logo_v1b.png",
                    "height": "70",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "55"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://clarin.oeaw.ac.at/privacy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJAI3rKBVKUcUJMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\nBAMTFWNsYXJpbi5hcnoub2Vhdy5hYy5hdDAeFw0xNDAxMjAxNDU3MThaFw0yNDAx\nMTgxNDU3MThaMCAxHjAcBgNVBAMTFWNsYXJpbi5hcnoub2Vhdy5hYy5hdDCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMJ8B6WyydvbvIHJ1Cb34h8838G5\nJItPpmJC+D/K+6MI3YiydVKKlhaGh/GqcWcz0Qw30W7WYilUZ5IkzZA12QY1CF1g\ncJPNUmYibzP3sAZ9KrvaCEMxlseoldh0yc+8Q8eplQH9id4u5G+J8SvTBejt261y\nATb6pIANsRQkOLMvxtq7/NrEnAmZQOM5obsshHxLlXlJ0qixakaYXWKCIuUUOEFY\nFT13vhWrUC4BWW0OGimoR1cBnyEJtS9kRNWQ85+03VVVvLk9AssoHWxOJVJ7HE1m\n5/xgMrmpOv1vbqDKDljrY19zheNOoFr3RdaSCb1Eh8lWCNigUgOwK8Mm7VECAwEA\nAaNDMEEwIAYDVR0RBBkwF4IVY2xhcmluLmFyei5vZWF3LmFjLmF0MB0GA1UdDgQW\nBBQ6IH3aND4GFYEEgrR0IKf/d4QEcDANBgkqhkiG9w0BAQUFAAOCAQEAhdcxQ+7/\n1WYPCTVz2HOk8J3eM3ZJylGdTnfgNDDGkBo0CGmyiulX8m+nimBKh7UNMkRkU8cH\nNUldSGR70wi0iQlx7t868V5pmkqxnaDu4+lo1QU59s5c7MRJXZ6OcbKB57O/d5l+\n+kX3/YW9WAQkmwcyVWDbcmk4DZK5kqqTk+u3fS48cLqai5YVcj8pDDoUx6/ZkwDv\nYqvva2v4+vhzX9SW3QyiChOgFo9sP/UD1U8JAZG0sds5ugwjwiXPPB41hwHdbdEj\nQZRW2NR0HHMFp0FZeSziXOeaap21wc/W1Nk7wpRI7jYdzLRJHmzhvWz95p0WSnt+\nrI8v6OTvibpLrg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://clarin.oeaw.ac.at/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://clarin.oeaw.ac.at/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://clarin.oeaw.ac.at/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://clarin.oeaw.ac.at/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://clarin.oeaw.ac.at/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://clarin.oeaw.ac.at/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://acdh.oeaw.ac.at/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://acdh.oeaw.ac.at/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://acdh.oeaw.ac.at/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://acdh.oeaw.ac.at/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://acdh.oeaw.ac.at/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://acdh.oeaw.ac.at/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ACDH-AW Services for Digital Humanities"
                },
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ACDH-AW Dienste f\u00fcr Digitale Geisteswissenschaften"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Various services provided by the Austrian Centre for Digital Humanities of the Austrian Academy of Sciences (ACDH-AW) (primarily in the context of the CLARIN initiative)."
                },
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Verschiedene Dienste des \u00f6sterreichischen Zentrums f\u00fcr Digitale Geisteswissenschaften der \u00d6sterreichischen Akademie der Wissenschaften (ACDH-AW) (prim\u00e4r im Rahmen der CLARIN-Initiative)."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ssp.kennedy.ox.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kirit@kennedy.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kennedy Institute IT"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Marsden"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:brian.marsden@kennedy.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ssp.kennedy.ox.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-01-19T12:23:40Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Oxford, Kennedy Institute of Rheumatology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kennedy.ox.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Oxford"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ssp.kennedy.ox.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ssp.kennedy.ox.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ssp.kennedy.ox.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ssp.kennedy.ox.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ssp.kennedy.ox.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ssp.kennedy.ox.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAKA5lz2cCSdXMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\n\t\t\t\t\t\tBAMTFHNzcC5rZW5uZWR5Lm94LmFjLnVrMB4XDTE2MDExNDE0MzQwMFoXDTI2MDEx\n\t\t\t\t\t\tMTE0MzQwMFowHzEdMBsGA1UEAxMUc3NwLmtlbm5lZHkub3guYWMudWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDF0ouTfpTeE7vfQ+5CBQou0Us95S/g\n\t\t\t\t\t\tyQJlZYxK/IlnDf/CUTYRrr3gLyEvmu1VsApqb2z58QquO/HvzY9F92X9esydACLz\n\t\t\t\t\t\tbeIP6lKkPpmGJ9S84Fd9hYCkXtfIomgMBMGmjn5hvEuSr6PmFqvtQlY/jtIarAV/\n\t\t\t\t\t\tcummcTPvtg/q6xgCTVcFIszD4j2ljdag9M5NaJ+mWs1WtcVCRRUiMUPdGKQlZ0Vh\n\t\t\t\t\t\tUbdYjRxF6EItfPck0i9+fkcifCu2kLwVNdY3lOQ5bg1w/nDnNnbnN+L3ZHdSOjls\n\t\t\t\t\t\tQyqH8EQ7Myz9ZnH2jRGWIwYmFPOLRuaHm/8Etp5u3bqkVz/kcQNFya+3AgMBAAGj\n\t\t\t\t\t\tazBpMEgGA1UdEQRBMD+CFHNzcC5rZW5uZWR5Lm94LmFjLnVrhidodHRwczovL3Nz\n\t\t\t\t\t\tcC5rZW5uZWR5Lm94LmFjLnVrL3NoaWJib2xldGgwHQYDVR0OBBYEFEqOtgn1iydX\n\t\t\t\t\t\tBwVOh1ZwBn/KnAzKMA0GCSqGSIb3DQEBBQUAA4IBAQAakJmRBd0pyIrVE0Bp+27x\n\t\t\t\t\t\t6c22Ls4RM+S+wOqOAs9VtQUY0OgLXnkLKatbXpWlBWfF6gYHf+Y404Bodf6fFClS\n\t\t\t\t\t\tX2GoXLuvRNrwMZq0g59rFRpAnbDOZVzK0duqNMKvmrVlLdo5jL1aUO5J5FQdkgYL\n\t\t\t\t\t\tLEqWhOKgn+ABisqdMbQd8LPKbg/lquvum0iPhpULXLgzn4laM1rOlcyhJxX1ekFT\n\t\t\t\t\t\tt7lCrX6c6vFUpYm+MG953JCIFO4jR+qRTRbGH8vep7i7EZWfIVCwO+Z6QvCr3lQc\n\t\t\t\t\t\tYS69W08VipSY/2dpHXFVFzTTP9FTSehQU7oPKjHzgKWZsq8iVBIq5Z/FjS+FNr3R"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ssp.kennedy.ox.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ssp.kennedy.ox.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ssp.kennedy.ox.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ssp.kennedy.ox.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ssp.kennedy.ox.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ssp.kennedy.ox.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.careknowledge.com/ukfed/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smith"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tim.smith@olmgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smith"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tim.smith@olmgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.careknowledge.com/ukfed/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-09-04T12:52:01Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Pavilion Publishing and Media Ltd"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.careknowledge.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "OLM Pavilion Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CareKnowledge helps you keep your social care knowledge and practice up to date."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.careknowledge.com/App_Themes/ck/img/logo-full-colour.gif",
                    "height": "110",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "275"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CareKnowledge"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDgjCCAmqgAwIBAgIJAOJNb5Ku1GAjMA0GCSqGSIb3DQEBBQUAMDQxFjAUBgNV\n\t\t\t\t\t\tBAoTDU9MTSBHcm91cCBMdGQxGjAYBgNVBAMTEWNhcmVrbm93bGVkZ2UuY29tMB4X\n\t\t\t\t\t\tDTE1MDkwMTA5MDEwMVoXDTI1MDgyOTA5MDEwMVowNDEWMBQGA1UEChMNT0xNIEdy\n\t\t\t\t\t\tb3VwIEx0ZDEaMBgGA1UEAxMRY2FyZWtub3dsZWRnZS5jb20wggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQD7ev4zyQ7HMiCkbYWVpiSSA2Omj5CXbhLnad3L\n\t\t\t\t\t\tHDbCkBwxYaCZXP7fpUf0hemOYyw7fNt1J/qs9kHCb8qafSv6rVcq+fPcDcYsjGQi\n\t\t\t\t\t\tVuTvU+VTvp2URoTLCDrWB1Kwhz0Q2EmltOJcoUsmHAHSPUuozYsIyzjIUCi9lihk\n\t\t\t\t\t\tIFpyqBu7dqmbeUcy33xCvme+pcbJLWhfvQow5T0rYiL0o9xkicsJu7pvo63QK5BP\n\t\t\t\t\t\tuxcY0hiwPR/Out0D7d0wQZOhxSJsAHE97Z4VDG0aLmLYGmXeo/v1QJ4Yx//Di0R0\n\t\t\t\t\t\tnRWIhLpjBHMxN2QxX4Y0FNTJjVqp/0mDplkUYLD2udVEdGPZAgMBAAGjgZYwgZMw\n\t\t\t\t\t\tHQYDVR0OBBYEFB2NMoBoS8qF/fkjhMN4LwWNySZ3MGQGA1UdIwRdMFuAFB2NMoBo\n\t\t\t\t\t\tS8qF/fkjhMN4LwWNySZ3oTikNjA0MRYwFAYDVQQKEw1PTE0gR3JvdXAgTHRkMRow\n\t\t\t\t\t\tGAYDVQQDExFjYXJla25vd2xlZGdlLmNvbYIJAOJNb5Ku1GAjMAwGA1UdEwQFMAMB\n\t\t\t\t\t\tAf8wDQYJKoZIhvcNAQEFBQADggEBAF7fI3GQsUNkl+owumSNj3v55CccAVxvcFDL\n\t\t\t\t\t\tkdt+s7o1PUAz8hHl+66nUN+YkTX2d5bYm+A9y2BxOdPnmENdxakBlie6Hg/xcA/y\n\t\t\t\t\t\teZprTXMN4TZU2fdAt9LgVluYMOYv/4p6CjwC8R4HzBpSJYU81WaI+UK/9HF0NiOS\n\t\t\t\t\t\tT6vyGj8/GEHzGU3g5jvAgBMNiLH9LfPZxa2nG6/Z7ZSTmsQg2ZKy2DsGDAMWqAK7\n\t\t\t\t\t\t1E1VZ+aWVHjwYQwYYI0dMVXneNLgdgqnwZzKgdWA9XgfPAyHtn+9Nip1xdxMLgOh\n\t\t\t\t\t\t14Vn2MYizmznFanAaXjq/VTYfu7b9KwW7Nl91socK3ZCSS4e04Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDgjCCAmqgAwIBAgIJAOJNb5Ku1GAjMA0GCSqGSIb3DQEBBQUAMDQxFjAUBgNV\n\t\t\t\t\t\tBAoTDU9MTSBHcm91cCBMdGQxGjAYBgNVBAMTEWNhcmVrbm93bGVkZ2UuY29tMB4X\n\t\t\t\t\t\tDTE1MDkwMTA5MDEwMVoXDTI1MDgyOTA5MDEwMVowNDEWMBQGA1UEChMNT0xNIEdy\n\t\t\t\t\t\tb3VwIEx0ZDEaMBgGA1UEAxMRY2FyZWtub3dsZWRnZS5jb20wggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQD7ev4zyQ7HMiCkbYWVpiSSA2Omj5CXbhLnad3L\n\t\t\t\t\t\tHDbCkBwxYaCZXP7fpUf0hemOYyw7fNt1J/qs9kHCb8qafSv6rVcq+fPcDcYsjGQi\n\t\t\t\t\t\tVuTvU+VTvp2URoTLCDrWB1Kwhz0Q2EmltOJcoUsmHAHSPUuozYsIyzjIUCi9lihk\n\t\t\t\t\t\tIFpyqBu7dqmbeUcy33xCvme+pcbJLWhfvQow5T0rYiL0o9xkicsJu7pvo63QK5BP\n\t\t\t\t\t\tuxcY0hiwPR/Out0D7d0wQZOhxSJsAHE97Z4VDG0aLmLYGmXeo/v1QJ4Yx//Di0R0\n\t\t\t\t\t\tnRWIhLpjBHMxN2QxX4Y0FNTJjVqp/0mDplkUYLD2udVEdGPZAgMBAAGjgZYwgZMw\n\t\t\t\t\t\tHQYDVR0OBBYEFB2NMoBoS8qF/fkjhMN4LwWNySZ3MGQGA1UdIwRdMFuAFB2NMoBo\n\t\t\t\t\t\tS8qF/fkjhMN4LwWNySZ3oTikNjA0MRYwFAYDVQQKEw1PTE0gR3JvdXAgTHRkMRow\n\t\t\t\t\t\tGAYDVQQDExFjYXJla25vd2xlZGdlLmNvbYIJAOJNb5Ku1GAjMAwGA1UdEwQFMAMB\n\t\t\t\t\t\tAf8wDQYJKoZIhvcNAQEFBQADggEBAF7fI3GQsUNkl+owumSNj3v55CccAVxvcFDL\n\t\t\t\t\t\tkdt+s7o1PUAz8hHl+66nUN+YkTX2d5bYm+A9y2BxOdPnmENdxakBlie6Hg/xcA/y\n\t\t\t\t\t\teZprTXMN4TZU2fdAt9LgVluYMOYv/4p6CjwC8R4HzBpSJYU81WaI+UK/9HF0NiOS\n\t\t\t\t\t\tT6vyGj8/GEHzGU3g5jvAgBMNiLH9LfPZxa2nG6/Z7ZSTmsQg2ZKy2DsGDAMWqAK7\n\t\t\t\t\t\t1E1VZ+aWVHjwYQwYYI0dMVXneNLgdgqnwZzKgdWA9XgfPAyHtn+9Nip1xdxMLgOh\n\t\t\t\t\t\t14Vn2MYizmznFanAaXjq/VTYfu7b9KwW7Nl91socK3ZCSS4e04Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://www.careknowledge.com/ukfed/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.careknowledge.com/ukfed/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://beta.projecteuclid.org/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ruddy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:EUCLID-TECH-L@cornell.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kim"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:EUCLID-TECH-L@cornell.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shinwoo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://beta.projecteuclid.org/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-09-17T14:15:37Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Project Euclid -- TEST"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://projecteuclid.org/about"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cornell University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://beta.projecteuclid.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://beta.projecteuclid.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://beta.projecteuclid.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://beta.projecteuclid.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://beta.projecteuclid.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://beta.projecteuclid.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://beta.projecteuclid.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://beta.projecteuclid.org/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://beta.projecteuclid.org/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNjCCAh6gAwIBAgIJANq1a2ZDBykIMA0GCSqGSIb3DQEBBQUAMDAxLjAsBgNV\n\t\t\t\t\t\tBAMTJXNmLWxpYi1hcHAtMDA4LnNlcnZlcmZhcm0uY29ybmVsbC5lZHUwHhcNMTMw\n\t\t\t\t\t\tNTMxMTUwNjIyWhcNMjMwNTI5MTUwNjIyWjAwMS4wLAYDVQQDEyVzZi1saWItYXBw\n\t\t\t\t\t\tLTAwOC5zZXJ2ZXJmYXJtLmNvcm5lbGwuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAs3Hxfw7oGscg+A30MSnTHdbuukajMhIlCtrm+bfsayPDApUE\n\t\t\t\t\t\tQLxW643U876lLNxMA5wmU0NV07gjj87yqv7ECGPLq95tIoTcTzI0MXLr8s3GTzwT\n\t\t\t\t\t\tM9N0LEWdp37CRH2kgvYA3Cf5Oba8FxpEDHgc6rzAc2LccucdpWvi8Zon9OLZuEsH\n\t\t\t\t\t\tqAjQlfIeuSB7YIe6z2/7VbZM9CcAb80cwYButlqMdIOcS7jBqofGq9YvovXJr7F0\n\t\t\t\t\t\tvEXJtiL7fW28Lmv2SHdS2mL/34ud2fj5CEDaXAzKWCiDR0L7a1qYNW7upxD+w6no\n\t\t\t\t\t\trDAYfWrO8E6mcXv1d8P1JKLzsaZKopsuHE3BtQIDAQABo1MwUTAwBgNVHREEKTAn\n\t\t\t\t\t\tgiVzZi1saWItYXBwLTAwOC5zZXJ2ZXJmYXJtLmNvcm5lbGwuZWR1MB0GA1UdDgQW\n\t\t\t\t\t\tBBSu8boXmoNWqSqD0y4uSmiE8p1EHzANBgkqhkiG9w0BAQUFAAOCAQEAQXOGXl4Y\n\t\t\t\t\t\tfTXnrJQuD1xaOmLgUkLpN4eq89OisGTsdefpvAJ1SD6QSaIj1UFchfQ6Qb4vK2Fp\n\t\t\t\t\t\tE1Ss6sZNU0rCE/C1EpQplAkQve8+IhQdIOQM7B/Yp4lHWd+3snJLF+fmIczVu9DB\n\t\t\t\t\t\todqQ2YbmpxPDBzZMRAIppajebSXLz2r65Uj8+cB28v4WhCt7v/T3M8w4h591pePO\n\t\t\t\t\t\txW2fpyIqGsGpuVRd2EOkYGmm7nqrAH9WGyUsRT1YHFY25mjgExVPYpah7eTsNYql\n\t\t\t\t\t\tfQHR5b61zSESkl8vo6eFRgzRnETr/fNIj08nhs3UCEfuYVy1yVKv2lHLzIvDTot/\n\t\t\t\t\t\tTyOzJ1GTj16SNA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://beta.projecteuclid.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://beta.projecteuclid.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://beta.projecteuclid.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://beta.projecteuclid.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://beta.projecteuclid.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://beta.projecteuclid.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Project Euclid -- TEST"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Project Euclid, an online publishing service for theoretical and applied mathematics and statistics."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonTargetedID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ittralee.ie/idp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Quirke"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:andrew.quirke@staff.ittralee.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bradshaw"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chris.bradshaw@staff.ittralee.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dineen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:padraig.dineen@staff.ittralee.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Padraig"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ittralee.ie/idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2010-11-04T00:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ittralee.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ittralee.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ittralee.ie/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ittralee.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ittralee.ie"
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/ittra.png",
                    "height": "62",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "248"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Technology Tralee"
                  },
                  {
                    "lang": "ga",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institi\u00faid Teicneola\u00edochta, Tr\u00e1 L\u00ed"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:52.28620934512703,-9.67296838760376"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDmDCCAoACCQCvcZzmkJJefjANBgkqhkiG9w0BAQUFADCBjTELMAkGA1UEBhMC\nSUUxEDAOBgNVBAgTB011bnN0ZXIxDzANBgNVBAcTBlRyYWxlZTEnMCUGA1UEChMe\nSW5zdGl0dXRlIG9mIFRlY2hub2xvZ3kgVHJhbGVlMRQwEgYDVQQLEwtJVCBTZXJ2\naWNlczEcMBoGA1UEAxMTSVQgVHJhbGVlIFNBTUwgQ2VydDAeFw0xNjAyMTcxMTQx\nMjJaFw0xNzAyMTYxMTQxMjJaMIGNMQswCQYDVQQGEwJJRTEQMA4GA1UECBMHTXVu\nc3RlcjEPMA0GA1UEBxMGVHJhbGVlMScwJQYDVQQKEx5JbnN0aXR1dGUgb2YgVGVj\naG5vbG9neSBUcmFsZWUxFDASBgNVBAsTC0lUIFNlcnZpY2VzMRwwGgYDVQQDExNJ\nVCBUcmFsZWUgU0FNTCBDZXJ0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAsSlLOaTLT3euymTBbf/fXo/z+VaDyW1GzlxYrMyyD5KxUPOfg/plR5sP48I0\nrAHH1TUcksqFd4+955jQEui7EM/7FoqYYXtsSIH+XZakvc81CpjOApQmRauN3LM2\n1cftSbJKmuYxpLTUe2cBEw5sTpG9i4G8VSwDU8MUEtC65IR9JMx0UoaN88PznlSd\nmgVln0pkP/CeLPKA54rEpGA6NidIwjn8S+myowP7QMDCBOChC1n0zKI3ruWqcMHU\nO4rNrMY+Rw+JK65c159OhLQQbq2peUVvCiSrsv3JOL6eGBId1e/U+cKZnBP8ti57\nsem3QZfG2cIWTj4U3p2hAu3K3wIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQBXuwp3\n7KOWoC0c6kQzwZXXNhUCGObIAKU/0ni/Z1aYYp4PooliL3d4cTgzSmeVus66X/Fm\nqL+TILYVzBY0SnF3D62qFaLEDMmrS6DibZ7ma8Tob9GMVyaVGuWZGfV+p2FjNqY8\nIadl1kiCBhNst+r7XvIn5OmqPihhlAvG94BD488MxDOygrinimzUF0vB+zrOVwxo\nr+1A8dYo/Q4pe4HchkK+bp8Uxg8D6Qkp/zWlWfUGJqU7SbhOE/tp1SW1GYDjkRKw\nbgyUlPiEHeB/o2fUwUV3PxrUpgt5sohBPH/x5ZG620GYODoZqdPVZ7NDZp0+UIcE\n6AWAe75jwYVCSeU3"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Technology Tralee"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ittralee.ie"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Technology Tralee"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ssp-dev.data.alpha.jisc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Baylis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lee.baylis@jisc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lee"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Baylis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lee.baylis@jisc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lee"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ssp-dev.data.alpha.jisc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-02-17T11:17:59Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Jisc Student Success Planner (Development)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.jisc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Jisc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ssp-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ssp-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ssp-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ssp-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ssp-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ssp-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Access to the Development version of the Jisc Student Success Planner"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.jisc.ac.uk/sites/all/themes/jisc_clean/logo.png",
                    "height": "34",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "61"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Jisc Student Success Planner (Development)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHjCCAgagAwIBAgIJAKYa1eymRKyTMA0GCSqGSIb3DQEBBQUAMCgxJjAkBgNV\n\t\t\t\t\t\tBAMTHXNzcC1kZXYuZGF0YS5hbHBoYS5qaXNjLmFjLnVrMB4XDTE2MDIxMDA5MjAx\n\t\t\t\t\t\tMFoXDTI2MDIwNzA5MjAxMFowKDEmMCQGA1UEAxMdc3NwLWRldi5kYXRhLmFscGhh\n\t\t\t\t\t\tLmppc2MuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCvbrQn\n\t\t\t\t\t\tK7QGj3KX66sbiqwn77f5g0TgTq8I7yaaT0IDbAdCXSkCcHEVmVclN+5zsFLQ+QJH\n\t\t\t\t\t\tTiXxoOPFiB3vo4IPCMKTokm6WHy1R9GDBWfc17Gml6cyinTfMWIZ5akl5RrL72UG\n\t\t\t\t\t\t8dQzerapI3HvBQi72gnN9+Y7wZy3mkRWQvCT3y7VHSAV8SP87a+I4gd3xAbFwg8E\n\t\t\t\t\t\ty5KxwBShs6Qe9iTaUcR68hcO66b6SaV+UkTASQDPvMgjWG+r9RPWq416BtiRoObC\n\t\t\t\t\t\tiYeOm755Ej3eGmI107F0JL21wKfU69CyYFptJFREw9r7J4Ursb7lCJx2Q16Z7iAZ\n\t\t\t\t\t\tZxiMIsYJfQrF2f9hAgMBAAGjSzBJMCgGA1UdEQQhMB+CHXNzcC1kZXYuZGF0YS5h\n\t\t\t\t\t\tbHBoYS5qaXNjLmFjLnVrMB0GA1UdDgQWBBRO39aIaVdqmoVWn+hVUEGd6XP/LzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAiNOnM5bIdTl00hVkCX/QRP2JiSH8HCVlDMbuSnC9\n\t\t\t\t\t\to7zj5rtka6SyXIXtrGKQn8uMBEb9BnSJh2OxfNUzhFaZV+kG1EnTkJjuWGhvzlCL\n\t\t\t\t\t\tuOJZFyYr5ny8f07lpPmCZqJq05XnPNDoGz2SrQNhNSLnylMrSe++DFBVmnsUf/TP\n\t\t\t\t\t\tNGRX3aWMJ3gfUEcOKa/pNafhcfRFJLbYnP7uIEEYSZqrRsRmZi3M+IPq9s48R8Zf\n\t\t\t\t\t\tPi5X8ZdGWC5t1XlUScpXMcxvNEJAD4OJ5EI+OrjpWKkNc3vIae10xBnf/a3Kzngi\n\t\t\t\t\t\tkJ7iQp3l8CU7AsqKSHqBcJJh+paZb1hULlB7rEzo8YOZww=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ssp-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ssp-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ssp-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ssp-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ssp-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ssp-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Jisc Student Success Planner (Development)"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonEntitlement",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ebi.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barker"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jbarker@ebi.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jonathan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barker"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jbarker@ebi.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jonathan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ebi.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-09-04T10:43:30Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUWQaCmO3/wgoyUm1kMsbfovSvHTcwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGDEWMBQGA1UEAxMNaWRwLmViaS5hYy51azAeFw0xMjAzMjIxNzE4NTVaFw0z\n\t\t\t\t\t\tMjAzMjIxNzE4NTVaMBgxFjAUBgNVBAMTDWlkcC5lYmkuYWMudWswggEiMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCMiq+DPwgvEvXHVvsqsWViCDVZv/q+qWZf\n\t\t\t\t\t\tAAFse/KaiA0HPbdailVUaFg/s3ce4elzfWpEbHBoeb+SIVkQPNwmtpVgix92H7dj\n\t\t\t\t\t\t0YEkYBiSvTDTp54b76yKjFKOpWGGYis+pWY8D8WwWeHce+nHxrCOHB0oCHageY1j\n\t\t\t\t\t\tbONXdq3AI4153yWAX62za7/F7bdOM+RuDzCj+ezqzRJEk2pP49ZFsaAbVbLfFMqt\n\t\t\t\t\t\tIgCEclMephDqXLM8MlgP3KIzaq9PhSC4vXS3xxKTbMfRqT+Dzgt1pZvY3jY2T702\n\t\t\t\t\t\ti99SOhame/gdYXiILCD2XjKnjZhFSNMfvy/FfQDCpx++yFTXEFZzAgMBAAGjYTBf\n\t\t\t\t\t\tMD4GA1UdEQQ3MDWCDWlkcC5lYmkuYWMudWuGJGh0dHBzOi8vaWRwLmViaS5hYy51\n\t\t\t\t\t\tay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUdskpfLSwe6x0/paoWOMdXjPcSZ4w\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAA7P/MO6GYM8Qev0usgkT58VRk1uRQMqFUc+cGUP\n\t\t\t\t\t\tQEhjFILRIwlAKyQzT5hg6wMRdFcgbye5NSDx23GCL3UqqoNpMmZ/wd/cSNuwd/TZ\n\t\t\t\t\t\tZDLn4NCFoBv/MbHzKwQPa0E4lD5eiPtwtm3SlRqfSCAL/FMK2RC5DtmKKVPIzBoN\n\t\t\t\t\t\tXjfN5xEXaK1Fqt+IcN1iKY7gEs115CL5oeing5GRNtUpW2/FGPKy2OYFhmIQs93n\n\t\t\t\t\t\txDj3eBfFJMqdPg8M/NzlVInJNekNUhBnfSMA15q8OUd02msz0euhp0hZeA90XAuV\n\t\t\t\t\t\tTswW9HqCAz4FI9WefVN4dcmt6/h29ZZTyHBqC8AhQpJlvuc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ebi.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ebi.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ebi.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ebi.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ebi.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ebi.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ebi.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ebi.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ebi.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ebi.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://idp.ebi.ac.uk/images/EMBL_EBI_logo_95x30.png",
                    "height": "30",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "95"
                  },
                  {
                    "text": "https://idp.ebi.ac.uk/images/EMBL_EBI_icon_16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "European Molecular Biology Laboratory - EMBL-EBI"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUWQaCmO3/wgoyUm1kMsbfovSvHTcwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGDEWMBQGA1UEAxMNaWRwLmViaS5hYy51azAeFw0xMjAzMjIxNzE4NTVaFw0z\n\t\t\t\t\t\tMjAzMjIxNzE4NTVaMBgxFjAUBgNVBAMTDWlkcC5lYmkuYWMudWswggEiMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCMiq+DPwgvEvXHVvsqsWViCDVZv/q+qWZf\n\t\t\t\t\t\tAAFse/KaiA0HPbdailVUaFg/s3ce4elzfWpEbHBoeb+SIVkQPNwmtpVgix92H7dj\n\t\t\t\t\t\t0YEkYBiSvTDTp54b76yKjFKOpWGGYis+pWY8D8WwWeHce+nHxrCOHB0oCHageY1j\n\t\t\t\t\t\tbONXdq3AI4153yWAX62za7/F7bdOM+RuDzCj+ezqzRJEk2pP49ZFsaAbVbLfFMqt\n\t\t\t\t\t\tIgCEclMephDqXLM8MlgP3KIzaq9PhSC4vXS3xxKTbMfRqT+Dzgt1pZvY3jY2T702\n\t\t\t\t\t\ti99SOhame/gdYXiILCD2XjKnjZhFSNMfvy/FfQDCpx++yFTXEFZzAgMBAAGjYTBf\n\t\t\t\t\t\tMD4GA1UdEQQ3MDWCDWlkcC5lYmkuYWMudWuGJGh0dHBzOi8vaWRwLmViaS5hYy51\n\t\t\t\t\t\tay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUdskpfLSwe6x0/paoWOMdXjPcSZ4w\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAA7P/MO6GYM8Qev0usgkT58VRk1uRQMqFUc+cGUP\n\t\t\t\t\t\tQEhjFILRIwlAKyQzT5hg6wMRdFcgbye5NSDx23GCL3UqqoNpMmZ/wd/cSNuwd/TZ\n\t\t\t\t\t\tZDLn4NCFoBv/MbHzKwQPa0E4lD5eiPtwtm3SlRqfSCAL/FMK2RC5DtmKKVPIzBoN\n\t\t\t\t\t\tXjfN5xEXaK1Fqt+IcN1iKY7gEs115CL5oeing5GRNtUpW2/FGPKy2OYFhmIQs93n\n\t\t\t\t\t\txDj3eBfFJMqdPg8M/NzlVInJNekNUhBnfSMA15q8OUd02msz0euhp0hZeA90XAuV\n\t\t\t\t\t\tTswW9HqCAz4FI9WefVN4dcmt6/h29ZZTyHBqC8AhQpJlvuc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "European Molecular Biology Laboratory - EMBL-EBI"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ebi.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "European Molecular Biology Laboratory"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sam.cs.lth.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Andersson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Per.Andersson@cs.lth.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Per"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sam.cs.lth.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vm67.cs.lth.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vm67.cs.lth.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vm67.cs.lth.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vm67.cs.lth.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vm67.cs.lth.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vm67.cs.lth.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ett system f\u00f6r att administrera studenters resultat p\u00e5 olika kursmoment."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "A system for administering student performance on different parts of the course."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SAM - Student Achievement Management"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SAM - Student Achievement Management"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "vm67.cs.lth.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJANllutKF7uhoMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDnZtNjcuY3MubHRoLnNlMB4XDTE1MTEyNDEyMTYzN1oXDTI1MTEyMTEyMTYz\nN1owGTEXMBUGA1UEAxMOdm02Ny5jcy5sdGguc2UwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDis+P3Ui9qq/tX0Q3tvIM/R8K2JLkNXNQCwJSAopctOGHq\n/iSFW+wuhQU6nGuVrr+EShcmjztRAboMtM/IxJVB8GnN3jaGUbpbbpl3wcU4JfEU\nvYj7fp7bJa50xzLUoeRZhiYW5Y68NkZwmcxlmq7IQ7g6bRd+xvxLsfQcc7Lgc4HO\ni6kTxr85tkasnyEXChZOLBAGaeG6wHee4aJkxoyaUbGpSwy/iMrtqVMpKYDAE9ci\nW1W4SbiKCbDs0Xo6znCtXAblCMrwXdGqo33xCPd7bk2NHA844SKz0ObSLkyJPeuy\nD44ddHJ9Ub+xRXZGbEuC31siNGD5xbUDqD3YHTVfAgMBAAGjPDA6MBkGA1UdEQQS\nMBCCDnZtNjcuY3MubHRoLnNlMB0GA1UdDgQWBBSlIc3HTHiCUgJWyBUMbeN7TlEG\nWzANBgkqhkiG9w0BAQUFAAOCAQEAouvHjvzUYaeiTLaUAzmsZiGdOz0Q16+mu6Zs\nbXGpZWDQ3Ajll6yD4MK3N6ovQYmAe5GCePIJArJ/6A1wZc+Xj+fX1OgAILCh6MAE\nho80mwse6u7gyih/yJX5et7Zzs5piw48Xf6fDeyDQkUh4ebqcA2agm7oSK/VcHlA\ncFMEM1Ex00lnZlc4Y7i3Zz+VTqBxmDD26BboDFepVmSABzqfzahb3vwm88bKGd3C\neantehm2RWmRIz8poebeGW4oirdCtSho8ZuO5JgDcxMB4gUV/QgPmfrxo0cTAL/7\n2Z0pVLLyQOFoGAA5K0Wzs5oNWO77SIa06R3uch9OsFwNUfG3Og=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=vm67.cs.lth.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vm67.cs.lth.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vm67.cs.lth.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vm67.cs.lth.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vm67.cs.lth.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vm67.cs.lth.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sam.cs.lth.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sam.cs.lth.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sam.cs.lth.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sam.cs.lth.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sam.cs.lth.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://fysik.sam.cs.lth.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://fysik.sam.cs.lth.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://fysik.sam.cs.lth.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://fysik.sam.cs.lth.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://fysik.sam.cs.lth.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "18"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://matstat.sam.cs.lth.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "19"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://matstat.sam.cs.lth.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "21"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://matstat.sam.cs.lth.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "22"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://matstat.sam.cs.lth.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "23"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://matstat.cs.lth.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "24"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://login.regis.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jperez@regis.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jerry Perez"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "edelcamp@regis.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Erich Delcamp"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ghatayam@regis.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Greg Hatayama"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.regis.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.regis.edu/idp/attrsvc.ssaml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWjCCAkKgAwIBAgIGASqgaBEhMA0GCSqGSIb3DQEBBQUAMG4xCzAJBgNVBAYTAlVTMQswCQYD\nVQQIEwJDbzEPMA0GA1UEBxMGRGVudmVyMRkwFwYDVQQKExBSZWdpcyBVbml2ZXJzaXR5MQwwCgYD\nVQQLEwNJVFMxGDAWBgNVBAMTD2xvZ2luLnJlZ2lzLmVkdTAeFw0xMDA4MjMxOTIzNDhaFw0xMjA4\nMjIxOTIzNDhaMG4xCzAJBgNVBAYTAlVTMQswCQYDVQQIEwJDbzEPMA0GA1UEBxMGRGVudmVyMRkw\nFwYDVQQKExBSZWdpcyBVbml2ZXJzaXR5MQwwCgYDVQQLEwNJVFMxGDAWBgNVBAMTD2xvZ2luLnJl\nZ2lzLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ6QoQongAUGrHZ9eTcGf0bV\nsSEle3y522qHTF2+kBMZaxcCtD9s12rOPkhIbgnmKeQMOr9abSyu9aY1RKcjIzE6eozkvvmsjjfU\naRBLXEMzW33CmFmEa2EP5RrNNmQkHJvjb2ZCoZJOjYSi+wnlSROkw3yxxj2ChV/FwhuMwXVZL/pL\nFCwO/XNNRjWaqyUbrHzbqVVlpch8NU0XyhaUlWfsxqqikWeEaPCT1VPWWLfzKiiuz9u9yqTcyuo8\n+g+gJ/ovzKOQ7ae6UGJL4rMzxK4fvYrMO0EWgfYRFnl8ShJ0AS5KIaSpwcufhBC2EhaV2gN7uI/E\nYkVnimyG/wvlNwMCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAemW0ASJe3Z5LbvPjskXhCA8fxq5D\nvaUH4GQUceN6JfBlugrwd1ivzhe5ez5vIwQPNmQiwdQphr0nXehMCm1WXsM8/Q9/VUF0FHzxLCB+\n79OKVSlCIMCZW77q4HqcXfGzxPqJr55f8oYb325AcvgugLclm5nLX+/hwGJoaBhoLju4ZI5DbgUg\nzRYY89D7K/WkbnW7gFRPZ8NTP+U5m2e+NP/+Xm0og9O2YhilNZH3Mn+NSZwNdbXJ5RXv4Wrq0F4e\nrEHhvsmbrjPpcG8BJ46pYReen2ZTZ1uEVmHsaAFD6Fz0nsWj7BwKPptmnkMPgxJ57Wod96ysgGjn\nzwa3cLKnmg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "regis.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.regis.edu/idp/SSO.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.regis.edu/idp/SSO.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.regis.edu/idp/soap.ssaml1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.regis.edu/idp/ARS.ssaml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "regis.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Regis University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWjCCAkKgAwIBAgIGASqgaBEhMA0GCSqGSIb3DQEBBQUAMG4xCzAJBgNVBAYTAlVTMQswCQYD\nVQQIEwJDbzEPMA0GA1UEBxMGRGVudmVyMRkwFwYDVQQKExBSZWdpcyBVbml2ZXJzaXR5MQwwCgYD\nVQQLEwNJVFMxGDAWBgNVBAMTD2xvZ2luLnJlZ2lzLmVkdTAeFw0xMDA4MjMxOTIzNDhaFw0xMjA4\nMjIxOTIzNDhaMG4xCzAJBgNVBAYTAlVTMQswCQYDVQQIEwJDbzEPMA0GA1UEBxMGRGVudmVyMRkw\nFwYDVQQKExBSZWdpcyBVbml2ZXJzaXR5MQwwCgYDVQQLEwNJVFMxGDAWBgNVBAMTD2xvZ2luLnJl\nZ2lzLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ6QoQongAUGrHZ9eTcGf0bV\nsSEle3y522qHTF2+kBMZaxcCtD9s12rOPkhIbgnmKeQMOr9abSyu9aY1RKcjIzE6eozkvvmsjjfU\naRBLXEMzW33CmFmEa2EP5RrNNmQkHJvjb2ZCoZJOjYSi+wnlSROkw3yxxj2ChV/FwhuMwXVZL/pL\nFCwO/XNNRjWaqyUbrHzbqVVlpch8NU0XyhaUlWfsxqqikWeEaPCT1VPWWLfzKiiuz9u9yqTcyuo8\n+g+gJ/ovzKOQ7ae6UGJL4rMzxK4fvYrMO0EWgfYRFnl8ShJ0AS5KIaSpwcufhBC2EhaV2gN7uI/E\nYkVnimyG/wvlNwMCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAemW0ASJe3Z5LbvPjskXhCA8fxq5D\nvaUH4GQUceN6JfBlugrwd1ivzhe5ez5vIwQPNmQiwdQphr0nXehMCm1WXsM8/Q9/VUF0FHzxLCB+\n79OKVSlCIMCZW77q4HqcXfGzxPqJr55f8oYb325AcvgugLclm5nLX+/hwGJoaBhoLju4ZI5DbgUg\nzRYY89D7K/WkbnW7gFRPZ8NTP+U5m2e+NP/+Xm0og9O2YhilNZH3Mn+NSZwNdbXJ5RXv4Wrq0F4e\nrEHhvsmbrjPpcG8BJ46pYReen2ZTZ1uEVmHsaAFD6Fz0nsWj7BwKPptmnkMPgxJ57Wod96ysgGjn\nzwa3cLKnmg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Regis University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://regis.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Regis University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.athena-innovation.gr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "staff@imis.athena-innovation.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Research Center Athena - Institute for the Management of Information Systems"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "staff@imis.athena-innovation.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Research Center Athena - Institute for the Management of Information Systems"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.athena-innovation.gr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEmzCCA4OgAwIBAgIQTEvhgWFGJLdkM4ZD5wBQTDANBgkqhkiG9w0BAQUFADA2\n                            MQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n                            U1NMIENBMB4XDTE0MDQwOTAwMDAwMFoXDTE3MDQwODIzNTk1OVowSDEhMB8GA1UE\n                            CxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMSMwIQYDVQQDExpsb2dpbi5hdGhl\n                            bmEtaW5ub3ZhdGlvbi5ncjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n                            AKaZpSw3Pb3kDBhJzRXUcnUqFZqJSoLjvSMHnxt0GDjBsvmQZwDflsuIu5nbXQ86\n                            DnK7ImdQszT42hal7RFODHrD9F1TC/7zoQRd5DoLnHdKOeHQRAa2WF+IwkrtiyQT\n                            gMhswaqal8wXr7sM+f0bDOYvU3Q2MVdAmE1TefrlPx90hHys+SbreRjj/HUCCsBI\n                            zgfnFcy56Mmr0m9Olbh56VhAs+qZhYpWDyGhuHaRaNEhuJCx0R7IZmFhNGZ/+2+s\n                            CdK1j/hq08c1L7wON/ZDdSBGbM5cuCoxPqIcLyyEgEh4ieo/c8e04ZfxwBFU9XZI\n                            ApX4niHSErzC/bNDMWR+f3kCAwEAAaOCAZEwggGNMB8GA1UdIwQYMBaAFAy9k2gM\n                            896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBR0AyJjhZwmKiXLMvyVR6BYE68JYTAO\n                            BgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcD\n                            AQYIKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEw\n                            OgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJF\n                            TkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8v\n                            Y3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYa\n                            aHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwPwYDVR0RBDgwNoIabG9naW4uYXRo\n                            ZW5hLWlubm92YXRpb24uZ3KCGGlkcC5hdGhlbmEtaW5ub3ZhdGlvbi5ncjANBgkq\n                            hkiG9w0BAQUFAAOCAQEAA1a3pfD6Iq6rMgZgmJeUEge9y3uLN5YGzJYjsNYvznhZ\n                            tnfuKighFcdQwH/Ph/ceZYtwcIMXstZFxXsFM878PiEehLSghYJorC0e9EDszIsc\n                            QgbzraX/vEjWRZ4ywQU1nsc1+3EYZyIfxmi35FiT8g0xSEVpSj4O1RoDO3xUz8NJ\n                            zDycQMlH2qMDDNdgYGqs/U3habyE1MeAHbz6zWhX6Sa1oeIy6gijvGUUadDULhX3\n                            iVNxJAYr4coKFN/Xj58Ay6JjomJCgmve/lnkdQRuvAZFcu7UiGJfDpBiJNr1Qyzp\n                            bH/fFKDIDSjRobYahs2BQ/SwbEwwA7e0gx0vS/ACwA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "athena-innovation.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "imis.athena-innovation.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ilsp.athena-innovation.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ceti.athena-innovation.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "isi.athena-innovation.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.athena-innovation.gr:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.athena-innovation.gr:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.athena-innovation.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.athena-innovation.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.athena-innovation.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.athena-innovation.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.athena-innovation.gr:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.athena-innovation.gr:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "athena-innovation.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "imis.athena-innovation.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ilsp.athena-innovation.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ceti.athena-innovation.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "isi.athena-innovation.gr"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.athena-innovation.gr/en.html"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.athena-innovation.gr/el.html"
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.athena-innovation.gr/logo.png",
                    "height": "90",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "73"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Athena - Research and Innovation Center"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u0391\u03b8\u03b7\u03bd\u03ac - \u0395\u03c1\u03b5\u03c5\u03bd\u03b7\u03c4\u03b9\u03ba\u03cc \u039a\u03ad\u03bd\u03c4\u03c1\u03bf \u039a\u03b1\u03b9\u03bd\u03bf\u03c4\u03bf\u03bc\u03af\u03b1\u03c2"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "athena-innovation.gr"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "imis.athena-innovation.gr"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "ilsp.gr"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "ceti.gr"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "isi.gr"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:38.0365046,23.802512"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.251.63.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.251.3.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.251.58.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "194.177.192.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "194.177.217.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:648:2600::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEmzCCA4OgAwIBAgIQTEvhgWFGJLdkM4ZD5wBQTDANBgkqhkiG9w0BAQUFADA2\n                            MQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n                            U1NMIENBMB4XDTE0MDQwOTAwMDAwMFoXDTE3MDQwODIzNTk1OVowSDEhMB8GA1UE\n                            CxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMSMwIQYDVQQDExpsb2dpbi5hdGhl\n                            bmEtaW5ub3ZhdGlvbi5ncjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n                            AKaZpSw3Pb3kDBhJzRXUcnUqFZqJSoLjvSMHnxt0GDjBsvmQZwDflsuIu5nbXQ86\n                            DnK7ImdQszT42hal7RFODHrD9F1TC/7zoQRd5DoLnHdKOeHQRAa2WF+IwkrtiyQT\n                            gMhswaqal8wXr7sM+f0bDOYvU3Q2MVdAmE1TefrlPx90hHys+SbreRjj/HUCCsBI\n                            zgfnFcy56Mmr0m9Olbh56VhAs+qZhYpWDyGhuHaRaNEhuJCx0R7IZmFhNGZ/+2+s\n                            CdK1j/hq08c1L7wON/ZDdSBGbM5cuCoxPqIcLyyEgEh4ieo/c8e04ZfxwBFU9XZI\n                            ApX4niHSErzC/bNDMWR+f3kCAwEAAaOCAZEwggGNMB8GA1UdIwQYMBaAFAy9k2gM\n                            896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBR0AyJjhZwmKiXLMvyVR6BYE68JYTAO\n                            BgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcD\n                            AQYIKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEw\n                            OgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJF\n                            TkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8v\n                            Y3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYa\n                            aHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwPwYDVR0RBDgwNoIabG9naW4uYXRo\n                            ZW5hLWlubm92YXRpb24uZ3KCGGlkcC5hdGhlbmEtaW5ub3ZhdGlvbi5ncjANBgkq\n                            hkiG9w0BAQUFAAOCAQEAA1a3pfD6Iq6rMgZgmJeUEge9y3uLN5YGzJYjsNYvznhZ\n                            tnfuKighFcdQwH/Ph/ceZYtwcIMXstZFxXsFM878PiEehLSghYJorC0e9EDszIsc\n                            QgbzraX/vEjWRZ4ywQU1nsc1+3EYZyIfxmi35FiT8g0xSEVpSj4O1RoDO3xUz8NJ\n                            zDycQMlH2qMDDNdgYGqs/U3habyE1MeAHbz6zWhX6Sa1oeIy6gijvGUUadDULhX3\n                            iVNxJAYr4coKFN/Xj58Ay6JjomJCgmve/lnkdQRuvAZFcu7UiGJfDpBiJNr1Qyzp\n                            bH/fFKDIDSjRobYahs2BQ/SwbEwwA7e0gx0vS/ACwA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Athena - Research and Innovation Center"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u0391\u03b8\u03b7\u03bd\u03ac - \u0395\u03c1\u03b5\u03c5\u03bd\u03b7\u03c4\u03b9\u03ba\u03cc \u039a\u03ad\u03bd\u03c4\u03c1\u03bf \u039a\u03b1\u03b9\u03bd\u03bf\u03c4\u03bf\u03bc\u03af\u03b1\u03c2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.athena-innovation.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.athena-innovation.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Athena - Research and Innovation Center in Information, Communication and Knowledge Technologies"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u0391\u03b8\u03b7\u03bd\u03ac - \u0395\u03c1\u03b5\u03c5\u03bd\u03b7\u03c4\u03b9\u03ba\u03cc \u039a\u03ad\u03bd\u03c4\u03c1\u03bf \u039a\u03b1\u03b9\u03bd\u03bf\u03c4\u03bf\u03bc\u03af\u03b1\u03c2 \u03c3\u03c4\u03b9\u03c2 \u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03af\u03b5\u03c2 \u03c4\u03b7\u03c2 \u03a0\u03bb\u03b7\u03c1\u03bf\u03c6\u03bf\u03c1\u03af\u03b1\u03c2, \u03c4\u03c9\u03bd \u0395\u03c0\u03b9\u03ba\u03bf\u03b9\u03bd\u03c9\u03bd\u03b9\u03ce\u03bd \u03ba\u03b1\u03b9 \u03c4\u03b7\u03c2 \u0393\u03bd\u03ce\u03c3\u03b7\u03c2"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://wiki.moonshot.ja.net/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bishop"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Adam.bishop@ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bishop"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Adam.bishop@ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://wiki.moonshot.ja.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-01-23T10:58:44Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Moonshot Wiki"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://wiki.moonshot.ja.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "JISC Collections and Janet Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://wiki.moonshot.ja.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://wiki.moonshot.ja.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wiki.moonshot.ja.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wiki.moonshot.ja.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://wiki.moonshot.ja.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://wiki.moonshot.ja.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://wiki.moonshot.ja.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Moonshot is a single, unifying technology for extending the benefits of federated identity to a broad range of non-web services. This service hosts the wiki for Moonshot, containing technical documentation, along with installation and configuration guides."
                  }
                ],
                "logo": [
                  {
                    "text": "https://wiki.moonshot.ja.net/download/thumbnails/786450/global.jpg",
                    "height": "300",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "300"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Moonshot Wiki"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAI2lVwLRmJlYMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\n\t\t\t\t\t\tBAMTFHdpa2kubW9vbnNob3QuamEubmV0MB4XDTE0MDEyMjE1NTUyMloXDTI0MDEy\n\t\t\t\t\t\tMDE1NTUyMlowHzEdMBsGA1UEAxMUd2lraS5tb29uc2hvdC5qYS5uZXQwggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDWGUu/30A3CbAtbHJxdqCH3sOeEBRh\n\t\t\t\t\t\t8zlXj4fg9hFnq+QGZFnprYbBGiJIlCrbESqX5xcJb1B36NbyW2G0FvUVzi6H+RlG\n\t\t\t\t\t\tt686NKc+NIODcbf4YiOcvn9Ixaxmd2q4/9c/3FBXlFm60chf3hENK9hF6kaw4LUd\n\t\t\t\t\t\tnXdkL6r4Ha2q2csGUSjWaPlS6azgn+Wx+KFE6AVdVRhhrkeuoU6qko+waPPjXjJG\n\t\t\t\t\t\tgzIfBs45AYwb6t5rw+7oaKWeDMR1pIDa3YkhyvLpeesi+ZXW+CzzWPO7LK6ffedB\n\t\t\t\t\t\tn4GOZkArOBo8y/KV6qt67w6wVujD9oW3bNTmt4zh6SPpK/qqUOPe4jZLAgMBAAGj\n\t\t\t\t\t\tQjBAMB8GA1UdEQQYMBaCFHdpa2kubW9vbnNob3QuamEubmV0MB0GA1UdDgQWBBQX\n\t\t\t\t\t\tl8auIWrO6aWUz4kAMl1ft5iPLjANBgkqhkiG9w0BAQUFAAOCAQEAEQirkb8jdIye\n\t\t\t\t\t\tbieiVOnSdkHSgR+9Nigf7DHEF0F1IXMVCKYONud2O4ospFignlg5UnPV1nrul6Fz\n\t\t\t\t\t\tc681gz4a0mY0Rkhg0noTbsfDsxmeddWBl2exsS8aLfoMcLmN2XaAPoiyXkUB07VM\n\t\t\t\t\t\tKfuD9TOWjaWBTUXGxqxvWxqYGyMqY/8K0YFmzOSlW3o38Wnal6BmBU70YdUeGpb9\n\t\t\t\t\t\tk/GRL1yvGpuhK1LGzCdtu0tg/tpLDB6vYqAUJOI9A/0nnavZ8ZRb7qyUU8hnxbGK\n\t\t\t\t\t\tnjlrDErSFqTmSYL6RiJyx24bQfVdDporsXDSrMprH3B2SIIXNHMDNWxraXUDTtg1\n\t\t\t\t\t\t0oPZBY6WCg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wiki.moonshot.ja.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://wiki.moonshot.ja.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wiki.moonshot.ja.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://wiki.moonshot.ja.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://wiki.moonshot.ja.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://wiki.moonshot.ja.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Moonshot Wiki"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Moonshot is a single, unifying technology for extending the benefits of federated identity to a broad range of non-web services. This service hosts the wiki for Moonshot, containing technical documentation, along with installation and configuration guides."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonTargetedID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "http://adfs2.cito.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs2.cito.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-04-29T12:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/b6dcca08852d4131ee33fa6e84d2ef65",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Cito"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Cito"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/cito.png",
                    "height": "48",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "94"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Cito"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Cito"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cito"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cito.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cito"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth2sp.mhp.semcs.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:techsupport@mhprofessional.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "McGraw-Hill Tech Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:techsupport@mhprofessional.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "McGraw-Hill Tech Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth2sp.mhp.semcs.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-09-23T13:54:33Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "McGraw-Hill Education"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mheducation.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "McGraw-Hill Education LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.mhp.semcs.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.mhp.semcs.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.mhp.semcs.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.mhp.semcs.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.mhp.semcs.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth2sp.mhp.semcs.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth2sp.mhp.semcs.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0jCCArqgAwIBAgIJAPx54Ehep++5MA0GCSqGSIb3DQEBBQUAMGsxCzAJBgNV\n\t\t\t\t\t\tBAYTAlVLMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIwEAYD\n\t\t\t\t\t\tVQQKEwlzZW1hbnRpY28xJDAiBgNVBAMTG3NoaWJib2xldGgyc3AubWhwLnNlbWNz\n\t\t\t\t\t\tLm5ldDAeFw0xMzA4MjkxNTQ1MzNaFw0zMzA4MjQxNTQ1MzNaMGsxCzAJBgNVBAYT\n\t\t\t\t\t\tAlVLMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIwEAYDVQQK\n\t\t\t\t\t\tEwlzZW1hbnRpY28xJDAiBgNVBAMTG3NoaWJib2xldGgyc3AubWhwLnNlbWNzLm5l\n\t\t\t\t\t\tdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALLkKacGmaIQb0f44H/J\n\t\t\t\t\t\tPPzSXgOvQaKBnm2r76HIj9DQCy71fneTf7dWt0XgNi6ycsP+lBPYxry28khmukva\n\t\t\t\t\t\tG1BJVsnvJcDSR6uu2O57Bv0tr50g6N8GHOAl+MlS1ONLwpGwVXs4X/OAY+8NnWFX\n\t\t\t\t\t\tbxTElNYuuu7p2zRL46qTwpUKe+9KQ2Np9NM1ZtPMLU/a4p8uKhq/4mJb4/wK+Ek5\n\t\t\t\t\t\t27WEKp8wdOaBGsZ9KsxlohgDpks0F5hTA99vzmlztBtR7OmEvkbT6S8MSOgNIPxM\n\t\t\t\t\t\tNacyuEdnkjQnUkBZFJYnGSbZnWvnmF2Vr3NqPnpISOTf1SLW98fuX49FdAC9Rhqu\n\t\t\t\t\t\t5ycCAwEAAaN5MHcwVgYDVR0RBE8wTYIbc2hpYmJvbGV0aDJzcC5taHAuc2VtY3Mu\n\t\t\t\t\t\tbmV0hi5odHRwczovL3NoaWJib2xldGgyc3AubWhwLnNlbWNzLm5ldC9zaGliYm9s\n\t\t\t\t\t\tZXRoMB0GA1UdDgQWBBQPQt9ON9lAutcLAfmC6Avxe1vevzANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAgwVbqg3PtW154Dg+JiUgVohCnst3ntJr+LU0gbu9i92Dcpfy1ZSDI82Z\n\t\t\t\t\t\tGVV2W70h0UfzRWiaejdi8+nOOp7q7Ak6zcm5bGwdkXSB7cTiybZ8OrkRPMS0Lp2M\n\t\t\t\t\t\tV5II6/xvAsvKWCA1bnLkTdzm+J2WTzvQG+tnxdBF3xkHSQLbuXO8guyRjh28V4uU\n\t\t\t\t\t\txzWt1riN1QDY2gtPot2jCKrPXE1/M0Xwj0UkV8OAM9RuttQXCPVyoppkI+/4ULDQ\n\t\t\t\t\t\tbDPaJ11iT7DRjo2la7koLO/ZuPVilaWNPD2DTKQzkbErUbKmWY7RSp2QgwIKuDT/\n\t\t\t\t\t\tzLCWlyfdI+tWif3o7y28c1cRve942w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0jCCArqgAwIBAgIJAPx54Ehep++5MA0GCSqGSIb3DQEBBQUAMGsxCzAJBgNV\n\t\t\t\t\t\tBAYTAlVLMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIwEAYD\n\t\t\t\t\t\tVQQKEwlzZW1hbnRpY28xJDAiBgNVBAMTG3NoaWJib2xldGgyc3AubWhwLnNlbWNz\n\t\t\t\t\t\tLm5ldDAeFw0xMzA4MjkxNTQ1MzNaFw0zMzA4MjQxNTQ1MzNaMGsxCzAJBgNVBAYT\n\t\t\t\t\t\tAlVLMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIwEAYDVQQK\n\t\t\t\t\t\tEwlzZW1hbnRpY28xJDAiBgNVBAMTG3NoaWJib2xldGgyc3AubWhwLnNlbWNzLm5l\n\t\t\t\t\t\tdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALLkKacGmaIQb0f44H/J\n\t\t\t\t\t\tPPzSXgOvQaKBnm2r76HIj9DQCy71fneTf7dWt0XgNi6ycsP+lBPYxry28khmukva\n\t\t\t\t\t\tG1BJVsnvJcDSR6uu2O57Bv0tr50g6N8GHOAl+MlS1ONLwpGwVXs4X/OAY+8NnWFX\n\t\t\t\t\t\tbxTElNYuuu7p2zRL46qTwpUKe+9KQ2Np9NM1ZtPMLU/a4p8uKhq/4mJb4/wK+Ek5\n\t\t\t\t\t\t27WEKp8wdOaBGsZ9KsxlohgDpks0F5hTA99vzmlztBtR7OmEvkbT6S8MSOgNIPxM\n\t\t\t\t\t\tNacyuEdnkjQnUkBZFJYnGSbZnWvnmF2Vr3NqPnpISOTf1SLW98fuX49FdAC9Rhqu\n\t\t\t\t\t\t5ycCAwEAAaN5MHcwVgYDVR0RBE8wTYIbc2hpYmJvbGV0aDJzcC5taHAuc2VtY3Mu\n\t\t\t\t\t\tbmV0hi5odHRwczovL3NoaWJib2xldGgyc3AubWhwLnNlbWNzLm5ldC9zaGliYm9s\n\t\t\t\t\t\tZXRoMB0GA1UdDgQWBBQPQt9ON9lAutcLAfmC6Avxe1vevzANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAgwVbqg3PtW154Dg+JiUgVohCnst3ntJr+LU0gbu9i92Dcpfy1ZSDI82Z\n\t\t\t\t\t\tGVV2W70h0UfzRWiaejdi8+nOOp7q7Ak6zcm5bGwdkXSB7cTiybZ8OrkRPMS0Lp2M\n\t\t\t\t\t\tV5II6/xvAsvKWCA1bnLkTdzm+J2WTzvQG+tnxdBF3xkHSQLbuXO8guyRjh28V4uU\n\t\t\t\t\t\txzWt1riN1QDY2gtPot2jCKrPXE1/M0Xwj0UkV8OAM9RuttQXCPVyoppkI+/4ULDQ\n\t\t\t\t\t\tbDPaJ11iT7DRjo2la7koLO/ZuPVilaWNPD2DTKQzkbErUbKmWY7RSp2QgwIKuDT/\n\t\t\t\t\t\tzLCWlyfdI+tWif3o7y28c1cRve942w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.mhp.semcs.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.mhp.semcs.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.mhp.semcs.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.mhp.semcs.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.mhp.semcs.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth2sp.mhp.semcs.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.mhp.semcs.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth2sp.mhp.semcs.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth2sp.mhp.semcs.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth2sp.mhp.semcs.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.runshaw.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@runshaw.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Runshaw College Servicedesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@runshaw.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Runshaw College Servicedesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.runshaw.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-20T09:52:24Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIVANxclogryqwYGu19nKOzmdP84Ca0MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCMxITAfBgNVBAMMGHNoaWJib2xldGgucnVuc2hhdy5hYy51azAeFw0xNTA0\n\t\t\t\t\t\tMjMxMDIyNThaFw0zNTA0MjMxMDIyNThaMCMxITAfBgNVBAMMGHNoaWJib2xldGgu\n\t\t\t\t\t\tcnVuc2hhdy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANiX\n\t\t\t\t\t\t7IYiXMY1SGFgrR8PBQA65R9qoS4XP8oyMOwSmXw66DxyzUa4zjjJY8iRSpXt6xYr\n\t\t\t\t\t\t0DpTBOGt/hbUeBXZz+MFL+QBlS9MmGMY8zKIXujaXWRhT208hxY8ROkhTGU9PGAA\n\t\t\t\t\t\tuE0qnylaLrqORKBmEQrFRUTMD9Rf3su7KN484Vr8IyW+W2GRVtvxkn6xrQCpRPb9\n\t\t\t\t\t\tV6GqlXVp9+NofrEUvl2mCAAXiGAKvIFBx/dHJdZg//zecRwMFIWmfKB+AfMiHr/d\n\t\t\t\t\t\tKotVIHtjV1Ln89qq7LD2GXNLczEg9c4PRhPo3/YiEBRLvUjuT6lDC0OwaiDwuLBa\n\t\t\t\t\t\tdtnQRrXdtI0kO94L8ucCAwEAAaN3MHUwHQYDVR0OBBYEFGXp66qZBQ87PR0+8dN5\n\t\t\t\t\t\tzINuFt7FMFQGA1UdEQRNMEuCGHNoaWJib2xldGgucnVuc2hhdy5hYy51a4YvaHR0\n\t\t\t\t\t\tcHM6Ly9zaGliYm9sZXRoLnJ1bnNoYXcuYWMudWsvaWRwL3NoaWJib2xldGgwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBANST0/5PspBh/cEXFzxvm5byFdLgAuIUG+vyLSw8yGur\n\t\t\t\t\t\ty5yAXJLQO6a6O3rQu36DYgbY1FTA3xPDByeYL+2tYCtrK7202KtMZ11boGQVwpWN\n\t\t\t\t\t\ttF6ddSgtBYkGFgaxKShsKKBowuf7eC7D5K8GO1ugJYK766MbYEzQtf467kvxKWeX\n\t\t\t\t\t\toXVx3Dt4T1rP+IYkKO2Fggyb6uKKZwhi2PrrPs2Kp4yvJ3JY9LPb+1Tf5LKbRS2b\n\t\t\t\t\t\t0sSweNlLsJ2jVGZ0v/LK1nTjT8d34alzVwYHrX7A9d1PhudmBIG9lzRIJxxHznSp\n\t\t\t\t\t\tkpaorlZ3en0Z1zG6x6U452/g5wbB9vkinE+NNpc6XBI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "runshaw.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.runshaw.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.runshaw.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.runshaw.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.runshaw.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.runshaw.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.runshaw.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.runshaw.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.runshaw.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.runshaw.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.runshaw.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.runshaw.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "runshaw.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIVANxclogryqwYGu19nKOzmdP84Ca0MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCMxITAfBgNVBAMMGHNoaWJib2xldGgucnVuc2hhdy5hYy51azAeFw0xNTA0\n\t\t\t\t\t\tMjMxMDIyNThaFw0zNTA0MjMxMDIyNThaMCMxITAfBgNVBAMMGHNoaWJib2xldGgu\n\t\t\t\t\t\tcnVuc2hhdy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANiX\n\t\t\t\t\t\t7IYiXMY1SGFgrR8PBQA65R9qoS4XP8oyMOwSmXw66DxyzUa4zjjJY8iRSpXt6xYr\n\t\t\t\t\t\t0DpTBOGt/hbUeBXZz+MFL+QBlS9MmGMY8zKIXujaXWRhT208hxY8ROkhTGU9PGAA\n\t\t\t\t\t\tuE0qnylaLrqORKBmEQrFRUTMD9Rf3su7KN484Vr8IyW+W2GRVtvxkn6xrQCpRPb9\n\t\t\t\t\t\tV6GqlXVp9+NofrEUvl2mCAAXiGAKvIFBx/dHJdZg//zecRwMFIWmfKB+AfMiHr/d\n\t\t\t\t\t\tKotVIHtjV1Ln89qq7LD2GXNLczEg9c4PRhPo3/YiEBRLvUjuT6lDC0OwaiDwuLBa\n\t\t\t\t\t\tdtnQRrXdtI0kO94L8ucCAwEAAaN3MHUwHQYDVR0OBBYEFGXp66qZBQ87PR0+8dN5\n\t\t\t\t\t\tzINuFt7FMFQGA1UdEQRNMEuCGHNoaWJib2xldGgucnVuc2hhdy5hYy51a4YvaHR0\n\t\t\t\t\t\tcHM6Ly9zaGliYm9sZXRoLnJ1bnNoYXcuYWMudWsvaWRwL3NoaWJib2xldGgwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBANST0/5PspBh/cEXFzxvm5byFdLgAuIUG+vyLSw8yGur\n\t\t\t\t\t\ty5yAXJLQO6a6O3rQu36DYgbY1FTA3xPDByeYL+2tYCtrK7202KtMZ11boGQVwpWN\n\t\t\t\t\t\ttF6ddSgtBYkGFgaxKShsKKBowuf7eC7D5K8GO1ugJYK766MbYEzQtf467kvxKWeX\n\t\t\t\t\t\toXVx3Dt4T1rP+IYkKO2Fggyb6uKKZwhi2PrrPs2Kp4yvJ3JY9LPb+1Tf5LKbRS2b\n\t\t\t\t\t\t0sSweNlLsJ2jVGZ0v/LK1nTjT8d34alzVwYHrX7A9d1PhudmBIG9lzRIJxxHznSp\n\t\t\t\t\t\tkpaorlZ3en0Z1zG6x6U452/g5wbB9vkinE+NNpc6XBI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Runshaw College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.runshaw.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Runshaw College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://peterborough.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wildman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Richard.wildman@peterborough.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Towler"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Lynton.towler@peterborough.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lynton"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wildman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Richard.wildman@peterborough.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://peterborough.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-11-26T15:19:53Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aas.peterborough.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aas.peterborough.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "peterborough.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZDCCAkygAwIBAgIINjMwhVf3jFkwDQYJKoZIhvcNAQEFBQAwSTEmMCQGA1UE\n\t\t\t\t\t\tCgwdUGV0ZXJib3JvdWdoIFJlZ2lvbmFsIENvbGxlZ2UxHzAdBgNVBAMMFmFhcy5w\n\t\t\t\t\t\tZXRlcmJvcm91Z2guYWMudWswHhcNMTIxMDE3MTMzODAwWhcNMjIxMDE3MTMzODAw\n\t\t\t\t\t\tWjBJMSYwJAYDVQQKDB1QZXRlcmJvcm91Z2ggUmVnaW9uYWwgQ29sbGVnZTEfMB0G\n\t\t\t\t\t\tA1UEAwwWYWFzLnBldGVyYm9yb3VnaC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQAD\n\t\t\t\t\t\tggEPADCCAQoCggEBAIIbeuWlQPhTqwxItEPE51NVFfArYjaRW8O9b0aYfoYRQH86\n\t\t\t\t\t\tyYBOpO0xeaqb6fpCrjwvZwz+SPDcSu26f2u0NJ4eHClO8QAWGyh9XGH3WZu0R6YW\n\t\t\t\t\t\tnvbPTHjJOxSlDVo2Ukba3/TG+6WMQXa89b86NKbzLrOBISyrbLky1NTAtFI2+Kcm\n\t\t\t\t\t\tTsw7G+lk/jbAR4WD/AaXS9iXZjvOR5Fd+6ntvKp7PheNoD+7pbnEJV2Il1YMrmT4\n\t\t\t\t\t\tpuMw74kAIRbwKOGwA1VivNNGfnuGW8lYmujwPVfJwWXUXUgOqr86MHt+iatvJ7EA\n\t\t\t\t\t\t3ZmSUYmlJYFkdc3aWbMplI5WuOLlKK0EeBlVAG0CAwEAAaNQME4wHQYDVR0OBBYE\n\t\t\t\t\t\tFAF22/FrH+1Anys4Xk2bheSlL00KMB8GA1UdIwQYMBaAFAF22/FrH+1Anys4Xk2b\n\t\t\t\t\t\theSlL00KMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAAkfZ2yKKff4\n\t\t\t\t\t\tP6/mGdaEIu1t/eVwRgeCHKiW4cnDTPlIJ3qQ0oWKPnqvMuLnARbwJcA+BAKHrH47\n\t\t\t\t\t\tZ/o9G70hzo4+yQrw9Oh9N+b99gW62DhdWNiVJKD7u9pFI5w9rX0wPRlM9tuJJQqY\n\t\t\t\t\t\tmkS3SnkZDJOloF0cUjC2zo9cJNsCbPrjN+DkkVweNV6Bbzu8ABwDr6UV3zkY8iot\n\t\t\t\t\t\tS7F79s1+CGoFcU8g07hpq93i957bqsyCasIEc/wn54jQyLs4LorcKO5WJg/50Q2j\n\t\t\t\t\t\t/HItds1Wpk/aLQjt2/wnywHR3yWeBQN4B4QqN5TrzkN5OdZZsFHyWIzTmeXTwJtM\n\t\t\t\t\t\t8OV0uQf2TwU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZDCCAkygAwIBAgIINjMwhVf3jFkwDQYJKoZIhvcNAQEFBQAwSTEmMCQGA1UE\n\t\t\t\t\t\tCgwdUGV0ZXJib3JvdWdoIFJlZ2lvbmFsIENvbGxlZ2UxHzAdBgNVBAMMFmFhcy5w\n\t\t\t\t\t\tZXRlcmJvcm91Z2guYWMudWswHhcNMTIxMDE3MTMzODAwWhcNMjIxMDE3MTMzODAw\n\t\t\t\t\t\tWjBJMSYwJAYDVQQKDB1QZXRlcmJvcm91Z2ggUmVnaW9uYWwgQ29sbGVnZTEfMB0G\n\t\t\t\t\t\tA1UEAwwWYWFzLnBldGVyYm9yb3VnaC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQAD\n\t\t\t\t\t\tggEPADCCAQoCggEBAIIbeuWlQPhTqwxItEPE51NVFfArYjaRW8O9b0aYfoYRQH86\n\t\t\t\t\t\tyYBOpO0xeaqb6fpCrjwvZwz+SPDcSu26f2u0NJ4eHClO8QAWGyh9XGH3WZu0R6YW\n\t\t\t\t\t\tnvbPTHjJOxSlDVo2Ukba3/TG+6WMQXa89b86NKbzLrOBISyrbLky1NTAtFI2+Kcm\n\t\t\t\t\t\tTsw7G+lk/jbAR4WD/AaXS9iXZjvOR5Fd+6ntvKp7PheNoD+7pbnEJV2Il1YMrmT4\n\t\t\t\t\t\tpuMw74kAIRbwKOGwA1VivNNGfnuGW8lYmujwPVfJwWXUXUgOqr86MHt+iatvJ7EA\n\t\t\t\t\t\t3ZmSUYmlJYFkdc3aWbMplI5WuOLlKK0EeBlVAG0CAwEAAaNQME4wHQYDVR0OBBYE\n\t\t\t\t\t\tFAF22/FrH+1Anys4Xk2bheSlL00KMB8GA1UdIwQYMBaAFAF22/FrH+1Anys4Xk2b\n\t\t\t\t\t\theSlL00KMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAAkfZ2yKKff4\n\t\t\t\t\t\tP6/mGdaEIu1t/eVwRgeCHKiW4cnDTPlIJ3qQ0oWKPnqvMuLnARbwJcA+BAKHrH47\n\t\t\t\t\t\tZ/o9G70hzo4+yQrw9Oh9N+b99gW62DhdWNiVJKD7u9pFI5w9rX0wPRlM9tuJJQqY\n\t\t\t\t\t\tmkS3SnkZDJOloF0cUjC2zo9cJNsCbPrjN+DkkVweNV6Bbzu8ABwDr6UV3zkY8iot\n\t\t\t\t\t\tS7F79s1+CGoFcU8g07hpq93i957bqsyCasIEc/wn54jQyLs4LorcKO5WJg/50Q2j\n\t\t\t\t\t\t/HItds1Wpk/aLQjt2/wnywHR3yWeBQN4B4QqN5TrzkN5OdZZsFHyWIzTmeXTwJtM\n\t\t\t\t\t\t8OV0uQf2TwU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Peterborough Regional College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.peterborough.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Peterborough Regional College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dans.idp.knaw.nl/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dans.idp.knaw.nl/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-09-10T20:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/37250172e5ee0e20a9477cdb1c0f9c19",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dans.knaw.nl"
              },
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Data Archiving and Networked Services (KNAW)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Data Archiving and Networked Services (KNAW)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/knaw-dans.png",
                    "height": "38",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Data Archiving and Networked Services (KNAW)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Data Archiving and Networked Services (KNAW)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Data Archiving and Networked Services (KNAW)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Data Archiving and Networked Services (KNAW)"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dans.knaw.nl/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dans.knaw.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Data Archiving and Networked Services (KNAW)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Data Archiving and Networked Services (KNAW)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.leedscitycollege.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Elliott"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:robert.elliott@leedscitycollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Elliott"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:robert.elliott@leedscitycollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.leedscitycollege.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUASZ17mZyc2P8yvTqlRkJ7HlBmGIwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJTEjMCEGA1UEAwwaaWRwLmxlZWRzY2l0eWNvbGxlZ2UuYWMudWswHhcNMTYw\n\t\t\t\t\t\tMjE2MTAzODEzWhcNMzYwMjE2MTAzODEzWjAlMSMwIQYDVQQDDBppZHAubGVlZHNj\n\t\t\t\t\t\taXR5Y29sbGVnZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAItzDj0k/BWt03nvPvnqFYP7yNNIv0kw26Mp8+sJ57dgoRDNouXV9rkvogl1a9HD\n\t\t\t\t\t\tqwdyFrXScT0i5qQNf9DzYfqRIMYIuK0JPjVANqECgYE+aPxjydrSWla/TrZnmNax\n\t\t\t\t\t\twV4akg2CBSW4MqNU/yiVEj60giVBtuSFktxbxYt2iu8YJQCv6qjTFhfldKYKsYjM\n\t\t\t\t\t\tnFzxxJ2ZOKwdkae2pNx1/5mr+foVzYV+LL72/O+osV1yCrSphxHKD9/e4l3923eM\n\t\t\t\t\t\tycBQf8KWko4kGBAZSyAT/qIfW/fZT/4DVnNf8+dxrVLC5SxGEWWr+I3WTm1bCcIw\n\t\t\t\t\t\tpsew+GIgr/QlhAgCZjgULpMCAwEAAaN7MHkwHQYDVR0OBBYEFGbfeQaIYjBWSyNI\n\t\t\t\t\t\tR1yxrwcEyXpSMFgGA1UdEQRRME+CGmlkcC5sZWVkc2NpdHljb2xsZWdlLmFjLnVr\n\t\t\t\t\t\thjFodHRwczovL2lkcC5sZWVkc2NpdHljb2xsZWdlLmFjLnVrL2lkcC9zaGliYm9s\n\t\t\t\t\t\tZXRoMA0GCSqGSIb3DQEBBQUAA4IBAQARbSnsXQTostANR0/c/KQ0qqY0SnkkDGgt\n\t\t\t\t\t\tXvdFxxiPrCV31690QHcLuJpNvtT/cYOD5n77D+uzT2GZs+UgqZ5cD69ZWhfe8ido\n\t\t\t\t\t\t68YHW52z1eeJotLvSG5G6zo7u1nzC8J1BSR9Z15y8Plu/h+pQjAWb8/HroreQ9mn\n\t\t\t\t\t\t0ceejOKUJdE0GWi3M/VdXBnq6xn+IJ9XUpLnAMVApoIF8ZYcrdeGUG5o92xnGVns\n\t\t\t\t\t\tOkHv4EZCNk+1JfIVGNA5w5t8ANJUJb/U2/ISd9eNZH4hqtwRK8LeLreWiOFMcWkK\n\t\t\t\t\t\tw/ZQfnfhrlXcEQ82N8Y7Rq24DoADTToXlxQ8BgqRAcmWayFKNn+2"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "leedscitycollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.leedscitycollege.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.leedscitycollege.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.leedscitycollege.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.leedscitycollege.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.leedscitycollege.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.leedscitycollege.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.leedscitycollege.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.leedscitycollege.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "leedscitycollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUASZ17mZyc2P8yvTqlRkJ7HlBmGIwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJTEjMCEGA1UEAwwaaWRwLmxlZWRzY2l0eWNvbGxlZ2UuYWMudWswHhcNMTYw\n\t\t\t\t\t\tMjE2MTAzODEzWhcNMzYwMjE2MTAzODEzWjAlMSMwIQYDVQQDDBppZHAubGVlZHNj\n\t\t\t\t\t\taXR5Y29sbGVnZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAItzDj0k/BWt03nvPvnqFYP7yNNIv0kw26Mp8+sJ57dgoRDNouXV9rkvogl1a9HD\n\t\t\t\t\t\tqwdyFrXScT0i5qQNf9DzYfqRIMYIuK0JPjVANqECgYE+aPxjydrSWla/TrZnmNax\n\t\t\t\t\t\twV4akg2CBSW4MqNU/yiVEj60giVBtuSFktxbxYt2iu8YJQCv6qjTFhfldKYKsYjM\n\t\t\t\t\t\tnFzxxJ2ZOKwdkae2pNx1/5mr+foVzYV+LL72/O+osV1yCrSphxHKD9/e4l3923eM\n\t\t\t\t\t\tycBQf8KWko4kGBAZSyAT/qIfW/fZT/4DVnNf8+dxrVLC5SxGEWWr+I3WTm1bCcIw\n\t\t\t\t\t\tpsew+GIgr/QlhAgCZjgULpMCAwEAAaN7MHkwHQYDVR0OBBYEFGbfeQaIYjBWSyNI\n\t\t\t\t\t\tR1yxrwcEyXpSMFgGA1UdEQRRME+CGmlkcC5sZWVkc2NpdHljb2xsZWdlLmFjLnVr\n\t\t\t\t\t\thjFodHRwczovL2lkcC5sZWVkc2NpdHljb2xsZWdlLmFjLnVrL2lkcC9zaGliYm9s\n\t\t\t\t\t\tZXRoMA0GCSqGSIb3DQEBBQUAA4IBAQARbSnsXQTostANR0/c/KQ0qqY0SnkkDGgt\n\t\t\t\t\t\tXvdFxxiPrCV31690QHcLuJpNvtT/cYOD5n77D+uzT2GZs+UgqZ5cD69ZWhfe8ido\n\t\t\t\t\t\t68YHW52z1eeJotLvSG5G6zo7u1nzC8J1BSR9Z15y8Plu/h+pQjAWb8/HroreQ9mn\n\t\t\t\t\t\t0ceejOKUJdE0GWi3M/VdXBnq6xn+IJ9XUpLnAMVApoIF8ZYcrdeGUG5o92xnGVns\n\t\t\t\t\t\tOkHv4EZCNk+1JfIVGNA5w5t8ANJUJb/U2/ISd9eNZH4hqtwRK8LeLreWiOFMcWkK\n\t\t\t\t\t\tw/ZQfnfhrlXcEQ82N8Y7Rq24DoADTToXlxQ8BgqRAcmWayFKNn+2"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Leeds City College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.leedscitycollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Leeds City College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.bridgend.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.bridgend.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/bridgend.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/bridgend.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bridgend.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bridgend College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bridgend.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.ripdev.co.uk/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Maeser"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dawid.maeser@rip.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dawid"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Maeser"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dawid.maeser@rip.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dawid"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.ripdev.co.uk/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-12-02T16:24:02Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Research in Practice (Development)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://rip.org.uk/about-us/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Dartington Hall Trust"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "logo": [
                  {
                    "text": "https://rip.org.uk/assets/_userfiles/images/general/Partner_logos/rip__logo_thumb_161_72.jpg",
                    "height": "72",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "161"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Research in Practice (Development)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDiDCCAnCgAwIBAgIJAL/6MNP9H2wJMA0GCSqGSIb3DQEBBQUAMDYxGTAXBgNV\n\t\t\t\t\t\tBAoTEFRlc3QgYXBwbGljYXRpb24xGTAXBgNVBAMTEHd3dy5yaXBkZXYuY28udWsw\n\t\t\t\t\t\tHhcNMTQwOTAyMTU1NTI2WhcNMjQwODMwMTU1NTI2WjA2MRkwFwYDVQQKExBUZXN0\n\t\t\t\t\t\tIGFwcGxpY2F0aW9uMRkwFwYDVQQDExB3d3cucmlwZGV2LmNvLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAwlcdLQ2hQWS+SRjt5QEgZ/OLdp0B4OZF\n\t\t\t\t\t\t8+fA4zz6ChjVctZNxXj2+nv9dTNNqLdBYM60fUzEO5aw0ZSwGfsqydi2ChNr0tYV\n\t\t\t\t\t\tgYWIhptsF09GsuRig396jXk76MnHIjEyPPkd38tpUJadrJL3ON+5RA8ZT/wvPH3f\n\t\t\t\t\t\tNE5t3Skig+sfSHm98aOCUPmHKHHRMGyZcKgVtQ4Jak8NpCvVbKRZBLrMGrR9Niuf\n\t\t\t\t\t\t+/I/A+7bye8KZWtdj7gheURvnWUV/90WDJyAZ1hAEweWXdezAm/h6o1xjlSQ67Um\n\t\t\t\t\t\tsP10MGcIn0eybKwMjEW6Z275gKArXof9A0+S2rxhRxTejg/bbEBDLwIDAQABo4GY\n\t\t\t\t\t\tMIGVMB0GA1UdDgQWBBQY/i2dHz4lM3HxLuYTVY0gzyCvHDBmBgNVHSMEXzBdgBQY\n\t\t\t\t\t\t/i2dHz4lM3HxLuYTVY0gzyCvHKE6pDgwNjEZMBcGA1UEChMQVGVzdCBhcHBsaWNh\n\t\t\t\t\t\tdGlvbjEZMBcGA1UEAxMQd3d3LnJpcGRldi5jby51a4IJAL/6MNP9H2wJMAwGA1Ud\n\t\t\t\t\t\tEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAHewb7qtFmo7XZOJExxQ92nS0EA9\n\t\t\t\t\t\tBXbvnO/m1PPsk8/86U5FWYNmXFBROF6W5Xhoi+6YsqmVUxtnpCKioDlG0q8j4n0d\n\t\t\t\t\t\taF9IifSckmrFoyOR3xQtqxFD+33AdXMliM9X8YRliEnsK7pAbVrQKx5lgfNItDUq\n\t\t\t\t\t\tfVnBpVHyc2It1F4wXI/Q4AAOIReAfWJhOebzZX1HJR35jgW4e7k43ws6+ugwePoT\n\t\t\t\t\t\tQ/e1eBcyJbEwzX7XZGlIA2LLqfCTaUdBKxKv8tM8+ozleQsBqApwAsU3v/fMpiKP\n\t\t\t\t\t\t9GcwjlRRJJrPgrX4dEDHCj2YUhnKS3CIgxT7eVW0OC3EoJ2P26mL6RWyWOY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDiDCCAnCgAwIBAgIJAL/6MNP9H2wJMA0GCSqGSIb3DQEBBQUAMDYxGTAXBgNV\n\t\t\t\t\t\tBAoTEFRlc3QgYXBwbGljYXRpb24xGTAXBgNVBAMTEHd3dy5yaXBkZXYuY28udWsw\n\t\t\t\t\t\tHhcNMTQwOTAyMTU1NTI2WhcNMjQwODMwMTU1NTI2WjA2MRkwFwYDVQQKExBUZXN0\n\t\t\t\t\t\tIGFwcGxpY2F0aW9uMRkwFwYDVQQDExB3d3cucmlwZGV2LmNvLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAwlcdLQ2hQWS+SRjt5QEgZ/OLdp0B4OZF\n\t\t\t\t\t\t8+fA4zz6ChjVctZNxXj2+nv9dTNNqLdBYM60fUzEO5aw0ZSwGfsqydi2ChNr0tYV\n\t\t\t\t\t\tgYWIhptsF09GsuRig396jXk76MnHIjEyPPkd38tpUJadrJL3ON+5RA8ZT/wvPH3f\n\t\t\t\t\t\tNE5t3Skig+sfSHm98aOCUPmHKHHRMGyZcKgVtQ4Jak8NpCvVbKRZBLrMGrR9Niuf\n\t\t\t\t\t\t+/I/A+7bye8KZWtdj7gheURvnWUV/90WDJyAZ1hAEweWXdezAm/h6o1xjlSQ67Um\n\t\t\t\t\t\tsP10MGcIn0eybKwMjEW6Z275gKArXof9A0+S2rxhRxTejg/bbEBDLwIDAQABo4GY\n\t\t\t\t\t\tMIGVMB0GA1UdDgQWBBQY/i2dHz4lM3HxLuYTVY0gzyCvHDBmBgNVHSMEXzBdgBQY\n\t\t\t\t\t\t/i2dHz4lM3HxLuYTVY0gzyCvHKE6pDgwNjEZMBcGA1UEChMQVGVzdCBhcHBsaWNh\n\t\t\t\t\t\tdGlvbjEZMBcGA1UEAxMQd3d3LnJpcGRldi5jby51a4IJAL/6MNP9H2wJMAwGA1Ud\n\t\t\t\t\t\tEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAHewb7qtFmo7XZOJExxQ92nS0EA9\n\t\t\t\t\t\tBXbvnO/m1PPsk8/86U5FWYNmXFBROF6W5Xhoi+6YsqmVUxtnpCKioDlG0q8j4n0d\n\t\t\t\t\t\taF9IifSckmrFoyOR3xQtqxFD+33AdXMliM9X8YRliEnsK7pAbVrQKx5lgfNItDUq\n\t\t\t\t\t\tfVnBpVHyc2It1F4wXI/Q4AAOIReAfWJhOebzZX1HJR35jgW4e7k43ws6+ugwePoT\n\t\t\t\t\t\tQ/e1eBcyJbEwzX7XZGlIA2LLqfCTaUdBKxKv8tM8+ozleQsBqApwAsU3v/fMpiKP\n\t\t\t\t\t\t9GcwjlRRJJrPgrX4dEDHCj2YUhnKS3CIgxT7eVW0OC3EoJ2P26mL6RWyWOY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://www.ripdev.co.uk/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.ripdev.co.uk/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ripdev.co.uk/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ripdev.co.uk/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://hornet.stars.manchester.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pssauth.support@manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stars Authentication Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pssauth.support@manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stars Authentication Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://hornet.stars.manchester.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Manchester: Hornet (Halls of Residence Network)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.manchester.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Manchester"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hornet.stars.manchester.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://hornet.stars.manchester.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hornet.stars.manchester.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hornet.stars.manchester.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://hornet.stars.manchester.ac.uk/Shibboleth.sso/STARSDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3zCCAcegAwIBAgIJAJuqRlY/1A1jMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\n\t\t\t\t\t\tBAMTCHZpbGxhbnVzMB4XDTA5MDUyMjA5MjYyN1oXDTE5MDUyMDA5MjYyN1owEzER\n\t\t\t\t\t\tMA8GA1UEAxMIdmlsbGFudXMwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDMytraxBwzCmyK3cnajuHo5sb2Hhs0aTIAEaUTpcP2qo/yQlT/S5Wjsm5tPtue\n\t\t\t\t\t\tpA8z0h56Y4on/k9gGGXnjej+23pfX/dPFCLEyE3MODunTkml1ObptRdMJT6CWRwg\n\t\t\t\t\t\tm9tdWr8r355vAbS/nEn0s0z3dwHBSuf7/q4GZoBkdbUG5TkOJidlWwe5y2OXSspU\n\t\t\t\t\t\tlehsON69DPXTxujsn9QNYzmdGxui+nrhHsj8hjPEQc9QcFDq7kXuDkM3Lry84h2p\n\t\t\t\t\t\tkWGXRebVqEGvs6b7CUxvS5xiOChpx6fTi0/LZQQRCzrtVOuYeb9o6wVejmzW6qun\n\t\t\t\t\t\tKH7dJCc14fgN2Icd7XYqIXYNAgMBAAGjNjA0MBMGA1UdEQQMMAqCCHZpbGxhbnVz\n\t\t\t\t\t\tMB0GA1UdDgQWBBTwGMy2sDPsfBZdE/1WuaxJDqVNuzANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAlvJzqsg5+ZiZ0XChtGL3j1n8PbGeah5AfEfXRvS6RrHu7/3w4WOy+XBpGteu\n\t\t\t\t\t\t8rqE/HkgqcpnXGS61TEU2HmdnNxqMTpGZoI7zbOkkcsNpvvG+dU5OdlEoTgJHuRI\n\t\t\t\t\t\t12EgBWjTXMweohxDkLANWaqfB9yVDT1MspMkxKmYalZK95N9M/d6gJfXWwU4GSd0\n\t\t\t\t\t\t4jfwMr9FzpOLAbxAHIohMA2djNfA2gNuve8PqIfBz6iaUAN0SGhGWMWWEL2B+uYZ\n\t\t\t\t\t\t2vtfZ+CtpWQteMiXFGEfEL/3U5OtjBxt7JaQxaJJ6iRTk5jdl+EI4NxHzmITf3+O\n\t\t\t\t\t\tEId1IbbmDWSHoeSw5za0bFOJcg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3zCCAcegAwIBAgIJAJuqRlY/1A1jMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\n\t\t\t\t\t\tBAMTCHZpbGxhbnVzMB4XDTA5MDUyMjA5MjYyN1oXDTE5MDUyMDA5MjYyN1owEzER\n\t\t\t\t\t\tMA8GA1UEAxMIdmlsbGFudXMwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDMytraxBwzCmyK3cnajuHo5sb2Hhs0aTIAEaUTpcP2qo/yQlT/S5Wjsm5tPtue\n\t\t\t\t\t\tpA8z0h56Y4on/k9gGGXnjej+23pfX/dPFCLEyE3MODunTkml1ObptRdMJT6CWRwg\n\t\t\t\t\t\tm9tdWr8r355vAbS/nEn0s0z3dwHBSuf7/q4GZoBkdbUG5TkOJidlWwe5y2OXSspU\n\t\t\t\t\t\tlehsON69DPXTxujsn9QNYzmdGxui+nrhHsj8hjPEQc9QcFDq7kXuDkM3Lry84h2p\n\t\t\t\t\t\tkWGXRebVqEGvs6b7CUxvS5xiOChpx6fTi0/LZQQRCzrtVOuYeb9o6wVejmzW6qun\n\t\t\t\t\t\tKH7dJCc14fgN2Icd7XYqIXYNAgMBAAGjNjA0MBMGA1UdEQQMMAqCCHZpbGxhbnVz\n\t\t\t\t\t\tMB0GA1UdDgQWBBTwGMy2sDPsfBZdE/1WuaxJDqVNuzANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAlvJzqsg5+ZiZ0XChtGL3j1n8PbGeah5AfEfXRvS6RrHu7/3w4WOy+XBpGteu\n\t\t\t\t\t\t8rqE/HkgqcpnXGS61TEU2HmdnNxqMTpGZoI7zbOkkcsNpvvG+dU5OdlEoTgJHuRI\n\t\t\t\t\t\t12EgBWjTXMweohxDkLANWaqfB9yVDT1MspMkxKmYalZK95N9M/d6gJfXWwU4GSd0\n\t\t\t\t\t\t4jfwMr9FzpOLAbxAHIohMA2djNfA2gNuve8PqIfBz6iaUAN0SGhGWMWWEL2B+uYZ\n\t\t\t\t\t\t2vtfZ+CtpWQteMiXFGEfEL/3U5OtjBxt7JaQxaJJ6iRTk5jdl+EI4NxHzmITf3+O\n\t\t\t\t\t\tEId1IbbmDWSHoeSw5za0bFOJcg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hornet.stars.manchester.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://hornet.stars.manchester.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hornet.stars.manchester.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hornet.stars.manchester.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hornet.stars.manchester.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://hornet.stars.manchester.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hornet.stars.manchester.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://hornet.stars.manchester.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://hornet.stars.manchester.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://hornet.stars.manchester.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sharav.abes.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "p2i@abes.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sharav.abes.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-04-10T08:58:06Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sharav.abes.fr/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sharav.abes.fr/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sharav.abes.fr/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sharav.abes.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sharav.abes.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sharav.abes.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "abes.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.abes.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Agency staff"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnels de l'Agence"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ABES - French Bibliographic Agency for Higher Education"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ABES - Agence Bibliographique de l'Enseignement Sup\u00e9rieur"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAMJyfTXyWtg2HoJZYvPzC5uTOkpLMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMMDnNoYXJhdi5hYmVzLmZyMB4XDTE1MDMxNjA5MzYxM1oX\nDTM1MDMxNjA5MzYxM1owGTEXMBUGA1UEAwwOc2hhcmF2LmFiZXMuZnIwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDTcLz3fcz0nnGZBl8dx+gsKgz2nazH\nqLl58rvOUGQdcZqWutb0rmSlLv14aLJcSZiCse01Xa3VTdNboftLB9TzHgsRhy6E\neR5ISWBs4Hdw2bdbaV4KQb5zh8Mrjt/CO6yVUE2cr0bVPZKB2dGyblpdwQkdyakA\nDz2GuTIW2egZ466y0FaOTHzQ4jw3cGtOm0r1v7aMOLQg0tJQ3Ao8we36p+T/YrKN\nqrt2kQbfbWMQz9rZsWLpI6YjCwImnTHOov+Sphq1QN/f3beZUM66hHBjTWytgZoB\ntRhPzG02XGwY5FPYp/+xxU2uBUyJTdzON+J+/jK8CXlmLh6Et8qCH2mnAgMBAAGj\nYzBhMB0GA1UdDgQWBBTxc6ftLuPBfgE21OFh7hYWV5sVODBABgNVHREEOTA3gg5z\naGFyYXYuYWJlcy5mcoYlaHR0cHM6Ly9zaGFyYXYuYWJlcy5mci9pZHAvc2hpYmJv\nbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAbxeaU+peTP/+ZEadJxgffuRWU3L+qZnc\nl36JFO9Rn1BFiABemGGUd1WU0AxNVJ0HDu3NZjKmQz3dYIjy5DR4nF9dDS25br3R\nyUPa2NSIAatSB4BPbf8j+EpWrcuBBRXGGWXfvOTQq/DuKU9/FPGEvrIW5Wnl/uDd\nkCI8+2KPpfuz002xNQID4wKyUJy9jyuE/2cn2JA1iYB0MMc3uqIls8T8Wn1leWr+\nTG5a9eJRJRp7O8KekUdkn17tzldLodiuduABA/gncseSrDLBUJntriF3yGGbCdJz\n8Dg24giw4jehoGYeEf1DW9ACdySlZDzf6YPGNUfVY9kVNDnLi9Th2Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ABES - Agence Bibliographique de l'Enseignement Sup\u00e9rieur"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.abes.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ABES - Agence Bibliographique de l'Enseignement Sup\u00e9rieur"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://signon.rug.nl/nidp/saml2/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://signon.rug.nl/nidp/saml2/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2014-10-09T11:57:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/56d78f05c751aeb3d57b29caff8510e3",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rug.nl"
              },
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Rijksuniversiteit Groningen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Rijksuniversiteit Groningen"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/rug.png",
                    "height": "25",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rijksuniversiteit Groningen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Groningen"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RUG"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rug.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Rijksuniversiteit Groningen"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://federation.citylit.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cassell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cliff.Cassell@citylit.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ratcliffe"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cassell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cliff.Cassell@citylit.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ratcliffe"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federation.citylit.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID3zCCAsegAwIBAgIBATANBgkqhkiG9w0BAQUFADBYMRQwEgYDVQQKDAtJbnRl\n\t\t\t\t\t\tcm5ldDJRSTEdMBsGA1UECwwUSW50ZXJuZXRRdWlja0luc3RhbGwxITAfBgNVBAMM\n\t\t\t\t\t\tGGZlZGVyYXRpb24uY2l0eWxpdC5hYy51azAeFw0wODEwMDExNTI3MDFaFw0xODEw\n\t\t\t\t\t\tMDExNTI3MDFaMFgxFDASBgNVBAoMC0ludGVybmV0MlFJMR0wGwYDVQQLDBRJbnRl\n\t\t\t\t\t\tcm5ldFF1aWNrSW5zdGFsbDEhMB8GA1UEAwwYZmVkZXJhdGlvbi5jaXR5bGl0LmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAm8uZyZuCsmNPxwh5\n\t\t\t\t\t\twYzBQxH5Lm4k88NjijrPczsmMv6ytTktOryvUT53onCvV56Q/K9fNFp6n2oED1qT\n\t\t\t\t\t\tGBFULXBjn2V05mXOcbxP10gbmVP3ik8K+uSfZWrG6Zhko2mCx+N1Ic9lvnjELAMZ\n\t\t\t\t\t\tn4iX9/XJpnYyzHJTCJ+nhsG3q1wYftXblAm3UQn3kBpzjAKTWmAKEFnfLYt2hXQi\n\t\t\t\t\t\tSJpTEMAMc7LF4x2Wn65D8Yy7ZUDv9D0gXvHCfLKaY9KP3nb5v9jxxOy2MY9myApV\n\t\t\t\t\t\t1FBauyD5N4zh5CoiXa5Kc4ulsPpgl7rsJzVK40nDsSTBh5z4zhKFoLY2ed9D4u5m\n\t\t\t\t\t\tN7gC2wIDAQABo4GzMIGwMB0GA1UdDgQWBBQt1uPa7g7op1dL4DqzM9jEUGbEjDCB\n\t\t\t\t\t\tgAYDVR0jBHkwd4AULdbj2u4O6KdXS+A6szPYxFBmxIyhXKRaMFgxFDASBgNVBAoM\n\t\t\t\t\t\tC0ludGVybmV0MlFJMR0wGwYDVQQLDBRJbnRlcm5ldFF1aWNrSW5zdGFsbDEhMB8G\n\t\t\t\t\t\tA1UEAwwYZmVkZXJhdGlvbi5jaXR5bGl0LmFjLnVrggEBMAwGA1UdEwQFMAMBAf8w\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAHUFXipOGkG4InAusODqfe1aUG+skCY9zzXTaIOP\n\t\t\t\t\t\tkpXQ0Q5FifQiShE/b2vIp15lQG+qDE0kppyk5cBkdZkGAVb5K0aQIxcl9MiL67QX\n\t\t\t\t\t\th6iqlSpAgMU6u6L2/VWBeVjNmqcc9X88nXWDv4VAOJy4YIZVMn16bkeD40doSuQJ\n\t\t\t\t\t\tS9ipahSI+KhN8a84nx+inBjh2W47rle5BYVjblu3eCKf3i4/W03r2jurW2+yEwlA\n\t\t\t\t\t\tauQ7PwLXsxQpFa/sfc+gSM6AvKc88UT/q3sQHt8vzrr6i2yN6U7s5jbeJ8UhXYeA\n\t\t\t\t\t\tEzP9054/ECA5LnVNOe+dKhGm84MWiC1ovYbuPx0vFQTzRJE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "citylit.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://federation.citylit.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://federation.citylit.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://federation.citylit.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.citylit.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://federation.citylit.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federation.citylit.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://federation.citylit.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://federation.citylit.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "citylit.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID3zCCAsegAwIBAgIBATANBgkqhkiG9w0BAQUFADBYMRQwEgYDVQQKDAtJbnRl\n\t\t\t\t\t\tcm5ldDJRSTEdMBsGA1UECwwUSW50ZXJuZXRRdWlja0luc3RhbGwxITAfBgNVBAMM\n\t\t\t\t\t\tGGZlZGVyYXRpb24uY2l0eWxpdC5hYy51azAeFw0wODEwMDExNTI3MDFaFw0xODEw\n\t\t\t\t\t\tMDExNTI3MDFaMFgxFDASBgNVBAoMC0ludGVybmV0MlFJMR0wGwYDVQQLDBRJbnRl\n\t\t\t\t\t\tcm5ldFF1aWNrSW5zdGFsbDEhMB8GA1UEAwwYZmVkZXJhdGlvbi5jaXR5bGl0LmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAm8uZyZuCsmNPxwh5\n\t\t\t\t\t\twYzBQxH5Lm4k88NjijrPczsmMv6ytTktOryvUT53onCvV56Q/K9fNFp6n2oED1qT\n\t\t\t\t\t\tGBFULXBjn2V05mXOcbxP10gbmVP3ik8K+uSfZWrG6Zhko2mCx+N1Ic9lvnjELAMZ\n\t\t\t\t\t\tn4iX9/XJpnYyzHJTCJ+nhsG3q1wYftXblAm3UQn3kBpzjAKTWmAKEFnfLYt2hXQi\n\t\t\t\t\t\tSJpTEMAMc7LF4x2Wn65D8Yy7ZUDv9D0gXvHCfLKaY9KP3nb5v9jxxOy2MY9myApV\n\t\t\t\t\t\t1FBauyD5N4zh5CoiXa5Kc4ulsPpgl7rsJzVK40nDsSTBh5z4zhKFoLY2ed9D4u5m\n\t\t\t\t\t\tN7gC2wIDAQABo4GzMIGwMB0GA1UdDgQWBBQt1uPa7g7op1dL4DqzM9jEUGbEjDCB\n\t\t\t\t\t\tgAYDVR0jBHkwd4AULdbj2u4O6KdXS+A6szPYxFBmxIyhXKRaMFgxFDASBgNVBAoM\n\t\t\t\t\t\tC0ludGVybmV0MlFJMR0wGwYDVQQLDBRJbnRlcm5ldFF1aWNrSW5zdGFsbDEhMB8G\n\t\t\t\t\t\tA1UEAwwYZmVkZXJhdGlvbi5jaXR5bGl0LmFjLnVrggEBMAwGA1UdEwQFMAMBAf8w\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAHUFXipOGkG4InAusODqfe1aUG+skCY9zzXTaIOP\n\t\t\t\t\t\tkpXQ0Q5FifQiShE/b2vIp15lQG+qDE0kppyk5cBkdZkGAVb5K0aQIxcl9MiL67QX\n\t\t\t\t\t\th6iqlSpAgMU6u6L2/VWBeVjNmqcc9X88nXWDv4VAOJy4YIZVMn16bkeD40doSuQJ\n\t\t\t\t\t\tS9ipahSI+KhN8a84nx+inBjh2W47rle5BYVjblu3eCKf3i4/W03r2jurW2+yEwlA\n\t\t\t\t\t\tauQ7PwLXsxQpFa/sfc+gSM6AvKc88UT/q3sQHt8vzrr6i2yN6U7s5jbeJ8UhXYeA\n\t\t\t\t\t\tEzP9054/ECA5LnVNOe+dKhGm84MWiC1ovYbuPx0vFQTzRJE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "City Lit"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.citylit.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "City Lit"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth-idp.collegenet.com/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "admins@collegenet.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CollegeNET IT Administrator"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "maint@collegenet.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CollegeNET Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth-idp.collegenet.com/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth-idp.collegenet.com:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-idp.collegenet.com:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYDCCAkigAwIBAgIUE7bIe4hwDfwhSM8wn4E8Rza/AdEwDQYJKoZIhvcNAQEF\nBQAwKDEmMCQGA1UEAxMdc2hpYmJvbGV0aC1pZHAuY29sbGVnZW5ldC5jb20wHhcN\nMTAwMjExMjMxNTMyWhcNMzAwMjExMjMxNTMyWjAoMSYwJAYDVQQDEx1zaGliYm9s\nZXRoLWlkcC5jb2xsZWdlbmV0LmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBAIFEn4f9ObsbquJlOPvIazrYJ+cltWyFL5My6Sci6K1L/xTfRNAtGA3U\nDQL3wOALSFtfddl/ULTfQYU2/AZKFj7BwA72lou6G9SUco5QchHUoaiCxnOs1LQ8\nkP2rA5nsxwfJrYnGULx1+c7qKmatN+OftKL96LD6g2rBw794FZd7j29ptrqOv97B\ngzVaH5od8ZMvegsKzpuYf0cOklD0dRJEW0ppb79JLJvSrWVX6K9oAvOXJx7+nHwK\nBGqETOU4nhXXJOgyVqib7d3mCg7YWyJXl1tLnTLZrHLi7bVk2BKUZO2yT62SsBy3\nMkThcDHokvyvwo/GUmF2dnJaYj59afUCAwEAAaOBgTB/MF4GA1UdEQRXMFWCHXNo\naWJib2xldGgtaWRwLmNvbGxlZ2VuZXQuY29thjRodHRwczovL3NoaWJib2xldGgt\naWRwLmNvbGxlZ2VuZXQuY29tL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRf5n4e\n0WSw5ow5doI1M71y7rzfGjANBgkqhkiG9w0BAQUFAAOCAQEAGlTRbPUU9d5ond5O\nO3efuPRoIMCurUo6xaTD39rnr5m94Cr55n3dOwCnvjn0IMQvvvqGBJRD92i0VvZI\n4r63QtU5ZqSeAiNG5FFCA89jnR6P0nZqXV3R3mRaRHDM2apD9pNz2PUtFdktw5AB\ncURaOv4usFw8sWMQg0oM3rHC5VbTCCoQbmiRGiMCIqSEJbZ02JG+lUhrv1jp9xNj\nPjDjvSkxTTH3Mo4Lt7jVww76pgWRDa8L0eZ4sOREQVqMXEMcB3JNy7fFimunvxgw\nfIJN0Yk9uqeMFBoZiL8r0itI9BTt4gk2sYDbNnG6/pqoPS9mwmiM22XEeTeG1x3a\nWWeBDw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "collegenet.com"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth-idp.collegenet.com/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth-idp.collegenet.com/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth-idp.collegenet.com/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth-idp.collegenet.com/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth-idp.collegenet.com:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-idp.collegenet.com:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "collegenet.com"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://corp.collegenet.com/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CollegeNET, Inc."
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CollegeNET, Inc. is a leading developer of web-based systems for higher education and non-profit organizations, serving more than 1,300 clients worldwide.\nCollegeNET products include course and event scheduling, space and resource management, web calendar publishing, e-commerce and contributions, accounting, online admission application processing, online course evaluation, and commencement services."
                  }
                ],
                "logo": [
                  {
                    "text": "https://corp.collegenet.com/img-link/CN_blue-small.jpg",
                    "lang": "en",
                    "height": "51",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "200"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://corp.collegenet.com/privacy.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYDCCAkigAwIBAgIUE7bIe4hwDfwhSM8wn4E8Rza/AdEwDQYJKoZIhvcNAQEF\nBQAwKDEmMCQGA1UEAxMdc2hpYmJvbGV0aC1pZHAuY29sbGVnZW5ldC5jb20wHhcN\nMTAwMjExMjMxNTMyWhcNMzAwMjExMjMxNTMyWjAoMSYwJAYDVQQDEx1zaGliYm9s\nZXRoLWlkcC5jb2xsZWdlbmV0LmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBAIFEn4f9ObsbquJlOPvIazrYJ+cltWyFL5My6Sci6K1L/xTfRNAtGA3U\nDQL3wOALSFtfddl/ULTfQYU2/AZKFj7BwA72lou6G9SUco5QchHUoaiCxnOs1LQ8\nkP2rA5nsxwfJrYnGULx1+c7qKmatN+OftKL96LD6g2rBw794FZd7j29ptrqOv97B\ngzVaH5od8ZMvegsKzpuYf0cOklD0dRJEW0ppb79JLJvSrWVX6K9oAvOXJx7+nHwK\nBGqETOU4nhXXJOgyVqib7d3mCg7YWyJXl1tLnTLZrHLi7bVk2BKUZO2yT62SsBy3\nMkThcDHokvyvwo/GUmF2dnJaYj59afUCAwEAAaOBgTB/MF4GA1UdEQRXMFWCHXNo\naWJib2xldGgtaWRwLmNvbGxlZ2VuZXQuY29thjRodHRwczovL3NoaWJib2xldGgt\naWRwLmNvbGxlZ2VuZXQuY29tL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRf5n4e\n0WSw5ow5doI1M71y7rzfGjANBgkqhkiG9w0BAQUFAAOCAQEAGlTRbPUU9d5ond5O\nO3efuPRoIMCurUo6xaTD39rnr5m94Cr55n3dOwCnvjn0IMQvvvqGBJRD92i0VvZI\n4r63QtU5ZqSeAiNG5FFCA89jnR6P0nZqXV3R3mRaRHDM2apD9pNz2PUtFdktw5AB\ncURaOv4usFw8sWMQg0oM3rHC5VbTCCoQbmiRGiMCIqSEJbZ02JG+lUhrv1jp9xNj\nPjDjvSkxTTH3Mo4Lt7jVww76pgWRDa8L0eZ4sOREQVqMXEMcB3JNy7fFimunvxgw\nfIJN0Yk9uqeMFBoZiL8r0itI9BTt4gk2sYDbNnG6/pqoPS9mwmiM22XEeTeG1x3a\nWWeBDw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CollegeNET, Inc."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://collegenet.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CollegeNET, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://federation.cyclone-project.eu/auth/realms/master",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Slawik"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mathias.slawik@tu-berlin.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mathias"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Slawik"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mathias.slawik@tu-berlin.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mathias"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Slawik"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mathias.slawik@tu-berlin.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mathias"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federation.cyclone-project.eu/auth/realms/master",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-09-30T08:59:16Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Technische Universit\u00e4t Berlin"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Technische Universit\u00e4t Berlin"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tu-berlin.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tu-berlin.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e160"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e160"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.cyclone-project.eu/auth/realms/master/broker/TU-Berlin/endpoint",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.cyclone-project.eu/auth/realms/master/broker/dfnaai/endpoint",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.cyclone-project.eu/auth/realms/master/broker/UVA/endpoint",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.cyclone-project.eu/auth/realms/master/broker/CNRS/endpoint",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Der CYCLONE Test Federation Provider dient zum Testen und zur Demonstration der im CYCLONE \u2013 Projekt entwickelten Technologien"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The CYCLONE Test Federation Provider is used for testing and demonstrating the technologies developed within the CYCLONE project"
                  }
                ],
                "logo": [
                  {
                    "text": "https://secure.cyclone-project.eu/assets/images/CYCLONE-LOGO-mini.png",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "197"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://secure.cyclone-project.eu/sp_privacy_policy.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CYCLONE Test Federation Provider"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CYCLONE Test Federation Provider"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "federation.cyclone-project.eu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF4jCCBMqgAwIBAgIHGc8MRIp62zANBgkqhkiG9w0BAQsFADBnMQswCQYDVQQG\nEwJERTEnMCUGA1UEChMeVGVjaG5pc2NoZSBVbml2ZXJzaXRhZXQgQmVybGluMQ8w\nDQYDVQQDEwZUVUItQ0ExHjAcBgkqhkiG9w0BCQEWD2NhQFRVLUJlcmxpbi5ERTAe\nFw0xNTA3MjIxMjM4MTNaFw0xODEwMTgxMjM4MTNaMIGlMQswCQYDVQQGEwJERTEP\nMA0GA1UECAwGQmVybGluMQ8wDQYDVQQHDAZCZXJsaW4xJzAlBgNVBAoMHlRlY2hu\naXNjaGUgVW5pdmVyc2l0YWV0IEJlcmxpbjEjMCEGA1UECwwaU2VydmljZS1jZW50\ncmljIE5ldHdvcmtpbmcxJjAkBgNVBAMMHWZlZGVyYXRpb24uY3ljbG9uZS1wcm9q\nZWN0LmV1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoGJTW+QZ156G\n51hhDG3nOpAdq+U9cb5kl0nEgFnvzSIu7tVZIr4dLBQjTFXfHl5tQ6JwbqxAvYFf\nLco+1llQe25I5ax/ULQv+Y0uZC2992pnsSezRB2sVc4UNb/XnQMCRP6nKAeLLmwg\nophcUmI5ItxkwftpW2iW8bAp3Rq3vpXHFVKgxvKXt8IQ37j0SwKVuSaDRbIdIPtC\nXjpRb9wXdKYgS+hCmF0IKblH5mowOr6qVy4ss+m/n3z23MoE3teTJrWK/urSRBuk\n7zzh5x4mVO5jH3/p8enh7ePX/sMgf68VDnIFrXPFdgDQxbv9eOGyMTyWX6Mt6AWE\nmVXA2SR1jQIDAQABo4ICUjCCAk4wTwYDVR0gBEgwRjARBg8rBgEEAYGtIYIsAQEE\nAwMwEQYPKwYBBAGBrSGCLAIBBAMBMA8GDSsGAQQBga0hgiwBAQQwDQYLKwYBBAGB\nrSGCLB4wCQYDVR0TBAIwADALBgNVHQ8EBAMCBeAwHQYDVR0lBBYwFAYIKwYBBQUH\nAwIGCCsGAQUFBwMBMB0GA1UdDgQWBBSGIY/ZZD7VJ2s/fIl5bKlKV71I0DAfBgNV\nHSMEGDAWgBQjMkKe/mJCTvtO0BebeOftiow+eDAoBgNVHREEITAfgh1mZWRlcmF0\naW9uLmN5Y2xvbmUtcHJvamVjdC5ldTCBgwYDVR0fBHwwejA7oDmgN4Y1aHR0cDov\nL2NkcDEucGNhLmRmbi5kZS90dS1iZXJsaW4tY2EvcHViL2NybC9jYWNybC5jcmww\nO6A5oDeGNWh0dHA6Ly9jZHAyLnBjYS5kZm4uZGUvdHUtYmVybGluLWNhL3B1Yi9j\ncmwvY2FjcmwuY3JsMIHTBggrBgEFBQcBAQSBxjCBwzAzBggrBgEFBQcwAYYnaHR0\ncDovL29jc3AucGNhLmRmbi5kZS9PQ1NQLVNlcnZlci9PQ1NQMEUGCCsGAQUFBzAC\nhjlodHRwOi8vY2RwMS5wY2EuZGZuLmRlL3R1LWJlcmxpbi1jYS9wdWIvY2FjZXJ0\nL2NhY2VydC5jcnQwRQYIKwYBBQUHMAKGOWh0dHA6Ly9jZHAyLnBjYS5kZm4uZGUv\ndHUtYmVybGluLWNhL3B1Yi9jYWNlcnQvY2FjZXJ0LmNydDANBgkqhkiG9w0BAQsF\nAAOCAQEAcD7me5NvAkGAAMQSxlDVtmHi6foUPNt9adzUh1HujfkpKj7SDffpvFzl\nqjQuzcyXT03k0mC5BzRVZcvhoTHO8iAN84zD98C26kWUW4rrnX0J0LNlJ6WuTwG8\ngvNWLsYAZQQQWfSgRUGQXMzCFgXa/pFe8En63eh49MHhMNMFCZ+CBzLCxJmtGqRR\n/GTZHsUfmLgMcM/i77wPSSTz/WJ1XqpSdTX3ZcqxHTj91Mkle4feDbs0esiRrgm+\npEG48bIOW7zC1nhkztvEfA5XgHVh9HvCV/QoeHOpuzCv8brHbPQtj1sZi6EsFb89\nawjhhm+d45PRPp1X8A1+/JdMtBQbiQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=federation.cyclone-project.eu,OU=Service-centric Networking,O=Technische Universitaet Berlin,L=Berlin,ST=Berlin,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "federation.cyclone-project.eu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF4jCCBMqgAwIBAgIHGc8MRIp62zANBgkqhkiG9w0BAQsFADBnMQswCQYDVQQG\nEwJERTEnMCUGA1UEChMeVGVjaG5pc2NoZSBVbml2ZXJzaXRhZXQgQmVybGluMQ8w\nDQYDVQQDEwZUVUItQ0ExHjAcBgkqhkiG9w0BCQEWD2NhQFRVLUJlcmxpbi5ERTAe\nFw0xNTA3MjIxMjM4MTNaFw0xODEwMTgxMjM4MTNaMIGlMQswCQYDVQQGEwJERTEP\nMA0GA1UECAwGQmVybGluMQ8wDQYDVQQHDAZCZXJsaW4xJzAlBgNVBAoMHlRlY2hu\naXNjaGUgVW5pdmVyc2l0YWV0IEJlcmxpbjEjMCEGA1UECwwaU2VydmljZS1jZW50\ncmljIE5ldHdvcmtpbmcxJjAkBgNVBAMMHWZlZGVyYXRpb24uY3ljbG9uZS1wcm9q\nZWN0LmV1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoGJTW+QZ156G\n51hhDG3nOpAdq+U9cb5kl0nEgFnvzSIu7tVZIr4dLBQjTFXfHl5tQ6JwbqxAvYFf\nLco+1llQe25I5ax/ULQv+Y0uZC2992pnsSezRB2sVc4UNb/XnQMCRP6nKAeLLmwg\nophcUmI5ItxkwftpW2iW8bAp3Rq3vpXHFVKgxvKXt8IQ37j0SwKVuSaDRbIdIPtC\nXjpRb9wXdKYgS+hCmF0IKblH5mowOr6qVy4ss+m/n3z23MoE3teTJrWK/urSRBuk\n7zzh5x4mVO5jH3/p8enh7ePX/sMgf68VDnIFrXPFdgDQxbv9eOGyMTyWX6Mt6AWE\nmVXA2SR1jQIDAQABo4ICUjCCAk4wTwYDVR0gBEgwRjARBg8rBgEEAYGtIYIsAQEE\nAwMwEQYPKwYBBAGBrSGCLAIBBAMBMA8GDSsGAQQBga0hgiwBAQQwDQYLKwYBBAGB\nrSGCLB4wCQYDVR0TBAIwADALBgNVHQ8EBAMCBeAwHQYDVR0lBBYwFAYIKwYBBQUH\nAwIGCCsGAQUFBwMBMB0GA1UdDgQWBBSGIY/ZZD7VJ2s/fIl5bKlKV71I0DAfBgNV\nHSMEGDAWgBQjMkKe/mJCTvtO0BebeOftiow+eDAoBgNVHREEITAfgh1mZWRlcmF0\naW9uLmN5Y2xvbmUtcHJvamVjdC5ldTCBgwYDVR0fBHwwejA7oDmgN4Y1aHR0cDov\nL2NkcDEucGNhLmRmbi5kZS90dS1iZXJsaW4tY2EvcHViL2NybC9jYWNybC5jcmww\nO6A5oDeGNWh0dHA6Ly9jZHAyLnBjYS5kZm4uZGUvdHUtYmVybGluLWNhL3B1Yi9j\ncmwvY2FjcmwuY3JsMIHTBggrBgEFBQcBAQSBxjCBwzAzBggrBgEFBQcwAYYnaHR0\ncDovL29jc3AucGNhLmRmbi5kZS9PQ1NQLVNlcnZlci9PQ1NQMEUGCCsGAQUFBzAC\nhjlodHRwOi8vY2RwMS5wY2EuZGZuLmRlL3R1LWJlcmxpbi1jYS9wdWIvY2FjZXJ0\nL2NhY2VydC5jcnQwRQYIKwYBBQUHMAKGOWh0dHA6Ly9jZHAyLnBjYS5kZm4uZGUv\ndHUtYmVybGluLWNhL3B1Yi9jYWNlcnQvY2FjZXJ0LmNydDANBgkqhkiG9w0BAQsF\nAAOCAQEAcD7me5NvAkGAAMQSxlDVtmHi6foUPNt9adzUh1HujfkpKj7SDffpvFzl\nqjQuzcyXT03k0mC5BzRVZcvhoTHO8iAN84zD98C26kWUW4rrnX0J0LNlJ6WuTwG8\ngvNWLsYAZQQQWfSgRUGQXMzCFgXa/pFe8En63eh49MHhMNMFCZ+CBzLCxJmtGqRR\n/GTZHsUfmLgMcM/i77wPSSTz/WJ1XqpSdTX3ZcqxHTj91Mkle4feDbs0esiRrgm+\npEG48bIOW7zC1nhkztvEfA5XgHVh9HvCV/QoeHOpuzCv8brHbPQtj1sZi6EsFb89\nawjhhm+d45PRPp1X8A1+/JdMtBQbiQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=federation.cyclone-project.eu,OU=Service-centric Networking,O=Technische Universitaet Berlin,L=Berlin,ST=Berlin,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.cyclone-project.eu/auth/realms/master/broker/TU-Berlin/endpoint",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.cyclone-project.eu/auth/realms/master/broker/UVA/endpoint",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.cyclone-project.eu/auth/realms/master/broker/CNRS/endpoint",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.cyclone-project.eu/auth/realms/master/broker/dfnaai/endpoint",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://fsa.rocmondriaan.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://fsa.rocmondriaan.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-05-01T16:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/5c809081b2d195aeef7614ef5986f937",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ROC Mondriaan"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ROC Mondriaan"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/ROC-Mondriaan_Logo.jpg",
                    "height": "78",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "214"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ROC Mondriaan"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ROC Mondriaan"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ROC Mondriaan"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ROC Mondriaan"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rocmondriaan.nl/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rocmondriaan.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ROC Mondriaan"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ROC Mondriaan"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://slateford.edina.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Stuart"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alex.stuart@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Stuart"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alex.stuart@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://slateford.edina.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-06-16T13:56:52Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Slateford"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://edina.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://slateford.edina.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://slateford.edina.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://slateford.edina.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://slateford.edina.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://slateford.edina.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://slateford.edina.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://slateford.edina.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJAOyJ8qoa9P1EMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\n\t\t\t\t\t\tBAMTFXNsYXRlZm9yZC5lZGluYS5hYy51azAeFw0xNTA2MTUxNjEzMTRaFw0yNTA2\n\t\t\t\t\t\tMTIxNjEzMTRaMCAxHjAcBgNVBAMTFXNsYXRlZm9yZC5lZGluYS5hYy51azCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOJTRzMDCh8DZkYxMxNJHCcWVNOV\n\t\t\t\t\t\tz6J3rWG90urlurHLozovTq+eTqr5JLrJ5c+BkGVUZlqmrmjbL3B4REbqo1z+OryS\n\t\t\t\t\t\tUeirpFAmg6x43kliIqRDhjEuyScZyUKW33Jv1J9bimNB1z+FWn7j43DZrb6K6sLV\n\t\t\t\t\t\t+ztjpgYXCRoQVctR04ARiwqVlhPnbULy3NydDVKtsgyICkEc0osOsMtD0HdvY+hY\n\t\t\t\t\t\tqa6kdLXKvYzZrkJOtfX7ELXSeIOJ2f9779PgGh4WBLgyieFQYarDu/PwK2QQIGhn\n\t\t\t\t\t\ty+g/eIBsYQ1XqWOz18nmAukLep7IrhL5b4d8IUFbF1yZFtbnlRh+KjIdQc0CAwEA\n\t\t\t\t\t\tAaNDMEEwIAYDVR0RBBkwF4IVc2xhdGVmb3JkLmVkaW5hLmFjLnVrMB0GA1UdDgQW\n\t\t\t\t\t\tBBSmLfXgbxNlCPa76Sf3WOtbBZ82RTANBgkqhkiG9w0BAQUFAAOCAQEAg2vimu9p\n\t\t\t\t\t\tGWq5ZeED2Km2oIAJShhXQzexi3implPYrXxik4/K9w3lrCBVLsEAIUkpK4VaeIoM\n\t\t\t\t\t\trwBCJsym0okPlHvepMejLOle6F3cuk9sfTIX2M39lpA9MKxMMMKwDLGVOaKzWP/N\n\t\t\t\t\t\tBSxgy9B0QWGlV1Olm1WL4RQ+neCmrYxYp7W46Q9vkEmiLcW+8Jc70xMmadFeu/5s\n\t\t\t\t\t\t9b2O8rjVYDR2KmtSD8Yqk2ZJxxt4VxDriGXgEMx7OAhsJ1KkydWKAS4FhW12GiAE\n\t\t\t\t\t\t8WdrnAJTiIHQ+dCDEJ7aP4UUyW27pNpqPHNQVRcj9x2fT2egIy/7qG6Xpy/ZaC6R\n\t\t\t\t\t\tGZxkOPiMUxA+/g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://slateford.edina.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://slateford.edina.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://slateford.edina.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://slateford.edina.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://slateford.edina.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://slateford.edina.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://earthserver-sg.consorzio-cometa.it/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bruno"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:riccardo.bruno@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Riccardo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:credentials-admin@ct.infn.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barbera"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:roberto.barbera@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roberto"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://earthserver-sg.consorzio-cometa.it/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2012-04-11T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Earth Server Science Gateway provided by Consorzio COMETA"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Earth Server Science Gateway erogato da Consorzio COMETA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.consorzio-cometa.it/en/home"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.consorzio-cometa.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consorzio COMETA"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consorzio COMETA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://earthserver-sg.consorzio-cometa.it/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://earthserver-sg.consorzio-cometa.it/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://earthserver-sg.consorzio-cometa.it/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://earthserver-sg.consorzio-cometa.it/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://earthserver-sg.consorzio-cometa.it/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://earthserver-sg.consorzio-cometa.it/service"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service allows to use on a Grid infrastructure the applications of the EarthServer project which provides Earth and planetary science researchers with tools to achieve barrier-free \"mix and match\" access to multi-source, any-size, multi-dimensional spatio-temporal data based on open standards."
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Questo servizio permette l'accesso e l'uso delle applicazioni/servizi sviluppati per il progetto europeo EarthServer che ha come obiettivo quello di fornire a ricercatori sui problemi della terra e degli astri tool l'accesso senza limiti ad un mix di dati provenienti da diverse sorgenti, con differenti dimensione e spazio-temporali, basati su open standards."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EarthServer Science Gateway"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EarthServer Science Gateway"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://earthserver-sg.consorzio-cometa.it/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://earthserver-sg.consorzio-cometa.it/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDwjCCAqoCCQDOuURFUMCewDANBgkqhkiG9w0BAQsFADCBojELMAkGA1UEBhMC\nSVQxDzANBgNVBAgMBlNpY2lseTEQMA4GA1UEBwwHQ2F0YW5pYTEZMBcGA1UECgwQ\nQ29uc29yemlvIENPTUVUQTErMCkGA1UEAwwiZWFydGhzZXJ2ZXItc2cuY29uc29y\nemlvLWNvbWV0YS5pdDEoMCYGCSqGSIb3DQEJARYZbWFyY28uZmFyZ2V0dGFAY3Qu\naW5mbi5pdDAeFw0xNjAyMTAxMTU3MThaFw00NjAyMDIxMTU3MThaMIGiMQswCQYD\nVQQGEwJJVDEPMA0GA1UECAwGU2ljaWx5MRAwDgYDVQQHDAdDYXRhbmlhMRkwFwYD\nVQQKDBBDb25zb3J6aW8gQ09NRVRBMSswKQYDVQQDDCJlYXJ0aHNlcnZlci1zZy5j\nb25zb3J6aW8tY29tZXRhLml0MSgwJgYJKoZIhvcNAQkBFhltYXJjby5mYXJnZXR0\nYUBjdC5pbmZuLml0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAr5Vu\nM43lwYixVhJN8HXJwit3CmZT3FBkChFfu0tMQLlnTorEmpUpoFcPqh/hOmCji/Jb\nFQHlANY2SW24uZadJZbvOt0qpTmieBjKq45t61TGMn55qaTEkUDSJsEJOcuTH1MG\nkKPCanD2805lv6Sr/krhO1uJDMClH23wbF1s496UXn83ibnR9P3/ID+dqEJeZCYO\nvTc0i0v+Yv6VtHc9LfUYFkGFnnv9pIE8Y8MgDGuFUiHYss5Lh5zVqV/5V6Bh8MPg\nrg3+ii8k/tJI7nM/+IYdLfI8NqYIM5tfCdYc4ldCz299AHSOKM2taD8EeaKKSxWS\n4RCF4cEy4P6e4P9WawIDAQABMA0GCSqGSIb3DQEBCwUAA4IBAQAlj/UvpjlrAu55\nPDFriEg5GTwcR9BQZ1RH7v6ea2VoGVyFVPB4UBpASGCp0t49LcfWMVNZBVm5aiFY\nWOrR3aVjaqgO3PusTcyG7Rc4wG+S0vm+vSOiBOt+f8Q4dDOBHiyQijNnTr/gfJak\nZbOhLYOF/zsQz3BA1YR8gUP1JTAFCWWsUEOeiTQZV72fmnYCH0dD2pOH4UYmDEpf\nJf5qMf2rWBWH12tA4OWB9K4mCxMreJXVLkVRZeBoUhsHPUw5dFjygxjltAjxwJzr\n+IKYqNdLx4qoYjhmMQA9tl71wtO30StilfIjD+Oun0FONKJs2SRSAGJbeardLJZ8\n6JqVlaVd"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://earthserver-sg.consorzio-cometa.it/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://earthserver-sg.consorzio-cometa.it/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://earthserver-sg.consorzio-cometa.it/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://earthserver-sg.consorzio-cometa.it/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://earthserver-sg.consorzio-cometa.it/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://earthserver-sg.consorzio-cometa.it/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "EarthServer Science Gateway"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This service allows to use on a Grid infrastructure the applications of the EarthServer project which provides Earth and planetary science researchers with tools to achieve barrier-free \"mix and match\" access to multi-source, any-size, multi-dimensional spatio-temporal data based on open standards."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cafe.iec.pa.gov.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Equipe de Operacao da Rede IEC"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rede@iec.pa.gov.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.iec.pa.gov.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDwDCCAqgCAQAwDQYJKoZIhvcNAQEFBQAwgaUxITAfBgNVBAoTGEluc3RpdHV0\nbyBFdmFuZHJvIENoYWdhczEUMBIGA1UECxMLSW5mb3JtYXRpY2ExITAfBgkqhkiG\n9w0BCQEWEnJlZGVAaWVjLnBhLmdvdi5icjEOMAwGA1UEBxMFQmVsZW0xDTALBgNV\nBAgTBFBhcmExCzAJBgNVBAYTAkJSMRswGQYDVQQDExJjYWZlLmllYy5wYS5nb3Yu\nYnIwHhcNMTUwMjI0MTIxNjMxWhcNMjAwMjIzMTIxNjMxWjCBpTEhMB8GA1UEChMY\nSW5zdGl0dXRvIEV2YW5kcm8gQ2hhZ2FzMRQwEgYDVQQLEwtJbmZvcm1hdGljYTEh\nMB8GCSqGSIb3DQEJARYScmVkZUBpZWMucGEuZ292LmJyMQ4wDAYDVQQHEwVCZWxl\nbTENMAsGA1UECBMEUGFyYTELMAkGA1UEBhMCQlIxGzAZBgNVBAMTEmNhZmUuaWVj\nLnBhLmdvdi5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALh7iEs2\nNi8j/GJ3Zw2jN9XApjZ+UL50nJDAL4XeLuP7e7yaXlW4BTU/5kpVyEKMBG6tdGRk\nhAhAySdMnYGevlMsh7ntx3rITe9IS6L7H9mHBbE8m3IJaoe3D16Y6tn5f1SZOD5M\npZoxpQGfIB1vScKfg/uiFZ+uWKeFoU+Tv7849/muDsM+RS6oY+06jKui0oVLQGsg\nTVzLFY985RICZDPva3m44wO7MsiSaAv0IdtLG51N8GzEDJaHBNpMz148gdo7I0ec\nTF74zqwWvBvcuK0xE3+/3j/gDPrTcIzqd4vD8bcwwedrY62OClPCGD37hLBGfZKO\nz8DXr0u4hX+qc7kCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAaTtMhdCZIJqL/pMA\npf91UXgHPVlvoJZYwEKJuTUF6pwlQAlSlL7J/fpEqXLbjWbVMPFTANx7c/MfwE54\njh3NMxgaxfeH6A+Xk3bOPMiSWRtTuF+Fbma9qfuA7mSsFbX8y0oRP3jZWgKmrAYg\nEkuVIN8rWqCemhAdb7oIa4TV0HSgVWc5yFRu6bX+JFJhIAw8vCL+Ml6HqK+Hku08\nnsZVerrPzQbWGxKGwAvRVxaV0ahOrMSRgE8A0eCEpU5Gso2vDZ9lnMzs8hHGzA2n\nJU0I6DpaM7+LMDUe10IlIxclhBktiIfWjTSGIpXc6dvJZS+YKC7q1Xn4Hgfv2Pi0\nEFJUUg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iec.pa.gov.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.iec.pa.gov.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.iec.pa.gov.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.iec.pa.gov.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.iec.pa.gov.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.iec.pa.gov.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.iec.pa.gov.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.iec.pa.gov.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.iec.pa.gov.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iec.pa.gov.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.iec.pa.gov.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.iec.pa.gov.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IEC - Instituto Evandro Chagas"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IEC - Instituto Evandro Chagas"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IEC - Instituto Evandro Chagas"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IEC - Instituto Evandro Chagas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDwDCCAqgCAQAwDQYJKoZIhvcNAQEFBQAwgaUxITAfBgNVBAoTGEluc3RpdHV0\nbyBFdmFuZHJvIENoYWdhczEUMBIGA1UECxMLSW5mb3JtYXRpY2ExITAfBgkqhkiG\n9w0BCQEWEnJlZGVAaWVjLnBhLmdvdi5icjEOMAwGA1UEBxMFQmVsZW0xDTALBgNV\nBAgTBFBhcmExCzAJBgNVBAYTAkJSMRswGQYDVQQDExJjYWZlLmllYy5wYS5nb3Yu\nYnIwHhcNMTUwMjI0MTIxNjMxWhcNMjAwMjIzMTIxNjMxWjCBpTEhMB8GA1UEChMY\nSW5zdGl0dXRvIEV2YW5kcm8gQ2hhZ2FzMRQwEgYDVQQLEwtJbmZvcm1hdGljYTEh\nMB8GCSqGSIb3DQEJARYScmVkZUBpZWMucGEuZ292LmJyMQ4wDAYDVQQHEwVCZWxl\nbTENMAsGA1UECBMEUGFyYTELMAkGA1UEBhMCQlIxGzAZBgNVBAMTEmNhZmUuaWVj\nLnBhLmdvdi5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALh7iEs2\nNi8j/GJ3Zw2jN9XApjZ+UL50nJDAL4XeLuP7e7yaXlW4BTU/5kpVyEKMBG6tdGRk\nhAhAySdMnYGevlMsh7ntx3rITe9IS6L7H9mHBbE8m3IJaoe3D16Y6tn5f1SZOD5M\npZoxpQGfIB1vScKfg/uiFZ+uWKeFoU+Tv7849/muDsM+RS6oY+06jKui0oVLQGsg\nTVzLFY985RICZDPva3m44wO7MsiSaAv0IdtLG51N8GzEDJaHBNpMz148gdo7I0ec\nTF74zqwWvBvcuK0xE3+/3j/gDPrTcIzqd4vD8bcwwedrY62OClPCGD37hLBGfZKO\nz8DXr0u4hX+qc7kCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAaTtMhdCZIJqL/pMA\npf91UXgHPVlvoJZYwEKJuTUF6pwlQAlSlL7J/fpEqXLbjWbVMPFTANx7c/MfwE54\njh3NMxgaxfeH6A+Xk3bOPMiSWRtTuF+Fbma9qfuA7mSsFbX8y0oRP3jZWgKmrAYg\nEkuVIN8rWqCemhAdb7oIa4TV0HSgVWc5yFRu6bX+JFJhIAw8vCL+Ml6HqK+Hku08\nnsZVerrPzQbWGxKGwAvRVxaV0ahOrMSRgE8A0eCEpU5Gso2vDZ9lnMzs8hHGzA2n\nJU0I6DpaM7+LMDUe10IlIxclhBktiIfWjTSGIpXc6dvJZS+YKC7q1Xn4Hgfv2Pi0\nEFJUUg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IEC - Instituto Evandro Chagas"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IEC - Instituto Evandro Chagas"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iec.pa.gov.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iec.pa.gov.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IEC - Instituto Evandro Chagas"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IEC - Instituto Evandro Chagas"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://alumidp.princeton.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "steven@princeton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven Niedzwiecki"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sdp@princeton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Security and Data Protection"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://alumidp.princeton.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://alumidp.princeton.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://alumidp.princeton.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://alumidp.princeton.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://alumidp.princeton.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://alumidp.princeton.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "alumni.princeton.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Princeton University Alumni Identity Provider"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Princeton University Alumni"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVAKG9V3PzZjR4ecwHT4AZLBOz/wyrMA0GCSqGSIb3DQEB\nBQUAMCAxHjAcBgNVBAMTFWFsdW1pZHAucHJpbmNldG9uLmVkdTAeFw0xNDAzMDQx\nOTAwMzZaFw0zNDAzMDQxOTAwMzZaMCAxHjAcBgNVBAMTFWFsdW1pZHAucHJpbmNl\ndG9uLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIkdv16hF0en\n8GQO6Z2JOUkKy+pcmGjRp4f4hdDaALfu2XgfZ1NKWGbU3+GAZ5J9gx+sMJ7REphq\np/g0aUWlzlxH4OBPOBI2yzH8Qk2SNgSzJJPzvKt1h9aC+6a5IzwezT3pwgJL6qwq\nvOqo64BKJt6hcRtMwcix/iiXCAOpYzPK5ELiNW/KFdJs9tBi/bsd4ismoNYP9v9Y\nuTRVUEB6UyGFW36l53TlNba3LqE8QD8W0ZKIk18AFCBkxGc5NdLkBa2Ba/FhflWI\n+PTpX2h8Zu6N2w10j9RylG6Tl18JA5GlJiYXIgLjIr/53axYuMXzv6qOMSFhbcOD\n//Vz5bTeP28CAwEAAaNxMG8wTgYDVR0RBEcwRYIVYWx1bWlkcC5wcmluY2V0b24u\nZWR1hixodHRwczovL2FsdW1pZHAucHJpbmNldG9uLmVkdS9pZHAvc2hpYmJvbGV0\naDAdBgNVHQ4EFgQUvO7+POJaCDIgds8naRSxtlmhgdAwDQYJKoZIhvcNAQEFBQAD\nggEBAFweyY54iGLK6pMSJy2HEcOk545A7nLi1l0ikqzHccVHX3UlTiUWQJwOGSsu\nEW/sjZJEtShgDgT87fo1wyV7F0ACsqqSIyTuP5EJEvAyK0KA3Q+1TS59QJ2WYGv9\nfvFLbxn8fzrgtx2OxBx0a9IKAZz1/8BlIRpyR9/D9ulCvzWYQDDMAcsVuIhCLsPC\n2zWpo/m3AlVWRT1ETM4qq87Gu3r3evpu24QdN+pbd6/72ebNRssdFY/2JsqsMyrw\nRbu421cAQ0VJGoLW4cLLElf0nCOJhhjboQziAH5uKGpYyJqMI/9djVZUQcMCAzXL\nOo1MSQQ0dwJedoRxmRK7sUYg9KY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Princeton University Alumni"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.princeton.edu/index.shtml"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Princeton University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://access.lcb.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Inglehearn"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:AInglehearn@lcb.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Anne-Mary"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Grimley"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cgrimley@lcb.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://access.lcb.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEBDCCAuygAwIBAgIJAN9TCY4/UbHrMA0GCSqGSIb3DQEBCwUAMIGCMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEXMBUGA1UECBMOV2VzdCBZb3Jrc2hpcmUxDjAMBgNVBAcTBUxlZWRz\n\t\t\t\t\t\tMSIwIAYDVQQKExlMZWVkcyBDb2xsZWdlIG9mIEJ1aWxkaW5nMQswCQYDVQQLEwJJ\n\t\t\t\t\t\tVDEZMBcGA1UEAxMQYWNjZXNzLmxjYi5hYy51azAeFw0xNTEwMjYxMjM2NTNaFw0y\n\t\t\t\t\t\tNTEwMjMxMjM2NTNaMIGCMQswCQYDVQQGEwJHQjEXMBUGA1UECBMOV2VzdCBZb3Jr\n\t\t\t\t\t\tc2hpcmUxDjAMBgNVBAcTBUxlZWRzMSIwIAYDVQQKExlMZWVkcyBDb2xsZWdlIG9m\n\t\t\t\t\t\tIEJ1aWxkaW5nMQswCQYDVQQLEwJJVDEZMBcGA1UEAxMQYWNjZXNzLmxjYi5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJhPGIb8Ic803/i5gcez\n\t\t\t\t\t\tRoBda2SRhO3OTa2/EJT4gV2wWpu8ZRtpHztDjGOIg7UugkPuYaf4gZYAEvxesV+Y\n\t\t\t\t\t\tq7tMo2PrAsgKpB6ojEMRKF4mTrL9zXmmPaVlFvNtcO9rLZsTrx2YTOnEQhQZDXKf\n\t\t\t\t\t\tTmFWOA9mcZTtsSVNorzXnzl9bbJ60z/J3WHgOe4CaySoB0XkZAuWz6rlPcNxiva+\n\t\t\t\t\t\t1mhuH/1L1VpjNikm1jbrPd3mOdtrXyV/pvsRtQSPIIwjJNH9tNxB0VUwnNMTBp0p\n\t\t\t\t\t\tEaVyD7YuuDtgTdTucXk9UAX2q5r1KcjDqUXzeKaqZaOW2DN1HJGGVSB32iUddUwq\n\t\t\t\t\t\tlUMCAwEAAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBH\n\t\t\t\t\t\tZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFJA+9GMp9gH9Aci+LoESpsYx\n\t\t\t\t\t\tiK28MB8GA1UdIwQYMBaAFJA+9GMp9gH9Aci+LoESpsYxiK28MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAA4IBAQCB+A+aczQV7nH16EGXoHX7mp53MhDaedNxby8/OvA0QPdmbswUzlFk\n\t\t\t\t\t\tkjTm586LHBVmHRl2T6O/frWa+Gj9a5JHZpPOPbfqX/cXukMxPPTowovaMCZpVt+M\n\t\t\t\t\t\tz3RGgVZM+bC/tG/6uRW8uqx+G15HmPPuaPGurm270PGMaCrZyeLsQFy7O49KiGPB\n\t\t\t\t\t\tatsdksWwCGMFwEZTBq1C8evMcXJsX+jXG2aJelmdzTXF3pgwk/xFEva/WRyTFJzw\n\t\t\t\t\t\twk9lJCd1E74ji6tYtVoFwsuyjSfAVHFBXW1A4uzzFcZXOHVNtnJC3mb+FbtD4l9S\n\t\t\t\t\t\tvjXcKCtem5JD2o4TAAjWFrb9l5ZJZvZq"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lcb.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://access.lcb.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://access.lcb.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://access.lcb.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://access.lcb.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://access.lcb.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://access.lcb.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://access.lcb.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://access.lcb.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lcb.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEBDCCAuygAwIBAgIJAN9TCY4/UbHrMA0GCSqGSIb3DQEBCwUAMIGCMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEXMBUGA1UECBMOV2VzdCBZb3Jrc2hpcmUxDjAMBgNVBAcTBUxlZWRz\n\t\t\t\t\t\tMSIwIAYDVQQKExlMZWVkcyBDb2xsZWdlIG9mIEJ1aWxkaW5nMQswCQYDVQQLEwJJ\n\t\t\t\t\t\tVDEZMBcGA1UEAxMQYWNjZXNzLmxjYi5hYy51azAeFw0xNTEwMjYxMjM2NTNaFw0y\n\t\t\t\t\t\tNTEwMjMxMjM2NTNaMIGCMQswCQYDVQQGEwJHQjEXMBUGA1UECBMOV2VzdCBZb3Jr\n\t\t\t\t\t\tc2hpcmUxDjAMBgNVBAcTBUxlZWRzMSIwIAYDVQQKExlMZWVkcyBDb2xsZWdlIG9m\n\t\t\t\t\t\tIEJ1aWxkaW5nMQswCQYDVQQLEwJJVDEZMBcGA1UEAxMQYWNjZXNzLmxjYi5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJhPGIb8Ic803/i5gcez\n\t\t\t\t\t\tRoBda2SRhO3OTa2/EJT4gV2wWpu8ZRtpHztDjGOIg7UugkPuYaf4gZYAEvxesV+Y\n\t\t\t\t\t\tq7tMo2PrAsgKpB6ojEMRKF4mTrL9zXmmPaVlFvNtcO9rLZsTrx2YTOnEQhQZDXKf\n\t\t\t\t\t\tTmFWOA9mcZTtsSVNorzXnzl9bbJ60z/J3WHgOe4CaySoB0XkZAuWz6rlPcNxiva+\n\t\t\t\t\t\t1mhuH/1L1VpjNikm1jbrPd3mOdtrXyV/pvsRtQSPIIwjJNH9tNxB0VUwnNMTBp0p\n\t\t\t\t\t\tEaVyD7YuuDtgTdTucXk9UAX2q5r1KcjDqUXzeKaqZaOW2DN1HJGGVSB32iUddUwq\n\t\t\t\t\t\tlUMCAwEAAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBH\n\t\t\t\t\t\tZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFJA+9GMp9gH9Aci+LoESpsYx\n\t\t\t\t\t\tiK28MB8GA1UdIwQYMBaAFJA+9GMp9gH9Aci+LoESpsYxiK28MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAA4IBAQCB+A+aczQV7nH16EGXoHX7mp53MhDaedNxby8/OvA0QPdmbswUzlFk\n\t\t\t\t\t\tkjTm586LHBVmHRl2T6O/frWa+Gj9a5JHZpPOPbfqX/cXukMxPPTowovaMCZpVt+M\n\t\t\t\t\t\tz3RGgVZM+bC/tG/6uRW8uqx+G15HmPPuaPGurm270PGMaCrZyeLsQFy7O49KiGPB\n\t\t\t\t\t\tatsdksWwCGMFwEZTBq1C8evMcXJsX+jXG2aJelmdzTXF3pgwk/xFEva/WRyTFJzw\n\t\t\t\t\t\twk9lJCd1E74ji6tYtVoFwsuyjSfAVHFBXW1A4uzzFcZXOHVNtnJC3mb+FbtD4l9S\n\t\t\t\t\t\tvjXcKCtem5JD2o4TAAjWFrb9l5ZJZvZq"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Leeds College of Building"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lcb.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Leeds College of Building"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://wccidp.west-cheshire.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Allmark"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sallmark@west-cheshire.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Allmark"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sallmark@west-cheshire.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://wccidp.west-cheshire.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-07-09T14:52:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIELDCCAxSgAwIBAgIJALbBsFNhx0GLMA0GCSqGSIb3DQEBCwUAMIGWMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjERMA8GA1UECAwIQ2hlc2hpcmUxFzAVBgNVBAcMDkVsbGVzbWVyZSBQ\n\t\t\t\t\t\tb3J0MR4wHAYDVQQKDBVXZXN0IENoZXNoaXJlIENvbGxlZ2UxGTAXBgNVBAsMEE5l\n\t\t\t\t\t\tdHdvcmsgU2VydmljZXMxIDAeBgNVBAMMF2lkcC53ZXN0LWNoZXNoaXJlLmFjLnVr\n\t\t\t\t\t\tMB4XDTE1MDQwNzA5NTYxNloXDTI1MDQwNDA5NTYxNlowgZYxCzAJBgNVBAYTAkdC\n\t\t\t\t\t\tMREwDwYDVQQIDAhDaGVzaGlyZTEXMBUGA1UEBwwORWxsZXNtZXJlIFBvcnQxHjAc\n\t\t\t\t\t\tBgNVBAoMFVdlc3QgQ2hlc2hpcmUgQ29sbGVnZTEZMBcGA1UECwwQTmV0d29yayBT\n\t\t\t\t\t\tZXJ2aWNlczEgMB4GA1UEAwwXaWRwLndlc3QtY2hlc2hpcmUuYWMudWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDEzVH8ZUrWUFt//z7BuE7E7soNCq2J\n\t\t\t\t\t\t8Aeq+KsiXbCK+tiwDXrIC8B7XFcyaDQvk5hxPt8XvYTpNpOBprTkIk9d7sy+cQX3\n\t\t\t\t\t\thfT44RCX+TNuWTKdQlUPkC0pbx2wFLROcMsUOgZP+ekC8SaQgRefui4unaRNNz9U\n\t\t\t\t\t\t++L/cgYZLtcmd9sPklLTkl+77e2d6W5onnvQ9gvBDQUQBoScR5fg2hfwmkQqXUt3\n\t\t\t\t\t\tFtXmcdhvILxKk9au7DLBqQfiAPfg9a08aBKJIn2XDW7q8NQ761edWQ2KF7IdgSL6\n\t\t\t\t\t\tgTx+I13wes3g7apkZ1ONco81O35+Hty0lcNHGCRNL8+zrgVH20Z4mvSnAgMBAAGj\n\t\t\t\t\t\tezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVk\n\t\t\t\t\t\tIENlcnRpZmljYXRlMB0GA1UdDgQWBBTL14zF0JlVNVY8uZXgSMl1u2pHwjAfBgNV\n\t\t\t\t\t\tHSMEGDAWgBTL14zF0JlVNVY8uZXgSMl1u2pHwjANBgkqhkiG9w0BAQsFAAOCAQEA\n\t\t\t\t\t\tIMvwvDpJGJAqMWnT+fNq8J5WYAbUOGIDLvhP0LNqFfYaZET989TX2anvblGibLDp\n\t\t\t\t\t\t7ydk0U2Y8lWhiivlqqYu2Re5LQuGXXmwms3QQPwm4hn3aCZd6c7gggyg80+uJXaj\n\t\t\t\t\t\t9rCSyQRR3Z0jGw2E4afl8ZZmirJL7fqNfKow/um85xl3RimY6WnLkgSCXYGmegmD\n\t\t\t\t\t\tVDR6eyHwIij3Os8EHb8XQx4PObO+GPLmfSPdtA+hpwnLgqUKDGqOaz951hAh97Cs\n\t\t\t\t\t\tfM/hzk/TNCxzJfh7dfU6mdVsSwq0J3hLAxHf7tSzXLRruF/9VruFlXSWwX+0brFn\n\t\t\t\t\t\tOWNVr2kgXYhLkUAS9p7LWg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "west-cheshire.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.west-cheshire.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.west-cheshire.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.west-cheshire.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.west-cheshire.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.west-cheshire.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.west-cheshire.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.west-cheshire.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.west-cheshire.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "west-cheshire.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIELDCCAxSgAwIBAgIJALbBsFNhx0GLMA0GCSqGSIb3DQEBCwUAMIGWMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjERMA8GA1UECAwIQ2hlc2hpcmUxFzAVBgNVBAcMDkVsbGVzbWVyZSBQ\n\t\t\t\t\t\tb3J0MR4wHAYDVQQKDBVXZXN0IENoZXNoaXJlIENvbGxlZ2UxGTAXBgNVBAsMEE5l\n\t\t\t\t\t\tdHdvcmsgU2VydmljZXMxIDAeBgNVBAMMF2lkcC53ZXN0LWNoZXNoaXJlLmFjLnVr\n\t\t\t\t\t\tMB4XDTE1MDQwNzA5NTYxNloXDTI1MDQwNDA5NTYxNlowgZYxCzAJBgNVBAYTAkdC\n\t\t\t\t\t\tMREwDwYDVQQIDAhDaGVzaGlyZTEXMBUGA1UEBwwORWxsZXNtZXJlIFBvcnQxHjAc\n\t\t\t\t\t\tBgNVBAoMFVdlc3QgQ2hlc2hpcmUgQ29sbGVnZTEZMBcGA1UECwwQTmV0d29yayBT\n\t\t\t\t\t\tZXJ2aWNlczEgMB4GA1UEAwwXaWRwLndlc3QtY2hlc2hpcmUuYWMudWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDEzVH8ZUrWUFt//z7BuE7E7soNCq2J\n\t\t\t\t\t\t8Aeq+KsiXbCK+tiwDXrIC8B7XFcyaDQvk5hxPt8XvYTpNpOBprTkIk9d7sy+cQX3\n\t\t\t\t\t\thfT44RCX+TNuWTKdQlUPkC0pbx2wFLROcMsUOgZP+ekC8SaQgRefui4unaRNNz9U\n\t\t\t\t\t\t++L/cgYZLtcmd9sPklLTkl+77e2d6W5onnvQ9gvBDQUQBoScR5fg2hfwmkQqXUt3\n\t\t\t\t\t\tFtXmcdhvILxKk9au7DLBqQfiAPfg9a08aBKJIn2XDW7q8NQ761edWQ2KF7IdgSL6\n\t\t\t\t\t\tgTx+I13wes3g7apkZ1ONco81O35+Hty0lcNHGCRNL8+zrgVH20Z4mvSnAgMBAAGj\n\t\t\t\t\t\tezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVk\n\t\t\t\t\t\tIENlcnRpZmljYXRlMB0GA1UdDgQWBBTL14zF0JlVNVY8uZXgSMl1u2pHwjAfBgNV\n\t\t\t\t\t\tHSMEGDAWgBTL14zF0JlVNVY8uZXgSMl1u2pHwjANBgkqhkiG9w0BAQsFAAOCAQEA\n\t\t\t\t\t\tIMvwvDpJGJAqMWnT+fNq8J5WYAbUOGIDLvhP0LNqFfYaZET989TX2anvblGibLDp\n\t\t\t\t\t\t7ydk0U2Y8lWhiivlqqYu2Re5LQuGXXmwms3QQPwm4hn3aCZd6c7gggyg80+uJXaj\n\t\t\t\t\t\t9rCSyQRR3Z0jGw2E4afl8ZZmirJL7fqNfKow/um85xl3RimY6WnLkgSCXYGmegmD\n\t\t\t\t\t\tVDR6eyHwIij3Os8EHb8XQx4PObO+GPLmfSPdtA+hpwnLgqUKDGqOaz951hAh97Cs\n\t\t\t\t\t\tfM/hzk/TNCxzJfh7dfU6mdVsSwq0J3hLAxHf7tSzXLRruF/9VruFlXSWwX+0brFn\n\t\t\t\t\t\tOWNVr2kgXYhLkUAS9p7LWg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "West Cheshire College (WCC)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.west-cheshire.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "West Cheshire College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.jyu.fi/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Haapalo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:useradmin@jyu.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pasi"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.jyu.fi/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.csc.fi/english/institutions/haka/instructions/join/eduGAINRegistrationStatement/"
              }
            ],
            "registration_authority": "http://www.csc.fi/haka",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDyjCCArICCQC/3Ou0lsl3wzANBgkqhkiG9w0BAQUFADCBpjEgMB4GA1UEChMX\nVW5pdmVyc2l0eSBvZiBKeXZhc2t5bGExKTAnBgNVBAsTIEhha2EgZmVkZXJhdGlv\nbiBzZWxmLXNpZ25lZCBjZXJ0MR8wHQYJKoZIhvcNAQkBFhB1c2VyYWRtaW5Aanl1\nLmZpMRIwEAYDVQQHEwlKeXZhc2t5bGExCzAJBgNVBAYTAkZJMRUwEwYDVQQDEwxs\nb2dpbi5qeXUuZmkwHhcNMTMwNDA1MTEyOTQxWhcNMzMwMzMxMTEyOTQxWjCBpjEg\nMB4GA1UEChMXVW5pdmVyc2l0eSBvZiBKeXZhc2t5bGExKTAnBgNVBAsTIEhha2Eg\nZmVkZXJhdGlvbiBzZWxmLXNpZ25lZCBjZXJ0MR8wHQYJKoZIhvcNAQkBFhB1c2Vy\nYWRtaW5Aanl1LmZpMRIwEAYDVQQHEwlKeXZhc2t5bGExCzAJBgNVBAYTAkZJMRUw\nEwYDVQQDEwxsb2dpbi5qeXUuZmkwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQD8Y4Twul9N7kGDhz5oRwEYR4maD7hhDsipJvdQMYM5BTDTh3FGX4KvPFKx\nytz1YVmtHwMmO/GVp0T1O+p9DDNE7AdyPGJieZlaOaYb6INKg1qNStJ3abmtTa1o\nZtNFnCSsTl+POeCw4tLBU+EIqK6qHMtWaMJk3Kh66oFYwxhVLkvFQuLAFPp13NS3\nNQp6t6zNZOBEJoJ6WIRtz7YT0RPC0Q0jWK8dJErbcqoyWQXhKhelyOWVl4P+JsqA\nU0UkVh/suKfmm/0VhoqWybfbtXyW983eRbmF7im+5LedpL28vNYRjdYk/Y0jGGC0\n8hqR0kjed9s/V+HFHjpnajmnEfD9AgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAIEO\nJdYZBrjvzJ4ytg8BqN4rggSSrKinsVdtQ1y9nEx/qpBP3W7PS40WkNdnKA+I2V/6\nzWTagYRZitwFvlinyxmetweYuSSSMlhlaJpGWz/fzJ6o+tDW5CVobSy2ijQen/SM\nQwNNrLA+WptOoM78cnMqm5EcPNAVr3JnxUQ7qUxU0pptTVc+R2Jqq26ASoMfoxDC\nlW022c90W26TOCwiKF0zlCi4pj3K9g1GR17bXoQYEsWw1TT34m5O9J8kQglBoqmP\nZT98QsABBlU/uI3L0YRvitCKE7hgN4v5OMmlyGOiktQteV93hU+gWyP0gwjSsaT+\nOH7h/C8smWC5jlD+a/0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "jyu.fi"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.jyu.fi:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.jyu.fi:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.jyu.fi/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.jyu.fi/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.jyu.fi/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "jyu.fi"
              },
              {
                "display_name": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Jyv\u00e4skyl\u00e4n yliopisto"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Jyv\u00e4skyl\u00e4 universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Jyv\u00e4skyla"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDyjCCArICCQC/3Ou0lsl3wzANBgkqhkiG9w0BAQUFADCBpjEgMB4GA1UEChMX\nVW5pdmVyc2l0eSBvZiBKeXZhc2t5bGExKTAnBgNVBAsTIEhha2EgZmVkZXJhdGlv\nbiBzZWxmLXNpZ25lZCBjZXJ0MR8wHQYJKoZIhvcNAQkBFhB1c2VyYWRtaW5Aanl1\nLmZpMRIwEAYDVQQHEwlKeXZhc2t5bGExCzAJBgNVBAYTAkZJMRUwEwYDVQQDEwxs\nb2dpbi5qeXUuZmkwHhcNMTMwNDA1MTEyOTQxWhcNMzMwMzMxMTEyOTQxWjCBpjEg\nMB4GA1UEChMXVW5pdmVyc2l0eSBvZiBKeXZhc2t5bGExKTAnBgNVBAsTIEhha2Eg\nZmVkZXJhdGlvbiBzZWxmLXNpZ25lZCBjZXJ0MR8wHQYJKoZIhvcNAQkBFhB1c2Vy\nYWRtaW5Aanl1LmZpMRIwEAYDVQQHEwlKeXZhc2t5bGExCzAJBgNVBAYTAkZJMRUw\nEwYDVQQDEwxsb2dpbi5qeXUuZmkwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQD8Y4Twul9N7kGDhz5oRwEYR4maD7hhDsipJvdQMYM5BTDTh3FGX4KvPFKx\nytz1YVmtHwMmO/GVp0T1O+p9DDNE7AdyPGJieZlaOaYb6INKg1qNStJ3abmtTa1o\nZtNFnCSsTl+POeCw4tLBU+EIqK6qHMtWaMJk3Kh66oFYwxhVLkvFQuLAFPp13NS3\nNQp6t6zNZOBEJoJ6WIRtz7YT0RPC0Q0jWK8dJErbcqoyWQXhKhelyOWVl4P+JsqA\nU0UkVh/suKfmm/0VhoqWybfbtXyW983eRbmF7im+5LedpL28vNYRjdYk/Y0jGGC0\n8hqR0kjed9s/V+HFHjpnajmnEfD9AgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAIEO\nJdYZBrjvzJ4ytg8BqN4rggSSrKinsVdtQ1y9nEx/qpBP3W7PS40WkNdnKA+I2V/6\nzWTagYRZitwFvlinyxmetweYuSSSMlhlaJpGWz/fzJ6o+tDW5CVobSy2ijQen/SM\nQwNNrLA+WptOoM78cnMqm5EcPNAVr3JnxUQ7qUxU0pptTVc+R2Jqq26ASoMfoxDC\nlW022c90W26TOCwiKF0zlCi4pj3K9g1GR17bXoQYEsWw1TT34m5O9J8kQglBoqmP\nZT98QsABBlU/uI3L0YRvitCKE7hgN4v5OMmlyGOiktQteV93hU+gWyP0gwjSsaT+\nOH7h/C8smWC5jlD+a/0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Jyv\u00e4skyl\u00e4n yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Jyv\u00e4skyla"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Jyv\u00e4skyl\u00e4 universitet"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jyu.fi"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jyu.fi"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jyu.fi"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Jyv\u00e4skyl\u00e4n yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Jyv\u00e4skyla"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Jyv\u00e4skyl\u00e4 universitet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://vince.csueastbay.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "matt.collins@csueastbay.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matt Collins"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ashok.kumar@csueastbay.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ashok Kumar"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dave.bartholomew@csueastbay.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dave Bartholomew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://vince.csueastbay.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://vince.csueastbay.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vince.csueastbay.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAJfj/FNmMcHe0xPOV8us8po5lTWAMA0GCSqGSIb3DQEB\nBQUAMB8xHTAbBgNVBAMTFHZpbmNlLmNzdWVhc3RiYXkuZWR1MB4XDTEwMDQwNzE3\nNTYyMloXDTMwMDQwNzE3NTYyMlowHzEdMBsGA1UEAxMUdmluY2UuY3N1ZWFzdGJh\neS5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCCSz8k6C812clo\n8NsvSM2lfRg04yrqJhsvW76whawnxOHxUFvsG9fjklhiV+chL/tXDHhM2LhanAOD\nRis/uKNRJnwNl4peCXe8OICeE4vf3qpM0Oa1kSUBpTwLwYHBu0Wf/KlxCprZRoz3\nlDRwd+JxwWi3B7DMozYQd9N9zeQVcocpnuMn3cbyRQpRMgxrRRaxxbIWQDl0FuVy\n38aWmO+AvU4HQahhbC8MA5wYhT85HcG3dRL1bK5V6NM52zl7Z0wttbwc1sTeibWl\n9cbWnlZGz/ZfRRI0MorqFz7637kcIAE9qsm82Wo9x2oJymVW4lCyoNn2SLnPfmIr\nn8JXmCx3AgMBAAGjbzBtMEwGA1UdEQRFMEOCFHZpbmNlLmNzdWVhc3RiYXkuZWR1\nhitodHRwczovL3ZpbmNlLmNzdWVhc3RiYXkuZWR1L2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBQ9tsPsyrMMnxzKEcQ4QJp0zWkHkjANBgkqhkiG9w0BAQUFAAOCAQEA\nd+OGtadQWjvus5q66l/ZdnAkC4DK4fyk1nX0vgtJ8BGOc6hLvsbs9HXWVCc6C3BJ\nBG5imn0tmbPolaR6SB1Lx/t+aJlizQJTnqIQdz6hEY3A4J6LqPfzlZlkh3wPmH6B\nJ+J/bhvaC32w/E5XeTruv3tvtt5k9p8lAo50JknOesN5M8s20OFdtXVichtxwJnB\nQc8LJ6ETsbSEOO22H9s1zBFA7eFtgbVJQXnncmyuP6ysmp7I8JzschRC8hd11mIZ\nxJDXvlpdRC1sHZ2/0U7h70Nzz/k9NK4+O3hR89/NU81ub+7d/TCECa/gj2F8RnOo\nz6yMjX4JYAX5nFs0wOheuQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csueastbay.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://vince.csueastbay.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vince.csueastbay.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vince.csueastbay.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vince.csueastbay.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://vince.csueastbay.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vince.csueastbay.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csueastbay.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "California State University, East Bay"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAJfj/FNmMcHe0xPOV8us8po5lTWAMA0GCSqGSIb3DQEB\nBQUAMB8xHTAbBgNVBAMTFHZpbmNlLmNzdWVhc3RiYXkuZWR1MB4XDTEwMDQwNzE3\nNTYyMloXDTMwMDQwNzE3NTYyMlowHzEdMBsGA1UEAxMUdmluY2UuY3N1ZWFzdGJh\neS5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCCSz8k6C812clo\n8NsvSM2lfRg04yrqJhsvW76whawnxOHxUFvsG9fjklhiV+chL/tXDHhM2LhanAOD\nRis/uKNRJnwNl4peCXe8OICeE4vf3qpM0Oa1kSUBpTwLwYHBu0Wf/KlxCprZRoz3\nlDRwd+JxwWi3B7DMozYQd9N9zeQVcocpnuMn3cbyRQpRMgxrRRaxxbIWQDl0FuVy\n38aWmO+AvU4HQahhbC8MA5wYhT85HcG3dRL1bK5V6NM52zl7Z0wttbwc1sTeibWl\n9cbWnlZGz/ZfRRI0MorqFz7637kcIAE9qsm82Wo9x2oJymVW4lCyoNn2SLnPfmIr\nn8JXmCx3AgMBAAGjbzBtMEwGA1UdEQRFMEOCFHZpbmNlLmNzdWVhc3RiYXkuZWR1\nhitodHRwczovL3ZpbmNlLmNzdWVhc3RiYXkuZWR1L2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBQ9tsPsyrMMnxzKEcQ4QJp0zWkHkjANBgkqhkiG9w0BAQUFAAOCAQEA\nd+OGtadQWjvus5q66l/ZdnAkC4DK4fyk1nX0vgtJ8BGOc6hLvsbs9HXWVCc6C3BJ\nBG5imn0tmbPolaR6SB1Lx/t+aJlizQJTnqIQdz6hEY3A4J6LqPfzlZlkh3wPmH6B\nJ+J/bhvaC32w/E5XeTruv3tvtt5k9p8lAo50JknOesN5M8s20OFdtXVichtxwJnB\nQc8LJ6ETsbSEOO22H9s1zBFA7eFtgbVJQXnncmyuP6ysmp7I8JzschRC8hd11mIZ\nxJDXvlpdRC1sHZ2/0U7h70Nzz/k9NK4+O3hR89/NU81ub+7d/TCECa/gj2F8RnOo\nz6yMjX4JYAX5nFs0wOheuQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://vince.csueastbay.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California State University, East Bay"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www20.csueastbay.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California State University, East Bay"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sesam.uu.se/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 18 4714400"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT Servicedesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@uu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Uppsala universitet"
          }
        }
      ],
      "entity_id": "https://sesam.uu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Uppsala University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uu.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Uppsala universitet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sesam.uu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sesam.uu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sesam.uu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sesam.uu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://sesam.uu.se"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://sesam.uu.se"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Uppsala University Sesam adminstration of contactless smart card access"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Uppsala Universitets Sesam administration av passager\u00e4ttigheter"
                  }
                ],
                "logo": [
                  {
                    "text": "https://weblogin.uu.se/idp/UUlogin/img/logga-50.png",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "https://weblogin.uu.se/idp/UUlogin/img/logga-50.png",
                    "lang": "sv",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Uppsala University Sesam"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Uppsala universitets Sesam"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE9zCCAt+gAwIBAgIJANlgavHQEC/nMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGZ1bGljYS5pdHMudXUuc2UwHhcNMTUwMzI0MTExMTI1WhcNMjUwMzIxMTEx\nMTI1WjAbMRkwFwYDVQQDExBmdWxpY2EuaXRzLnV1LnNlMIICIjANBgkqhkiG9w0B\nAQEFAAOCAg8AMIICCgKCAgEAxeaD6qC5cpckyRkfjur6EGZ1NSs7h+EBZUkvIDPG\nNeWOXWr20Ii9Mw8XffmdwD/0pi/tTx4y2Z/eIQI3WZfmVRQ5fz3theDjUwi7Cuat\nAHN4VAYCy1+/dH6iAPz/I1h83v9H1brMcwNaYkEQ4gGzedxfS7WHFCnI4JhBem4O\nzQWdtkTkYQyVdd4pgfN4LMA3d/Rft6Oj3nEiTO7jmlOb17a376E7g8oPzZpA3ZFr\ngRHriD1Lx35ZeL7olxWzAgWN8cSZ8mCHihLmP2XAuf1j5usP72setI5U+iUscwwU\nj1tDQkmYCGpAoa3fzF54Gji7HyCf1kTSY64IzplLJychu95YAw+WJPmdJ+92SF8D\nT02bGMmPcLhCMHcp/Y3xiUrxDzXqI50mMcDC1UrrQeG56snWGUxEUev6c0t0q/xA\njEnV+G6/C8CbPMmiI1QfMyKGtNOYqVC5HEa1I/tTF6vS1nxPC9zq/hSfWN6w5RBd\nvErBV1S2LkHHVU8EWWTMUocxSbuyCHP4qdM4IahO9/NlnWectGLXNe9Si0svcKtA\nmLDe+kI5BIyEScvGfvYqsBjYoOFvwyDqdXERk8p8XZOiTm9GGaYXDQif4Hrow42g\ntrlPnfZlNMsYIaX1E82cryuoFSUD5Ho55oYKUG7bz4wprS073yfopGgvJzMXJchB\nr88CAwEAAaM+MDwwGwYDVR0RBBQwEoIQZnVsaWNhLml0cy51dS5zZTAdBgNVHQ4E\nFgQUqnejPQZZa1dzbtJzx0fOHLC5l54wDQYJKoZIhvcNAQEFBQADggIBACLSKVID\ncaXq37D93jv2NgR0iViQ3/oBebJ97fxhQab1LBoEjAPTjb+QoKXk42kT88SNETYC\nmqDgB0mu2YY4Ap5XGztTiIxwCzAkfMmUDUEpI/LzNgcd+PFBqFh1v+hDZG+5H3JN\nvwt3r74aghb3vFVr/WoP7ZcoqSVl9e1MuQCoC5lqbNWKuyU4soLEAscB75EuHNrr\n6pViXUhu1iclk7FmirR3Zv3gOrGPIFNMWOWGUowN28t1+2ZReg0U/ilG3ndzH0nQ\nIMu+0lpncYc36IJs+LNbjXzCcJjJQDVNlZ1ql/AaA5AEtkqUfGGemWn1A1Gy2ELr\nmZ3RYBwKoWcoqVwhbEOXEURSQzrE1IrpsgI3eSqNH87zx8/E/KvhFpkHZuLRsLmk\nYHDMxjqEnFJkRgkflVtJfJRrskAT5NkEyZ9SXmOqkvxwCG4uMEUIriICpeoWq6Z9\nK6OLyB+43HnPTVJ5kd9yswd6jXECnuPECQX2LedWu+7Bkly3HXLq+z91XI6pEYw6\nVJLQwplhF7wwyMumd5vvbMszPduvzmtaYki3DX+7n4gLle/9ECAmX3NEaOoB2Hqk\nnSUCO0wa/nKfvKLmz31H2OE3Om5UCgYAvB6y2u6fBIis7Z78X5/nR2JvRF8ReLDB\nOb0pZI5pkqdbQ/X+dGRz0ifwq1CQ44OjMnFi"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sesam.uu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sesam.uu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sesam.uu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.uibk.ac.at/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mueller"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:innet-admin@uibk.ac.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Walter"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uibk.ac.at/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://eduid.at/policy/mdrps-20140606"
              }
            ],
            "registration_instant": "2008-09-10T14:16:23Z",
            "registration_authority": "http://eduid.at",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAKPXC0xL8CC3lPXuHb8IXl0TkWbIMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC51aWJrLmFjLmF0MB4XDTA4MDkwOTA3NDkyN1oX\nDTI4MDkwOTA3NDkyN1owGTEXMBUGA1UEAxMOaWRwLnVpYmsuYWMuYXQwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCZeU5zvz1e6lRu0eimAxjcuBUXJuKY\nmCw2TeMaEmzJCi5U0l1TnNondXURanmxzPDpgFzHFDknW0dSENJFEv5QVMwq/waX\n6+otXcL8q9zPfuHu7I23ykPPBKWXKgG+kdfq8kvtuXGxS9Xy1VGMFjufM8myH2bP\nxPTo4Drx9bLLfb+M6S6exSy8JG5PTneo62VeO2GF9KQev/x/iKSnPWxPj6HdXOwj\nnDUpTiKGVTd0zS22jVVtrJybMTLmIiynhQRAWHlcDk06dXzmZyxg6pixvL6Wkqua\n0ySOIqvDgxIusXnyls2VcPLmNjW1fNYQ4vSduxbj4Z0C994DEMm0pduHAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC51aWJrLmFjLmF0hiVodHRwczovL2lkcC51aWJr\nLmFjLmF0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQeRcsefJI7EPSmjbGFWej1\nOPmcEjANBgkqhkiG9w0BAQUFAAOCAQEAaHZPqUT5AVi7MAzl591PrLZOdDzND3Jj\n6+CSk73rorB0tyE0ng5KDqS607zSDyaM/M2iTsCLH63+a7Ku5fVnx7Vnc7YvtCWF\nhCbCPQXs8bnNX3MzsxH8l3jEJWmgiTKMK9OMafS0zU/t15PhGBl5WwG0ZTokGJYF\nfW9oqrK1fafq6xwjjH34md+tEEGUADopOwtw669f64go3d1vQ1lemF3F5xp6Mwv/\nHpQvY9OrdfUdQ/lYbHMFnZTi4mm6912J3HNd1Cngjj2kvLhbH7Ki74G3sCNhYu2i\nsUbbplFi52tSH+D6jCVIQTMb3X8MG7lAf62Cm0BocKwL/0M6jMQWJQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uibk.ac.at"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uibk.ac.at:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uibk.ac.at:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.uibk.ac.at/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uibk.ac.at/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.uibk.ac.at/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uibk.ac.at/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uibk.ac.at:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uibk.ac.at:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uibk.ac.at"
              },
              {
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e4t Innsbruck"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Innsbruck"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAKPXC0xL8CC3lPXuHb8IXl0TkWbIMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC51aWJrLmFjLmF0MB4XDTA4MDkwOTA3NDkyN1oX\nDTI4MDkwOTA3NDkyN1owGTEXMBUGA1UEAxMOaWRwLnVpYmsuYWMuYXQwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCZeU5zvz1e6lRu0eimAxjcuBUXJuKY\nmCw2TeMaEmzJCi5U0l1TnNondXURanmxzPDpgFzHFDknW0dSENJFEv5QVMwq/waX\n6+otXcL8q9zPfuHu7I23ykPPBKWXKgG+kdfq8kvtuXGxS9Xy1VGMFjufM8myH2bP\nxPTo4Drx9bLLfb+M6S6exSy8JG5PTneo62VeO2GF9KQev/x/iKSnPWxPj6HdXOwj\nnDUpTiKGVTd0zS22jVVtrJybMTLmIiynhQRAWHlcDk06dXzmZyxg6pixvL6Wkqua\n0ySOIqvDgxIusXnyls2VcPLmNjW1fNYQ4vSduxbj4Z0C994DEMm0pduHAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC51aWJrLmFjLmF0hiVodHRwczovL2lkcC51aWJr\nLmFjLmF0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQeRcsefJI7EPSmjbGFWej1\nOPmcEjANBgkqhkiG9w0BAQUFAAOCAQEAaHZPqUT5AVi7MAzl591PrLZOdDzND3Jj\n6+CSk73rorB0tyE0ng5KDqS607zSDyaM/M2iTsCLH63+a7Ku5fVnx7Vnc7YvtCWF\nhCbCPQXs8bnNX3MzsxH8l3jEJWmgiTKMK9OMafS0zU/t15PhGBl5WwG0ZTokGJYF\nfW9oqrK1fafq6xwjjH34md+tEEGUADopOwtw669f64go3d1vQ1lemF3F5xp6Mwv/\nHpQvY9OrdfUdQ/lYbHMFnZTi4mm6912J3HNd1Cngjj2kvLhbH7Ki74G3sCNhYu2i\nsUbbplFi52tSH+D6jCVIQTMb3X8MG7lAf62Cm0BocKwL/0M6jMQWJQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e4t Innsbruck"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Innsbruck"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uibk.ac.at/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uibk.ac.at/index.html.en"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e4t Innsbruck"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Innsbruck"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.racc.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Matthews"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ray.matthews@racc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ray"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Matthews"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ray.matthews@racc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ray"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.racc.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-10-16T09:00:14Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUf8EAs09RQNjeRsweRhhhdo0gIh4wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGTEXMBUGA1UEAxMOaWRwLnJhY2MuYWMudWswHhcNMTQwODEyMTUzMzExWhcN\n\t\t\t\t\t\tMzQwODEyMTUzMzExWjAZMRcwFQYDVQQDEw5pZHAucmFjYy5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ2gWjs0nqPuueSEDuCJHThpcFI7Y0XA\n\t\t\t\t\t\tu1LbM4nRfXAEOjx9TKQ6H+70I4GZf2ljmbwINbPyVmtpcZgLuXzf7nxTIkIaqSK3\n\t\t\t\t\t\to4aDQj72VVQhVSJ2HAYvhkrtOznPDCWY6FyeBjqhuPghvEbgJtW/o+4VClUdkwMX\n\t\t\t\t\t\t/7PH7gQNqskjkiSdjVOLGD99F0syRFwtxYNoZxMt5gSltz7CmyOPqZDJWfIpJt/1\n\t\t\t\t\t\tSoj0dAaOrIxz79I9pdmkh/VAb8RyasFRSEE290BtUdAw7BLzlwvEre5k9Yafzg0g\n\t\t\t\t\t\tRXXYXidZ+Gkt9zz8TYb/p12J+ktMfbJCAtC0KUYkhpY4ZjYE0G/3RRMCAwEAAaNj\n\t\t\t\t\t\tMGEwQAYDVR0RBDkwN4IOaWRwLnJhY2MuYWMudWuGJWh0dHBzOi8vaWRwLnJhY2Mu\n\t\t\t\t\t\tYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFLcKRq3/gCr9G2rw89xbfpI3\n\t\t\t\t\t\tRHHTMA0GCSqGSIb3DQEBBQUAA4IBAQAdAW7tZBzJOS+ULQ54b20VL2Cmvj0bZuVO\n\t\t\t\t\t\tnEDW3vnAJdbi3Q6RNDl6ru0KHiGqQxz3SPN6UpKYbydZy/rgBu67tFS2nDPdfv83\n\t\t\t\t\t\tD0Cozu/u12G7X/9u0HR4QwW51XPUgPjZBOY54ZbnVL7inTYCVwjABA4zNZ9KHgsu\n\t\t\t\t\t\tiddLoyAZP4t9/hobm3qxeEAItYYz45aQei8f+ztAqhUq789Ble1ll1nw6SOwcujT\n\t\t\t\t\t\teSrWyEExSZKTu9diPVDG/ChJCFRBGLR3CScBgaoT6+d6WRYUX8bbeao89JjBm0Nf\n\t\t\t\t\t\tACWJFCPa6s7SURC2luCO0NnF6QxNTCBrkXI8Amw4U+Bvpv7v3Fhg"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "racc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.racc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.racc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.racc.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.racc.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.racc.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.racc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.racc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.racc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.racc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.racc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.racc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "racc.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://www.racc.ac.uk/files/images/racclogo.png",
                    "height": "71",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "154"
                  },
                  {
                    "text": "https://www.racc.ac.uk/files/images/smallracclogo.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Richmond Adult Community College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUf8EAs09RQNjeRsweRhhhdo0gIh4wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGTEXMBUGA1UEAxMOaWRwLnJhY2MuYWMudWswHhcNMTQwODEyMTUzMzExWhcN\n\t\t\t\t\t\tMzQwODEyMTUzMzExWjAZMRcwFQYDVQQDEw5pZHAucmFjYy5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ2gWjs0nqPuueSEDuCJHThpcFI7Y0XA\n\t\t\t\t\t\tu1LbM4nRfXAEOjx9TKQ6H+70I4GZf2ljmbwINbPyVmtpcZgLuXzf7nxTIkIaqSK3\n\t\t\t\t\t\to4aDQj72VVQhVSJ2HAYvhkrtOznPDCWY6FyeBjqhuPghvEbgJtW/o+4VClUdkwMX\n\t\t\t\t\t\t/7PH7gQNqskjkiSdjVOLGD99F0syRFwtxYNoZxMt5gSltz7CmyOPqZDJWfIpJt/1\n\t\t\t\t\t\tSoj0dAaOrIxz79I9pdmkh/VAb8RyasFRSEE290BtUdAw7BLzlwvEre5k9Yafzg0g\n\t\t\t\t\t\tRXXYXidZ+Gkt9zz8TYb/p12J+ktMfbJCAtC0KUYkhpY4ZjYE0G/3RRMCAwEAAaNj\n\t\t\t\t\t\tMGEwQAYDVR0RBDkwN4IOaWRwLnJhY2MuYWMudWuGJWh0dHBzOi8vaWRwLnJhY2Mu\n\t\t\t\t\t\tYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFLcKRq3/gCr9G2rw89xbfpI3\n\t\t\t\t\t\tRHHTMA0GCSqGSIb3DQEBBQUAA4IBAQAdAW7tZBzJOS+ULQ54b20VL2Cmvj0bZuVO\n\t\t\t\t\t\tnEDW3vnAJdbi3Q6RNDl6ru0KHiGqQxz3SPN6UpKYbydZy/rgBu67tFS2nDPdfv83\n\t\t\t\t\t\tD0Cozu/u12G7X/9u0HR4QwW51XPUgPjZBOY54ZbnVL7inTYCVwjABA4zNZ9KHgsu\n\t\t\t\t\t\tiddLoyAZP4t9/hobm3qxeEAItYYz45aQei8f+ztAqhUq789Ble1ll1nw6SOwcujT\n\t\t\t\t\t\teSrWyEExSZKTu9diPVDG/ChJCFRBGLR3CScBgaoT6+d6WRYUX8bbeao89JjBm0Nf\n\t\t\t\t\t\tACWJFCPa6s7SURC2luCO0NnF6QxNTCBrkXI8Amw4U+Bvpv7v3Fhg"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Richmond Adult Community College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.racc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Richmond Adult Community College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.mmu.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ss@mmu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Servers and Storage Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ss@mmu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Servers and Storage Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.mmu.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-07-09T15:44:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF7zCCBNegAwIBAgIKEQ8ZqQAFAAGwijANBgkqhkiG9w0BAQUFADBsMRIwEAYK\n\t\t\t\t\t\tCZImiZPyLGQBGRYCdWsxEjAQBgoJkiaJk/IsZAEZFgJhYzETMBEGCgmSJomT8ixk\n\t\t\t\t\t\tARkWA21tdTESMBAGCgmSJomT8ixkARkWAmFkMRkwFwYDVQQDExBhZC1KREVBRE1H\n\t\t\t\t\t\tTVQxLUNBMB4XDTE0MDYxMDA5NDY0MloXDTIzMDYwODA5NDY0MlowgY8xCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRAwDgYDVQQIEwdFbmdsYW5kMRswGQYDVQQHExJHcmVhdGVyIE1hbmNo\n\t\t\t\t\t\tZXN0ZXIxKzApBgNVBAoTIk1hbmNoZXN0ZXIgTWV0cm9wb2xpdGFuIFVuaXZlcnNp\n\t\t\t\t\t\tdHkxDDAKBgNVBAsTA0lUUzEWMBQGA1UEAxMNaWRwLm1tdS5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK2aUJf4/gCMBJ9blo9YjL9nNvw1H61B\n\t\t\t\t\t\tPj0B4g3CDLXuAUocLLokpDJgvAqoPou7BXA3q/zeaF1m6mSue/bgg7obCUY/Pjyk\n\t\t\t\t\t\tPnsSp8YbAoMv5/AeQLb+RGrsZ6Vvnv1/mUglpt6I7/8KuDlq89+x/lXshx09elrI\n\t\t\t\t\t\tuiUf4vbWIbJjklaW8kLBsGkZ3k4I+sfu/oGRDAo5id5vI8/sWvxwXizJMb5+sC1z\n\t\t\t\t\t\tAcofB9ux8vlIH8osZK4Jon976j+F+89+lP5R6x5YcXc0XI54X3LkpmKTxxhF0Vg7\n\t\t\t\t\t\twymvSihurHOwtAkSsWFZ/rJ/Gn8Zo7HTRopVPTdOiLS6ZNo92aYmiQUCAwEAAaOC\n\t\t\t\t\t\tAm0wggJpMB0GA1UdDgQWBBSwEMs3Qept/2PCAEj9gGidV4+aYTAfBgNVHSMEGDAW\n\t\t\t\t\t\tgBTuEDNk61YXy8+cyWM7HuKODmd0zTCB2wYDVR0fBIHTMIHQMIHNoIHKoIHHhoHE\n\t\t\t\t\t\tbGRhcDovLy9DTj1hZC1KREVBRE1HTVQxLUNBKDUpLENOPUpERUFETUdNVDEsQ049\n\t\t\t\t\t\tQ0RQLENOPVB1YmxpYyUyMEtleSUyMFNlcnZpY2VzLENOPVNlcnZpY2VzLENOPUNv\n\t\t\t\t\t\tbmZpZ3VyYXRpb24sREM9YWQsREM9bW11LERDPWFjLERDPXVrP2NlcnRpZmljYXRl\n\t\t\t\t\t\tUmV2b2NhdGlvbkxpc3Q/YmFzZT9vYmplY3RDbGFzcz1jUkxEaXN0cmlidXRpb25Q\n\t\t\t\t\t\tb2ludDCByQYIKwYBBQUHAQEEgbwwgbkwgbYGCCsGAQUFBzAChoGpbGRhcDovLy9D\n\t\t\t\t\t\tTj1hZC1KREVBRE1HTVQxLUNBLENOPUFJQSxDTj1QdWJsaWMlMjBLZXklMjBTZXJ2\n\t\t\t\t\t\taWNlcyxDTj1TZXJ2aWNlcyxDTj1Db25maWd1cmF0aW9uLERDPWFkLERDPW1tdSxE\n\t\t\t\t\t\tQz1hYyxEQz11az9jQUNlcnRpZmljYXRlP2Jhc2U/b2JqZWN0Q2xhc3M9Y2VydGlm\n\t\t\t\t\t\taWNhdGlvbkF1dGhvcml0eTAOBgNVHQ8BAf8EBAMCBaAwOwYJKwYBBAGCNxUHBC4w\n\t\t\t\t\t\tLAYkKwYBBAGCNxUIhbWgdYPgngWZjTPfs06EztIPgXexhHaD/MAYAgFkAgEGMBMG\n\t\t\t\t\t\tA1UdJQQMMAoGCCsGAQUFBwMBMBsGCSsGAQQBgjcVCgQOMAwwCgYIKwYBBQUHAwEw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAJWqoyrhg8HA0WFS/egaof7pmRJaGddx7hOij8As\n\t\t\t\t\t\tI/aeLxFJoOYz5ahVhFEGUfJYGLQMvTJ0jAU9oMVnOzkw0qeAgjtKUOTq0msOrSWw\n\t\t\t\t\t\tYgEYtXSyTnr84swBtF5aPsQmn/DTc4PceCKY0AOljsmjxnf51z70CvAQqCbYdAJ+\n\t\t\t\t\t\tO+pFeLNMCKZSdC4kkLILN4wvfd2FlphLJG2C67yLoo8c7/cDCJxPdLGkJMkCzjRO\n\t\t\t\t\t\tZRaaAx9lEqDFa/xy/J6cRxhqq+Dw3TKBvOZyetNHg38Lwy2APwzTVlgdJrbR7+Wg\n\t\t\t\t\t\tooB93xRbkV/WtLUE+WHNVFjsTcVoQZ/XY4FMbXl5gqji35I="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mmu.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.mmu.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.mmu.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.mmu.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.mmu.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.mmu.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.mmu.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.mmu.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.mmu.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mmu.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF7zCCBNegAwIBAgIKEQ8ZqQAFAAGwijANBgkqhkiG9w0BAQUFADBsMRIwEAYK\n\t\t\t\t\t\tCZImiZPyLGQBGRYCdWsxEjAQBgoJkiaJk/IsZAEZFgJhYzETMBEGCgmSJomT8ixk\n\t\t\t\t\t\tARkWA21tdTESMBAGCgmSJomT8ixkARkWAmFkMRkwFwYDVQQDExBhZC1KREVBRE1H\n\t\t\t\t\t\tTVQxLUNBMB4XDTE0MDYxMDA5NDY0MloXDTIzMDYwODA5NDY0MlowgY8xCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRAwDgYDVQQIEwdFbmdsYW5kMRswGQYDVQQHExJHcmVhdGVyIE1hbmNo\n\t\t\t\t\t\tZXN0ZXIxKzApBgNVBAoTIk1hbmNoZXN0ZXIgTWV0cm9wb2xpdGFuIFVuaXZlcnNp\n\t\t\t\t\t\tdHkxDDAKBgNVBAsTA0lUUzEWMBQGA1UEAxMNaWRwLm1tdS5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK2aUJf4/gCMBJ9blo9YjL9nNvw1H61B\n\t\t\t\t\t\tPj0B4g3CDLXuAUocLLokpDJgvAqoPou7BXA3q/zeaF1m6mSue/bgg7obCUY/Pjyk\n\t\t\t\t\t\tPnsSp8YbAoMv5/AeQLb+RGrsZ6Vvnv1/mUglpt6I7/8KuDlq89+x/lXshx09elrI\n\t\t\t\t\t\tuiUf4vbWIbJjklaW8kLBsGkZ3k4I+sfu/oGRDAo5id5vI8/sWvxwXizJMb5+sC1z\n\t\t\t\t\t\tAcofB9ux8vlIH8osZK4Jon976j+F+89+lP5R6x5YcXc0XI54X3LkpmKTxxhF0Vg7\n\t\t\t\t\t\twymvSihurHOwtAkSsWFZ/rJ/Gn8Zo7HTRopVPTdOiLS6ZNo92aYmiQUCAwEAAaOC\n\t\t\t\t\t\tAm0wggJpMB0GA1UdDgQWBBSwEMs3Qept/2PCAEj9gGidV4+aYTAfBgNVHSMEGDAW\n\t\t\t\t\t\tgBTuEDNk61YXy8+cyWM7HuKODmd0zTCB2wYDVR0fBIHTMIHQMIHNoIHKoIHHhoHE\n\t\t\t\t\t\tbGRhcDovLy9DTj1hZC1KREVBRE1HTVQxLUNBKDUpLENOPUpERUFETUdNVDEsQ049\n\t\t\t\t\t\tQ0RQLENOPVB1YmxpYyUyMEtleSUyMFNlcnZpY2VzLENOPVNlcnZpY2VzLENOPUNv\n\t\t\t\t\t\tbmZpZ3VyYXRpb24sREM9YWQsREM9bW11LERDPWFjLERDPXVrP2NlcnRpZmljYXRl\n\t\t\t\t\t\tUmV2b2NhdGlvbkxpc3Q/YmFzZT9vYmplY3RDbGFzcz1jUkxEaXN0cmlidXRpb25Q\n\t\t\t\t\t\tb2ludDCByQYIKwYBBQUHAQEEgbwwgbkwgbYGCCsGAQUFBzAChoGpbGRhcDovLy9D\n\t\t\t\t\t\tTj1hZC1KREVBRE1HTVQxLUNBLENOPUFJQSxDTj1QdWJsaWMlMjBLZXklMjBTZXJ2\n\t\t\t\t\t\taWNlcyxDTj1TZXJ2aWNlcyxDTj1Db25maWd1cmF0aW9uLERDPWFkLERDPW1tdSxE\n\t\t\t\t\t\tQz1hYyxEQz11az9jQUNlcnRpZmljYXRlP2Jhc2U/b2JqZWN0Q2xhc3M9Y2VydGlm\n\t\t\t\t\t\taWNhdGlvbkF1dGhvcml0eTAOBgNVHQ8BAf8EBAMCBaAwOwYJKwYBBAGCNxUHBC4w\n\t\t\t\t\t\tLAYkKwYBBAGCNxUIhbWgdYPgngWZjTPfs06EztIPgXexhHaD/MAYAgFkAgEGMBMG\n\t\t\t\t\t\tA1UdJQQMMAoGCCsGAQUFBwMBMBsGCSsGAQQBgjcVCgQOMAwwCgYIKwYBBQUHAwEw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAJWqoyrhg8HA0WFS/egaof7pmRJaGddx7hOij8As\n\t\t\t\t\t\tI/aeLxFJoOYz5ahVhFEGUfJYGLQMvTJ0jAU9oMVnOzkw0qeAgjtKUOTq0msOrSWw\n\t\t\t\t\t\tYgEYtXSyTnr84swBtF5aPsQmn/DTc4PceCKY0AOljsmjxnf51z70CvAQqCbYdAJ+\n\t\t\t\t\t\tO+pFeLNMCKZSdC4kkLILN4wvfd2FlphLJG2C67yLoo8c7/cDCJxPdLGkJMkCzjRO\n\t\t\t\t\t\tZRaaAx9lEqDFa/xy/J6cRxhqq+Dw3TKBvOZyetNHg38Lwy2APwzTVlgdJrbR7+Wg\n\t\t\t\t\t\tooB93xRbkV/WtLUE+WHNVFjsTcVoQZ/XY4FMbXl5gqji35I="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Manchester Metropolitan University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://icts.mmu.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Manchester Metropolitan University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://api.bridgemanimages.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Anschuetz"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kerstin.anschuetz@bridgemanimages.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kerstin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chambers"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sean.chambers@bridgemanimages.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sean"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://api.bridgemanimages.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-08-21T12:54:59Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bridgeman Education"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bridgemaneducation.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Bridgeman Art Library Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://api.bridgemanimages.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://api.bridgemanimages.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://api.bridgemanimages.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://api.bridgemanimages.com/Shibboleth.sso/UKfederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://api.bridgemanimages.com/Shibboleth.sso/UKfederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDITCCAgmgAwIBAgIJAJ3czdb0R2hQMA0GCSqGSIb3DQEBBQUAMCkxJzAlBgNV\n\t\t\t\t\t\tBAMTHmFwaW5zdGFuY2UuYnJpZGdlbWFuaW1hZ2VzLmNvbTAeFw0xNTA4MTgxMzUw\n\t\t\t\t\t\tMDlaFw0yNTA4MTUxMzUwMDlaMCkxJzAlBgNVBAMTHmFwaW5zdGFuY2UuYnJpZGdl\n\t\t\t\t\t\tbWFuaW1hZ2VzLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ9b\n\t\t\t\t\t\tIY7MjLpmntgBUMyLd+uXb6XPbhCx5db2LBGlzhmLRr5EowlHmK/94lb15rc8iWd1\n\t\t\t\t\t\tg4GqY9eM+eV3iENVSsd2VRVzGgb4vQpS4nFYy0RxarhWtVA9WlgNooMXk5bUB645\n\t\t\t\t\t\tTQbcSAaCkGyhLlqO8M6EUCwWqjflH5incXgId4fpE9h9FGmLBGROmGAeZMF2cJf3\n\t\t\t\t\t\tsBlVM727CRepJIyRB3oY2TZ4DbH+KVdQrA8DjHzm3qhB9WaMk51PNXJKetTeaT+t\n\t\t\t\t\t\tc26TDqy7Eq8dZqmOjgejlMPSvN0PgIKxFIte53anUqrESN/wB8v37K7XZlrRIufS\n\t\t\t\t\t\t5nBd9FqTvJpiDE1FtWkCAwEAAaNMMEowKQYDVR0RBCIwIIIeYXBpbnN0YW5jZS5i\n\t\t\t\t\t\tcmlkZ2VtYW5pbWFnZXMuY29tMB0GA1UdDgQWBBRKecH57s3sItz2dH60A33pLN3I\n\t\t\t\t\t\tcTANBgkqhkiG9w0BAQUFAAOCAQEAcobfnWV/lrSG3feeD1XA2xtZfaXkaVwDrv6W\n\t\t\t\t\t\txlFJ7c351l2H13pAPiwHwinMJAf43R5dQBylq5HO4a70EEys4Dfa0s6dqiLZ+NaD\n\t\t\t\t\t\tKHld2UQ6F7BATH8ydZx8JqDu0MSme8zJXytePRlZMwHpNW7sKP+zoxQ5b0ZwcrOm\n\t\t\t\t\t\ttnSUiRRpBHEll0HprabEauXfgVtOE21ukKy9FklWY34Azhk/xiMw7i4GdQqgeY8o\n\t\t\t\t\t\tf4a3t5SoUQdhtmJiegvPVyE8t2CvrOP0SCXIZ5XYFNu4cHjUzZVg2zmc5d2zTGRW\n\t\t\t\t\t\tzN6H7og0AK1oMx+zi6VsV3liq768srmyafMOAuYPqXR48VXcHQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://api.bridgemanimages.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://api.bridgemanimages.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://api.bridgemanimages.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://api.bridgemanimages.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://api.bridgemanimages.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://api.bridgemanimages.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ifg-srv-cafe.ifg.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Roberval Lustosa de Aguiar Filho"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "roberval.filho@ifg.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ifg-srv-cafe.ifg.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvDCCAqQCAQAwDQYJKoZIhvcNAQEFBQAwgaMxIzAhBgNVBAoTGkluc3RpdHV0\nbyBGZWRlcmFsIGRlIEdvaWFzMQwwCgYDVQQLEwNEVEkxHTAbBgkqhkiG9w0BCQEW\nDmR0aUBpZmcuZWR1LmJyMRAwDgYDVQQHEwdHb2lhbmlhMQ4wDAYDVQQIEwVHb2lh\nczELMAkGA1UEBhMCQlIxIDAeBgNVBAMTF2lmZy1zcnYtY2FmZS5pZmcuZWR1LmJy\nMB4XDTE1MDUyMTEzMzAzM1oXDTE4MDUyMDEzMzAzM1owgaMxIzAhBgNVBAoTGklu\nc3RpdHV0byBGZWRlcmFsIGRlIEdvaWFzMQwwCgYDVQQLEwNEVEkxHTAbBgkqhkiG\n9w0BCQEWDmR0aUBpZmcuZWR1LmJyMRAwDgYDVQQHEwdHb2lhbmlhMQ4wDAYDVQQI\nEwVHb2lhczELMAkGA1UEBhMCQlIxIDAeBgNVBAMTF2lmZy1zcnYtY2FmZS5pZmcu\nZWR1LmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAyCymZfUeAa/S\nSEbbSYRCgcdQoJPPlkgiAc/lXZeTIYhO3qDppq4fL8dXQgyg35iGR8TXUd4LdGkv\nVCmcpx5GS8tiJIYLZCLBcGBieA1fIVyyuwl3sV44/Ye/TP/y6zZEKw9UQTawgw1K\nFezVTW+qwBtHCQDqkMxDbX5eW97Gft7oPo6TgT9E3hCBaA8fpnEXYHoSOYQ1STeb\njvdAU649hKF6bOBhLVMfAJ7qBwbjm4J5Zl1c1RX1uKWurhepDG94u7zS05orNPVL\nh3xljF16iVsPRj23emEmTS7cwjk4tiZg46SByMC1Iol1yHHlBJoNjgDejMjpeaKz\np2Q7zOroZwIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQAB0lp4DGQswNz/ooH8V2W+\n4RYUc3ATZHGxAOPuPRWdSEnOIINDMAKJQgwxlrjm/yotHd61ooPMAosHh/JK5OJc\n2Kmasd3PPDwzmayM/+1ZZbrJsPiBu1KrpXaPfeij9jXZMrNjWXF3VRORXYwxHS4W\nYTHjkyT7rPewJERdNu18ClDr3Srbeo2wOpw8xoct3hWA80CuXdAqEaEi5XzR9AiG\nqZHDzBemsNLwR7IBmZngXvnrysVf9nUIXTOct1KgJhqpBAQ+ySB0sGpGUjMow7S1\nnivla3ZHx3NkSg0K+ctKO7/L6VXK5w42gzTzOt/+Q1w05HVTY48caTgiXY3Dg6mP"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ifg-srv-cafe.ifg.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://ifg-srv-cafe.ifg.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ifg-srv-cafe.ifg.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ifg-srv-cafe.ifg.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://ifg-srv-cafe.ifg.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ifg-srv-cafe.ifg.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ifg-srv-cafe.ifg.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://ifg-srv-cafe.ifg.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifg.edu.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifg.edu.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFG - Instituto Federal de Goias"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFG - Instituto Federal de Goias"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFG - Instituto Federal de Goias"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFG - Instituto Federal de Goias"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvDCCAqQCAQAwDQYJKoZIhvcNAQEFBQAwgaMxIzAhBgNVBAoTGkluc3RpdHV0\nbyBGZWRlcmFsIGRlIEdvaWFzMQwwCgYDVQQLEwNEVEkxHTAbBgkqhkiG9w0BCQEW\nDmR0aUBpZmcuZWR1LmJyMRAwDgYDVQQHEwdHb2lhbmlhMQ4wDAYDVQQIEwVHb2lh\nczELMAkGA1UEBhMCQlIxIDAeBgNVBAMTF2lmZy1zcnYtY2FmZS5pZmcuZWR1LmJy\nMB4XDTE1MDUyMTEzMzAzM1oXDTE4MDUyMDEzMzAzM1owgaMxIzAhBgNVBAoTGklu\nc3RpdHV0byBGZWRlcmFsIGRlIEdvaWFzMQwwCgYDVQQLEwNEVEkxHTAbBgkqhkiG\n9w0BCQEWDmR0aUBpZmcuZWR1LmJyMRAwDgYDVQQHEwdHb2lhbmlhMQ4wDAYDVQQI\nEwVHb2lhczELMAkGA1UEBhMCQlIxIDAeBgNVBAMTF2lmZy1zcnYtY2FmZS5pZmcu\nZWR1LmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAyCymZfUeAa/S\nSEbbSYRCgcdQoJPPlkgiAc/lXZeTIYhO3qDppq4fL8dXQgyg35iGR8TXUd4LdGkv\nVCmcpx5GS8tiJIYLZCLBcGBieA1fIVyyuwl3sV44/Ye/TP/y6zZEKw9UQTawgw1K\nFezVTW+qwBtHCQDqkMxDbX5eW97Gft7oPo6TgT9E3hCBaA8fpnEXYHoSOYQ1STeb\njvdAU649hKF6bOBhLVMfAJ7qBwbjm4J5Zl1c1RX1uKWurhepDG94u7zS05orNPVL\nh3xljF16iVsPRj23emEmTS7cwjk4tiZg46SByMC1Iol1yHHlBJoNjgDejMjpeaKz\np2Q7zOroZwIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQAB0lp4DGQswNz/ooH8V2W+\n4RYUc3ATZHGxAOPuPRWdSEnOIINDMAKJQgwxlrjm/yotHd61ooPMAosHh/JK5OJc\n2Kmasd3PPDwzmayM/+1ZZbrJsPiBu1KrpXaPfeij9jXZMrNjWXF3VRORXYwxHS4W\nYTHjkyT7rPewJERdNu18ClDr3Srbeo2wOpw8xoct3hWA80CuXdAqEaEi5XzR9AiG\nqZHDzBemsNLwR7IBmZngXvnrysVf9nUIXTOct1KgJhqpBAQ+ySB0sGpGUjMow7S1\nnivla3ZHx3NkSg0K+ctKO7/L6VXK5w42gzTzOt/+Q1w05HVTY48caTgiXY3Dg6mP"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFG - Instituto Federal de Goias"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFG - Instituto Federal de Goias"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifg.edu.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifg.edu.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFG - Instituto Federal de Goias"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFG - Instituto Federal de Goias"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.rediris.es/sir/usjidp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sir@rediris.es"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SIR helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.rediris.es/sir/usjidp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.rediris.es/sir/edugain/SIR_MRPS.pdf"
              }
            ],
            "registration_instant": "2012-10-09T13:08:24Z",
            "registration_authority": "http://www.rediris.es/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "response_location": "http://sir.rediris.es/usj/saml2/idp/SingleLogoutService.php",
              "location": "http://sir.rediris.es/usj/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "http://sir.rediris.es/usj/shib13/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "http://sir.rediris.es/usj/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Identity Provider of Universidad San Jorge"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "El proveedor de identidad de la Universidad San Jorge"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "USJ - Universidad San Jorge"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "USJ - Universidad San Jorge"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "usj.es"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEeTCCA2GgAwIBAgIQCP9faAGj247/+QVzgpX08zANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDcwMTAwMDAwMFoXDTE2MDYzMDIzNTk1OVowRDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMR8wHQYDVQQDExZzYW1saWRwLnNp\nci5yZWRpcmlzLmVzMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA5tO6\ntYAdozpFMDwS7QH1qm7eECkY05lG1sp14vcVOdyN0mAf8oai+M8dCQ5iyMxD/RaG\noSmhXfHUvJ+0x8Cp/NHYbKr0cXskANcYTI0JFMFypn9Uac62CGxUYZRhHQ/2LxiE\nvzNgKrm2JiXCvOQbWrbg0sZDEsONv2G1Ln3fvOLiSiO1AjWLvOeYFPNgkNy5dxxt\n7ms7mZ0bFth6Cj38BBL0I1RebVnMgAKZWSgICUXDx35nkB+iLtidIykBgz92ZQ5h\nUrVNndP5+lraoMRuIewESSFt+LBYVeUZFTBGlupiUZ/bi7rhtIuhMM8ahaKIstbu\nIgfQBHPqRkkiiKOJawIDAQABo4IBczCCAW8wHwYDVR0jBBgwFoAUDL2TaAzz3quj\nSWsrN1dH6pDjue0wHQYDVR0OBBYEFARoBLDWcsveEZQhaMVIR9mmJkUkMA4GA1Ud\nDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggr\nBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNV\nHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNT\nTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQu\ndGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRw\nOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAhBgNVHREEGjAYghZzYW1saWRwLnNpci5y\nZWRpcmlzLmVzMA0GCSqGSIb3DQEBBQUAA4IBAQB0gmr232YgpUC4HkwAHXaH91Zx\n8ZrwiEc8c4jGLh5VsaO0OqMfUEIXMuqZ+P9JNWVwlc6VLtmsypqTuqb9a06DS88q\n2o5sAUpbXZwhArhQs1bQnu5HJ6S84Ajn+NfMOyaO7NF8Colq/9lf3DihkT0jlD7i\nPHPMw2zauvtR/WPwdPszgfIOV/vkJ0rq9AjOXxSX7V2jpkxISGW/m93iahwXEoVF\nc8VXQhNjEfcm6uawmISjsyp6ta/U3e/8GJka2csDrF/bfipMBDSdWcLMscpYO8cb\nDC0L6vehZJ+lPz3wPH6YJmlstICZUdJIgDV3TUhmji6NNKa4p6by34QdYcDH"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universidad San Jorge"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universidad San Jorge"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rediris.es/index.php.en"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rediris.es/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "USJ"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "USJ"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.aub.edu.lb/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "monassi@aub.edu.lb"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mona Assi"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Shibboleth@aub.edu.lb"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Support Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Shibboleth@aub.edu.lb"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Techincal Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "maherk@aub.edu.lb"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Maher Kassab"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.aub.edu.lb/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.aub.edu.lb/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.aub.edu.lb/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.aub.edu.lb/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.aub.edu.lb/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.aub.edu.lb/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.aub.edu.lb/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.aub.edu.lb:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.aub.edu.lb:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aub.edu.lb"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "American University of Beirut"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIULYKLvS4tqdodA2Tpx8fCYWx2u9AwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOaWRwLmF1Yi5lZHUubGIwHhcNMTQwNzIyMDkxMTM4WhcN\nMzQwNzIyMDkxMTM4WjAZMRcwFQYDVQQDEw5pZHAuYXViLmVkdS5sYjCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKZmVQ3esrju64+cm06CzqI3ibvg3E3I\nFnox2okzwxJMAl4SJTunO4NVX1quiXbURRk7aY8XOY7aZYJ6ruatsh0Ng/q/PyoI\nl3EWI3MmE7h55DsIi+NRd/oQZG57ENr2UKkZQca5esRtfWx/mqkTEcf48hOMmmwd\nIpnGnxpTu9bsWCf+RiRTySZnWcXpllvHSrkAET7Kl3Aeexs8WYAlJ8WYg8blx5QS\nQHIM2wIbRbhVWOaTO905J6lLF3LhrWdZ7637RMDivVTNwdA8nuk0QJm0dZN5Z+hE\n2MbUnOvB5SYFLLo3mrU4a7b0Bl1J/pxMJZrlaoVn8OhJrDqkf77jxFECAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOaWRwLmF1Yi5lZHUubGKGJWh0dHBzOi8vaWRwLmF1Yi5l\nZHUubGIvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFOdoJG41Ncg47yzvfG0DH3HZ\noaT+MA0GCSqGSIb3DQEBBQUAA4IBAQBs+g6B7jh5AFf6bXX+TzFJalywRYNfTBfU\nYDF64/TFX8OziVUb5d+up9B+EFDudMASU5BqTr8pGfoQackmI0TEvl9n/BZBEhrr\nlel95gK/Y614xMJkoFFZle3u3Kp415r56M7PDRkDJ+a4QTn5ILEjLVoZvwrboHWb\nJfTFVPALyF2oZex7bbHZ2i6CyE0qLetqWmZGgLEl2SscK2Ue1w/pqW6yoo2YMsOC\nX4Ic+GreOjVGJN1TRDjBY6sei0ef+aAulVL1K1aWSjFWjJUazdq4TlZsOF0Z/WGG\nZderlj8oMgziT8XJHB+2YcRnJm63bJ4PpmitJEcGpgcszR+U1OoQ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "American University of Beirut"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aub.edu.lb/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "American University of Beirut"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ncnidp2.ncn.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cook"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:matthew.cook@ncn.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matthew"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cook"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:matthew.cook@ncn.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matthew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ncnidp2.ncn.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-11-04T10:36:29Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVALRppuv8S4ANdlBHMhXkfMZDERBpMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB0xGzAZBgNVBAMTEm5jYS1pZHAxLm5jbi5hYy51azAeFw0xMzEwMDgxMzIz\n\t\t\t\t\t\tMDNaFw0zMzEwMDgxMzIzMDNaMB0xGzAZBgNVBAMTEm5jYS1pZHAxLm5jbi5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKCGTdXZNjFkxlbPHQZ+\n\t\t\t\t\t\tAJcFLw+6FdBn+L2ryybG5i4X9Ft92AEKXbaIH/Q0nOwP3+Gq0yyFPgloiAk/r3KJ\n\t\t\t\t\t\tuhIziuJ1di0tRxJcCJWH3E+Mv4LrDsV30xILVq3pNiQW96Y7jwPqquHJS6116cjh\n\t\t\t\t\t\txBIwMnMizXkAz6ZbUyayFO5KfQ5ShcJKCA/fUbNZ2jIT0imHwIWEzsF/uCrxMpVL\n\t\t\t\t\t\tGGu+hnWZOz8Jd0zbI3+ZowJB9HB8mX7GpP6WsImuSay0JTGxcb80v6GIV/8iuMwk\n\t\t\t\t\t\tBAYWskCARpIImOABiYzUN4t5be3frkdrmOVuvKDmFhKU362V6IaVpaYUifNK+7jk\n\t\t\t\t\t\tIQMCAwEAAaNrMGkwSAYDVR0RBEEwP4ISbmNhLWlkcDEubmNuLmFjLnVrhilodHRw\n\t\t\t\t\t\tczovL25jYS1pZHAxLm5jbi5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n\t\t\t\t\t\tnZnTzYWrQVq2AEx7CHvOlze4oH4wDQYJKoZIhvcNAQEFBQADggEBAAPRO5cV0WBn\n\t\t\t\t\t\tpJrW/poSP+Y0adkGgK3vIihqdp4blGWWwitUryfhoWJd6s5fDwAlCUzmUjrGuxlh\n\t\t\t\t\t\tQIsgrUyYbBKAmrDoAwzlTiz6hs3Q3eN8ljN1jviJmStQoV4HugtrmKLP8A5bI6eI\n\t\t\t\t\t\tVR/fx4TFwbsIgmZR+mM73zf0z2oOPp6WiIOZV0JIiEeT2Z5vIMTUzyGdIhGmr6FF\n\t\t\t\t\t\t4cP+49glAVtsuTup9MRChUB6znydUVf9fVmi74FCsLaxEqMys8UMzXXMiCG1g6XG\n\t\t\t\t\t\tpra6VEmKTwxJPyFY5D9627VwJmrePAUZsozY3mIE5oibbq3U92VpvsTb7EQFlKMj\n\t\t\t\t\t\tLh83rrpEo40="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ncn.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://nca-idp1.ncn.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nca-idp1.ncn.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://nca-idp1.ncn.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nca-idp1.ncn.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://nca-idp1.ncn.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nca-idp1.ncn.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://nca-idp1.ncn.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nca-idp1.ncn.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ncn.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVALRppuv8S4ANdlBHMhXkfMZDERBpMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB0xGzAZBgNVBAMTEm5jYS1pZHAxLm5jbi5hYy51azAeFw0xMzEwMDgxMzIz\n\t\t\t\t\t\tMDNaFw0zMzEwMDgxMzIzMDNaMB0xGzAZBgNVBAMTEm5jYS1pZHAxLm5jbi5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKCGTdXZNjFkxlbPHQZ+\n\t\t\t\t\t\tAJcFLw+6FdBn+L2ryybG5i4X9Ft92AEKXbaIH/Q0nOwP3+Gq0yyFPgloiAk/r3KJ\n\t\t\t\t\t\tuhIziuJ1di0tRxJcCJWH3E+Mv4LrDsV30xILVq3pNiQW96Y7jwPqquHJS6116cjh\n\t\t\t\t\t\txBIwMnMizXkAz6ZbUyayFO5KfQ5ShcJKCA/fUbNZ2jIT0imHwIWEzsF/uCrxMpVL\n\t\t\t\t\t\tGGu+hnWZOz8Jd0zbI3+ZowJB9HB8mX7GpP6WsImuSay0JTGxcb80v6GIV/8iuMwk\n\t\t\t\t\t\tBAYWskCARpIImOABiYzUN4t5be3frkdrmOVuvKDmFhKU362V6IaVpaYUifNK+7jk\n\t\t\t\t\t\tIQMCAwEAAaNrMGkwSAYDVR0RBEEwP4ISbmNhLWlkcDEubmNuLmFjLnVrhilodHRw\n\t\t\t\t\t\tczovL25jYS1pZHAxLm5jbi5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n\t\t\t\t\t\tnZnTzYWrQVq2AEx7CHvOlze4oH4wDQYJKoZIhvcNAQEFBQADggEBAAPRO5cV0WBn\n\t\t\t\t\t\tpJrW/poSP+Y0adkGgK3vIihqdp4blGWWwitUryfhoWJd6s5fDwAlCUzmUjrGuxlh\n\t\t\t\t\t\tQIsgrUyYbBKAmrDoAwzlTiz6hs3Q3eN8ljN1jviJmStQoV4HugtrmKLP8A5bI6eI\n\t\t\t\t\t\tVR/fx4TFwbsIgmZR+mM73zf0z2oOPp6WiIOZV0JIiEeT2Z5vIMTUzyGdIhGmr6FF\n\t\t\t\t\t\t4cP+49glAVtsuTup9MRChUB6znydUVf9fVmi74FCsLaxEqMys8UMzXXMiCG1g6XG\n\t\t\t\t\t\tpra6VEmKTwxJPyFY5D9627VwJmrePAUZsozY3mIE5oibbq3U92VpvsTb7EQFlKMj\n\t\t\t\t\t\tLh83rrpEo40="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "New College Nottingham"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ncn.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "New College Nottingham"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://test.play.umu.se",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:saml_admin@kaltura.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test.play.umu.se",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ume\u00e5 universitet (TEST)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://test.play.umu.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ume\u00e5 universitet (TEST)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://test.play.umu.se/user/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Testmilj\u00f6 f\u00f6r UMU Play video portal vid Ume\u00e5 universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Test environment for UMU Play video portal at Ume\u00e5 University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UMU Play TEST, Ume\u00e5 universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UMU Play TEST, Ume\u00e5 University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.play.umu.se/user/authenticate",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:incommon:ucsc.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jeffreyc@ucsc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeffrey Crawford"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@ucsc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UCSC Support Center"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "abuse@ucsc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Security and Compliance"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kari@ucsc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kari Robertson"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:ucsc.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.ucsc.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.ucsc.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDmDCCAoACCQDLTquv7ZdiLTANBgkqhkiG9w0BAQsFADCBjTELMAkGA1UEBhMC\nVVMxEzARBgNVBAgMCkNhbGlmb3JuaWExEzARBgNVBAcMClNhbnRhIENydXoxLTAr\nBgNVBAoMJFVuaXZlcnNpdHkgb2YgQ2FsaWZvcm5pYSwgU2FudGEgQ3J1ejEMMAoG\nA1UECwwDSVRTMRcwFQYDVQQDDA5sb2dpbi51Y3NjLmVkdTAeFw0xNTA2MDIyMzE3\nNDJaFw0yMDA1MzEyMzE3NDJaMIGNMQswCQYDVQQGEwJVUzETMBEGA1UECAwKQ2Fs\naWZvcm5pYTETMBEGA1UEBwwKU2FudGEgQ3J1ejEtMCsGA1UECgwkVW5pdmVyc2l0\neSBvZiBDYWxpZm9ybmlhLCBTYW50YSBDcnV6MQwwCgYDVQQLDANJVFMxFzAVBgNV\nBAMMDmxvZ2luLnVjc2MuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAs8RybvRl9WBJDpXGOsoBrEfFKsAuwnz0sSFmjI4zkkV7WXuX2lLbBPhOnJdK\nbrXL11J6mDZgf8ydhH31nJJvP98bHo0LQIXe2t1dfLVinhtpOy3TQguQ7Biipwe4\ng0E+HI4U9ndL7jEO/Xf2diMGCSOKyZjSubSYFpgXj0ORpvixqsAId0R0JLA4Xf4O\nV8+l6BqlB7DwzzeZcf49pSq8CCP8QkgU3DzaemNM6Yvqtu1cTpYJ9HqRV2aRGj+G\nOOMVshmJ+8iDr02U5jh+0E+5485lNKb7gWHNA7kLa0QBWm4eBAU0DYQzgnuVG2Oe\nHpP1mKsc77wBkfScyGlOcKvCNQIDAQABMA0GCSqGSIb3DQEBCwUAA4IBAQAZBRvJ\nsHdjLTtoPfa8MuuL3KcyE9dj9rWHeyrnEuWuMfhO95BN6utPkneoOsDKZORHDAVE\nLTrZ4E4iq36xLWarv+37jh2U7EFFqW4zVm/0Pmoa+NtnKTs78tF80n4+Zwt2iPSI\nJS0ZPHiNl2XYjNb7auwUK2XvpqBqh8rP63+nSEHmgFOzg01nWoJz2Q0uQ7C0mEV6\naai0jp7M5se6pgnauX2g28ZyFORa5H0DO8Ku0SY8l9lTKRgXgsEOk8b2jJwuYnHu\n2dafiqrLOkdpKFPczD6ZGIx6eofqKmMeT4x+rZSvIZsq1j1wRw04gzQTHWCuEb+a\nN4x9ogtc8tHKC0O7"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucsc.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.ucsc.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.ucsc.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.ucsc.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.ucsc.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDmDCCAoACCQDLTquv7ZdiLTANBgkqhkiG9w0BAQsFADCBjTELMAkGA1UEBhMC\nVVMxEzARBgNVBAgMCkNhbGlmb3JuaWExEzARBgNVBAcMClNhbnRhIENydXoxLTAr\nBgNVBAoMJFVuaXZlcnNpdHkgb2YgQ2FsaWZvcm5pYSwgU2FudGEgQ3J1ejEMMAoG\nA1UECwwDSVRTMRcwFQYDVQQDDA5sb2dpbi51Y3NjLmVkdTAeFw0xNTA2MDIyMzE3\nNDJaFw0yMDA1MzEyMzE3NDJaMIGNMQswCQYDVQQGEwJVUzETMBEGA1UECAwKQ2Fs\naWZvcm5pYTETMBEGA1UEBwwKU2FudGEgQ3J1ejEtMCsGA1UECgwkVW5pdmVyc2l0\neSBvZiBDYWxpZm9ybmlhLCBTYW50YSBDcnV6MQwwCgYDVQQLDANJVFMxFzAVBgNV\nBAMMDmxvZ2luLnVjc2MuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAs8RybvRl9WBJDpXGOsoBrEfFKsAuwnz0sSFmjI4zkkV7WXuX2lLbBPhOnJdK\nbrXL11J6mDZgf8ydhH31nJJvP98bHo0LQIXe2t1dfLVinhtpOy3TQguQ7Biipwe4\ng0E+HI4U9ndL7jEO/Xf2diMGCSOKyZjSubSYFpgXj0ORpvixqsAId0R0JLA4Xf4O\nV8+l6BqlB7DwzzeZcf49pSq8CCP8QkgU3DzaemNM6Yvqtu1cTpYJ9HqRV2aRGj+G\nOOMVshmJ+8iDr02U5jh+0E+5485lNKb7gWHNA7kLa0QBWm4eBAU0DYQzgnuVG2Oe\nHpP1mKsc77wBkfScyGlOcKvCNQIDAQABMA0GCSqGSIb3DQEBCwUAA4IBAQAZBRvJ\nsHdjLTtoPfa8MuuL3KcyE9dj9rWHeyrnEuWuMfhO95BN6utPkneoOsDKZORHDAVE\nLTrZ4E4iq36xLWarv+37jh2U7EFFqW4zVm/0Pmoa+NtnKTs78tF80n4+Zwt2iPSI\nJS0ZPHiNl2XYjNb7auwUK2XvpqBqh8rP63+nSEHmgFOzg01nWoJz2Q0uQ7C0mEV6\naai0jp7M5se6pgnauX2g28ZyFORa5H0DO8Ku0SY8l9lTKRgXgsEOk8b2jJwuYnHu\n2dafiqrLOkdpKFPczD6ZGIx6eofqKmMeT4x+rZSvIZsq1j1wRw04gzQTHWCuEb+a\nN4x9ogtc8tHKC0O7"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucsc.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ucsc.edu"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www2.ucsc.edu/shibboleth-sp/logo.jpg",
                    "lang": "en",
                    "height": "129",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "400"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://policy.ucsc.edu"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of California, Santa Cruz"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of California, Santa Cruz"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ucsc.edu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of California, Santa Cruz"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shakespeare.acropolis.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shakespeareaccess@bbc.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "BBC Shakespeare Archive Resource Access Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:adops@bbc.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "BBC Archive Development Operations"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shakespeare.acropolis.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-02-04T16:37:05Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "BBC Shakespeare Archive Resource"
          },
          {
            "lang": "cy",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "BBC Shakespeare Ffeil Adnoddau"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://shakespeare.ch.bbc.co.uk/index.en"
          },
          {
            "lang": "cy",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://shakespeare.ch.bbc.co.uk/index.cy"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "BBC Worldwide Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shakespeare.acropolis.org.uk/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shakespeare.acropolis.org.uk/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hundreds of TV & radio programmes and thousands of photos from the BBC's Shakespeare collection"
                  }
                ],
                "logo": [
                  {
                    "text": "https://shakespeare.acropolis.org.uk/assets/shakespeare-350x170.png",
                    "height": "170",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "BBC Shakespeare Archive Resource"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEMzCCAxugAwIBAgIJAIQQbjEkRVeBMA0GCSqGSIb3DQEBBQUAMIGvMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEPMA0GA1UEBwwGTG9uZG9uMSkwJwYDVQQKDCBCcml0aXNoIEJyb2Fk\n\t\t\t\t\t\tY2FzdGluZyBDb3Jwb3JhdGlvbjEcMBoGA1UECwwTQXJjaGl2ZSBEZXZlbG9wbWVu\n\t\t\t\t\t\tdDElMCMGA1UEAwwcc2hha2VzcGVhcmUuYWNyb3BvbGlzLm9yZy51azEfMB0GCSqG\n\t\t\t\t\t\tSIb3DQEJARYQYWRvcHNkQGJiYy5jby51azAeFw0xNTEyMTcxNDM3MTlaFw0yNTEy\n\t\t\t\t\t\tMTQxNDM3MTlaMIGvMQswCQYDVQQGEwJHQjEPMA0GA1UEBwwGTG9uZG9uMSkwJwYD\n\t\t\t\t\t\tVQQKDCBCcml0aXNoIEJyb2FkY2FzdGluZyBDb3Jwb3JhdGlvbjEcMBoGA1UECwwT\n\t\t\t\t\t\tQXJjaGl2ZSBEZXZlbG9wbWVudDElMCMGA1UEAwwcc2hha2VzcGVhcmUuYWNyb3Bv\n\t\t\t\t\t\tbGlzLm9yZy51azEfMB0GCSqGSIb3DQEJARYQYWRvcHNkQGJiYy5jby51azCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM78CtAqZYFeUykWi4zfUAh4e5t/\n\t\t\t\t\t\tq6+yMCWoG8jyAdn9kQlD5sIcCpRj0BzhqswvDCpPlav1lN3uQtHWp5WkTeld7KmQ\n\t\t\t\t\t\tUOFzN4TB+TDbL3EPjteAi/vORNXWXbH7scbKPgneCdTEm5Oz9oOf5xVmpl/rc4m9\n\t\t\t\t\t\tAPS6nFM4f1/mPOp2fJZEtXMi6YVf1peTJ5aVy7hNlvS6Zmlk7nj4R5QsTOaR6neP\n\t\t\t\t\t\ttszmiNiiBdjYoTnIyb8eWLBxONVR6/DBgy/pf2G1HIQ1us2PQTgakRFYg7RnYGF8\n\t\t\t\t\t\tjhR2payBOWO+iEn9tHM0xilEkgIfgdQFjHGKVtMT+UwpqwU1EccVxLaHHr0CAwEA\n\t\t\t\t\t\tAaNQME4wHQYDVR0OBBYEFCyOkkYcSBjuw8jHXml8ZHoBU1T0MB8GA1UdIwQYMBaA\n\t\t\t\t\t\tFCyOkkYcSBjuw8jHXml8ZHoBU1T0MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQADggEBADS84JefjipO3bx4athzVuor9SdOUSLlVQgENSUwPowA+HR9flUKIvJ1\n\t\t\t\t\t\tSoGR5AOzArWB0tjTU4Tkj5L3dinfQseI/LAgEOEV4+r4wpCgVxceEMnAz1YzAXHz\n\t\t\t\t\t\tzfmQ5Ws4qKGLb9oPstwkZMDZUlN9SdHYUdrvrljeNmn8yL92zZLMAm/qD6hgrcG/\n\t\t\t\t\t\tLtQc8rGUJ9WlA9laajT8WeH3aC3CJlKIh3LdZyQcuxVCLGKFgoysEFgB8DQcsbjR\n\t\t\t\t\t\t676YU6Puh5cRfQI1JFl9BonHZ1Pr/QWtBYt9ZnpA/VnfJ3hWCMQsUfwbJ1PfBUjy\n\t\t\t\t\t\t/c56ELxxmXaa2osp99WXDsVLDjCDanE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEMzCCAxugAwIBAgIJAIQQbjEkRVeBMA0GCSqGSIb3DQEBBQUAMIGvMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEPMA0GA1UEBwwGTG9uZG9uMSkwJwYDVQQKDCBCcml0aXNoIEJyb2Fk\n\t\t\t\t\t\tY2FzdGluZyBDb3Jwb3JhdGlvbjEcMBoGA1UECwwTQXJjaGl2ZSBEZXZlbG9wbWVu\n\t\t\t\t\t\tdDElMCMGA1UEAwwcc2hha2VzcGVhcmUuYWNyb3BvbGlzLm9yZy51azEfMB0GCSqG\n\t\t\t\t\t\tSIb3DQEJARYQYWRvcHNkQGJiYy5jby51azAeFw0xNTEyMTcxNDM3MTlaFw0yNTEy\n\t\t\t\t\t\tMTQxNDM3MTlaMIGvMQswCQYDVQQGEwJHQjEPMA0GA1UEBwwGTG9uZG9uMSkwJwYD\n\t\t\t\t\t\tVQQKDCBCcml0aXNoIEJyb2FkY2FzdGluZyBDb3Jwb3JhdGlvbjEcMBoGA1UECwwT\n\t\t\t\t\t\tQXJjaGl2ZSBEZXZlbG9wbWVudDElMCMGA1UEAwwcc2hha2VzcGVhcmUuYWNyb3Bv\n\t\t\t\t\t\tbGlzLm9yZy51azEfMB0GCSqGSIb3DQEJARYQYWRvcHNkQGJiYy5jby51azCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM78CtAqZYFeUykWi4zfUAh4e5t/\n\t\t\t\t\t\tq6+yMCWoG8jyAdn9kQlD5sIcCpRj0BzhqswvDCpPlav1lN3uQtHWp5WkTeld7KmQ\n\t\t\t\t\t\tUOFzN4TB+TDbL3EPjteAi/vORNXWXbH7scbKPgneCdTEm5Oz9oOf5xVmpl/rc4m9\n\t\t\t\t\t\tAPS6nFM4f1/mPOp2fJZEtXMi6YVf1peTJ5aVy7hNlvS6Zmlk7nj4R5QsTOaR6neP\n\t\t\t\t\t\ttszmiNiiBdjYoTnIyb8eWLBxONVR6/DBgy/pf2G1HIQ1us2PQTgakRFYg7RnYGF8\n\t\t\t\t\t\tjhR2payBOWO+iEn9tHM0xilEkgIfgdQFjHGKVtMT+UwpqwU1EccVxLaHHr0CAwEA\n\t\t\t\t\t\tAaNQME4wHQYDVR0OBBYEFCyOkkYcSBjuw8jHXml8ZHoBU1T0MB8GA1UdIwQYMBaA\n\t\t\t\t\t\tFCyOkkYcSBjuw8jHXml8ZHoBU1T0MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQADggEBADS84JefjipO3bx4athzVuor9SdOUSLlVQgENSUwPowA+HR9flUKIvJ1\n\t\t\t\t\t\tSoGR5AOzArWB0tjTU4Tkj5L3dinfQseI/LAgEOEV4+r4wpCgVxceEMnAz1YzAXHz\n\t\t\t\t\t\tzfmQ5Ws4qKGLb9oPstwkZMDZUlN9SdHYUdrvrljeNmn8yL92zZLMAm/qD6hgrcG/\n\t\t\t\t\t\tLtQc8rGUJ9WlA9laajT8WeH3aC3CJlKIh3LdZyQcuxVCLGKFgoysEFgB8DQcsbjR\n\t\t\t\t\t\t676YU6Puh5cRfQI1JFl9BonHZ1Pr/QWtBYt9ZnpA/VnfJ3hWCMQsUfwbJ1PfBUjy\n\t\t\t\t\t\t/c56ELxxmXaa2osp99WXDsVLDjCDanE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shakespeare.acropolis.org.uk/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shakespeare.acropolis.org.uk/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shakespeare.acropolis.org.uk/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shakespeare.acropolis.org.uk/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "BBC Shakespeare Archive Resource"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Hundreds of TV & radio programmes and thousands of photos from the BBC's Shakespeare collection"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.colegsirgar.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@colegsirgar.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Palmer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Simon.Palmer@colegsirgar.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.colegsirgar.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-01-13T11:27:19Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Coleg Sir Gar"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://colegsirgar.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Coleg Sir Gar"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.colegsirgar.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.colegsirgar.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.colegsirgar.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.colegsirgar.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.colegsirgar.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Shibboleth Service Provider for Coleg Sir Gar providing online access to Coleg Sir Gar applications"
                  }
                ],
                "logo": [
                  {
                    "text": "https://sp.colegsirgar.ac.uk/img/csg_logo_350.png",
                    "height": "142",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  },
                  {
                    "text": "https://sp.colegsirgar.ac.uk/img/csg_shield.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Coleg Sir Gar"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sp.colegsirgar.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp.colegsirgar.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICzTCCAbWgAwIBAgIJAIl+WHxfd4mhMA0GCSqGSIb3DQEBBQUAMA0xCzAJBgNV\n\t\t\t\t\t\tBAMTAnNwMB4XDTE1MDEwNzEzNDc0N1oXDTI1MDEwNDEzNDc0N1owDTELMAkGA1UE\n\t\t\t\t\t\tAxMCc3AwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC6TAAssygAHhtn\n\t\t\t\t\t\tscD7mgyf5RjV5+wncxcsVLdGtm6GaROqqhz/SL521Y+aQLxtqCfJyBlN9mIkboAv\n\t\t\t\t\t\tvBmmcvc4xCBirmHWFQEtcISIYyh7KYcVpUomXQUIJUkJa8EXdyWlVxV9EE0K3VYF\n\t\t\t\t\t\tz5nlUXgpLjwfxnevkRJhRI/lR5J4iAJner61vAWNvcTyu6g6Hlj4TeH20GzuuEY/\n\t\t\t\t\t\tadgKwtqW8riKaQWNIebfHNGzW3S0lqEYLmntPC2Y/M8rH6m9t8yN2qUx6hBKB0mH\n\t\t\t\t\t\teCwqxC3BAbZax55sMSw+f6/MHKF0pjtWymqDbbNfD98VxhUkmqmVjgq3/DhbKWCH\n\t\t\t\t\t\taI6p4KKVAgMBAAGjMDAuMA0GA1UdEQQGMASCAnNwMB0GA1UdDgQWBBR7ZIA5K0DE\n\t\t\t\t\t\t+CdJsFCvDsIXaCvouDANBgkqhkiG9w0BAQUFAAOCAQEAY79NtNn1cgqdO9E985g5\n\t\t\t\t\t\tvx4j3mzDqBkajG6TP/pnAEzNoHODaltP5bHAX0Kew6bVnlYwzN7jVZec0WDdH/SH\n\t\t\t\t\t\t2enUTJkD15/XZvH+oFa7MWLJ2pLYEfgJIxFz3nw0ozzZKAHuPsRejpXMKAv56bT3\n\t\t\t\t\t\tlu1S/dkNs9u6MttdCQcznLppIGSjx7QUx7tPF6bE706BYytYlCHziB9NmgqT1b4n\n\t\t\t\t\t\txccA2shkXbhcoEQ78y2YHMlhkM4axlYHsnnpVmTA2vASPrQoaIim/diEbv44/EFm\n\t\t\t\t\t\tiiXTgSzWSDPcAp/x5Vqrvd2qkKx5efJYioATLHvnBeW8L2Tnwf4ehtlaI524a/y4\n\t\t\t\t\t\tOA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.colegsirgar.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp.colegsirgar.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.colegsirgar.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp.colegsirgar.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp.colegsirgar.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp.colegsirgar.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.dl.begellhouse.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:orders@begellhouse.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Begell House Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Judin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alex@offsiteteam.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.dl.begellhouse.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Begell House Digital Library"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dl.begellhouse.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Begell House Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.dl.begellhouse.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.dl.begellhouse.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.dl.begellhouse.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.dl.begellhouse.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDATCCAemgAwIBAgIBADANBgkqhkiG9w0BAQUFADAhMR8wHQYDVQQDExZ3d3cu\n\t\t\t\t\t\tZGwuYmVnZWxsaG91c2UuY29tMB4XDTA5MTEwMjE3MzYzNVoXDTE5MTAzMTE3MzYz\n\t\t\t\t\t\tNVowITEfMB0GA1UEAxMWd3d3LmRsLmJlZ2VsbGhvdXNlLmNvbTCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBAMuFDBpujB8wIt6HdNkuWSn9PBX2obMNrsqY\n\t\t\t\t\t\tNMHFPRNP0t8T7NwuOm9qRbvL/W+ViiVCAphbJK5BdgQBQd1O/S90ViBuPGQ3INVg\n\t\t\t\t\t\tuLiWiuon37yUb/pAhn/4tSi8rEv5LYJmwvmZmJSV8gBwb03i1LYGb2aF3nGqffNy\n\t\t\t\t\t\tTiObBhFOUaoyWBi+X4+MQT8DHyV9T1E9mTXDsWGPm2hb5htSxloDgrnqrVFhShzv\n\t\t\t\t\t\tLtV4+4ksGTA/GRNriuYgcpiB1PEvnMfiVASysOOKWojEEQ3U0e2Q2lyEiczH+MFL\n\t\t\t\t\t\tOkmrUMbYPXxNdck9mhREPbckZbJasKHGetDoy4XsHh5DyRl102kCAwEAAaNEMEIw\n\t\t\t\t\t\tIQYDVR0RBBowGIIWd3d3LmRsLmJlZ2VsbGhvdXNlLmNvbTAdBgNVHQ4EFgQUD6sj\n\t\t\t\t\t\t78W4QOa1Vp52Ui0rw8eeb2EwDQYJKoZIhvcNAQEFBQADggEBAADoC2XeOIaCYrC8\n\t\t\t\t\t\t6tWbcuSq6trWxyTDH+Vz5Pe6cR+UVwsaQ2/3NAzqxQ2gZRJU2A/UoFoC9CuiBvv9\n\t\t\t\t\t\tXenHkZu3a8wRoG1SxhrNkC98D4o4wxp0IlU7R2KEJte+UHLNZ1Om0EjHkva1JrB1\n\t\t\t\t\t\tUV+o7xI8AFxu3Ym9m5UW7mqs2eo29xbkJ+TEyW/SifXkp9kowFPGyQlfFY14x3Xb\n\t\t\t\t\t\tDftb5D+IXvsPJAVKfqiMUuDN5r4JtrEnhx4J2QrC2OF061JTrDINitdSN+k1cAhO\n\t\t\t\t\t\tP4j8jBZlm09UY2vIfbVGHkXfF2bY8oUHwtJvdrJNOfQMcAabjX4JjAXtzPoylgQ7\n\t\t\t\t\t\tdbHMS9g="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDATCCAemgAwIBAgIBADANBgkqhkiG9w0BAQUFADAhMR8wHQYDVQQDExZ3d3cu\n\t\t\t\t\t\tZGwuYmVnZWxsaG91c2UuY29tMB4XDTA5MTEwMjE3MzYzNVoXDTE5MTAzMTE3MzYz\n\t\t\t\t\t\tNVowITEfMB0GA1UEAxMWd3d3LmRsLmJlZ2VsbGhvdXNlLmNvbTCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBAMuFDBpujB8wIt6HdNkuWSn9PBX2obMNrsqY\n\t\t\t\t\t\tNMHFPRNP0t8T7NwuOm9qRbvL/W+ViiVCAphbJK5BdgQBQd1O/S90ViBuPGQ3INVg\n\t\t\t\t\t\tuLiWiuon37yUb/pAhn/4tSi8rEv5LYJmwvmZmJSV8gBwb03i1LYGb2aF3nGqffNy\n\t\t\t\t\t\tTiObBhFOUaoyWBi+X4+MQT8DHyV9T1E9mTXDsWGPm2hb5htSxloDgrnqrVFhShzv\n\t\t\t\t\t\tLtV4+4ksGTA/GRNriuYgcpiB1PEvnMfiVASysOOKWojEEQ3U0e2Q2lyEiczH+MFL\n\t\t\t\t\t\tOkmrUMbYPXxNdck9mhREPbckZbJasKHGetDoy4XsHh5DyRl102kCAwEAAaNEMEIw\n\t\t\t\t\t\tIQYDVR0RBBowGIIWd3d3LmRsLmJlZ2VsbGhvdXNlLmNvbTAdBgNVHQ4EFgQUD6sj\n\t\t\t\t\t\t78W4QOa1Vp52Ui0rw8eeb2EwDQYJKoZIhvcNAQEFBQADggEBAADoC2XeOIaCYrC8\n\t\t\t\t\t\t6tWbcuSq6trWxyTDH+Vz5Pe6cR+UVwsaQ2/3NAzqxQ2gZRJU2A/UoFoC9CuiBvv9\n\t\t\t\t\t\tXenHkZu3a8wRoG1SxhrNkC98D4o4wxp0IlU7R2KEJte+UHLNZ1Om0EjHkva1JrB1\n\t\t\t\t\t\tUV+o7xI8AFxu3Ym9m5UW7mqs2eo29xbkJ+TEyW/SifXkp9kowFPGyQlfFY14x3Xb\n\t\t\t\t\t\tDftb5D+IXvsPJAVKfqiMUuDN5r4JtrEnhx4J2QrC2OF061JTrDINitdSN+k1cAhO\n\t\t\t\t\t\tP4j8jBZlm09UY2vIfbVGHkXfF2bY8oUHwtJvdrJNOfQMcAabjX4JjAXtzPoylgQ7\n\t\t\t\t\t\tdbHMS9g="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.dl.begellhouse.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.dl.begellhouse.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.dl.begellhouse.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.dl.begellhouse.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.dl.begellhouse.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.dl.begellhouse.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.dl.begellhouse.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.dl.begellhouse.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.dl.begellhouse.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.dl.begellhouse.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://auth.chimie-paristech.fr/idp/saml2/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "reseau@chimie-paristech.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://auth.chimie-paristech.fr/idp/saml2/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-02-05T11:03:17Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.chimie-paristech.fr/idp/saml2/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.chimie-paristech.fr/idp/saml2/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://auth.chimie-paristech.fr/idp/saml2/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "chimie-paristech.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.chimie-paristech.fr/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "F\u00e9d\u00e9ration d'identit\u00e9 Chime-ParisTech"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "F\u00e9d\u00e9ration d'identit\u00e9 Chime-ParisTech"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Nationale Sup\u00e9rieure de Chimie Paris"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Nationale Sup\u00e9rieure de Chimie Paris"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+TCCAeGgAwIBAgIJAJmcv9A/+nY6MA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\nBAMMCHdob2NhcmVzMB4XDTE1MDcyNzA5MjYzNFoXDTI1MDcyNDA5MjYzNFowEzER\nMA8GA1UEAwwId2hvY2FyZXMwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQDb9zK81GuZJ/4TX0AalLD46F8+lcmfXc3Y5ccE2ZctCXVmeRUcnHXIr4jFJRQ3\n8AJ/g8A8zcsTYuDbhAg7Yd2vqmSSGGf9EETNn45NluBhfdtVTOKTXYyv+aY2RZKV\niqpWzz5i134rXXy61xLOcC0ci74K8PbwkfviMwYlnNNzFMBRIFOLTTFKgdDtjcE5\nIe5oZPS4j5Tx0dYC3T2yhCWA7k0kc1VF/7Q9tF2+9msXHkGBMDOWoaKy6QKi6CHK\nviEFYBd5U2PpSWQhqmcIBzIelQ2J3XIcoeyg/85tnN/s0+ZsADjJmzsOFVtAMYqI\nRy+75rqt+CLhs2RLXEFMkkTzAgMBAAGjUDBOMB0GA1UdDgQWBBRAoB5K4Z/Gm1zk\nWtY9P638mmAeGjAfBgNVHSMEGDAWgBRAoB5K4Z/Gm1zkWtY9P638mmAeGjAMBgNV\nHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAVYVLSftwjAw0CyOcH8QXxjQmm\nI/bQpPnAb6UDktX8zIqDfl3gZNa2oqMARcAgN/hBReqFpWQIUdsaJlePCxnWyxjP\naF3rWvXt47VoAABO9C3CdB5IoP65+GPbTNUQG0xFvrKFg4/Dw0/LyGf1I92cLl17\nGwtPeH74WWUS3211Vj/I5sgWqxWn7fDCA6uaEUEvFXlM9IVEOFfNhH1X+uJInXvG\nydZRy1PJDov/EFcatxt2v0DTIuqmtqTKi+luC1Zf5HdqV7d3EH76JeXcrvUGc8sa\nqyA+HoSIue07UW2+enWOYUPVdkGqJ2+aSWgdYiwY825Q+GWXN7qSuOwGIXeg"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+TCCAeGgAwIBAgIJAMZ6vEXbndNaMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\nBAMMCHdob2NhcmVzMB4XDTE1MDMyNDEzMTQzMFoXDTI1MDMyMTEzMTQzMFowEzER\nMA8GA1UEAwwId2hvY2FyZXMwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQDWk7SHWFBV5+TjxZtU1rIe9xGGVhLqaT7UWB+S0YnTgPBPNWSEUctMgUpBZh+X\nLFSmYR/wt/qIsZEfmfjdxNQBjyiieP6fh7eBdYHZ1y7EYJAwGThL5kGEUG5okgJl\niMWUSvOs2I52cWwGl/u8tTv6JbFun+XE3hosxiPHtUcdZYCJdss4bbmJFR8F2nzz\nGy6YTS6U5+DSreONEKXjLvcHCEkDzXwHdhEu/3Fn4Pv821HDRn3Qf1D+t/VUsp4k\nxeSKx1fbAlNutGwedvE+zzibI1h/9OQe+YjXlLh+rxRJqNbVXmTJ0M/wK0MnGvde\nI76K6F2jht/Oe86GKOUYUM/zAgMBAAGjUDBOMB0GA1UdDgQWBBR+GgMt/hMq5lnR\nODKvRP4WL13oXzAfBgNVHSMEGDAWgBR+GgMt/hMq5lnRODKvRP4WL13oXzAMBgNV\nHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCTKC2uCURy2zt2YIOx3GrbYAnO\nxCtEiEC8QSsd3ImVUjVWFr2MlDD0DlRioWTJdE6YpGUM0r/614QDXV74CTz0RNpf\n01YkIhL5VgXxx4RmUz/3IdxDFvthw/lwJ/kUsvwuaj5LKtMpXGDSu0t4KHoM30os\nFr5vPb+9jZ9eCB4dle9Dy1Ig89CMmv5y0II4m5kxY6pBvErWKi1kAfWoVbUVW2o0\nZjlGleUJuyQavgQkOIyFg51+ltYLQ748tyZEJA6AFMTUNo3PEW5owRJkz1kUyPiv\ngfR+hAVdryNm7EwlyO/nkqxhil2SSwTWyZi7YLmScmmyefERLhWt3uEtxBep"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ecole Nationale Sup\u00e9rieure de Chimie Paris"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.chimie-paristech.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ecole Nationale Sup\u00e9rieure de Chimie Paris"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://xenosmilus2.umdc.umu.se:8086/re/sp.xml",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://xenosmilus2.umdc.umu.se:8086/re/sp.xml",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://xenosmilus2.umdc.umu.se:8086/disco",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICIzCCAYwCCQDFqR2p3amCSjANBgkqhkiG9w0BAQUFADBWMQswCQYDVQQGEwJT\nRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UECgwDVW1VMQwwCgYDVQQLDANJVFMxHDAa\nBgNVBAMME2xpbmdvbi5sYWRvay51bXUuc2UwHhcNMTMwNjE0MTY1MjAyWhcNMTQw\nNjE0MTY1MjAyWjBWMQswCQYDVQQGEwJTRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UE\nCgwDVW1VMQwwCgYDVQQLDANJVFMxHDAaBgNVBAMME2xpbmdvbi5sYWRvay51bXUu\nc2UwgZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGBAM8nCb97J2QNi/U+4EnR2vL/\nvGtUM44dyOrdQ4xdD/feHyu0kWoNal/8CXJTYtDVrbKMg90fakPfw6Lw5KxQTzGl\nR6qNRyuuMq7KIgRzlbZEWiAh1YKQMOn+C3qIM0HqkfjD/rnCokIpFhGFi+7886AD\nVNB5CnUQXrSTAkUJzVS7AgMBAAEwDQYJKoZIhvcNAQEFBQADgYEABfQAzyDkwIQZ\nHu3tPi7QvJbdTDH8F3q8iSQwOT7MvxmHmCO/DZFwYu5jjYg/FtBfpbh8mQTziCy8\nFyVMuMKNSZn2rEIJF1ghgQqtHwn08zsPPhD9XW0LXeP6Exl/xIguWJElU9JzmPU6\naZOix3ahmr0PwcIhFbWaZvsjL46MdHI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICIzCCAYwCCQDFqR2p3amCSjANBgkqhkiG9w0BAQUFADBWMQswCQYDVQQGEwJT\nRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UECgwDVW1VMQwwCgYDVQQLDANJVFMxHDAa\nBgNVBAMME2xpbmdvbi5sYWRvay51bXUuc2UwHhcNMTMwNjE0MTY1MjAyWhcNMTQw\nNjE0MTY1MjAyWjBWMQswCQYDVQQGEwJTRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UE\nCgwDVW1VMQwwCgYDVQQLDANJVFMxHDAaBgNVBAMME2xpbmdvbi5sYWRvay51bXUu\nc2UwgZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGBAM8nCb97J2QNi/U+4EnR2vL/\nvGtUM44dyOrdQ4xdD/feHyu0kWoNal/8CXJTYtDVrbKMg90fakPfw6Lw5KxQTzGl\nR6qNRyuuMq7KIgRzlbZEWiAh1YKQMOn+C3qIM0HqkfjD/rnCokIpFhGFi+7886AD\nVNB5CnUQXrSTAkUJzVS7AgMBAAEwDQYJKoZIhvcNAQEFBQADgYEABfQAzyDkwIQZ\nHu3tPi7QvJbdTDH8F3q8iSQwOT7MvxmHmCO/DZFwYu5jjYg/FtBfpbh8mQTziCy8\nFyVMuMKNSZn2rEIJF1ghgQqtHwn08zsPPhD9XW0LXeP6Exl/xIguWJElU9JzmPU6\naZOix3ahmr0PwcIhFbWaZvsjL46MdHI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://xenosmilus2.umdc.umu.se:8086/acs/re/redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://xenosmilus2.umdc.umu.se:8086/acs/re/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cavle.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@uniservity.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Zefaj"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rezar.zefaj@UniServity.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rezar"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fraser"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:brian.fraser@uniservity.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cavle.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-10-08T08:32:16Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFjCCAf6gAwIBAgIQGVM0uhTD3rVCMPoy0rMlwzANBgkqhkiG9w0BAQsFADAd\n\t\t\t\t\t\tMRswGQYDVQQDExJpZHAudW5pc2Vydml0eS5jb20wHhcNMTQxMDA3MTMyNTQ3WhcN\n\t\t\t\t\t\tMzUxMjMwMjMwMDAwWjAdMRswGQYDVQQDExJpZHAudW5pc2Vydml0eS5jb20wggEi\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDRCBuPl18hR/OOGblHjWWTo9LR\n\t\t\t\t\t\tc3BZ9sTsDw2oLTV7QZiPuzFkmaelEFjnkWUsbjKQcjaidaA/UxP0YGaTypRUJDyM\n\t\t\t\t\t\tA83zRfCrqGOFE8qvjesl0VNJrhw+8pxxKnxnOsnzqLT2rMid4cGuTLtNK0BnCXaU\n\t\t\t\t\t\t9tQ6ggrZEEZUtZsQ4GUhapc/FiX9SV2OGeVlUfeDPCCeegVxWnTjoW6NirXRHw7e\n\t\t\t\t\t\tB8CZmculcAm549Di1chMRmy1W1TPPUS16hZI65fU8ra5anxtEjPrPm/42VI3b7EC\n\t\t\t\t\t\tn9HKTZL90O38/iUu1CGZBvSd8BHsFpta9IuEcAPzwb5oggRe0jOqYfVVM0svAgMB\n\t\t\t\t\t\tAAGjUjBQME4GA1UdAQRHMEWAEARX+D7bRC1NV+4PE+pA07ehHzAdMRswGQYDVQQD\n\t\t\t\t\t\tExJpZHAudW5pc2Vydml0eS5jb22CEBlTNLoUw961QjD6MtKzJcMwDQYJKoZIhvcN\n\t\t\t\t\t\tAQELBQADggEBACLhDJtzDh6aqM/ZBf8nGEyVYEbav54Hnw+tHMdpRfgQXRT4UEed\n\t\t\t\t\t\tzkG9b8TCFnbWuGkkdfT5GesY3P+KjJQ05AkvtVcgq6CTencq5a9mcocXeFhmO45a\n\t\t\t\t\t\t/6w8VV+iNrMov2gxsOdTx6cbU0pP5UUxYRNCzMc20CoOb1YENt6LMxXn0zlM2uR+\n\t\t\t\t\t\t5/xuR9hxY8TbZgoQzIU6ZSmfRND2VufgaL3ndxQgyd86qmIkkPfL1yOgPglINkrI\n\t\t\t\t\t\tWArFmTaBqIHzgsuZgaqJNsEiLP8KgnKvtQoq7YyLXKGEjQGSlvEB3CY67XMAMleR\n\t\t\t\t\t\tW/SZFaCEqoPVCkUSY5QwNt5efTT4YWfcwis="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cavle.org"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uniservity.com:8443/shib/profile/saml1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uniservity.com:8443/shib/profile/saml2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uniservity.com/shib/profile/saml2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uniservity.com/shib/profile/saml2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.uniservity.com/shib/profile/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uniservity.com/shib/profile/saml2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.uniservity.com/shib/profile/saml2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uniservity.com/shib/profile/saml2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uniservity.com:8443/shib/profile/saml1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uniservity.com:8443/shib/profile/saml2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cavle.org"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFjCCAf6gAwIBAgIQGVM0uhTD3rVCMPoy0rMlwzANBgkqhkiG9w0BAQsFADAd\n\t\t\t\t\t\tMRswGQYDVQQDExJpZHAudW5pc2Vydml0eS5jb20wHhcNMTQxMDA3MTMyNTQ3WhcN\n\t\t\t\t\t\tMzUxMjMwMjMwMDAwWjAdMRswGQYDVQQDExJpZHAudW5pc2Vydml0eS5jb20wggEi\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDRCBuPl18hR/OOGblHjWWTo9LR\n\t\t\t\t\t\tc3BZ9sTsDw2oLTV7QZiPuzFkmaelEFjnkWUsbjKQcjaidaA/UxP0YGaTypRUJDyM\n\t\t\t\t\t\tA83zRfCrqGOFE8qvjesl0VNJrhw+8pxxKnxnOsnzqLT2rMid4cGuTLtNK0BnCXaU\n\t\t\t\t\t\t9tQ6ggrZEEZUtZsQ4GUhapc/FiX9SV2OGeVlUfeDPCCeegVxWnTjoW6NirXRHw7e\n\t\t\t\t\t\tB8CZmculcAm549Di1chMRmy1W1TPPUS16hZI65fU8ra5anxtEjPrPm/42VI3b7EC\n\t\t\t\t\t\tn9HKTZL90O38/iUu1CGZBvSd8BHsFpta9IuEcAPzwb5oggRe0jOqYfVVM0svAgMB\n\t\t\t\t\t\tAAGjUjBQME4GA1UdAQRHMEWAEARX+D7bRC1NV+4PE+pA07ehHzAdMRswGQYDVQQD\n\t\t\t\t\t\tExJpZHAudW5pc2Vydml0eS5jb22CEBlTNLoUw961QjD6MtKzJcMwDQYJKoZIhvcN\n\t\t\t\t\t\tAQELBQADggEBACLhDJtzDh6aqM/ZBf8nGEyVYEbav54Hnw+tHMdpRfgQXRT4UEed\n\t\t\t\t\t\tzkG9b8TCFnbWuGkkdfT5GesY3P+KjJQ05AkvtVcgq6CTencq5a9mcocXeFhmO45a\n\t\t\t\t\t\t/6w8VV+iNrMov2gxsOdTx6cbU0pP5UUxYRNCzMc20CoOb1YENt6LMxXn0zlM2uR+\n\t\t\t\t\t\t5/xuR9hxY8TbZgoQzIU6ZSmfRND2VufgaL3ndxQgyd86qmIkkPfL1yOgPglINkrI\n\t\t\t\t\t\tWArFmTaBqIHzgsuZgaqJNsEiLP8KgnKvtQoq7YyLXKGEjQGSlvEB3CY67XMAMleR\n\t\t\t\t\t\tW/SZFaCEqoPVCkUSY5QwNt5efTT4YWfcwis="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UniServity: CAVLE"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://uniservity.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UniServity Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib-idp-1.oru.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 19 303166"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT Avdelningen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@oru.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "\u00d6rebro University"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 19 303851"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jonny Ehrnberg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jonny.ehrnberg@oru.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "\u00d6rebro University"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 19 303166"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT Avdelningen \u00d6rebro universitet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@oru.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "\u00d6rebro University"
          }
        }
      ],
      "entity_id": "https://shib-idp-1.oru.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oasis:names:tc:SAML:attribute:assurance-certification",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVALJU7HH8NWybHvd6JV9KLneiEBQ9MA0GCSqGSIb3DQEB\nBQUAMBwxGjAYBgNVBAMTEXNoaWItaWRwLTEub3J1LnNlMB4XDTA5MTAyNjEwMjU1\nNVoXDTI5MTAyNjA5MjU1NVowHDEaMBgGA1UEAxMRc2hpYi1pZHAtMS5vcnUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC7J4bgJcpbTuu4SD8pYvDC\nD5lRoaxVTvvacSPEIt2FUTGfa+smWLJvaoxL7eaP517Re9xqqw0MyRZ2fjyDW2GU\nz84RhCMQemT6EccDCEDwubkjoq41QQFbOsk/uh40Q0a/fOniP+e9cDpq57vQTux6\na1tFNHgbOVR/1PsCksVsY6tdVbR364otqKXIti8ddYmPB5ax5Qr4+ezD7MJwitvN\nNyOgZZ2qM8P7Y1rMN+kKb4OTPHLIhVUiCRtww3p/9HTZOhjxRZbDKNLVQjHCwv9N\npKh+cON1k5YGSEYba28z1ZuKKvVq6cCMcgndTiMA0R8LxMi3psbWB6rohddoo8E9\nAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEXNoaWItaWRwLTEub3J1LnNlhihodHRwczov\nL3NoaWItaWRwLTEub3J1LnNlL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSJG9Hv\n5hKDK9iBmJYEU3Hg0DZZPzANBgkqhkiG9w0BAQUFAAOCAQEAC1tgenssXaACi4b0\nO+j5Qno3bjq35y+cj0OC/Za2lBuD10zYiySOMcuxg7WdPDiiTKtoBdYkRRN6oKiT\nix3hLTwuU3PjLTIZ83ytNgezEa6oK+iCGi/ecz2ax77QZ9rqpQCRNudIZjbTN6SO\nx+FduJkHovXk0Z9zfp5YZzJG2ViPYemurS8OEofkJXQKgmoFmw+LycSTMx2G6rnN\nSqQVF5wbEc9N1wy/sisZQ8yw4Err6mDAChcnrGtfFQ5aR89Xrb2VIkaOTRysytEQ\nJCVUOimhAjCyTt7bIWWH3Y1VYBQ9PfklNyHfusJ3AjqnuqYjoDiDKEz42EqLnq71\nPz8R3A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oru.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-idp-1.oru.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp-1.oru.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib-idp-1.oru.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-idp-1.oru.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib-idp-1.oru.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-idp-1.oru.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-idp-1.oru.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp-1.oru.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oru.se"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r \u00d6rebro universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "\u00d6rebro University Identity Provider"
                  }
                ],
                "logo": [
                  {
                    "text": "https://cas-01.oru.se/cas/Logo_txt_runt_farg.gif",
                    "height": "65",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "90"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u00d6rebro universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u00d6rebro University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "oru.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:59.2547,15.2485"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:59.7065,14.5473"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.243.96.0/19"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVALJU7HH8NWybHvd6JV9KLneiEBQ9MA0GCSqGSIb3DQEB\nBQUAMBwxGjAYBgNVBAMTEXNoaWItaWRwLTEub3J1LnNlMB4XDTA5MTAyNjEwMjU1\nNVoXDTI5MTAyNjA5MjU1NVowHDEaMBgGA1UEAxMRc2hpYi1pZHAtMS5vcnUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC7J4bgJcpbTuu4SD8pYvDC\nD5lRoaxVTvvacSPEIt2FUTGfa+smWLJvaoxL7eaP517Re9xqqw0MyRZ2fjyDW2GU\nz84RhCMQemT6EccDCEDwubkjoq41QQFbOsk/uh40Q0a/fOniP+e9cDpq57vQTux6\na1tFNHgbOVR/1PsCksVsY6tdVbR364otqKXIti8ddYmPB5ax5Qr4+ezD7MJwitvN\nNyOgZZ2qM8P7Y1rMN+kKb4OTPHLIhVUiCRtww3p/9HTZOhjxRZbDKNLVQjHCwv9N\npKh+cON1k5YGSEYba28z1ZuKKvVq6cCMcgndTiMA0R8LxMi3psbWB6rohddoo8E9\nAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEXNoaWItaWRwLTEub3J1LnNlhihodHRwczov\nL3NoaWItaWRwLTEub3J1LnNlL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSJG9Hv\n5hKDK9iBmJYEU3Hg0DZZPzANBgkqhkiG9w0BAQUFAAOCAQEAC1tgenssXaACi4b0\nO+j5Qno3bjq35y+cj0OC/Za2lBuD10zYiySOMcuxg7WdPDiiTKtoBdYkRRN6oKiT\nix3hLTwuU3PjLTIZ83ytNgezEa6oK+iCGi/ecz2ax77QZ9rqpQCRNudIZjbTN6SO\nx+FduJkHovXk0Z9zfp5YZzJG2ViPYemurS8OEofkJXQKgmoFmw+LycSTMx2G6rnN\nSqQVF5wbEc9N1wy/sisZQ8yw4Err6mDAChcnrGtfFQ5aR89Xrb2VIkaOTRysytEQ\nJCVUOimhAjCyTt7bIWWH3Y1VYBQ9PfklNyHfusJ3AjqnuqYjoDiDKEz42EqLnq71\nPz8R3A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u00d6rebro universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u00d6rebro University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oru.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ORU"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://mnementh.csi.cam.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Warbrick"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jw35@cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jon"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Warbrick"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jw35@cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://mnementh.csi.cam.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Test SP on mnementh.csi"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cam.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Cambridge"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mnementh.csi.cam.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mnementh.csi.cam.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mnementh.csi.cam.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mnementh.csi.cam.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://mnementh.csi.cam.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3zCCAcegAwIBAgIJAOVxp6HWm9xkMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\n\t\t\t\t\t\tBAMTCG1uZW1lbnRoMB4XDTA5MDIxODE3MjYzOFoXDTE5MDIxNjE3MjYzOFowEzER\n\t\t\t\t\t\tMA8GA1UEAxMIbW5lbWVudGgwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCWDFJMwCnDDlN4+JVj+jxbThz13wSWChP78LNPleUdjm1zbsQJOfcJ542EkyqM\n\t\t\t\t\t\t7/O3TqgXES/VlkTccIfr/e86lO8AxFYeXsowEju+3AnyAXav3fL03diiRR+mWTlr\n\t\t\t\t\t\tA0GjD6uQHlIZGce0IACh/GUc+nMxYjSZlnc/IKDF0lGrOhQdsdjasxc9daJ0HQOY\n\t\t\t\t\t\tBXcJkFQO1m4uztNXPu/3JLYSzpLgKVY9W/24fyd9zpsPrG4xHl3D08jUovDvnENc\n\t\t\t\t\t\t+q0gyt5TwRt28hifF9kdV+zdyTYQvKi4uOimqzt9wjSbv9xhvNa5VElt7GbiAZRE\n\t\t\t\t\t\tOGUAj4gEbQbBhU4TLJN84h9jAgMBAAGjNjA0MBMGA1UdEQQMMAqCCG1uZW1lbnRo\n\t\t\t\t\t\tMB0GA1UdDgQWBBQjLNqsyE3DpyRHamNjGNFPfpd5qTANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAGkihtfVr4oVSzPreJwViJnqosAxrnTg2rEwvTnp02Es6Vaam5M995JQkWS8x\n\t\t\t\t\t\tvQAwCywoccsRuk02LOZ7bhP7IExPYSmzSJ3bIbXYxTJ5+36ELmxS0dETZq69c0QT\n\t\t\t\t\t\tXja0CXAviE3TjK3VLvemSaJWJlssPB3dGIHhJ1oulB7mG1F1gj6MY8FHtjgsjJ2k\n\t\t\t\t\t\tjKWUyCTonkcj/j22UdaMzsBb0vOtRoDBlhtEyppm06VQFQpizV2XyH/de8R1mrNK\n\t\t\t\t\t\tm2tWL3l+kX0MHJVAQ7i6iSXhiXCX1/ATGEPniV71u9gRMd/FQBJo9D5jTOHUpNzA\n\t\t\t\t\t\tdvLRXByBJtURFonOb55G90gyqg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3zCCAcegAwIBAgIJAOVxp6HWm9xkMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\n\t\t\t\t\t\tBAMTCG1uZW1lbnRoMB4XDTA5MDIxODE3MjYzOFoXDTE5MDIxNjE3MjYzOFowEzER\n\t\t\t\t\t\tMA8GA1UEAxMIbW5lbWVudGgwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCWDFJMwCnDDlN4+JVj+jxbThz13wSWChP78LNPleUdjm1zbsQJOfcJ542EkyqM\n\t\t\t\t\t\t7/O3TqgXES/VlkTccIfr/e86lO8AxFYeXsowEju+3AnyAXav3fL03diiRR+mWTlr\n\t\t\t\t\t\tA0GjD6uQHlIZGce0IACh/GUc+nMxYjSZlnc/IKDF0lGrOhQdsdjasxc9daJ0HQOY\n\t\t\t\t\t\tBXcJkFQO1m4uztNXPu/3JLYSzpLgKVY9W/24fyd9zpsPrG4xHl3D08jUovDvnENc\n\t\t\t\t\t\t+q0gyt5TwRt28hifF9kdV+zdyTYQvKi4uOimqzt9wjSbv9xhvNa5VElt7GbiAZRE\n\t\t\t\t\t\tOGUAj4gEbQbBhU4TLJN84h9jAgMBAAGjNjA0MBMGA1UdEQQMMAqCCG1uZW1lbnRo\n\t\t\t\t\t\tMB0GA1UdDgQWBBQjLNqsyE3DpyRHamNjGNFPfpd5qTANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAGkihtfVr4oVSzPreJwViJnqosAxrnTg2rEwvTnp02Es6Vaam5M995JQkWS8x\n\t\t\t\t\t\tvQAwCywoccsRuk02LOZ7bhP7IExPYSmzSJ3bIbXYxTJ5+36ELmxS0dETZq69c0QT\n\t\t\t\t\t\tXja0CXAviE3TjK3VLvemSaJWJlssPB3dGIHhJ1oulB7mG1F1gj6MY8FHtjgsjJ2k\n\t\t\t\t\t\tjKWUyCTonkcj/j22UdaMzsBb0vOtRoDBlhtEyppm06VQFQpizV2XyH/de8R1mrNK\n\t\t\t\t\t\tm2tWL3l+kX0MHJVAQ7i6iSXhiXCX1/ATGEPniV71u9gRMd/FQBJo9D5jTOHUpNzA\n\t\t\t\t\t\tdvLRXByBJtURFonOb55G90gyqg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mnementh.csi.cam.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mnementh.csi.cam.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mnementh.csi.cam.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mnementh.csi.cam.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mnementh.csi.cam.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://mnementh.csi.cam.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mnementh.csi.cam.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://mnementh.csi.cam.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://mnementh.csi.cam.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://mnementh.csi.cam.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.telecom-lille1.eu/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Landru"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jacques.landru@telecom-lille1.eu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sion"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "martine.sion@telecom-lille1.eu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.telecom-lille1.eu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-12-04T10:53:26Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.telecom-lille1.eu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.telecom-lille1.eu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.telecom-lille1.eu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "telecom-lille1.eu"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.telecom-lille.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Telecom Lille1"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Telecom Lille1"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUJLHfF/BYKnVTAfbCyG7p6neXmikwDQYJKoZIhvcNAQEF\nBQAwIDEeMBwGA1UEAxMVaWRwLnRlbGVjb20tbGlsbGUxLmV1MB4XDTA5MTAxMzEy\nNTE1NVoXDTI5MTAxMzEyNTE1NVowIDEeMBwGA1UEAxMVaWRwLnRlbGVjb20tbGls\nbGUxLmV1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAke9f/k5yNntZ\nmKHJse2R1dALp2yQ431GM7WgcwLz61E10KQFp4QvHcRnOA28aQ2ftOdDYXF8Ce/g\nl/f/gzmfLI3UkV33VQnu7wTUcG7qnA4ixmSz1wXshiBNiCqy+DlvzxxFa1rrrhTK\nDCGNxJEsNcT42xnnoL739jJt7hhwOzNTR6jd+PtnkBBJkULj0JNU3lgVVLaic61Z\n2sqqbp976AE81I5Peu/uNwBEQEze3JZFq4lPMftIT1qCrpZueUzZJe/IaB8gckur\nU+ts8Qk7X6LaWA9rHLz3M1cS5I/nFgxX5BzNTpJac8YEFl4rN0j8VVNKMuQ8NPoz\nlMSlVexERQIDAQABo3EwbzBOBgNVHREERzBFghVpZHAudGVsZWNvbS1saWxsZTEu\nZXWGLGh0dHBzOi8vaWRwLnRlbGVjb20tbGlsbGUxLmV1L2lkcC9zaGliYm9sZXRo\nMB0GA1UdDgQWBBRIcbHtrFzmqsjXU8/WEtUyCjUm+DANBgkqhkiG9w0BAQUFAAOC\nAQEAfeUGRk0BupcoO20DeNRmBokqCZn0N7n5mmco4eJWjl4CD0dvxcNmTHmO9nYS\nFPVBNASEjmnaU12RSAIM0mVnLwo6kXAQsbKa2xKGL6l3jkmsvcEj8F1Dg5e0QGBe\neSdYLGI2mGbAoIQWeK3majTQXZ+UyzVXKjzJ2JCk96MvEwKODd4HGX+Z8eMRE/0A\nSoP9I+z1FYAuXjOeKazq+UY3jbiSx/UDBAA0g7FHkzJRaFiws0BZiiOkqPMHLGlB\ncjxHOjLM8xkrkI3+w28uv1nrNWH82728WeyMt5PWqVTyKg8SjPViZWusJF0KUkS/\n/jKovrhBMghl87+BWkzQTRzSyw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Telecom Lille1"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.telecom-lille.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Telecom Lille1"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://saml.adu.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "saml.tech@my.adu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "saml.admin@my.adu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Administrative Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "webmaster@adu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Information Technology"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://saml.adu.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://saml.adu.edu/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://saml.adu.edu/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "adu.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://my.adu.edu/university-services/information-technology/incommon-pop"
                  }
                ],
                "logo": [
                  {
                    "text": "https://saml.adu.edu/simplesaml/module.php/themeADU/logo.png",
                    "lang": "en",
                    "height": "204",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "600"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.adu.edu/privacy-policy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Adventist University of Health Sciences"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGDTCCA/WgAwIBAgIBATANBgkqhkiG9w0BAQUFADCBjjEwMC4GA1UEChMnQWR2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\nv37iXkv+oRVPop1y3YlvtgI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Adventist University of Health Sciences"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://adu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Adventist University of Health Sciences"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://webapp-utv.ita.mdh.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://webapp-utv.ita.mdh.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://webapp-utv.ita.mdh.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://webapp-utv.ita.mdh.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webapp-utv.ita.mdh.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://webapp-utv.ita.mdh.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://webapp-utv.ita.mdh.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://webapp-utv.ita.mdh.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.mdh.se/student/service/studentportalen-1.260?l=sv_SE"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.mdh.se/student/service/studentportalen-1.260?l=en_UK"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Denna applikation anv\u00e4nds f\u00f6r att testregistrera sig p\u00e5 kurs p\u00e5 MDH."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service is used for test registering at course at MDH."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.mdh.se/gemensamt/webbplatsen/juridisk-information-1.205?l=sv_SE"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.mdh.se/gemensamt/webbplatsen/juridisk-information-1.205?l=en_UK"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Utveckling av Studentportal MDH"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Development of Student portal MDH"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "v-bus.ita.mdh.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7zCCAdegAwIBAgIBADANBgkqhkiG9w0BAQUFADAbMRkwFwYDVQQDExB2LWJ1\ncy5pdGEubWRoLnNlMB4XDTEwMDcwMTEwMDI0MFoXDTIwMDYyODEwMDI0MFowGzEZ\nMBcGA1UEAxMQdi1idXMuaXRhLm1kaC5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAM0c4T2DWUsZAVs1kTwviQb6nzXgkRHUlb9Rc5gK+AM7sP2cWscY\n6lsBqnnJqnKRxQ2gnu6fEWr/g3rTZSeR/L4vxPCP99tbgULTvvb0/TiotyTABPrj\nv1JF2uCMsOP1qn7upLp5mRLQq+fcW2w/D+RlihYPkoS4Up1go7/JO5ClFeIzdAQ0\nixPDBjMxqF/DVQ9m7G9RysOgZLWlnR3CTHhxQG9mLXopkqBGM5xRqSLVghLUu4lV\nwcpAmu54gOG/b93D9ue9P+JlLLxkYxZ9wLFQcnceY+WA90Me+AwZ0goieTicSVC/\n2jg3RsQDOu2XFFc3sPnIYpR+0KYEO4F0pCMCAwEAAaM+MDwwGwYDVR0RBBQwEoIQ\ndi1idXMuaXRhLm1kaC5zZTAdBgNVHQ4EFgQUwhL0egDc1L7Y/HR/EPW7ISIJkFkw\nDQYJKoZIhvcNAQEFBQADggEBACr96wsmELGnAT1EnTmePCh+oFR1j8GnTp/9CRUK\n4bhyBGBxKSTbYo0xHNT5sadC7XkeJpSzFkMprvM1kyZSS07SGlpluRqFsqTY5fzy\nsJ38nAdmdPApSkQpAvSwahi8G0ypVc3YOntoXE8jUaN5CjdRk3iAfNrNVD4BW9PM\nPOXR8OXczDAkW9TEEPTf0ssyTmGmeHReH8wz2LmjXD33B8jEXAl/+03ANlGaptw9\nOH42t1fxzvwRrnUXZv8WyUQrrzjHTcs5+SbfqaVlewI8KRHTNC4XUefcGULgC1rK\np4Dxx1fOE+4Z6F1w818nIPfOIFisdZ0n+f4Qt3oL1+WqEsM="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=v-bus.ita.mdh.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "v-bus.ita.mdh.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7zCCAdegAwIBAgIBADANBgkqhkiG9w0BAQUFADAbMRkwFwYDVQQDExB2LWJ1\ncy5pdGEubWRoLnNlMB4XDTEwMDcwMTEwMDI0MFoXDTIwMDYyODEwMDI0MFowGzEZ\nMBcGA1UEAxMQdi1idXMuaXRhLm1kaC5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAM0c4T2DWUsZAVs1kTwviQb6nzXgkRHUlb9Rc5gK+AM7sP2cWscY\n6lsBqnnJqnKRxQ2gnu6fEWr/g3rTZSeR/L4vxPCP99tbgULTvvb0/TiotyTABPrj\nv1JF2uCMsOP1qn7upLp5mRLQq+fcW2w/D+RlihYPkoS4Up1go7/JO5ClFeIzdAQ0\nixPDBjMxqF/DVQ9m7G9RysOgZLWlnR3CTHhxQG9mLXopkqBGM5xRqSLVghLUu4lV\nwcpAmu54gOG/b93D9ue9P+JlLLxkYxZ9wLFQcnceY+WA90Me+AwZ0goieTicSVC/\n2jg3RsQDOu2XFFc3sPnIYpR+0KYEO4F0pCMCAwEAAaM+MDwwGwYDVR0RBBQwEoIQ\ndi1idXMuaXRhLm1kaC5zZTAdBgNVHQ4EFgQUwhL0egDc1L7Y/HR/EPW7ISIJkFkw\nDQYJKoZIhvcNAQEFBQADggEBACr96wsmELGnAT1EnTmePCh+oFR1j8GnTp/9CRUK\n4bhyBGBxKSTbYo0xHNT5sadC7XkeJpSzFkMprvM1kyZSS07SGlpluRqFsqTY5fzy\nsJ38nAdmdPApSkQpAvSwahi8G0ypVc3YOntoXE8jUaN5CjdRk3iAfNrNVD4BW9PM\nPOXR8OXczDAkW9TEEPTf0ssyTmGmeHReH8wz2LmjXD33B8jEXAl/+03ANlGaptw9\nOH42t1fxzvwRrnUXZv8WyUQrrzjHTcs5+SbfqaVlewI8KRHTNC4XUefcGULgC1rK\np4Dxx1fOE+4Z6F1w818nIPfOIFisdZ0n+f4Qt3oL1+WqEsM="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=v-bus.ita.mdh.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://webapp-utv.ita.mdh.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://webapp-utv.ita.mdh.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webapp-utv.ita.mdh.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://webapp-utv.ita.mdh.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webapp-utv.ita.mdh.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://webapp-utv.ita.mdh.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://webapp-utv.ita.mdh.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://webapp-utv.ita.mdh.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://webapp-utv.ita.mdh.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://webapp-utv.ita.mdh.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://umdac-utv1.ad.umu.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://umdac-utv1.ad.umu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://umdac-utv1.ad.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://umdac-utv1.ad.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://umdac-utv1.ad.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://umdac-utv1.ad.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://umdac-utv1.ad.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://umdac-utv1.ad.umu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://umdac-utv1.ad.umu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "En samling av verktyg och tj\u00e4nster f\u00f6r studenter och anst\u00e4llda vid Ume\u00e5 universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "A collection of tools and services for students and staff at Ume\u00e5 University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "QA-milj\u00f6 f\u00f6r ServiceDesk"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "QA-environment for ServiceDesk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "Tommy Larsson"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEnjCCA4agAwIBAgIJAJEv/JM5LIg2MA0GCSqGSIb3DQEBBQUAMIGQMQswCQYD\nVQQGEwJTRTEVMBMGA1UECBMMVmFzdGVyYm90dGVuMQ0wCwYDVQQHEwRVbWVhMQww\nCgYDVQQKEwNJVFMxDDAKBgNVBAsTA0lUUzEWMBQGA1UEAxMNVG9tbXkgTGFyc3Nv\nbjEnMCUGCSqGSIb3DQEJARYYdG9tbXkubGFyc3NvbkBhZG0udW11LnNlMB4XDTEx\nMDEyNzA4NDcyOVoXDTEzMTIxMDA4NDcyOVowgZAxCzAJBgNVBAYTAlNFMRUwEwYD\nVQQIEwxWYXN0ZXJib3R0ZW4xDTALBgNVBAcTBFVtZWExDDAKBgNVBAoTA0lUUzEM\nMAoGA1UECxMDSVRTMRYwFAYDVQQDEw1Ub21teSBMYXJzc29uMScwJQYJKoZIhvcN\nAQkBFhh0b21teS5sYXJzc29uQGFkbS51bXUuc2UwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDsxGkZlSQiqzNG33NY9U+7skx7LQSXB/6tjjbkM/VjDqfa\nKNd1uWJuP6NWgoOD3vAlCljL3EuBWMKysyDiJBi8BS02/YT2IBRuXxQ7VK5tvE3/\nGwKH2j/nTPTlpevfcQuv+5Rpwde6fpMsm/rZmoaEWdBhLSuvzY4HJHRa+qGJlJoh\nylaQsQjj8smh+6+pNgYNQH/g3FSuf7/xwSmpIdjy84HYtuV8Bi+bx6OU0/NC3oyH\nYaxZj0TTk96929pSO5jIgwQQ91Jws8rh5wxHy7ZAQrxSni8sxst6euqH0LCmFI6b\njjxBclg6VvB1zCNsMRHakiUNJwNMDdpeWuhAcEVVAgMBAAGjgfgwgfUwHQYDVR0O\nBBYEFEBdLsnYxFEP+hBIqHEyx/8IDMIJMIHFBgNVHSMEgb0wgbqAFEBdLsnYxFEP\n+hBIqHEyx/8IDMIJoYGWpIGTMIGQMQswCQYDVQQGEwJTRTEVMBMGA1UECBMMVmFz\ndGVyYm90dGVuMQ0wCwYDVQQHEwRVbWVhMQwwCgYDVQQKEwNJVFMxDDAKBgNVBAsT\nA0lUUzEWMBQGA1UEAxMNVG9tbXkgTGFyc3NvbjEnMCUGCSqGSIb3DQEJARYYdG9t\nbXkubGFyc3NvbkBhZG0udW11LnNlggkAkS/8kzksiDYwDAYDVR0TBAUwAwEB/zAN\nBgkqhkiG9w0BAQUFAAOCAQEAV7YyyId9u6p0X6EVdYYgJRw3YgPeT/7KQAXrM5Fd\n+0ZloD6py7JKk6MjKSJKPh7dcfxubJZWpPpv4tvLlxVh5d8h1ke8B9Pll/SOkF7m\nT6an+GTWbWfB3C5w2LbiuwdHvydvJgM61f8437rF9s22MYeSStuhsnzT8KlUg6OV\nrzavOVnYMhei94uDmHesTRdB1GlO7Gut34C8V9L9CysEj6ezjPaeUTw/1+oP81SS\nwlEG2Ix+o0k2AGIkAww8dfmdCG6TSWJ7ovpvHeNgC9BoGrANqmLDG/tFlx6CZxtp\nNwnL2DNdxAIqK+BGt+Q0XVGJGEfnh/8XuYwTn2MNoJcxSQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=tommy.larsson@adm.umu.se,CN=Tommy Larsson,OU=ITS,O=ITS,L=Umea,ST=Vasterbotten,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://umdac-utv1.ad.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://umdac-utv1.ad.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://umdac-utv1.ad.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://umdac-utv1.ad.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://umdac-utv1.ad.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://umdac-utv1.ad.umu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://umdac-utv1.ad.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://umdac-utv1.ad.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://umdac-utv1.ad.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://umdac-utv1.ad.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.cnous.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Christian Muller"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "christian.muller@cnous.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jos\u00e9 tripet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jose.tripet@cnous.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cnous.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-05-11T16:41:00Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cnous.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cnous.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.cnous.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cnous.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.cnous.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CNOUS"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CNOUS"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAISouLAcDEdM79Z0SpsLrgjU/8rtMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDGlkcC5jbm91cy5mcjAeFw0xMjA1MDMxNTU4NTVaFw0z\nMjA1MDMxNTU4NTVaMBcxFTATBgNVBAMTDGlkcC5jbm91cy5mcjCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALl+NBrwCB2xYd0y4dbi3QADG3oBYfNLiGJw\nrajvTmKUZaTKrQvgjtesfvM04pSOoMwRjkaG2ae3Pp/5fsuYc83zaOakgWSgc5/j\nzZfJOaxk+RGBofTInmWwgoCqDHGZ4WHLYphzwlLnV8VH6Ca7qa5bR+uEsZeLpICw\nC7d22rk2+llioeyFhwPMQBT9IRydChqGr79B7t1iT7ssTHP9v1ZDgtIB29+gkP4S\nYdzA11oZOJzeaGZXl0h9QsUBBnn6cyUgYE0SEgxBMl6+qlmQAuwrWO24pungPYx3\nC1k0i8xuFF3+98we5US4mQkRitgm0JVvB4pn6TtkgG+RTV+/uz8CAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMaWRwLmNub3VzLmZyhiNodHRwczovL2lkcC5jbm91cy5mci9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUPLiOl86NYkKW2Dz3T05kKwEcuCQwDQYJ\nKoZIhvcNAQEFBQADggEBAA9/88dlu6RIXF2MsXqLOFguSQcRXyjUe7qRbneRLhk7\n3m5pH/AKRWpgfWPllLy1ui8ZgJ3upJg8NDF9pipAXGm9XXUlYwgO/bD91o591iw+\nffKTKQATF1SxMVKBwNtUOdR7HUaHNgz38w5DNd5DE0ZEAatVFsCbJdYG1WKgFPhU\nHB02bxkRdxUUgdWRL7WuldON2M3vefzJYqYd+Pu5+gP8I6HvgiLXvySmGroTnb2f\nRC6L4jwyDgp7R4rULrUz94moM+7O7Y95uDRxszNoDpFdKdcwD2yjYhBUrV6dPHHy\ngMoijoNgZZc/CqICHEnTC2xx4c9HR/114ON1vrxiYR4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CNOUS"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cnous.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CNOUS"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://acesso.ufabc.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Leonardo Monteiro Bersan de Araujo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "contato.cafe@ufabc.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://acesso.ufabc.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEMDCCAxgCAQAwDQYJKoZIhvcNAQEFBQAwgd0xLDAqBgNVBAoTI1VGQUJDIC0g\n\t\t\t\tVW5pdmVyc2lkYWRlIEZlZGVyYWwgZG8gQUJDMTEwLwYDVQQLEyhOVEkgLSBOdWNs\n\t\t\t\tZW8gZGUgVGVjbm9sb2dpYSBkYSBJbmZvcm1hY2FvMSUwIwYJKoZIhvcNAQkBFhZ3\n\t\t\t\tZWJtYXN0ZXJAdWZhYmMuZWR1LmJyMRQwEgYDVQQHEwtTYW50byBBbmRyZTESMBAG\n\t\t\t\tA1UECBMJU2FvIFBhdWxvMQswCQYDVQQGEwJCUjEcMBoGA1UEAxMTYWNlc3NvLnVm\n\t\t\t\tYWJjLmVkdS5icjAeFw0xNDEwMDYyMDAyMDFaFw0xNzEwMDUyMDAyMDFaMIHdMSww\n\t\t\t\tKgYDVQQKEyNVRkFCQyAtIFVuaXZlcnNpZGFkZSBGZWRlcmFsIGRvIEFCQzExMC8G\n\t\t\t\tA1UECxMoTlRJIC0gTnVjbGVvIGRlIFRlY25vbG9naWEgZGEgSW5mb3JtYWNhbzEl\n\t\t\t\tMCMGCSqGSIb3DQEJARYWd2VibWFzdGVyQHVmYWJjLmVkdS5icjEUMBIGA1UEBxML\n\t\t\t\tU2FudG8gQW5kcmUxEjAQBgNVBAgTCVNhbyBQYXVsbzELMAkGA1UEBhMCQlIxHDAa\n\t\t\t\tBgNVBAMTE2FjZXNzby51ZmFiYy5lZHUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\n\t\t\t\tDwAwggEKAoIBAQC6mGtdNAUQx0I9sNxQdovn7t0/2USXnGKkw3kE9SOuyxq2b4/w\n\t\t\t\t1F70EfFTDLi14Tu1U2GdaWhv1CksPhYF/MrmX5bdv2oykorrS+VTloxiVA/qWIPa\n\t\t\t\tVdfHWSyLLa28kpQs39RtRVl1WgZ2acKYO48d0rWzm0NrRJ3gnm8W33d3VcDmQImQ\n\t\t\t\t0/8HFYlF4SgAvOg5Pdywr8beFrNlSO2oZitc7turdF8cs2FoqHJ1Zb0hwDHbDTyp\n\t\t\t\tD0cZoITbAdo3/JqYXM5eRh43Phvt/VjSuQy/haU3DbEfa5JMOsjad2k3WltaMluy\n\t\t\t\t3FpD5sQAWqHzAXprcI3tkywJZkMbD/0BU3RTAgMBAAEwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\tggEBAJzEMvntE4fOAoqO18wZUhi7g1HZmHAzTtWLH+5YrvlcOIGRgEqe7g0j9eqU\n\t\t\t\tz0Rm98+7LEwaCF+VshS125JNDmAjk2nbOUsJQ1GwtVo/hPrAsI9TZKkMftOqi+ga\n\t\t\t\tzi2xUzSvhtE52kUIPm35PLVzKNDAQKGMgdQfcexhBjzBX7Ozt5h7hPaOutpR71t3\n\t\t\t\teTCiukdeCPU6k4+MzuUR1wAXBZUAqo+BOcrZE8/7YgGsUykaPS1YJyturDhgfq4U\n\t\t\t\tV7x6Y5Rikv9YMJX2is1jMz31f8AOiDDliT7qLpmuhFX5Ub1TJiXuT3qfExNTh7Dj\n\t\t\t\t9r2+SoV9gdVYdUvQjPmDt3ebeiM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://acesso.ufabc.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://acesso.ufabc.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://acesso.ufabc.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://acesso.ufabc.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://acesso.ufabc.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://acesso.ufabc.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://acesso.ufabc.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://acesso.ufabc.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufabc.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufabc.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFABC - Universidade Federal do ABC"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFABC - Universidade Federal do ABC"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFABC - Universidade Federal do ABC"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFABC - Universidade Federal do ABC"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEMDCCAxgCAQAwDQYJKoZIhvcNAQEFBQAwgd0xLDAqBgNVBAoTI1VGQUJDIC0g\n\t\t\t\tVW5pdmVyc2lkYWRlIEZlZGVyYWwgZG8gQUJDMTEwLwYDVQQLEyhOVEkgLSBOdWNs\n\t\t\t\tZW8gZGUgVGVjbm9sb2dpYSBkYSBJbmZvcm1hY2FvMSUwIwYJKoZIhvcNAQkBFhZ3\n\t\t\t\tZWJtYXN0ZXJAdWZhYmMuZWR1LmJyMRQwEgYDVQQHEwtTYW50byBBbmRyZTESMBAG\n\t\t\t\tA1UECBMJU2FvIFBhdWxvMQswCQYDVQQGEwJCUjEcMBoGA1UEAxMTYWNlc3NvLnVm\n\t\t\t\tYWJjLmVkdS5icjAeFw0xNDEwMDYyMDAyMDFaFw0xNzEwMDUyMDAyMDFaMIHdMSww\n\t\t\t\tKgYDVQQKEyNVRkFCQyAtIFVuaXZlcnNpZGFkZSBGZWRlcmFsIGRvIEFCQzExMC8G\n\t\t\t\tA1UECxMoTlRJIC0gTnVjbGVvIGRlIFRlY25vbG9naWEgZGEgSW5mb3JtYWNhbzEl\n\t\t\t\tMCMGCSqGSIb3DQEJARYWd2VibWFzdGVyQHVmYWJjLmVkdS5icjEUMBIGA1UEBxML\n\t\t\t\tU2FudG8gQW5kcmUxEjAQBgNVBAgTCVNhbyBQYXVsbzELMAkGA1UEBhMCQlIxHDAa\n\t\t\t\tBgNVBAMTE2FjZXNzby51ZmFiYy5lZHUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\n\t\t\t\tDwAwggEKAoIBAQC6mGtdNAUQx0I9sNxQdovn7t0/2USXnGKkw3kE9SOuyxq2b4/w\n\t\t\t\t1F70EfFTDLi14Tu1U2GdaWhv1CksPhYF/MrmX5bdv2oykorrS+VTloxiVA/qWIPa\n\t\t\t\tVdfHWSyLLa28kpQs39RtRVl1WgZ2acKYO48d0rWzm0NrRJ3gnm8W33d3VcDmQImQ\n\t\t\t\t0/8HFYlF4SgAvOg5Pdywr8beFrNlSO2oZitc7turdF8cs2FoqHJ1Zb0hwDHbDTyp\n\t\t\t\tD0cZoITbAdo3/JqYXM5eRh43Phvt/VjSuQy/haU3DbEfa5JMOsjad2k3WltaMluy\n\t\t\t\t3FpD5sQAWqHzAXprcI3tkywJZkMbD/0BU3RTAgMBAAEwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\tggEBAJzEMvntE4fOAoqO18wZUhi7g1HZmHAzTtWLH+5YrvlcOIGRgEqe7g0j9eqU\n\t\t\t\tz0Rm98+7LEwaCF+VshS125JNDmAjk2nbOUsJQ1GwtVo/hPrAsI9TZKkMftOqi+ga\n\t\t\t\tzi2xUzSvhtE52kUIPm35PLVzKNDAQKGMgdQfcexhBjzBX7Ozt5h7hPaOutpR71t3\n\t\t\t\teTCiukdeCPU6k4+MzuUR1wAXBZUAqo+BOcrZE8/7YgGsUykaPS1YJyturDhgfq4U\n\t\t\t\tV7x6Y5Rikv9YMJX2is1jMz31f8AOiDDliT7qLpmuhFX5Ub1TJiXuT3qfExNTh7Dj\n\t\t\t\t9r2+SoV9gdVYdUvQjPmDt3ebeiM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFABC - Universidade Federal do ABC"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFABC - Universidade Federal do ABC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufabc.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufabc.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFABC - Universidade Federal do ABC"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFABC - Universidade Federal do ABC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.mbu.cas.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Van\u00ed\u010dek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vanicekp@utia.cas.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.mbu.cas.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2014-09-08T13:24:31Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/avcr"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUYdcHhLDHNl2QZ3A36tC8tB4N+0YwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOaWRwLm1idS5jYXMuY3owHhcNMTQwNTA5MDk0ODE3WhcN\nMzQwNTA5MDk0ODE3WjAZMRcwFQYDVQQDEw5pZHAubWJ1LmNhcy5jejCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKvELL+7e19R7w9WNnuLbvd9MI9Y6emS\n0o4NDUddY65/SqZeeNaTqsdCQO8htLIIvzwm2vh9geeNEVwpRejz1N1kzcVLIpxa\n9udowrfSKKAuavwFiSYyrznKAtD2/G00U+Ity4Mi6IjxpdNocIQgSfaD/cVOvg3k\nQw2B0jOSYdEAu0nG8I6LlUp9T6aSI7jqUDcAIAB6CMOxGL6/+GwEuPYMNBxGrAAZ\npWPGUO4mBaK0eVrMyq++fImM5yab6B42nfe4RvA9C2Lt50OgvOia8LKRjtVGaATI\nDUOOiX2B5sWVYAHFfsXCFuS9CjjYMxMMT5t5A1guNOhd86rPCayVfJ0CAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOaWRwLm1idS5jYXMuY3qGJWh0dHBzOi8vaWRwLm1idS5j\nYXMuY3ovaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFA/LgQ/gox/xI5+K8hQ6Nrq5\ny0R3MA0GCSqGSIb3DQEBBQUAA4IBAQAxf9HYNhASVDz1dbW/OMXd7mtFoxk7v5bP\nJgXz3W7kW8HyERpcssEbJhB1mmrWTnM/5qiPf6OuBQ7Loa3Wtthx7tei2bXXBwKb\nRE5DK04UiRufSq8G6yioadxyMG4lpt+mSSkyYDdP+4DnBgJcrPLORCpkcZaFvZWy\nrgr4jGpkpj7QnuJR5O/mUpLZSxEqspE7TWOgFFWhWfddhKRiThLI/KLysYWaFBOp\nFTr/8tfzH95qtEgw+8NoX7xWbKp42mN27+MCYLdK+gS6RqIv4i+KnDyNO2gYssjq\neL/EaqTf+uStC8AdxobBI9SwoXW5JUfxiorsYdYvY8cX9JxnJLbA"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mbu.cas.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.mbu.cas.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.mbu.cas.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.mbu.cas.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.mbu.cas.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.mbu.cas.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.mbu.cas.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.mbu.cas.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.mbu.cas.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.mbu.cas.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.mbu.cas.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.mbu.cas.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mbu.cas.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mbu.cas.cz/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mbu.cas.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider IMIC AV CR employees."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance MB\u016e AV \u010cR"
                  }
                ],
                "logo": [
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-mbu-44.png",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  },
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-mbu-100.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "137"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Microbiology AS CR"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mikrobiologick\u00fd \u00fastav AV \u010cR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUYdcHhLDHNl2QZ3A36tC8tB4N+0YwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOaWRwLm1idS5jYXMuY3owHhcNMTQwNTA5MDk0ODE3WhcN\nMzQwNTA5MDk0ODE3WjAZMRcwFQYDVQQDEw5pZHAubWJ1LmNhcy5jejCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKvELL+7e19R7w9WNnuLbvd9MI9Y6emS\n0o4NDUddY65/SqZeeNaTqsdCQO8htLIIvzwm2vh9geeNEVwpRejz1N1kzcVLIpxa\n9udowrfSKKAuavwFiSYyrznKAtD2/G00U+Ity4Mi6IjxpdNocIQgSfaD/cVOvg3k\nQw2B0jOSYdEAu0nG8I6LlUp9T6aSI7jqUDcAIAB6CMOxGL6/+GwEuPYMNBxGrAAZ\npWPGUO4mBaK0eVrMyq++fImM5yab6B42nfe4RvA9C2Lt50OgvOia8LKRjtVGaATI\nDUOOiX2B5sWVYAHFfsXCFuS9CjjYMxMMT5t5A1guNOhd86rPCayVfJ0CAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOaWRwLm1idS5jYXMuY3qGJWh0dHBzOi8vaWRwLm1idS5j\nYXMuY3ovaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFA/LgQ/gox/xI5+K8hQ6Nrq5\ny0R3MA0GCSqGSIb3DQEBBQUAA4IBAQAxf9HYNhASVDz1dbW/OMXd7mtFoxk7v5bP\nJgXz3W7kW8HyERpcssEbJhB1mmrWTnM/5qiPf6OuBQ7Loa3Wtthx7tei2bXXBwKb\nRE5DK04UiRufSq8G6yioadxyMG4lpt+mSSkyYDdP+4DnBgJcrPLORCpkcZaFvZWy\nrgr4jGpkpj7QnuJR5O/mUpLZSxEqspE7TWOgFFWhWfddhKRiThLI/KLysYWaFBOp\nFTr/8tfzH95qtEgw+8NoX7xWbKp42mN27+MCYLdK+gS6RqIv4i+KnDyNO2gYssjq\neL/EaqTf+uStC8AdxobBI9SwoXW5JUfxiorsYdYvY8cX9JxnJLbA"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Microbiology  AS CR, v.v.i."
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mikrobiologick\u00fd \u00fastav AV \u010cR, v.v.i."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mbu.cas.cz/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mbu.cas.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Microbiology  AS CR"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Mikrobiologick\u00fd \u00fastav AV \u010cR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://eu01.alma.exlibrisgroup.com/mng/login",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Benoit.Ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Benoit.Ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://eu01.alma.exlibrisgroup.com/mng/login",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-11-18T14:42:51Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ex Libris Alma EU01 - The Next-Generation Library Services Framework"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://exlibrisgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ex Libris (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEUDCCArigAwIBAgIEUWQ+bzANBgkqhkiG9w0BAQUFADBqMQswCQYDVQQGEwJJ\n\t\t\t\t\t\tTDESMBAGA1UECBMJSmVydXNhbGVtMRIwEAYDVQQHEwlKZXJ1c2FsZW0xETAPBgNV\n\t\t\t\t\t\tBAoTCEV4bGlicmlzMQ0wCwYDVQQLEwRBbG1hMREwDwYDVQQDEwhTQU1MIEpLUzAe\n\t\t\t\t\t\tFw0xMzA0MDkxNjE0MzlaFw0yMzA0MDcxNjE0MzlaMGoxCzAJBgNVBAYTAklMMRIw\n\t\t\t\t\t\tEAYDVQQIEwlKZXJ1c2FsZW0xEjAQBgNVBAcTCUplcnVzYWxlbTERMA8GA1UEChMI\n\t\t\t\t\t\tRXhsaWJyaXMxDTALBgNVBAsTBEFsbWExETAPBgNVBAMTCFNBTUwgSktTMIIBojAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQEFAAOCAY8AMIIBigKCAYEAkZEP11/7z1BnlfvByEfwmvkEeWdS\n\t\t\t\t\t\t4h0500whQeaSyLAeIQLnBvv0AL+yrnHUCQhdXtuKcB2KP1hHkORujT/AoyX5KaV6\n\t\t\t\t\t\tiO+afUWdMfePg6nHRXhg/Efpkg4pzq1suDRNlY36nloFU39LHMTDOm6fc6cli5/h\n\t\t\t\t\t\tv0mSgEI3rwTQRYKxe3gt7Yx2HCnyehxdEMYxxLgTUst+fnDvlJ8XSeLcIgwMe8S6\n\t\t\t\t\t\t5tDQJDxCSumDG9gLv4mHIeIWKbAaX3boeDKXM0cj7k1MA0ppDjXZiYeTeM11c3A9\n\t\t\t\t\t\tYNHnosQPN03vKl2Z38Qtg5wBJfGKxbI9mmO517iLpZWw0ppnW0VuxOuzUoIRRgM8\n\t\t\t\t\t\tH9Ic4MdrHrOBpdkjTdiC5P6Dy9CvPsKAf53L2olwlWtv0fAljQ1Zd7tABvUjzOHD\n\t\t\t\t\t\tI+oGLmP5JKt42Pr1xQtA3HEm6Gdi7CMclBAFqOb//xt9fmCh6o8Elxr4p70qU48S\n\t\t\t\t\t\thZAXj5G1oykPWWL0Z9/Jf106wQ4fK5ePxhapAgMBAAEwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggGBAIfkCOJbJuchcJJOQVa1Ryw6T5MDdOS81uZW8MyFRlBI9bB0CfcM0BcddzFs\n\t\t\t\t\t\tWAGslqQra8XWpTQXUrkyY+Uqt5pM1fIupPciVoeCJcK899u+5RM5D6gP5HpC/yc3\n\t\t\t\t\t\tIKyHg91SiGq3nUynaMsRUgGPHZ5rjsXoFg+wYbfT6fDcO+ca4y8OI/mrGczTRjWb\n\t\t\t\t\t\tWWDkVX4RzUZgk8DqwTMytfOdUzhml7qKfdoJyP7+ScfhEkwri1ZinIJ+Drn7lQdw\n\t\t\t\t\t\txCofIkXeJ/2llGWekavHYf+wCINX2m7zrsl7u0pBdbvOrqB54xJ9Jd03tKlyFs7k\n\t\t\t\t\t\t87lAj02qwCOxkOQ1PmbzjBji8NOq05yfUEHzKG/l3mPfj25HTLqLQ8M8Qs87S/H/\n\t\t\t\t\t\t2lA7QhxVaWc0V7kPWo1yIE0KYVnXbHy4Hw2on+dcwH7wPLItCneryp8rM1WRSE+X\n\t\t\t\t\t\ts7Q3F7NVAvvfPrcXUfxw67jc3NQEGPGESn2ZCdcD8SQNPBymdG0572nebb4AhmBR\n\t\t\t\t\t\t2PN4Eg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://eu01.alma.exlibrisgroup.com/mng/pdsHandleLogin",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://idp.dunstable.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.dunstable.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/dunstable.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/dunstable.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dunstable.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Central Bedfordshire College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dunstable.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp-dev.sussex.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lewney"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:d.m.lewney@sussex.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dave"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lewney"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:d.m.lewney@sussex.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dave"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-dev.sussex.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUaXHTQJ0iHL7M96NNUnD8cG38agowDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAxMUaWRwLWRldi5zdXNzZXguYWMudWswHhcNMTMwODAyMTMy\n\t\t\t\t\t\tMjI3WhcNMzMwODAyMTMyMjI3WjAfMR0wGwYDVQQDExRpZHAtZGV2LnN1c3NleC5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIw2HMiV8nzFA8Af\n\t\t\t\t\t\tOW2WvgKdr/rsNxXTNhMFNH8dFKnUlBkz7SHAg9ikrDOrJYsZ+19o0B6eUFzO9O9j\n\t\t\t\t\t\t/weeCN6hSXp3Fm9PKrWx8atVR6mK3sBvN4UjwPy5SrArkvDeZddNYAiklIDo2VXg\n\t\t\t\t\t\tQt5C2/0uCfa7GnRwKYrN0Pr83V4w1XAOaY10PhV5au7q2kTtNJo1WZHHT6Kf4K5g\n\t\t\t\t\t\tfEEYG9P+9M7C846vqEkow5K57cz+/LDBTKJXeuCRNdWydnfn6leDFtCh2ZXviAYs\n\t\t\t\t\t\tFhug70+RxVSsJ0eZx5G31y3Z8GB8UfWjWF+a1fQy6vrgK4XZc9QxLc6urOMdmDfL\n\t\t\t\t\t\tNKzkbdECAwEAAaNvMG0wTAYDVR0RBEUwQ4IUaWRwLWRldi5zdXNzZXguYWMudWuG\n\t\t\t\t\t\tK2h0dHBzOi8vaWRwLWRldi5zdXNzZXguYWMudWsvaWRwL3NoaWJib2xldGgwHQYD\n\t\t\t\t\t\tVR0OBBYEFKuGMvjPXWBURM7ApWOBW81l8cfZMA0GCSqGSIb3DQEBBQUAA4IBAQAx\n\t\t\t\t\t\tXWbyQnOLcIsVg77HRr+FBRmkIv11efMGAdGx8N5S3RJ1T52QquHuizTKO0pldfzx\n\t\t\t\t\t\tuHPc1FoAW92dIdlaImZbss9BNFvdjQ+oDbjst32RpXmpBr703p4FbxTk30ceZhhd\n\t\t\t\t\t\tHLTr8pd9Ti2k9XNI+cAaSjCfwcXiJ0BVDDhs+tD6aLmnFPZZbab6Rd01acxmXn/H\n\t\t\t\t\t\tac+9/iJP8c3w50IarnevAh7/3Jpfxgrv8MilBzFuDu1VqR1mRvQqaI86FLYkxhgF\n\t\t\t\t\t\trWyVSAMwo1dTlw0V7i05upCRLj6pDHJwq8dX5iHO1Gt8JSFfY6aNdIz+kfVgM321\n\t\t\t\t\t\tYV5CgHdLYfAq+Bcvp9eq"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sussex.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-dev.sussex.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-dev.sussex.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-dev.sussex.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-dev.sussex.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-dev.sussex.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-dev.sussex.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-dev.sussex.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-dev.sussex.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Sussex (development)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.sussex.ac.uk/includes/images/external/logo.jpg",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "147"
                  },
                  {
                    "text": "https://www.sussex.ac.uk/includes/images/external/favicon.gif",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Sussex (development)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sussex.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUaXHTQJ0iHL7M96NNUnD8cG38agowDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAxMUaWRwLWRldi5zdXNzZXguYWMudWswHhcNMTMwODAyMTMy\n\t\t\t\t\t\tMjI3WhcNMzMwODAyMTMyMjI3WjAfMR0wGwYDVQQDExRpZHAtZGV2LnN1c3NleC5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIw2HMiV8nzFA8Af\n\t\t\t\t\t\tOW2WvgKdr/rsNxXTNhMFNH8dFKnUlBkz7SHAg9ikrDOrJYsZ+19o0B6eUFzO9O9j\n\t\t\t\t\t\t/weeCN6hSXp3Fm9PKrWx8atVR6mK3sBvN4UjwPy5SrArkvDeZddNYAiklIDo2VXg\n\t\t\t\t\t\tQt5C2/0uCfa7GnRwKYrN0Pr83V4w1XAOaY10PhV5au7q2kTtNJo1WZHHT6Kf4K5g\n\t\t\t\t\t\tfEEYG9P+9M7C846vqEkow5K57cz+/LDBTKJXeuCRNdWydnfn6leDFtCh2ZXviAYs\n\t\t\t\t\t\tFhug70+RxVSsJ0eZx5G31y3Z8GB8UfWjWF+a1fQy6vrgK4XZc9QxLc6urOMdmDfL\n\t\t\t\t\t\tNKzkbdECAwEAAaNvMG0wTAYDVR0RBEUwQ4IUaWRwLWRldi5zdXNzZXguYWMudWuG\n\t\t\t\t\t\tK2h0dHBzOi8vaWRwLWRldi5zdXNzZXguYWMudWsvaWRwL3NoaWJib2xldGgwHQYD\n\t\t\t\t\t\tVR0OBBYEFKuGMvjPXWBURM7ApWOBW81l8cfZMA0GCSqGSIb3DQEBBQUAA4IBAQAx\n\t\t\t\t\t\tXWbyQnOLcIsVg77HRr+FBRmkIv11efMGAdGx8N5S3RJ1T52QquHuizTKO0pldfzx\n\t\t\t\t\t\tuHPc1FoAW92dIdlaImZbss9BNFvdjQ+oDbjst32RpXmpBr703p4FbxTk30ceZhhd\n\t\t\t\t\t\tHLTr8pd9Ti2k9XNI+cAaSjCfwcXiJ0BVDDhs+tD6aLmnFPZZbab6Rd01acxmXn/H\n\t\t\t\t\t\tac+9/iJP8c3w50IarnevAh7/3Jpfxgrv8MilBzFuDu1VqR1mRvQqaI86FLYkxhgF\n\t\t\t\t\t\trWyVSAMwo1dTlw0V7i05upCRLj6pDHJwq8dX5iHO1Gt8JSFfY6aNdIz+kfVgM321\n\t\t\t\t\t\tYV5CgHdLYfAq+Bcvp9eq"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Sussex (development)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sussex.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Sussex"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.nottingham.edu.my/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itservicedesk@nottingham.edu.my"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itservicedesk@nottingham.edu.my"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.nottingham.edu.my/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-11-20T10:50:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0jCCAroCCQCeoFvQJDQiEjANBgkqhkiG9w0BAQUFADCBqjELMAkGA1UEBhMC\n\t\t\t\t\t\tbXkxETAPBgNVBAgTCFNlbGFuZ29yMREwDwYDVQQHEwhTZW1lbnlpaDE2MDQGA1UE\n\t\t\t\t\t\tChMtVGhlIFVuaXZlcnNpdHkgT2YgTm90dGluZ2hhbSBNYWxheXNpYSBDYW1wdXMg\n\t\t\t\t\t\tMR0wGwYDVQQLExRJbmZvcm1hdGlvbiBTZXJ2aWNlczEeMBwGA1UEAxMVaWRwLm5v\n\t\t\t\t\t\tdHRpbmdoYW0uZWR1Lm15MB4XDTEyMDMyMzE0MDIzMVoXDTIyMDMyMTE0MDIzMVow\n\t\t\t\t\t\tgaoxCzAJBgNVBAYTAm15MREwDwYDVQQIEwhTZWxhbmdvcjERMA8GA1UEBxMIU2Vt\n\t\t\t\t\t\tZW55aWgxNjA0BgNVBAoTLVRoZSBVbml2ZXJzaXR5IE9mIE5vdHRpbmdoYW0gTWFs\n\t\t\t\t\t\tYXlzaWEgQ2FtcHVzIDEdMBsGA1UECxMUSW5mb3JtYXRpb24gU2VydmljZXMxHjAc\n\t\t\t\t\t\tBgNVBAMTFWlkcC5ub3R0aW5naGFtLmVkdS5teTCCASIwDQYJKoZIhvcNAQEBBQAD\n\t\t\t\t\t\tggEPADCCAQoCggEBANt9uwt87a0uDUwXnCynAFOhpydrO0MzTlQiAxic8o4TY4yG\n\t\t\t\t\t\tIjBb50cMlOkyseJY5I3qN6fFKmWYiAEQtNeiH0PB2h/tgF8M65aHirnW1Z7zjZYK\n\t\t\t\t\t\tYHUTntVrL9WCJNg7UJoE2alh7Tn0irWPL4JS5BSbxqLYgTLA05uk6+2XCKY+zYnM\n\t\t\t\t\t\trHet/LoNkv2Hge74ES1dU99PSSDCUwDGn27t+iPIYPth1hD1hu7/c3NCY2NmU6VF\n\t\t\t\t\t\tmg3X3TcNoLtAyzZZn1Fc3+TGIU5LUryF/33+5168JT6J2RznMI5FkQvp+YVroEQ/\n\t\t\t\t\t\tV5THBheiGsd5CNCwDdqcjj6V8auKXb/QsNYMFQMCAwEAATANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAFUUJk2E+KDSDBSGE6dU5Tq1cvTmIn2TNMUA5uBC/K1v7WzeZjZiid9CP\n\t\t\t\t\t\tnri9DbU3SrvAaGqE4+Sxt1AwnLJuq2izqWuouUvywRYhq7fyJpJTl7ydaL00n/fH\n\t\t\t\t\t\tVOXec31++JNdvqIBERONkv92NC9vBggAK8eFQ3rbqSOAR/Q3r6KcILKbp2gGoAqt\n\t\t\t\t\t\ta3TO/dtiUzllJqAvg3pWnczxGnK5qE7MSQihSWDcFhzSMLiX1NjR3/hM/Vu/hJi/\n\t\t\t\t\t\tNlA5Oye9QvSkVvudFAiz8chuXWu+3LevA/C1IVXBfKA+ZDJ+69JbbEmhOiUceBCB\n\t\t\t\t\t\tHQBzUZxVahSEqoMUTVycJI/zZ6WQwA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nottingham.edu.my"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.nottingham.edu.my:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nottingham.edu.my:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.nottingham.edu.my/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.nottingham.edu.my/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.nottingham.edu.my/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.nottingham.edu.my/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.nottingham.edu.my:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nottingham.edu.my:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nottingham.edu.my"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0jCCAroCCQCeoFvQJDQiEjANBgkqhkiG9w0BAQUFADCBqjELMAkGA1UEBhMC\n\t\t\t\t\t\tbXkxETAPBgNVBAgTCFNlbGFuZ29yMREwDwYDVQQHEwhTZW1lbnlpaDE2MDQGA1UE\n\t\t\t\t\t\tChMtVGhlIFVuaXZlcnNpdHkgT2YgTm90dGluZ2hhbSBNYWxheXNpYSBDYW1wdXMg\n\t\t\t\t\t\tMR0wGwYDVQQLExRJbmZvcm1hdGlvbiBTZXJ2aWNlczEeMBwGA1UEAxMVaWRwLm5v\n\t\t\t\t\t\tdHRpbmdoYW0uZWR1Lm15MB4XDTEyMDMyMzE0MDIzMVoXDTIyMDMyMTE0MDIzMVow\n\t\t\t\t\t\tgaoxCzAJBgNVBAYTAm15MREwDwYDVQQIEwhTZWxhbmdvcjERMA8GA1UEBxMIU2Vt\n\t\t\t\t\t\tZW55aWgxNjA0BgNVBAoTLVRoZSBVbml2ZXJzaXR5IE9mIE5vdHRpbmdoYW0gTWFs\n\t\t\t\t\t\tYXlzaWEgQ2FtcHVzIDEdMBsGA1UECxMUSW5mb3JtYXRpb24gU2VydmljZXMxHjAc\n\t\t\t\t\t\tBgNVBAMTFWlkcC5ub3R0aW5naGFtLmVkdS5teTCCASIwDQYJKoZIhvcNAQEBBQAD\n\t\t\t\t\t\tggEPADCCAQoCggEBANt9uwt87a0uDUwXnCynAFOhpydrO0MzTlQiAxic8o4TY4yG\n\t\t\t\t\t\tIjBb50cMlOkyseJY5I3qN6fFKmWYiAEQtNeiH0PB2h/tgF8M65aHirnW1Z7zjZYK\n\t\t\t\t\t\tYHUTntVrL9WCJNg7UJoE2alh7Tn0irWPL4JS5BSbxqLYgTLA05uk6+2XCKY+zYnM\n\t\t\t\t\t\trHet/LoNkv2Hge74ES1dU99PSSDCUwDGn27t+iPIYPth1hD1hu7/c3NCY2NmU6VF\n\t\t\t\t\t\tmg3X3TcNoLtAyzZZn1Fc3+TGIU5LUryF/33+5168JT6J2RznMI5FkQvp+YVroEQ/\n\t\t\t\t\t\tV5THBheiGsd5CNCwDdqcjj6V8auKXb/QsNYMFQMCAwEAATANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAFUUJk2E+KDSDBSGE6dU5Tq1cvTmIn2TNMUA5uBC/K1v7WzeZjZiid9CP\n\t\t\t\t\t\tnri9DbU3SrvAaGqE4+Sxt1AwnLJuq2izqWuouUvywRYhq7fyJpJTl7ydaL00n/fH\n\t\t\t\t\t\tVOXec31++JNdvqIBERONkv92NC9vBggAK8eFQ3rbqSOAR/Q3r6KcILKbp2gGoAqt\n\t\t\t\t\t\ta3TO/dtiUzllJqAvg3pWnczxGnK5qE7MSQihSWDcFhzSMLiX1NjR3/hM/Vu/hJi/\n\t\t\t\t\t\tNlA5Oye9QvSkVvudFAiz8chuXWu+3LevA/C1IVXBfKA+ZDJ+69JbbEmhOiUceBCB\n\t\t\t\t\t\tHQBzUZxVahSEqoMUTVycJI/zZ6WQwA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Nottingham Malaysia Campus"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nottingham.edu.my/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Nottingham"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://aktivera.ki.se/shibboleth",
    {
      "entity_id": "https://aktivera.ki.se/shibboleth",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Karolinska Institutet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ki.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "KI"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aktivera.ki.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aktivera.ki.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aktivera.ki.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://aktivera.ki.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aktivera.ki.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://aktivera.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://aktivera.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Kontoaktiveringstj\u00e4nst f\u00f6r Karolinska Institutet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Account activation service for Karolinska Institutet"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kontoaktivering Karolinska Institutet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Account activation Karolinska Institutet"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "aktivera.ki.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJALyq1Aqsb9IBMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDmFrdGl2ZXJhLmtpLnNlMB4XDTEzMDMwMTEyNDIzM1oXDTIzMDIyNzEyNDIz\nM1owGTEXMBUGA1UEAxMOYWt0aXZlcmEua2kuc2UwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQCl1rok6UwvfFyFpN/akmpBOTAy6JJnWpMjIQPOcW/cJDQa\nfAri1mWsarSzgKM/C4MdL2T3IjQyhLvydm++hQvGEIn2OPLrWPr9j9KFCZ6Vysnh\nGTa3j29SReSKjJkMVMD4t9nAJsDkx8NQyimSV7hgxhhvoVIMchJ0WusWqxxpeLyt\nLfNt5UModNQMmrF66Nr+DCCBOYsYOUDhjHz3EYWs2jEx1LfnZomcn365bDEG9Z3t\nqg+kcXTvnHwhO9CAE4oFzn4OWy1ucFyffGair12FkQUhHSLkgcMnhsa9qa+9yViM\nX7zII9pVE6BeebBscN3BeDjYphEuo5Z6UamQ/yhdAgMBAAGjPDA6MBkGA1UdEQQS\nMBCCDmFrdGl2ZXJhLmtpLnNlMB0GA1UdDgQWBBTTRtopMmSDYlR/zxoMdZDFeO+X\n+zANBgkqhkiG9w0BAQUFAAOCAQEAmszPge3RJcRexpZwaD70KOr4MMKn7+ke6y+J\nym/fHpNH3FSHSTCNGzcl+80uXYtXnlcFTZ7gyDmoqhtcrxjwc4elOGlPfOXbUlri\nXsIGra4z/g/5ZeIFHczDVBek1obXVrYDGj6GYtzF6Mkkghy6iJvhTzPQfvJwxgfT\nQHLT0e/V9KmT2E1eHx7QpfBh5Uab714COk5zoP5PWFnwvBfpSb0sTlJcOGP9nz2E\nHxR7p2CxcGozA68nst9lx34XSYT1VTXRED7m+H+nGN8lJNjDcAZsudpBsmOU7Pbs\nt1UEJRh1QFCjTJZ0dWFqE9ZDz8jPeZGuERdOnxv9ooMtwU9t1w=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=aktivera.ki.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aktivera.ki.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aktivera.ki.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://aktivera.ki.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://aktivera.ki.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://aktivera.ki.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://aktivera.ki.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.his.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 500 448800"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "HiS Netadmin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:netadmin@his.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University of Sk\u00f6vde"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 500 448800"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "HiS Netadmin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:netadmin@his.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University of Sk\u00f6vde"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 500 448800"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT Helpdesk H\u00f6gskolan i Sk\u00f6vde"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@his.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University of Sk\u00f6vde"
          }
        }
      ],
      "entity_id": "https://idp.his.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAOlJBVpaMgEd+tU+i5F9QK3R5+6IMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC5oaXMuc2UwHhcNMTAwNDE0MTIxNTI0WhcNMzAw\nNDE0MTIxNTI0WjAVMRMwEQYDVQQDEwppZHAuaGlzLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAm+RktUz4LD4GyD5AIBsAfy40Z7mZvYdKdCaTWAmd\nWucpWyu/0H2J3SFtXgOGedzgWjm7nbTmrnZHB87zc/yVuGdtpebq4Ye0XdBLg2A4\nH43lyPdknzQDxD035wzfcyi6/+PRzTK0jucR9KGtEPkNhPg0ziAbHggROKQ1ylNd\nRAul/8b2wDOA4yzBvO4FYFQj+H9bgge869M65P5f/AdBZAWtXy0Ox4G+2ysZfOSi\n7rGMyiX1/s+hgLO2AdosfAnQkKUOax3YsyRzyqbCu8PHEuDciwI2y968Kuq7kv7J\n7vMbZmPLcO4mLjsRnxrfyKlGG+Jpg0BGxRlMlmKn79kdEwIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAuaGlzLnNlhiFodHRwczovL2lkcC5oaXMuc2UvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFE1bH9W+VqwoZnGTvPca0DNTcLL3MA0GCSqGSIb3DQEB\nBQUAA4IBAQBUX+vjv7eCQRljAwrRjH8jNoJyUwMIjQsyStbHM7A5y7+MIdOjBELv\neNYBKGHHEMOiPiB0uPPFrgdN82q8l3PCcYMAYO6aWcwBJsHTpcEBx0lVa4OmW0/r\nBc4RC+rrqNNf8XkYQnD80Px3ncb0OfXmNwSLnLDIKOoQq7hh4DGY73K66vi0sSor\n9e7hji23KpjhR2vPqmiNAvJuEMzDolB3hn2oz+rWfwynb85vFAghd4gJxTMPzsUj\nhNY1IDFKGebFhCWmlG7MMPDm/omu6mBurSE9EAhVTretr0YXxmkfFrOvDysPOYWj\ndrVlFNv2EtdNX1C9u3EJYqslqtyXv2nZ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "his.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.his.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.his.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.his.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.his.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.his.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.his.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.his.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.his.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "his.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.his.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.his.se/en/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r H\u00f6gskolan i Sk\u00f6vde"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for University of Sk\u00f6vde"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.his.se/his_eng_rubin.png",
                    "height": "196",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "193"
                  },
                  {
                    "text": "https://idp.his.se/his_se_rubin.png",
                    "lang": "sv",
                    "height": "196",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "206"
                  },
                  {
                    "text": "https://idp.his.se/his_eng_rubin.png",
                    "lang": "en",
                    "height": "196",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "193"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "H\u00f6gskolan i Sk\u00f6vde"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Sk\u00f6vde"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "his.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:58.39,13.85"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:58.39412,13.85542"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.176.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.184.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.11.96.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "212.25.128.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "212.25.134.0/23"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAOlJBVpaMgEd+tU+i5F9QK3R5+6IMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC5oaXMuc2UwHhcNMTAwNDE0MTIxNTI0WhcNMzAw\nNDE0MTIxNTI0WjAVMRMwEQYDVQQDEwppZHAuaGlzLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAm+RktUz4LD4GyD5AIBsAfy40Z7mZvYdKdCaTWAmd\nWucpWyu/0H2J3SFtXgOGedzgWjm7nbTmrnZHB87zc/yVuGdtpebq4Ye0XdBLg2A4\nH43lyPdknzQDxD035wzfcyi6/+PRzTK0jucR9KGtEPkNhPg0ziAbHggROKQ1ylNd\nRAul/8b2wDOA4yzBvO4FYFQj+H9bgge869M65P5f/AdBZAWtXy0Ox4G+2ysZfOSi\n7rGMyiX1/s+hgLO2AdosfAnQkKUOax3YsyRzyqbCu8PHEuDciwI2y968Kuq7kv7J\n7vMbZmPLcO4mLjsRnxrfyKlGG+Jpg0BGxRlMlmKn79kdEwIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAuaGlzLnNlhiFodHRwczovL2lkcC5oaXMuc2UvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFE1bH9W+VqwoZnGTvPca0DNTcLL3MA0GCSqGSIb3DQEB\nBQUAA4IBAQBUX+vjv7eCQRljAwrRjH8jNoJyUwMIjQsyStbHM7A5y7+MIdOjBELv\neNYBKGHHEMOiPiB0uPPFrgdN82q8l3PCcYMAYO6aWcwBJsHTpcEBx0lVa4OmW0/r\nBc4RC+rrqNNf8XkYQnD80Px3ncb0OfXmNwSLnLDIKOoQq7hh4DGY73K66vi0sSor\n9e7hji23KpjhR2vPqmiNAvJuEMzDolB3hn2oz+rWfwynb85vFAghd4gJxTMPzsUj\nhNY1IDFKGebFhCWmlG7MMPDm/omu6mBurSE9EAhVTretr0YXxmkfFrOvDysPOYWj\ndrVlFNv2EtdNX1C9u3EJYqslqtyXv2nZ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "H\u00f6gskolan i Sk\u00f6vde"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Sk\u00f6vde"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.his.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HIS"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.guilfordjournals.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.guilfordjournals.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Atypon Systems: Guilford Press Journals"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.guilford.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDrTCCApWgAwIBAgIJAKnRupkZlL3vMA0GCSqGSIb3DQEBBQUAMIGVMQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEUMBIGA1UEBxMLU2FudGEgQ2xh\n\t\t\t\t\t\tcmExHTAbBgNVBAoTFEF0eXBvbiBTeXN0ZW1zLCBJbmMuMR0wGwYDVQQLExRBdHlw\n\t\t\t\t\t\tb24gU3lzdGVtcywgSW5jLjEdMBsGA1UEAxMUZ3VpbGZvcmRqb3VybmFscy5jb20w\n\t\t\t\t\t\tHhcNMTEwNjI4MjE1MjI0WhcNMjEwNjI1MjE1MjI0WjCBlTELMAkGA1UEBhMCVVMx\n\t\t\t\t\t\tEzARBgNVBAgTCkNhbGlmb3JuaWExFDASBgNVBAcTC1NhbnRhIENsYXJhMR0wGwYD\n\t\t\t\t\t\tVQQKExRBdHlwb24gU3lzdGVtcywgSW5jLjEdMBsGA1UECxMUQXR5cG9uIFN5c3Rl\n\t\t\t\t\t\tbXMsIEluYy4xHTAbBgNVBAMTFGd1aWxmb3Jkam91cm5hbHMuY29tMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAukY3Suc40qnHE6QmmMhIkFT74Pn1V/NB\n\t\t\t\t\t\trak3v7CSX0SZaF5eWhHE2qgnObdCCNzEOwKMprP0/cyLM4AfLou90RE9a3VyMu6k\n\t\t\t\t\t\tf/DmMf5ZLJIIP6SF7y94N+gswlbPh9IXxQVAp7rR4qEqdYKThC3hz+/8G4UPFr+g\n\t\t\t\t\t\thy4xzz/Op35Zo2GYapsyuvclhzyfjj/YjT9CliNeGktdq6O97obw5oz5ZaAVlWlq\n\t\t\t\t\t\tSf6P0EKQUWRUxPfyutbjUVkuGWZtRJOXC3QZxhsvby31Rh2g5gIB2KiynKURGCl8\n\t\t\t\t\t\t136mP4X2wVGqHnEdiA4+R4ofAEuBpuqSBeW4yAGUdLqVzxEcFl+m6wIDAQABMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBBQUAA4IBAQBR7zjTkZGpMUIQn8F/2yZcFu/Ub8j5Goop4FCLfuyN\n\t\t\t\t\t\tLkVUwceiKlYVB05ZHr3TtHcyGjv2+19Ueo8QuNuI5BzqMRimfsiYdR6y44A1T5N6\n\t\t\t\t\t\tYHi+cqfv6eKvXw+qLJ4k49ctR+8zV8YTVLgBBW3UJLW+r6MMUXtLfdBJGFigg/WT\n\t\t\t\t\t\tu/VDMQFnTBgvQ0nSUnhuu3A8w+wXA2Yvk0gXIpnySD7ZhP99WcFDjFqwaYiu8iVS\n\t\t\t\t\t\tVB0Di9U3LXyKtrtkDze+28e1YM/C0+Z1L8iMRwc1Bl//37zvMFLQW76s9+yQMJVc\n\t\t\t\t\t\t27TWzs2tyoA/K2JsjCy5trHj/oEhD2obZvDuvJ89VKDQ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://guilfordjournals.com/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.guilfordjournals.com/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.guilfordjournals.com/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://voting.wlv.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://voting.wlv.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-05-29T14:29:29Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Wolverhampton - Voting"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wlv.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://voting.wlv.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://voting.wlv.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://voting.wlv.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://voting.wlv.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://voting.wlv.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://voting.wlv.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Wolverhampton - Voting system"
                  }
                ],
                "logo": [
                  {
                    "text": "https://oa-idp.wlv.ac.uk/oala/wlv_uni_logo.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Wolverhampton - Voting"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://voting.wlv.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://voting.wlv.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://voting.wlv.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://voting.wlv.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://voting.wlv.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://voting.wlv.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://voting.wlv.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://voting.wlv.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://voting.wlv.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://voting.wlv.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib.alexanderstreet.com/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@alexanderstreet.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Field"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jfield@astreetpress.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.alexanderstreet.com/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-08-11T17:15:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Alexander Street Press LLC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.alexanderstreet.com/about/index.htm"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Alexander Street Press, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.alexanderstreet.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.alexanderstreet.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.alexanderstreet.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.alexanderstreet.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "1",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shib.alexanderstreet.com/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDwDCCAqgCCQDCf0TzHdVL9zANBgkqhkiG9w0BAQUFADCBoTELMAkGA1UEBhMC\n\t\t\t\t\t\tVVMxETAPBgNVBAgMCFZpcmdpbmlhMRMwEQYDVQQHDApBbGV4YW5kcmlhMR8wHQYD\n\t\t\t\t\t\tVQQKDBZBbGV4YW5kZXIgU3RyZWV0IFByZXNzMSEwHwYDVQQDDBhzaGliLmFsZXhh\n\t\t\t\t\t\tbmRlcnN0cmVldC5jb20xJjAkBgkqhkiG9w0BCQEWF2FzcC1pdEBhc3RyZWV0cHJl\n\t\t\t\t\t\tc3MuY29tMB4XDTE0MDkyOTE0MzI0MloXDTI0MDkyNjE0MzI0MlowgaExCzAJBgNV\n\t\t\t\t\t\tBAYTAlVTMREwDwYDVQQIDAhWaXJnaW5pYTETMBEGA1UEBwwKQWxleGFuZHJpYTEf\n\t\t\t\t\t\tMB0GA1UECgwWQWxleGFuZGVyIFN0cmVldCBQcmVzczEhMB8GA1UEAwwYc2hpYi5h\n\t\t\t\t\t\tbGV4YW5kZXJzdHJlZXQuY29tMSYwJAYJKoZIhvcNAQkBFhdhc3AtaXRAYXN0cmVl\n\t\t\t\t\t\tdHByZXNzLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANT9VZht\n\t\t\t\t\t\ttKm/kA8GzvNL7sCY66dybafPY36Glm7gLRFeZAC09fAGkzkW+SmLrY5Gum5kYYhH\n\t\t\t\t\t\t99ckibDhfe3/61sgoBIwmaFn0atEb9bMbO7IVQ9bQV3vdVI+/AvsA5EIF8W9ildv\n\t\t\t\t\t\ttx09CLonner4y8yol0h7VuUJyrlMef/rEBFiFnnDceEswiP1va3vGRRlYx396Uki\n\t\t\t\t\t\tn/cCPae+YYFxo0HZFc6QFfCwmGkSdPeEjjrew4OBmbEeTV4NWgn7a2y81n4FlUwY\n\t\t\t\t\t\tC6fNHuLjaB11lc0i+yNjKipTuAiTr1zRzvXuRSwwPpI9OJ0YHPUXB1Ug3U+jkNE+\n\t\t\t\t\t\tqihC1Waoa6RNKiMCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAuUgodJSN/sFhG1wy\n\t\t\t\t\t\tifZuq4hKlDGtpmwds+qFBYyCJV/dChhasqcvkqWfzTj7BUn83mPmdIfDcP0evdup\n\t\t\t\t\t\t6QCFVlIr5Qv5I5f5eThovcJquPHKUTWEQdMh3VAhnp+zrjnO8CYozCKlEYJs0Z0J\n\t\t\t\t\t\tvCIOdqIBfxQ/De7HqksyEeLWT/aAuI8WJHmYT4ZrcXs3t0zadwmxf+Fx7ItyjYSG\n\t\t\t\t\t\t35u+naLO9KhT59QszZB81NpWP7n7dgh8TKyJzWSKI5ZcnRdD3y+J41RvnBRxuKQ+\n\t\t\t\t\t\tDe08tywH8Z0G4Htt9kxk6Em2I/C+6x7hMYYoK0mAWGcKktXMaaAFyoQQv5WZPzxB\n\t\t\t\t\t\tTVh0fw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.alexanderstreet.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.alexanderstreet.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.alexanderstreet.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.alexanderstreet.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.alexanderstreet.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.alexanderstreet.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.alexanderstreet.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shib.alexanderstreet.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shib.alexanderstreet.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shib.alexanderstreet.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://login.ufl.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ebs@ufl.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Eli Ben-Shoshan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "whcurry@ufl.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Warren Curry"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ufrich@ufl.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rich Lowrey"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "crt@ufl.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Charles Tompkins"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.ufl.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.ufl.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.ufl.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAM6XTJCGu1xXMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDWxvZ2luLnVmbC5lZHUwHhcNMTEwNjMwMTY1NDU5WhcNMjEwNjI3MTY1NDU5\nWjAYMRYwFAYDVQQDEw1sb2dpbi51ZmwuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEA2Hnmxqt0Z+RxiAbs6TZxfJFOchZDwSr6t328myucayB/l4T6\ncujQyzG6TMlQP+isgvsQywqV+zbvRI5i+g7nCsivGelAeFyBzor+JT+rg94ypyug\nSWlPh/coPjkETQaGMR+bgBxGOEJfOOApFJxdBpl0StKbX2oPjwIEGSo3zjhmPTpx\naVEr0lUBrgJmp5Of6dKPZ/32SF98Ed79lr8C9fOJHTfh4LYwZ/9fiYUG7HPfjR/m\nPDChsgXYJ5Ao3+bRNqf2q4+vndU27JCVwiWI+RmwlfmbPXKLufl2ZfDdLYqyrc5P\nJDsx4oHwbAkcH7cLNW67bTMmSEp+1rSBKa1v8QIDAQABo3kwdzAdBgNVHQ4EFgQU\n1hjdCt1pTU62iZ837vmDLpznn3IwSAYDVR0jBEEwP4AU1hjdCt1pTU62iZ837vmD\nLpznn3KhHKQaMBgxFjAUBgNVBAMTDWxvZ2luLnVmbC5lZHWCCQDOl0yQhrtcVzAM\nBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBQJTcTLE95HTa5E/IMbMl6\n5e0fPWiSm7KfRtZSSTMe4mK+6Ub0x8YWTsAN1RoSIQtftK2DuyNtUbJ2+Y9PS7bs\nftfegfOoVBTTOkOQ+CeKWEmwT+1Yw2IRts0vHXvgqzA5b8OYT81RrKcJtMFfyKMi\npm+Rc95JoFHZz3tYflLU+3kOkEGHUCX08+BrQLc26BcdZokKySbKzXPUsBpmYUEY\nMStdDm/Po7ON4Shh1TpvMEFEofUNUIU5uY5oHLO8gFx+AWRG47URXfxgeyEf9+SB\naFbDixFvCWbqDUiuKdivSWdqiPYSPiINYEAm3p46viJ4+6CBFELzDOTcZUrXZaSD"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufl.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.ufl.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.ufl.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.ufl.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.ufl.edu/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.ufl.edu/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufl.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.it.ufl.edu/identity/shibboleth/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Florida"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Florida - GatorLink Credentials"
                  }
                ],
                "logo": [
                  {
                    "text": "https://images.webadmin.ufl.edu/signatures/wordmark.gif",
                    "lang": "en",
                    "height": "38",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "135"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://privacy.ufl.edu/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAM6XTJCGu1xXMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDWxvZ2luLnVmbC5lZHUwHhcNMTEwNjMwMTY1NDU5WhcNMjEwNjI3MTY1NDU5\nWjAYMRYwFAYDVQQDEw1sb2dpbi51ZmwuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEA2Hnmxqt0Z+RxiAbs6TZxfJFOchZDwSr6t328myucayB/l4T6\ncujQyzG6TMlQP+isgvsQywqV+zbvRI5i+g7nCsivGelAeFyBzor+JT+rg94ypyug\nSWlPh/coPjkETQaGMR+bgBxGOEJfOOApFJxdBpl0StKbX2oPjwIEGSo3zjhmPTpx\naVEr0lUBrgJmp5Of6dKPZ/32SF98Ed79lr8C9fOJHTfh4LYwZ/9fiYUG7HPfjR/m\nPDChsgXYJ5Ao3+bRNqf2q4+vndU27JCVwiWI+RmwlfmbPXKLufl2ZfDdLYqyrc5P\nJDsx4oHwbAkcH7cLNW67bTMmSEp+1rSBKa1v8QIDAQABo3kwdzAdBgNVHQ4EFgQU\n1hjdCt1pTU62iZ837vmDLpznn3IwSAYDVR0jBEEwP4AU1hjdCt1pTU62iZ837vmD\nLpznn3KhHKQaMBgxFjAUBgNVBAMTDWxvZ2luLnVmbC5lZHWCCQDOl0yQhrtcVzAM\nBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBQJTcTLE95HTa5E/IMbMl6\n5e0fPWiSm7KfRtZSSTMe4mK+6Ub0x8YWTsAN1RoSIQtftK2DuyNtUbJ2+Y9PS7bs\nftfegfOoVBTTOkOQ+CeKWEmwT+1Yw2IRts0vHXvgqzA5b8OYT81RrKcJtMFfyKMi\npm+Rc95JoFHZz3tYflLU+3kOkEGHUCX08+BrQLc26BcdZokKySbKzXPUsBpmYUEY\nMStdDm/Po7ON4Shh1TpvMEFEofUNUIU5uY5oHLO8gFx+AWRG47URXfxgeyEf9+SB\naFbDixFvCWbqDUiuKdivSWdqiPYSPiINYEAm3p46viJ4+6CBFELzDOTcZUrXZaSD"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://login.ufl.edu/error.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Florida"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufl.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Florida"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://vmfetid.iamm.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "assistance@iamm.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://vmfetid.iamm.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-03-19T13:59:43Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vmfetid.iamm.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vmfetid.iamm.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://vmfetid.iamm.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iamm.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.iamm.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnel du CIHEAM / IAMM"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnel du CIHEAM / IAMM"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CIHEAM / IAMM"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CIHEAM / IAMM"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUa6YcSsah7wzB8e/uovuAIHgDDikwDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPdm1mZXRpZC5pYW1tLmZyMB4XDTE0MDMxOTE0MzUxMloX\nDTM0MDMxOTE0MzUxMlowGjEYMBYGA1UEAxMPdm1mZXRpZC5pYW1tLmZyMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAgvu2YJSUPkAxdOhba3LMGpEcisXf\nVdNeH7ghFbg6CPBJUUNaDWftx8OqbB7q9UpYJRhSPxoZlsglDLCxmQPNH8zSC7F5\nTg0cuRRMoUt7UopzEoDoeklLxfd8jTLXQBXdcQftKpZLuQAdSDuAMEW/n8pPTkCE\nUjy7NkS7SwJTBz8aW2wiXiRrMoYO4MC0IxW0peQ9yp4ovjPqy8P/KfsPh/QjfevC\nPG+SH3J80NIjcSl6tf7CLJBVa4s/zfT6znpl1LB6qnV0gJ+jh+wSXIEsy+Q/Km/E\nVyiDxnl5NI04RKi7kDgPSpsbzAqa9oZrs9uZKIeer/lScG7oizWZZHDwXQIDAQAB\no2UwYzBCBgNVHREEOzA5gg92bWZldGlkLmlhbW0uZnKGJmh0dHBzOi8vdm1mZXRp\nZC5pYW1tLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSRB4UIB+9SgknpoQOp\nMWDrw6esHjANBgkqhkiG9w0BAQUFAAOCAQEAK/jgKZJrp7uM7+h7wwHdByANU16I\nQVPXf5TNHqduJKKNgdZt84pq6ixn6WRxvFEuLWJdf2LRvRt2jwkaZEOM8gcZhUGq\n68F97X+xBDQt5iqMRmLVDnYsitc6osw5Kf4sxPdwDlt3k56aRl3vHADDsqK54vqI\naFmAtn0cvucCFRDk7+BxejNbAi0cZWFz9yRaD2ACeJAZuNPt7giuIDjVX1hsD76f\nOa/zVHg8v6w2WtOYhe/6PW6Aw0vPRStXXissHMStkekSzPRrHxZqu99YyyobYCKi\nI4Uca1MsJ2JD+Ds5G4kRkfKAWM9UDePCbVe9FM9SbU7rY9j+vHlnYjQpHg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CIHEAM / IAMM"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iamm.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CIHEAM / IAMM"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://efoyer.glam.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@southwales.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Services Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sewell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kevin.sewell@southwales.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kevin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://efoyer.glam.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of South Wales: Efoyer"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.glam.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of South Wales"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://efoyer.glam.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://efoyer.glam.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://efoyer.glam.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://efoyer.glam.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://efoyer.glam.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEFjCCAv6gAwIBAgIJANpMyk1kQRAJMA0GCSqGSIb3DQEBBQUAMIGLMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEbMBkGA1UECBMSUmhvbmRkYSBDeW5vbiBUYWZmMRIwEAYDVQQHEwlU\n\t\t\t\t\t\tcmVmb3Jlc3QxIDAeBgNVBAoTF1VuaXZlcnNpdHkgb2YgR2xhbW9yZ2FuMQ0wCwYD\n\t\t\t\t\t\tVQQLEwRMQ1NTMRowGAYDVQQDExFlZm95ZXIuZ2xhbS5hYy51azAeFw0xMjA1MDgw\n\t\t\t\t\t\tOTA2MzNaFw0zMjA1MDMwOTA2MzNaMIGLMQswCQYDVQQGEwJHQjEbMBkGA1UECBMS\n\t\t\t\t\t\tUmhvbmRkYSBDeW5vbiBUYWZmMRIwEAYDVQQHEwlUcmVmb3Jlc3QxIDAeBgNVBAoT\n\t\t\t\t\t\tF1VuaXZlcnNpdHkgb2YgR2xhbW9yZ2FuMQ0wCwYDVQQLEwRMQ1NTMRowGAYDVQQD\n\t\t\t\t\t\tExFlZm95ZXIuZ2xhbS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAN4kgz4TvCUcw44kQHtV73yTm23GSLQ2iMySRCUthIbTCdg3nj7icN433D3o\n\t\t\t\t\t\tRsT0iUCjOWKlroCQOx1Rt5HubJzQ6CptodtqujNFaGGBpzlXpFeqyt60vu6AX5xa\n\t\t\t\t\t\tlcEdBBfPctYbfn6ioW/pJhNaBiYLAyt4u5ds3iCpj3VTkKWF2rLlIZ16QGtMq0bP\n\t\t\t\t\t\tXgjUBRqufWWzcRLy496G6Wv9namhV9wBrJpzWf4jYVDdm5U8zc3NtXih3vdyn9gj\n\t\t\t\t\t\tL5jnDnGsTIyrkxyL+GLwuQoEPtkomAnpJBTB+71cNuoottmqdaIv+DwR1HVS2gwv\n\t\t\t\t\t\te0RDi02Umo3UfeLpYONNsjnM4acCAwEAAaN7MHkwCQYDVR0TBAIwADAsBglghkgB\n\t\t\t\t\t\thvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYE\n\t\t\t\t\t\tFO7rrCmESBalKYdXW1ALKFihdCsjMB8GA1UdIwQYMBaAFO7rrCmESBalKYdXW1AL\n\t\t\t\t\t\tKFihdCsjMA0GCSqGSIb3DQEBBQUAA4IBAQC6j+4T1O1FXXDC8kZ+JCGwilaKKfxh\n\t\t\t\t\t\tIvwnas/R+j6xv7TszUzIjaaSXycZdjH8z7DYXgedtotm9v4oO5ItrcsS/jsV0G8V\n\t\t\t\t\t\tbwn7jJ518Dq9OIdvuvs3lFIdwoajxJdwQiQddOznFh4cWzG5/XgqVNSEUtjiPuK6\n\t\t\t\t\t\tlee/vFySOO/silc+hYPLZO3Uf0fC/pE7LOf940D5rEmAH6KoEMNAE8MdXFJ/H+km\n\t\t\t\t\t\t/Icjg2pu0TrSKd4w2J+oNs4zx2V9mDthQ9El/gOUlP66C49AHryg3Q2Frton8rcy\n\t\t\t\t\t\tLhM4j8K3Z85HZOMAm5o9KbdApcJ5tX1yBg3JtB/LC5Keg5X7PxRoK8ck"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEFjCCAv6gAwIBAgIJANpMyk1kQRAJMA0GCSqGSIb3DQEBBQUAMIGLMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEbMBkGA1UECBMSUmhvbmRkYSBDeW5vbiBUYWZmMRIwEAYDVQQHEwlU\n\t\t\t\t\t\tcmVmb3Jlc3QxIDAeBgNVBAoTF1VuaXZlcnNpdHkgb2YgR2xhbW9yZ2FuMQ0wCwYD\n\t\t\t\t\t\tVQQLEwRMQ1NTMRowGAYDVQQDExFlZm95ZXIuZ2xhbS5hYy51azAeFw0xMjA1MDgw\n\t\t\t\t\t\tOTA2MzNaFw0zMjA1MDMwOTA2MzNaMIGLMQswCQYDVQQGEwJHQjEbMBkGA1UECBMS\n\t\t\t\t\t\tUmhvbmRkYSBDeW5vbiBUYWZmMRIwEAYDVQQHEwlUcmVmb3Jlc3QxIDAeBgNVBAoT\n\t\t\t\t\t\tF1VuaXZlcnNpdHkgb2YgR2xhbW9yZ2FuMQ0wCwYDVQQLEwRMQ1NTMRowGAYDVQQD\n\t\t\t\t\t\tExFlZm95ZXIuZ2xhbS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAN4kgz4TvCUcw44kQHtV73yTm23GSLQ2iMySRCUthIbTCdg3nj7icN433D3o\n\t\t\t\t\t\tRsT0iUCjOWKlroCQOx1Rt5HubJzQ6CptodtqujNFaGGBpzlXpFeqyt60vu6AX5xa\n\t\t\t\t\t\tlcEdBBfPctYbfn6ioW/pJhNaBiYLAyt4u5ds3iCpj3VTkKWF2rLlIZ16QGtMq0bP\n\t\t\t\t\t\tXgjUBRqufWWzcRLy496G6Wv9namhV9wBrJpzWf4jYVDdm5U8zc3NtXih3vdyn9gj\n\t\t\t\t\t\tL5jnDnGsTIyrkxyL+GLwuQoEPtkomAnpJBTB+71cNuoottmqdaIv+DwR1HVS2gwv\n\t\t\t\t\t\te0RDi02Umo3UfeLpYONNsjnM4acCAwEAAaN7MHkwCQYDVR0TBAIwADAsBglghkgB\n\t\t\t\t\t\thvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYE\n\t\t\t\t\t\tFO7rrCmESBalKYdXW1ALKFihdCsjMB8GA1UdIwQYMBaAFO7rrCmESBalKYdXW1AL\n\t\t\t\t\t\tKFihdCsjMA0GCSqGSIb3DQEBBQUAA4IBAQC6j+4T1O1FXXDC8kZ+JCGwilaKKfxh\n\t\t\t\t\t\tIvwnas/R+j6xv7TszUzIjaaSXycZdjH8z7DYXgedtotm9v4oO5ItrcsS/jsV0G8V\n\t\t\t\t\t\tbwn7jJ518Dq9OIdvuvs3lFIdwoajxJdwQiQddOznFh4cWzG5/XgqVNSEUtjiPuK6\n\t\t\t\t\t\tlee/vFySOO/silc+hYPLZO3Uf0fC/pE7LOf940D5rEmAH6KoEMNAE8MdXFJ/H+km\n\t\t\t\t\t\t/Icjg2pu0TrSKd4w2J+oNs4zx2V9mDthQ9El/gOUlP66C49AHryg3Q2Frton8rcy\n\t\t\t\t\t\tLhM4j8K3Z85HZOMAm5o9KbdApcJ5tX1yBg3JtB/LC5Keg5X7PxRoK8ck"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://efoyer.glam.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://efoyer.glam.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://efoyer.glam.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://efoyer.glam.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://efoyer.glam.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://efoyer.glam.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://efoyer.glam.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://efoyer.glam.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://efoyer.glam.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://efoyer.glam.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://demo.eduopen.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Minerva"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cea@unimore.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tommaso"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://demo.eduopen.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2015-10-09T12:03:03Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Eduopen Network fornito da Unimore"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Eduopen Network provided by Unimore"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eduopen.org"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eduopen.org"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 di Modena e Reggio Emilia"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Modena e Reggio Emilia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://demo.eduopen.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://demo.eduopen.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://demo.eduopen.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://demo.eduopen.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://demo.eduopen.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://demo.eduopen.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://demo.eduopen.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://demo.eduopen.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://demo.eduopen.org/eduopen/information-en.php"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://demo.eduopen.org/eduopen/information-it.php"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Test portal for providing demonstration courses for EDUOPEN Network in a federated environment"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Portale di test per l'erogazione dei corsi dimostrativi per la rete EDUOPEN in un ambiente federato"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://demo.eduopen.org/eduopen/privacy-en.php"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://demo.eduopen.org/eduopen/privacy-it.php"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Eduopen Network provided by Unimore"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Eduopen Network fornito da Unimore"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHTCCAgWgAwIBAgIJAKTsiYGHB4eEMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2Rldi5lZHVvcGVuLm9yZzAeFw0xNTEwMDgxOTEyMTJaFw0zNTEwMDMxOTEy\nMTJaMBoxGDAWBgNVBAMTD2Rldi5lZHVvcGVuLm9yZzCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAOLTNa351EGsrWjOLExh1KsdepEkjmLu6Np410xnUW2t\nMRcVOTkAr1bm1rdvGp/7DbdxxQay0jEwYI0AhFW/uPhzaUjKatlZzcy/ApMb8+RQ\nvtyoja86vCMIzQmTCoVZIJY+WKOpqSmx6U+ycZXN17uYLH6v+kAj9C4dFOsiQKP3\nFTsqviTYmYAfXEtmzlQf5ag0UipMlCD3O4M5kY0GJOShDAUcgy4E34xdt0YMvOks\niLvm8cLqQ7//b3ir2yZ7ldWY9w15CEqXOT/VQmQ18ez7TptlKzviM3oKGLNoiOyT\nZ+t5ZfIvD18NAeS4lPo35VCHr5z/cEVpHL/Cp8VY3QkCAwEAAaNmMGQwQwYDVR0R\nBDwwOoIPZGV2LmVkdW9wZW4ub3JnhidodHRwczovL2Rldi5lZHVvcGVuLm9yZy9h\ndXRoL3NoaWJib2xldGgwHQYDVR0OBBYEFNVJx+JWzWU5V4JnYk/b/tvNpWz7MA0G\nCSqGSIb3DQEBBQUAA4IBAQAZir5mWwsi3FOoi3Tp+OI6umALyvAAihBdrg9hZ6Gn\nOa3rrgFoOiISpqj5zTjXOGC40ZLOl269VdQzxrMMX5NvO9C9qPOuQ+dEllkQ4bP0\nvHr5XHeCVYW3kpmVXrO+wCX+zMUrTwsOhUP0J7Pxo38+mMT3JLeGXwel5fs8wHEU\nYMaYMWKMN7R5nJxW7LIfJCNFZfgm5pfo2dJs5SGCgmZxw9hrS/26xaKArfPMumls\nzczrSGA9TWebd4JiqYgR++we4HpNTJDoMV4azydOG1GkhGfU3o+V1sZBWrlaJwiy\numrvPDF3/bdUFQW96kAoCVF7Gj2x+yIy2SK2RTpyELZY"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://demo.eduopen.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://demo.eduopen.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://demo.eduopen.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://demo.eduopen.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://demo.eduopen.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://demo.eduopen.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Eduopen Network provided by Unimore"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Eduopen Network fornito da Unimore"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Test portal for providing demonstration courses for EDUOPEN Network in a federated environment"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Portale di test per l'erogazione dei corsi dimostrativi per la rete EDUOPEN in un ambiente federato"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.ascopubs.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.ascopubs.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-07-29T15:42:14Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Journals of the American Society of Clinical Oncology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ascopubs.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HighWire Press, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.highwire.org/applications/ascojnls/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.highwire.org/applications/ascojnls/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIJAMTRVlqTJ11lMA0GCSqGSIb3DQEBBQUAMIG+MQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBD\n\t\t\t\t\t\taXR5MRcwFQYDVQQKEw5IaWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUx\n\t\t\t\t\t\tIDAeBgNVBAMTF3NoaWJib2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkB\n\t\t\t\t\t\tFiZzaGliYm9sZXRoLWFkbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTAeFw0xNDA0\n\t\t\t\t\t\tMTUxOTQzMDNaFw0yNDA0MTIxOTQzMDNaMIG+MQswCQYDVQQGEwJVUzETMBEGA1UE\n\t\t\t\t\t\tCBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBDaXR5MRcwFQYDVQQKEw5I\n\t\t\t\t\t\taWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUxIDAeBgNVBAMTF3NoaWJi\n\t\t\t\t\t\tb2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkBFiZzaGliYm9sZXRoLWFk\n\t\t\t\t\t\tbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALPB99M9iWjentrddY/rLgzKn1X0j4Ao191iyiowBBt/r/pmn2oz\n\t\t\t\t\t\tfrbONkkTVBB++mNtiufK6jyKnBM5mffPOkXHRo+K1DQec7TvpQ1PmLv/BpBgPrr9\n\t\t\t\t\t\tldViOSUnYJuB0IgJVV8oylgeH2Ay0XRkNPlBUjBA2fUPWVpXcvFe+aD2tLdVR9uO\n\t\t\t\t\t\tXvfTMxAEGqzxTU+OxO6pW2sBXNBmGvZQ0TRyovQh5+pTURY/lm0V/iWvRmRe51WE\n\t\t\t\t\t\tO/nhYyvRuMmNj8EL38o10S9TXuCkVzY00hK5cclaFge7gz/tfjmadVVcbe8xCVxc\n\t\t\t\t\t\tnb1lhmt1kH2XtKvU5hyZMTO+VUfXQvqcQyECAwEAAaN7MHkwCQYDVR0TBAIwADAs\n\t\t\t\t\t\tBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYD\n\t\t\t\t\t\tVR0OBBYEFJpUZq/XaW9/bPvjffkxX0IDvuPiMB8GA1UdIwQYMBaAFJpUZq/XaW9/\n\t\t\t\t\t\tbPvjffkxX0IDvuPiMA0GCSqGSIb3DQEBBQUAA4IBAQCq/FF56ZB1cL3KbniEJP99\n\t\t\t\t\t\tU9wTD6KpOrWxvqNbUSV1cefLf5cYHonOjy6oAJSSBSNuP7U5Q//0tXtkvlJoqGUY\n\t\t\t\t\t\tvqngmeg9wLZ/Fla3tXcDdTj0n1F+NZOx9vBDacIk0Ua4aHXDA4bdytzkV1QyZDRq\n\t\t\t\t\t\tQ8vq7RoQ8E5IF7Cll+kt2dZXQk8o6Qp3w2ppoMRtYdKOQassqn+V1MYcMPgdxZkS\n\t\t\t\t\t\tDrcgzktR/JMb5OmPrp4mSy1OWDGrFvUIigsLBPZV9tw1f7y42lnbmQas3RCS30yr\n\t\t\t\t\t\tCtUPT/PQDkCdBRViGmmMkYwjdaOTiHOJveWtrVXu8vLvO36pqFF4Kft0pgqlfvAE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.highwire.org/applications/ascojnls/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.highwire.org/applications/ascojnls/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.highwire.org/applications/ascojnls/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.highwire.org/applications/ascojnls/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://butare.ifrn.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Carlos Eduardo Egito"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "eduardo.egito@ifrn.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://butare.ifrn.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC0DCCAbgCAQAwDQYJKoZIhvcNAQEFBQAwLjEOMAwGA1UECxMFRElHVEkxCzAJ\nBgNVBAYTAkJSMQ8wDQYDVQQDEwZidXRhcmUwHhcNMTQwNTIzMTcxNjA1WhcNMTkw\nNTIyMTcxNjA1WjAuMQ4wDAYDVQQLEwVESUdUSTELMAkGA1UEBhMCQlIxDzANBgNV\nBAMTBmJ1dGFyZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM36HWGk\nw9Q7QoZ/pbtE5BKDjrXkwJ9tZVggplOmcnG4XzvKsafA5oTyjkentzuk089/V8JN\n9mzTByAOyMJ1HZLoaWRKw5irjAh81RrPPZyLPjC3VCU6S7VGBwpwu/scnrLkIuz2\nPA4unF/vgPY0GCLtkVS7TKm59szt87xZQfhvKTibtji+DXqeJktm0L1DfZBWC1yH\nVTedJJUOzlGRh44xyZMcmyXO0J2sIu2BTHg0pbZkMmWubG0Gg5ieyn540znoTQ0Y\nykhImtdHzr+NJnNJUrx0FP+tsfPlY+9+Jtd2hM8PwWoxyrMZ/Hrj6R3kblT4Ycu7\nzIgWdGliX+T+zoECAwEAATANBgkqhkiG9w0BAQUFAAOCAQEASiVRDUu+K0fsrVl8\nLd9zFoEKWhywzji/ySqDyIep1wf9HKzuPscMkol+lHcwqWdDfP4dSCeIbBp0HB/M\n/b9h67Kd8W2HMo1Mj12dOow0SfUtSkS8jbGctmwRxok5wf4SkCBlXmDKw04T7O0u\nlx+OaodZO13DPijFFDZ6R5nzOpwA6e+psoKODdqhm5mvQ+VDbRT/YZuunq68OAp7\nW35U8nuplIQL1tiVmUzL7Zub4O/riXx0JChZvR5A5tw4s3ciugLNbUx/UAJkntmG\nXwk5tjWfp+KBfraGK4/jLrShRzEEXl6J8UQl9r5q7ZD1UqQdRentbihSj4pfN5ID\nUG8d4Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ifrn.local"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://butare.ifrn.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://butare.ifrn.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://butare.ifrn.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://butare.ifrn.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://butare.ifrn.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://butare.ifrn.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://butare.ifrn.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://butare.ifrn.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ifrn.local"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifrn.edu.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifrn.edu.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFRN - Instituto Federal do Rio Grande do Norte"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFRN - Instituto Federal do Rio Grande do Norte"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFRN - Instituto Federal do Rio Grande do Norte"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFRN - Instituto Federal do Rio Grande do Norte"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC0DCCAbgCAQAwDQYJKoZIhvcNAQEFBQAwLjEOMAwGA1UECxMFRElHVEkxCzAJ\nBgNVBAYTAkJSMQ8wDQYDVQQDEwZidXRhcmUwHhcNMTQwNTIzMTcxNjA1WhcNMTkw\nNTIyMTcxNjA1WjAuMQ4wDAYDVQQLEwVESUdUSTELMAkGA1UEBhMCQlIxDzANBgNV\nBAMTBmJ1dGFyZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM36HWGk\nw9Q7QoZ/pbtE5BKDjrXkwJ9tZVggplOmcnG4XzvKsafA5oTyjkentzuk089/V8JN\n9mzTByAOyMJ1HZLoaWRKw5irjAh81RrPPZyLPjC3VCU6S7VGBwpwu/scnrLkIuz2\nPA4unF/vgPY0GCLtkVS7TKm59szt87xZQfhvKTibtji+DXqeJktm0L1DfZBWC1yH\nVTedJJUOzlGRh44xyZMcmyXO0J2sIu2BTHg0pbZkMmWubG0Gg5ieyn540znoTQ0Y\nykhImtdHzr+NJnNJUrx0FP+tsfPlY+9+Jtd2hM8PwWoxyrMZ/Hrj6R3kblT4Ycu7\nzIgWdGliX+T+zoECAwEAATANBgkqhkiG9w0BAQUFAAOCAQEASiVRDUu+K0fsrVl8\nLd9zFoEKWhywzji/ySqDyIep1wf9HKzuPscMkol+lHcwqWdDfP4dSCeIbBp0HB/M\n/b9h67Kd8W2HMo1Mj12dOow0SfUtSkS8jbGctmwRxok5wf4SkCBlXmDKw04T7O0u\nlx+OaodZO13DPijFFDZ6R5nzOpwA6e+psoKODdqhm5mvQ+VDbRT/YZuunq68OAp7\nW35U8nuplIQL1tiVmUzL7Zub4O/riXx0JChZvR5A5tw4s3ciugLNbUx/UAJkntmG\nXwk5tjWfp+KBfraGK4/jLrShRzEEXl6J8UQl9r5q7ZD1UqQdRentbihSj4pfN5ID\nUG8d4Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFRN - Instituto Federal do Rio Grande do Norte"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFRN - Instituto Federal do Rio Grande do Norte"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifrn.edu.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifrn.edu.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFRN - Instituto Federal do Rio Grande do Norte"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFRN - Instituto Federal do Rio Grande do Norte"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://averell.unimes.fr/authsaml2/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Olivier FALZONE"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "olivier.falzone@unimes.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Florence VERSE"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "florence.verse@unimes.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://averell.unimes.fr/authsaml2/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-07-08T14:00:47Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/wifi"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/local"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Nimes"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unimes.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Nimes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://averell.unimes.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Eduspot - Nimes University"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Portail captif Univnautes - Universit\u00e9 de N\u00eemes"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.unimes.fr/skins/Univ-Nimes/resources/img/logo-unimes.png",
                    "height": "151",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "147"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Eduspot - Nimes University"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Portail Captif Univnautes - Universit\u00e9 de N\u00eemes"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEUTCCAzmgAwIBAgIBADANBgkqhkiG9w0BAQUFADB9MQswCQYDVQQGEwJGUjEN\nMAsGA1UECBMER2FyZDEOMAwGA1UEBxMFTmltZXMxDzANBgNVBAoTBlVuaW1lczEo\nMCYGCSqGSIb3DQEJARYZb2xpdmllci5mYWx6b25lQHVuaW1lcy5mcjEUMBIGA1UE\nAxMLaW50ZXJuYWwtY2EwHhcNMTMwNzA4MTExMTU0WhcNMjMwNzA2MTExMTU0WjB9\nMQswCQYDVQQGEwJGUjENMAsGA1UECBMER2FyZDEOMAwGA1UEBxMFTmltZXMxDzAN\nBgNVBAoTBlVuaW1lczEoMCYGCSqGSIb3DQEJARYZb2xpdmllci5mYWx6b25lQHVu\naW1lcy5mcjEUMBIGA1UEAxMLaW50ZXJuYWwtY2EwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDE+lfDp2RWVlMLP3x8TW02kx6ctJvtLoaz+qJzz7m5/a/a\n2OLO9/qGF5mFNlkGuo9Jc1nU+dyldBZhc2AFVZBZ8gXKay4gIvXfuKFLgPBIDO4r\ng6UhPYrKnVLsu2ubZNOpuGV6U5C9Fn+0ujtjmCqDyO7WVOmk3cnd1v0OYBMM+FQu\nacqKQU2hM+7Z3pAZ5vmarofS7ruI1lL4cPthXhUWC94cGCewlixYIX8AVEOXhrx8\nugGr4Yc/+scusm2opSfYOO44SONJpd2UAWHEKuLAkMhdT6j1kIzo2fvw7oT4c6j/\nVRGL6bVZNyYO8RohuCdfrs7fW/CItv1VDQwIyN/1AgMBAAGjgdswgdgwHQYDVR0O\nBBYEFEGc2vp8DvLW7KwnfwLGZQ7VmuNXMIGoBgNVHSMEgaAwgZ2AFEGc2vp8DvLW\n7KwnfwLGZQ7VmuNXoYGBpH8wfTELMAkGA1UEBhMCRlIxDTALBgNVBAgTBEdhcmQx\nDjAMBgNVBAcTBU5pbWVzMQ8wDQYDVQQKEwZVbmltZXMxKDAmBgkqhkiG9w0BCQEW\nGW9saXZpZXIuZmFsem9uZUB1bmltZXMuZnIxFDASBgNVBAMTC2ludGVybmFsLWNh\nggEAMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAC1stNrPLwVX5HKT\nA8zdX1CIqPxdaLPIgCqDqteResAAP2OjqBV7Scb9CAXsltwEanIPLOP2ynstERCw\nCnRWWwltWn2jIf1JWBVMGJKwN7YOQGZogABAsbuTlWQo/bIeFEkkLSaqlICQhEvM\nHJ6AKj0GUxyDr3VLSgCa9g4pj1gBINst/mKj0mPSGL+fHvzbFlEjGSnthIdcPqQG\nCqjOMoX6iPj3vvAXSo++WFj+VYDOq/DSdZq2z1mwUZ78qpiQJ+KT7FOkurZjaOsy\neVfJ8kjDRKJ3wAixUi1+wFuVdpGnUbFLYhMQZdnXblhMzFE3uzni83QirSmLOemI\nKLb8WUE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEUTCCAzmgAwIBAgIBADANBgkqhkiG9w0BAQUFADB9MQswCQYDVQQGEwJGUjEN\nMAsGA1UECBMER2FyZDEOMAwGA1UEBxMFTmltZXMxDzANBgNVBAoTBlVuaW1lczEo\nMCYGCSqGSIb3DQEJARYZb2xpdmllci5mYWx6b25lQHVuaW1lcy5mcjEUMBIGA1UE\nAxMLaW50ZXJuYWwtY2EwHhcNMTMwNzA4MTExMTU0WhcNMjMwNzA2MTExMTU0WjB9\nMQswCQYDVQQGEwJGUjENMAsGA1UECBMER2FyZDEOMAwGA1UEBxMFTmltZXMxDzAN\nBgNVBAoTBlVuaW1lczEoMCYGCSqGSIb3DQEJARYZb2xpdmllci5mYWx6b25lQHVu\naW1lcy5mcjEUMBIGA1UEAxMLaW50ZXJuYWwtY2EwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDE+lfDp2RWVlMLP3x8TW02kx6ctJvtLoaz+qJzz7m5/a/a\n2OLO9/qGF5mFNlkGuo9Jc1nU+dyldBZhc2AFVZBZ8gXKay4gIvXfuKFLgPBIDO4r\ng6UhPYrKnVLsu2ubZNOpuGV6U5C9Fn+0ujtjmCqDyO7WVOmk3cnd1v0OYBMM+FQu\nacqKQU2hM+7Z3pAZ5vmarofS7ruI1lL4cPthXhUWC94cGCewlixYIX8AVEOXhrx8\nugGr4Yc/+scusm2opSfYOO44SONJpd2UAWHEKuLAkMhdT6j1kIzo2fvw7oT4c6j/\nVRGL6bVZNyYO8RohuCdfrs7fW/CItv1VDQwIyN/1AgMBAAGjgdswgdgwHQYDVR0O\nBBYEFEGc2vp8DvLW7KwnfwLGZQ7VmuNXMIGoBgNVHSMEgaAwgZ2AFEGc2vp8DvLW\n7KwnfwLGZQ7VmuNXoYGBpH8wfTELMAkGA1UEBhMCRlIxDTALBgNVBAgTBEdhcmQx\nDjAMBgNVBAcTBU5pbWVzMQ8wDQYDVQQKEwZVbmltZXMxKDAmBgkqhkiG9w0BCQEW\nGW9saXZpZXIuZmFsem9uZUB1bmltZXMuZnIxFDASBgNVBAMTC2ludGVybmFsLWNh\nggEAMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAC1stNrPLwVX5HKT\nA8zdX1CIqPxdaLPIgCqDqteResAAP2OjqBV7Scb9CAXsltwEanIPLOP2ynstERCw\nCnRWWwltWn2jIf1JWBVMGJKwN7YOQGZogABAsbuTlWQo/bIeFEkkLSaqlICQhEvM\nHJ6AKj0GUxyDr3VLSgCa9g4pj1gBINst/mKj0mPSGL+fHvzbFlEjGSnthIdcPqQG\nCqjOMoX6iPj3vvAXSo++WFj+VYDOq/DSdZq2z1mwUZ78qpiQJ+KT7FOkurZjaOsy\neVfJ8kjDRKJ3wAixUi1+wFuVdpGnUbFLYhMQZdnXblhMzFE3uzni83QirSmLOemI\nKLb8WUE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://averell.unimes.fr/authsaml2/singleSignOnPost",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Portail Captif Univnautes - Universit\u00e9 de N\u00eemes"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Eduspot - Nimes University"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Portail captif Univnautes - Universit\u00e9 de N\u00eemes"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Eduspot - Nimes University"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ifs00sv056.ifsul.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Maicon Anca dos Santos"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dtic@ifsul.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ifs00sv056.ifsul.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEajCCA1ICAQAwDQYJKoZIhvcNAQEFBQAwgfoxNDAyBgNVBAoTK0lGU3VsIC0g\nSW5zdGl0dXRvIEZlZGVyYWwgU3VsLXJpby1ncmFuZGVuc2UxQzBBBgNVBAsTOkRU\nSUMgLSBEaXJldG9yaWEgZGUgVGVjbm9sb2dpYSBkYSBJbmZvcm1hY2FvIGUgQ29t\ndW5pY2FjYW8xIDAeBgkqhkiG9w0BCQEWEWR0aWNAaWZzdWwuZWR1LmJyMRAwDgYD\nVQQHEwdQZWxvdGFzMRowGAYDVQQIExFSaW8gR3JhbmRlIGRvIFN1bDELMAkGA1UE\nBhMCQlIxIDAeBgNVBAMTF2lmczAwc3YwNTYuaWZzdWwuZWR1LmJyMB4XDTEzMDkx\nMDE0MDUxOFoXDTE2MDkwOTE0MDUxOFowgfoxNDAyBgNVBAoTK0lGU3VsIC0gSW5z\ndGl0dXRvIEZlZGVyYWwgU3VsLXJpby1ncmFuZGVuc2UxQzBBBgNVBAsTOkRUSUMg\nLSBEaXJldG9yaWEgZGUgVGVjbm9sb2dpYSBkYSBJbmZvcm1hY2FvIGUgQ29tdW5p\nY2FjYW8xIDAeBgkqhkiG9w0BCQEWEWR0aWNAaWZzdWwuZWR1LmJyMRAwDgYDVQQH\nEwdQZWxvdGFzMRowGAYDVQQIExFSaW8gR3JhbmRlIGRvIFN1bDELMAkGA1UEBhMC\nQlIxIDAeBgNVBAMTF2lmczAwc3YwNTYuaWZzdWwuZWR1LmJyMIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuz4oD/NvC0Hwk0WhnCSYP29C98DOVwJ8sjOT\n1tfcOSkYq2DfXvI9macZLWi6PY8moeOGRlUCquo+w3Y1PJpwj0Hck0+HNN3JchyA\niKr5LqnS/Ukx5M/CSvrwaeu7uA2Mpqv5PtfnUaU4ytDGBtWX/w1TgxbOTLFQ47UN\n69+359uqqHTvUFiRSPYGE7xGrpu6lq5A5Q/E6mkCMtypRAHH9Ld6fFH7AAWiExJH\nSGJq5rRoml2GTzm786NeM4rc4hIBkE9GuUyTtix6VJumm9PkF3HctGQZRYT/Iwi+\nPyISeGuDy2JWQy+VYgLBuyGsXo3O9LVMVe/sTUPr+2gU52AD1QIDAQABMA0GCSqG\nSIb3DQEBBQUAA4IBAQB1yTZ5bnXiK5+4mMT6NSQvkxnBn6KAu5hau+MREI3WM3CL\n+3udcHBNFkxSEL1BVJjfrg40IzSic5rVQ8pK9EWyhey4AcD9BBkrdem0P7Z+0+PJ\npV6SV+n0MoAGf7VJxxXaX4JcJmrwQOXhj0v+YhOoBmmm3ccCrmzWvWpKPO/NgUYR\nmXkx/UZzoIc8si4G4f0tdrteQMtpq3p31STZAX7kIr7Ih2GwQXWRqvyRmd0CtAwE\n0YO4sFwtY/JBMQIwBDQNYFv6H/+6wo24inxILDSj/jHX60t/tSKPBRdkN0JXnv1A\n2EfD1BzA7Hv6BsAWRmUYnsxjtSsQc4LJizwpTTvp"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ifs00sv056.ifsul.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://ifs00sv056.ifsul.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ifs00sv056.ifsul.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ifs00sv056.ifsul.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://ifs00sv056.ifsul.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ifs00sv056.ifsul.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ifs00sv056.ifsul.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://ifs00sv056.ifsul.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifsul.edu.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifsul.edu.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFSul - Instituto Federal Sul-rio-grandense"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFSul - Instituto Federal Sul-rio-grandense"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFSul - Instituto Federal Sul-rio-grandense"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFSul - Instituto Federal Sul-rio-grandense"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEajCCA1ICAQAwDQYJKoZIhvcNAQEFBQAwgfoxNDAyBgNVBAoTK0lGU3VsIC0g\nSW5zdGl0dXRvIEZlZGVyYWwgU3VsLXJpby1ncmFuZGVuc2UxQzBBBgNVBAsTOkRU\nSUMgLSBEaXJldG9yaWEgZGUgVGVjbm9sb2dpYSBkYSBJbmZvcm1hY2FvIGUgQ29t\ndW5pY2FjYW8xIDAeBgkqhkiG9w0BCQEWEWR0aWNAaWZzdWwuZWR1LmJyMRAwDgYD\nVQQHEwdQZWxvdGFzMRowGAYDVQQIExFSaW8gR3JhbmRlIGRvIFN1bDELMAkGA1UE\nBhMCQlIxIDAeBgNVBAMTF2lmczAwc3YwNTYuaWZzdWwuZWR1LmJyMB4XDTEzMDkx\nMDE0MDUxOFoXDTE2MDkwOTE0MDUxOFowgfoxNDAyBgNVBAoTK0lGU3VsIC0gSW5z\ndGl0dXRvIEZlZGVyYWwgU3VsLXJpby1ncmFuZGVuc2UxQzBBBgNVBAsTOkRUSUMg\nLSBEaXJldG9yaWEgZGUgVGVjbm9sb2dpYSBkYSBJbmZvcm1hY2FvIGUgQ29tdW5p\nY2FjYW8xIDAeBgkqhkiG9w0BCQEWEWR0aWNAaWZzdWwuZWR1LmJyMRAwDgYDVQQH\nEwdQZWxvdGFzMRowGAYDVQQIExFSaW8gR3JhbmRlIGRvIFN1bDELMAkGA1UEBhMC\nQlIxIDAeBgNVBAMTF2lmczAwc3YwNTYuaWZzdWwuZWR1LmJyMIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuz4oD/NvC0Hwk0WhnCSYP29C98DOVwJ8sjOT\n1tfcOSkYq2DfXvI9macZLWi6PY8moeOGRlUCquo+w3Y1PJpwj0Hck0+HNN3JchyA\niKr5LqnS/Ukx5M/CSvrwaeu7uA2Mpqv5PtfnUaU4ytDGBtWX/w1TgxbOTLFQ47UN\n69+359uqqHTvUFiRSPYGE7xGrpu6lq5A5Q/E6mkCMtypRAHH9Ld6fFH7AAWiExJH\nSGJq5rRoml2GTzm786NeM4rc4hIBkE9GuUyTtix6VJumm9PkF3HctGQZRYT/Iwi+\nPyISeGuDy2JWQy+VYgLBuyGsXo3O9LVMVe/sTUPr+2gU52AD1QIDAQABMA0GCSqG\nSIb3DQEBBQUAA4IBAQB1yTZ5bnXiK5+4mMT6NSQvkxnBn6KAu5hau+MREI3WM3CL\n+3udcHBNFkxSEL1BVJjfrg40IzSic5rVQ8pK9EWyhey4AcD9BBkrdem0P7Z+0+PJ\npV6SV+n0MoAGf7VJxxXaX4JcJmrwQOXhj0v+YhOoBmmm3ccCrmzWvWpKPO/NgUYR\nmXkx/UZzoIc8si4G4f0tdrteQMtpq3p31STZAX7kIr7Ih2GwQXWRqvyRmd0CtAwE\n0YO4sFwtY/JBMQIwBDQNYFv6H/+6wo24inxILDSj/jHX60t/tSKPBRdkN0JXnv1A\n2EfD1BzA7Hv6BsAWRmUYnsxjtSsQc4LJizwpTTvp"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFSul - Instituto Federal Sul-rio-grandense"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFSul - Instituto Federal Sul-rio-grandense"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifsul.edu.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifsul.edu.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFSul - Instituto Federal Sul-rio-grandense"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFSul - Instituto Federal Sul-rio-grandense"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.childlink.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McCune"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:adammccune@gmail.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McCune"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:adammccune@gmail.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.childlink.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-08-01T16:19:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Childlink Information Service"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.childlink.co.uk/about_us.php"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Childlink Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.childlink.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.childlink.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.childlink.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.childlink.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "logo": [
                  {
                    "text": "https://www.childlink.co.uk/images/childlink_wayf_logo.gif",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Childlink Information Service"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.childlink.co.uk/Shibboleth.sso/WAYF/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/DCCAeQCCQCh6QBQgqGHfDANBgkqhkiG9w0BAQUFADBAMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjETMBEGA1UEChMKQ2hpbGQgTGluazEcMBoGA1UEAxMTd3d3LmNoaWxkbGluay5j\n\t\t\t\t\t\tby51azAeFw0xNDA0MTAxMDExMDlaFw0zNDA0MDUxMDExMDlaMEAxCzAJBgNVBAYT\n\t\t\t\t\t\tAkdCMRMwEQYDVQQKEwpDaGlsZCBMaW5rMRwwGgYDVQQDExN3d3cuY2hpbGRsaW5r\n\t\t\t\t\t\tLmNvLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAs4Z92m8/+i1t\n\t\t\t\t\t\t2UfQc99uMI8HNlYLHtu5gR1TtvsOSQG+SBtQmB2NkpxyVL3XkasTRPT0knwWTxgu\n\t\t\t\t\t\tTTLDuCVDeL9lr2t1DF9tCCXJWy1jCWxrcn3tUhwAV6ki4cIPmGrv+voKyAt4eY7m\n\t\t\t\t\t\twTYLD0QRQ8qYcIHd1m1kP7PEiHy3Tejd3ZoeWYRCiko0HDLGW9PTAZAniSQAWPRT\n\t\t\t\t\t\tKhuiLHOOA1SRnk+EkoDAZzV9PcpzGayhIKDH3asqpi06asAbU1wfmZBL9Yxh+QHv\n\t\t\t\t\t\tSK8l3ZI91SN78024wp5kTeIaulsY84XgQyFgxXtRaAehGko/sfMS09yBBDHHS/fl\n\t\t\t\t\t\t5z0lm/QOZwIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQBLvSfOj2ehKrEGA+lzNXwx\n\t\t\t\t\t\tS9gc8jORwmN8Q1jBqdO3URMbmY8d9kgX+qYoNHKuDv3dhMQzqmcbPnH8lVpd8JSr\n\t\t\t\t\t\tC77QYlULzeRgLQm7CVxnafMTUFyLjNrH5OGj+FixSjAaajxPjO2dV2D7d4sglvRG\n\t\t\t\t\t\tKBupx5dqhqaAaMS01tXMRcHWylHkg1/UWxhunnVDs8vAzKhGOF1SvdRG8jB3zuJa\n\t\t\t\t\t\tnKVEi4fGw65i9apDSYscpk2Kvyeu89/UGTq1N3UZdZqkIMgr/Y9TZL5w+n4kl1aN\n\t\t\t\t\t\tT58weS7Nep9P2UuLPrDhrbAGb0fT0LHFBkeMy2Z8/5JH5HRqCt60B9Z0Xtz7/Fyh"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.childlink.co.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.childlink.co.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.childlink.co.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.childlink.co.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.childlink.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.childlink.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.childlink.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.childlink.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.childlink.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.childlink.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://zeus.grnet.gr/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@grnet.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Greek Research and Technology Network"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "800-11-47638"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+30-2109569181"
            }
          ]
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@grnet.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Greek Research and Technology Network"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "800-11-47638"
            }
          ]
        }
      ],
      "entity_id": "https://zeus.grnet.gr/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Greek Research and Technology Network"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u0395\u03b8\u03bd\u03b9\u03ba\u03cc \u0394\u03af\u03ba\u03c4\u03c5\u03bf \u0388\u03c1\u03b5\u03c5\u03bd\u03b1\u03c2 \u03ba\u03b1\u03b9 \u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03af\u03b1\u03c2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.grnet.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.grnet.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Greek Research and Technology Network"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u0395\u03b8\u03bd\u03b9\u03ba\u03cc \u0394\u03af\u03ba\u03c4\u03c5\u03bf \u0388\u03c1\u03b5\u03c5\u03bd\u03b1\u03c2 \u03ba\u03b1\u03b9 \u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03af\u03b1\u03c2"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://zeus.grnet.gr/zeus/auth/auth/shibboleth/default/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://zeus.grnet.gr/zeus/auth/auth/shibboleth/default/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://zeus.grnet.gr/zeus/auth/auth/shibboleth/default/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://zeus.grnet.gr/zeus/auth/auth/shibboleth/default/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://zeus.grnet.gr/zeus/auth/auth/shibboleth/default/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://zeus.grnet.gr/zeus/"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://zeus.grnet.gr/zeus/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Zeus Elections"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u03a8\u03b7\u03c6\u03bf\u03c6\u03bf\u03c1\u03af\u03b5\u03c2 \u00ab\u0396\u03b5\u03c5\u03c2\u00bb"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Zeus Digital Ballot Box is an information system for unimpeachable conduct of confidential voting by purely electronic means"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "\u0397 \u00ab\u03a8\u03b7\u03c6\u03b9\u03b1\u03ba\u03ae \u039a\u03ac\u03bb\u03c0\u03b7 \u0396\u03b5\u03c5\u03c2\u00bb \u03b5\u03af\u03bd\u03b1\u03b9 \u03ad\u03bd\u03b1 \u03c0\u03bb\u03b7\u03c1\u03bf\u03c6\u03bf\u03c1\u03b9\u03b1\u03ba\u03cc \u03c3\u03cd\u03c3\u03c4\u03b7\u03bc\u03b1 \u03b3\u03b9\u03b1 \u03c4\u03b7\u03bd \u03b1\u03b4\u03b9\u03ac\u03b2\u03bb\u03b7\u03c4\u03b7 \u03b4\u03b9\u03b5\u03be\u03b1\u03b3\u03c9\u03b3\u03ae \u03b1\u03c0\u03cc\u03c1\u03c1\u03b7\u03c4\u03c9\u03bd \u03c8\u03b7\u03c6\u03bf\u03c6\u03bf\u03c1\u03b9\u03ce\u03bd \u03bc\u03b5 \u03b1\u03bc\u03b9\u03b3\u03ce\u03c2 \u03b7\u03bb\u03b5\u03ba\u03c4\u03c1\u03bf\u03bd\u03b9\u03ba\u03cc \u03c4\u03c1\u03cc\u03c0\u03bf"
                  }
                ],
                "logo": [
                  {
                    "text": "https://zeus.grnet.gr/static/zeus/images/zeus-logo-en.png",
                    "lang": "en",
                    "height": "150",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "890"
                  },
                  {
                    "text": "https://zeus.grnet.gr/static/zeus/images/zeus-logo-el.png",
                    "lang": "el",
                    "height": "150",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "890"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://zeus.grnet.gr/zeus/terms/"
                  }
                ]
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://zeus.grnet.gr/zeus/auth/auth/shibboleth/default/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://zeus.grnet.gr/zeus/auth/auth/shibboleth/default/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://zeus.grnet.gr/shibboleth"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "zeus.grnet.gr"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEDCCAfigAwIBAgIJANMdvx+ohi/gMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n                            BAMTDXpldXMuZ3JuZXQuZ3IwHhcNMTYwMjEwMTgzODA0WhcNMjEwMjA4MTgzODA0\n                            WjAYMRYwFAYDVQQDEw16ZXVzLmdybmV0LmdyMIIBIjANBgkqhkiG9w0BAQEFAAOC\n                            AQ8AMIIBCgKCAQEAqZY6MxafENaLnAJEfcQiLe6/q5Pq6SKrihjXRhUVWM+0O7UN\n                            wcVUBnxRqrPA9agOlz0g5619zlfVEwk2QP0iEMKH+1tepVTVulv7QtnQBtaA0vgt\n                            L/iCzvT2CqvhtSNy2NeHuy8HTgaMULaOl7Tf+9cb4qHZbGq3M7YLfMaNWsequmgO\n                            pOd/wYd/o+ba2vtFHcGPTaG1EktGei6hszOihckovBp9yqcntta5XHT06IGOdmln\n                            WS6lakzZ60atmJEdCImq3HjiGce6B6oHxFecWczFi7IgMFtz/aDCQQfVUxzTDdTi\n                            VYhemVnpUBgx2C+sDHQwPTXe9/qQ95UeRznFxwIDAQABo10wWzA6BgNVHREEMzAx\n                            gg16ZXVzLmdybmV0LmdyhiBodHRwczovL3pldXMuZ3JuZXQuZ3Ivc2hpYmJvbGV0\n                            aDAdBgNVHQ4EFgQUNS9rEXnxxLZ028nq/p6Bcx3yI6YwDQYJKoZIhvcNAQEFBQAD\n                            ggEBAGheIDudyldnOYqUWxtfiQ0Q9tt/EVTIixALgYxHCGnZO/OfVlyAwwbnHYf2\n                            r5TJ18HIonEruAGsugPyq8WLANxPINVqry1g6OkgQ959NU6idwJt4fCVe4XE/heY\n                            vnMMNe/Ql01Xph7NgyiB85ABbBr+5YVoKhd7PiDm7h/x9Bp7hlHKFUFuMnx6DsQQ\n                            ONH6NcbuvZtVBDXENeSemkqEG8qxKegGQ4OJM55QRQEt0ZcH2i6EL7y4Mgca8NkP\n                            tUjWB99zWt4Ske4Prz5RAiSsfYvZHl1v4NjFJtSbIp/u8oW8Xk/WSxTrVdq+eqSH\n                            BeFAMmfxrsmNkv2p7y88VjtdsHc="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=zeus.grnet.gr"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://zeus.grnet.gr/zeus/auth/auth/shibboleth/default/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://zeus.grnet.gr/zeus/auth/auth/shibboleth/default/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://zeus.grnet.gr/zeus/auth/auth/shibboleth/default/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://zeus.grnet.gr/zeus/auth/auth/shibboleth/default/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://zeus.grnet.gr/zeus/auth/auth/shibboleth/default/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://zeus.grnet.gr/zeus/auth/auth/shibboleth/default/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Zeus Digital Ballot Box is an information system for unimpeachable conduct of confidential voting by purely electronic means"
                },
                {
                  "lang": "el",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "\u0397 \u00ab\u03a8\u03b7\u03c6\u03b9\u03b1\u03ba\u03ae \u039a\u03ac\u03bb\u03c0\u03b7 \u0396\u03b5\u03c5\u03c2\u00bb \u03b5\u03af\u03bd\u03b1\u03b9 \u03ad\u03bd\u03b1 \u03c0\u03bb\u03b7\u03c1\u03bf\u03c6\u03bf\u03c1\u03b9\u03b1\u03ba\u03cc \u03c3\u03cd\u03c3\u03c4\u03b7\u03bc\u03b1 \u03b3\u03b9\u03b1 \u03c4\u03b7\u03bd \u03b1\u03b4\u03b9\u03ac\u03b2\u03bb\u03b7\u03c4\u03b7 \u03b4\u03b9\u03b5\u03be\u03b1\u03b3\u03c9\u03b3\u03ae \u03b1\u03c0\u03cc\u03c1\u03c1\u03b7\u03c4\u03c9\u03bd \u03c8\u03b7\u03c6\u03bf\u03c6\u03bf\u03c1\u03b9\u03ce\u03bd \u03bc\u03b5 \u03b1\u03bc\u03b9\u03b3\u03ce\u03c2 \u03b7\u03bb\u03b5\u03ba\u03c4\u03c1\u03bf\u03bd\u03b9\u03ba\u03cc \u03c4\u03c1\u03cc\u03c0\u03bf"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Zeus Elections"
                },
                {
                  "lang": "el",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "\u03a8\u03b7\u03c6\u03bf\u03c6\u03bf\u03c1\u03af\u03b5\u03c2 \u00ab\u0396\u03b5\u03c5\u03c2\u00bb"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "false",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "false",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonTargetedID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "false",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:mail",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.upv.es/saml/module.php/saml/sp/metadata.php/upv-sp-saml",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "identidades@upv.es"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ASIC-UPV"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.upv.es/saml/module.php/saml/sp/metadata.php/upv-sp-saml",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.rediris.es/sir/edugain/SIR_MRPS.pdf"
              }
            ],
            "registration_instant": "2013-05-15T10:18:00Z",
            "registration_authority": "http://www.rediris.es/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universitat Polit\u00e8cnica de Val\u00e8ncia"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universitat Polit\u00e8cnica de Val\u00e8ncia"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.upv.es/"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.upv.es/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universitat Polit\u00e8cnica de Val\u00e8ncia"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universitat Polit\u00e8cnica de Val\u00e8ncia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.upv.es/saml/module.php/saml/sp/saml2-logout.php/upv-sp-saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.upv.es/saml/module.php/saml/sp/saml2-acs.php/upv-sp-saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp.upv.es/saml/module.php/saml/sp/saml1-acs.php/upv-sp-saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.upv.es/saml/module.php/saml/sp/saml2-acs.php/upv-sp-saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp.upv.es/saml/module.php/saml/sp/saml1-acs.php/upv-sp-saml/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:profiles:holder-of-key:SSO:browser",
              "location": "https://sp.upv.es/saml/module.php/saml/sp/saml2-acs.php/upv-sp-saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-10.ladok.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-10.ladok.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;10"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;10"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-10.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-10.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAMWbtSdAnrAVMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0xMC5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTQ0MzE4WhcNMjQx\nMDA0MTQ0MzE4WjAhMR8wHQYDVQQDExZsYWRvazMtMTAubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnDpADu728OIV57+XopAF7/6A\n0a26Wa8qO0WS4hsIcqPdkIq27kPgsPbm7sh1pKBAQ/BG3wCFSvc3t15ul8NxckCI\nbd4miJxPTP6AIAw3h0WAKGWYmVBKXodhW2PLwkS+bmUva6z2xncWG8/jXsTxPdJK\nilx+SnLgHgCbUOxOdWgc8TZI2sGpC/8S+wrxiY21/mueg4jMzq4tlTz7L+5bJvoH\nom+qi42iUPYWdbqPXgZx79NjAyA0c82lzbMiwG2OCcPrA0DjajyIsm2c3vpddTMK\nE7ErtBkctwPGZDjypQz7pmIrYoA+O3CO5VdUJfmUFr/NEPo1Oh/QnKU40D6i6wID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMTAubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0xMC5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUAkkqvZzOBJ82CEDGCrZQnN1is8EwDQYJKoZIhvcNAQEFBQADggEB\nAEq9QB0UetFzg9pXEXPwlpT6Fc15uF5bRxmRMrqi4Sbv7XUBZzBIxmJYdFqzJd50\nnSBzBJ2qDrtkK2FMRQwWNwo86XGdyiufQMlwzkIE0dKBkzHIi+Zqbwp8yGV4ezR4\ntwW+VeeLOfAYUdGNQy3aB40c2E1uekz+rOxpGyas0Uhjf97HT6r3ydGYK2gpv3kt\nZZUz8BdNuajMBgDmW3z2BHnhALPtNBIxNF+8fhUEfFUfjGRvd20Kj5BybjyX+HP1\n6Dl6Et7Dxr9UooyconthAy8uqv4R9aCr+FkFIR1QWbg2rfnR6FVnJ+D9LL4l0JkG\n7qpp/QqMhIdfb1k6Z+/eZzM="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-10.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-10.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://adfs01.fhs.se/adfs/services/trust",
    {
      "entity_id": "http://adfs01.fhs.se/adfs/services/trust",
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://adfs01.fhs.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://adfs01.fhs.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://adfs01.fhs.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://adfs01.fhs.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://adfs01.fhs.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://adfs01.fhs.se/adfs/services/trust/artifactresolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fhs.se"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "student.fhs.se"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "op.fhs.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.fhs.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.fhs.se/en/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r F\u00f6rsvarsh\u00f6gskolan"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Swedish National Defence College"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.fhs.se/files/sidhuvud/logotyp-sv.jpg",
                    "lang": "sv",
                    "height": "118",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "106"
                  },
                  {
                    "text": "https://www.fhs.se/files/sidhuvud/logotyp-en.jpg",
                    "lang": "en",
                    "height": "116",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "103"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "F\u00f6rsvarsh\u00f6gskolan"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Swedish National Defence College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "fhs.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute": [
            {
              "friendly_name": "E-Mail Address",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/emailaddress",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Given Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/givenname",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/name",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "UPN",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/upn",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Common Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/CommonName",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "AD FS 1.x E-Mail Address",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/EmailAddress",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Group",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/Group",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "AD FS 1.x UPN",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/UPN",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Role",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/role",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Surname",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/surname",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "PPID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/privatepersonalidentifier",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Name ID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/nameidentifier",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Authentication time stamp",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/authenticationinstant",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Authentication method",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/authenticationmethod",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Deny only group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/denyonlysid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Deny only primary SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/denyonlyprimarysid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Deny only primary group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/denyonlyprimarygroupsid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/groupsid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Primary group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/primarygroupsid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Primary SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/primarysid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Windows account name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/windowsaccountname",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "eduPersonScopedAffiliation",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/eduPersonScopedAffiliation",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            }
          ],
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 8 55342545"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "FHS IT Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@fhs.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Swedish Defence University"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 8 55342545"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "FHS IT Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@fhs.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Swedish Defence University"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 08 55342545"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "FHS IT Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@fhs.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Swedish Defence University"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "F\u00f6rsvarsh\u00f6gskolan"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish National Defence College"
          }
        ],
        "organization_url": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fhs.se/"
          }
        ],
        "organization_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "F\u00f6rsvarsh\u00f6gskolan"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor"
    }
  ],
  [
    "https://idp.lboro.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.lboro.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/lboro.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/lboro.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lboro.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Loughborough University (ATHENS)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lboro.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://hades.slu.se/shibboleth",
    {
      "entity_id": "https://hades.slu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hades.slu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://hades.slu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hades.slu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hades.slu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hades.slu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://hades.slu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://hades.slu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "fme1-1.ad.slu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAID0pitDTgz2MA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGZtZTEtMS5hZC5zbHUuc2UwHhcNMTIwNjI3MDg0NDEzWhcNMjIwNjI1MDg0\nNDEzWjAbMRkwFwYDVQQDExBmbWUxLTEuYWQuc2x1LnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAw7oOCbv2+Z2jh0uM6YlV7Q9sF0uH03jBj67JPA4r\nCIXIFdJ/g7gLliZa+DjxaNlPxQAE4xc3vGGO7TUyKCftvRIUI49Phm8WKtapy6XE\nPb52xE0ie+B0RO2boUG9xiM50WlZT0VsmdYjwHey7fT5UZjaGa/PLOAAoKXLvfJG\nVQb1IAO8bQ+k4XWf/2oR2BLEKWmy3xW1T4ew34SmAPcpbwZOxj5t0GRDt6lblHvG\nL4KB5a6hEOuU+0U0KjFYKG2PYLJUB4RM6ctmGOnuwUyoWmFAN1h4OZzXoyckr8u2\ngdaWyFL+k/ojckmw5aaJBpce332Bh9wy53W6J77qa0ANawIDAQABoz4wPDAbBgNV\nHREEFDASghBmbWUxLTEuYWQuc2x1LnNlMB0GA1UdDgQWBBSrX7qpYidl+M3/uMRp\nBZk7JtDvtTANBgkqhkiG9w0BAQUFAAOCAQEAAh37ouHU+pXCxffOUOrDNkBSJSAb\nmmD67HCLmcdLwMxBLji/M/FTK5RYdxlwAwK5F1ntbHovDJKWMva7wuWzmjbcSJ6R\nJVrolJWJDR+Fc84L2Lh1Q3sVOXjDXU5Lw+yYApNcs+f2TdYZEa9HDqTyEjupjecd\na7N6bBlELYgoYFbTpg8AmQOsvVl2yQQiX07lBHHeGOn4i1bbB6ip6exRTxUqf0Ed\nQM0LY0RQjVj4+R+UdaRYQfizHG1rnKcEiRzi/mXYt2YXSjKuyvNUn6uc1GY9/3aJ\n9wX+6Hnwlg8X2wAoLJDLxAoOWSUSyPLCSzqp90tYAn1L6/pX68R46PWq4Q=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=fme1-1.ad.slu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hades.slu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://hades.slu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hades.slu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://hades.slu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://hades.slu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://hades.slu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://federation.icer.niaid.nih.gov/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-support@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Technical Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-support@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-support@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Technical Support"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-admin@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Administrative Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federation.icer.niaid.nih.gov/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "National Institutes of Health"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nih.gov/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National Institutes of Health"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federation.scienceforum.sc/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.scienceforum.sc/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://scienceforum.sc/adfs-global.html"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Requests and obtains identity assertions on behalf of Windows-based web applications operated by NIAID"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://scienceforum.sc/privacy.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NIAID Science Forum Federation Gateway"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFezCCA2OgAwIBAgIJALYMiWa4l0I2MA0GCSqGSIb3DQEBDQUAMFQxJjAkBgNV\nBAMMHWZlZGVyYXRpb24uaWNlci5uaWFpZC5uaWguZ292MSowKAYJKoZIhvcNAQkB\nFhtpY2VyLXZyby1hZG1pbkBsaXN0Lm5paC5nb3YwHhcNMTYwMTA4MTgyNzE1WhcN\nMjYwMTA1MTgyNzE1WjBUMSYwJAYDVQQDDB1mZWRlcmF0aW9uLmljZXIubmlhaWQu\nbmloLmdvdjEqMCgGCSqGSIb3DQEJARYbaWNlci12cm8tYWRtaW5AbGlzdC5uaWgu\nZ292MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEA6RkYI8piZAZInxSQ\n2PAw8OyBbKDwi3L7d8aE3OWqoquBg8RN0aQsC6yGB4IlYXNDCi3OL5VthNwfAfDh\n0sXbIrdvT27Np42iYpl/U6wO59011bycFJSdoadJ4LtyVh2VPy2iZQq5p6a2t4Yf\n54Goepn0RkBZVT9xDt4iO15u09YkVrmdSv00NuWjZ+R8Y5Dwr9tu7VO1mzy0l0Q3\nv9raY591+8soasFcG2kC+6Mohr1uqbngjokVrpniAGPKVO0J3feaWV9Cev6qaavE\nk5A2cEXMTPOBluZk4ZACWNHA7CgUzDSxtBQpG/k9ZE5le7XHM450VIYhbrfn1DiB\nLRZJFJZohEQrQqKA7ny1JF2cShLgpcx1Lbr0Q3ZDHRZDAFcLjy5ewyyLncuZ5vYv\n562sNaG5xNmV85kKhBeD1258ueGLC2Ab/VjPSTqL9LrReo/KF6byAIIFnFX7LaLl\nedvakvNlWRu3v+TQpiVPcDF4pxMggosYy1p8I0PI8dctcDtBY2mUmjNRI3TxQf41\nNiLaKTmxTFuSxjTQ/7XAQ6WkLc6A/pRFo04Rls1nac7q0PswjMaPBVWAeI9T/WnC\nEWnIeTx08j0o1RDAHnhar+JOhcr1eYQkiN+HTsr9BXd1pkFp3xbco7kja9pzSwJA\nSXapouWF6YR31plWt7eCMBeEKVsCAwEAAaNQME4wHQYDVR0OBBYEFL4YbQSM+69j\njVPRtF+/4YIRxQvYMB8GA1UdIwQYMBaAFL4YbQSM+69jjVPRtF+/4YIRxQvYMAwG\nA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQENBQADggIBACijR28JRebVoXBABqukuPdo\nVKEi3OfQn9+lLziYUQVsC76cFXs7G9oV5GHA1dP3rQH/rt7Q7V9P24AQ5nVQKh6O\njG+JS0fiHHip8ee8MHnrs/SlPPEATcZSc/lmgpaKnkLx4IONgFM0qT+BhN5baMCy\ng/VL3TSO9MFxn1lH76om9nJ5eSc859tJqaqwrq/q1UMTLS2+iLe8oaEsW5sFyKL7\nzZNBBmXNvaXqvhATDwRrbroZnPqWtGxbZIr81fi9haqHv/goZCOmMj1Qk9VqGyHs\nccJ46dE1kaTJNjrNxmjfwsg77dj7i/XwJtrOKiNmk1pwvAPI8Vvgu47mfMBdQv7Y\nt5NpSIlK1D+xRy5a02a6nXBdz5NyHRYwo9/r1Xnu5PTDnUjPyAchTtuaCA1d7bgU\n9Wt2D1EkssTYyw5U/tr75iEWKvuTvmZtThmiJjrIrW2GCRD6FjiJEtx9o1xO5mCv\n9+E4qtSoyldzmQrdUrnkDP8v76/iZ3J656mrYN+r0eBfOEO1b8IwBkTk0wYv9x9w\nScxbRAj7FwAKXdGU5nPzBWtkYrIDuqstCAPWlNV8G8dseekesL9ijRNekw/C9Js2\nPK8wGfLpntIRF/Ec8cAd77jGs220bhixADMHx0nGzVS6uTyGAN31V/k3uJwwYzUP\nnDw8c68uLUfGzxh3jg1q"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.scienceforum.sc/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://federation.scienceforum.sc/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "NIAID Science Forum Federation Gateway"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Requests and obtains identity assertions on behalf of Windows-based web applications operated by NIAID"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://customers.myunidays.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bullock"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:andrew@myunidays.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bullock"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:andrew@myunidays.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Saidani"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:stephen@myunidays.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stephen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://customers.myunidays.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-09-16T17:03:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNiDAYS - Perks of Student Life - Customers"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.myunidays.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "MYUNiDAYS Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://customers.myunidays.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://customers.myunidays.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://customers.myunidays.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://customers.myunidays.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://customers.myunidays.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://customers.myunidays.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://customers.myunidays.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://customers.myunidays.com/Shibboleth.sso/WAYF/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://customers.myunidays.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://customers.myunidays.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://customers.myunidays.com/Shibboleth.sso/DSEdugate",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://customers.myunidays.com/Shibboleth.sso/DSEdugate",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://customers.myunidays.com/Shibboleth.sso/AAF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://customers.myunidays.com/Shibboleth.sso/AAF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "4"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://customers.myunidays.com/Shibboleth.sso/WAYFProd",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://customers.myunidays.com/Shibboleth.sso/Tuakiri",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://customers.myunidays.com/Shibboleth.sso/Tuakiri",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "5"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://customers.myunidays.com/Shibboleth.sso/InCommonDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://customers.myunidays.com/Shibboleth.sso/InCommonDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "6"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://customers.myunidays.com/Shibboleth.sso/DFN-AAI-test",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://customers.myunidays.com/Shibboleth.sso/DFN-AAI-test",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "7"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://customers.myunidays.com/Shibboleth.sso/DFN-AAI",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://customers.myunidays.com/Shibboleth.sso/DFN-AAI",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "8"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Delivering online student discount and promotions from the biggest retailers for free to students."
                  }
                ],
                "logo": [
                  {
                    "text": "https://d2hltel0toual2.cloudfront.net/images/wayf/logo_300x100px.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "300"
                  },
                  {
                    "text": "https://d2hltel0toual2.cloudfront.net/images/wayf/logo_80x16px.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNiDAYS"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhACCQC8EjoQK/aL7jANBgkqhkiG9w0BAQUFADBWMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjETMBEGA1UECBMKU29tZS1TdGF0ZTEQMA4GA1UEChMHVW5pRGF5czEgMB4GA1UE\n\t\t\t\t\t\tAxMXY3VzdG9tZXJzLm15dW5pZGF5cy5jb20wHhcNMTIwMzIwMDk0NzUyWhcNMzIw\n\t\t\t\t\t\tMzE1MDk0NzUyWjBWMQswCQYDVQQGEwJHQjETMBEGA1UECBMKU29tZS1TdGF0ZTEQ\n\t\t\t\t\t\tMA4GA1UEChMHVW5pRGF5czEgMB4GA1UEAxMXY3VzdG9tZXJzLm15dW5pZGF5cy5j\n\t\t\t\t\t\tb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCwMJfrb7y+eVIjMnMj\n\t\t\t\t\t\tKQEaWZWX9omtsMmrkxgOAEO5snjni2OJfWShhGmTKpBHClE8AmomOdDr3grEW6Nd\n\t\t\t\t\t\t5J0+yDh21A7bW6cdaxpwvr2FRZGaIkJFob0Lh7pnH59UIwfeO36fEUa/QfVWafZJ\n\t\t\t\t\t\tJeWZe4gKcdI+ndY0tMvK4m/pMcO6rxy4AwsJdvxM0bE9R3WNlB8lgcxmbP4pjoZC\n\t\t\t\t\t\tB29buyOS5/CmFzbA5IffwyJcyk+8dHVF7tbZ0CyjjOsXIrjCryUzsqDOdBLt5yup\n\t\t\t\t\t\tn6BcBzob6bU8AMojnVT10NCxOWqL+O9i1VScJ/dzyiDbR05iWDa2VQ+/Ya9UpD4d\n\t\t\t\t\t\tPl5bAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAKp/yt95eag2/oZdvxaIWLzjljEd\n\t\t\t\t\t\tlZdlxzZVSXgI67Ci+RhBp+jrBAgNrk/2QxEtau8t54Ufy4hxCFh4o/YvQ3F/Rmaz\n\t\t\t\t\t\tt7jz51Xj4/DeQ0Y/b5Kb+8MaZF8ZCNseU8Fd92c1Io+sAPQPtFqgR+kzxMOQAWET\n\t\t\t\t\t\tL/IOUn+DhRh434WBVEciLUduGIpP+sI3gaszurWQIJslPrxOEf+X9aDjOSvLqJvw\n\t\t\t\t\t\tjPsDxBi12zyperdHQgdNr6Jbd1h110XCpJzwCGXElxlNd+Z3R/sMW0wn7lCLYQA7\n\t\t\t\t\t\txmBjp1ntxjW8jWQiW/3pb5t/HODL79ntP17sTv4kT8EURtMRgYxttfreDdg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://customers.myunidays.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://customers.myunidays.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://customers.myunidays.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://customers.myunidays.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://customers.myunidays.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://customers.myunidays.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:cru.fr:federation:univ-rennes1.fr",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "fed-admin@listes.univ-rennes1.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:cru.fr:federation:univ-rennes1.fr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-05-19T16:25:25Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ident-shib.univ-rennes1.fr/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ident-shib.univ-rennes1.fr/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://ident-shib.univ-rennes1.fr/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-rennes1.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-rennes1.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Rennes 1"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Universit\u00e9 de Rennes 1"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Rennes 1"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Rennes 1"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUAOfkyDP7IZUpxjLBqzh2u2A52aEwDQYJKoZIhvcNAQEF\nBQAwJTEjMCEGA1UEAxMaaWRlbnQtc2hpYi51bml2LXJlbm5lczEuZnIwHhcNMDkw\nMzAyMTE1ODE5WhcNMjkwMzAyMTE1ODE5WjAlMSMwIQYDVQQDExppZGVudC1zaGli\nLnVuaXYtcmVubmVzMS5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAIgsyIsKtRo7oQxJsA+lI4Yr616n8irMvAEkvp22Z3Qp891HG5Jz3g7UMOv0ec+F\nLKRLNWoV6+DkM2TZiAji42ltH9pj5t27JhRZ2RMbpOOi37KYGKjUUSK5AVznwutp\nlvW2p4pYCR8TSuZMaFCxjTz4Re43HYLdH/rS1IjKF8LZPV5ymmHJRIEsC50VPx6S\nLLqEz46AxgNWc15oBEvLeBwHKQVC170RLAsFxUjQeuUXVTwaSpd9mwgkbzH28w6p\ndp3q9uAy2iKWXqLUvCIqTuH9u5+iNhnD4ZOYdFb8wW1Ebkbpsb0Vp6Uh64K60n/4\nQ/+mpg/CVGDdOkFppYFATa8CAwEAAaN7MHkwWAYDVR0RBFEwT4IaaWRlbnQtc2hp\nYi51bml2LXJlbm5lczEuZnKGMWh0dHBzOi8vaWRlbnQtc2hpYi51bml2LXJlbm5l\nczEuZnIvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFJWD/tJoDhnkOpuBRxm6nBAi\nAwlPMA0GCSqGSIb3DQEBBQUAA4IBAQAnSdwW+9NJWxtugXueUnfSQttGDOUmQIie\ngUHPCRj8VEbPG6upxZnFC/slOfR+dUeP6hIyCIE1pzqjCe8Lmc9wrKvee3nBPnCf\ngXMbzpVCNYXOMM8DhikOdBwGOfCWsK5cdkDVz5OWHv+gU/kgo1mcN6EQI8rzSi0h\nSvwYWTv/BTnA3R/idih2dS8sZDISLsBJnXtIWZTH28S4NX3sttHZSjyALT2nJbLD\n+2Xhef7YCNxkQshmTU9MI7TzdTNBEQS3p82TT9N4oXNVH0WPY3l0YLKBNzQSvNj2\nrkwHcu+LmiqBbNYaIImujo8IZ7laiF30+nPuPGRfCqU7IEjA7cga"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Rennes 1"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-rennes1.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Rennes 1"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idpdev.bham.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ServiceDesk@contacts.bham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bryan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:J.G.Bryan@bham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Graham"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idpdev.bham.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-10-30T12:57:07Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idpdev.bham.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idpdev.bham.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idpdev.bham.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idpdev.bham.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idpdev.bham.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idpdev.bham.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bham.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://idpdev.bham.ac.uk/idp/images/University-of-Birmingham-logo.gif",
                    "height": "34",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "141"
                  },
                  {
                    "text": "https://idpdev.bham.ac.uk/idp/images/University-of-Birmingham-crest.gif",
                    "height": "48",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "39"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Birmingham (Development IdP)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUIVfgOu5tTWi4eR0vOLjm8kVDIzgwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwHDEaMBgGA1UEAwwRaWRwZGV2LmJoYW0uYWMudWswHhcNMTUxMTE5MDg0NzA4\n\t\t\t\t\t\tWhcNMzUxMTE5MDg0NzA4WjAcMRowGAYDVQQDDBFpZHBkZXYuYmhhbS5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALG3IP3QvX9BKJDA94oGiquA\n\t\t\t\t\t\tMz15vKyq/OtUkLmiC19jzJg6VtznAL6yp4qFPv4t/19pj+2reQWT7zs5nkTEKkkj\n\t\t\t\t\t\tap4FOOpyGRuwPQQG48Gc2jYEY00BJM+TPa8LnotOR6znW333Ep3k1/pSr6dDpwHE\n\t\t\t\t\t\t08mnqnmJDCUVyAzqmApkNPYTlepo9oW94RvQ0WpXj0Z5KwhoE4yuxq7+mdHwInjI\n\t\t\t\t\t\tXRQt6iHCOOapTcai47EC50z10WevvjqGBoPtWO/kaApC/H1sjw/8FmoV0Bn+BD0n\n\t\t\t\t\t\t423NXJnQ2kUm43vZuuHEjuw1ByNvbW4lx33ghTIT0yX7sGQwtoJDYbTGDzRdG08C\n\t\t\t\t\t\tAwEAAaNpMGcwHQYDVR0OBBYEFKct1G1nTMcO8eIOvkAnHOgeJFmpMEYGA1UdEQQ/\n\t\t\t\t\t\tMD2CEWlkcGRldi5iaGFtLmFjLnVrhihodHRwczovL2lkcGRldi5iaGFtLmFjLnVr\n\t\t\t\t\t\tL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQBvofZpFqz8kPrEPSVY\n\t\t\t\t\t\tzPeClJi1VajT0HznS94/ZDYJMu/xP+fjaXSgGNKYpo37Uc079s/tteWxA9y5hJ0G\n\t\t\t\t\t\t64sGBXm2041w3FhbK/IJo4WGQf5utrF0aNhPAT4x4NAWRwZRA2JqHNV/Geawmht3\n\t\t\t\t\t\tp6y9IYZNOrv4M2YHzVmeY25Nb3c4AEsG47chKwFsReLvcuucqbMWC7yJUZoqCOT7\n\t\t\t\t\t\tfgbE9mA7sxBJ8warsZ6DVZmljLnF92j/X/lXDGjURpapxtSY0+UYg0FAwq4YlA4w\n\t\t\t\t\t\tsZsmv/TzR9q8jnIN9nRfOVaA/uIzGPuI7hlMbTfkx0gAXOxFF2uiwX0H/SXGmYkk\n\t\t\t\t\t\ttHKz"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAJ+rTweaxT3S5IdRTlFMWNcLNE1IMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMBwxGjAYBgNVBAMMEWlkcGRldi5iaGFtLmFjLnVrMB4XDTE1MTExOTA4NDcw\n\t\t\t\t\t\tN1oXDTM1MTExOTA4NDcwN1owHDEaMBgGA1UEAwwRaWRwZGV2LmJoYW0uYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCUaNT+DQalsoK/PJotX5oh\n\t\t\t\t\t\tseeMwxjnMpFJNljC/l4tet23SMyk2596lp9Y8sE3yKh2FtnznsF4S+TI+x/bx+gt\n\t\t\t\t\t\tEuu5MAgwZMb2ZZFaYTp6O0d0fE588PJE47b7gWczkxPrXu1aGIBy3cffMyhdqL1e\n\t\t\t\t\t\tbG6/mSc15t0RQear14o2oELmubPR+ZjrH88WOqzAtz2oSN5VYE0hutqV6PdUC8AS\n\t\t\t\t\t\tq8gcIzJ2u14oxr0P3zfV93qhxiD9P6kSKdF2kqKAcht4+0uMchWbWLbqLpumuS69\n\t\t\t\t\t\tCnuV1iglJGJopDbEMK6bYr8XMVcU5fbhdFGBUNSnOKUd/89GbKvBTX+mjdRmzv4H\n\t\t\t\t\t\tAgMBAAGjaTBnMB0GA1UdDgQWBBTWrGSLIekxRAms8ycd1foNhIMB5TBGBgNVHREE\n\t\t\t\t\t\tPzA9ghFpZHBkZXYuYmhhbS5hYy51a4YoaHR0cHM6Ly9pZHBkZXYuYmhhbS5hYy51\n\t\t\t\t\t\tay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEALNUtZ95OSpqYy4HL\n\t\t\t\t\t\tbcLDeFsVwfWAwg7kOrezxRWWVdz6noGhr891sAQ4m1bIkNMHtwkJd9t5bJqw3kk1\n\t\t\t\t\t\tf/37P1gfNJG73EbyarZU6QzyzEOljRYPxFiagDe/pom4uoSumr2cpu56PW5gq5RD\n\t\t\t\t\t\tBIK1y6p5gu/NbDwqTPGkltVzRTCjVm44G5m8OtLvvAjtKhoNw/Dex4yxofdhdCrs\n\t\t\t\t\t\t3S+sgmkLrNrjUHcCBefyLbrX+T6KbVKjhNZHDlNNqkKiw8MbWo9eQwcwjNV4Ln8z\n\t\t\t\t\t\tOvMRf3TuK2qF9eWHTcGhip5YVOeps3YnuVE3iFzvSeW7sFuydHpiLxeDAV3Zz/fX\n\t\t\t\t\t\t1eJP3Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUUI3OcSf1ugfmUml1jp6Uz6UPFf0wDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwHDEaMBgGA1UEAwwRaWRwZGV2LmJoYW0uYWMudWswHhcNMTUxMTE5MDg0NzA3\n\t\t\t\t\t\tWhcNMzUxMTE5MDg0NzA3WjAcMRowGAYDVQQDDBFpZHBkZXYuYmhhbS5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKv0OMi7eSvWLrc7jc4jfBsk\n\t\t\t\t\t\tr+3mD8o38/LuKJkxpfzgAuz91XbX/1+5sx24gpb4f94RVYbVA8i/hEbvR3lneiiN\n\t\t\t\t\t\t9A3yApH3NNmvEhQH7Qzol2ZXhWdBHmNf57h7L4RHgyPtcSxPjPkL387haB3iGoU1\n\t\t\t\t\t\tNz6Wr/RwSaYks4VXVh8/EJH2908H+PTk3PM2WlTqMLdllzZTimq1y9PZeZZNDDTM\n\t\t\t\t\t\t9+RTZIZW+B/VRwlmist3L46I+ftHyJzQpDleCq/WeajFMQriTYVi8NFYw+ym2Drl\n\t\t\t\t\t\twmThyH4g99kK0Ofrv5gigDLpMdn5oQ7CA4AdAHcNMN7wU6DCgzyuUstOHCKRJlEC\n\t\t\t\t\t\tAwEAAaNpMGcwHQYDVR0OBBYEFO9JKvKCIsh+vUHamkucUrIv+beQMEYGA1UdEQQ/\n\t\t\t\t\t\tMD2CEWlkcGRldi5iaGFtLmFjLnVrhihodHRwczovL2lkcGRldi5iaGFtLmFjLnVr\n\t\t\t\t\t\tL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQAE4MCBT5XbidZy6cyy\n\t\t\t\t\t\tE939H/RzH8OVX+zqaERhPPRHFue6155e20KgBorDtr8ACbur33e4gQotJYFvjtt8\n\t\t\t\t\t\tHCFZbSQwvW3OBtQPzqG5yZZ47EH0aasrqIA3PY8hVis9fSwjStFSR7cAygUUFRuB\n\t\t\t\t\t\timk4LuZAq2W54mkl+xazBjpcZN4cK118cyL/TMxNXPJ82qGAfy8mdIsIGKEfhBdI\n\t\t\t\t\t\trMvl4K04hEvzQblh3Lghb1GtF8GMjIIQAjQIoUiRPCWUd37tRW17rE1RLLjVCLlz\n\t\t\t\t\t\tSnivPWw0ouKAaF/GJbfDfu2SAhuJ2Fw6RC7bU7pyMbFZ3NrCAQHA4l0tJAHME7EA\n\t\t\t\t\t\t2T4z"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Birmingham (Development IdP)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bham.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Birmingham"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://student.mit.ladok.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://student.mit.ladok.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://student.mit.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://student.mit.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3-projektets Migrations-, Integrations- och Testmilj\u00f6 (MIT-milj\u00f6n)"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 MIT Studentgr\u00e4nsnitt"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://student.mit.ladok.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "student.mit.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNTCCAh2gAwIBAgIJAJ3icKR+gNdqMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFHN0dWRlbnQubWl0LmxhZG9rLnNlMB4XDTE1MDIxMjA3MzEzOFoXDTI1MDIw\nOTA3MzEzOFowHzEdMBsGA1UEAxMUc3R1ZGVudC5taXQubGFkb2suc2UwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC3GvpMV8JsG+orqyQ1bx9vsley4AxO\nB7nDmfRwX63t22mpyBDer4ZMMwDxb8lNf0a9rzXyfacDh6UkbBghPB6w71onmt60\nrCozzqCUOYwyPwocEQZ9mxelc9dEyN1c8WhyIo6BnhQWPbPr7Y+EAihe4oOK16p1\nw+wyPlKxNRj1g0zOJHvvmg2vbXALyt1xJ60y7vSWKiZEMDpclnTwHCd2icU7AB5R\nEGBGxAV3rGVXQWzHZnDoP0NPr+OlzVbTowTAC7KoNlY0iBZwwtxyI1BolXgU4oN9\nXlpnu/FroqFAlsCuyZCc3/VLNwiNl7wH8ZOYRBoy+6rJMPVBLf1TEA+ZAgMBAAGj\ndDByMFEGA1UdEQRKMEiCFHN0dWRlbnQubWl0LmxhZG9rLnNlhjBodHRwczovL3N0\ndWRlbnQubWl0LmxhZG9rLnNlL3N0dWRlbnQtZnJvbnRlbmQtc3AwHQYDVR0OBBYE\nFGy8rVzZpS2hPPUQeQeK1LWAOhgZMA0GCSqGSIb3DQEBBQUAA4IBAQB2IVqSGbpJ\nqO1bh7aHHdnnmw2Wbc3jnyU8dhbJ4PuEii1m6rbu8b+pdpwYjqit1UZ2RVjzaL38\n4V8hCooWybOQ5phNj7pohwUqliPOX4rockK9nAhk0MT69KYArh+VfsvBmN9sb5uf\nCy4YS1P+vUWvWJqwmCwuKvBuCu3K8zI6QELhHFpafXTvkz+K+z3A22G1FigBqsMT\nua2Dzh2zE+wfcRwqZ+GwH0mN0iqxDJUKqgs9aEsl8Q9iHH1cmBYOMQnCaCIbnd6l\nXp4VZ3QgIMowFfU+rOyCR3jMz8kW9hLPuIGQXq65q14lETenxSds3d9Z6TGB6Xbc\naQxSEmvTJulB"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=student.mit.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://dep.s2dv.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Heath"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ryan.heath@software2.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ryan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Heath"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ryan.heath@software2.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ryan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dep.s2dv.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-03-28T09:04:45Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Software2 Shibboleth development server"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.software2.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Software2 Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dep.s2dv.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dep.s2dv.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dep.s2dv.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dep.s2dv.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dep.s2dv.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dep.s2dv.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dep.s2dv.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICrjCCAZYCCQDgMPi3gaCJaTANBgkqhkiG9w0BAQUFADAZMRcwFQYDVQQDEw5k\n\t\t\t\t\t\tZXAuczJkdi5jby51azAeFw0xMjAzMjAxMDM0NDhaFw0yMTEwMTkxMDM0NDhaMBkx\n\t\t\t\t\t\tFzAVBgNVBAMTDmRlcC5zMmR2LmNvLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\n\t\t\t\t\t\tMIIBCgKCAQEA260OtuavH9SsL1u8r3jFFu3h19Xo9rt7x9bu8eIM1WigGbMqm9ag\n\t\t\t\t\t\tv3aVwamCnRyyjG8kJGChD6KrOrYjBSI4OE0smQSVW7SNy2cwY2ImrseKhyhap9Rr\n\t\t\t\t\t\tNI6c3ddAawG7cvFNetkPddAoEI1Vs3TfFZnA02qUcScMT7ZTlLbL75j7RkIQepdy\n\t\t\t\t\t\tl3/xD6Qrp3m3N1+tuLi4pxMYXmBlKLLmQcu0TLfYDmDKRowakyZKN4tqKx0tGw/v\n\t\t\t\t\t\tkE4l5waECFbKBVWIk0A+GcCH1Uch11KbTE/6SOQMq4A5y+Ee7oqgldvUYyjcW1ic\n\t\t\t\t\t\tq4wR8sOXVAtsElzk0eXycE5KuAYW3aAP4wIDAQABMA0GCSqGSIb3DQEBBQUAA4IB\n\t\t\t\t\t\tAQBvVkGHCryLmiekLnyjsSM6VQClJsQBmv8PYnPd27aFweEm1APcTRMETqSU+BHf\n\t\t\t\t\t\t9WOERh4BYLgABtUG93L9mSSTEHCUjp9KdubGCEpzJP84lYW+dP3PnIolCP4D5P3N\n\t\t\t\t\t\tWrLAdh9WvLpFR7I7yx1CQ2EUhY8ydszebZUc5FqbqoV/SV69mxsSTmyY2Jr44Zko\n\t\t\t\t\t\tdOReO4xW0knkopP4t/0U8A8HlPCsV+1J/GNkUBhx7OQlZNnxejj8PZZET7zEeU4a\n\t\t\t\t\t\teBnOFtTWrMYru4OCuEepLXTjIRRit4mKuGqOz59j5woy2lfFP/tG35t0EYFiXHv6\n\t\t\t\t\t\tPbImR0UCz6WD9A9knry75FGl"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dep.s2dv.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dep.s2dv.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dep.s2dv.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dep.s2dv.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dep.s2dv.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dep.s2dv.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.london.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Litteck"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:h.litteck@ulcc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hans"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Litteck"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:h.litteck@ulcc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hans"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.london.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAJCgNzs/ToqPMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEGlkcC5sb25kb24uYWMudWswHhcNMTIwNjIxMTMyODU4WhcNMjIwNjE5MTMy\n\t\t\t\t\t\tODU4WjAbMRkwFwYDVQQDExBpZHAubG9uZG9uLmFjLnVrMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEA1LZ7Lmg5HanDG+ZqOnVenp96NaSrrj6ZFWMy9Vlj\n\t\t\t\t\t\t1E37wy5ooUifd0ICIecUc6FDM7btoMuhRn4YWec7n2purs2O8p9LD11SthO+lwZO\n\t\t\t\t\t\tqD6F2VzRYuV9KaaaganyoIgbJAt+UowXepcyZJy+wdmLu4neoBuoIfnigoCLnb+9\n\t\t\t\t\t\tNkArvT91kJvFmKMWXEW9L9rO8vnsJRMcl9WU7VftLXUY4pXLm4C4QdpocFv8J2O1\n\t\t\t\t\t\t2PIigtSKb4uUulaZpUZ3HfkzMqmkBB7RH1XZVR3l4NmmVs/82knDGv9BOr3hNWeq\n\t\t\t\t\t\t/2HjRB8z2r2S/oDJ/20Ka8W+jkqCAbkFhxva6F/fDoB/BwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghBpZHAubG9uZG9uLmFjLnVrMB0GA1UdDgQWBBS8mlo8ov/oCSegN5ZL\n\t\t\t\t\t\tE7HMjHcdNzANBgkqhkiG9w0BAQUFAAOCAQEAP4E7FG9dDRTYo/w+s4qziV7Vh3IH\n\t\t\t\t\t\tRYHPfTogu8x2ORmAuSlE6VlFSL5HgTUQcT/JQgAdVYErdGxj7BKTIu+JgwzWJI6W\n\t\t\t\t\t\tZh/tb3u2/4kNMGC84UuplJ1XCkltdaKn3Z3rYbowBM8lXrEckfvucE56e+MKNdjx\n\t\t\t\t\t\tSX9iUs1YEIWsSFoZzjRfEoZi7+bVZ45o5dZWWyJc3wFzke3AjuIBmccAvbA8g6/S\n\t\t\t\t\t\tni0aehQMWN4NdxrC/1Q36n95Krbq7dzTNFrpf1nL/egN6rmgCGzyT/GxPfbi/Nvf\n\t\t\t\t\t\t1aev0Vum2CXcvkJbLl0J2H59qh/IBKgxDIIUItznpVWoi5HDxGWmCNMnUQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "london.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.london.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.london.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.london.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.london.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.london.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.london.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.london.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.london.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "london.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://idp.london.ac.uk/images/uol-logo.png",
                    "height": "75",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "239"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of London"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAJCgNzs/ToqPMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEGlkcC5sb25kb24uYWMudWswHhcNMTIwNjIxMTMyODU4WhcNMjIwNjE5MTMy\n\t\t\t\t\t\tODU4WjAbMRkwFwYDVQQDExBpZHAubG9uZG9uLmFjLnVrMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEA1LZ7Lmg5HanDG+ZqOnVenp96NaSrrj6ZFWMy9Vlj\n\t\t\t\t\t\t1E37wy5ooUifd0ICIecUc6FDM7btoMuhRn4YWec7n2purs2O8p9LD11SthO+lwZO\n\t\t\t\t\t\tqD6F2VzRYuV9KaaaganyoIgbJAt+UowXepcyZJy+wdmLu4neoBuoIfnigoCLnb+9\n\t\t\t\t\t\tNkArvT91kJvFmKMWXEW9L9rO8vnsJRMcl9WU7VftLXUY4pXLm4C4QdpocFv8J2O1\n\t\t\t\t\t\t2PIigtSKb4uUulaZpUZ3HfkzMqmkBB7RH1XZVR3l4NmmVs/82knDGv9BOr3hNWeq\n\t\t\t\t\t\t/2HjRB8z2r2S/oDJ/20Ka8W+jkqCAbkFhxva6F/fDoB/BwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghBpZHAubG9uZG9uLmFjLnVrMB0GA1UdDgQWBBS8mlo8ov/oCSegN5ZL\n\t\t\t\t\t\tE7HMjHcdNzANBgkqhkiG9w0BAQUFAAOCAQEAP4E7FG9dDRTYo/w+s4qziV7Vh3IH\n\t\t\t\t\t\tRYHPfTogu8x2ORmAuSlE6VlFSL5HgTUQcT/JQgAdVYErdGxj7BKTIu+JgwzWJI6W\n\t\t\t\t\t\tZh/tb3u2/4kNMGC84UuplJ1XCkltdaKn3Z3rYbowBM8lXrEckfvucE56e+MKNdjx\n\t\t\t\t\t\tSX9iUs1YEIWsSFoZzjRfEoZi7+bVZ45o5dZWWyJc3wFzke3AjuIBmccAvbA8g6/S\n\t\t\t\t\t\tni0aehQMWN4NdxrC/1Q36n95Krbq7dzTNFrpf1nL/egN6rmgCGzyT/GxPfbi/Nvf\n\t\t\t\t\t\t1aev0Vum2CXcvkJbLl0J2H59qh/IBKgxDIIUItznpVWoi5HDxGWmCNMnUQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of London"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.london.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://account.mdh.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://account.mdh.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://account.mdh.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://account.mdh.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://account.mdh.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://account.mdh.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://account.mdh.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://account.mdh.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIJAPaKAClrLbTPMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDmFjY291bnQubWRoLnNlMB4XDTEyMTIwNDE0MjgxNloXDTIyMTIwMjE0Mjgx\nNlowGTEXMBUGA1UEAxMOYWNjb3VudC5tZGguc2UwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDnDT2AU69L2h1ZQ6iEVWhGtQYC78dkJBcJ8XjDHImC8BEC\nwxJVg2SNwzT4pb8tBT0PpAXHRbTdsg7Isxa6Ah13OBWN4pEuj1+gweijXwie6BGn\nAL2WMeVIDYkA31tNcy5h2qqfhyHFTeFBhoVfwjL38kXb5eZ8z3so6HKX7CRyg3w8\ni8Wvisey073edn6ojH+k/6hjOCU2Yw7Gi9nfgZF5fAIh50djp52Ygvfer5QuNvow\nS0V2vZlvU4Le9SkJhMZZyJa7xcbXCte3d7ZzkqW20H/8b9OxZq72HrJILodJkmzp\nNSsn2xesDp5eVb5U0uSDf5Ecw3I/xH57Q6AI0qRfAgMBAAGjXzBdMDwGA1UdEQQ1\nMDOCDmFjY291bnQubWRoLnNlhiFodHRwczovL2FjY291bnQubWRoLnNlL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFAX+Mwdh0P9/9UldxwhrauU/EvDpMA0GCSqGSIb3DQEB\nBQUAA4IBAQDON1n9lbL4S1b+aPR6pegQxpF1Kcw0NnmKp9tECubXVCSJw8V+1lLt\nxSRdF8i5PNALSwxahOYndivb1bY23dPZ1oKIbR9yGrcAY9aSRzt4l2Yh7k73LBgI\n0OHsbLLKxiReYWvMR5+QseIN3FpgBeAUJmOPQL79FcYxQl+nX4DgBatb/aYYOU0S\nnLhAo0q9al1Is1QdxLo5FyHaYR/Xu+p31ltowAg4NQ29zRHfW7BQG2JmBEXrxIB2\nzpHIUu/5SWS3wMnuRZgdr25OF2r+/mwgyOrAJ69Zi1ajEIA7YhGwVZ5V5FF4UgPe\nTy6ceQwd7bOvvrpf5YqChJKmoxF3bTiK"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://account.mdh.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Kontoaktiveringstj\u00e4nst f\u00f6r M\u00e4lardalens h\u00f6gskola"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Account activation service for M\u00e4lardalen University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kontoaktivering M\u00e4lardalens h\u00f6gskola"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Account activation M\u00e4lardalen University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://www.openaccessrepository.it/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:credentials-admin@ct.infn.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.openaccessrepository.it/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2014-10-10T08:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INFN"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.infn.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Italian National Institute for Nuclear Physics"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.openaccessrepository.it/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.openaccessrepository.it/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.openaccessrepository.it/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.openaccessrepository.it/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.openaccessrepository.it/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.openaccessrepository.it/service/"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.openaccessrepository.it/service/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Open Access repository of INFN and other Italian research organisations' research products (publications, software, data, etc.)"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Archivio Open Access dei prodotti della ricerca (pubblicazioni, software, dati, ecc.) dell'INFN ed altri organismi di ricerca italiani"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.openaccessrepository.it/help/privacy-policy?ln=en"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.openaccessrepository.it/help/privacy-policy?ln=it"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Open Access Repository"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Open Access Repository"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.openaccessrepository.it/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.openaccessrepository.it/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEgzCCA2ugAwIBAgIQAcOBBEDrU0NaTC9JniJAAjANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDYyMzAwMDAwMFoXDTE3MDYyMjIzNTk1OVowSTEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMSQwIgYDVQQDExt3d3cub3BlbmFj\nY2Vzc3JlcG9zaXRvcnkuaXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQC5FlOs0obBs1hyIZkL9ZIySN0OIOIRr0FMaxM2X0ROLUruSg7FvLuMtBf6a5EC\nELEpkasqJU/T7MoHhOTG1S1pAcx9aQ1AfKB1fJPu7//s6nLMvDV8GzrV9dhEl7MW\nhqHobSjBQsq2cfdic9YvFMW2+dY/fvS0Cqlk0Ga9edM7HFDJ9gVKl6j6G4HbMXXA\nln/0HplJCG1PyZ50URd3giVuM38SSkQ2V9WtsL4cjENJ7XECFXh1uikqPTsnRHD+\n7dJPw8c+j3/MKqk1d/ZMZ0CnuWsNWD6g+a2TpADUssioabQ9FxyJk4UNdGrqdVIc\nHpj1Ah+bwMvR1rBY08E+Gi2lAgMBAAGjggF4MIIBdDAfBgNVHSMEGDAWgBQMvZNo\nDPPeq6NJays3V0fqkOO57TAdBgNVHQ4EFgQUjtXXHKbMBYRtpsvnZvTF0zJ+oaQw\nDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUH\nAwEGCCsGAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIB\nMDoGA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVS\nRU5BU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDov\nL2NydC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGG\nGmh0dHA6Ly9vY3NwLnRjcy50ZXJlbmEub3JnMCYGA1UdEQQfMB2CG3d3dy5vcGVu\nYWNjZXNzcmVwb3NpdG9yeS5pdDANBgkqhkiG9w0BAQUFAAOCAQEAPJVl6xygzniD\nZd+1rE7mCqLa4b/by2up2mg4CGED05mIX+XD3XFlVnHY2S4KM/E8Ac0VkiLZmDdG\ndm0Z2MDBSbDZKFfdNvC3/8kFYMtXhhk8Owrg+l+MY1QxjzlC0BD9eisIL7uSf7p0\nW580j+lzHziV0KDB//HekpLtRgJHoYOxMxrvhIYexiptNuhRswO6Og8UZ7CsrA5q\nh/rBSQ+HrCM6vkeKTW79h7Wy6u3dlag1vD2ToM/0Sp7x16auORbwST05kRr83pJB\nxoOiE+hrgoBGwJidjNIMD641bADIz8WXCWpy0QVCuBzdufaa1vJszW3r1Y6cVyBL\nVGXrPl4Lcw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.openaccessrepository.it/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.openaccessrepository.it/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.openaccessrepository.it/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.openaccessrepository.it/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.openaccessrepository.it/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.openaccessrepository.it/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Open Access Repository"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Open Access repository of INFN and other Italian research organisations' research products (publications, software, data, etc.)"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eppn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.lux17.mpi.nl",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Admin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth@mpi.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Admin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:latadmin@mpi.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LAT"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Admin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:latadmin@mpi.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LAT"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.lux17.mpi.nl",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-02-13T16:54:14Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://clarin.eu/category/clarin-member"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lux17.mpi.nl/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lux17.mpi.nl/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lux17.mpi.nl/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lux17.mpi.nl/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Korpuslinguistik und Sprachdokumentation Anwendungen - lux17 (dev)"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Corpus linguistics and language documentation applications - lux17 (dev)"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Sprachanwendungen f\u00fcr Forscher: Annex, IMDI Browser, Lamus, Metadata Browser."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Linguistic applications for researchers: Annex, IMDI Browser, Lamus, Metadata Browser."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://lux17.mpi.nl/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://tla.mpi.nl/tools/tla-tools/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Korpuslinguistik und Sprachdokumentation Anwendungen - lux17 (dev)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Corpus linguistics and language documentation applications - lux17 (dev)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Sprachanwendungen f\u00fcr Forscher: Annex, IMDI Browser, Lamus, Metadata Browser."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Linguistic applications for researchers: Annex, IMDI Browser, Lamus, Metadata Browser."
                  }
                ],
                "logo": [
                  {
                    "text": "https://lux17.mpi.nl/gif/mpg-logo-90x90-grey.gif",
                    "height": "90",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "90"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://lux17.mpi.nl/privacy_statement.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "lux17.mpi.nl"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDaDCCAlACCQD2mDCAJYMG3jANBgkqhkiG9w0BAQUFADB2MQswCQYDVQQGEwJO\nTDEMMAoGA1UECBMDR0xEMREwDwYDVQQHEwhOaWptZWdlbjEPMA0GA1UEChMGTVBJ\nLVBMMRUwEwYDVQQDEwxsdXgxNy5tcGkubmwxHjAcBgkqhkiG9w0BCQEWD2xhdGFk\nbWluQG1waS5ubDAeFw0xNDA1MDIxMTI2MDZaFw0xOTA1MDExMTI2MDZaMHYxCzAJ\nBgNVBAYTAk5MMQwwCgYDVQQIEwNHTEQxETAPBgNVBAcTCE5pam1lZ2VuMQ8wDQYD\nVQQKEwZNUEktUEwxFTATBgNVBAMTDGx1eDE3Lm1waS5ubDEeMBwGCSqGSIb3DQEJ\nARYPbGF0YWRtaW5AbXBpLm5sMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEA3QaSP0LJ0mVZZIdEh7zFJW8lnkVGQFuueAiDfVVvGtGvJ5iz7CRoyrdTQDco\noJjQDFub/uU6v0i+saVgI+LuzUlq28hrKF5hIjhWCLMRgYZzsnArcGK3etcChsNE\nOPfWNCOCGi90sIqNmJcVRoDw36tLiHXmIkhcy4ZE06SYXvT+qAwo4h30Z/IH2de/\nQlYEpkqF131p2lJGWx1Bi5l7IMeZtlwIzbJn08htAT/T8h6g9XvDfmQxS4xuiXGr\nuRwVhTTkTP9OsdrXkktJEkSE2p+qP0tYekb+ZPd4LzlSjnDWf3V1T/DrbL071eiC\nrx2iDW3n5Wy7so0iwmU5nr9QhwIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQAFSrqi\nHOMohDd4JXB3rjX8npCSTTeam84LTI1Twd8GXOmDQ8izcwsfUIILusEqd+66V/kh\niwnBgmrwgw0CVEZjgwkbVdZH68RGO4i6n5hZwmzr5jx4yNkfLZ5uwfHLIkqgJjj0\nDvsA6Saom/5BD6dln6TuQ9cwFu+9pOxaWjfEeD2Rm5HFP+VF9GPxM19Gs6xcYi2L\nGlEfBQvH/6vp65r3ciw760KPeO1ITxaIfqX5fOxOaA0NLOIGLjX0G11vf/i3n1OQ\nMZTR7RMV+bjZiLNoPOJ/Ezz5lr+k0V12yVJ35J2J6TIz6lcB9M1tCFDY7tS89nYf\nHFhkY9jzkGrcHMME"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=latadmin@mpi.nl,CN=lux17.mpi.nl,O=MPI-PL,L=Nijmegen,ST=GLD,C=NL"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "lux17.mpi.nl"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDaDCCAlACCQD2mDCAJYMG3jANBgkqhkiG9w0BAQUFADB2MQswCQYDVQQGEwJO\nTDEMMAoGA1UECBMDR0xEMREwDwYDVQQHEwhOaWptZWdlbjEPMA0GA1UEChMGTVBJ\nLVBMMRUwEwYDVQQDEwxsdXgxNy5tcGkubmwxHjAcBgkqhkiG9w0BCQEWD2xhdGFk\nbWluQG1waS5ubDAeFw0xNDA1MDIxMTI2MDZaFw0xOTA1MDExMTI2MDZaMHYxCzAJ\nBgNVBAYTAk5MMQwwCgYDVQQIEwNHTEQxETAPBgNVBAcTCE5pam1lZ2VuMQ8wDQYD\nVQQKEwZNUEktUEwxFTATBgNVBAMTDGx1eDE3Lm1waS5ubDEeMBwGCSqGSIb3DQEJ\nARYPbGF0YWRtaW5AbXBpLm5sMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEA3QaSP0LJ0mVZZIdEh7zFJW8lnkVGQFuueAiDfVVvGtGvJ5iz7CRoyrdTQDco\noJjQDFub/uU6v0i+saVgI+LuzUlq28hrKF5hIjhWCLMRgYZzsnArcGK3etcChsNE\nOPfWNCOCGi90sIqNmJcVRoDw36tLiHXmIkhcy4ZE06SYXvT+qAwo4h30Z/IH2de/\nQlYEpkqF131p2lJGWx1Bi5l7IMeZtlwIzbJn08htAT/T8h6g9XvDfmQxS4xuiXGr\nuRwVhTTkTP9OsdrXkktJEkSE2p+qP0tYekb+ZPd4LzlSjnDWf3V1T/DrbL071eiC\nrx2iDW3n5Wy7so0iwmU5nr9QhwIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQAFSrqi\nHOMohDd4JXB3rjX8npCSTTeam84LTI1Twd8GXOmDQ8izcwsfUIILusEqd+66V/kh\niwnBgmrwgw0CVEZjgwkbVdZH68RGO4i6n5hZwmzr5jx4yNkfLZ5uwfHLIkqgJjj0\nDvsA6Saom/5BD6dln6TuQ9cwFu+9pOxaWjfEeD2Rm5HFP+VF9GPxM19Gs6xcYi2L\nGlEfBQvH/6vp65r3ciw760KPeO1ITxaIfqX5fOxOaA0NLOIGLjX0G11vf/i3n1OQ\nMZTR7RMV+bjZiLNoPOJ/Ezz5lr+k0V12yVJ35J2J6TIz6lcB9M1tCFDY7tS89nYf\nHFhkY9jzkGrcHMME"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=latadmin@mpi.nl,CN=lux17.mpi.nl,O=MPI-PL,L=Nijmegen,ST=GLD,C=NL"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lux17.mpi.nl/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lux17.mpi.nl/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lux17.mpi.nl/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lux17.mpi.nl/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lux17.mpi.nl/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://lux17.mpi.nl/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lux17.mpi.nl/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://lux17.mpi.nl/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://lux17.mpi.nl/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://lux17.mpi.nl/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://srvcafe.ifma.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Daniel Torres"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "daniel.torres@ifma.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://srvcafe.ifma.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIERjCCAy4CAQAwDQYJKoZIhvcNAQEFBQAwgegxLjAsBgNVBAoUJUlGTUEgLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkbyBNYXJhbmjDo28xQjBABgNVBAsUOURHVEkgLSBE\naXJldG9yaWEgZGUgR2VzdMOjbyBkYSBUZWNub2xvZ2lhIGRhIEluZm9ybWHDp8Oj\nbzEfMB0GCSqGSIb3DQEJARYQZGd0aUBpZm1hLmVkdS5icjESMBAGA1UEBxQJU8Oj\nbyBMdWlzMRIwEAYDVQQIFAlNYXJhbmjDo28xCzAJBgNVBAYTAkJSMRwwGgYDVQQD\nExNzcnZjYWZlLmlmbWEuZWR1LmJyMB4XDTE0MDQxMTIwNTEzNVoXDTE5MDQxMDIw\nNTEzNVowgegxLjAsBgNVBAoUJUlGTUEgLSBJbnN0aXR1dG8gRmVkZXJhbCBkbyBN\nYXJhbmjDo28xQjBABgNVBAsUOURHVEkgLSBEaXJldG9yaWEgZGUgR2VzdMOjbyBk\nYSBUZWNub2xvZ2lhIGRhIEluZm9ybWHDp8OjbzEfMB0GCSqGSIb3DQEJARYQZGd0\naUBpZm1hLmVkdS5icjESMBAGA1UEBxQJU8OjbyBMdWlzMRIwEAYDVQQIFAlNYXJh\nbmjDo28xCzAJBgNVBAYTAkJSMRwwGgYDVQQDExNzcnZjYWZlLmlmbWEuZWR1LmJy\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAndeQ2TDWt0/WD456cqgd\nXQ9b/8GofISh4bqfAgE/ryJnTq7+Qf/ZEFoAD0dIpSyPlBhUjYE2wwOlUURD4+8y\nivNSwYbC44MXvTH+7QES86Ei+/rSUvmjOaibXr3jcoEZZPoYSHBUWvuPM8yubjXw\naY+dyyg9AjGMGq6bm5xm7prcE9IQT++sCzhnLx9PLpfEiFlPr3pnZKuLWvlEb/OV\nE0IkzzCAoFfLDfZAbEK5NInsd399Zw9o0Bfo3M0pRGzyZUHahnTKiGBagdK//tpm\nBhiT3azSvfWF7pxleUOCMJHTEum426AtaBpFyKBrvIEKr0OqgDj8uBsia4PH1lUY\nIwIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQBIZQEEWkQzIWbBHPbM5qGGkRgu2KfT\n39lv6LGDDjZaJH7CPFP1FElKAsw1FVOlsYGdF5xbvclqLiZeRa2WUlFqsEeZQHS2\nWcCWgsYjMANovjer9I834lFpxNATnKe4H3NsI3rlrfyBGJrSX3w/48s2xa8XgWDq\n7EWAk7GVDgPvc25kWIzlex6FXlfmPOnwsXrgpieCk6HH1jFn+xKshJHMntCjk3al\nFBO6NIuxgaFzNAp1X7EbCxKpFTZxjxC1YjfZAa/4XbZHqV9NHuW9w7QRz5wYvbDB\nUgQ4/xzHw95wCdYlE/aIdGiIG/ATFHnXv2ZiSCm8XDmz6wDBRVfw3Wv6"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ifma.edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://srvcafe.ifma.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://srvcafe.ifma.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://srvcafe.ifma.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://srvcafe.ifma.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://srvcafe.ifma.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://srvcafe.ifma.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://srvcafe.ifma.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://srvcafe.ifma.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ifma.edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifma.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifma.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFMA - Instituto Federal do Maranhao"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFMA - Instituto Federal do Maranhao"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFMA - Instituto Federal do Maranhao"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFMA - Instituto Federal do Maranhao"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIERjCCAy4CAQAwDQYJKoZIhvcNAQEFBQAwgegxLjAsBgNVBAoUJUlGTUEgLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkbyBNYXJhbmjDo28xQjBABgNVBAsUOURHVEkgLSBE\naXJldG9yaWEgZGUgR2VzdMOjbyBkYSBUZWNub2xvZ2lhIGRhIEluZm9ybWHDp8Oj\nbzEfMB0GCSqGSIb3DQEJARYQZGd0aUBpZm1hLmVkdS5icjESMBAGA1UEBxQJU8Oj\nbyBMdWlzMRIwEAYDVQQIFAlNYXJhbmjDo28xCzAJBgNVBAYTAkJSMRwwGgYDVQQD\nExNzcnZjYWZlLmlmbWEuZWR1LmJyMB4XDTE0MDQxMTIwNTEzNVoXDTE5MDQxMDIw\nNTEzNVowgegxLjAsBgNVBAoUJUlGTUEgLSBJbnN0aXR1dG8gRmVkZXJhbCBkbyBN\nYXJhbmjDo28xQjBABgNVBAsUOURHVEkgLSBEaXJldG9yaWEgZGUgR2VzdMOjbyBk\nYSBUZWNub2xvZ2lhIGRhIEluZm9ybWHDp8OjbzEfMB0GCSqGSIb3DQEJARYQZGd0\naUBpZm1hLmVkdS5icjESMBAGA1UEBxQJU8OjbyBMdWlzMRIwEAYDVQQIFAlNYXJh\nbmjDo28xCzAJBgNVBAYTAkJSMRwwGgYDVQQDExNzcnZjYWZlLmlmbWEuZWR1LmJy\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAndeQ2TDWt0/WD456cqgd\nXQ9b/8GofISh4bqfAgE/ryJnTq7+Qf/ZEFoAD0dIpSyPlBhUjYE2wwOlUURD4+8y\nivNSwYbC44MXvTH+7QES86Ei+/rSUvmjOaibXr3jcoEZZPoYSHBUWvuPM8yubjXw\naY+dyyg9AjGMGq6bm5xm7prcE9IQT++sCzhnLx9PLpfEiFlPr3pnZKuLWvlEb/OV\nE0IkzzCAoFfLDfZAbEK5NInsd399Zw9o0Bfo3M0pRGzyZUHahnTKiGBagdK//tpm\nBhiT3azSvfWF7pxleUOCMJHTEum426AtaBpFyKBrvIEKr0OqgDj8uBsia4PH1lUY\nIwIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQBIZQEEWkQzIWbBHPbM5qGGkRgu2KfT\n39lv6LGDDjZaJH7CPFP1FElKAsw1FVOlsYGdF5xbvclqLiZeRa2WUlFqsEeZQHS2\nWcCWgsYjMANovjer9I834lFpxNATnKe4H3NsI3rlrfyBGJrSX3w/48s2xa8XgWDq\n7EWAk7GVDgPvc25kWIzlex6FXlfmPOnwsXrgpieCk6HH1jFn+xKshJHMntCjk3al\nFBO6NIuxgaFzNAp1X7EbCxKpFTZxjxC1YjfZAa/4XbZHqV9NHuW9w7QRz5wYvbDB\nUgQ4/xzHw95wCdYlE/aIdGiIG/ATFHnXv2ZiSCm8XDmz6wDBRVfw3Wv6"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFMA - Instituto Federal do Maranhao"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFMA - Instituto Federal do Maranhao"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifma.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifma.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFMA - Instituto Federal do Maranhao"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFMA - Instituto Federal do Maranhao"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:cru.fr:federation:univ-angers.fr",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ddn-ssr@listes.univ-angers.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:cru.fr:federation:univ-angers.fr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-06-23T11:48:50Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.univ-angers.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.univ-angers.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.univ-angers.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-angers.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-angers.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Employees and students from the University of Angers"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Les personnels et \u00e9tudiants de l'Universit\u00e9 d'Angers"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Angers"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 d'Angers"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVAMabeXzhOvplUR9r4t9fsuUrWixGMA0GCSqGSIb3DQEB\nBQUAMCQxIjAgBgNVBAMTGXNoaWJib2xldGgudW5pdi1hbmdlcnMuZnIwHhcNMTQw\nNDE4MDY1MzI1WhcNMzQwNDE4MDY1MzI1WjAkMSIwIAYDVQQDExlzaGliYm9sZXRo\nLnVuaXYtYW5nZXJzLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\nnjrHW1QuXFlucp6z9Q5qwHBNer+ZquJPEs1detiZARHyigMJILaslGc8b6FwA+xC\npam+vAnnhFVXLI7iR4G7chrAl0cpiuBLifK3uMFKo+a7NTOBT4N9UNSyWPuVoF23\nkq+cPptIw01BV4jp4A4QoZbfqr4ueeY3oujYi4HhAZS3Twh+EByeJb208XZJjE78\npokPWU//uWpLdVWm+fq8X9HOBhyMaFqsbBV0pRI72rYiSUifPrws5EI6aWonLt9R\n59HcvN0bx+k3dlMgEBOx9y1B2189/8bLVAg1wM2zaKlyGMbmzlJ5PwzjVUAs5G/J\nEMaRfdVHCNiX3r33XO4ZYQIDAQABo3kwdzBWBgNVHREETzBNghlzaGliYm9sZXRo\nLnVuaXYtYW5nZXJzLmZyhjBodHRwczovL3NoaWJib2xldGgudW5pdi1hbmdlcnMu\nZnIvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFAKn+28vOVV2v3JY1xRWVCTpRbI6\nMA0GCSqGSIb3DQEBBQUAA4IBAQB+45tSXigpVOHs6oJCae7LyB97FXb2w2TTkYsI\nXD1hgEszYlaxjEF1Y1+GYX9eC7EX+al9pil/3buaFHcd5hi7NeY8HBsNqTjXI8kr\n4/vaJqT/RhnWHb9ylDweiCtIDu6W2NjUw1zEehgtG1WbxeERvggVZw6p4B5U3WQ5\nEW8UH2uweFDWwfDBLnYAiX2IYiHzvR1+N1CHFXs1x7JeatpsHtOJeoaYfWDtBHVu\nR2mmF7L5xU2Vz6xEp0X4OUPKsBXAaRBFHs+2LIY+wAdwM3tjjUxCYgwp5uOoX2dk\nSIWEfxyrSc9yevZKOFUP04Oi4b6WcQbgRl5bIy6PHi2kYiRe"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVAMHj2Cu/7KEX13/aTUHqdXfb3tFgMA0GCSqGSIb3DQEB\nBQUAMCExHzAdBgNVBAMTFmZyb250YWwudW5pdi1hbmdlcnMuZnIwHhcNMTAwOTA5\nMTAzMjQyWhcNMzAwOTA5MTAzMjQyWjAhMR8wHQYDVQQDExZmcm9udGFsLnVuaXYt\nYW5nZXJzLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAjIh2qi8D\nqFiSERXM4uugvV8s4OBCMbosII48TW6O0zG5KMtaLDnTDatBTchVONzQ7M5IEg/7\nnM90aocij3FZxWqDnV/o5A/MMuBoB8/J9oWgMVPnB+sBlixpQiWc5L/31HQgVPtL\n7AOuyC9xxldTx1e5kDBpW0QDyqZdtbApqAI0N4pCtrIKm8lYTYJ28eZQDUF7nu/h\nhw6HgSRY3qtCWnpkahaRziIFfsxyt1PJQSmaEdkHheFJWuoW8ptt3DwVn+ywBkX4\nEkZnBkuHZ3E5CMWXMz8WzfSqeJj+epi1vCDr80R6v7wKez7CWLt+uit7ZFyjjv+l\nzKa9OHlDCG52qQIDAQABo3MwcTBQBgNVHREESTBHghZmcm9udGFsLnVuaXYtYW5n\nZXJzLmZyhi1odHRwczovL2Zyb250YWwudW5pdi1hbmdlcnMuZnIvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFJC10iOKAVjMBWfVlXG7viH4rneDMA0GCSqGSIb3DQEB\nBQUAA4IBAQBXoZx/uNmrVDdvRMUZL0ZVPP0XtHRngakIEi0ADSAh2zHAhvMgybDE\nW2EprWWG3CEltjt59/ugMV7y7/VkAuw2CMcFiKWGNYrlyXqx+u045lFxaB1VEkyH\nNFCBhYR00KhKcsyLZFGRhjJsRF8BrPPk4APrhMzKMm7yyysWgK8zaIx1G1vWG5FD\ne2SaH84F6OdHlwY/DFR+h6JFkH7FrBoJxKcnlCTL8NGhH2Kc15JweNdb7aTthrqb\n85iK6ee+lD481XBORDuJ9IueWi+kuDTSoTCP403vuFXe3SCMDi5ifHnw+7CH/jd8\n+2aam5wgFGGrA1qTjyQEFHulpuQ6mnIK"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 d'Angers"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-angers.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 d'Angers"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://gw-astronomy.org/wiki/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "uwm-help@gravity.phys.uwm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UWM CGCA Help"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "anders15@uwm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Warren Anderson"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lsc-seccomm@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LIGO Scientific Collaboration Security Committee"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "stephanb@uwm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Branson Stephens"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://gw-astronomy.org/wiki/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Wisconsin-Milwaukee"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uwm.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Wisconsin-Milwaukee"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://gw-astronomy.org/wiki/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://gw-astronomy.org/wiki/Main/SPInfo"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Gravitational Wave Astronomy Community wiki used to support collaboration across astronomy and astrophysics projects."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://gw-astronomy.org/wiki/Main/SPPrivacy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Gravitational Wave Astronomy Community Wiki"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEWDCCA0CgAwIBAgIBPjANBgkqhkiG9w0BAQUFADCBhzETMBEGCgmSJomT8ixk\nARkWA29yZzEUMBIGCgmSJomT8ixkARkWBGxpZ28xDTALBgNVBAoTBExJR08xIDAe\nBgNVBAsTF0NlcnRpZmljYXRlIEF1dGhvcml0aWVzMRUwEwYDVQQLEwxXZWIgU2Vy\ndmljZXMxEjAQBgNVBAMTCUxJR08gQ0EgMTAeFw0xMTA0MjkxNzI0MTJaFw0yMTA0\nMjgxNzI0MTJaMGoxEzARBgoJkiaJk/IsZAEZFgNvcmcxFDASBgoJkiaJk/IsZAEZ\nFgRsaWdvMQ0wCwYDVQQKEwRMSUdPMRUwEwYDVQQLEwxXZWIgU2VydmljZXMxFzAV\nBgNVBAMTDmd1ZXN0LmxpZ28ub3JnMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\nCgKCAQEApxrDaMIRCnagFhhjD4rY47JBOHKjA4IS6EG1MvqG6kMXm73ZdYRhRraQ\nonVmFMUPPlkR5zTlok+qvb+Iy58s6PqguQe0Tz3eEnfRlVqLaXniKNGxkef5pXFY\nhndYXzkfeoclycdYZGwu12ANoG5wjADhYcWEuiyJKprfWXF/msa65rkczuMd5WFw\nlde6hnpZTXa6FaeYb1Hi8Me36pHFCU3DfhARdup7DQ4t3QDEttQY1mn/pnY6vd2o\noa/jmL1iHkJbTDT6+EWhk/3XdrC1tfo1VKQ+B4RebTyzRY8Wsgn3CAyAz9K5nA7w\naYBOYhK26Z6envlE+vXviDI89J/C7QIDAQABo4HqMIHnMAwGA1UdEwEB/wQCMAAw\nDgYDVR0PAQH/BAQDAgSwMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAZ\nBgNVHSAEEjAQMA4GDCsGAQQBgfpGAgECATA5BgNVHR8EMjAwMC6gLKAqhihodHRw\nOi8vY2EubGlnby5vcmcvNTQxNDA0YzMvNTQxNDA0YzMuY3JsMB8GA1UdIwQYMBaA\nFFJu3Xuqb4VcCCLTl5+tfyNWHmrRMDEGA1UdEQQqMCiCDmd1ZXN0LmxpZ28ub3Jn\ngRZzY290dC5rb3JhbmRhQGxpZ28ub3JnMA0GCSqGSIb3DQEBBQUAA4IBAQBXTyxj\nWEiIQ4kG8I9ujY9AssDMi63g9m4AT7uAm6mbNJVRaYkYVy7lnRi227fBjIXr8rku\ngfUhzwRULi9OUuY5eO713iB/urMn3mysch9R6heciYGzccnn5nN3gWrUN3kZ0AWd\nXaIE5G8rZOACTDp7SCVyNH1eZNkk6apK9LJgblo44XppU8gZk1OIzBzeknCuZhGz\n6Lnu58KItVKI+8w7FepUsXIdF6pHRLevhzW7d61QZ5iW8o2qW0TG24RDY4JJE45m\ny6qIv7HErgRcZZrxupRI6NfHLBxJx22n8rBD7gmVoCLXkAftIKQZ8pBKF4c74ErF\nxWUYS9G3JfMMW9UY"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gw-astronomy.org/wiki/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://gw-astronomy.org/wiki/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://gw-astronomy.org/wiki/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Gravitational Wave Astronomy Community Wiki"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Gravitational Wave Astronomy Community wiki used to support collaboration across astronomy and astrophysics projects."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sso.tugraz.at/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Admins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso@tugraz.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.tugraz.at/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://eduid.at/policy/mdrps-20140606"
              }
            ],
            "registration_instant": "2009-07-15T16:30:10Z",
            "registration_authority": "http://eduid.at",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUG6ra0BvXswfyErcCDmzw3AV+uI0wDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNc3NvLnR1Z3Jhei5hdDAeFw0xMDAzMjkxNzEzMTZaFw0z\nMDAzMjkxODEzMTZaMBgxFjAUBgNVBAMTDXNzby50dWdyYXouYXQwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCEyQxHIM1zxbBnXn60Ksg7B7HcPLPcN7bX\nLrLPOFXtkZxm0YkHY5Rxignm7wHD7C81U09DFS2eT8qRCcVtVz+kuwdgS54fC/al\ng9oLxXk4CgKjhtZZ2ECLdTHfUXOA5uOLlpoN1LY6VpIjSYe3UEX3HxfhXx/fPeE8\nVInGCKnml8Too22G30htB/EU44A2yqrR3LUngJIaq//N0QbeMYitNh02o6xB5+bp\n6k6noM7DH6S9phe0kCEibaiLaCf7k9LpNnAz9bPtQVth0gdJqoUry/iK1QBTFTEX\nvvJynFEp0+5Wz/XFmEcFhsaK8OcHd0R9FfpX5Z2fewA2Q0SLKz+bAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDXNzby50dWdyYXouYXSGJGh0dHBzOi8vc3NvLnR1Z3Jhei5h\ndC9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUXd76PcSiXR6wFna5qQi+S0W/9Y0w\nDQYJKoZIhvcNAQEFBQADggEBACgkQqxBtYY1OcuoAUP/P+ukJW7XyofK89qs2dkG\nClx7s0hR/1zImWgljgfguLJOSfC/CWE1wfNK9bTi4Fu9809PmOoaCxkNmniFRAya\nOiBoUz5XIpJniW7wBo+YBpBlXZXi5PmU2DOsfZxo7fs4se32dHO1WqgJodqkK2Wa\n4HDiigh42trZ9i3uS73uHSSCeIJYQNj84BMJ+ifgj3Zi/TgLS+IX7Ayy2bkDzIzI\nRnj7ULQ/MgfacGXQXJPHyp+w+YvydQalPAWc43+5DkNacN34K8cE3XjHq1kx/BgY\nOtQ7M2Xa1oApLzPoHO4D2kaf6FCgGR8Mx7GVAz0aQVxfB8I="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tugraz.at"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.tugraz.at:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.tugraz.at:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso.tugraz.at/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.tugraz.at/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sso.tugraz.at/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.tugraz.at/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.tugraz.at:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.tugraz.at:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tugraz.at"
              },
              {
                "logo": [
                  {
                    "text": "https://bigmail.tugraz.at/source/images/logo_head.gif",
                    "height": "77",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "200"
                  },
                  {
                    "text": "https://bigmail.tugraz.at/favicon.ico",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Technische Universit\u00e4t Graz"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Graz University of Technology"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUG6ra0BvXswfyErcCDmzw3AV+uI0wDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNc3NvLnR1Z3Jhei5hdDAeFw0xMDAzMjkxNzEzMTZaFw0z\nMDAzMjkxODEzMTZaMBgxFjAUBgNVBAMTDXNzby50dWdyYXouYXQwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCEyQxHIM1zxbBnXn60Ksg7B7HcPLPcN7bX\nLrLPOFXtkZxm0YkHY5Rxignm7wHD7C81U09DFS2eT8qRCcVtVz+kuwdgS54fC/al\ng9oLxXk4CgKjhtZZ2ECLdTHfUXOA5uOLlpoN1LY6VpIjSYe3UEX3HxfhXx/fPeE8\nVInGCKnml8Too22G30htB/EU44A2yqrR3LUngJIaq//N0QbeMYitNh02o6xB5+bp\n6k6noM7DH6S9phe0kCEibaiLaCf7k9LpNnAz9bPtQVth0gdJqoUry/iK1QBTFTEX\nvvJynFEp0+5Wz/XFmEcFhsaK8OcHd0R9FfpX5Z2fewA2Q0SLKz+bAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDXNzby50dWdyYXouYXSGJGh0dHBzOi8vc3NvLnR1Z3Jhei5h\ndC9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUXd76PcSiXR6wFna5qQi+S0W/9Y0w\nDQYJKoZIhvcNAQEFBQADggEBACgkQqxBtYY1OcuoAUP/P+ukJW7XyofK89qs2dkG\nClx7s0hR/1zImWgljgfguLJOSfC/CWE1wfNK9bTi4Fu9809PmOoaCxkNmniFRAya\nOiBoUz5XIpJniW7wBo+YBpBlXZXi5PmU2DOsfZxo7fs4se32dHO1WqgJodqkK2Wa\n4HDiigh42trZ9i3uS73uHSSCeIJYQNj84BMJ+ifgj3Zi/TgLS+IX7Ayy2bkDzIzI\nRnj7ULQ/MgfacGXQXJPHyp+w+YvydQalPAWc43+5DkNacN34K8cE3XjHq1kx/BgY\nOtQ7M2Xa1oApLzPoHO4D2kaf6FCgGR8Mx7GVAz0aQVxfB8I="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Technische Universit\u00e4t Graz"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Graz University of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.zid.tugraz.at/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tugraz.at/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Technische Universit\u00e4t Graz"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Graz University of Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://accounts.bils.se/saml2/metadata/",
    {
      "contact_person": [
        {
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://accounts.bils.se/saml2/metadata/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bioinformatics Infrastructure for Life Sciences"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.bils.se/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Bioinformatics Infrastructure for Life Sciences"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://accounts.bils.se/saml2/acs/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Med BILS kontoportal kan du ans\u00f6ka om och hantera ditt konto f\u00f6r \u00e5tkomst till de verktyg BILS erbjuder."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Using the BILS Account Registry users can apply for and manage their accounts for the various tools offered by BILS."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "BILS Kontoportal"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "BILS Account Registry"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEbTCCA1WgAwIBAgIQKEB8OmOTI+IoIs2uuCInzjANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQyNDAwMDAwMFoXDTE3MDQyMzIzNTk1OVowPjEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRkwFwYDVQQDExBhY2NvdW50cy5i\naWxzLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAz8v9r4VuxSCG\n1C6Mx/BemGTmZqco1i9jwprOinBM7otG+605q3i9d3l6ii7jm7G5OkDbK7D9uCKl\nk2JfPxwKnmHEsAOqUPs/B1GQrcvvz33+dafSazz9fITJi4cvHqrVXHqMHRuS5+kr\nidoKdVs/ezJMtecWSkkn8/XBEHOHTVQ5KJxnlAOAmObGogQZKP/CWrriVILwdB59\nwetwqRt8tGBNpI2hagcm3PIWhVpYgfbaXibgXMkN7UCCprjx3a0Qx1Prs9Q0wKfu\nP/LTFgGrxU419HMudPGR61UJpiN9WrI4BhmRqaqflLkSZ8Txzril4jt+aLDkNkj0\nMPWYas90YQIDAQABo4IBbTCCAWkwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH\n6pDjue0wHQYDVR0OBBYEFP/1uVSK8uMoag5p3FIdor4yULAcMA4GA1UdDwEB/wQE\nAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcD\nAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAx\nMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNy\nbDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRl\ncmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8vb2Nz\ncC50Y3MudGVyZW5hLm9yZzAbBgNVHREEFDASghBhY2NvdW50cy5iaWxzLnNlMA0G\nCSqGSIb3DQEBBQUAA4IBAQAeHAeaSytzyAMadq4MlstVvNxxqLwcS+t7pIzGusS3\nUxs4iLJxWdTEeHuiJ6lf3j35HaNbDRXTItx/fJ+tZpW1eqamCO226q/ZEAacqvnr\ndECD8w4hPUI6PUyMGxCTsQ1aI2ZYMGDp8ZiFP5lF2ENlP7Na2QFnj/EnZOFyS44w\nVTHEQSFFGdZTY7+ZXxgOtn4bjJkQB4zQ06vzlp0+TsbiSqhmX8xvqMq5KKF2AUwd\nG7JObLb3ULf7tNpsvhUmhzMNdTzZa3Mb6atMTvTWq/IMX3lpIQ/uEPYoxub8vBU7\naM3Ix3yd/kE2ExTHbzAz/CVwuHbTJZvF6qHDb0YWqnKb"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://accounts.bils.se/saml2/acs/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "BILS Account Registry"
                }
              ],
              "requested_attribute": [
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "first_name",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "last_name",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "email",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.2.840.113549.1.9.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibidp.luc.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dns-admin@luc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ITS"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibidp.luc.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.luc.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.luc.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFGDCCBACgAwIBAgIJAMgsqvOPf0BMMA0GCSqGSIb3DQEBBQUAMIG4MQswCQYD\nVQQGEwJVUzERMA8GA1UECBMISWxsaW5vaXMxEDAOBgNVBAcTB0NoaWNhZ28xHjAc\nBgNVBAoTFVVuaXZlcnNpdHkgb2YgQ2hpY2FnbzEoMCYGA1UECxMfSW5mb3JtYXRp\nb24gVGVjaG5vbG9neSBTZXJ2aWNlczEYMBYGA1UEAxMPc2hpYmlkcC5sdWMuZWR1\nMSAwHgYJKoZIhvcNAQkBFhFkbnMtYWRtaW5AbHVjLmVkdTAeFw0xMzA1MTcxOTIw\nNDNaFw0xODA1MTgxOTIwNDNaMIG4MQswCQYDVQQGEwJVUzERMA8GA1UECBMISWxs\naW5vaXMxEDAOBgNVBAcTB0NoaWNhZ28xHjAcBgNVBAoTFVVuaXZlcnNpdHkgb2Yg\nQ2hpY2FnbzEoMCYGA1UECxMfSW5mb3JtYXRpb24gVGVjaG5vbG9neSBTZXJ2aWNl\nczEYMBYGA1UEAxMPc2hpYmlkcC5sdWMuZWR1MSAwHgYJKoZIhvcNAQkBFhFkbnMt\nYWRtaW5AbHVjLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAPaB\noFEEJ8SB3HPYxRlz+AP8kqfvxXZUg3qW1SUOdR61LNQ3H105Mn87JNEOBJI0fXKD\nGhP52UeXy6VCGWiCW424GVvPqCC0iqDE+MOnQd7AVarUsERF53ngfJLw7UT89CA0\nTuoHwMqG9t2N7f8RYe3m7MoHPfE2gccfKUvA7gXj/licMNCLJnDvYHBERud0ljpm\nMAYc8+eqhBCsouumiofrFeotfNverU03OasKptJZ21nu6o7tCoz2FgTIRWlHtyEz\nT8bjHG+TYyEaW/4vhcwCvCyPEm76GLhSLKd8Ye7ZLPNMJEcX8zOR+ah1jJlFILzP\nKh3/Q/Zdm99ztv+YlUcCAwEAAaOCASEwggEdMB0GA1UdDgQWBBSnFXtGoWXa2qok\neiLJ+7t2DhemaDCB7QYDVR0jBIHlMIHigBSnFXtGoWXa2qokeiLJ+7t2DhemaKGB\nvqSBuzCBuDELMAkGA1UEBhMCVVMxETAPBgNVBAgTCElsbGlub2lzMRAwDgYDVQQH\nEwdDaGljYWdvMR4wHAYDVQQKExVVbml2ZXJzaXR5IG9mIENoaWNhZ28xKDAmBgNV\nBAsTH0luZm9ybWF0aW9uIFRlY2hub2xvZ3kgU2VydmljZXMxGDAWBgNVBAMTD3No\naWJpZHAubHVjLmVkdTEgMB4GCSqGSIb3DQEJARYRZG5zLWFkbWluQGx1Yy5lZHWC\nCQDILKrzj39ATDAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCwagY4\n6ZOKo7qE0bURa18HAKsNDltHriyEqmLfWulHrru4GybvoLbRG+CgPk/CVORQ4ISC\nqlMvC87ii3cX+zuGH6qEwUxiU4OkR0/bF6iMuLTvMZCZ8N4yBdSbmooICax7NbMd\nx7+QlahCJeChDx/na1jHXFk0PNxynKPf4sKdgXqdsaKUc0eT7gbOilG0O03RZp/k\nSv1JUZ8WViWg/2H1ELeCnhc5MDvHCKZd2+tdm7vyi+9gQTuBUhTcAM68yqtMf9kA\nF4MhlfISGNByyfe+7TgWasEJjTyrX1UyNm4S219PsfZ1xvfk+5mv3ZgRnk/ioqB7\nl2CikVfLPoeavqtv"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "luc.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.luc.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.luc.edu/idp/profile/Shibboleth/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.luc.edu/idp/profile/Shibboleth/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.luc.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.luc.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "luc.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Loyola University of Chicago"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFGDCCBACgAwIBAgIJAMgsqvOPf0BMMA0GCSqGSIb3DQEBBQUAMIG4MQswCQYD\nVQQGEwJVUzERMA8GA1UECBMISWxsaW5vaXMxEDAOBgNVBAcTB0NoaWNhZ28xHjAc\nBgNVBAoTFVVuaXZlcnNpdHkgb2YgQ2hpY2FnbzEoMCYGA1UECxMfSW5mb3JtYXRp\nb24gVGVjaG5vbG9neSBTZXJ2aWNlczEYMBYGA1UEAxMPc2hpYmlkcC5sdWMuZWR1\nMSAwHgYJKoZIhvcNAQkBFhFkbnMtYWRtaW5AbHVjLmVkdTAeFw0xMzA1MTcxOTIw\nNDNaFw0xODA1MTgxOTIwNDNaMIG4MQswCQYDVQQGEwJVUzERMA8GA1UECBMISWxs\naW5vaXMxEDAOBgNVBAcTB0NoaWNhZ28xHjAcBgNVBAoTFVVuaXZlcnNpdHkgb2Yg\nQ2hpY2FnbzEoMCYGA1UECxMfSW5mb3JtYXRpb24gVGVjaG5vbG9neSBTZXJ2aWNl\nczEYMBYGA1UEAxMPc2hpYmlkcC5sdWMuZWR1MSAwHgYJKoZIhvcNAQkBFhFkbnMt\nYWRtaW5AbHVjLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAPaB\noFEEJ8SB3HPYxRlz+AP8kqfvxXZUg3qW1SUOdR61LNQ3H105Mn87JNEOBJI0fXKD\nGhP52UeXy6VCGWiCW424GVvPqCC0iqDE+MOnQd7AVarUsERF53ngfJLw7UT89CA0\nTuoHwMqG9t2N7f8RYe3m7MoHPfE2gccfKUvA7gXj/licMNCLJnDvYHBERud0ljpm\nMAYc8+eqhBCsouumiofrFeotfNverU03OasKptJZ21nu6o7tCoz2FgTIRWlHtyEz\nT8bjHG+TYyEaW/4vhcwCvCyPEm76GLhSLKd8Ye7ZLPNMJEcX8zOR+ah1jJlFILzP\nKh3/Q/Zdm99ztv+YlUcCAwEAAaOCASEwggEdMB0GA1UdDgQWBBSnFXtGoWXa2qok\neiLJ+7t2DhemaDCB7QYDVR0jBIHlMIHigBSnFXtGoWXa2qokeiLJ+7t2DhemaKGB\nvqSBuzCBuDELMAkGA1UEBhMCVVMxETAPBgNVBAgTCElsbGlub2lzMRAwDgYDVQQH\nEwdDaGljYWdvMR4wHAYDVQQKExVVbml2ZXJzaXR5IG9mIENoaWNhZ28xKDAmBgNV\nBAsTH0luZm9ybWF0aW9uIFRlY2hub2xvZ3kgU2VydmljZXMxGDAWBgNVBAMTD3No\naWJpZHAubHVjLmVkdTEgMB4GCSqGSIb3DQEJARYRZG5zLWFkbWluQGx1Yy5lZHWC\nCQDILKrzj39ATDAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCwagY4\n6ZOKo7qE0bURa18HAKsNDltHriyEqmLfWulHrru4GybvoLbRG+CgPk/CVORQ4ISC\nqlMvC87ii3cX+zuGH6qEwUxiU4OkR0/bF6iMuLTvMZCZ8N4yBdSbmooICax7NbMd\nx7+QlahCJeChDx/na1jHXFk0PNxynKPf4sKdgXqdsaKUc0eT7gbOilG0O03RZp/k\nSv1JUZ8WViWg/2H1ELeCnhc5MDvHCKZd2+tdm7vyi+9gQTuBUhTcAM68yqtMf9kA\nF4MhlfISGNByyfe+7TgWasEJjTyrX1UyNm4S219PsfZ1xvfk+5mv3ZgRnk/ioqB7\nl2CikVfLPoeavqtv"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Loyola University of Chicago"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.luc.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Loyola University of Chicago"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.cvt.grayzone.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.cvt.grayzone.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cvt.grayzone.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.cvt.grayzone.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cvt.grayzone.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cvt.grayzone.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cvt.grayzone.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.cvt.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.cvt.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.cvt.grayzone.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.cvt.grayzone.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.cvt.grayzone.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.cvt.grayzone.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.cvt.grayzone.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIJAKYg5cljlFfLMA0GCSqGSIb3DQEBCwUAMCQxIjAgBgNV\nBAMTGXd3dy5jdnQuZ3JheXpvbmUubGFkb2suc2UwHhcNMTYwMzE0MDg1MTUyWhcN\nMjYwMzEyMDg1MTUyWjAkMSIwIAYDVQQDExl3d3cuY3Z0LmdyYXl6b25lLmxhZG9r\nLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0SvPRcE2m0x356V7\nAYAJE3FFkqhJC2DRIh3V73qhu8bW0eEiP1biuAjefC43Mz71/OAMdcPYqbz1NZH0\nyWD8HLKtHgc2uLTHGyxDtmdz3Qx3siEXHThkxPZ6ULXuXxn5nTAiRotTgpev24kI\nZ5XW2EuOYbug0ffLS7fTx2YjHATuWtlukeicog5q3QA+NTYKRr3nSoUPyTmjwjxW\nvuBMLmgkZbEDK83EfejsnAagC9Gf4uBErzT1BWhJtvHMCFe8xWWcygmfczxHC3Ui\n1oeX5a6tmtbQpHXq5JGSICuw1MwExNTzYPcGlxQTi2EsNf4xFOsekLAg/vcRLoQf\nERTtWQIDAQABo3EwbzBOBgNVHREERzBFghl3d3cuY3Z0LmdyYXl6b25lLmxhZG9r\nLnNlhihodHRwczovL3d3dy5jdnQuZ3JheXpvbmUubGFkb2suc2UvZ3VpLXNwMB0G\nA1UdDgQWBBQtwDy/NQNla4m2lX9LSz7dZv4jqDANBgkqhkiG9w0BAQsFAAOCAQEA\nfLPa5lVl8MWg+y4MW88Gyx6xJJ6VlPpp5Try8fveAHqg59aTsQP63slN9T/abEde\n+EeYGf/wSjwpPvry80RXwjpvIAxrI8tCzrmPcA8AScio20D0nzQEFLNgrkKi0TZM\nbfOYldl4Zy2E7BO6FWutqVYQKa4yWfKP3gM2VUIhZlQ1ZnjOjZ/btmhgk9KvhHXo\naanLruOHz1dPK5bxvsGAfgaccCbU6Nkx1x5cjKfdlbLBtsCPZynSL6uIT+Tsx/3/\nkOhM8gni3b9R6PzNrSgXKf9+4brfTmQTQTaXsbONluEx7VH7i93XTorzvczhi6mt\n7968+n/qrUu+uywa/Z0NuQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.cvt.grayzone.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cvt.grayzone.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.cvt.grayzone.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cvt.grayzone.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cvt.grayzone.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cvt.grayzone.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cvt.grayzone.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.cvt.grayzone.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.cvt.grayzone.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.cvt.grayzone.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.oamk.fi/idp/shibboleth",
    {
      "entity_id": "https://idp.oamk.fi/idp/shibboleth",
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "true",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.oamk.fi/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oamk.fi"
              },
              {
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Yrkesh\u00f6gskolan i Ule\u00e5borg"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Oulu University of Applied Sciences"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Oulun ammattikorkeakoulu"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "kalmar"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "finland"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "tags",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEkTCCA3mgAwIBAgIRAOvPb9GQ1sEnxj0afzGU0O8wDQYJKoZIhvcNAQELBQAw\nZDELMAkGA1UEBhMCTkwxFjAUBgNVBAgTDU5vb3JkLUhvbGxhbmQxEjAQBgNVBAcT\nCUFtc3RlcmRhbTEPMA0GA1UEChMGVEVSRU5BMRgwFgYDVQQDEw9URVJFTkEgU1NM\nIENBIDIwHhcNMTQxMTI3MDAwMDAwWhcNMTcxMTI2MjM1OTU5WjA5MSEwHwYDVQQL\nExhEb21haW4gQ29udHJvbCBWYWxpZGF0ZWQxFDASBgNVBAMTC2lkcC5vYW1rLmZp\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuQYKaIbFH0R00fZDIBhB\nNFdIqyarvuGbRkgoD2XmZzI0n50WZlk1F4Dy171oLEx8s+q3y/5ydQNFqYotujnC\ncr674Kc567BAjxuiDVAuTuYAEY21jJkdLO7lZOsNP52u3CtqdrWPklt1ONyifASl\nR0OFxYBBSS0XaKX7woODViViknpGjU5xEOyJlAmDvo3+prBlJIFtGw3vHgB+mdzE\nuFsgYgHrS8j7HM9NpFixYqnvK0ovltajHPCqH7PNGY1zGnRVHJ9Yn1RWzWXL8isu\nSOaOxa+MG6B6d/rZEM2T6KYaopVLTeeeqKxJA0h+jhw5edg+a79OYnhYzQILrxSg\nCwIDAQABo4IBZzCCAWMwHwYDVR0jBBgwFoAUW9CKHJoyW+C13ZZUG+GGKLD9tr0w\nHQYDVR0OBBYEFLQRokdb7Vb9rnDtyl3+aoTtHueCMA4GA1UdDwEB/wQEAwIFoDAM\nBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNV\nHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAxMC+gLaAr\nhilodHRwOi8vY3JsLnVzZXJ0cnVzdC5jb20vVEVSRU5BU1NMQ0EyLmNybDBsBggr\nBgEFBQcBAQRgMF4wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudXNlcnRydXN0LmNv\nbS9URVJFTkFTU0xDQTIuY3J0MCUGCCsGAQUFBzABhhlodHRwOi8vb2NzcC51c2Vy\ndHJ1c3QuY29tMBYGA1UdEQQPMA2CC2lkcC5vYW1rLmZpMA0GCSqGSIb3DQEBCwUA\nA4IBAQBnkrnvWXKAE19U5qtyyMjmxcDtCRmEVjVeR/AJdXaxfMrZxKFrgZtTWQzY\nW0u3VFy4wbI2xpXJUy4sN6XdVctLJw/h6zj1xoMQc3wNCQjG4/UpzWyu6PpwEHTl\nyYL1HYL/NinHcCWnZG5QCGcoLmuaIjQYEa4wq2yQsLDm6SGAayVOltuHiQOHwPU6\n1ijxXQahfxhtxGx5DWIIBbLi98SIvvYMziAuhNhzmcCyk3fuh9PwTWuy+cLIn4oK\ngtHNRKeAa8a5U1VhWiERIJdxpn5OspN3NNwcM0inQSqawfC81R+DevcE8FE9FEHG\nTX93hQUG67uFAzr2POHZGdUrsSca"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jylha"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:haka_admin@oamk.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Panu"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jylha"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:haka_admin@oamk.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Panu"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Oulun ammattikorkeakoulu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Oulu University of Applied Sciences"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Yrkesh\u00f6gskolan i Ule\u00e5borg"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oamk.fi"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oamk.fi"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oamk.fi"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Oulun ammattikorkeakoulu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Oulu University of Applied Sciences"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Yrkesh\u00f6gskolan i Ule\u00e5borg"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor"
    }
  ],
  [
    "https://vpp.midlands3cities.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itservicedesk@nottingham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Betts"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Craig.Betts@nottingham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Craig"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://vpp.midlands3cities.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-09-17T10:01:33Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "M3C VPP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.midlands3cities.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Nottingham"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vpp.midlands3cities.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vpp.midlands3cities.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vpp.midlands3cities.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vpp.midlands3cities.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vpp.midlands3cities.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vpp.midlands3cities.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://vpp.midlands3cities.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Virtual Postgraduate Platform"
                  }
                ],
                "logo": [
                  {
                    "text": "https://vpp.midlands3cities.ac.uk/shibboleth-ds/logo_transparent.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "143"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "M3C VPP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIJAOAjIQJx+4c/MA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\n\t\t\t\t\t\tBAMTGXZwcC5taWRsYW5kczNjaXRpZXMuYWMudWswHhcNMTUwOTE1MTEyMjQxWhcN\n\t\t\t\t\t\tMjUwOTEyMTEyMjQxWjAkMSIwIAYDVQQDExl2cHAubWlkbGFuZHMzY2l0aWVzLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAyGltDWl57D+/WfKV\n\t\t\t\t\t\tQSoHkEpwh9Hp8aflx1uF9NDg+3kLcucXCz5/x9+Vbb6c4Eh22wQSQZxRoMDR3eQd\n\t\t\t\t\t\tHbSect7xZWiEZVpftJdWbDWPNbayQdfUNOeLCQohBt9DAXYxcRwsO5RZdMkrTm72\n\t\t\t\t\t\tMhW5j0CtFmB2SjLZ16D/mRJCPAVsLtaQ1mThTUU75xtDL3FYEZQDYreyMDxjRqeU\n\t\t\t\t\t\tW4JnSUGyPjAdaA8v3mWMptyQCkzHJtYbeAXre639aunbl7brZR/H4ysDydEI65q3\n\t\t\t\t\t\truyFUA/hzatm2/tW0vmTbkYBdMLt4AG7v6oQuuoT4XCJmgP58uDo8MGEN2ds/i8r\n\t\t\t\t\t\tDw65RQIDAQABo3UwczBSBgNVHREESzBJghl2cHAubWlkbGFuZHMzY2l0aWVzLmFj\n\t\t\t\t\t\tLnVrhixodHRwczovL3ZwcC5taWRsYW5kczNjaXRpZXMuYWMudWsvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQUBAJDQt2jWrbNLitgyQu4PotWNwAwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAJxgwVcNBRoOVCPVBxj+a37OSoD3DZmQl07k1k8cijVr/0MOTboZiYkDBzqe\n\t\t\t\t\t\tzmrytY6CM/ej5IHJR7ByltSi/Nj67BQWFafhThULzZ1b+1ARWtvMQRaU9LuEVp3S\n\t\t\t\t\t\tebpzHFa4KrtNUFYp1UJs0YMPF63pA+uR0SomYpeB20BDULQ0lLR55dxcWH8lELM+\n\t\t\t\t\t\t9PEY7Z5v6asho2lBZ+PjdR1zBs11ffv4Y2G+3VLLndMm7MOs7m7Bo6m8PDl9p+f9\n\t\t\t\t\t\thCljjUhEyX/lIWuZjv5jZI8bCsviOM+ZLBwhoVpj1NMicj7PCeVP7k7RjnHM4qN+\n\t\t\t\t\t\tcevd/sPqVI0kteZSRYR9CQgLkco="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vpp.midlands3cities.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vpp.midlands3cities.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vpp.midlands3cities.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vpp.midlands3cities.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vpp.midlands3cities.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vpp.midlands3cities.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://secure.stevenson.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibadmin@stevenson.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibadmin@stevenson.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://secure.stevenson.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://secure.stevenson.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://secure.stevenson.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://secure.stevenson.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://secure.stevenson.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://secure.stevenson.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://secure.stevenson.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stevenson.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Stevenson University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAKgovFDN1fBUWFA+v7d4R+4C2FLWMA0GCSqGSIb3DQEB\nBQUAMB8xHTAbBgNVBAMTFHNlY3VyZS5zdGV2ZW5zb24uZWR1MB4XDTEyMDcxODE4\nNDUyNFoXDTMyMDcxODE4NDUyNFowHzEdMBsGA1UEAxMUc2VjdXJlLnN0ZXZlbnNv\nbi5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCSvX4t9W3UxKym\nQv9OKQzPSE2f/a6e5AjIa+a8A7V/Zt7u5AzFMyRsfARKGI24GrWTer9fJHvI4wTD\nOhqufNOjV3fNu570+HL1W9d/1ueM4ztmoh5jiWF4JxhxVTjJwBPkx2bkv7R10nI5\nl2HaRNyPSUSOSH3U9L0jN/a/KY97rOuM66fQ4V79L+g09C6XVxyqJrKBvryjk0f0\n5E/Ua8JcAZlgf0y200x5YdcZADjF8DwUtfEItUJ1FdxOnwXjbVDIcK02+J4Os3vT\nveZ0gmeRxsj9jAvZh44qjJlW2aFElFiE+PvE5QPhheSAx7LahyRM8Y9JWAhUD4JU\ngzsimD8xAgMBAAGjbzBtMEwGA1UdEQRFMEOCFHNlY3VyZS5zdGV2ZW5zb24uZWR1\nhitodHRwczovL3NlY3VyZS5zdGV2ZW5zb24uZWR1L2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBR5zC5WIV6lZzMAYwPbhfWgZN2omTANBgkqhkiG9w0BAQUFAAOCAQEA\nEpMtRKoKGLYWI+5ltPGqL7nhMzsqnlwLXP5cMLFN+FCxwa7kBi1fk//NCleLoaf7\nBiYxMqq3cDh1vhaklyr+NC3iwXGAbi6/D74rFksOhePX05xdAIi83s+6ImJXC+Gk\njPgB9Pyd+NV6S1CkehB2fCDRE8bMBOInspa1eszMqUUmJcfOg3jqYfnUMsk6rgKG\nQUqhM9TAwowIJzUEfJcwkNrCkBAzuUIG/R9zgi/wWARXSBdpvRwTeh2feHIoRrlL\nBVngyd850gsxHeIyUveI6rZDsRI6MozOP7ApzA482aHh8YHlekMh+mDafbuYDtMV\nvcW4oD4N2OIPcMam+7V1yw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Stevenson University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://stevenson.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Stevenson University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://federation.umcg.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://federation.umcg.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2014-12-05T00:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/32171f5a7a012631cb41c6824947cf99",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "umcg.nl"
              },
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UMCG"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UMCG"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/sp/UMCGkort_fc.png",
                    "height": "264",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "500"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UMC Groningen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UMC Groningen"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UMC Groningen"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UMC Groningen"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.umcg.nl"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.umcg.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UMC Groningen"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UMC Groningen"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://datasets.sunet.se/shibboleth",
    {
      "entity_id": "https://datasets.sunet.se/shibboleth",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish University Network (SUNET)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sunet.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SUNET"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://datasets.sunet.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://datasets.sunet.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://datasets.sunet.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://datasets.sunet.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://datasets.sunet.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://datasets.sunet.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://datasets.sunet.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "datasets.sunet.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+jCCAeKgAwIBAgIJAPzAlxKPYTw3MA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\nBAMTEWRhdGFzZXRzLnN1bmV0LnNlMB4XDTE1MDkxNjA4MjU0M1oXDTI1MDkxMzA4\nMjU0M1owHDEaMBgGA1UEAxMRZGF0YXNldHMuc3VuZXQuc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCuZGVdZIHFznevZLKckdbgYwu4Cb+B0M6YswGv\nqxAM29BWVbk8wdASB/8dThtEjX7GLhFpy3L59JMluBFZHub73kqcHxnX+dYDNiAE\nnYsthoVf3rx7j6gTqH1YNsfJYkcokVwxVCvTyPLyjIk0gZHp8WFrPdqNpl/YajX+\na5TtkMrhjgTWyA/cUSfnoDQqtJmfyz+0fp+I8sirma7i4W5QMrIllIEniyjFOKGc\nWO/LqY5RweMLpMe2VSizrp4JfgbY5ilei9YHaVZHfSJW0ezC59bO3Hlw43Wt3uCb\nKxPMPYpyDUqgW19a4mtbxQj5n6PC80/dqR1b/VfyOk8xI5zdAgMBAAGjPzA9MBwG\nA1UdEQQVMBOCEWRhdGFzZXRzLnN1bmV0LnNlMB0GA1UdDgQWBBQvAJ/2+qj0VzNn\nkpAMYo69KlcbXTANBgkqhkiG9w0BAQUFAAOCAQEAH0dYbfY5hsGZn7KGPda9Bvbo\nRl7rt39To9O5IrYwc7/FEgbuIOzjCDdx5Eeo+khhz9WEWv6jCMIMtZoHdqWHkcAn\nf2rTykgCw4Sck95sQT/Euw4wLtcrIOugwvVfGq9NfABJN8jGzJJtWkGhOxxn8QvQ\nYIHckCom/BLu632ON+EMgKnouow4xlfsruXbaFMC8w/dS8MPFnzTa36HccqJ65WS\nExH64IKAxSKgB0qIQrXyRK6v0oeHL+gFsx5aOuMScLXg7xLckD+xPEh+6G50mgKR\n2nnLFf/3OslGE3stQ+W+ofQTzHQA/3+3jlPtiuWzWoRrnIClym29edoJUg/2Gg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=datasets.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://datasets.sunet.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://datasets.sunet.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://datasets.sunet.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://datasets.sunet.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://datasets.sunet.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://hscshib1.qub.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:eresources@qub.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "E-Resouces Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Goodall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.goodall@qub.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://hscshib1.qub.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-01-04T11:59:59Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUZayvO9xYY8CR1y0pwTGPs9KIzC0wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHTEbMBkGA1UEAxMSaHNjLXNoaWIucXViLmFjLnVrMB4XDTE1MTExMDA4MTk0\n\t\t\t\t\t\tM1oXDTM1MTExMDA4MTk0M1owHTEbMBkGA1UEAxMSaHNjLXNoaWIucXViLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAiL/Lr+7KiGp3LM2YZYEQ\n\t\t\t\t\t\tJGwPGfKZnu9fUWORH5Bj7yCSDyU1efyxjnAvwgVeArgliZNJh2ux6Hm8izqeDWuL\n\t\t\t\t\t\tShCq9rAHyTa8s68abT47OiOIdqGtYVcWueOPljOghiloNQw3b025jdSuyk9pTMAU\n\t\t\t\t\t\tsaoUkTBbdrKwIXigKlUCQ1y6bc2e8PCdOrLs2n5QL7JGCns7/eK+ZVXywAjUAChW\n\t\t\t\t\t\tZYHEwijiDx/E4WSHbG1eTH+ep9gOy8P3e05/LrSiDp3ZfBlp74UqBVj+tyTut0nw\n\t\t\t\t\t\tZormRTd9yGO26/mwWeeQrfhPAhEUs0r12lD1G1tbUCFRxlWbceBUzVa9QfbD/0QV\n\t\t\t\t\t\tqwIDAQABo2swaTBIBgNVHREEQTA/ghJoc2Mtc2hpYi5xdWIuYWMudWuGKWh0dHBz\n\t\t\t\t\t\tOi8vaHNjLXNoaWIucXViLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQR\n\t\t\t\t\t\tSXVKceopY/texxj9jBmxSjCsbzANBgkqhkiG9w0BAQUFAAOCAQEAbm2e/5gMgp79\n\t\t\t\t\t\tSVOxVfxcBD4MxNgangNQ1l3v83NGhzXKKDnFwup5Nllq9S9P4IiTsB4avy8D+XBr\n\t\t\t\t\t\tKRERQmh65FYcBhELHMtd6CD+qiMftPcWtom747fp8cnM6shaehrsgg4a9J7t5IBB\n\t\t\t\t\t\tpMFvKinh78DghwuA+h96XoqVv3+KJdR8Vrx0gcTWrlZiIc710gz470q+fhNwkcYd\n\t\t\t\t\t\tVaVeY9/1bRYtkS8Xehr5lLBLYixCqaHFki/qu0IezZ0GzTGVP3x5ZaGz1up4ysdd\n\t\t\t\t\t\txD/wWsUwD8KQDwanJormGA7fh42ZkmnnQAEjgVmUxMFv0eTrald6mZ78fWQqBC5A\n\t\t\t\t\t\ttzZmZKhhgA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "honni.qub.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://hsc-shib.qub.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hsc-shib.qub.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://hsc-shib.qub.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hsc-shib.qub.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://hsc-shib.qub.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://hsc-shib.qub.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://hsc-shib.qub.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hsc-shib.qub.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "honni.qub.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUZayvO9xYY8CR1y0pwTGPs9KIzC0wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHTEbMBkGA1UEAxMSaHNjLXNoaWIucXViLmFjLnVrMB4XDTE1MTExMDA4MTk0\n\t\t\t\t\t\tM1oXDTM1MTExMDA4MTk0M1owHTEbMBkGA1UEAxMSaHNjLXNoaWIucXViLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAiL/Lr+7KiGp3LM2YZYEQ\n\t\t\t\t\t\tJGwPGfKZnu9fUWORH5Bj7yCSDyU1efyxjnAvwgVeArgliZNJh2ux6Hm8izqeDWuL\n\t\t\t\t\t\tShCq9rAHyTa8s68abT47OiOIdqGtYVcWueOPljOghiloNQw3b025jdSuyk9pTMAU\n\t\t\t\t\t\tsaoUkTBbdrKwIXigKlUCQ1y6bc2e8PCdOrLs2n5QL7JGCns7/eK+ZVXywAjUAChW\n\t\t\t\t\t\tZYHEwijiDx/E4WSHbG1eTH+ep9gOy8P3e05/LrSiDp3ZfBlp74UqBVj+tyTut0nw\n\t\t\t\t\t\tZormRTd9yGO26/mwWeeQrfhPAhEUs0r12lD1G1tbUCFRxlWbceBUzVa9QfbD/0QV\n\t\t\t\t\t\tqwIDAQABo2swaTBIBgNVHREEQTA/ghJoc2Mtc2hpYi5xdWIuYWMudWuGKWh0dHBz\n\t\t\t\t\t\tOi8vaHNjLXNoaWIucXViLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQR\n\t\t\t\t\t\tSXVKceopY/texxj9jBmxSjCsbzANBgkqhkiG9w0BAQUFAAOCAQEAbm2e/5gMgp79\n\t\t\t\t\t\tSVOxVfxcBD4MxNgangNQ1l3v83NGhzXKKDnFwup5Nllq9S9P4IiTsB4avy8D+XBr\n\t\t\t\t\t\tKRERQmh65FYcBhELHMtd6CD+qiMftPcWtom747fp8cnM6shaehrsgg4a9J7t5IBB\n\t\t\t\t\t\tpMFvKinh78DghwuA+h96XoqVv3+KJdR8Vrx0gcTWrlZiIc710gz470q+fhNwkcYd\n\t\t\t\t\t\tVaVeY9/1bRYtkS8Xehr5lLBLYixCqaHFki/qu0IezZ0GzTGVP3x5ZaGz1up4ysdd\n\t\t\t\t\t\txD/wWsUwD8KQDwanJormGA7fh42ZkmnnQAEjgVmUxMFv0eTrald6mZ78fWQqBC5A\n\t\t\t\t\t\ttzZmZKhhgA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "DHSSPS: honni-HSC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.honni.qub.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Queen's University of Belfast"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.fccn.pt/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pires"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rctsaai@fccn.pt"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Esmeralda"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "RCTSaai"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rctsaai@fccn.pt"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Equipa"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.fccn.pt/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2011-12-16T09:00:00Z",
            "registration_authority": "https://www.fccn.pt",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.fccn.pt/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.fccn.pt/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.fccn.pt/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.fccn.pt/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fccn.pt"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.fccn.pt/en/"
                  },
                  {
                    "lang": "pt",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.fccn.pt"
                  }
                ],
                "logo": [
                  {
                    "text": "https://rctsaai-rr.fccn.pt/rr/logos/FCT-FCCN_cmyk.png",
                    "height": "55",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "300"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FCT|FCCN"
                  },
                  {
                    "lang": "pt",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FCT|FCCN"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "fccn.pt"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:38.7591742762959,-9.142287969589233"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUGjtxtRHoicZCdPTxK6N9BrR1vZ8wDQYJKoZIhvcNAQEF\nBQAwFjEUMBIGA1UEAxMLaWRwLmZjY24ucHQwHhcNMTExMjE1MTUzOTExWhcNMzEx\nMjE1MTUzOTExWjAWMRQwEgYDVQQDEwtpZHAuZmNjbi5wdDCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAMk7r9by+CMZzGA/003Hjz08jJ9JrtfEQYOLVeh3\nCaMM3vAfwg5BljE+c7/fBs0teQRcnkx8oEGwGuBUV91qN5CIwRRgraXg2Xl5NDd+\nE76ebKWuOYqsB07V99esvRWwGMhAJrjd2Lc3u/th+8PNBfeXJOt49ZkC27uZ8ikf\nQauE0s9H+4i4c3bldrSVSuDq45yWr0wIHdox6dN/TjMk4kxSxyADmb/Ebp8N5n9v\n2l7Q9HFoaU2LnPJYyrbLrSepoFwdXgEYiu1pnrvbqT0SJ3vREctngTJ8MaL9dTLK\n2QaLN3cJkUby8254idNi8zPUHkvp2IFjuCcLc1k+ezdbc6kCAwEAAaNdMFswOgYD\nVR0RBDMwMYILaWRwLmZjY24ucHSGImh0dHBzOi8vaWRwLmZjY24ucHQvaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFAPVb6XSbR8AYJEn/xiLnVzx8KSoMA0GCSqGSIb3\nDQEBBQUAA4IBAQDF0YZ3v7xshyEUHIRxc8c2jM2cJOUBRj7aOqnJvOnK7FI/AaSG\nqtEMx9RJ+NHxr5sALx1/DBu1XPEdtuBfueL0C5ky4H8a78LRqH3x50oZto+Oq1DG\nhZr/kURJyAM9dzi8BYZx5K2wB9vvJO2DICmnla20DTlKPY8NMZwtFbwfMloQduMi\nbLam1wEq+9o8TKYrw4C0pBGa8nY9gDjB1yzbT04VAuqctQL0+Sw+cXFDEk2JLbCl\nBo4JbRU3T37aRSPJmLSx/lEQMBKP3cqlq+eig/e6thk3SA494XDUFlO6V+0XQF+u\nG5N6VkL0FX4oQt/9e14FaHZtwfb5uf02x6oO"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "pt",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "FCCN - unidade da FCT I.P."
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "FCCN"
          }
        ],
        "organization_url": [
          {
            "lang": "pt",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.fccn.pt"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.fccn.pt"
          }
        ],
        "organization_name": [
          {
            "lang": "pt",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "FCCN - unidade da FCT I.P."
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "FCCN"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.catalog.clarin.eu",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Admin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:clarin@clarin.eu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CLARIN"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sysops"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sysops@clarin.eu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CLARIN"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.catalog.clarin.eu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-02-13T16:53:40Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://clarin.eu/category/clarin-member"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://catalog.clarin.eu/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://catalog.clarin.eu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://catalog.clarin.eu/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://catalog.clarin.eu/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CLARIN CMDI Metadaten Anwendungen und Dienste - Katalog"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CLARIN CMDI metadata applications and services - catalog"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "F\u00fcr die Component Registry, Virtual Language Observatory."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "For the Component Registry, Virtual Language Observatory."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://catalog.clarin.eu/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.clarin.eu/applications"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CLARIN CMDI Metadaten Anwendungen und Dienste - Katalog"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CLARIN CMDI metadata applications and services - catalog"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "F\u00fcr die Component Registry, Virtual Language Observatory."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "For the Component Registry, Virtual Language Observatory."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.clarin.eu/sites/default/files/clarin-logo.png",
                    "height": "220",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "195"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://catalog.clarin.eu/privacy_statement.xhtml"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "catalog.clarin.eu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDnjCCAoYCCQCIw16p56fGnTANBgkqhkiG9w0BAQUFADCBkDELMAkGA1UEBhMC\nTkwxDDAKBgNVBAgTA0dMRDERMA8GA1UEBxMITmlqbWVnZW4xDzANBgNVBAoTBk1Q\nSS1QTDETMBEGA1UECxMKY2F0YWxvZyBzcDEaMBgGA1UEAxMRY2F0YWxvZy5jbGFy\naW4uZXUxHjAcBgkqhkiG9w0BCQEWD2xhdGFkbWluQG1waS5ubDAeFw0xNDA0Mjgw\nODAyMDVaFw0xOTA0MjcwODAyMDVaMIGQMQswCQYDVQQGEwJOTDEMMAoGA1UECBMD\nR0xEMREwDwYDVQQHEwhOaWptZWdlbjEPMA0GA1UEChMGTVBJLVBMMRMwEQYDVQQL\nEwpjYXRhbG9nIHNwMRowGAYDVQQDExFjYXRhbG9nLmNsYXJpbi5ldTEeMBwGCSqG\nSIb3DQEJARYPbGF0YWRtaW5AbXBpLm5sMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEA38nLf8TTeexrcqzfF5LOQ3F/9Tar+V7kNsLFUKO1ua6npX+4zgBu\nEYCm+hKrKDW09QN8yrBd+79a+slA4nCcpUymkh02rQhVbMpNiEQh8UFjqfaYv5fM\nR1OlgIWYXx2POdn60KbUYXIPGSrp2zQSXMFJMrnUOXHqxF8fxfTdbDEtcviXXwyC\nUjhXC4AJSLL/S8eftV8iioQDZMs5h1Kd95NVFsMhRC5MtD+iUyNsYR8X1PGaFg20\nbVg/Jg2eVNwPas49POr+HBOxk3BBtk8KwCAMwjCQUGL3zn7KeDLDFYsry/bWQtVn\nIbebSTysNhbrji3/VKnsPHiuOfCvYiqWEQIDAQABMA0GCSqGSIb3DQEBBQUAA4IB\nAQDTDfQr4wjJGAUo7os8PWTmKFkAH4D3oFQpxe4bvf6U9of4+fmE778S+WZc9kKs\nA0oCNgDwBaY/GdYIYloU/6GAxEu5Kql4HmB1XW5XyYZ15+zYluL86eLFe2DHnPHR\nZ3ZjnjzAkcZS6VU/vbowpAL9Oiic9I15BwyNXsT8lWPtOxKcmxAESMc7OtWm0o4C\nijjjB4MNkyvUmnvJZD+7ZpYW6qI4v64a4h1kdydtuCSxFz7lQ9U80gOA+oJWKa9a\nyN2Xk8rmco4g1veIYIZ6hKrydr0QJ40WvaiR1EkO0tpPa7wkayhFaOQDRrzFNpfr\ngDLbA/e0dbDclBvxUIm9cemA"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=latadmin@mpi.nl,CN=catalog.clarin.eu,OU=catalog sp,O=MPI-PL,L=Nijmegen,ST=GLD,C=NL"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "catalog.clarin.eu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDnjCCAoYCCQCIw16p56fGnTANBgkqhkiG9w0BAQUFADCBkDELMAkGA1UEBhMC\nTkwxDDAKBgNVBAgTA0dMRDERMA8GA1UEBxMITmlqbWVnZW4xDzANBgNVBAoTBk1Q\nSS1QTDETMBEGA1UECxMKY2F0YWxvZyBzcDEaMBgGA1UEAxMRY2F0YWxvZy5jbGFy\naW4uZXUxHjAcBgkqhkiG9w0BCQEWD2xhdGFkbWluQG1waS5ubDAeFw0xNDA0Mjgw\nODAyMDVaFw0xOTA0MjcwODAyMDVaMIGQMQswCQYDVQQGEwJOTDEMMAoGA1UECBMD\nR0xEMREwDwYDVQQHEwhOaWptZWdlbjEPMA0GA1UEChMGTVBJLVBMMRMwEQYDVQQL\nEwpjYXRhbG9nIHNwMRowGAYDVQQDExFjYXRhbG9nLmNsYXJpbi5ldTEeMBwGCSqG\nSIb3DQEJARYPbGF0YWRtaW5AbXBpLm5sMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEA38nLf8TTeexrcqzfF5LOQ3F/9Tar+V7kNsLFUKO1ua6npX+4zgBu\nEYCm+hKrKDW09QN8yrBd+79a+slA4nCcpUymkh02rQhVbMpNiEQh8UFjqfaYv5fM\nR1OlgIWYXx2POdn60KbUYXIPGSrp2zQSXMFJMrnUOXHqxF8fxfTdbDEtcviXXwyC\nUjhXC4AJSLL/S8eftV8iioQDZMs5h1Kd95NVFsMhRC5MtD+iUyNsYR8X1PGaFg20\nbVg/Jg2eVNwPas49POr+HBOxk3BBtk8KwCAMwjCQUGL3zn7KeDLDFYsry/bWQtVn\nIbebSTysNhbrji3/VKnsPHiuOfCvYiqWEQIDAQABMA0GCSqGSIb3DQEBBQUAA4IB\nAQDTDfQr4wjJGAUo7os8PWTmKFkAH4D3oFQpxe4bvf6U9of4+fmE778S+WZc9kKs\nA0oCNgDwBaY/GdYIYloU/6GAxEu5Kql4HmB1XW5XyYZ15+zYluL86eLFe2DHnPHR\nZ3ZjnjzAkcZS6VU/vbowpAL9Oiic9I15BwyNXsT8lWPtOxKcmxAESMc7OtWm0o4C\nijjjB4MNkyvUmnvJZD+7ZpYW6qI4v64a4h1kdydtuCSxFz7lQ9U80gOA+oJWKa9a\nyN2Xk8rmco4g1veIYIZ6hKrydr0QJ40WvaiR1EkO0tpPa7wkayhFaOQDRrzFNpfr\ngDLbA/e0dbDclBvxUIm9cemA"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=latadmin@mpi.nl,CN=catalog.clarin.eu,OU=catalog sp,O=MPI-PL,L=Nijmegen,ST=GLD,C=NL"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://catalog.clarin.eu/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://catalog.clarin.eu/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://catalog.clarin.eu/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://catalog.clarin.eu/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://catalog.clarin.eu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://catalog.clarin.eu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://catalog.clarin.eu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://catalog.clarin.eu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://catalog.clarin.eu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://catalog.clarin.eu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.leedsuniversityunion.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.leedsuniversityunion.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Leeds University Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.leedsuniversityunion.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.leedsuniversityunion.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.leedsuniversityunion.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.leedsuniversityunion.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.leedsuniversityunion.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.leedsuniversityunion.org.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.leedsuniversityunion.org.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.leedsuniversityunion.org.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.leedsuniversityunion.org.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.leedsuniversityunion.org.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.leedsuniversityunion.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.leedsuniversityunion.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.leedsuniversityunion.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.leedsuniversityunion.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.leedsuniversityunion.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.leedsuniversityunion.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idem.univpm.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem-help@univpm.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idem.univpm.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2010-08-06T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAJRPddpXPFSzRqSfPdrn/IFdufKtMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkZW0udW5pdnBtLml0MB4XDTEzMDgyNzA4Mjk1MVoX\nDTE2MDgyNzA4Mjk1MVowGTEXMBUGA1UEAxMOaWRlbS51bml2cG0uaXQwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCrVLl1s2FWb4lmcg+qOwTW/SfzsEEK\nozdQMTP66NHa/cNfGsIfnJsilNPRXedR7zCdtWzAQ81XZ8Yi0fwUjo3C1tEoNcaH\nGM1asCRUu1jYjGfT72weUEzHHlU+QlGzhlm6mcI9tAU9CJfB3CMwPYotrlufWHTQ\nbbKwNTBHS+9bmICLeSy7P6SqJOyCTqsU7FqF2B3nW7aLwRba7X5u3T1gUyAUYmjW\n7Ej8fTh9IYpCC2tCYgjYy99R9eF3RePUx2znbR8/Kap6fA0OgjN4DuM265HsLXgp\nU9te4k04BcxbFJ6K81yRGGE5qrhowJGvSbcv8qLEP0LKtuK3/RaInmGNAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkZW0udW5pdnBtLml0hiVodHRwczovL2lkZW0udW5p\ndnBtLml0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRv4qE5cJdI0tWc0PcoXfKY\nBG4YFDANBgkqhkiG9w0BAQUFAAOCAQEAXVsfjXIBRoEQ3AMcYlOcQ5lggDuHFdcB\nPDxVUzYlTDEyxhr4G0Nr/QjyQepInZneIKpSIiQTLN7iWaVz8CTTn5aiphMzF0hb\ndghLRtKuft4+M4ke7dEod8Xdu2vNFCoA9fdS44ycClWo7KlNmEdCKVsSK5UX8CRL\nRi+HTOO6KSAFxhAfOXVwcaZNst4vTyClGjVeGpV/HxG+5bCBsZOLHE8O2IH0tmjX\n5jpMJJwEvEo9wG4E08QNP09bTRA9VrhdsvTOBnQtgj+ni0EfOJ2T88Y1SmgRJgpz\nggqcHGSwpbNvAB4pbdMeCIdrPoaW3eZX3trf8/hnZOVxwVsXJey0nQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univpm.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idem.univpm.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idem.univpm.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idem.univpm.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idem.univpm.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idem.univpm.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idem.univpm.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idem.univpm.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idem.univpm.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univpm.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idem.univpm.it/index_en.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idem.univpm.it/index.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universita' Politecnica delle Marche"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universita' Politecnica delle Marche"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for \"UnivPM = Universita' Politecnica delle Marche\" users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider per gli utenti della \"UnivPM = Universita' Politecnica delel Marche\""
                  }
                ],
                "logo": [
                  {
                    "text": "https://idem.univpm.it/logo/16x16.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idem.univpm.it/logo/16x16.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idem.univpm.it/logo/60x80.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idem.univpm.it/logo/60x80.png",
                    "lang": "it",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://idem.univpm.it/attributes-released.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://idem.univpm.it/attributi-rilasciati.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAJRPddpXPFSzRqSfPdrn/IFdufKtMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkZW0udW5pdnBtLml0MB4XDTEzMDgyNzA4Mjk1MVoX\nDTE2MDgyNzA4Mjk1MVowGTEXMBUGA1UEAxMOaWRlbS51bml2cG0uaXQwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCrVLl1s2FWb4lmcg+qOwTW/SfzsEEK\nozdQMTP66NHa/cNfGsIfnJsilNPRXedR7zCdtWzAQ81XZ8Yi0fwUjo3C1tEoNcaH\nGM1asCRUu1jYjGfT72weUEzHHlU+QlGzhlm6mcI9tAU9CJfB3CMwPYotrlufWHTQ\nbbKwNTBHS+9bmICLeSy7P6SqJOyCTqsU7FqF2B3nW7aLwRba7X5u3T1gUyAUYmjW\n7Ej8fTh9IYpCC2tCYgjYy99R9eF3RePUx2znbR8/Kap6fA0OgjN4DuM265HsLXgp\nU9te4k04BcxbFJ6K81yRGGE5qrhowJGvSbcv8qLEP0LKtuK3/RaInmGNAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkZW0udW5pdnBtLml0hiVodHRwczovL2lkZW0udW5p\ndnBtLml0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRv4qE5cJdI0tWc0PcoXfKY\nBG4YFDANBgkqhkiG9w0BAQUFAAOCAQEAXVsfjXIBRoEQ3AMcYlOcQ5lggDuHFdcB\nPDxVUzYlTDEyxhr4G0Nr/QjyQepInZneIKpSIiQTLN7iWaVz8CTTn5aiphMzF0hb\ndghLRtKuft4+M4ke7dEod8Xdu2vNFCoA9fdS44ycClWo7KlNmEdCKVsSK5UX8CRL\nRi+HTOO6KSAFxhAfOXVwcaZNst4vTyClGjVeGpV/HxG+5bCBsZOLHE8O2IH0tmjX\n5jpMJJwEvEo9wG4E08QNP09bTRA9VrhdsvTOBnQtgj+ni0EfOJ2T88Y1SmgRJgpz\nggqcHGSwpbNvAB4pbdMeCIdrPoaW3eZX3trf8/hnZOVxwVsXJey0nQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universita' Politecnica delle Marche"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universita' Politecnica delle Marche"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univpm.it/English/Engine/RAServePG.php/P/25001ENG0101/L/0"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univpm.it"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universita' Politecnica delle Marche"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universita' Politecnica delle Marche"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://auth.dariah.eu/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Haase"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:martin.haase@daasi.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:register@dariah.eu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dariah"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://auth.dariah.eu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-07-31T06:57:48Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Gesellschaft f\u00fcr wissenschaftliche Datenverarbeitung mbH"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Gesellschaft f\u00fcr wissenschaftliche Datenverarbeitung mbH"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gwdg.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gwdg.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e112"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e112"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://auth.dariah.eu/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.dariah.eu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.dariah.eu/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://auth.dariah.eu/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://auth.dariah.eu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://dariah.eu/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://dariah.eu/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DARIAH Self Service"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DARIAH Self Service"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Verwaltung von DARIAH-Benutzerdaten Registrierung f\u00fcr DARIAH Services"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "DARIAH user data management and registration for DARIAH Services"
                  }
                ],
                "logo": [
                  {
                    "text": "https://ldap-dariah.esc.rzg.mpg.de/images/DARIAH_flower_icon.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://ldap-dariah.esc.rzg.mpg.de/images/DARIAH_flower.png",
                    "height": "154",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "160"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://de.dariah.eu/ServicePrivacyPolicy"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://de.dariah.eu/ServicePrivacyPolicy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "auth.dariah.eu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGDjCCBPagAwIBAgIHGFSphGu/5zANBgkqhkiG9w0BAQsFADCBrjELMAkGA1UE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\nkeb+gnNfYWJuJWwjSHeUJ3vL"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=auth.dariah.eu,O=Georg-August-Universitaet Goettingen,L=Goettingen,ST=Niedersachsen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.dariah.eu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://auth.dariah.eu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://auth.dariah.eu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://auth.dariah.eu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://auth.dariah.eu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://auth.dariah.eu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "DARIAH Self Service"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "DARIAH Self Service"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Verwaltung von DARIAH-Benutzerdaten Registrierung f\u00fcr DARIAH Services"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "DARIAH user data management and registration for DARIAH Services"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "o",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.gsmd.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.gsmd.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/gsmd.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/gsmd.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gsmd.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Guildhall School of Music & Drama"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gsmd.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://cassiopee.ac-nice.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Patrick Ciurleo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "patrick.ciurleo@ac-nice.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cassiopee.ac-nice.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2016-02-16T12:11:42Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cassiopee.ac-nice.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cassiopee.ac-nice.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cassiopee.ac-nice.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ac-nice.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www2.ac-nice.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Academie de Nice - IDPCassiopee"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Academie de Nice - IDPCassiopee"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/vnd.microsoft.icon;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rectorat de Nice - IDPCassiopee"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rectorat de Nice - IDPCassiopee"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUAeJJ5uWv/WTgBy63zoOeEfL9p6IwDQYJKoZIhvcNAQEL\nBQAwHzEdMBsGA1UEAwwUY2Fzc2lvcGVlLmFjLW5pY2UuZnIwHhcNMTYwMjAyMTI0\nNzA1WhcNMzYwMjAyMTI0NzA1WjAfMR0wGwYDVQQDDBRjYXNzaW9wZWUuYWMtbmlj\nZS5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL1cuXlQ3/OfR+94\n3+UyC1dCcvgUPHRPgRpIVxQf4tWVVaLBJzeqY1D1Hc7MjRChhlBP62eHac0vtqXI\nNj3Q2E2F6VkGssd8vXS3A0hSrEGxkpoD6P4Wd3fzM0Dz7jnSzK7dRByHmceO2zLc\n6zjRlJIYYaMJSIsAqBZJCt8v3mTyWCU5ItGd6Fu87+UbN87cBpFg7zAotNrUrcsm\neetCe8ua0eqyxNQjRPJ0SQEHGOgxx0JR9R5n4ibdTXP3KjEQ0bkixhjG11IFj4YN\nMh+lcZTKTY46cBjqhfC3P/0BqAscQJiMhLnml7HzvnYVYfhTWEx+zr16o6QjGvVh\nwJkrDeUCAwEAAaNvMG0wHQYDVR0OBBYEFLRlBq2upxRDOUwr0SIhTZmOxpjwMEwG\nA1UdEQRFMEOCFGNhc3Npb3BlZS5hYy1uaWNlLmZyhitodHRwczovL2Nhc3Npb3Bl\nZS5hYy1uaWNlLmZyL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQBp\nnf1FS3NW1Svyr9QaOrGHAM9uKu/X9Z5MXKDOT/VsqvKQXr6feaMxVJJn6yt1CNhM\nwuAJJ8a/XYXRhz0E++Au5N6AFaYre3Th2BxR8LZXAhtjI2n8PezO70hVGXbRNd5E\nF3ihURVthgR4HQ4W3R4WSJad344+GwuSZ2GUsd1L+4kIMEdxHaXxakLmKFJywpgy\ndKzDhDlasOFyoThenaqXM2K+x/QSv7GKLXUKyPzAnY6y/22PAYSLdHzxcTNE/DnZ\nuFEGEOIv/gZhm+z5OKxZHxGZQDPQPzJXbOjZFRNWX69QMOLk9PJjc/6l8PBnYJmf\nzpXHRPUEnrUOAStKRZni"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Rectorat de Nice - IDPCassiopee"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www2.ac-nice.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Rectorat de Nice - IDPCassiopee"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.mrc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.mrc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/mrc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/mrc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mrc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Medical Research Council"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mrc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://auth.ncrm.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Serviceline@soton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Serviceline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Peters"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:C.L.Peters@soton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Clayton"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://auth.ncrm.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-04-14T08:12:15Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "National Center for Research Methods"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ncrm.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Southampton"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://auth.ncrm.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.ncrm.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.ncrm.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://auth.ncrm.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://auth.ncrm.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://auth.ncrm.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://auth.ncrm.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3zCCAcegAwIBAgIJAOYQ8STpMV7WMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\n\t\t\t\t\t\tBAMTCHNydjAxMjE4MB4XDTE1MDMwMzE0MTIzMVoXDTI1MDIyODE0MTIzMVowEzER\n\t\t\t\t\t\tMA8GA1UEAxMIc3J2MDEyMTgwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDNYJrzmb5hamunPwEaZ4FezQwG+anG6ugluXtQGyHTeXqz/BKYVhgctLFIU5gI\n\t\t\t\t\t\tEc4fHH8JtP5yEXXgCSES0K9AoK5mv2mz+sz/+1zxFXiZpU0qmYkWegGeJpwBSQbs\n\t\t\t\t\t\tr/nN0rhUpy9c965OPkpC0xTWvduIKQvpn4JzwBf4L64D32r1H8E4XBMAvuKmnJnI\n\t\t\t\t\t\tzYtucFPjPuT338MLWDQ1A0QwyPhtApXsRwxjUvMjSv0qLLM7qlOMH0b2jOwK/hwe\n\t\t\t\t\t\tEMd2eCEiJi+uFcuOiY/aDh7Jx0uFzhbVyQng0GqmZY5kyC8yCYkJ2+/FPf+/SgES\n\t\t\t\t\t\tJCyt92KigkrkDrw2iJmiOTE1AgMBAAGjNjA0MBMGA1UdEQQMMAqCCHNydjAxMjE4\n\t\t\t\t\t\tMB0GA1UdDgQWBBTH1Z4V/CI7bS6osZJeIhihVaDCCjANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAQQ+0hncb9g/mVjS2Yg6IKbfEodhgwvXx7hdIsEulUp8/6UeXaIEH4Ptcujqh\n\t\t\t\t\t\tW69W7RFo9mL2PkQmmQB65KurBNoamLa5tUexD4fx+bhYCKSFBeNQLOcXTfWaQYqN\n\t\t\t\t\t\tQi2Ewdu9YFL769Zpx+gLZPE838HJjrT+k4KQaT0iLQHSuRcmpxGIlFEpMIU/Qkt0\n\t\t\t\t\t\tYV4GO1sWN75ije5n91lJdWvs8WeqIzcg1+CxHvYEbWTQ9m4ZkQ/r6Dbyyf4eocyQ\n\t\t\t\t\t\t13zlOpN5KeAlvEsSB4URyk96P5u9KwSYe1cQVW8WV8LFlOBckBE+4Q1UVGQsxj43\n\t\t\t\t\t\t2lic9hwyPF2jaiIJPCu5UA4iRg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.ncrm.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://auth.ncrm.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://auth.ncrm.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://auth.ncrm.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://auth.ncrm.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://auth.ncrm.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.school-portal.co.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@uniservity.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UniServity Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Zefaj"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rezar.zafaj@uniservity.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rezar"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.school-portal.co.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-03-24T14:11:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UniServity: cLc Service"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uniservity.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UniServity Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.school-portal.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.school-portal.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.school-portal.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.school-portal.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "1",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE8TCCA9mgAwIBAgIJAM7Pg7fr+cKKMA0GCSqGSIb3DQEBBQUAMIGrMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjESMBAGA1UECBMJQmVya3NoaXJlMRAwDgYDVQQHEwdSZWFkaW5nMRsw\n\t\t\t\t\t\tGQYDVQQKExJVbmlTZXJ2aXR5IExpbWl0ZWQxEDAOBgNVBAsTB1N1cHBvcnQxIDAe\n\t\t\t\t\t\tBgNVBAMTF3d3dy5zY2hvb2wtcG9ydGFsLmNvLnVrMSUwIwYJKoZIhvcNAQkBFhZz\n\t\t\t\t\t\tdXBwb3J0QHVuaXNlcnZpdHkuY29tMB4XDTExMDMzMDEzNDgxOVoXDTIxMDMyNzEz\n\t\t\t\t\t\tNDgxOVowgasxCzAJBgNVBAYTAkdCMRIwEAYDVQQIEwlCZXJrc2hpcmUxEDAOBgNV\n\t\t\t\t\t\tBAcTB1JlYWRpbmcxGzAZBgNVBAoTElVuaVNlcnZpdHkgTGltaXRlZDEQMA4GA1UE\n\t\t\t\t\t\tCxMHU3VwcG9ydDEgMB4GA1UEAxMXd3d3LnNjaG9vbC1wb3J0YWwuY28udWsxJTAj\n\t\t\t\t\t\tBgkqhkiG9w0BCQEWFnN1cHBvcnRAdW5pc2Vydml0eS5jb20wggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDUMkvx0wIC8biqHJx0WvOa99Lrow43Zks4NSoZ\n\t\t\t\t\t\tg6SJRJIFuqaxQBt3/PgGj5T9n3psWT3DFJNTgOpIgydqp/+swQ9TTLxcmsX7qCke\n\t\t\t\t\t\t105z5j2OjV0VySclV2as1B63Aaugyc5lDV4ES3HV1bKbdQbJwQDLYBNbRXqsxciG\n\t\t\t\t\t\tFdIuec17GOIlEOnM+gcx3z2yq0TCx6aPfyRm/ookHPJua/vtDJPGCHlGd7k/kHhB\n\t\t\t\t\t\tVVITm1BbtXT6J+dNF7BXkDzH1+CqFHUcIx45MJLu2tyhHOiuYRMs59Ul4N1TIgCa\n\t\t\t\t\t\tFjOqA8gQtSrd7i15CKgCfyQcH/XaEGw8IgaJ4g/cDYqyxQWZAgMBAAGjggEUMIIB\n\t\t\t\t\t\tEDAdBgNVHQ4EFgQUL7mt/WQeUEByCdGzFnowAEsQpIswgeAGA1UdIwSB2DCB1YAU\n\t\t\t\t\t\tL7mt/WQeUEByCdGzFnowAEsQpIuhgbGkga4wgasxCzAJBgNVBAYTAkdCMRIwEAYD\n\t\t\t\t\t\tVQQIEwlCZXJrc2hpcmUxEDAOBgNVBAcTB1JlYWRpbmcxGzAZBgNVBAoTElVuaVNl\n\t\t\t\t\t\tcnZpdHkgTGltaXRlZDEQMA4GA1UECxMHU3VwcG9ydDEgMB4GA1UEAxMXd3d3LnNj\n\t\t\t\t\t\taG9vbC1wb3J0YWwuY28udWsxJTAjBgkqhkiG9w0BCQEWFnN1cHBvcnRAdW5pc2Vy\n\t\t\t\t\t\tdml0eS5jb22CCQDOz4O36/nCijAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUA\n\t\t\t\t\t\tA4IBAQCzblIudcBQ05klAftWWLTSxh8cAv7A+3QFGoQOSO7BJocSX/7sBJ2px1Hx\n\t\t\t\t\t\tvJgTnn2Qm7wy9UQ1dpDrKpgk+3WpB2Fp3OHmqh/fqgvhe9bNYISDy9QIudCLASEJ\n\t\t\t\t\t\tThfaFVFpiSAab6qXbDVIbS+Emmbq4oeLuK2vxh0nf5CormNButRnrt8xmdMzg20b\n\t\t\t\t\t\tftqs96cb5cQsRLB0yM/qAtKCUZKZEUkCRz4oE/xYVDschoYlk6lh2snACWHtXorV\n\t\t\t\t\t\tb6BCgz3fqaNRQJEpSSOpcndNKJ0NtXw0lWcF1BUIXeGYgYr+/f+QsofPu2JjtkTc\n\t\t\t\t\t\t7UAwF7gdFAY1KwlgXEFthStJX1I8"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE8TCCA9mgAwIBAgIJAM7Pg7fr+cKKMA0GCSqGSIb3DQEBBQUAMIGrMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjESMBAGA1UECBMJQmVya3NoaXJlMRAwDgYDVQQHEwdSZWFkaW5nMRsw\n\t\t\t\t\t\tGQYDVQQKExJVbmlTZXJ2aXR5IExpbWl0ZWQxEDAOBgNVBAsTB1N1cHBvcnQxIDAe\n\t\t\t\t\t\tBgNVBAMTF3d3dy5zY2hvb2wtcG9ydGFsLmNvLnVrMSUwIwYJKoZIhvcNAQkBFhZz\n\t\t\t\t\t\tdXBwb3J0QHVuaXNlcnZpdHkuY29tMB4XDTExMDMzMDEzNDgxOVoXDTIxMDMyNzEz\n\t\t\t\t\t\tNDgxOVowgasxCzAJBgNVBAYTAkdCMRIwEAYDVQQIEwlCZXJrc2hpcmUxEDAOBgNV\n\t\t\t\t\t\tBAcTB1JlYWRpbmcxGzAZBgNVBAoTElVuaVNlcnZpdHkgTGltaXRlZDEQMA4GA1UE\n\t\t\t\t\t\tCxMHU3VwcG9ydDEgMB4GA1UEAxMXd3d3LnNjaG9vbC1wb3J0YWwuY28udWsxJTAj\n\t\t\t\t\t\tBgkqhkiG9w0BCQEWFnN1cHBvcnRAdW5pc2Vydml0eS5jb20wggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDUMkvx0wIC8biqHJx0WvOa99Lrow43Zks4NSoZ\n\t\t\t\t\t\tg6SJRJIFuqaxQBt3/PgGj5T9n3psWT3DFJNTgOpIgydqp/+swQ9TTLxcmsX7qCke\n\t\t\t\t\t\t105z5j2OjV0VySclV2as1B63Aaugyc5lDV4ES3HV1bKbdQbJwQDLYBNbRXqsxciG\n\t\t\t\t\t\tFdIuec17GOIlEOnM+gcx3z2yq0TCx6aPfyRm/ookHPJua/vtDJPGCHlGd7k/kHhB\n\t\t\t\t\t\tVVITm1BbtXT6J+dNF7BXkDzH1+CqFHUcIx45MJLu2tyhHOiuYRMs59Ul4N1TIgCa\n\t\t\t\t\t\tFjOqA8gQtSrd7i15CKgCfyQcH/XaEGw8IgaJ4g/cDYqyxQWZAgMBAAGjggEUMIIB\n\t\t\t\t\t\tEDAdBgNVHQ4EFgQUL7mt/WQeUEByCdGzFnowAEsQpIswgeAGA1UdIwSB2DCB1YAU\n\t\t\t\t\t\tL7mt/WQeUEByCdGzFnowAEsQpIuhgbGkga4wgasxCzAJBgNVBAYTAkdCMRIwEAYD\n\t\t\t\t\t\tVQQIEwlCZXJrc2hpcmUxEDAOBgNVBAcTB1JlYWRpbmcxGzAZBgNVBAoTElVuaVNl\n\t\t\t\t\t\tcnZpdHkgTGltaXRlZDEQMA4GA1UECxMHU3VwcG9ydDEgMB4GA1UEAxMXd3d3LnNj\n\t\t\t\t\t\taG9vbC1wb3J0YWwuY28udWsxJTAjBgkqhkiG9w0BCQEWFnN1cHBvcnRAdW5pc2Vy\n\t\t\t\t\t\tdml0eS5jb22CCQDOz4O36/nCijAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUA\n\t\t\t\t\t\tA4IBAQCzblIudcBQ05klAftWWLTSxh8cAv7A+3QFGoQOSO7BJocSX/7sBJ2px1Hx\n\t\t\t\t\t\tvJgTnn2Qm7wy9UQ1dpDrKpgk+3WpB2Fp3OHmqh/fqgvhe9bNYISDy9QIudCLASEJ\n\t\t\t\t\t\tThfaFVFpiSAab6qXbDVIbS+Emmbq4oeLuK2vxh0nf5CormNButRnrt8xmdMzg20b\n\t\t\t\t\t\tftqs96cb5cQsRLB0yM/qAtKCUZKZEUkCRz4oE/xYVDschoYlk6lh2snACWHtXorV\n\t\t\t\t\t\tb6BCgz3fqaNRQJEpSSOpcndNKJ0NtXw0lWcF1BUIXeGYgYr+/f+QsofPu2JjtkTc\n\t\t\t\t\t\t7UAwF7gdFAY1KwlgXEFthStJX1I8"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.school-portal.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.school-portal.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://bournemouth.co-tutor.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chung"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ray.chung@lboro.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ray"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Newman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:p.m.newman@lboro.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bournemouth.co-tutor.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-02-12T10:34:14Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Co-Tutor at Bournemouth"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.co-tutor.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Loughborough University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bournemouth.co-tutor.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://bournemouth.co-tutor.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bournemouth.co-tutor.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bournemouth.co-tutor.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bournemouth.co-tutor.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://bournemouth.co-tutor.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAOiYjTsFNgAsMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\n\t\t\t\t\t\tBAMTD2lwLTE3Mi0zMS00Ny04NzAeFw0xNjAyMDQxODI2NTZaFw0yNjAyMDExODI2\n\t\t\t\t\t\tNTZaMBoxGDAWBgNVBAMTD2lwLTE3Mi0zMS00Ny04NzCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBAJ0Kt7P6RpsSFzbjdq9cuXPBpVaAxbDQyLxX8xxZQk7W\n\t\t\t\t\t\tz+HYmRCW2FfmAWRGtLe6TxXY2eSDPnaCRSXnM6L5VJ79htgf224Minz44V7pkH4b\n\t\t\t\t\t\tfB3V2+SZo6GdFsLPvArVQD3ykyzNZ6snrk6h+wzN1AD2mgmB47emRS5nrb/nCFQi\n\t\t\t\t\t\tAcwTKc4ko1TUx7sg3njifh9ApsLK72MQgNtG/R0CxUwV82F+nHph0Ghz0Fb1YoCL\n\t\t\t\t\t\tvYVgTbK0pmvovpkzHmwNvBwHr4ZCTObGI4rrwo7YWqbJsoHzDb1CtkFEaOsXIcH9\n\t\t\t\t\t\t3ed+qWGW4Ujpio/e1YLYZHkQV72Wc99Mb/f+lXKinykCAwEAAaM9MDswGgYDVR0R\n\t\t\t\t\t\tBBMwEYIPaXAtMTcyLTMxLTQ3LTg3MB0GA1UdDgQWBBSCl5autvAPKmaDFvcx2H84\n\t\t\t\t\t\tVZJmhDANBgkqhkiG9w0BAQUFAAOCAQEAAm9hrwpV+DbmkZ+Q0pp8IxAQ3kzNP9NJ\n\t\t\t\t\t\tD09nyP4UeyRNIJLrN2TWnq+eTMhu45DGs4Ft/Exm7HWbJBlKqHt7tpEIgI+YMG8J\n\t\t\t\t\t\t4Cnz/S5K9MBFLQCi6zBA0ysept1RX39Gvk5pqtHh+GaOIYxaluQnvi62kblw93g2\n\t\t\t\t\t\thWJFRyUJ1KE/YhmBLOwRV49hxwMIDsy2nxRR6RG4s2Xkw8S5veBYk2j4wcboQOw1\n\t\t\t\t\t\tC/ljsLpP7qjsvG7N7hcxcxL6p1cEHxZNOp+e1jwB8RztxoMrX0NDDAdal0gJ5tD9\n\t\t\t\t\t\tYe+vQFT2JsBRulniJ54ZuPutnGhHrOtsewshVpHRdPa+qdVhxqrsgw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bournemouth.co-tutor.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://bournemouth.co-tutor.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bournemouth.co-tutor.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://bournemouth.co-tutor.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://bournemouth.co-tutor.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://bournemouth.co-tutor.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.testb.antagning.se/aws-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al2"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://www.swamid.se/assurance-requirement",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.testb.antagning.se/aws-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.testb.antagning.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.testb.antagning.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.testb.antagning.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.testb.antagning.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.testb.antagning.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.testb.antagning.se/aws-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.testb.antagning.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJAKCQNeL/EBzjMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFnd3dy50ZXN0Yi5hbnRhZ25pbmcuc2UwHhcNMTEwODI1MTMxNzU2WhcNMjEw\nODIyMTMxNzU2WjAhMR8wHQYDVQQDExZ3d3cudGVzdGIuYW50YWduaW5nLnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzH0zgKGfxWBRVrjK/Vi2yWU3\nKSbmZfwjRfznULF3EUooB2ylh3pzm4uDHlRlC7kMet2NaOeTfUFrU7Ea1WiTlJik\n+mW+xXhL3IVua3UNuPd3NvYcAi6P5WCoqfzmDGq/EsZPcDCF6N4TeK2d/1ZsIi4l\nlVGnwrkeHBudCt5jFqvz2kUIRuRhKr+8/KNFCJyHthL+aPilI+cTZbYSYGs2uxA6\ngycuW5sHqhhWX+po32bBXVkmIQiNf3pC+/+zN/se5bHisqZvNk7WMGpplKgxDY+3\nrAZ4m1t/oqNAC0qR8cdp1rU6QYUNwuthdrrz6+0/dkiZD0v+rHnLHD0L83mgIwID\nAQABo2swaTBIBgNVHREEQTA/ghZ3d3cudGVzdGIuYW50YWduaW5nLnNlhiVodHRw\nczovL3d3dy50ZXN0Yi5hbnRhZ25pbmcuc2UvYXdzLXNwMB0GA1UdDgQWBBTIQhxb\nkYXnJHxpO2M1oJS4lsDquTANBgkqhkiG9w0BAQUFAAOCAQEAThmqiMzJ/PbSc0PH\nwtxuLxgOs7/an5DFVs6Nb+sFzih78APz2gF9g2jUQp/A0SkvWeyW8Qhy2OmVTDZx\ntX3ZEUqIDBa5QoDpdQdR7Jjcqk0wbhJTYYFngd5Q9pNXHCk6yBsxFNHDo4lTJkTP\nsD2aW1Zb/f7QkiCLAtnhJcVTV2r5m98AAxFL153+OIy3C8m8zMPQ/w4JEwjrHsC8\nKXY4ClB5AiNom7BHLFHxkvrQaBh2Xuw1QR+N+RiV63O4oTDc1+PfV9U6TIZuGtmW\nU0kuBfzXbhSZIt95QCN4uKIl0MATKArcZT/+3GWXAX1NC2sCeYBqMu2yakST2OcT\nUvKqjQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.testb.antagning.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.testb.antagning.se/aws-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.testb.antagning.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJAKCQNeL/EBzjMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFnd3dy50ZXN0Yi5hbnRhZ25pbmcuc2UwHhcNMTEwODI1MTMxNzU2WhcNMjEw\nODIyMTMxNzU2WjAhMR8wHQYDVQQDExZ3d3cudGVzdGIuYW50YWduaW5nLnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzH0zgKGfxWBRVrjK/Vi2yWU3\nKSbmZfwjRfznULF3EUooB2ylh3pzm4uDHlRlC7kMet2NaOeTfUFrU7Ea1WiTlJik\n+mW+xXhL3IVua3UNuPd3NvYcAi6P5WCoqfzmDGq/EsZPcDCF6N4TeK2d/1ZsIi4l\nlVGnwrkeHBudCt5jFqvz2kUIRuRhKr+8/KNFCJyHthL+aPilI+cTZbYSYGs2uxA6\ngycuW5sHqhhWX+po32bBXVkmIQiNf3pC+/+zN/se5bHisqZvNk7WMGpplKgxDY+3\nrAZ4m1t/oqNAC0qR8cdp1rU6QYUNwuthdrrz6+0/dkiZD0v+rHnLHD0L83mgIwID\nAQABo2swaTBIBgNVHREEQTA/ghZ3d3cudGVzdGIuYW50YWduaW5nLnNlhiVodHRw\nczovL3d3dy50ZXN0Yi5hbnRhZ25pbmcuc2UvYXdzLXNwMB0GA1UdDgQWBBTIQhxb\nkYXnJHxpO2M1oJS4lsDquTANBgkqhkiG9w0BAQUFAAOCAQEAThmqiMzJ/PbSc0PH\nwtxuLxgOs7/an5DFVs6Nb+sFzih78APz2gF9g2jUQp/A0SkvWeyW8Qhy2OmVTDZx\ntX3ZEUqIDBa5QoDpdQdR7Jjcqk0wbhJTYYFngd5Q9pNXHCk6yBsxFNHDo4lTJkTP\nsD2aW1Zb/f7QkiCLAtnhJcVTV2r5m98AAxFL153+OIy3C8m8zMPQ/w4JEwjrHsC8\nKXY4ClB5AiNom7BHLFHxkvrQaBh2Xuw1QR+N+RiV63O4oTDc1+PfV9U6TIZuGtmW\nU0kuBfzXbhSZIt95QCN4uKIl0MATKArcZT/+3GWXAX1NC2sCeYBqMu2yakST2OcT\nUvKqjQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.testb.antagning.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.testb.antagning.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.testb.antagning.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.testb.antagning.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.testb.antagning.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.testb.antagning.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.testb.antagning.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.testb.antagning.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.testb.antagning.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.testb.antagning.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.testb.antagning.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.uconn.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "marc.jones@uconn.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marc Jones"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "marc.jones@uconn.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marc Jones"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpcenter@uconn.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Help Center"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "security@uconn.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Information Security"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://shibboleth.uconn.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.uconn.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.uconn.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAM0bjDh08PO/4qtkatg7X4k6+BN1MA0GCSqGSIb3DQEB\nBQUAMB8xHTAbBgNVBAMTFHNoaWJib2xldGgudWNvbm4uZWR1MB4XDTExMTIwNzE2\nMTIzMFoXDTMxMTIwNzE2MTIzMFowHzEdMBsGA1UEAxMUc2hpYmJvbGV0aC51Y29u\nbi5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDAqGjMJ07oRFxk\nesd2xSZmYBtBth7KiGzou8rHdMQ+heGKU3BwIpWtirCNONmClq6A0tFrYfhyF+8W\nq8XLtVjrn3QXmbie09QYrvqj46kr8CiQ0aMGuIB3l8/pDMG8WVwOAUgSY3ffMSrL\nO/j1yg6IgiIT3Gf0MNgyj5G7qHKGWfFL4uw1BaRX08BOfmgFBDBdrSPKpLNoKw9z\nbtjt/ytPxKMl4+cQ3jBxKQAK5unOT5Cmhc0tLmUBMFs0cWEkZPwX3HkuVoYVx8Vu\n0Zeb0keEByRO3j055oHTHtvdu6P03ThC8N2mOGOumSPn4v6enHEy5bZmE+VflfZi\nLKlv32tDAgMBAAGjbzBtMEwGA1UdEQRFMEOCFHNoaWJib2xldGgudWNvbm4uZWR1\nhitodHRwczovL3NoaWJib2xldGgudWNvbm4uZWR1L2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBSkRSc23CRBgycmRtZEAQnbW6I2fjANBgkqhkiG9w0BAQUFAAOCAQEA\nRIWT9lvMkliN3McoYMKi44BBnd6oxGbJtioZdDr2xZZ2GQfdijtR5YcflA4BwF27\nGetQ2pzGIX5O28jgjxYv6GjNY389+CxucT9pHRvO3tEkdY8GAJOFi06nDGtGcsS+\ntxkM8CItNzbEG962C3c85A5GwX/y4OtmiAe4EkScPAYYaKiNnuf3KvAlOw0ZiqZ3\nSPGQ7Db04FPcLLncNwkIeT0h235ZPOo6wM0Utwa6e+n2hhV4AVKj/r4U/F6CAPuC\n+7lvO1Xvsty0e7ruYk84+USBla8u5Iq8tJokQk8dboLLJQViygVpiVdS6oCwZDG7\nK1bUJ0l1vnaNfRNJ/rLFgg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uconn.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.uconn.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.uconn.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.uconn.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.uconn.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.uconn.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.uconn.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uconn.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Connecticut"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAM0bjDh08PO/4qtkatg7X4k6+BN1MA0GCSqGSIb3DQEB\nBQUAMB8xHTAbBgNVBAMTFHNoaWJib2xldGgudWNvbm4uZWR1MB4XDTExMTIwNzE2\nMTIzMFoXDTMxMTIwNzE2MTIzMFowHzEdMBsGA1UEAxMUc2hpYmJvbGV0aC51Y29u\nbi5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDAqGjMJ07oRFxk\nesd2xSZmYBtBth7KiGzou8rHdMQ+heGKU3BwIpWtirCNONmClq6A0tFrYfhyF+8W\nq8XLtVjrn3QXmbie09QYrvqj46kr8CiQ0aMGuIB3l8/pDMG8WVwOAUgSY3ffMSrL\nO/j1yg6IgiIT3Gf0MNgyj5G7qHKGWfFL4uw1BaRX08BOfmgFBDBdrSPKpLNoKw9z\nbtjt/ytPxKMl4+cQ3jBxKQAK5unOT5Cmhc0tLmUBMFs0cWEkZPwX3HkuVoYVx8Vu\n0Zeb0keEByRO3j055oHTHtvdu6P03ThC8N2mOGOumSPn4v6enHEy5bZmE+VflfZi\nLKlv32tDAgMBAAGjbzBtMEwGA1UdEQRFMEOCFHNoaWJib2xldGgudWNvbm4uZWR1\nhitodHRwczovL3NoaWJib2xldGgudWNvbm4uZWR1L2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBSkRSc23CRBgycmRtZEAQnbW6I2fjANBgkqhkiG9w0BAQUFAAOCAQEA\nRIWT9lvMkliN3McoYMKi44BBnd6oxGbJtioZdDr2xZZ2GQfdijtR5YcflA4BwF27\nGetQ2pzGIX5O28jgjxYv6GjNY389+CxucT9pHRvO3tEkdY8GAJOFi06nDGtGcsS+\ntxkM8CItNzbEG962C3c85A5GwX/y4OtmiAe4EkScPAYYaKiNnuf3KvAlOw0ZiqZ3\nSPGQ7Db04FPcLLncNwkIeT0h235ZPOo6wM0Utwa6e+n2hhV4AVKj/r4U/F6CAPuC\n+7lvO1Xvsty0e7ruYk84+USBla8u5Iq8tJokQk8dboLLJQViygVpiVdS6oCwZDG7\nK1bUJ0l1vnaNfRNJ/rLFgg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Connecticut"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uconn.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Connecticut"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.liu.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "LiU-IT SAML admins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:saml-admins@it.liu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Link\u00f6ping University"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "LiU-IT SAML admins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:saml-admins@it.liu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Link\u00f6ping University"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 13 282828"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "LiU-IT Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@liu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Link\u00f6ping University"
          }
        }
      ],
      "entity_id": "https://login.liu.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUUGevf/6+3wexHl4UyWmMfjha+8owDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMbG9naW4ubGl1LnNlMB4XDTA5MDYyNTA2Mjg1NloXDTI5\nMDYyNTA2Mjg1NlowFzEVMBMGA1UEAxMMbG9naW4ubGl1LnNlMIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkdGaEeZYE4lLbCTP3I/7SWH2dI4RfbVp0bPH\nX3TSDGUAJMf8lVwignl37pypkj1it/Ea1oOs1QAUUJF2s7eDKbbsQZ6IMEZHUCG9\n2yBt6cAA7HH8XyhyQodkTZd6JhY/HJY1oAiKXar7JSnxnVdg6365Z4rP+W4UHcHM\nePgj6SqR0eW6qXmEIx9a/cyJ+s/R5cUiTrNDL9c0FH/watGYgesLxCxSSgijW7L1\nCobl5Y5+Wr8i3sPPNVVtHXsp1aRI4G4YWW2qsoPF94s9f+LguJ+vHMT2URqplOZ3\ng41V7NFMqSw8f7n32BKl7ekAVBfhAwMuiKSENCuJ1vWHsXS7wwIDAQABo18wXTA8\nBgNVHREENTAzggxsb2dpbi5saXUuc2WGI2h0dHBzOi8vbG9naW4ubGl1LnNlL2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBSouPd/n3U2de/t4ArJMSZcZGlsrjANBgkq\nhkiG9w0BAQUFAAOCAQEAdupL+cmtm9wOczmRze5JGpSkrEnJLWOABVH71QGhRPd3\nbEA93XLjwiO9NPuFyLrb03IUrcgdlgkxnCoq2dla2IQBI6ky+VSuc4lCsdanI+XB\nt2SymRPiqJ60K04Rm4TYOZHsDVHPO3dE3f4mjbhx/irlPmDIM+eB88SbT1nPRQfv\nG2bsafC6oxZjtT5CDJP30lUpieKkmIneVjTmYHBLQmWvl0G5o5j5OLtVj1xhfz9r\nzB2373DVTdsTnFIbFLDF8bGXt1jhxNOT5cxviUYKI+L1VLwKRjWlFd2tUMMKKz/I\ndE1S/LL5o/3BCZXOh9Fuvm6ND4e+jSkCizMQNgm4iw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "liu.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.liu.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.liu.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.liu.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.liu.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.liu.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.liu.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.liu.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.liu.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "liu.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.liu.se/?l=sv"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.liu.se/?l=en"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identitsutgivare f\u00f6r anst\u00e4llda och studenter vid Link\u00f6pings universitet."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for employees and students at Link\u00f6ping University."
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.liu.se/idp/images/logo-350x68-sv.png",
                    "height": "68",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  },
                  {
                    "text": "https://login.liu.se/idp/images/logo-350x68-sv.png",
                    "lang": "sv",
                    "height": "68",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  },
                  {
                    "text": "https://login.liu.se/idp/images/logo-350x68-en.png",
                    "lang": "en",
                    "height": "68",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Link\u00f6pings Universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Link\u00f6ping University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "liu.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:58.397282,15.578624"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.236.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:6b0:17::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUUGevf/6+3wexHl4UyWmMfjha+8owDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMbG9naW4ubGl1LnNlMB4XDTA5MDYyNTA2Mjg1NloXDTI5\nMDYyNTA2Mjg1NlowFzEVMBMGA1UEAxMMbG9naW4ubGl1LnNlMIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkdGaEeZYE4lLbCTP3I/7SWH2dI4RfbVp0bPH\nX3TSDGUAJMf8lVwignl37pypkj1it/Ea1oOs1QAUUJF2s7eDKbbsQZ6IMEZHUCG9\n2yBt6cAA7HH8XyhyQodkTZd6JhY/HJY1oAiKXar7JSnxnVdg6365Z4rP+W4UHcHM\nePgj6SqR0eW6qXmEIx9a/cyJ+s/R5cUiTrNDL9c0FH/watGYgesLxCxSSgijW7L1\nCobl5Y5+Wr8i3sPPNVVtHXsp1aRI4G4YWW2qsoPF94s9f+LguJ+vHMT2URqplOZ3\ng41V7NFMqSw8f7n32BKl7ekAVBfhAwMuiKSENCuJ1vWHsXS7wwIDAQABo18wXTA8\nBgNVHREENTAzggxsb2dpbi5saXUuc2WGI2h0dHBzOi8vbG9naW4ubGl1LnNlL2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBSouPd/n3U2de/t4ArJMSZcZGlsrjANBgkq\nhkiG9w0BAQUFAAOCAQEAdupL+cmtm9wOczmRze5JGpSkrEnJLWOABVH71QGhRPd3\nbEA93XLjwiO9NPuFyLrb03IUrcgdlgkxnCoq2dla2IQBI6ky+VSuc4lCsdanI+XB\nt2SymRPiqJ60K04Rm4TYOZHsDVHPO3dE3f4mjbhx/irlPmDIM+eB88SbT1nPRQfv\nG2bsafC6oxZjtT5CDJP30lUpieKkmIneVjTmYHBLQmWvl0G5o5j5OLtVj1xhfz9r\nzB2373DVTdsTnFIbFLDF8bGXt1jhxNOT5cxviUYKI+L1VLwKRjWlFd2tUMMKKz/I\ndE1S/LL5o/3BCZXOh9Fuvm6ND4e+jSkCizMQNgm4iw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Link\u00f6pings Universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Link\u00f6ping University"
          }
        ],
        "organization_url": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.liu.se?l=sv"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.liu.se?l=en"
          }
        ],
        "organization_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LiU"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LiU"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://cwpub2.imodules.com/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jwicoff@imodules.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Josh Wicoff"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://cwpub2.imodules.com/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Imodules Software, Inc."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.imodules.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Imodules Software, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cwpubsecure.imodules.com/controls/login/AssertionConsumerService.aspx?sid=13410&gid=2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBDCCAeygAwIBAgIQzEDukSw9R5BHpxVmr1UwFjANBgkqhkiG9w0BAQQFADAX\nMRUwEwYDVQQDEwxpbW9kdWxlcy5jb20wHhcNMTQwNjEwMjExODU3WhcNMzQwNjEw\nMjExODU2WjAXMRUwEwYDVQQDEwxpbW9kdWxlcy5jb20wggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQDC5hlDfEQ7RoqQgtcZjOxN2FdUOMu4MI8hIeydiFDy\n1fT1t1jJHmFF5V4JDGpITIapK2caenljBcGl7CGC+Z6EXID8i0lxc7lLWOOrYkJb\n8PeuVOpbxTZfOxfkC3jf4IfLZPtBfDvWjYtVUPwDCpwLLE/GQzz6HySoMIcWAkQ9\nbPoAIITTRnDpo1f4J6nO81DKx0XjBVIbz6aTsF60pcXQzLJ69KGI5Jkh3DjmNbeq\nEXH6ENtq823q4JGXRrKvCPrTlt+79EI1p+ECSaRUx006raAYHktUTT2KY1oUlsuk\nqVA+LMmhX/+jF1fgOehHEurOiKQp2aGmeV4PnJ8pXKM9AgMBAAGjTDBKMEgGA1Ud\nAQRBMD+AEG94Y5yfOU4e+OzhpzVt1UyhGTAXMRUwEwYDVQQDEwxpbW9kdWxlcy5j\nb22CEMxA7pEsPUeQR6cVZq9VMBYwDQYJKoZIhvcNAQEEBQADggEBAFDDvIjK8eJO\nYjDqnY9DfzUEN6Vp80w3ZLhT/K49/McNbbGkt0bgg45MeJ78IxLdclTIhOEeHACN\nF71+XLb9PjRfISiB37V157w0nKF5MsMYU1dathFrVOzCIxvhERgoD4lMNtwZiKKH\nJ/xYeczpnHz5iFpoiCvsvPTP5sZqAKvf5ovpermVcLyqEPJJHvLHe+TbwdwTuGMS\npF2w1WQGpSgdbcxWWwmwpbeiF5ADI6UTS5txOfG0p8L2RTxgRJ6Nb7lNrelIEcup\n6nWHUla/60ENe+AN9qsqYh1vnknLi7kSMHwvtyzFQDHnXhwhLa9mkpsZVkeLEGsR\nMJlfQnuceWY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Current Work Test"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://idp.4cd.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ftahan@4cd.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Fred Tahan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jsmith@4cd.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeanie Smith"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.4cd.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.4cd.edu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.4cd.edu:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.4cd.edu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.4cd.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.4cd.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.4cd.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.4cd.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "4cd.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Contra Costa Community College District"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3jCCAcagAwIBAgIQY/dQsE83PaZJoxxonVIzyzANBgkqhkiG9w0BAQUFADAY\nMRYwFAYDVQQDEw1NRUcuYWMucG9ydGFsMB4XDTE1MDczMDE3MzU0NVoXDTE2MDcz\nMDAwMDAwMFowGDEWMBQGA1UEAxMNTUVHLmFjLnBvcnRhbDCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAJuqbkxV/IezNIvfuL/JYtWjVc+A4GYsfHV0t77/\nKP7RzXD8uUfax9NaNo6Vvh35fD8FjBRBybOnjsA9mBcHGC3uhQeveX5qgrzqvZfa\ncBlQ0nnXDzAEAdM20mFRATpqZMqaR83ZsSdul2Mvf29KJdktPBNfvBiuXfGNP0Bb\nhQWsc4XOVjSvtYd3vKUmJUtor8UttL4V4YJLXy7jcKPBYHEIjiaoDSv3A14waZmO\niO9kK6520bEnJfRZ1s0QzIXfJRY/YWAFxSmnWLu99tunzNY7JiK3GXj9LbY643Ou\nIafLtJP6+/ZjYJG8SX+nThYUmvXbsgMFzZ/3fJELnk1xXZECAwEAAaMkMCIwCwYD\nVR0PBAQDAgQwMBMGA1UdJQQMMAoGCCsGAQUFBwMBMA0GCSqGSIb3DQEBBQUAA4IB\nAQBEysihZ5OnJKTHDaV3h/HEcAxY0ALCrVwk4Buv1SHdeZowCgA0Dqey1j24tANH\nP3CEd4HX6C7wBBMtrMBtZUDH7yZpjfh0YAXZD289l7Frm6P2/4eIXEzdYUvN9X+M\n5vBo2RSgfV0Z8CvdfahVe6zj3B2LURzZ6/Aj5CpAIQnv9qyQ5LJ0eDPIkcHvq+xy\n6WEb/JeSfcXjfbEvt8A7XhsaCYH+EDxLNqazR0y+/CGdzldZzT484KH3ighNM7It\nVGhn/FMx6CwPgaVvSUFhZSF1S/Zy5LGo5L+NwSskBZbsggvcFK81A8OQyRpqkfJ0\nFdNlLCLTu6n6ORJmir+X2PzI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUbFc/9Zd90s2OyW+CDf6IsoyodFIwDQYJKoZIhvcNAQEL\nBQAwFjEUMBIGA1UEAwwLaWRwLjRjZC5lZHUwHhcNMTUwNzE1MjIwNTM4WhcNMzUw\nNzE1MjIwNTM4WjAWMRQwEgYDVQQDDAtpZHAuNGNkLmVkdTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAJbSYoWAUTBA7xoIOTmGtfr9OmJixa3N/euDzOay\nZtlcf7S48qoo7uBW0H4QHkIIBBkK8YstmsgIqRtA03QL+62trDygN9oWqdbtT5CE\nq7JBI0qxcHb2AXW2LMAW1rjgSeyjRMxUdrbii8aNpJ/PQyHSwqo6l62Xdg9kzDRH\ns7NPchMrplv1NIILukLR87Lu1heirZtpBEzJcc/bj8T98A7Pt/BJURsJsixO3pkq\nq8DmCWggrajOFsYuUsNuwK7AObp3SEv/RvDHwoVLbtO9hCqMzVcS5DwpmHT/TRNd\nSu03LWv/U2tWAY7r2HVeVJmB1QoZCXDtIvCtLa8KkFKCP9kCAwEAAaNdMFswHQYD\nVR0OBBYEFPmijRIb0Yjq1QnJUWQQee6zJVxFMDoGA1UdEQQzMDGCC2lkcC40Y2Qu\nZWR1hiJodHRwczovL2lkcC40Y2QuZWR1L2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3\nDQEBCwUAA4IBAQCJjWVXlEaCfNiUUngeOgeU/Afe6juBV7kN0C9+SqxlmK/hgj9l\n32yoALnA/jec86VVif2sQUy7IJBwsl4+rqx4x04mfZxb0y719YDj5kIgP8ZxOT2s\nyknrDzqbGwe21sAkeirtLANYDjCTgWUB3BpKdqz9iBHI8A0rY1g4glKcWxTYVnej\nmDPEfrVywFVFmXyEtwyEYJSYXsfWLrFwAOpeiO1mq9T1Vk2Mr3P/F5+2E4+J06wg\n+iP2GsQmy1PGMfVhuKKGDMDx2YhCzbiGaDjF2782KYJ5xHr8jRIr3qzTRr/SIMsd\n5JecuW9DWVNJsuwR/jW02/KrcCa429lfK5mp"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Contra Costa Community College District"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.4cd.edu/default.aspx"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Contra Costa Community College District"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp-utv.ldc.lu.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://sp-utv.ldc.lu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp-utv.ldc.lu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp-utv.ldc.lu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp-utv.ldc.lu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp-utv.ldc.lu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp-utv.ldc.lu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sp-utv.ldc.lu.se/Shibboleth.sso/Login-lu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp-utv.ldc.lu.se/Shibboleth.sso/Login-swamid",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://sp-utv.ldc.lu.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://sp-utv.ldc.lu.se"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SP anv\u00e4nd under utveckling av verktygsst\u00f6d riktade mot utbildning och forskning vid Lunds universitet."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SP used for development of applications for education and reasearch at Lund university."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Utvecklings-SP LDC"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Development SP LDC"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://sp-utv.ldc.lu.se/shibboleth"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "sp-utv.ldc.lu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIJAN65YVXdSJ7XMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEHNwLXV0di5sZGMubHUuc2UwHhcNMTQxMDA3MTAxNjMzWhcNMTcxMDA2MTAx\nNjMzWjAbMRkwFwYDVQQDExBzcC11dHYubGRjLmx1LnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAsOutKnHh2PBCsGI2cUYfbpi6/fZB3MqHM7E3PmEY\nbqr4yKvORvhTDELByzk8UWekuVFOAvAMRRxFXt8D8CcZfTdtZJ76fOrnWA/1fyLS\nCp0qOqXS6t8knKKVxaeU68XCGmyYtii8kSWg/a6wcjb5oZnOM3hlSPbW2UqFS3Gz\nIxM+elaAsJmFBmbmZAFLCMv16luWMSb+PeopYxKgzAzcPlPJUpKa1O5Fj5lpXBFn\ndERSIYpglDDroP19KyjX4Yx6Qt1W0Lk/SHLRSL9yhTBj/2FmP8Oh0Cb6nuvEhX8/\n+EqAl5+1mDZqub2+zK4yhvXoSLbxj5SqWb2rKhOT4aIwBwIDAQABo2MwYTBABgNV\nHREEOTA3ghBzcC11dHYubGRjLmx1LnNlhiNodHRwczovL3NwLXV0di5sZGMubHUu\nc2Uvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUMDubZakw5ve46w+NRnXk/wtb9f8wDQYJ\nKoZIhvcNAQEFBQADggEBADNXPStinQ6fhQmLYBCJLqSAiu9LiQ/72KCTtQ/gGWhl\ncpVD6wxib2U3uVXi27WVH7RCnFAOBilUCV0sZ3PlNfzlseeS2v4nIul05Y7onV18\nE1tCPpfcgLYNkDXPpisiLsfRZoemSLo8asgYPZazWOT1RQcBaDUmoKRu3JaJm+ok\nvbvRVfuv5ILsWaTB3aM+bkPCqNFU+9jwnf8xHqz7OozAvAaktqojTn6z1sdcNwVU\nRalEs/MrU/fHzsNJ9rWhWGMDHgwJUD0vluORdGrw4+D+m9WerEBC/1LsEiluhkKE\nN+oxvR5W/Ta3bfsVAYaIRqIam+/ysez57D1OXJDaLV0="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=sp-utv.ldc.lu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp-utv.ldc.lu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp-utv.ldc.lu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp-utv.ldc.lu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp-utv.ldc.lu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp-utv.ldc.lu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp-utv.ldc.lu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp-utv.ldc.lu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp-utv.ldc.lu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp-utv.ldc.lu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://baran-is0.educampus.ie/adfs/services/trust",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NOC"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:noc-middleware@heanet.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "HEAnet"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://baran-is0.educampus.ie/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2016-01-27T13:23:57Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://baran-is0.educampus.ie/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://baran-is0.educampus.ie/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://baran-is0.educampus.ie/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "educampus.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.educampus.ie"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Educampus Services Ltd"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Staff of Edcampus Services Ltd."
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "223",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "968"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.educampus.ie/privacy"
                  }
                ]
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "educampus.ie"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6DCCAdCgAwIBAgIQfLkrExunx71JJG9k7UWICDANBgkqhkiG9w0BAQsFADAw\nMS4wLAYDVQQDEyVBREZTIFNpZ25pbmcgLSBiYXJhbi1pczAuZWR1Y2FtcHVzLmll\nMB4XDTE2MDEyNTExMTczOVoXDTE3MDEyNDExMTczOVowMDEuMCwGA1UEAxMlQURG\nUyBTaWduaW5nIC0gYmFyYW4taXMwLmVkdWNhbXB1cy5pZTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAJqSMshN9B+p//tO+khi7fUF+Pp43f8oTL5jr1eG\n9LNY1b1NLKbLmPF8os0wzs2x0KuELokSdPRAY6UWbsW45LsX1u1V7KwprzNSaiEL\n4O/7cYOsN5p2rSLWhFZMygClPJcYaCFCuD4xb/4I1prCB0aXgfg2sMv5TWot1iRY\nbJvQXjbLjnUZEusxQcHd6Iw2CzjC1zessRNPXRTMs9oFRdkFVQApTmOgxclPabE3\nz5B7YuR+COq5kGyzxCQpzdc8JKBK+SMB7nSqz8rlHsNSOm+Kp5rzOxKvBbFFDDBu\ngLH/hdw8AKf7fJupGXq9ZdxEKlFKsm7oXtLzRIQoLs0o2PUCAwEAATANBgkqhkiG\n9w0BAQsFAAOCAQEAUs8jgnbOjl20OBxE7bWb2uJLe6bPR8nUJmiwgu4u6ufHi0oP\nvajjIol/JekifoY3cQsUP9yee6ZIohxCmgPQAb/qRPna6QKVKVqtQCqw+zH8UiCF\nStH5mQU2/XrPXX7nNMx4W9ARVOA7SyLlF+QltbQTgx3QnpjUlL1o9f9YEyoXKFI9\nmMfiP9hRIKA7jSNg8FuO8RO9jcJ/aR3g0DVXh0xTX1HsIz+h8LXzuVqWWirpEMZQ\nHqKbiihLuzkSlaouL8VaSfU3tbWdFQJ++sFRXjm/zH7QUj8IejoqPshbmDi6uy8Q\n2zfsdnP8zq18XmlTterKy+KbHl2/8AEH0wtdRg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIQGaxn4WoVJ4RGY7ynHoDt+jANBgkqhkiG9w0BAQsFADAz\nMTEwLwYDVQQDEyhBREZTIEVuY3J5cHRpb24gLSBiYXJhbi1pczAuZWR1Y2FtcHVz\nLmllMB4XDTE2MDEyNTExMTc0MFoXDTE3MDEyNDExMTc0MFowMzExMC8GA1UEAxMo\nQURGUyBFbmNyeXB0aW9uIC0gYmFyYW4taXMwLmVkdWNhbXB1cy5pZTCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKozsCxS4zD0GpzN4B8HzEQV6kkrt8IN\nw+vdMmjJ8wSm01R2LIOkEbRcGSWEpOrl3Lwr7WTY3FiSEYhAjobfck6sdf4GN+N3\n2hS/G7q1ZoebGP9ybLCl9/CL8dQbh605gDSmed/7NQc0RhzcI/72kC48Eb2oiena\nWjGOj2GkHsEd3h70aX/bP6fSHZkZtOncgJWZGdhXriYIXy+GzerSq9AUEGdq6CGG\nKp4lXhwn4BVk2ara2KPG8YO5Vw2pKBW/AyrVYgNDY0VFSwE0vu67SyLUjNX2cyxc\nBCCwxHHrNC91BA5kvpi/RyxypzmotERxWcLQ5+WeVjfehs6Hrz4cIE0CAwEAATAN\nBgkqhkiG9w0BAQsFAAOCAQEAKHpPDd4WdpYgD4EMYi/qE0ey27pj0cJFZD0EFBi1\nfIYzXZUc84BZort4yrBsqDnjd/HxeWcDNAm3CLStyFUK1ZM4on88zlW6UrXNnw4d\nPDledccnW0loFec1YuzSxreinl/+zQG5uUPTaU7V3do+hGoZmxQHq3Z5xN6qbdsc\n3/ktlL/Qobxn8uGtXNXwACMplQHXzMx9/IKBAG4MGhtcfe/+aARm7NnP2TO6Pv+9\naw8ObgdtzJVmfGsk3+PEztPlQTMix1Ov2j8LPJK2det9Yv0QAwMNQD5MymNIz85U\nfFBvKQ+xuUed4ReV1CgCnv0jbQZkaDHO2ctZSojPnN08fA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Educampus Services"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.educampus.ie"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Educampus Services Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.unicon.net/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jlewis@unicon.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Lewis"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp-admin@unicon.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IdP Administrator"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.unicon.net/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unicon.net:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unicon.net:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUIEHTfbStY0ckKZzxIgqd5p1O2K0wDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOaWRwLnVuaWNvbi5uZXQwHhcNMTEwOTEzMDMyMzE2WhcN\nMzEwOTEzMDMyMzE2WjAZMRcwFQYDVQQDEw5pZHAudW5pY29uLm5ldDCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBANtUsFXxlhvD3bWT5Y7TqKkf5rxa+dPA\nz7vpbJ6bWhDPSMXb/9MiJe/ciY5ZKKrB1rdRC04s7blrzem3YtjGihfGd4ld+NRt\nPi0xoAT2YIp83CvEe5BHAKwqD7KTonN1unbN84mVo65itbme9d8lZKc0PfLM+BQp\nfhXKUBfYeBCkYU4YWxmgL4Vs7XBaKjEjpTN4ncar4YSrarWTTPyO5RzmVPLAcv88\n1OBqewTyN41+JRXt0Jopi4ZQ8JjKkm73vhoYDBPHr/VMqk1lFfrDcDwJa2ygyWCm\nqTlq6zyLE9Fr6sYz6CbgA2lAqu/b1rYCqVCnRpoHZKahAQ9uGQSfHD8CAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOaWRwLnVuaWNvbi5uZXSGJWh0dHBzOi8vaWRwLnVuaWNv\nbi5uZXQvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFK6yUrpGjvY3B09ke0kVl4wA\nCMAnMA0GCSqGSIb3DQEBBQUAA4IBAQDG/gMpr3N+nAMuo7RhtDBsckiJV2+BwT/r\nJmpxlHAV1Zgc3eeuOdyxm5/jA78tspLldL0+6W/LzZWov/je36IqVT1wSGy1n0Sc\nPjw8DHgyEJLCij2vVScV+j/Y4Eg0bVy6pZTeQW+e3ygb6WgiVT/ARM8QBp6GjAUC\nqIlJCads9Rcx3vAih72I4exUUD4qMuBMeLIdY5XReHy5YHqxbkPjQhDIEORAFlzJ\njLqO/Ldzn4waEa5snDZyeYjsl6pi+8CVGfXLSDVsDuk5s47B9OD+gOSJ1wEc7O/N\nnU9d/WCcM1V4IGZGL8TXUdfJoVXYZUFF08jUGSL2mj30WS1orIWo"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unicon.net"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.unicon.net/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unicon.net/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unicon.net/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unicon.net:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unicon.net:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unicon.net"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Login service for Unicon Employees"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.unicon.net/files/Image/unicon_logo_600_high.jpg",
                    "lang": "en",
                    "height": "88",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "600"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Unicon, Inc."
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUIEHTfbStY0ckKZzxIgqd5p1O2K0wDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOaWRwLnVuaWNvbi5uZXQwHhcNMTEwOTEzMDMyMzE2WhcN\nMzEwOTEzMDMyMzE2WjAZMRcwFQYDVQQDEw5pZHAudW5pY29uLm5ldDCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBANtUsFXxlhvD3bWT5Y7TqKkf5rxa+dPA\nz7vpbJ6bWhDPSMXb/9MiJe/ciY5ZKKrB1rdRC04s7blrzem3YtjGihfGd4ld+NRt\nPi0xoAT2YIp83CvEe5BHAKwqD7KTonN1unbN84mVo65itbme9d8lZKc0PfLM+BQp\nfhXKUBfYeBCkYU4YWxmgL4Vs7XBaKjEjpTN4ncar4YSrarWTTPyO5RzmVPLAcv88\n1OBqewTyN41+JRXt0Jopi4ZQ8JjKkm73vhoYDBPHr/VMqk1lFfrDcDwJa2ygyWCm\nqTlq6zyLE9Fr6sYz6CbgA2lAqu/b1rYCqVCnRpoHZKahAQ9uGQSfHD8CAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOaWRwLnVuaWNvbi5uZXSGJWh0dHBzOi8vaWRwLnVuaWNv\nbi5uZXQvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFK6yUrpGjvY3B09ke0kVl4wA\nCMAnMA0GCSqGSIb3DQEBBQUAA4IBAQDG/gMpr3N+nAMuo7RhtDBsckiJV2+BwT/r\nJmpxlHAV1Zgc3eeuOdyxm5/jA78tspLldL0+6W/LzZWov/je36IqVT1wSGy1n0Sc\nPjw8DHgyEJLCij2vVScV+j/Y4Eg0bVy6pZTeQW+e3ygb6WgiVT/ARM8QBp6GjAUC\nqIlJCads9Rcx3vAih72I4exUUD4qMuBMeLIdY5XReHy5YHqxbkPjQhDIEORAFlzJ\njLqO/Ldzn4waEa5snDZyeYjsl6pi+8CVGfXLSDVsDuk5s47B9OD+gOSJ1wEc7O/N\nnU9d/WCcM1V4IGZGL8TXUdfJoVXYZUFF08jUGSL2mj30WS1orIWo"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Unicon, Inc."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unicon.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Unicon, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.raven.cam.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:service-desk@uis.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "University Information Services' Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:raven-support@ucs.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Raven Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.raven.cam.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICujCCAaICCQDN9BMM2g2oWzANBgkqhkiG9w0BAQUFADAfMR0wGwYDVQQDExRz\n\t\t\t\t\t\taGliLnJhdmVuLmNhbS5hYy51azAeFw0xNTExMjAxNDUwNTFaFw0yNTExMTcxNDUw\n\t\t\t\t\t\tNTFaMB8xHTAbBgNVBAMTFHNoaWIucmF2ZW4uY2FtLmFjLnVrMIIBIjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxBNt1CZhNwQfCTD7sT0VctwAsdHAqhOmADg+\n\t\t\t\t\t\tJkpw27QKxVIPlUANAY3e7mbKuWGNYjLv9+KUrkwGhSXnOwUUCC01w+8JpII2j1W6\n\t\t\t\t\t\t8iAvKGszfolVfmfj8vqscQ/UqlSKaGjruWk394v3b7eddYh7HCAOtgOJDIKX9F0e\n\t\t\t\t\t\tbMkIdqQgw2e5uenwt1S9TgwOvYi+IfuZ5yhQv9Yuwo76QS8UkxOyvZdRZl7MIchx\n\t\t\t\t\t\tO0THaTYbrca0GsSc+r9SIb++rM5fQ0yxQzh36PqbGiA1noS/dhkRZb3ywLPNoFzu\n\t\t\t\t\t\tqwWOvcN6ubhO5YOKmTPn1N0uVg94LVMCxMWlO+DjZ8aFmMr96wIDAQABMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQBimCfClavq2Wk1Zsq9AQ3TWeVFrm1kaCUi4J5j3uWNlMVK\n\t\t\t\t\t\tPsIGE0BHAALMixG+XWt5+QW70CXq6RnHXMS0TLfM5q6K8jIVURK599bTF2/d4fNq\n\t\t\t\t\t\t3QJNaVusuqCqym3Z7rt71QfGtPi0rVKVlQL+lL87a0TDLIyWLsbEe786NpYe0mEe\n\t\t\t\t\t\tBXPQwpPwSaJ1PnPNlsl5i/cUZou5zZQGHtqEY/PR7wAxS/28A6qWLVpMQEUYtb9M\n\t\t\t\t\t\tZBb6lO15RJ5qwk6paQG87nhMPAFwSbK+OpCkt3hYd7l8LjXNG74eOZdPM5V6DmZz\n\t\t\t\t\t\tnMRF0t4QBDKsuZ64N/+u7R3Nj6uzsQsb7PJXGNTf"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cam.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eresources.lib.cam.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.raven.cam.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.raven.cam.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.raven.cam.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.raven.cam.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.raven.cam.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.raven.cam.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.raven.cam.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.raven.cam.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cam.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eresources.lib.cam.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://shib.raven.cam.ac.uk/idp-logo-80x60.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://shib.raven.cam.ac.uk/idp-logo-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Cambridge"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "cam.ac.uk"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:52.208056,0.1225"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "128.232.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "129.169.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "131.111.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.18.195.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.60.80.0/20"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.63.252.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:630:200::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICujCCAaICCQDN9BMM2g2oWzANBgkqhkiG9w0BAQUFADAfMR0wGwYDVQQDExRz\n\t\t\t\t\t\taGliLnJhdmVuLmNhbS5hYy51azAeFw0xNTExMjAxNDUwNTFaFw0yNTExMTcxNDUw\n\t\t\t\t\t\tNTFaMB8xHTAbBgNVBAMTFHNoaWIucmF2ZW4uY2FtLmFjLnVrMIIBIjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxBNt1CZhNwQfCTD7sT0VctwAsdHAqhOmADg+\n\t\t\t\t\t\tJkpw27QKxVIPlUANAY3e7mbKuWGNYjLv9+KUrkwGhSXnOwUUCC01w+8JpII2j1W6\n\t\t\t\t\t\t8iAvKGszfolVfmfj8vqscQ/UqlSKaGjruWk394v3b7eddYh7HCAOtgOJDIKX9F0e\n\t\t\t\t\t\tbMkIdqQgw2e5uenwt1S9TgwOvYi+IfuZ5yhQv9Yuwo76QS8UkxOyvZdRZl7MIchx\n\t\t\t\t\t\tO0THaTYbrca0GsSc+r9SIb++rM5fQ0yxQzh36PqbGiA1noS/dhkRZb3ywLPNoFzu\n\t\t\t\t\t\tqwWOvcN6ubhO5YOKmTPn1N0uVg94LVMCxMWlO+DjZ8aFmMr96wIDAQABMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQBimCfClavq2Wk1Zsq9AQ3TWeVFrm1kaCUi4J5j3uWNlMVK\n\t\t\t\t\t\tPsIGE0BHAALMixG+XWt5+QW70CXq6RnHXMS0TLfM5q6K8jIVURK599bTF2/d4fNq\n\t\t\t\t\t\t3QJNaVusuqCqym3Z7rt71QfGtPi0rVKVlQL+lL87a0TDLIyWLsbEe786NpYe0mEe\n\t\t\t\t\t\tBXPQwpPwSaJ1PnPNlsl5i/cUZou5zZQGHtqEY/PR7wAxS/28A6qWLVpMQEUYtb9M\n\t\t\t\t\t\tZBb6lO15RJ5qwk6paQG87nhMPAFwSbK+OpCkt3hYd7l8LjXNG74eOZdPM5V6DmZz\n\t\t\t\t\t\tnMRF0t4QBDKsuZ64N/+u7R3Nj6uzsQsb7PJXGNTf"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Cambridge"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cam.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Cambridge"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.ufsc.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Marcio Clemes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "marcio@npd.ufsc.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.ufsc.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDpjCCAo4CAQAwDQYJKoZIhvcNAQEFBQAwgZgxDTALBgNVBAoTBFVGU0MxDjAM\nBgNVBAsTBVNlVElDMRwwGgYJKoZIhvcNAQkBFg1hZG1pbkB1ZnNjLmJyMRYwFAYD\nVQQHEw1GbG9yaWFub3BvbGlzMRcwFQYDVQQIEw5TYW50YSBDYXRhcmluYTELMAkG\nA1UEBhMCQlIxGzAZBgNVBAMTEnNoaWJib2xldGgudWZzYy5icjAeFw0xNDA0MTYy\nMjI4MTZaFw0xOTA0MTUyMjI4MTZaMIGYMQ0wCwYDVQQKEwRVRlNDMQ4wDAYDVQQL\nEwVTZVRJQzEcMBoGCSqGSIb3DQEJARYNYWRtaW5AdWZzYy5icjEWMBQGA1UEBxMN\nRmxvcmlhbm9wb2xpczEXMBUGA1UECBMOU2FudGEgQ2F0YXJpbmExCzAJBgNVBAYT\nAkJSMRswGQYDVQQDExJzaGliYm9sZXRoLnVmc2MuYnIwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQC/oBIF0VeleZ37F3PzefDHAIrgwIaN2aRyLzZ4Uv8/\nFYsWLIXeOxXr49qJ77jFFkv/UzXZJvLvb6yhKC0A18E+ZDcKSQZuYoG8Arx+ohPR\nEI824htm1uAwGAw/SUsDVTgFodHOmIOmal71f6sorCKb1GeBkDkpkSYyYXG3t7fk\ntVY741kqaPcGellMrccwKztjFs31GvNLNZCpLOpF3lLmmpDApOaFO1f9qbSKv0GZ\nPYPm/8NxE+4wJMUVHzExCpn/YV0rBd4DfNhU4LJGx6yYQCe+Rj6Uu9vL3AHcBU5k\nPT/ggxte+CDsQADIoYct8oPPDsZa4ezejgh1+XbTcqTzAgMBAAEwDQYJKoZIhvcN\nAQEFBQADggEBALAr9prD3ASLuuTCydBg5NHQIFkQdIhoPkgu1VA5IHdqr4qpM4HL\nI1BFbUi7CFBXMlVFC6xDB4H5byq8TidvLcAvePhrL4WLbO6q/CmuOeLEuGXEXY2T\nrYGyJI3JK0/Y2vb4IURylGMQvl0+dX8PHocy3wfNoXVdUYG4w3XYPKAXgWKlKC8F\nsexAwdseeJPodXooXs+WzgUbhKZAlQtfw8w/jEEf3UiOtj8R0oKJpp9NjDxmvFt1\n0Zsj1b736wkbB0weh6x+SjGFDGvN0Pqy6oMe1Up1GltN2e2mwU//UUWTp7hwgRuK\nO/t+U9FZLkeIH0u6xb0pl+3M4vupjleTToU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufsc.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.ufsc.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.ufsc.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.ufsc.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.ufsc.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.ufsc.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.ufsc.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.ufsc.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.ufsc.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufsc.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufsc.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufsc.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFSC - Universidade Federal de Santa Catarina"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFSC - Universidade Federal de Santa Catarina"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFSC - Universidade Federal de Santa Catarina"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFSC - Universidade Federal de Santa Catarina"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDpjCCAo4CAQAwDQYJKoZIhvcNAQEFBQAwgZgxDTALBgNVBAoTBFVGU0MxDjAM\nBgNVBAsTBVNlVElDMRwwGgYJKoZIhvcNAQkBFg1hZG1pbkB1ZnNjLmJyMRYwFAYD\nVQQHEw1GbG9yaWFub3BvbGlzMRcwFQYDVQQIEw5TYW50YSBDYXRhcmluYTELMAkG\nA1UEBhMCQlIxGzAZBgNVBAMTEnNoaWJib2xldGgudWZzYy5icjAeFw0xNDA0MTYy\nMjI4MTZaFw0xOTA0MTUyMjI4MTZaMIGYMQ0wCwYDVQQKEwRVRlNDMQ4wDAYDVQQL\nEwVTZVRJQzEcMBoGCSqGSIb3DQEJARYNYWRtaW5AdWZzYy5icjEWMBQGA1UEBxMN\nRmxvcmlhbm9wb2xpczEXMBUGA1UECBMOU2FudGEgQ2F0YXJpbmExCzAJBgNVBAYT\nAkJSMRswGQYDVQQDExJzaGliYm9sZXRoLnVmc2MuYnIwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQC/oBIF0VeleZ37F3PzefDHAIrgwIaN2aRyLzZ4Uv8/\nFYsWLIXeOxXr49qJ77jFFkv/UzXZJvLvb6yhKC0A18E+ZDcKSQZuYoG8Arx+ohPR\nEI824htm1uAwGAw/SUsDVTgFodHOmIOmal71f6sorCKb1GeBkDkpkSYyYXG3t7fk\ntVY741kqaPcGellMrccwKztjFs31GvNLNZCpLOpF3lLmmpDApOaFO1f9qbSKv0GZ\nPYPm/8NxE+4wJMUVHzExCpn/YV0rBd4DfNhU4LJGx6yYQCe+Rj6Uu9vL3AHcBU5k\nPT/ggxte+CDsQADIoYct8oPPDsZa4ezejgh1+XbTcqTzAgMBAAEwDQYJKoZIhvcN\nAQEFBQADggEBALAr9prD3ASLuuTCydBg5NHQIFkQdIhoPkgu1VA5IHdqr4qpM4HL\nI1BFbUi7CFBXMlVFC6xDB4H5byq8TidvLcAvePhrL4WLbO6q/CmuOeLEuGXEXY2T\nrYGyJI3JK0/Y2vb4IURylGMQvl0+dX8PHocy3wfNoXVdUYG4w3XYPKAXgWKlKC8F\nsexAwdseeJPodXooXs+WzgUbhKZAlQtfw8w/jEEf3UiOtj8R0oKJpp9NjDxmvFt1\n0Zsj1b736wkbB0weh6x+SjGFDGvN0Pqy6oMe1Up1GltN2e2mwU//UUWTp7hwgRuK\nO/t+U9FZLkeIH0u6xb0pl+3M4vupjleTToU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFSC - Universidade Federal de Santa Catarina"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFSC - Universidade Federal de Santa Catarina"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufsc.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufsc.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFSC - Universidade Federal de Santa Catarina"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFSC - Universidade Federal de Santa Catarina"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-23.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-23.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-23.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-23.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-23.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-23.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-23.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-23.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-23.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;23"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;23"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-23.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-23.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJAI8NVUOyHlojMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0yMy5sYWRvay51bXUuc2UwHhcNMTQwOTAxMTQ0NTQ3WhcNMjQw\nODI5MTQ0NTQ3WjAhMR8wHQYDVQQDExZsYWRvazMtMjMubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA9waKrN3pOyTiTTW34wEcmkEm\nzzrtRb6PTQMp+YrwyXA8TD+FCU3oDlYoLTi3QWprCAc+kd7eTNHD2A9yHmQa+dQG\ngKcnv2GH9Bm2WVi6E0XvepiGduYCWGY6aEy0ZjkFB/aqTZNp+4D1bSItUcV5EOvU\njrvt7cwXwr2djJeMRV4LFTuZXiIRcOYyhNYBiqaY4NI8FXkgzpRX5cVm/Lpistvc\nlrx9H2YWjWyBFF9M1OEp50noxhiZe9Ze1GCZTpgqg8g+9WV3b1MTclhQDPCxui94\nOf+oJUbwy71/LaAAJ5MjaciXf/XU0WydTRsApLI5ecme4bQvCL5rdhcdZ8cS2wID\nAQABo2swaTBIBgNVHREEQTA/ghZsYWRvazMtMjMubGFkb2sudW11LnNlhiVodHRw\nczovL2xhZG9rMy0yMy5sYWRvay51bXUuc2UvZ3VpLXNwMB0GA1UdDgQWBBSyoRuK\nSKk6YtboKzoayYA98a2RPjANBgkqhkiG9w0BAQUFAAOCAQEAe8bmJlBVp0vLemx9\n0ujdvDRu6obF6o4qMcS3aMkvXU/OC3f8rDWAcIBbC437lY0sbvh0n7lXLFrkllP7\njukCb38EIQlZoJFO57fsqXAwyuE69DMrR6WnUhI7EMm9uC1qC5pk3oqagTe+JZod\ndQSLAxNhGsmPcwuMLRFnfMkUsmmPhYzKB4Lk3FOAoQ8HkEsPE/jdc5JgD49gLF+6\nvOwrX1PmCNRmdx/rSaW2rRee8ZgB8UL7lsbZU7B0iv8Zu2xsdPMBcPXAVJi9QW9+\nUDoSSkKkxefoQk+WUIBtDf8cyapWG0zmxQONgAiIhUI7mfPlo/gM/H48nLlXi/MV\nvH4mRA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-23.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-23.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-23.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-23.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-23.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-23.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-23.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-23.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-23.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-23.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sdauth.sciencedirect.com/",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibbolethsupport@elsevier.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Elsevier Shibboleth Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibbolethsupport@elsevier.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Elsevier Shibboleth Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sdauth.sciencedirect.com/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Elsevier: ScienceDirect"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.elsevier.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Elsevier B.V."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.elsevier.com/SHIRE/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://auth.elsevier.com/SHIRE/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sdauth.sciencedirect.com/SHIRE/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cdc310-auth.elsevier.com/SHIRE/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://cdc310-auth.elsevier.com/SHIRE/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cdc312-auth.elsevier.com/SHIRE/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://cdc312-auth.elsevier.com/SHIRE/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cdc313-auth.elsevier.com/SHIRE/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://cdc313-auth.elsevier.com/SHIRE/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cdc315-auth.elsevier.com/SHIRE/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://cdc315-auth.elsevier.com/SHIRE/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cdc316-auth.elsevier.com/SHIRE/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://cdc316-auth.elsevier.com/SHIRE/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cdc327-auth.elsevier.com/SHIRE/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://cdc327-auth.elsevier.com/SHIRE/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEoDCCA4igAwIBAgIBATANBgkqhkiG9w0BAQQFADCBljELMAkGA1UEBhMC\nVVMxDTALBgNVBAgTBE9oaW8xEzARBgNVBAcTCk1pYW1pc2J1cmcxFDASBgNV\nBAoTC0xFWElTLU5FWElTMSEwHwYDVQQDExhzZGF1dGguc2NpZW5jZWRpcmVj\ndC5jb20xKjAoBgkqhkiG9w0BCQEWG0VtYWlsTm90TmVlZGVkQGVsc2V2aWVy\nLmNvbTAeFw0xMjA3MjcxMzU2MDlaFw0yMjA3MjUxMzU2MDlaMIGWMQswCQYD\nVQQGEwJVUzENMAsGA1UECBMET2hpbzETMBEGA1UEBxMKTWlhbWlzYnVyZzEU\nMBIGA1UEChMLTEVYSVMtTkVYSVMxITAfBgNVBAMTGHNkYXV0aC5zY2llbmNl\nZGlyZWN0LmNvbTEqMCgGCSqGSIb3DQEJARYbRW1haWxOb3ROZWVkZWRAZWxz\nZXZpZXIuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArv49\nmYjjAEm6cINEmhRwPk3amwJjENDm/adyrmDVyo8vP2qV0t1yMkQ4/mjtKNbN\ntHXdYmHhfKWUvkcfGrWSlTTtL58pzUa1yrAa4/zG4yMDsu0TRa9mXrJObLyQ\ngbW7UW6k4cYVFYh7NdNUlYYZJlQcnOnzd1vg5YUoTCG72bVvN18ECMgmwpet\nOuU34+C/0VMWmAta11MnI9SVFdBa7/V34Ui3kQURo9rZGBOKX38UCEQaL0t6\nOaStEVpPOBubbG3Xk/dOCLTqq0L/694oXr38pZLRy+R+PinTTqTLgg2k8d35\nknIQoQ+/HbTJnTZ+N0RG2Qs8PjQ+saYJtvf8lQIDAQABo4H2MIHzMB0GA1Ud\nDgQWBBRj2Qz+DnqMnI6xhYJHngQCnWxPyjCBwwYDVR0jBIG7MIG4gBSSutEA\n8L7ay1vyhalDZtLDe5WNRqGBnKSBmTCBljELMAkGA1UEBhMCVVMxDTALBgNV\nBAgTBE9oaW8xEzARBgNVBAcTCk1pYW1pc2J1cmcxFDASBgNVBAoTC0xFWElT\nLU5FWElTMSEwHwYDVQQDExhzZGF1dGguc2NpZW5jZWRpcmVjdC5jb20xKjAo\nBgkqhkiG9w0BCQEWG0VtYWlsTm90TmVlZGVkQGVsc2V2aWVyLmNvbYIBADAM\nBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBAUAA4IBAQAjfpImUzNMumHr2S2v\nLEsK7z+m7NQNPEarTSYxj+0TNH3W+ylvgjcEprAoXWVEkJEQkvcYHXS8rWqx\nqZ9zJptPsaqJ/kDEv3i2MguF4iCRAhUJzNCpIvdpaJ2rDTfLfx2mk+2co78G\nx6Ixc5TaUYimoKbWdBgetTLMAT0iEUxAtEgo6M2yacBtQGewYQSnA6/pAiJU\nlDUBvw0tyEUDs8sAv/LrBFnl/jeYcb4V/khhD8zTvlmaPoCttZyxx/VABsfo\nsRfkEgf52ge02TXsHTvDuKe3GKJUqzqYnuQw0sdo9tQp3aTFCi0r/pYqPrB2\n1ZIbkQ/xybNtFratD7yuJ3Or"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Elsevier Service Provider"
                  }
                ],
                "logo": [
                  {
                    "text": "https://origin-cdn.els-cdn.com/sd/elsevier.gif",
                    "height": "80",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "73"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.elsevier.com/wps/find/privacypolicy.cws_home/privacypolicy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Elsevier Service Provider"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://idp.enit.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Viret"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jean-marc.viret@enit.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barriere"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jean-philippe.barriere@enit.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.enit.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-10-08T16:39:40Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.enit.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.enit.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.enit.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "enit.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.enit.fr"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENIT Ecole Nationale Ing\u00e9nieurs Tarbes"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENIT Ecole Nationale Ing\u00e9nieurs Tarbes"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUNCWmiXUxvGHYUEqaiw+kQmjPnKcwDQYJKoZIhvcNAQEL\nBQAwFjEUMBIGA1UEAwwLaWRwLmVuaXQuZnIwHhcNMTYwMzAyMTMyNzAxWhcNMzYw\nMzAyMTMyNzAxWjAWMRQwEgYDVQQDDAtpZHAuZW5pdC5mcjCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBALJaCTnb+oBxag1Y/mge6WKXQ6uqrJ17HUFEPa05\nKx5fBhLa2fSbBxvCCqQU4u/b4QCgKNR3NmQHAqRZt+oHnspkn5MYiYVwx3JJ7t3g\n/6hn2I31Kz3JoujEATO9+ZiMWp5ZF0hsxErHJY/3GSD4+XgY9x/JT85sNDPnAK8b\nFEkDK7SyyyFBSDSMRqFlRCmXLvW2t1KL57Uwh3DcaGxtnbIqt+7rgWZGCRFPj6Uz\n1sAogGlWXsIF4HllUrY99ZbqkQsQ8KwJzUmdxM/R+9mer957lPfJloLRkO/EFrVk\n/LTbN/LfIyR4wArEHtUzEFnsjvpon8naOiQjDGVYGmYs/isCAwEAAaNdMFswHQYD\nVR0OBBYEFLiWQuZmgnPlpReNgQTHErpPOQYgMDoGA1UdEQQzMDGCC2lkcC5lbml0\nLmZyhiJodHRwczovL2lkcC5lbml0LmZyL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3\nDQEBCwUAA4IBAQA10j0ZZq38hq4tGi2+rnTGkczknzTEoe4mOG9qc43qVJCa65lV\n4Ejk7SpQLL+AK6+vICzfYNFM/lgAzBIS4fO7SXP5Ylrrs3+n8BF95GcTZkvSNRfX\nBVlp26/Cz5mOss5AmiW3gixHPG362fD+LzC8V0S71A/KciqOtGAYFJ4qZHu4WWqT\no2bWx+GbPlzS4PSFVXgGsjuv2/qewBGXIxhUNLawjrSH7oq71WdgtILHS4EP9P0a\nkd6UdaVOuEAAvuHMgXsD6egYms+/cssmyyjewVTVE067vgggo3t0rl6W8ab9JmVF\njX7UGDVzBkRCz7RJLf3iOx0LnxPRwifm5n5Q"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAP4SLqi+2pminMR8C652zJZyirCyMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2lkcC5lbml0LmZyMB4XDTExMDYyODEyNTYyMVoXDTMx\nMDYyODEyNTYyMVowFjEUMBIGA1UEAxMLaWRwLmVuaXQuZnIwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCBzWn8nDXCVpi+0KdNV9lzB3Q9HfFrZcMiLZaj\no6rzdI1VtYnTE0fgHOfQX0fwiSBhRFmwaTMVHDy6jRZQWkB8Zg7IxBdvQnEn7tUx\ngLW0/gZ6Pgw4V/ZRimpWUn0Ga/s7EBv7Nsyn7HZhRLse0t7d8dTgAD01TivVHx54\nSEOiZF5b+GFJJjeGJHpxTwj7Dto0Pr0vhmQ+4C3ppPigrrideIc9EaiiW+kAm/q1\n4tNlttLaOUp3u5l+5lDfUlfcPiHYGCgXdmkJ/Hg6iIoYl6A+QdqiSFuUO8z/Jk0G\nmdGixe/BrTC0fWjwOF4EG8b2TbYYjBVU3/BwA319eP4tqdvHAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2lkcC5lbml0LmZyhiJodHRwczovL2lkcC5lbml0LmZyL2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBTidErzqd3TgXkbgGawiY3XHdywljANBgkqhkiG\n9w0BAQUFAAOCAQEAR2vDr33t9oTs96KycknrBoQk+I1nGpvaogo0qNbK1db0/NIW\nHjsiQgteVwvIm2BWsYjeaNiKI3VFAJ2jd0DVTIHASrq4Zuhv73VrEVfPPv/BcAot\nQyZM/38k0QU0zzr/XobhBP2pk5l7CMtYnmYKamQBvQrFq+JWe6mg6rXpLt5dai3q\nsHNSMvsplcRaenBakuEP6IJ5+X73tg4BvnTXHF8gSE5zoE1Fvoo4j8WlzX5VFpnm\nynWSKIvu7JYtfAV0YXTDZ1JWanatwUv2PFIeGBfg8jh3f+xU7+nOiGsC3sOfr4dK\nYcFtZchDCMTlBKAW8xGvvTVS6hZSzntZe4Z97w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ENIT Ecole Nationale Ing\u00e9nieurs Tarbes"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.enit.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ENIT Ecole Nationale Ing\u00e9nieurs Tarbes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://secure.palgraveconnect.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Abia"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:C.Abia@nature.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chike"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Abia"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:C.Abia@nature.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chike"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://secure.palgraveconnect.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-10-03T09:56:41Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Macmillan Publishers Limited: Palgrave Connect"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.palgraveconnect.com/pc/info/about.html"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Macmillan Publishers Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRjCCAi6gAwIBAgIEUgn/jjANBgkqhkiG9w0BAQUFADBlMQswCQYDVQQGEwJV\n\t\t\t\t\t\tSzEPMA0GA1UEBxMGTG9uZG9uMRIwEAYDVQQKEwlNYWNtaWxsYW4xDDAKBgNVBAsT\n\t\t\t\t\t\tA05QRzEjMCEGA1UEAxMac2VjdXJlLnBhbGdyYXZlY29ubmVjdC5jb20wHhcNMTMw\n\t\t\t\t\t\tODEzMDk0MjM4WhcNMjMwODExMDk0MjM4WjBlMQswCQYDVQQGEwJVSzEPMA0GA1UE\n\t\t\t\t\t\tBxMGTG9uZG9uMRIwEAYDVQQKEwlNYWNtaWxsYW4xDDAKBgNVBAsTA05QRzEjMCEG\n\t\t\t\t\t\tA1UEAxMac2VjdXJlLnBhbGdyYXZlY29ubmVjdC5jb20wggEiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tAQUAA4IBDwAwggEKAoIBAQDVuyehBoUW75bHqXMOByfTlLs2QoQlyQjZdoQ6CE3N\n\t\t\t\t\t\tiAsKnBQ9SzcxeLUItBFzZ5rrZtSgfbOrF8qGX7JDvr61o3We5tz33Z4zClmolRUU\n\t\t\t\t\t\tPWItfDhUybNf217Yg0nASYdovP3feM8Li2tg+jSguD+EwUIpfNcQ+DQShpPaOj+d\n\t\t\t\t\t\tnvl7Kut68r6JcLPaWWD/FMxFzyEr/EGmfWzyFb4wfZEaRBEEvMpwJxl+kk8hoCXx\n\t\t\t\t\t\tvIjr4KLxlWjzplPbhdQFAvyiYvrzGEhCbNedFDXX9qE66KvY0bB4+JQ5dLEsVlIc\n\t\t\t\t\t\tzxNZY/pCQo7k6HJ1W+lDpr8EddoJ0gt+dzwWx7Ea+5HfAgMBAAEwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAK/wqCVa2CziSKHgisbadotO21AeWCn8p1ny0df1iytnuxqK+UX8\n\t\t\t\t\t\tlfr96g99CWWU74FHr0bT80sEi0HGsRXzQ2SwoHCEUNHFrSgvLWWDEVM/MOrJy/fB\n\t\t\t\t\t\t2turD2G56p77lp1prGNUGmVQzuQaGTktcT/20+mOw0cCoHXzGPeqGb2M1EqgC5Ua\n\t\t\t\t\t\teGEGQvbkiflwYCRd8BLV8NL1Y5b+W+Qb+6K8GbLWiA2HLKnJBgXAtjrDau1B431H\n\t\t\t\t\t\tTEGsxRspwZ7E6JlhHEbi4meh4zlPLll7d7el31no1O9mD+n+E8hGQCpwz/fpDWlh\n\t\t\t\t\t\tJMnPorN3jbXoB/LWy9wZpDt7llDnSqOcr6s="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://secure.palgraveconnect.com/shibboleth/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://secure.palgraveconnect.com/shibboleth/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://secure.palgraveconnect.com/shibboleth/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://secure.palgraveconnect.com/shibboleth/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://qmul.co-tutor.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chung"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ray.chung@lboro.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ray"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Newman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:p.m.newman@lboro.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://qmul.co-tutor.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-18T09:37:34Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Co-Tutor at QMUL"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.co-tutor.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Loughborough University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://qmul.co-tutor.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://qmul.co-tutor.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://qmul.co-tutor.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://qmul.co-tutor.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://qmul.co-tutor.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://qmul.co-tutor.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAMPVjUQDBuJ5MA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\n\t\t\t\t\t\tBAMTD2lwLTE3Mi0zMS0xMy02MDAeFw0xNTA1MTIxMDAxNDNaFw0yNTA1MDkxMDAx\n\t\t\t\t\t\tNDNaMBoxGDAWBgNVBAMTD2lwLTE3Mi0zMS0xMy02MDCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBALmRo9osDCFd4HuAtT+hQKmnBkQPLaCUJ6K0TGOy/EWX\n\t\t\t\t\t\tfy/NNFsaBetqLsm4d5ShSfujl0UWC/xcL1MqDUd9aMnFFVC+3pQRnTML96vp6R29\n\t\t\t\t\t\t1IPkzXWGMUvMC4keLy2ylXyCz0RmoMFzH0o1IpAxtPbIeA0PSeVd9LbjQkDDzmpI\n\t\t\t\t\t\tVT4bRXYoR48iu1tp7v2X/I+9B89jWwTd92Y1UrVFgu0+EjhI6rIHr/U8CzAXHpbB\n\t\t\t\t\t\ta1Mghz4QlkcdHZCppzKGrYIoZ8TfU9CzlmvMwCFg8xKKPsScWCKaI4WRM+/hQ/q4\n\t\t\t\t\t\tbXwxrnXq7suyVD+gE6Ubg3MYNi2kwKtW2TtytFAiCKkCAwEAAaM9MDswGgYDVR0R\n\t\t\t\t\t\tBBMwEYIPaXAtMTcyLTMxLTEzLTYwMB0GA1UdDgQWBBSzWJU+LpvPG9LjM0yHFHaj\n\t\t\t\t\t\tToDlOzANBgkqhkiG9w0BAQUFAAOCAQEAXJchQuBPLMhqJYiyPMgnGdOMvCE5yiL9\n\t\t\t\t\t\tcKUJ4OfqI0kyNNCclJsoaBoBlXU0aDVZmv3gQDeB/aszlDlJceU5rrw30dMl9+pi\n\t\t\t\t\t\tW/nYKX7E6olhHfBGhWz8boNLsQhDx0/JKSTgouWCktryXIEoMIg1mpsZxT6GCzqH\n\t\t\t\t\t\tH6kpNEE8FcczMFVb88sDUlJ2+5iTnqlh6qK5xXIIXSRUHA6RwwmeFqDgqPE5vFPN\n\t\t\t\t\t\tpPkRcJVGSe6cU9x58powQzQfNIyb9TtyvnlGWYq/iGPaQOogU8kKtYt2C6uQvNEK\n\t\t\t\t\t\tnEuAlUv6RvvvmULiZCAyICctzohEu712x3JsegldHPq9oZUhJqTJPg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://qmul.co-tutor.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://qmul.co-tutor.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://qmul.co-tutor.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://qmul.co-tutor.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://qmul.co-tutor.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://qmul.co-tutor.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://adfs.artez.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs.artez.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-04-29T16:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/c1e805c6dae3737d023a834e859622f8",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ArtEZ Hogeschool voor de Kunsten"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ArtEZ Institute of the Arts"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/artez.png",
                    "height": "35",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "96"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ArtEZ Institute of the Arts Hogeschool voor de Kunsten"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ArtEZ Institute of the Arts Hogeschool voor de Kunsten"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ArtEZ Institute of the Arts"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.artez.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ArtEZ Institute of the Arts"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-p09.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-p09.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;p09"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;p09"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-p09.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-p09.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQTCCAimgAwIBAgIJAJDMEf13vqm0MA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2xhZG9rMy1wMDkubGFkb2sudW11LnNlMB4XDTE1MDIwOTEwNDExOVoXDTI1\nMDIwNjEwNDExOVowIjEgMB4GA1UEAxMXbGFkb2szLXAwOS5sYWRvay51bXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCgU1uWIVhW231AIUHyZneh\nDWU+Ugltcvv53ihgCwRaXRI9QvLhExPGDLYniweFv6PGRX8fom3u/OGT7cTy+QnF\n8mZ5VgJb6Mtkv0ZgIuuFsasCQX7Hg/4UnECz6ZPdLZnjNV/AC38v9ZQnLvrx7SJU\neBcqCQRmudcz3Qlo+9+I1vUB3LH3IBdLGcRVEtOOnS7J0pb0mWPT6FIpVEa+g7cm\nI3QDrFZjAYeix6scDVIqYgnPwwSJral64tUqIRtuRsTZC3FsCzB8h6J9rszi1dPW\nEGy/I9RTG14rGCuLtXaZQALBm1Mo/7dVD6J7E+E+ChxMHPnykHAl4lY4gjc5FdLx\nAgMBAAGjejB4MFcGA1UdEQRQME6CF2xhZG9rMy1wMDkubGFkb2sudW11LnNlhjNo\ndHRwczovL2xhZG9rMy1wMDkubGFkb2sudW11LnNlL3N0dWRlbnQtZnJvbnRlbmQt\nc3AwHQYDVR0OBBYEFLwAiGxbc8cqytq7LRCVyVBmfs/uMA0GCSqGSIb3DQEBBQUA\nA4IBAQBj4wqdwkNWasllr/4ov3YfHCzDEzk5oRRD0mvK+n4EPqjOe0U0DSEsALFh\nBq3jL6ETaGDCBVFWnzVInGGo8Q+iEWtDi0IbBG3nKFXH3CzYPGzGRb1jxjOKs9wm\ndaqZwPSI+4E6hgz7SGMZUpEXcaIkqUw+Ha2JHIvT3qzmPVNeNHzqv2klAwPQSMKA\niGOXogu4t0iBxIrWwIJSawO3FaWlNa9s8WvVHpdml+4hFF61dkQ4Z1rYwUcv1MGj\nncrI0Cpb8E0yZl4rItbZkZat1Xr7ZabhVno2hgVeuSpEgB42dxmfrg2ohLByjMbs\nKrLP2rhVcVzanxwt02kjYwaqb4YH"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-p09.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://id.nps.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "webmaster@nps.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NPS Webmaster"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "webmaster@nps.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NPS Webmaster"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tac@nps.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NPS TAC"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ia-support@nps.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NPS Cybersecurity"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://id.nps.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://id.nps.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://id.nps.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://id.nps.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://id.nps.edu/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nps.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.nps.edu"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Naval Postgraduate School"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Naval Postgraduate School Identity Provider"
                  }
                ],
                "logo": [
                  {
                    "text": "https://id.nps.edu/idp/images/nps_logo.png",
                    "lang": "en",
                    "height": "69",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://my.nps.edu/privacy-policy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAM2gN4tPKNZOEipQHfXFdM1sxWfzMA0GCSqGSIb3DQEB\nCwUAMBUxEzARBgNVBAMMCmlkLm5wcy5lZHUwHhcNMTUxMjA0MTkzMTE3WhcNMzUx\nMjA0MTkzMTE3WjAVMRMwEQYDVQQDDAppZC5ucHMuZWR1MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAgP9en/WfxAWe9aDUXWnup+Xeslht28QK5J2B9I+4\nEhEJ6CXJgX4q0cWLj18T76WBo2ZvKpgwMh49XDyGxPavnJryVosHQoirHpr5N33z\nZ5+geXrDmPkkKXO7iTCoiQ8DQWYEvmrlj1wTlq2Nd8FwgSozTprnWtyijhNZlm2K\n5i4r2te3HQdeegb9k44n7DboYnRFLaKwy+74LQ5/RbwIA5oZfQ76b8kWzSCdRC0z\nHK2WnAuyxy+4u7JTI4QjQ+GputqEyM1fMeLsF/23GqSMDVpD/BtJRzY3D3j3cz6B\nUe+ABaJGbBAcQ4VPHWnKxx5U8VKood97XqnpN/2AHFUZSwIDAQABo1swWTAdBgNV\nHQ4EFgQUWxDS23WSKHpO0zaU1LD4hgvdFBYwOAYDVR0RBDEwL4IKaWQubnBzLmVk\ndYYhaHR0cHM6Ly9pZC5ucHMuZWR1L2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\nCwUAA4IBAQA1e3zWP1ke/drvQ1i8SavOC2hBjpYfoIGNdLTdop2UR85vWQVn/cW8\no6DmV/Jc5oAVdBVMnXCLgYIhFtOOokc8VYHo9Q2u0fQhcQWjpv07EVKgxplTCar0\n5r5NvNilpwQuMUfhBSaidCY3ogmVZsaGDDMxIba+VbkkflcqRJNrng/jsVRLJbGK\njrQk4BB+3mECgvZw9Z1ejXIwif6LK+y1ErY0e6xQ0PyMOp39lS2ZpWf0IFqyKdV9\nvdTNeb8Pauw8SObWRJ91C0Hn5eajfmm4iaCOh5nkAyexSrOzdI/deoKfAVOOyBvl\nccPVb6WCA68tlf2YbL2E57QkuO8lV1TL"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://id.nps.edu/idp/help.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Naval Postgraduate School"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nps.navy.mil/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Naval Postgraduate School"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.icermali.org/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-support@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Technical Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-support@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-support@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Technical Support"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-admin@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Administrative Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.icermali.org/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.icermali.org:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAP/E5zTtSKQRMA0GCSqGSIb3DQEBCwUAMB0xGzAZBgNV\nBAMMEmxvZ2luLmljZXJtYWxpLm9yZzAeFw0xNTA1MDcyMDI3NDBaFw0yNTA1MDQy\nMDI3NDBaMB0xGzAZBgNVBAMMEmxvZ2luLmljZXJtYWxpLm9yZzCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAMmPB0HebXfTLmw98ZpK7/LWJ+mH+XJF/4x8\nwoQyRPox4C6LCRRM9CsFzHz9qZ1tJpRAjfzS47fexijeB9ZObEKajP4URe5rpOOz\n8d7qdp3KqylKCxKw+bvqaJQ1ki4QRxJBkKx9jcMc99yUomEEA5imBW/Q419+TkH/\nstLPzZmVKlaLOM1uqsHuo6PRORIcWkJ6HB0H0CNhKzB5gKGjCXvwkJ3kPGYjjFwQ\n7SnwzDawZCPpxMwQupPpc8TH0287A5w5PeXLrtuPU+WhLk1DcEVj1lhRv5/zZ5Je\nJsY492CUPrtyXm34/KJZFs7be81lE0Neeb0714lVeFgkjqz0VAcCAwEAAaNAMD4w\nHQYDVR0OBBYEFBOih/OT84Yk6H1pTl0LqwzhJS8rMB0GA1UdEQQWMBSCEmxvZ2lu\nLmljZXJtYWxpLm9yZzANBgkqhkiG9w0BAQsFAAOCAQEAZjNezwo9xN9fHKzyzx9A\nQAGWEmW7Td/n//vAAinYrjvp2E/yw3JExB55W500cemxLGM2pErzF9w62GE52Ryx\n0+HI4/CMCpkv55NLDl3bMbmlGIpE5kjpMsSOZ+gfQ0dAlGbacfjBExWZ0HqkN/l2\nkvYEKN0LukZkGOV3FAx77qr/uoKJTn6lDpQ/W+Yslt4eDo9SqGPZf/hwDvG50bIb\nIQOJxWPA3xS0JvEmdZRpcZzjo8quu4BM4J/FpBxCfLuEuNlhost8CuuYSphn10DQ\nb8J09UEArwi0vrZHClp0AanLon5PFgAkiXyT892CPD+Syo1ZFFMpB6JClp4Qh5cJ\nsQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAIEHUdC/eXeBMA0GCSqGSIb3DQEBCwUAMB0xGzAZBgNV\nBAMMEmxvZ2luLmljZXJtYWxpLm9yZzAeFw0xNTA1MDcyMDI2MzBaFw0yNTA1MDQy\nMDI2MzBaMB0xGzAZBgNVBAMMEmxvZ2luLmljZXJtYWxpLm9yZzCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAORvgT83hFUOb+C8kxgd3f5R3Q26QODxysFY\n85D8/feOde9hoyZ5nV6gOy4EIybFGCJhpI9XWsLDSNULYrzqK3PjH118zCoHc7Qz\nbskZTOWp+O/i3EZfYnY4EJSMeyGSHLjEQsxDXV1AZupk9zVqwFJFFDKBgNQzqMN9\n5tC0kCIyv8UTuogInzx1FYp2QptEai1a3HRrB3vF8n+uD6oFUWw1oPVpx3mNOnBJ\ne4FmEkQg8iq3PnbFYmljEeEzxK+1Wh+BbiX+2IoTmbDqvBc2KtSoS0xoMC3wL8uR\n1u12QnXQ9g6gOiebZ6b189HgNvtwQClzevYA8qc7yHc3oVKe9p8CAwEAAaNAMD4w\nHQYDVR0OBBYEFKo1xcaGTEzrtnFzsA/5sWSDcPx0MB0GA1UdEQQWMBSCEmxvZ2lu\nLmljZXJtYWxpLm9yZzANBgkqhkiG9w0BAQsFAAOCAQEAqybun7p6dZqscYKiuphs\nx8BNZlSrBBDvH4sooDsmd+lVseuvTRrea1Jqw9pE+qmJuhaV5xBUyGrk3Bq+T5qz\nh4cUbdUWNdUmGpf90Pzl2YmaaYWny81zNh/UtvnyR/kMJaGmAuInhA3jkoOQ5W1i\nqC8+CU4C7E3PNpBU8tx3U3ZKwojStWpiiz82uoxewYxy1xla3hfVV7d0isR8YJhD\n+jdOFJW2BEwPt1YKpmEp3OCkiXBJJ++p2/ptoYWDwm3or+TLCQi8FGjr4MTUBkDO\nO1GdrLusEqTXS0x86NfP8+J63P3Gd3iwpmHnFvuYu2OVDVeLas+nHQVkThNbnqN8\ncQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "icermali.org"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.icermali.org/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.icermali.org/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.icermali.org/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.icermali.org/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.icermali.org:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "icermali.org"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://login.icermali.org/federation/info"
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.icermali.org/federation/ui/logo/icermalilogo80x60.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://login.icermali.org/federation/privacy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ICER - Mali"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAP/E5zTtSKQRMA0GCSqGSIb3DQEBCwUAMB0xGzAZBgNV\nBAMMEmxvZ2luLmljZXJtYWxpLm9yZzAeFw0xNTA1MDcyMDI3NDBaFw0yNTA1MDQy\nMDI3NDBaMB0xGzAZBgNVBAMMEmxvZ2luLmljZXJtYWxpLm9yZzCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAMmPB0HebXfTLmw98ZpK7/LWJ+mH+XJF/4x8\nwoQyRPox4C6LCRRM9CsFzHz9qZ1tJpRAjfzS47fexijeB9ZObEKajP4URe5rpOOz\n8d7qdp3KqylKCxKw+bvqaJQ1ki4QRxJBkKx9jcMc99yUomEEA5imBW/Q419+TkH/\nstLPzZmVKlaLOM1uqsHuo6PRORIcWkJ6HB0H0CNhKzB5gKGjCXvwkJ3kPGYjjFwQ\n7SnwzDawZCPpxMwQupPpc8TH0287A5w5PeXLrtuPU+WhLk1DcEVj1lhRv5/zZ5Je\nJsY492CUPrtyXm34/KJZFs7be81lE0Neeb0714lVeFgkjqz0VAcCAwEAAaNAMD4w\nHQYDVR0OBBYEFBOih/OT84Yk6H1pTl0LqwzhJS8rMB0GA1UdEQQWMBSCEmxvZ2lu\nLmljZXJtYWxpLm9yZzANBgkqhkiG9w0BAQsFAAOCAQEAZjNezwo9xN9fHKzyzx9A\nQAGWEmW7Td/n//vAAinYrjvp2E/yw3JExB55W500cemxLGM2pErzF9w62GE52Ryx\n0+HI4/CMCpkv55NLDl3bMbmlGIpE5kjpMsSOZ+gfQ0dAlGbacfjBExWZ0HqkN/l2\nkvYEKN0LukZkGOV3FAx77qr/uoKJTn6lDpQ/W+Yslt4eDo9SqGPZf/hwDvG50bIb\nIQOJxWPA3xS0JvEmdZRpcZzjo8quu4BM4J/FpBxCfLuEuNlhost8CuuYSphn10DQ\nb8J09UEArwi0vrZHClp0AanLon5PFgAkiXyT892CPD+Syo1ZFFMpB6JClp4Qh5cJ\nsQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAIEHUdC/eXeBMA0GCSqGSIb3DQEBCwUAMB0xGzAZBgNV\nBAMMEmxvZ2luLmljZXJtYWxpLm9yZzAeFw0xNTA1MDcyMDI2MzBaFw0yNTA1MDQy\nMDI2MzBaMB0xGzAZBgNVBAMMEmxvZ2luLmljZXJtYWxpLm9yZzCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAORvgT83hFUOb+C8kxgd3f5R3Q26QODxysFY\n85D8/feOde9hoyZ5nV6gOy4EIybFGCJhpI9XWsLDSNULYrzqK3PjH118zCoHc7Qz\nbskZTOWp+O/i3EZfYnY4EJSMeyGSHLjEQsxDXV1AZupk9zVqwFJFFDKBgNQzqMN9\n5tC0kCIyv8UTuogInzx1FYp2QptEai1a3HRrB3vF8n+uD6oFUWw1oPVpx3mNOnBJ\ne4FmEkQg8iq3PnbFYmljEeEzxK+1Wh+BbiX+2IoTmbDqvBc2KtSoS0xoMC3wL8uR\n1u12QnXQ9g6gOiebZ6b189HgNvtwQClzevYA8qc7yHc3oVKe9p8CAwEAAaNAMD4w\nHQYDVR0OBBYEFKo1xcaGTEzrtnFzsA/5sWSDcPx0MB0GA1UdEQQWMBSCEmxvZ2lu\nLmljZXJtYWxpLm9yZzANBgkqhkiG9w0BAQsFAAOCAQEAqybun7p6dZqscYKiuphs\nx8BNZlSrBBDvH4sooDsmd+lVseuvTRrea1Jqw9pE+qmJuhaV5xBUyGrk3Bq+T5qz\nh4cUbdUWNdUmGpf90Pzl2YmaaYWny81zNh/UtvnyR/kMJaGmAuInhA3jkoOQ5W1i\nqC8+CU4C7E3PNpBU8tx3U3ZKwojStWpiiz82uoxewYxy1xla3hfVV7d0isR8YJhD\n+jdOFJW2BEwPt1YKpmEp3OCkiXBJJ++p2/ptoYWDwm3or+TLCQi8FGjr4MTUBkDO\nO1GdrLusEqTXS0x86NfP8+J63P3Gd3iwpmHnFvuYu2OVDVeLas+nHQVkThNbnqN8\ncQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://login.icermali.org/federation/error"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ICER - Mali"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nih.gov/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National Institutes of Health"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.kentunion.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.kentunion.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Membership Solutions Limited: Kent Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kentunion.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.kentunion.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.kentunion.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.kentunion.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.kentunion.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.kentunion.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.kentunion.co.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.kentunion.co.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.kentunion.co.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.kentunion.co.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.kentunion.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.kentunion.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.kentunion.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.kentunion.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.kentunion.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.kentunion.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.dailywhat.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jones"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:orig.jones@tinopolis.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Orig"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jones"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:orig.jones@tinopolis.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Orig"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.dailywhat.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-09-10T15:57:52Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Tinopolis Interactive Limited: Daily What"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tinopolis.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Tinopolis Interactive Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.dailywhat.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.dailywhat.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.dailywhat.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.dailywhat.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.dailywhat.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.dailywhat.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJAO7V64q3+QyMMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXRpbi1laC13ZWIwMDEwHhcNMTMwOTIxMTgzNDUzWhcNMjMwOTE5MTgzNDUz\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw10aW4tZWgtd2ViMDAxMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEA1u0wwroEU98KO6FGUH6IPwjCBQOb9EiK9eWStt9wTmfPIvK6\n\t\t\t\t\t\tcW4iqKvWxv/Ic89+mZGhJUgUqAgiMGpG8geQMtSDw/PxG0SCt5m5X3LE38pLrktF\n\t\t\t\t\t\tCJ9Z1MezuVMKhy/mxB7IWAuGTcuY+X8bGpt5BmtenOC2u2Of4PhG6OA5U+7R2hfn\n\t\t\t\t\t\tYGxJRaGyzaaL+L69sElGZ8nG1ag/jvJ6VQ+uGpB6pM7e5gCdEnseM/ruLxgmi1tY\n\t\t\t\t\t\tmnXvIHr2oPlGIDCFor+l53BK5gbdxBBfgxy+NtJA6rd9TDwBZ+922KKCCYlxAxzn\n\t\t\t\t\t\tRcFapFbp2MLxeU1lLJ4qxEGb8x7IW3/IWcK+PQIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg10aW4tZWgtd2ViMDAxMB0GA1UdDgQWBBTDGP+cpqj3AiOmkJqDHmwChMkESzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAvXMz3dAhtPMjjZxukiDzUv/M24SPbqdAjkl0TRTD\n\t\t\t\t\t\tl+VrbACwKPrg5X4cz2jRhcCk27rtcqaTJivQtYeNgOeFhyttSDn+XBksEE8+dTtj\n\t\t\t\t\t\t7C7pBF3nNXTelefmyvGhFZBcFtL0OGtzD+JWyqi/SE1r663RbkKDq62PVZrumH95\n\t\t\t\t\t\tgTmainsoFW14kPR3ZrdJsjUhmI/q5YfM8TiNebBD3el4x+CvlmtX+o7UndTEzb6R\n\t\t\t\t\t\tAWMb1wiURu0Lw4Ywgpkrd91bJIyoPDc2VJO9ABs4pHeG3NKaNjSY1suN4R5A4dfG\n\t\t\t\t\t\tV4hOHeRDvUlKIx3SpSVrMWsRCywyIdzIWrknAgdCJM2qIQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.dailywhat.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.dailywhat.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.dailywhat.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.dailywhat.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.dailywhat.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.dailywhat.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://st-andrews.unidesk.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:IS.Helpdesk@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-certs@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Application Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://st-andrews.unidesk.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-05-14T14:49:26Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Edinburgh: Unidesk - University of St Andrews"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://st-andrews.unidesk.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://st-andrews.unidesk.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://st-andrews.unidesk.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://st-andrews.unidesk.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://st-andrews.unidesk.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://st-andrews.unidesk.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAPHsl6kKrFrnMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\n\t\t\t\t\t\tBAMTEmxpdmUudW5pZGVzay5hYy51azAeFw0xMjA0MTExNDU4MjhaFw0yMjA0MDkx\n\t\t\t\t\t\tNDU4MjhaMB0xGzAZBgNVBAMTEmxpdmUudW5pZGVzay5hYy51azCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBAL9qh/Dehm5jJdWdeFPNKqcjMdiqii8Iz9Rc\n\t\t\t\t\t\ttCAsEwRsYww4EQDG7MxG5hg4NSS+iIPFCp9gR+G7hTnZAMGgNpxs2vk4vs9lmhRY\n\t\t\t\t\t\tGmB7Y1NFloP9Pcsu+MaufaLzxi6bzIXV4dBVHqVnIcgxchDIsXmPE6xlq4poEq+q\n\t\t\t\t\t\tXJ3aFE/eWwxfwN9z0s5yeICzsil73xk9T9NLeNAeYq+jfVTcdqDbBHY6eHtMOYh/\n\t\t\t\t\t\tuPVYYxkKXjkgSH5cwG0b+7qN4z+uzKDNBXxnI1Nz+bLOazXW6ljQIDtAPQZMJSlr\n\t\t\t\t\t\t3OepVaQS+fMBi0Sku5yvADgINdXxkz6H4Zx4pZg/rTQBQ/8u2esCAwEAAaNAMD4w\n\t\t\t\t\t\tHQYDVR0RBBYwFIISbGl2ZS51bmlkZXNrLmFjLnVrMB0GA1UdDgQWBBQ2tPlzxC8e\n\t\t\t\t\t\takC2nh9qrG4TWfI3tzANBgkqhkiG9w0BAQUFAAOCAQEAWPY3Nv9ChZ+4XVNANhLq\n\t\t\t\t\t\tfGF7SbiPmUNj9vWGNjCp8Ma0tdDOZPvqBRzxKkkR+LS+fHpSQQ54RuNeZrulWBiN\n\t\t\t\t\t\takZe3LZiSH9AHG2uD0lDuxr0UQt1AHGDiLjFXuRg9+CdqqrdT3Anmy6exDDfRsjH\n\t\t\t\t\t\tk+ZJflkEtqTNd0dbEVlkYlg8Baqx/ZMOxkccx8PtQt1yptAMsH4Rn92vXLd9d3JM\n\t\t\t\t\t\tH1mrFuiriqrgsAfVLmzc4WeGmB+dK01cSB+CY7hKnoe7ds1y7kNhOmZ9HP3Iy7ev\n\t\t\t\t\t\tgF2RCdnqkP9zScihW4b20PlVa/sWMUyCj2uZE1lSO51PJcGVU0H/JFrBEpaM7u6t\n\t\t\t\t\t\tjg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://st-andrews.unidesk.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://st-andrews.unidesk.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://st-andrews.unidesk.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://st-andrews.unidesk.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://st-andrews.unidesk.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://st-andrews.unidesk.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.mbl.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "knasveschuk@mbl.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kent Nasveschuk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cdematos@mbl.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Christopher Dematos"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cdematos@mbl.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Christopher Dematos"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://idp.mbl.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.mbl.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.mbl.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.mbl.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.mbl.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.mbl.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.mbl.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mbl.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mbl.edu"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Marine Biological Laboratory Federated Single Sign-On Service"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.mbl.edu/it/files/2013/05/incommon_privacy_statement.pdf"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Marine Biological Laboratory"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDeDCCAuGgAwIBAgIJAJXRYjhSMB8sMA0GCSqGSIb3DQEBBQUAMIGDMQswCQYD\nVQQGEwJVUzEWMBQGA1UECBMNTWFzc2FjaHVzZXR0czElMCMGA1UEChMcTWFyaW5l\nIEJpb2xvZ2ljYWwgTGFib3JhdG9yeTEfMB0GA1UECxMWSW5mb3JtYXRpb24gVGVj\naG5vbG9neTEUMBIGA1UEAxMLaWRwLm1ibC5lZHUwHhcNMTIwNzE2MTUxNzI1WhcN\nMzIwNzExMTUxNzI1WjB3MQswCQYDVQQGEwJVUzEWMBQGA1UECBMNTWFzc2FjaHVz\nZXR0czETMBEGA1UEBxMKV29vZHMgSG9sZTElMCMGA1UEChMcTWFyaW5lIEJpb2xv\nZ2ljYWwgTGFib3JhdG9yeTEUMBIGA1UEAxMLaWRwLm1ibC5lZHUwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDf2IMVS6Uj/AY6Y0M/XlafcHbg0Io2mnqr\nE9rImOw7bx5x9mNZVERGP0IM4tQW8hIHI+OAivK8FhDW5LgLPqqcd0fSeJROFOBW\nu1+ssYXg7Qae+QkAbbkjP7qWV5pF4JSe+NfSZVptIllS/LEb2LThSx1muyKe7dvE\nuruYglpLwtELh9JJt7CFKd+0Z16J1C+mPjXr8v7YSbCEAeakV5EFGrUEx/VzzvRv\nMEn2E+6KM8e78Z6m3aYRKenRF0VryFHpiKkkKhwg3iDKf7Y2SEJf3CnshIxpoUEU\n/YPqr9KSGx4/RDG2Enu2EAAFoKDwZpSpGZqMCNJytauQnBzy+hR7AgMBAAGjezB5\nMAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENl\ncnRpZmljYXRlMB0GA1UdDgQWBBQmngP4M69E0dBfby8kif3ltwOxrTAfBgNVHSME\nGDAWgBReurFgimXLG1EYKa8q4rJPb+X7tzANBgkqhkiG9w0BAQUFAAOBgQBWsE6q\n2ba1QbVCDTa7tSODC6vBZT5ioij1JUPeXyoZIS+RW8lvDmkGShG+4iRvEX21pUk2\nLfjdzGmLyOc+oHKS1CuQPe7hZS3IzC8U1fuyY/KIfqjba2zCk4ZyRFCP0vRlzxGc\nD9aaA2f9N+a9QmB0Bnwu75zgxjIrbQmLdJJp+A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Marine Biological Laboratory"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mbl.edu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Marine Biological Laboratory"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://aci-bookings.sisoshibboleth.co.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Info"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Oates"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://aci-bookings.sisoshibboleth.co.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-06T14:39:40Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SiSo South Bank Online Resource Booking"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.siso.uk.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "TechEthika Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aci-bookings.siso.co/sso/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://aci-bookings.siso.co/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://aci-bookings.siso.co/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SiSo London South Bank Resource Booking"
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth.siso.co/siso-logo64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SiSo London South Bank Online Resource Booking"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAOSUhyDXVj7AMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB3Npc28uY28wHhcNMTMwMTA3MTYzMTIxWhcNMjMwMTA1MTYzMTIxWjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdzaXNvLmNvMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\txDnj9YFJVXclawo/8rs1aWYAgk6rKi8A/Cyycq0mW5yOKLLh8MUIgDeOGL7bLl7p\n\t\t\t\t\t\tMBeZM4ILlNaeJhICWm1tuLB6SYzREnXwpO7+lvx13xsRHW2TjCPGV3yUgz55vRYj\n\t\t\t\t\t\tbseFrwFHJ8IrL24UTLcpX/R//9cMkZpSqM+77Hn22dxbYvGUOQCHOQzL78AO91qz\n\t\t\t\t\t\tdUaxKzYWyWM7w2U4APP41Zvd0flyUtRZXp8W+WwlUDffFoNndsjR4L/9wuXvOcrH\n\t\t\t\t\t\t+VZtMLy60+cB9bpvVlaQVlt+1stEABdMVvuGNkJ9wIjRjP2b9OLUI76QmgwIDtdE\n\t\t\t\t\t\t5BS0Bv0Puz66L96r2MunRQIDAQABozUwMzASBgNVHREECzAJggdzaXNvLmNvMB0G\n\t\t\t\t\t\tA1UdDgQWBBRRosxNbUQXXwtWDl/kYMScRImh5TANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tgrfjza9Btcz+9WvzcjDTZ+KSrWWvrthA3zc6Q+C/MIBG8CCuxMO+uwFBnXIopGlX\n\t\t\t\t\t\tbLa/QtVLjOugsnizFxjaEFTG4jGndtPJ8+9V8Eja5RlOazuM2LT738+Um8/1Frhr\n\t\t\t\t\t\tGXa0Hdv9ZWEbIhil65fFqZNOmOteja6xxAQ9NgGG/XUnTVTbr7msihEAYTTcS40/\n\t\t\t\t\t\tGSYpT9nQwiryfSWDNJ17Zyl44389kSw+FCUsu8Ns9VSDEDWr/R+97ZMcjN6hAfJL\n\t\t\t\t\t\tdji3X1aaAC/JbnJl/v+yR1TH/sdHyObVaM7FToUGKiyjX9VpfOe64d0hjogzEr0x\n\t\t\t\t\t\tfirJubLNu96jbGctasqcpQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aci-bookings.siso.co/sso/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aci-bookings.siso.co/sso/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://aci-bookings.siso.co/sso/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://aci-bookings.siso.co/sso/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://aci-bookings.siso.co/sso/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://aci-bookings.siso.co/sso/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.waltham.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.waltham.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/waltham.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/waltham.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "waltham.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Waltham Forest College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.waltham.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.kmh.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "KMH IT-avdelningen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:swamid@kmh.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Royal College of Music"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "KMH IT-avdelningen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:swamid@kmh.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Royal College of Music"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 8 161939"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "KMH IT HelpDesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@kmh.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Royal College of Music"
          }
        }
      ],
      "entity_id": "https://idp.kmh.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEzCCAfugAwIBAgIUbIUKEMZ6zDwgjsseeJEEBZ0IDv4wDQYJKoZIhvcNAQEF\nBQAwFTETMBEGA1UEAwwKaWRwLmttaC5zZTAeFw0xNTA1MjYxMzIwNTZaFw0zNTA1\nMjYxMzIwNTZaMBUxEzARBgNVBAMMCmlkcC5rbWguc2UwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQC8Fndbl7VcQp77YvwrHZJw+P4jup3EJWLqXwTPBQAl\npUfZXW1ZwlfZ/8Y+ng8GPn11ZS9gVEc9aW5+ZtvIX4rPgceB4Y5z3XFQpQfDrcBY\ng+dZc7xR24UZN5T1Er8i5xZWW7/Q2ariLfarK0X0oDoUEi5kaHcLc0ejvT2K3CVY\nuQ/LCw+4Wl7txbisiwh7AFjlqpgb2lNQxxzP/0xQwUBAMplxOZ/yxlK1RzKCHTOI\nsBHN6Sx3AW27HQduAzvKa3IDw7RV/WBi5ENER5U446LdSfWvObqSq4tNRSSpSszU\n6Vxldhar+0aACK/sBWw8FlLM5OM9K1SWeE7fk5PgTwQbAgMBAAGjWzBZMB0GA1Ud\nDgQWBBTdW08Nts1dNGIfcY8chlK5Yu0MlzA4BgNVHREEMTAvggppZHAua21oLnNl\nhiFodHRwczovL2lkcC5rbWguc2UvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEF\nBQADggEBAI20AdShxGWSxSVuiWzRnQKRpHQnalD84ev3BhaurMP93fzWJp4H1FzG\n+1+4K5tz5hbf1J1qaIZPn4+hEhYJLxQCiccH37Nqbs9zJFC6fQrCqKiMnh987f8X\n5X/BVsK9W2bNF8+e/a89O7X9u/4mFW7vdpHcsf/kO2QN1fkkukoCLSEWU4oWnWTr\nD0C4p8pAxxuCh86fN/plT6bfLbne17O9qmyT5miEhmfSG4uHoIgwMtbhOljOarH2\ncHGoE/CfcSGO7FS4bovPq7y8Mo2K5Xi9CXfzKzhWfUD72Md9dDYwFbY+gu31ceP1\nSqYks9bV+ae2Fl2AyXQXVv2GR6FNF8Y="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kmh.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.kmh.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.kmh.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.kmh.se/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.kmh.se/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.kmh.se:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.kmh.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.kmh.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.kmh.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.kmh.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.kmh.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.kmh.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kmh.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.kmh.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.kmh.se/english"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r Kungliga Musikh\u00f6gskolan"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Royal College of Music"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.kmh.se/idp/images/logo.jpg",
                    "lang": "sv",
                    "height": "141",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "313"
                  },
                  {
                    "text": "https://idp.kmh.se/idp/images/logo.jpg",
                    "lang": "en",
                    "height": "141",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "313"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kungliga Musikh\u00f6gskolan i Stockholm"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Royal College of Music"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "kmh.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:59.34474,18.08126"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.62.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEzCCAfugAwIBAgIUbIUKEMZ6zDwgjsseeJEEBZ0IDv4wDQYJKoZIhvcNAQEF\nBQAwFTETMBEGA1UEAwwKaWRwLmttaC5zZTAeFw0xNTA1MjYxMzIwNTZaFw0zNTA1\nMjYxMzIwNTZaMBUxEzARBgNVBAMMCmlkcC5rbWguc2UwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQC8Fndbl7VcQp77YvwrHZJw+P4jup3EJWLqXwTPBQAl\npUfZXW1ZwlfZ/8Y+ng8GPn11ZS9gVEc9aW5+ZtvIX4rPgceB4Y5z3XFQpQfDrcBY\ng+dZc7xR24UZN5T1Er8i5xZWW7/Q2ariLfarK0X0oDoUEi5kaHcLc0ejvT2K3CVY\nuQ/LCw+4Wl7txbisiwh7AFjlqpgb2lNQxxzP/0xQwUBAMplxOZ/yxlK1RzKCHTOI\nsBHN6Sx3AW27HQduAzvKa3IDw7RV/WBi5ENER5U446LdSfWvObqSq4tNRSSpSszU\n6Vxldhar+0aACK/sBWw8FlLM5OM9K1SWeE7fk5PgTwQbAgMBAAGjWzBZMB0GA1Ud\nDgQWBBTdW08Nts1dNGIfcY8chlK5Yu0MlzA4BgNVHREEMTAvggppZHAua21oLnNl\nhiFodHRwczovL2lkcC5rbWguc2UvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEF\nBQADggEBAI20AdShxGWSxSVuiWzRnQKRpHQnalD84ev3BhaurMP93fzWJp4H1FzG\n+1+4K5tz5hbf1J1qaIZPn4+hEhYJLxQCiccH37Nqbs9zJFC6fQrCqKiMnh987f8X\n5X/BVsK9W2bNF8+e/a89O7X9u/4mFW7vdpHcsf/kO2QN1fkkukoCLSEWU4oWnWTr\nD0C4p8pAxxuCh86fN/plT6bfLbne17O9qmyT5miEhmfSG4uHoIgwMtbhOljOarH2\ncHGoE/CfcSGO7FS4bovPq7y8Mo2K5Xi9CXfzKzhWfUD72Md9dDYwFbY+gu31ceP1\nSqYks9bV+ae2Fl2AyXQXVv2GR6FNF8Y="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Kungliga Musikh\u00f6gskolan i Stockholm"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Royal College of Music"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kmh.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "KMH"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ias.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idpadmin@ias.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeffrey Berliner"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idptech@ias.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Federated Authentication Support Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idphelp@ias.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Federated Authentication Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ias.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ias.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ias.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ias.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ias.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ias.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ias.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ias.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute for Advanced Study"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAJ4Rw7cCRxZXoeImY29/aVrW2esLMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2lkcC5pYXMuZWR1MB4XDTExMDMyNTE5MTEyNVoXDTMx\nMDMyNTE5MTEyNVowFjEUMBIGA1UEAxMLaWRwLmlhcy5lZHUwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCMUHgH7Im7k1tzx4W+Zxl/SJCC+UxEiwfDYUxr\n6gWmhgAfP8L1q6NjZ0uNqv4KX95VNrS6FzqW0mQFhPgVZh8X/b0ZPfHUXQPqqE/0\nyEpPWJBDipAsCiSDGqhgQcMxcsXO9jGLPBXhWD+Wzn7gVIXAn/13ExLh2i69IVrK\nDO7Xf5GXQwf//6TmRoNJnG7ZDPb/nF9dV2Ob+JyvdzIAyJKP6/3lLOpe+S+yacvq\nQLRQBCm0rmtE89Nv6l7meFijEv333I7DpltNsV0E4Sscf7C3bffIHwNyvZaUrhWm\nQ7EuyNXqg3tuAzaAQ+AYNYDWcEeINbPVU8PkCuw4xh3tQe7DAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2lkcC5pYXMuZWR1hiJodHRwczovL2lkcC5pYXMuZWR1L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBSY93bJArkW7rakEvXuLPKlPY+izDANBgkqhkiG\n9w0BAQUFAAOCAQEAB2vj4jeU+hx42zJUzhUkjCSBcKPMNHhLc7H824X1isfFwPaA\nahC1lNisUHjdOeugjChmAYKi/RS5PCF8GbEQpG1c4mDwYJFy0YyZkCA81k0y5Ruf\n4THC4P/iLNBUA4UZpECK2Ew96sWHlNcqTCPfhAXDX+P9dYC45Zyw3NIKhMRPlg71\n+D7ebhxnJQxVShc5S4bRB0GORWE4TlLn8sIRAk+R+iGuAghut2ueG44ipp7kIQ/0\nYyxdIMVGKSdzuKeh2yNoiNTzjqKqQc8d4GiWmVcJLw6kwD4MtniEexvkkRzlYW8q\nSvUIEk0xTVbv2eyIxcQBeXXgXyvtErmlxmp5gw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute for Advanced Study"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ias.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute for Advanced Study"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth-dev-v.musc.edu/shibboleth-idp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "gadsden@musc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard Gadsden"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vignesh@musc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Vanna Vignesh"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth-dev-v.musc.edu/shibboleth-idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-dev-v.musc.edu/shibboleth-idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth-dev-v.musc.edu/shibboleth-idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFZzCCBE+gAwIBAgIJAN5m0nACGtBMMA0GCSqGSIb3DQEBBQUAMIHSMQswCQYD\nVQQGEwJVUzEXMBUGA1UECBMOU291dGggQ2Fyb2xpbmExEzARBgNVBAcTCkNoYXJs\nZXN0b24xLTArBgNVBAoTJE1lZGljYWwgVW5pdmVyc2l0eSBvZiBTb3V0aCBDYXJv\nbGluYTEfMB0GA1UECxMWSW5jaWRlbnQgUmVzcG9uc2UgVGVhbTEiMCAGA1UEAxMZ\nc2hpYmJvbGV0aC1kZXYtdi5tdXNjLmVkdTEhMB8GCSqGSIb3DQEJARYSd2VibWFz\ndGVyQG11c2MuZWR1MB4XDTEwMTEyMjE4MTEyOFoXDTIwMTExOTE4MTEyOFowgdIx\nCzAJBgNVBAYTAlVTMRcwFQYDVQQIEw5Tb3V0aCBDYXJvbGluYTETMBEGA1UEBxMK\nQ2hhcmxlc3RvbjEtMCsGA1UEChMkTWVkaWNhbCBVbml2ZXJzaXR5IG9mIFNvdXRo\nIENhcm9saW5hMR8wHQYDVQQLExZJbmNpZGVudCBSZXNwb25zZSBUZWFtMSIwIAYD\nVQQDExlzaGliYm9sZXRoLWRldi12Lm11c2MuZWR1MSEwHwYJKoZIhvcNAQkBFhJ3\nZWJtYXN0ZXJAbXVzYy5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQDCCF+n5SXiIr8D7N0K68NXX8JBqVlHA9Auo0WQh/DDJ4Lf63FYw9eqPXBJeOJT\nRlbKTmq2Q4oHvrkvh4pmssIHvrLjQF5RDHJc/qfGLo+oo+xgPP44jfz4ak8jd7C3\nt8fZWTalElwC1/UfTxOYWPAqHef+6sSp4HD6rkjrwYfnhX3IGCmO5uMuJolIFDlo\n/VyMSO6DehbQsfjm+B3mBRPjkMoMEw9ues7BoY6vnP1GP+72fQOBmc1m4xh5Ysj5\nwl3F1qf1ElsjX2Lt74UimCfvWPpBLCSOwbipaFEKqavhgDJRWnrcTFPke8vC1/Bw\nFYau2JsGxPPzSKSdo2O4YEL7AgMBAAGjggE8MIIBODAdBgNVHQ4EFgQUsrCn25jz\nUegOu65+7KfBsc95K6kwggEHBgNVHSMEgf8wgfyAFLKwp9uY81HoDruufuynwbHP\neSupoYHYpIHVMIHSMQswCQYDVQQGEwJVUzEXMBUGA1UECBMOU291dGggQ2Fyb2xp\nbmExEzARBgNVBAcTCkNoYXJsZXN0b24xLTArBgNVBAoTJE1lZGljYWwgVW5pdmVy\nc2l0eSBvZiBTb3V0aCBDYXJvbGluYTEfMB0GA1UECxMWSW5jaWRlbnQgUmVzcG9u\nc2UgVGVhbTEiMCAGA1UEAxMZc2hpYmJvbGV0aC1kZXYtdi5tdXNjLmVkdTEhMB8G\nCSqGSIb3DQEJARYSd2VibWFzdGVyQG11c2MuZWR1ggkA3mbScAIa0EwwDAYDVR0T\nBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAQ7L76s5GZWA6vqOCp63oOUE1IPKr\nNZaw732+R42eePV0qVkzTUDHPH4kfdAfnFp8eU3ikkPg8TyDI7bFtMvFcgKUQStv\n924dbbA04MCbqxqoszOs5nILxDV0S8dXf+WHCZIIRb6s4DHm3+rZYLKS4gBvn5B1\nOnY4wSmMr4fMM9XqZDkcZtCwaWJwmK6p1gHOkEUxkBUlT/LxWIUwShOATcsfFPmm\nQM9DHUw4fMzqiqGdj4gYPKb14f1ShAGCKnhzOH/ziiX1EuspJOIkLTWDdJhbMJ+a\nFk6V6xmt1PTXZUnBvjYptaPWiVFHepuIdkaPr9Mvo7BvOc3CzwmmQUH5XA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "musc.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth-dev-v.musc.edu/shibboleth-idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth-dev-v.musc.edu/shibboleth-idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth-dev-v.musc.edu/shibboleth-idp/profile/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth-dev-v.musc.edu/shibboleth-idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth-dev-v.musc.edu/shibboleth-idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-dev-v.musc.edu/shibboleth-idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "musc.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ztest_Medical University of South Carolina"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFZzCCBE+gAwIBAgIJAN5m0nACGtBMMA0GCSqGSIb3DQEBBQUAMIHSMQswCQYD\nVQQGEwJVUzEXMBUGA1UECBMOU291dGggQ2Fyb2xpbmExEzARBgNVBAcTCkNoYXJs\nZXN0b24xLTArBgNVBAoTJE1lZGljYWwgVW5pdmVyc2l0eSBvZiBTb3V0aCBDYXJv\nbGluYTEfMB0GA1UECxMWSW5jaWRlbnQgUmVzcG9uc2UgVGVhbTEiMCAGA1UEAxMZ\nc2hpYmJvbGV0aC1kZXYtdi5tdXNjLmVkdTEhMB8GCSqGSIb3DQEJARYSd2VibWFz\ndGVyQG11c2MuZWR1MB4XDTEwMTEyMjE4MTEyOFoXDTIwMTExOTE4MTEyOFowgdIx\nCzAJBgNVBAYTAlVTMRcwFQYDVQQIEw5Tb3V0aCBDYXJvbGluYTETMBEGA1UEBxMK\nQ2hhcmxlc3RvbjEtMCsGA1UEChMkTWVkaWNhbCBVbml2ZXJzaXR5IG9mIFNvdXRo\nIENhcm9saW5hMR8wHQYDVQQLExZJbmNpZGVudCBSZXNwb25zZSBUZWFtMSIwIAYD\nVQQDExlzaGliYm9sZXRoLWRldi12Lm11c2MuZWR1MSEwHwYJKoZIhvcNAQkBFhJ3\nZWJtYXN0ZXJAbXVzYy5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQDCCF+n5SXiIr8D7N0K68NXX8JBqVlHA9Auo0WQh/DDJ4Lf63FYw9eqPXBJeOJT\nRlbKTmq2Q4oHvrkvh4pmssIHvrLjQF5RDHJc/qfGLo+oo+xgPP44jfz4ak8jd7C3\nt8fZWTalElwC1/UfTxOYWPAqHef+6sSp4HD6rkjrwYfnhX3IGCmO5uMuJolIFDlo\n/VyMSO6DehbQsfjm+B3mBRPjkMoMEw9ues7BoY6vnP1GP+72fQOBmc1m4xh5Ysj5\nwl3F1qf1ElsjX2Lt74UimCfvWPpBLCSOwbipaFEKqavhgDJRWnrcTFPke8vC1/Bw\nFYau2JsGxPPzSKSdo2O4YEL7AgMBAAGjggE8MIIBODAdBgNVHQ4EFgQUsrCn25jz\nUegOu65+7KfBsc95K6kwggEHBgNVHSMEgf8wgfyAFLKwp9uY81HoDruufuynwbHP\neSupoYHYpIHVMIHSMQswCQYDVQQGEwJVUzEXMBUGA1UECBMOU291dGggQ2Fyb2xp\nbmExEzARBgNVBAcTCkNoYXJsZXN0b24xLTArBgNVBAoTJE1lZGljYWwgVW5pdmVy\nc2l0eSBvZiBTb3V0aCBDYXJvbGluYTEfMB0GA1UECxMWSW5jaWRlbnQgUmVzcG9u\nc2UgVGVhbTEiMCAGA1UEAxMZc2hpYmJvbGV0aC1kZXYtdi5tdXNjLmVkdTEhMB8G\nCSqGSIb3DQEJARYSd2VibWFzdGVyQG11c2MuZWR1ggkA3mbScAIa0EwwDAYDVR0T\nBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAQ7L76s5GZWA6vqOCp63oOUE1IPKr\nNZaw732+R42eePV0qVkzTUDHPH4kfdAfnFp8eU3ikkPg8TyDI7bFtMvFcgKUQStv\n924dbbA04MCbqxqoszOs5nILxDV0S8dXf+WHCZIIRb6s4DHm3+rZYLKS4gBvn5B1\nOnY4wSmMr4fMM9XqZDkcZtCwaWJwmK6p1gHOkEUxkBUlT/LxWIUwShOATcsfFPmm\nQM9DHUw4fMzqiqGdj4gYPKb14f1ShAGCKnhzOH/ziiX1EuspJOIkLTWDdJhbMJ+a\nFk6V6xmt1PTXZUnBvjYptaPWiVFHepuIdkaPr9Mvo7BvOc3CzwmmQUH5XA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ztest_Medical University of South Carolina"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.musc.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Medical University of South Carolina"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://lu-idp.lu.lv",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ITserviss"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itserviss@lu.lv"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://lu-idp.lu.lv",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://laife.lanet.lv/wiki/Latvian-Academic-Identity-Federation-Policy.pdf"
              }
            ],
            "registration_instant": "2013-10-10T10:10:10Z",
            "registration_authority": "http://laife.lanet.lv/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lu-idp.lu.lv/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lu-idp.lu.lv/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lu.lv"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:56.950974,24.116292"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "logo": [
                  {
                    "text": "https://lu-idp.lu.lv/icons/icon-lu.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Latvia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Latvia - LU IDP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://laife.lanet.lv/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LAIFE - LU"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://childcare.uas.ox.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ops-team@maillist.admin.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Operations Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Letellier"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nick.letellier@it.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nick"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://childcare.uas.ox.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-11-04T12:12:25Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Oxford ChildCare Portal"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.it.ox.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Oxford"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://childcare.uas.ox.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://childcare.uas.ox.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://childcare.uas.ox.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://childcare.uas.ox.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://childcare.uas.ox.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://childcare.uas.ox.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJANnFKhkCv1e7MA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\n\t\t\t\t\t\tBAMTFmNoaWxkY2FyZS51YXMub3guYWMudWswHhcNMTUxMTAyMTUzODE3WhcNMjUx\n\t\t\t\t\t\tMDMwMTUzODE3WjAhMR8wHQYDVQQDExZjaGlsZGNhcmUudWFzLm94LmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzDCaP3Q0V2IdOBQURxihDJ3r\n\t\t\t\t\t\tfgOaOOgaZSehFMDzKUEbZOhCGASNjwaiTKFkYSpV+/3CttYMQbGy12xCxabEv5Qn\n\t\t\t\t\t\tsffscveJ1zWQeThPkp+Djs743JlWFPnkzxt4i0Q37fzVeMkPPmkYqA4AtqfMFtzi\n\t\t\t\t\t\tWAIyMoY2eGOIG8tahjGOt7hyQYAC9GWa/Wouc87onKCnY3ZnnkHvB3MUM7lzc8xW\n\t\t\t\t\t\tnkt1GicChIyCS13YDh1y3AhpTRsMvSyGzfyHVloHwnR1OX3jbFtCLbQHlCDuQFYS\n\t\t\t\t\t\tETk4Clgr7REcIAEaXD0PY5KJhgJwyormYV+go0/c0DIYkwD+svX0pTwTPUvP7QID\n\t\t\t\t\t\tAQABo0QwQjAhBgNVHREEGjAYghZjaGlsZGNhcmUudWFzLm94LmFjLnVrMB0GA1Ud\n\t\t\t\t\t\tDgQWBBSv7+ruCM5zakyYLDbFv7YQfhgOrDANBgkqhkiG9w0BAQUFAAOCAQEAWum0\n\t\t\t\t\t\ttyPa1Kk9Y3pQE3CBmq8mpWC0T8TJPqXlP8vgZuKxzmPdGn/Eki6aM6x85njtve9b\n\t\t\t\t\t\tfaDye6QuTPUMcZs/zh0QUTwnFWnM9tkA+eS+VPgtcymh0s6gA8Ib0zUSVsDtPKsY\n\t\t\t\t\t\t7IPdC9jZSxiqcYruoTTwnKTfvQTdksWa+jy1B1eM6NvWAYHxdpWVAzb9qK70g/jA\n\t\t\t\t\t\tNawWWKSieR9RPAikHU+btS7ikxSx1xsRm+l0eTm3Wlsrppbjwt7jHPSzecoww9IN\n\t\t\t\t\t\tDW+O1RyeuBy4TiG51lRS1mm/nbsd4NN5++Q2ta1iNebgxxzu/pFawTJjVphn3NHZ\n\t\t\t\t\t\tTqAaVAnA6pWtBzspjg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://childcare.uas.ox.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://childcare.uas.ox.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://childcare.uas.ox.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://childcare.uas.ox.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://childcare.uas.ox.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://childcare.uas.ox.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.universityadmissions.se/aws-sp-en",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al2"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://www.swamid.se/assurance-requirement",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.universityadmissions.se/aws-sp-en",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.universityadmissions.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.universityadmissions.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.universityadmissions.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.universityadmissions.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.universityadmissions.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.universityadmissions.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.universityadmissions.se/aws-sp-en"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.universityadmissions.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRzCCAi+gAwIBAgIJAPXTNM83oP+DMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\nBAMTG3d3dy51bml2ZXJzaXR5YWRtaXNzaW9ucy5zZTAeFw0xMjAyMTMwOTUxMDFa\nFw0yMjAyMTAwOTUxMDFaMCYxJDAiBgNVBAMTG3d3dy51bml2ZXJzaXR5YWRtaXNz\naW9ucy5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK/i8atiZRz6\ntGlOqjfywbRHg3BN22NXS0GDOCL7N7Ges+27Cir2X6cKxgkvkmIYTKM/CwxBpbVA\n6aCzwJR0aiwF7Yk+iCd+lZN1UZ+zqGAwVaYFWwJvJj9Pml1JBKtrI2UtWD6giUO1\nM4ADSc+v8c2GI99XuqicJ7RshRFfptzMgQD1EHzXrqcAWKWKcgk0cE7Im7i+Gf8t\nvqIGfWXTyQz/vLRN9TEuqC5lWUpxQthyydCfUxoNhVuP5r2C5f+xNspEmLXGCGy/\nLqPp8Qzti+A2ep93ycTYQ7UWsREjIc7mSSxJA2yNR0KiXAwhqCMEi2K2ifB5vQiA\nnw2d9qprbI8CAwEAAaN4MHYwVQYDVR0RBE4wTIIbd3d3LnVuaXZlcnNpdHlhZG1p\nc3Npb25zLnNlhi1odHRwczovL3d3dy51bml2ZXJzaXR5YWRtaXNzaW9ucy5zZS9h\nd3Mtc3AtZW4wHQYDVR0OBBYEFDCP8QQn4b49RQahrkPcr6O5x69eMA0GCSqGSIb3\nDQEBBQUAA4IBAQBx6LWrsGdO0RGf/p1gPt1Ss9x6FwqzFflqEwr1ogN9eLl+0svq\nr170nch935DrVqLU6v1CpMaCXrx2IG9OY3f9+JIU0xWCfjDwv8/l9JQ29cCZMBG5\ncer8XBtDmhZn/VZcCxD+E1USlg2kZdITY1PVH9V7BMNvGgAHFhWeGeSHPVNb6y0W\nj18Hf2KbZy+9Zod8DFQKzznA4j5qqAjX+4JsaXpJjcw2pteRbz6GwOWbMTDQYqc0\nUVO3Je8b81cYnxOzkTjcC46OOnwfKMCulFfBWoiza3xbuiS+Iv/lBbEPdRVN4HKa\nkLtKCIiImX90JFDcYwMMQyXM3dXWrJFi7exA"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.universityadmissions.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.universityadmissions.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.universityadmissions.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.universityadmissions.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.universityadmissions.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.universityadmissions.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.universityadmissions.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.universityadmissions.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.universityadmissions.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.universityadmissions.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.universityadmissions.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib.byu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "djw5@byu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Doug Walker"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dbm8@byu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dan McNeece"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ako@byu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex Olson"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "valinda@byu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "BYU IAM Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.byu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.byu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.byu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAMdtkhNUKYuSdtVPTI46fURWKKoyMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDHNoaWIuYnl1LmVkdTAeFw0xNTAzMjYyMjI0NTdaFw0z\nNTAzMjYyMjI0NTdaMBcxFTATBgNVBAMTDHNoaWIuYnl1LmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAJE7Bi6W9Q828ZLW5wKkU6yvOLy6F+10UB8M\n2nQx8aD/7J3Qd5rhqYpMHxbePXXhjL0IwJvSHeyVkIS9nj09VjRMFDj7Py3PmNUY\n3EqHsQHGYfVP4SrpkImJzBHVDxzTppN2vMg4JdiR1V+tD9wI2aLgpzw60yezfzQt\n5aBxYmKbQo3INNgCMnd2Xhy7y4Kc89L90qEM2dpwzEunkbgTs8HFVK4Xh5H/e6Ht\n5PRG1WxqqHX/hcn2m+bpxjgPav/udwxBs4AwyE1/M+cWiUfQMz9ZcX7PDL3Xa9bk\nFxoyujWjZhfoMrucOI0J/3mr9vCze4dBsYkvI4PVMLmb+5+l8nsCAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMc2hpYi5ieXUuZWR1hiNodHRwczovL3NoaWIuYnl1LmVkdS9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU1zJQjFI7ZL36TWulgBcYpYSA8cowDQYJ\nKoZIhvcNAQEFBQADggEBADP0+8gGWisnCSl/lRB/uSOffxdWGNp9243q5Q2wF+3f\nAHln1ndFRp9/pTZpTMYuhIfhj3nhBVSfbA82OIn4eq8Rn3iunj0KtxITjmsoUz55\nTwCG5KoQVVooC7SMbOabuYGCt6R/up83BdSCQR3hFraVgbcsiJXeSTYLiuiqtp0S\nCjKIp5uLbOun7i02xqPFWP98i/NYeeelpv8B9rjdPgXSUIoraJU0dmezG3WRVcEx\ngeODhddBhA/9t4MPUhxE2NkerjOJ1kxuxzyTBtvo1kS7Hhe+BnwZceEfqZ3Ieb+k\ntAvdjb86Vcp7Qd6mgqHTsmU05bXWB4TCg0JngVfp4bo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "byu.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Brigham Young University IdP"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Brigham Young University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Brigham Young University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.byu.edu/index.html"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Brigham Young University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://fs-test.restena.lu/simplesaml/module.php/saml/sp/metadata.php/discover",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NOC"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@restena.lu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "RESTENA"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://fs-test.restena.lu/simplesaml/module.php/saml/sp/metadata.php/discover",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://eduid.lu/media/eduid-mrps-02.pdf"
              }
            ],
            "registration_instant": "2015-07-07T08:20:00Z",
            "registration_authority": "http://eduid.lu",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RESTENA Foundation"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Fondation RESTENA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.restena.lu/restena/en/EN-Presentation.html"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.restena.lu/restena/fr/FR-Presentation.html"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RESTENA Foundation asbl"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Fondation RESTENA asbl"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://fs-test.restena.lu/simplesaml/module.php/saml/sp/saml2-logout.php/discover",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "(TEST) RESTENA FileSender is a secure way to share large files with anyone! Logon to upload your files or to invite people to send you a file."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "(TEST) RESTENA FileSender propose un moyen s\u00e9curis\u00e9 pour partager des gros fichiers avec vos coll\u00e8gues! Connectez-vous pour envoyer vos fichiers ou pour inviter vos interlocuteurs \u00e0 vous en envoyer."
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "(TEST) RESTENA FileSender ist eine sichere Methode grosse Dateien mit jedermann zu teilen! Verbinden Sie sich um Dateien zu verschicken oder um jemanden aufzufordern Ihnen eine Datei zu schicken."
                  },
                  {
                    "lang": "lb",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "(TEST) De RESTENA FileSender ass e s\u00e9chere Wee, fir grouss Fichieren ze versch\u00e9cken! Loggt Iech an, fir Fichieren eropzelueden oder aner Leit ze invit\u00e9ieren, Iech Fichieren ze sch\u00e9cken."
                  }
                ],
                "logo": [
                  {
                    "text": "http://fs-test.restena.lu/filesender.png",
                    "lang": "en",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RESTENA FileSender Service (TEST)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://fs-test.restena.lu/simplesaml/module.php/saml/sp/saml2-acs.php/discover",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://fs-test.restena.lu/simplesaml/module.php/saml/sp/saml2-acs.php/discover",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:profiles:holder-of-key:SSO:browser",
              "extension_attributes": {
                "{urn:oasis:names:tc:SAML:2.0:profiles:holder-of-key:SSO:browser}ProtocolBinding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect"
              },
              "location": "https://fs-test.restena.lu/simplesaml/module.php/saml/sp/saml2-acs.php/discover",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "RESTENA FileSender Service (TEST)"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "(TEST) RESTENA FileSender is a secure way to share large files with anyone! Logon to upload your files or to invite people to send you a file."
                },
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "(TEST) RESTENA FileSender propose un moyen s\u00e9curis\u00e9 pour partager des gros fichiers avec vos coll\u00e8gues! Connectez-vous pour envoyer vos fichiers ou pour inviter vos interlocuteurs \u00e0 vous en envoyer."
                },
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "(TEST) RESTENA FileSender ist eine sichere Methode grosse Dateien mit jedermann zu teilen! Verbinden Sie sich um Dateien zu verschicken oder um jemanden aufzufordern Ihnen eine Datei zu schicken."
                },
                {
                  "lang": "lb",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "(TEST) De RESTENA FileSender ass e s\u00e9chere Wee, fir grouss Fichieren ze versch\u00e9cken! Loggt Iech an, fir Fichieren eropzelueden oder aner Leit ze invit\u00e9ieren, Iech Fichieren ze sch\u00e9cken."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.23735.100.0",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.statistics.gov.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.statistics.gov.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/statistics.gov.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/statistics.gov.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "statistics.gov.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Office for National Statistics"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.statistics.gov.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/kadk-idp.wayf.kb.dk",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/kadk-idp.wayf.kb.dk",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2012-01-12T09:31:21Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/kadk-idp.wayf.kb.dk/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kadk.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kunstakademiets Arkitekt, Design og Konservatorskoler"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Schools of Architecture, Design and Conservation"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "kadk.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICwDCCAagCAQcwDQYJKoZIhvcNAQELBQAwJjEkMCIGA1UEAwwbaHR0cHM6Ly9r\nYWRrLWlkcC53YXlmLmtiLmRrMB4XDTE1MDEwMTAwMDAwMFoXDTI1MTIzMTIzNTk1\nOVowJjEkMCIGA1UEAwwbaHR0cHM6Ly9rYWRrLWlkcC53YXlmLmtiLmRrMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAx4gMCmoQU7iOGfiCda4DnhIggst2\n0fUCHtwaQrHoxQlOa0s5FgDalbnNTw36dCXSGYaz17JgyUDJonTwhjyA0CqPm5Pm\nn9/hFBUvyP/t+bEgV9r3/odQx72VfY7M55qUlY6ex2f1qD1gcpFgSTtADlZswec5\nWqpEt+ie+vsMXq8HabhMVZ2EjXe90vgMk/xGfrVwDvupUPBS/2DJSZ1JEmkqi0hx\nctNQ9qgTZmEcAaQkuv3VGcsYtLeY/IISlA+ARzmVWr5+uSetnCXV4jnDEclACKee\nxl0Ky+tyra4yHF3Xavgmcmebd+xHVDiM+No6BXMu9zBTp7cp5ShLzsNQSQIDAQAB\nMA0GCSqGSIb3DQEBCwUAA4IBAQCmawXmJcTJjkSG2CWmf0cqhJ77eZ/VfL57f5OX\nBcSbYryjWX5Wd1Z/t+/+83h18d94xPiw7dbv+bMq7Rdrxi9dYhcDWRLzEJ53CczD\nQdmqJtvYjGCWhR4Ab0Nm3IOVLepSUH24e2pEiq9/4516miiIpcNIxlEnVOu7gEcF\n3uvY2iWCki7dFaN5gDYHWm9bNY341nzT7OnP02Ehi7Sg5oAUlKuo8rQurMNcthrd\nJehUn8MIZDD/v/obLp8TImJijyvEbcJdqVIXmdx8L5DPoP9vJlVeMtSai3ED6hsW\nrBue0WdqjxUhj4Yyw2JK3w2jM3vzSNu7HWJ8AIBKco5rG/vo"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Kunstakademiets Arkitekt, Design og Konservatorskoler"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Schools of Architecture, Design and Conservation"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kadk.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kadk.dk/en"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Kunstakademiets Arkitekt, Design og Konservatorskoler"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Schools of Architecture, Design and Conservation"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.hainaut-promsoc.be/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+3271531578"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Technical Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "webmaster@hainaut-promsoc.be"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          }
        }
      ],
      "entity_id": "https://idp.hainaut-promsoc.be/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://federation.belnet.be/files/Belnet-metadata-registration-practice-statement.txt"
              }
            ],
            "registration_instant": "2012-03-27T12:00:00Z",
            "registration_authority": "http://federation.belnet.be/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.hainaut-promsoc.be/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.hainaut-promsoc.be/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.hainaut-promsoc.be/idp/profile/SAML2/POST-SimpleSign/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.hainaut-promsoc.be:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.hainaut-promsoc.be/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.hainaut-promsoc.be/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.hainaut-promsoc.be/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.hainaut-promsoc.be/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.hainaut-promsoc.be/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.hainaut-promsoc.be:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.hainaut-promsoc.be:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hainaut-promsoc.be"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Students and Teachers from Social Promotion Schools of Province de Hainaut"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Etudiants et Enseignants de l'Enseignement de Promotion Sociale de la Province de Hainaut"
                  }
                ],
                "logo": [
                  {
                    "text": "https://cdn.ecampus-hainaut.be/logos/idp-hps-16x16.jpg",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://cdn.ecampus-hainaut.be/logos/idp-hps-291x88.png",
                    "height": "291",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "88"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hainaut-PromSoc"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hainaut-PromSoc"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "hainaut-promsoc.be"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "50.41719089999999,4.448670300000003"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.199.64/26"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVAN68rKymbP0przSDvaG0eMoh/UGiMA0GCSqGSIb3DQEB\nCwUAMCExHzAdBgNVBAMMFmlkcC5oYWluYXV0LXByb21zb2MuYmUwHhcNMTUxMjAz\nMTIxMTQ0WhcNMzUxMjAzMTIxMTQ0WjAhMR8wHQYDVQQDDBZpZHAuaGFpbmF1dC1w\ncm9tc29jLmJlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAgFh9v8nu\nDZ22vG1hQaV9mA6+H6eobWNhEKHO/YdcC+uNU8dNrHgfvdGjTrrIk9BGFdsTuxak\nUnmVYQho3ASbc7LQdTlxJegvogiI6e+zl8vGrwKyhCYmAz3oDHnLA/YAkgk0EWRE\njuD2qYAYfgqMg/M6goWyn1EsCUk9pFc4D1tnmqsUWzG2dTwAfOlbDduMhJrU9F+v\nnNlayDAHWiPxASDsbQSRYtkA9O4xjujLcj65r3p2c+Xba5fVu9M57yeykvjVkYs2\nx+3rKyMzLEV46emeLCHiltpzHr3VJBlkT6ny66eXYd2Y7nTnRNEka/JACmcFFpO4\nhHPl8Rrf0qBqiQIDAQABo3MwcTAdBgNVHQ4EFgQU2/sCjD8jZll6GJw9Kf5qRcu+\nT7owUAYDVR0RBEkwR4IWaWRwLmhhaW5hdXQtcHJvbXNvYy5iZYYtaHR0cHM6Ly9p\nZHAuaGFpbmF1dC1wcm9tc29jLmJlL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\nCwUAA4IBAQBqaAQAbDvMlqplLVZpzw0F+UgxxsOL3kI2ATOH6jGrTqrWA/7bj8Ma\noYM22iUjtuMPa9r9+F3IA08krhALvMhgRsseM8n0kxWxIWtcGEE37MlHgaCsNUXt\nFnkP8thyCr8CnwzqWpFj5ouXaNqtDhx+qFM08XBDJh2mkCDQriD8lqHE2NUnfgGl\nDu+vSV7PfHKMdpMYJLFmT+Ry3bjrNA/WibJkQ4Hf9OtuOQ4M5k3VodWj2LCO4Ybh\nlGfxo5nF26RIBrY4mtTninIvP75nJjAJoS029RDpoYpl8Mh8t+lxsY0tisaYoJgF\nFgGl1jbigT4J3Bxxv1wcRfblufkR5grP"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVAPLtvCrrYfdTvxrnQNxT4wh/M2m9MA0GCSqGSIb3DQEB\nCwUAMCExHzAdBgNVBAMMFmlkcC5oYWluYXV0LXByb21zb2MuYmUwHhcNMTUxMjAz\nMTIxMTQyWhcNMzUxMjAzMTIxMTQyWjAhMR8wHQYDVQQDDBZpZHAuaGFpbmF1dC1w\ncm9tc29jLmJlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA9Z7Y1aEi\nBjtge0mCkmRNZBB+ZCJa/w1WFVh2kuY0gFYzeHdsN91yxUiaDujaXigN9rl9Z+cv\nAE/RN0MQtZbRROu89WA6ZcDcgsvcKLWfXr/RjC/nmtxuwBcvfJyFphXaaz1V2334\n6m1lIFQ43aE5s4NhrtENXhiukbHeCvaN1rwjdski73+POVKTDUr4a00r8/tybJgO\niUZrFDbRBZJ/TnQohhhGWTJEHbrvYApwKju8JQcMwk7R+bABsgf/oqki4pNmxXH8\nHevxO72Exn6uVi6AWO5rGiQX+jIyIJZprZCPeUoMjge5bpz3+vRlm9kO9Y0ablbT\nurOW9BAgDEHcNQIDAQABo3MwcTAdBgNVHQ4EFgQU6QJuMQqUcLoXMT4CrRK/yO8x\nz1wwUAYDVR0RBEkwR4IWaWRwLmhhaW5hdXQtcHJvbXNvYy5iZYYtaHR0cHM6Ly9p\nZHAuaGFpbmF1dC1wcm9tc29jLmJlL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\nCwUAA4IBAQDmP+yXnrrlRJ2D+inYx0mRAClGzzo3fG4Jgr46DWXrsRcrCJH3sjQr\n5MKNtgyPyZDy/NXcNtVS3IFJZkg27pokUD28RQtRB1dcCT++YIoViKtXnPct9nSQ\njnORWcsiw2Yx48rauTpJzA5vIEmwSv79iidoalBaxpiO7gXJL7JNqgVjhjBd9yDX\nRVL+pTLN5MhbSF6izeLcpvI/xhneStzW3b3IhHS+rPikg3GufLhM++5A45qAAqAz\nVRQosvXh6gvNKUDJpqCMK+m4b/Ue9rOBqtV9g8peJfZ9TQ9CKwDB0UbPPCfEEI/7\nMilG31thHKJnTIULp8CAkF+DIFtOcpk6"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUcuiw7sw3OSPjhIvrmbLChEBZ60AwDQYJKoZIhvcNAQEL\nBQAwITEfMB0GA1UEAwwWaWRwLmhhaW5hdXQtcHJvbXNvYy5iZTAeFw0xNTEyMDMx\nMjExNDJaFw0zNTEyMDMxMjExNDJaMCExHzAdBgNVBAMMFmlkcC5oYWluYXV0LXBy\nb21zb2MuYmUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCfLBJTJiLz\no30Vpv8ZwM2q/p9p6RdXo/zpvhNO3nkcvLYHPZssOR/u6MDCNNbjP/3PeLdqepvo\nUOzEw3hPg/IWsoPTnr3MYHRWYmzvBnr33rA/QAmv6OnW3RQjtCwQFH5UXQ9S/Xv3\no5YbB8vRaVrPZPd5EzyXoyo2zIZc5si2pbQj/0B40BPI8M+dsrInvtwOCJ6CgLkq\nzCD1bzY0P3EtbxGRFSA4fyZDO+72sIXX1fU0jniek/oEDTjRsi0svgUdwNcTi+qV\ntotEXOvkjv8jRJnzh0E2jOqGeXcSv6673gZvddG+Tcy8aQlNhfF9nvA9scNxtU1s\nb9Kor1NNei7ZAgMBAAGjczBxMB0GA1UdDgQWBBQBxbm5XMUopQNiz45GhwbwO0MZ\nqTBQBgNVHREESTBHghZpZHAuaGFpbmF1dC1wcm9tc29jLmJlhi1odHRwczovL2lk\ncC5oYWluYXV0LXByb21zb2MuYmUvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEL\nBQADggEBAJitAtWal9yuAUxDZhwEcq8s7R8+UpopnmhanN/8/QbaJq5SnsDecbRe\n0vds9Q8WQ2C/WBUq33+Szk5jxSO2b830qqaQoS3+aaXM6f9tnROYGpLcGxubtpa6\nWS0SvJWfMV82YL6KMkRbKmhjOUaOsS9kzbG+pevWlB5HtqwqYo13auvD8pzdZj6O\nkXjj5QdTeFZqiqhfLGzAbN2PT8m9ooeompaKdXPPPE6lGxBbkxb7oaiTbhQ2Vq2a\nThgBAs9l2+KxbBZMSIKonHuNy4rabps8OlUROSbh9uwTGfK/wP540Ig3zmKlNJ2n\nyre8A56stjeXAkdXHlOhm0/9YlW1hHQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hainaut-PromSoc"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hainaut-promsoc.be"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Enseignement de Promotion Sociale de la Province de Hainaut"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://hereford.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Saville"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tbs@hereford.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tom"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Saville"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tbs@hereford.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tom"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://hereford.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-05-23T09:59:18Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.hereford.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.hereford.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hereford.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkCgAwIBAgIILT4zd54jo/wwDQYJKoZIhvcNAQEFBQAwQzEkMCIGA1UE\n\t\t\t\t\t\tCgwbSGVyZWZvcmQgU2l4dGggRm9ybSBDb2xsZWdlMRswGQYDVQQDDBJpZHAuaGVy\n\t\t\t\t\t\tZWZvcmQuYWMudWswHhcNMTMwNjE5MTAzNTM2WhcNMjMwNjE5MTAzNTM2WjBDMSQw\n\t\t\t\t\t\tIgYDVQQKDBtIZXJlZm9yZCBTaXh0aCBGb3JtIENvbGxlZ2UxGzAZBgNVBAMMEmlk\n\t\t\t\t\t\tcC5oZXJlZm9yZC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAIfFoXIUvMYf21sWKJQfFVVOi0h8y7aC/dvDJA4lOBImafBE5Nj5X4LzK2LKMVp8\n\t\t\t\t\t\tmajS8DXN3GHhjtNWNiq6H/+7uGUZZjOhXvirrt8NIunX3Sxh+utQHV1MHkcHYaLz\n\t\t\t\t\t\t4k6j7ZdzFv1XrAsELK+/qjLkj0stXwYPSwYFIzrF1wBdqn8wqc8dzem30D8gWJ8i\n\t\t\t\t\t\tGzXXDGnp3UHqxgk1rx26HCbWqNY4BqwT3OO7H324hxQIcFWdD096NYxE9Cam8fUI\n\t\t\t\t\t\tqknu5RBAD25wqJVDrOWBYtl9A4IvczNVjcOrs6MpjmI0OspHQvY9V9G5TYObHG5Q\n\t\t\t\t\t\tbnzhYPyG7EVtsldbNWMeSjUCAwEAAaNQME4wHQYDVR0OBBYEFANLmaGyW7F0uvbZ\n\t\t\t\t\t\tVe1RHwWuqN7DMB8GA1UdIwQYMBaAFANLmaGyW7F0uvbZVe1RHwWuqN7DMAwGA1Ud\n\t\t\t\t\t\tEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAAQPkd/yCL7mA9DSkO8t65XZ+IDT\n\t\t\t\t\t\tVCBxORxaTmXjmtbtiKkFfF5LxCOAaoVbiuBQLPm5mn6vH9kgzyApMhfwSYgGMssP\n\t\t\t\t\t\teckyVfa28lGU5B+0Ug6QOb90kjFD7OUFx+510xyRkPtU6WmF+VJgXbsJQa6z96wb\n\t\t\t\t\t\tvfK1jq82mtG1hUGG5CzNxAGeyGLE3w7wd22gXclr//LVjdCBDmrKDCZuRZtIcspl\n\t\t\t\t\t\t/QfZ2h67XMQyd8Jdu0oxB1XgXPgzqI/LbokdqnHCLEjOyqJ/dNwf/CACNKxFPZTM\n\t\t\t\t\t\trpEhJNmmPFKIi9lPEv6R3hzNVPsfyxYFHsVL+hA5xx6Ak8t96zdGWMA9RCY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkCgAwIBAgIILT4zd54jo/wwDQYJKoZIhvcNAQEFBQAwQzEkMCIGA1UE\n\t\t\t\t\t\tCgwbSGVyZWZvcmQgU2l4dGggRm9ybSBDb2xsZWdlMRswGQYDVQQDDBJpZHAuaGVy\n\t\t\t\t\t\tZWZvcmQuYWMudWswHhcNMTMwNjE5MTAzNTM2WhcNMjMwNjE5MTAzNTM2WjBDMSQw\n\t\t\t\t\t\tIgYDVQQKDBtIZXJlZm9yZCBTaXh0aCBGb3JtIENvbGxlZ2UxGzAZBgNVBAMMEmlk\n\t\t\t\t\t\tcC5oZXJlZm9yZC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAIfFoXIUvMYf21sWKJQfFVVOi0h8y7aC/dvDJA4lOBImafBE5Nj5X4LzK2LKMVp8\n\t\t\t\t\t\tmajS8DXN3GHhjtNWNiq6H/+7uGUZZjOhXvirrt8NIunX3Sxh+utQHV1MHkcHYaLz\n\t\t\t\t\t\t4k6j7ZdzFv1XrAsELK+/qjLkj0stXwYPSwYFIzrF1wBdqn8wqc8dzem30D8gWJ8i\n\t\t\t\t\t\tGzXXDGnp3UHqxgk1rx26HCbWqNY4BqwT3OO7H324hxQIcFWdD096NYxE9Cam8fUI\n\t\t\t\t\t\tqknu5RBAD25wqJVDrOWBYtl9A4IvczNVjcOrs6MpjmI0OspHQvY9V9G5TYObHG5Q\n\t\t\t\t\t\tbnzhYPyG7EVtsldbNWMeSjUCAwEAAaNQME4wHQYDVR0OBBYEFANLmaGyW7F0uvbZ\n\t\t\t\t\t\tVe1RHwWuqN7DMB8GA1UdIwQYMBaAFANLmaGyW7F0uvbZVe1RHwWuqN7DMAwGA1Ud\n\t\t\t\t\t\tEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAAQPkd/yCL7mA9DSkO8t65XZ+IDT\n\t\t\t\t\t\tVCBxORxaTmXjmtbtiKkFfF5LxCOAaoVbiuBQLPm5mn6vH9kgzyApMhfwSYgGMssP\n\t\t\t\t\t\teckyVfa28lGU5B+0Ug6QOb90kjFD7OUFx+510xyRkPtU6WmF+VJgXbsJQa6z96wb\n\t\t\t\t\t\tvfK1jq82mtG1hUGG5CzNxAGeyGLE3w7wd22gXclr//LVjdCBDmrKDCZuRZtIcspl\n\t\t\t\t\t\t/QfZ2h67XMQyd8Jdu0oxB1XgXPgzqI/LbokdqnHCLEjOyqJ/dNwf/CACNKxFPZTM\n\t\t\t\t\t\trpEhJNmmPFKIi9lPEv6R3hzNVPsfyxYFHsVL+hA5xx6Ak8t96zdGWMA9RCY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hereford Sixth Form College OALA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hereford.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hereford Sixth Form College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://gcs.simitive.com",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Latham"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:adrian.latham@simitive.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adrian"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Latham"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:adrian.latham@simitive.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adrian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://gcs.simitive.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-12-22T11:11:17Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GCS Simitive"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.simitive.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Simitive Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://gcs.simitive.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://gcs.simitive.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gcs.simitive.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://gcs.simitive.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://gcs.simitive.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "authn_requests_signed": "1",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://gcs.simitive.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://gcs.simitive.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+TCCAeGgAwIBAgIJAJRQgVZWDd/zMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\n\t\t\t\t\t\tBAMTCElTLTI0ODMxMB4XDTE0MTIxNjExMTkyOFoXDTI0MTIxMzExMTkyOFowEzER\n\t\t\t\t\t\tMA8GA1UEAxMISVMtMjQ4MzEwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQC0THPJbqQqabRo8UmrYIVXK5FbfeMbRzh+KY+OKj+y1JPBwaF2eiyGW6y6yfaW\n\t\t\t\t\t\tu/ht+IVlmEIGkNCPSYDhRLVeX/EoFjXMSO8WFNUmrcK3V/nzvl4LpD1+5EIUT9ew\n\t\t\t\t\t\tX20Orkct5earRWmIa/DUfwL+7nHucu48b/0CNVVVqs1t/Qpnk1RU3n1lWZhN4R3m\n\t\t\t\t\t\tcUu8w1tyrZ52+bGUVPKtYgQSt9Qi66lonzz5k/ZLlSHTbdpPl85eO9ZGetiqqDjT\n\t\t\t\t\t\tkYF0juPHPQJyhX1y3N9yhDSX4MYKbCVXwLUek4UbYX9YjGfaaegGPv5g7DjgfPGV\n\t\t\t\t\t\tnxTINfawpUcYazq3Gq/wZTVRAgMBAAGjUDBOMC0GA1UdEQQmMCSCCElTLTI0ODMx\n\t\t\t\t\t\thhhodHRwczovL2djcy5zaW1pdGl2ZS5jb20wHQYDVR0OBBYEFEW/SH169Rn82c3p\n\t\t\t\t\t\thFRU/6GjSchgMA0GCSqGSIb3DQEBBQUAA4IBAQCWFmKpMIImEy1wWxc2vbZzqFIw\n\t\t\t\t\t\tw+k/dBQIXXrBfUckYA6WqvsUCGkGQpkUDtmaGRwkOWr2rGvhZZOqTDk2gt09Eatq\n\t\t\t\t\t\tDmiFWH4n7Bn9J02xXL+A+b0NRWtm4+UBRMZtyO5tvdW9ZzNNyBzAzo10i6WkcntJ\n\t\t\t\t\t\tkFuhwz2Y7CKka8ekE0gvanRjChmghI+SapQSdyLaa0RYTD/Dhoe4CqbsNkuGg/2A\n\t\t\t\t\t\tLJRFvT+VJIoJphSZ92EKiMxg7wQQmJkLBLlcmBCDzlXIa0YDezgSES7aXaqnx3cr\n\t\t\t\t\t\tderpKZtZARC+hGy1ZeUjiZGXXiGfEa23WC71DtIvJU8B8TbmgoKDWGeARwKK"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gcs.simitive.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://gcs.simitive.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://gcs.simitive.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://gcs.simitive.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://gcs.simitive.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://gcs.simitive.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol"
        }
      ]
    }
  ],
  [
    "http://fs.liu.se/adfs/services/trust",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 13 28 5730"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Johan Peterson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:johan.peterson@liu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Link\u00f6ping University (ADFS)"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 13 28 5898"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "LiU-IT:s Kundcenter"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@student.liu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Link\u00f6ping University (ADFS)"
          }
        }
      ],
      "entity_id": "http://fs.liu.se/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://fs.liu.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://fs.liu.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://fs.liu.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://fs.liu.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://fs.liu.se/adfs/services/trust/artifactresolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "liu.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.liu.se/?l=sv"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.liu.se/?l=en"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identitsutgivare f\u00f6r anst\u00e4llda och studenter vid Link\u00f6pings universitet."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for employees and students at Link\u00f6ping University."
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.liu.se/idp/images/logo-350x68-en.png",
                    "height": "68",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  },
                  {
                    "text": "https://login.liu.se/idp/images/logo-350x68-sv.png",
                    "lang": "sv",
                    "height": "68",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  },
                  {
                    "text": "https://login.liu.se/idp/images/logo-350x68-en.png",
                    "lang": "en",
                    "height": "68",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Link\u00f6pings universitet (ADFS)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Link\u00f6ping University (ADFS)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "liu.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:58.397282,15.578624"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.236.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:6b0:17::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute": [
            {
              "friendly_name": "E-Mail Address",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/emailaddress",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Given Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/givenname",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/name",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "UPN",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/upn",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Common Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/CommonName",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "AD FS 1.x E-Mail Address",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/EmailAddress",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Group",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/Group",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "AD FS 1.x UPN",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/UPN",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Role",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/role",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Surname",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/surname",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "PPID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/privatepersonalidentifier",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Name ID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/nameidentifier",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Authentication time stamp",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/authenticationinstant",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Authentication method",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/authenticationmethod",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Deny only group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/denyonlysid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Deny only primary SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/denyonlyprimarysid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Deny only primary group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/denyonlyprimarygroupsid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/groupsid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Primary group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/primarygroupsid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Primary SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/primarysid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Windows account name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/windowsaccountname",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFOTCCBCGgAwIBAgIQAdlHVjMUXk6RFVjqYeenpjANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMzAeFw0xNTAxMDcwMDAwMDBaFw0xODAxMTExMjAwMDBaMIGJMQswCQYDVQQG\nEwJTRTEXMBUGA1UECAwOw5ZzdGVyZ8O2dGxhbmQxEzARBgNVBAcMCkxpbmvDtnBp\nbmcxIDAeBgNVBAoMF0xpbmvDtnBpbmdzIHVuaXZlcnNpdGV0MQ8wDQYDVQQLEwZM\naVUtSVQxGTAXBgNVBAMTEGZzc2lnbmluZy5saXUuc2UwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQCS5bpEkEcbJAsNdgyK1QYAbuq5PKl8bAcujqKIRZAr\n4uixWudDxRVhwOxDyZMTZGN0vNVdf+ZtUZQ9NWYaLcgEvzxhNbsA0fmTSwRlMvxj\n0R/JbDs5Slmew11wZ6rxgX7wRv8rjB3PSdf/SVc5LKgcDuCCGCLv+OE7d4K13OfK\nBxUv/vrD7upz6lgT79OWX6udFhU8sXmP8u8P/mID83o5N32hwxymRuEmjnLiVIrU\nR4cF5EwgblrpoqQKeGKdkroZApU0EJxvtopesVgUEGXW4tkogTJ8qtSPQK8iPEet\neR6YpFCIxIbE0gpwDgo0bubt8T+FkQE71SLvbhv9RcZBAgMBAAGjggG/MIIBuzAf\nBgNVHSMEGDAWgBRn/YggFCeYxwnSJRm76VERY3VQYjAdBgNVHQ4EFgQU8vPdaPx+\nJhyN970NWqrTcbU/c0MwGwYDVR0RBBQwEoIQZnNzaWduaW5nLmxpdS5zZTAOBgNV\nHQ8BAf8EBAMCBaAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMGsGA1Ud\nHwRkMGIwL6AtoCuGKWh0dHA6Ly9jcmwzLmRpZ2ljZXJ0LmNvbS9URVJFTkFTU0xD\nQTMuY3JsMC+gLaArhilodHRwOi8vY3JsNC5kaWdpY2VydC5jb20vVEVSRU5BU1NM\nQ0EzLmNybDBCBgNVHSAEOzA5MDcGCWCGSAGG/WwBATAqMCgGCCsGAQUFBwIBFhxo\ndHRwczovL3d3dy5kaWdpY2VydC5jb20vQ1BTMG4GCCsGAQUFBwEBBGIwYDAkBggr\nBgEFBQcwAYYYaHR0cDovL29jc3AuZGlnaWNlcnQuY29tMDgGCCsGAQUFBzAChixo\ndHRwOi8vY2FjZXJ0cy5kaWdpY2VydC5jb20vVEVSRU5BU1NMQ0EzLmNydDAMBgNV\nHRMBAf8EAjAAMA0GCSqGSIb3DQEBCwUAA4IBAQCgqdZfizsQZYpLif+sV+mgkkln\n6WVGv1KVw2xvRDO9jF192qjkL9zmB081qOydPtt8aLbXQHp13M/URoFK2Vvdikq5\nWQMkGxJu3zLtQD4lJsJXAaGdm7nSwWS4NHHIf5yg0rWC5kQBJnWhAHhPedFzfgGR\n9lUohhvnLJJ/PFuvN0sCsYYpRraQT880RdTq1imsFB3wAUHjN9tQCS3Ss9Cf6MOv\nwHb3flDe4OLwxxMZfI3oGwoUJHltib7xFuT7w5hOYts3Js+BBtsSskGSp/dz8PiH\n6NDQZG/9USNN1biuUCDxrhTBgSHIAeB3h7k6wue5C30EE8SCLfZ6Xxsmk1rn"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFOTCCBCGgAwIBAgIQAnyNaDk3tSxKoRwzDMG6yjANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMzAeFw0xNTAxMDcwMDAwMDBaFw0xODAxMTExMjAwMDBaMIGJMQswCQYDVQQG\nEwJTRTEXMBUGA1UECAwOw5ZzdGVyZ8O2dGxhbmQxEzARBgNVBAcMCkxpbmvDtnBp\nbmcxIDAeBgNVBAoMF0xpbmvDtnBpbmdzIHVuaXZlcnNpdGV0MQ8wDQYDVQQLEwZM\naVUtSVQxGTAXBgNVBAMTEGZzZGVjcnlwdC5saXUuc2UwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQChPGysC8lsTi7EJHyrabNiyAW1pKBt8hDR7PiEOHWz\n/kDoxdoBftjelfewOvT+DM1t6WwQ3K2hbNDGuHmapaIuG/K491tXAZCiopcwZ4ud\nw7npBYJM3Err3sth2Yk3JtB69iN61t77hezMYyWd9yGmt5zd+DlXzzeJxNacWgkw\nW5ONAMRFCPV0VNBSk3QpxKe0V/VkhkGrwp2Jc+qVgykkUDPamyxc7cCnot1AFslS\n0WWl6LN1XllNxaqg8aYgNmRu/2w93SKPNfNEj94dlD5s4y4HuTIQhDtBLt4PEwPj\n5YUZRAu5LisOjhdljwkd3FrbTS/T5f/+pb8iYN8eY7YJAgMBAAGjggG/MIIBuzAf\nBgNVHSMEGDAWgBRn/YggFCeYxwnSJRm76VERY3VQYjAdBgNVHQ4EFgQURqiugOjE\npXEKObsutOUXMD8ucwkwGwYDVR0RBBQwEoIQZnNkZWNyeXB0LmxpdS5zZTAOBgNV\nHQ8BAf8EBAMCBaAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMGsGA1Ud\nHwRkMGIwL6AtoCuGKWh0dHA6Ly9jcmwzLmRpZ2ljZXJ0LmNvbS9URVJFTkFTU0xD\nQTMuY3JsMC+gLaArhilodHRwOi8vY3JsNC5kaWdpY2VydC5jb20vVEVSRU5BU1NM\nQ0EzLmNybDBCBgNVHSAEOzA5MDcGCWCGSAGG/WwBATAqMCgGCCsGAQUFBwIBFhxo\ndHRwczovL3d3dy5kaWdpY2VydC5jb20vQ1BTMG4GCCsGAQUFBwEBBGIwYDAkBggr\nBgEFBQcwAYYYaHR0cDovL29jc3AuZGlnaWNlcnQuY29tMDgGCCsGAQUFBzAChixo\ndHRwOi8vY2FjZXJ0cy5kaWdpY2VydC5jb20vVEVSRU5BU1NMQ0EzLmNydDAMBgNV\nHRMBAf8EAjAAMA0GCSqGSIb3DQEBCwUAA4IBAQB/beJOqNGjOrssjwprX+jSVvno\nIAv+XZgMIei0sLe4x0Ag6wp0sRG8/gchprI4cbZPPG70wDQcHIu8q/Rz4xV50FX9\nwvZPVPjdC5v9ClN48/3jL2dybydaDHR9ZyB0EcNyuNb7zoFUTbI0UcoeFaDFDRf7\nCTysvjpvVhZwfef2ACrIVhof89+ZRz24odlm1AA/bteruiEKbKP3oTr50zKlj0YZ\n0qhwXGgRPhpnpQsZ6EZjdbYYVFs0Y0z+JLt2nv8pVqKvQjBS90urSMvppeHfPNO1\nG7u2lFQuAIzdjRsBLntKNPKgiHqkOOk8w9dPs56MXnfzAjGIIu5IasvXmhTF"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Link\u00f6pings universitet (ADFS)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Link\u00f6ping University (ADFS)"
          }
        ],
        "organization_url": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.liu.se/"
          }
        ],
        "organization_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Link\u00f6ping University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://fs.liu.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://fs.liu.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFOTCCBCGgAwIBAgIQAdlHVjMUXk6RFVjqYeenpjANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMzAeFw0xNTAxMDcwMDAwMDBaFw0xODAxMTExMjAwMDBaMIGJMQswCQYDVQQG\nEwJTRTEXMBUGA1UECAwOw5ZzdGVyZ8O2dGxhbmQxEzARBgNVBAcMCkxpbmvDtnBp\nbmcxIDAeBgNVBAoMF0xpbmvDtnBpbmdzIHVuaXZlcnNpdGV0MQ8wDQYDVQQLEwZM\naVUtSVQxGTAXBgNVBAMTEGZzc2lnbmluZy5saXUuc2UwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQCS5bpEkEcbJAsNdgyK1QYAbuq5PKl8bAcujqKIRZAr\n4uixWudDxRVhwOxDyZMTZGN0vNVdf+ZtUZQ9NWYaLcgEvzxhNbsA0fmTSwRlMvxj\n0R/JbDs5Slmew11wZ6rxgX7wRv8rjB3PSdf/SVc5LKgcDuCCGCLv+OE7d4K13OfK\nBxUv/vrD7upz6lgT79OWX6udFhU8sXmP8u8P/mID83o5N32hwxymRuEmjnLiVIrU\nR4cF5EwgblrpoqQKeGKdkroZApU0EJxvtopesVgUEGXW4tkogTJ8qtSPQK8iPEet\neR6YpFCIxIbE0gpwDgo0bubt8T+FkQE71SLvbhv9RcZBAgMBAAGjggG/MIIBuzAf\nBgNVHSMEGDAWgBRn/YggFCeYxwnSJRm76VERY3VQYjAdBgNVHQ4EFgQU8vPdaPx+\nJhyN970NWqrTcbU/c0MwGwYDVR0RBBQwEoIQZnNzaWduaW5nLmxpdS5zZTAOBgNV\nHQ8BAf8EBAMCBaAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMGsGA1Ud\nHwRkMGIwL6AtoCuGKWh0dHA6Ly9jcmwzLmRpZ2ljZXJ0LmNvbS9URVJFTkFTU0xD\nQTMuY3JsMC+gLaArhilodHRwOi8vY3JsNC5kaWdpY2VydC5jb20vVEVSRU5BU1NM\nQ0EzLmNybDBCBgNVHSAEOzA5MDcGCWCGSAGG/WwBATAqMCgGCCsGAQUFBwIBFhxo\ndHRwczovL3d3dy5kaWdpY2VydC5jb20vQ1BTMG4GCCsGAQUFBwEBBGIwYDAkBggr\nBgEFBQcwAYYYaHR0cDovL29jc3AuZGlnaWNlcnQuY29tMDgGCCsGAQUFBzAChixo\ndHRwOi8vY2FjZXJ0cy5kaWdpY2VydC5jb20vVEVSRU5BU1NMQ0EzLmNydDAMBgNV\nHRMBAf8EAjAAMA0GCSqGSIb3DQEBCwUAA4IBAQCgqdZfizsQZYpLif+sV+mgkkln\n6WVGv1KVw2xvRDO9jF192qjkL9zmB081qOydPtt8aLbXQHp13M/URoFK2Vvdikq5\nWQMkGxJu3zLtQD4lJsJXAaGdm7nSwWS4NHHIf5yg0rWC5kQBJnWhAHhPedFzfgGR\n9lUohhvnLJJ/PFuvN0sCsYYpRraQT880RdTq1imsFB3wAUHjN9tQCS3Ss9Cf6MOv\nwHb3flDe4OLwxxMZfI3oGwoUJHltib7xFuT7w5hOYts3Js+BBtsSskGSp/dz8PiH\n6NDQZG/9USNN1biuUCDxrhTBgSHIAeB3h7k6wue5C30EE8SCLfZ6Xxsmk1rn"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFOTCCBCGgAwIBAgIQAnyNaDk3tSxKoRwzDMG6yjANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMzAeFw0xNTAxMDcwMDAwMDBaFw0xODAxMTExMjAwMDBaMIGJMQswCQYDVQQG\nEwJTRTEXMBUGA1UECAwOw5ZzdGVyZ8O2dGxhbmQxEzARBgNVBAcMCkxpbmvDtnBp\nbmcxIDAeBgNVBAoMF0xpbmvDtnBpbmdzIHVuaXZlcnNpdGV0MQ8wDQYDVQQLEwZM\naVUtSVQxGTAXBgNVBAMTEGZzZGVjcnlwdC5saXUuc2UwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQChPGysC8lsTi7EJHyrabNiyAW1pKBt8hDR7PiEOHWz\n/kDoxdoBftjelfewOvT+DM1t6WwQ3K2hbNDGuHmapaIuG/K491tXAZCiopcwZ4ud\nw7npBYJM3Err3sth2Yk3JtB69iN61t77hezMYyWd9yGmt5zd+DlXzzeJxNacWgkw\nW5ONAMRFCPV0VNBSk3QpxKe0V/VkhkGrwp2Jc+qVgykkUDPamyxc7cCnot1AFslS\n0WWl6LN1XllNxaqg8aYgNmRu/2w93SKPNfNEj94dlD5s4y4HuTIQhDtBLt4PEwPj\n5YUZRAu5LisOjhdljwkd3FrbTS/T5f/+pb8iYN8eY7YJAgMBAAGjggG/MIIBuzAf\nBgNVHSMEGDAWgBRn/YggFCeYxwnSJRm76VERY3VQYjAdBgNVHQ4EFgQURqiugOjE\npXEKObsutOUXMD8ucwkwGwYDVR0RBBQwEoIQZnNkZWNyeXB0LmxpdS5zZTAOBgNV\nHQ8BAf8EBAMCBaAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMGsGA1Ud\nHwRkMGIwL6AtoCuGKWh0dHA6Ly9jcmwzLmRpZ2ljZXJ0LmNvbS9URVJFTkFTU0xD\nQTMuY3JsMC+gLaArhilodHRwOi8vY3JsNC5kaWdpY2VydC5jb20vVEVSRU5BU1NM\nQ0EzLmNybDBCBgNVHSAEOzA5MDcGCWCGSAGG/WwBATAqMCgGCCsGAQUFBwIBFhxo\ndHRwczovL3d3dy5kaWdpY2VydC5jb20vQ1BTMG4GCCsGAQUFBwEBBGIwYDAkBggr\nBgEFBQcwAYYYaHR0cDovL29jc3AuZGlnaWNlcnQuY29tMDgGCCsGAQUFBzAChixo\ndHRwOi8vY2FjZXJ0cy5kaWdpY2VydC5jb20vVEVSRU5BU1NMQ0EzLmNydDAMBgNV\nHRMBAf8EAjAAMA0GCSqGSIb3DQEBCwUAA4IBAQB/beJOqNGjOrssjwprX+jSVvno\nIAv+XZgMIei0sLe4x0Ag6wp0sRG8/gchprI4cbZPPG70wDQcHIu8q/Rz4xV50FX9\nwvZPVPjdC5v9ClN48/3jL2dybydaDHR9ZyB0EcNyuNb7zoFUTbI0UcoeFaDFDRf7\nCTysvjpvVhZwfef2ACrIVhof89+ZRz24odlm1AA/bteruiEKbKP3oTr50zKlj0YZ\n0qhwXGgRPhpnpQsZ6EZjdbYYVFs0Y0z+JLt2nv8pVqKvQjBS90urSMvppeHfPNO1\nG7u2lFQuAIzdjRsBLntKNPKgiHqkOOk8w9dPs56MXnfzAjGIIu5IasvXmhTF"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://fs.liu.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://fs.liu.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://fs.liu.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://rave.sisoshibboleth.co.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Info"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Oates"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://rave.sisoshibboleth.co.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-08-20T10:08:46Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SiSo Ravensbourne Online Resource Booking"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.siso.uk.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "TechEthika Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://rave.siso.co/sso/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://rave.siso.co/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://rave.siso.co/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SiSo Ravensbourne Online Resource Booking"
                  }
                ],
                "logo": [
                  {
                    "text": "https://rave.siso.co/images/layout/siso-logo.jpg",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SiSo Ravensbourne Online Resource Booking"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAOSUhyDXVj7AMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB3Npc28uY28wHhcNMTMwMTA3MTYzMTIxWhcNMjMwMTA1MTYzMTIxWjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdzaXNvLmNvMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\txDnj9YFJVXclawo/8rs1aWYAgk6rKi8A/Cyycq0mW5yOKLLh8MUIgDeOGL7bLl7p\n\t\t\t\t\t\tMBeZM4ILlNaeJhICWm1tuLB6SYzREnXwpO7+lvx13xsRHW2TjCPGV3yUgz55vRYj\n\t\t\t\t\t\tbseFrwFHJ8IrL24UTLcpX/R//9cMkZpSqM+77Hn22dxbYvGUOQCHOQzL78AO91qz\n\t\t\t\t\t\tdUaxKzYWyWM7w2U4APP41Zvd0flyUtRZXp8W+WwlUDffFoNndsjR4L/9wuXvOcrH\n\t\t\t\t\t\t+VZtMLy60+cB9bpvVlaQVlt+1stEABdMVvuGNkJ9wIjRjP2b9OLUI76QmgwIDtdE\n\t\t\t\t\t\t5BS0Bv0Puz66L96r2MunRQIDAQABozUwMzASBgNVHREECzAJggdzaXNvLmNvMB0G\n\t\t\t\t\t\tA1UdDgQWBBRRosxNbUQXXwtWDl/kYMScRImh5TANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tgrfjza9Btcz+9WvzcjDTZ+KSrWWvrthA3zc6Q+C/MIBG8CCuxMO+uwFBnXIopGlX\n\t\t\t\t\t\tbLa/QtVLjOugsnizFxjaEFTG4jGndtPJ8+9V8Eja5RlOazuM2LT738+Um8/1Frhr\n\t\t\t\t\t\tGXa0Hdv9ZWEbIhil65fFqZNOmOteja6xxAQ9NgGG/XUnTVTbr7msihEAYTTcS40/\n\t\t\t\t\t\tGSYpT9nQwiryfSWDNJ17Zyl44389kSw+FCUsu8Ns9VSDEDWr/R+97ZMcjN6hAfJL\n\t\t\t\t\t\tdji3X1aaAC/JbnJl/v+yR1TH/sdHyObVaM7FToUGKiyjX9VpfOe64d0hjogzEr0x\n\t\t\t\t\t\tfirJubLNu96jbGctasqcpQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://rave.siso.co/sso/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://rave.siso.co/sso/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://rave.siso.co/sso/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://rave.siso.co/sso/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://rave.siso.co/sso/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://rave.siso.co/sso/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://2012.qmplus.qmul.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:its-aa@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Academic Applications"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:moodle-support@ulcc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Moodle Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:its-aa@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Academic Applications"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://2012.qmplus.qmul.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-06-30T09:22:05Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Queen Mary and Westfield College :2012 Archive service QMPlus"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qmul.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Queen Mary and Westfield College, University of London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://2012.qmplus.qmul.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://2012.qmplus.qmul.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJAKfCPp1ZOBsNMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\n\t\t\t\t\t\tBAMTFjIwMTIucW1wbHVzLnFtdWwuYWMudWswHhcNMTQwNjI1MDk1ODE3WhcNMjQw\n\t\t\t\t\t\tNjIyMDk1ODE3WjAhMR8wHQYDVQQDExYyMDEyLnFtcGx1cy5xbXVsLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtKJY1LEzeMszLBA7vIwDWTvd\n\t\t\t\t\t\ta07jaXtUFBdFyEqnwBIr91EJxyCdkHd4qGhw3riCUE5XEEaHq7YkIA1sHjzAxkv3\n\t\t\t\t\t\tbpjnI1iaP4gU4+Dwec0kJ4VkPFt4vE6TSICeA//DBrL+ZMcD8hjZDRhTxAHv9t96\n\t\t\t\t\t\tbIfsmxrlBizuS6GAAAHm3eWbzYJ6V5tf79Z9GZjMTjZtrloem4B1+UsS0Ze17CU9\n\t\t\t\t\t\tliUSJUZKT39gQN7JywnQ+DAkGe1rfQmQHdwdt1ekPnPomOBy9h6aymxgOqGHxmIK\n\t\t\t\t\t\tl2tixtmYVZYoAPlrDEZEtdU6BRUMPiJCYlz/wG+QRN75PvMjbmpNIKAyJUwAZwID\n\t\t\t\t\t\tAQABo0QwQjAhBgNVHREEGjAYghYyMDEyLnFtcGx1cy5xbXVsLmFjLnVrMB0GA1Ud\n\t\t\t\t\t\tDgQWBBS9sdhTGd7ns9eUGONqUjAaTo1ADjANBgkqhkiG9w0BAQUFAAOCAQEAKtjj\n\t\t\t\t\t\to3HiYvqfjOcaUNv0yq3i3LCTf+PobbmX5YBXDBQhYrvkuaUcfTRr6hIE86RZwMC7\n\t\t\t\t\t\t9rGV63IqTKQtpjF3odt/rSTNgRz0iEc2p+HtCdN4cBR6aSEwOyHfj8MotC8L5JO9\n\t\t\t\t\t\t3GTfasl+ZuRDEtsgZeIZv+zIjO1CDL6eE/OyyMo9bFmvOrrvGKXp01LR2VuqEy+M\n\t\t\t\t\t\ts9GzHa6yGaWQBoQaLVXMhRT3AM3y9hRh1P4GgsIS+Z0oOeW1VGEg6nDC29fXLfrN\n\t\t\t\t\t\tYWbnO44vlTi3MGoezwxe/U2v+4+rXPEJ28rVZp74FaLYsR+5OpsC5VR7moj78OWF\n\t\t\t\t\t\tuifWa1iscTfgACwOQg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://2012.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://2012.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://2012.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://2012.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://2012.qmplus.qmul.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://2012.qmplus.qmul.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.bridgeport.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sysadmin@bridgeport.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UB SysAdmin Group"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.bridgeport.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.bridgeport.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.bridgeport.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.bridgeport.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.bridgeport.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.bridgeport.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bridgeport.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Bridgeport"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAJBfTu+adrdocAWNWMrxwsQDwbgMMA0GCSqGSIb3DQEB\nCwUAMB0xGzAZBgNVBAMMEmlkcC5icmlkZ2Vwb3J0LmVkdTAeFw0xNTAyMTcxNzAy\nMDhaFw0zNTAyMTcxNzAyMDhaMB0xGzAZBgNVBAMMEmlkcC5icmlkZ2Vwb3J0LmVk\ndTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAISnvHsXiLtSfOwZmxMk\nZWpmFniFsXRUG5G5NJY2SSScW0lVGdiPHQWL8Zr9YmFiAdSyI4oCt3R5I7U+IG1l\nFYhUkPFSr8glxU41G6iFhPBdpW3DNM0dYZeIE4/3ZX4JSaYEEUDtYtL4v2V7+gho\nFXWTu0gKieH4AME2MPBhK9KKeCbK0Lb1GmotenJbytjLQ3g6iTvbxoVxdTEFQgqZ\neG63w9yxCuc7VikYO9xRSboI9cv4JikOeX0D2WmjwydJnb4qpFg06oImMqt+PdHW\nRyYlrrPj3hPHF1HZpbGtMh+yIC+L9rUDyWtRJbExSbNQpE/y17sQ4PCDHyn0H93o\n4vECAwEAAaNrMGkwHQYDVR0OBBYEFKPBWfXIDrPwfVJvMxMrrwkygF+GMEgGA1Ud\nEQRBMD+CEmlkcC5icmlkZ2Vwb3J0LmVkdYYpaHR0cHM6Ly9pZHAuYnJpZGdlcG9y\ndC5lZHUvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAFuGe9J4DqlY\n9jdvpul5xzjlGqDJYh5ieLmDQKd/6El74jknxzBe68Mk2e1kqHtzvtFVWFPn2EES\nnD5P3xQ6Pxgy2TIZtiBRbbajkyVUF7keKjVDP9iUFbW8189wCjgLVtfOhAEnh7eX\nOU6Gs/5IQM4ji4XL9OH9GMTX2JWWPNBgmFgEhSOtQUAglVvVcfBZPNTwuVeF5y/q\nrYyOmoL9mXRqzHMl05ZcI8fUZlT+E/yVPIvs973WwsG5ucJhtRJo1MCDTJvjWw2e\n4b4d7MXdduNZ9DTkP+xKvxcR0/7njMmhDx+2Ziy6RAXD2NPOPoK7qZU0b2RFkGj2\nJe/ZCyY6zCI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Bridgeport"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://bridgeport.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Bridgeport"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://nacho.adm.gu.se/shibboleth",
    {
      "entity_id": "https://nacho.adm.gu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nacho.adm.gu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nacho.adm.gu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nacho.adm.gu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nacho.adm.gu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nacho.adm.gu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://nacho.adm.gu.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "nacho-pc"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3zCCAcegAwIBAgIJANjsPUfkRN00MA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\nBAMTCG5hY2hvLXBjMB4XDTEwMDQxMzEzMzI1OVoXDTIwMDQxMDEzMzI1OVowEzER\nMA8GA1UEAxMIbmFjaG8tcGMwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQC99pEipkOSaRwbIYY/dfFIR2/COahYi+fU3qDpCmG6JbZzO3O9ybjF/sUmt1fA\nUnq+1HinEwSGDfizUoN+/NUcAG4N8juD+UL9bbYEcfx7Ly7jlGiZa3Fr3zFqxXGQ\nw+vAtnk4tKtt0kNKPXNs9oApEzGpUAj12EQBRMiKLhFPqNMo8YQ+OUqCyZMYm2Oc\nuJFj9QBN3vLCRFJJZCt7kmpfnC9M4KdMFvhzbDMixrk4qdjuUB0W7bRAiHk0Yupw\nQUZMk0kF4AJrWFliUIsNVIm3q4I0AOlAgbii5rsarDjGaRlE421K6TZxwx+0UfnQ\nG3pn+xmBV7purr0y6VmQOaZvAgMBAAGjNjA0MBMGA1UdEQQMMAqCCG5hY2hvLXBj\nMB0GA1UdDgQWBBQAzw+GSXwuDMhAaUP+M9D28G8yNDANBgkqhkiG9w0BAQUFAAOC\nAQEAKmp+HbJKFXb+NEPdktE8Y+PKV9YWsPpBKCxSHxDkgFSXLnCjxr6RpPYPvgqY\noHjkqzea//qZ4oqVRjOBauGqZ1u+PBYEwsZGSL6v2/AMjM51D1VOvMJz3Rt63ee1\n+oIZbU7teIK3n5BpSjHhScglXf2psZEEmQ5FGTLMUvq1Ri5bMJjmVNNyQH0Cm1WM\nIGGsITC3/oso3+KzpqcWISIqCeBFfYZ4mh/PIOoZEpYSN9jkMBHtlcc9mcR6aQX3\n0KtgoDtLnJA0Xw9ubL3YhxZLOdWTswHGr4AoplV09zQkNG87GIfVDAtzmZHLlP6S\ns0eg2zS0HU2kmUbaL6tbYB5jyw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=nacho-pc"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "nacho-pc"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3zCCAcegAwIBAgIJANjsPUfkRN00MA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\nBAMTCG5hY2hvLXBjMB4XDTEwMDQxMzEzMzI1OVoXDTIwMDQxMDEzMzI1OVowEzER\nMA8GA1UEAxMIbmFjaG8tcGMwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQC99pEipkOSaRwbIYY/dfFIR2/COahYi+fU3qDpCmG6JbZzO3O9ybjF/sUmt1fA\nUnq+1HinEwSGDfizUoN+/NUcAG4N8juD+UL9bbYEcfx7Ly7jlGiZa3Fr3zFqxXGQ\nw+vAtnk4tKtt0kNKPXNs9oApEzGpUAj12EQBRMiKLhFPqNMo8YQ+OUqCyZMYm2Oc\nuJFj9QBN3vLCRFJJZCt7kmpfnC9M4KdMFvhzbDMixrk4qdjuUB0W7bRAiHk0Yupw\nQUZMk0kF4AJrWFliUIsNVIm3q4I0AOlAgbii5rsarDjGaRlE421K6TZxwx+0UfnQ\nG3pn+xmBV7purr0y6VmQOaZvAgMBAAGjNjA0MBMGA1UdEQQMMAqCCG5hY2hvLXBj\nMB0GA1UdDgQWBBQAzw+GSXwuDMhAaUP+M9D28G8yNDANBgkqhkiG9w0BAQUFAAOC\nAQEAKmp+HbJKFXb+NEPdktE8Y+PKV9YWsPpBKCxSHxDkgFSXLnCjxr6RpPYPvgqY\noHjkqzea//qZ4oqVRjOBauGqZ1u+PBYEwsZGSL6v2/AMjM51D1VOvMJz3Rt63ee1\n+oIZbU7teIK3n5BpSjHhScglXf2psZEEmQ5FGTLMUvq1Ri5bMJjmVNNyQH0Cm1WM\nIGGsITC3/oso3+KzpqcWISIqCeBFfYZ4mh/PIOoZEpYSN9jkMBHtlcc9mcR6aQX3\n0KtgoDtLnJA0Xw9ubL3YhxZLOdWTswHGr4AoplV09zQkNG87GIfVDAtzmZHLlP6S\ns0eg2zS0HU2kmUbaL6tbYB5jyw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=nacho-pc"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nacho.adm.gu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nacho.adm.gu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nacho.adm.gu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nacho.adm.gu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nacho.adm.gu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://nacho.adm.gu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nacho.adm.gu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://nacho.adm.gu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://nacho.adm.gu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://nacho.adm.gu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://test-secure.nature.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ollier"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:j.ollier@nature.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ollier"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:j.ollier@nature.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test-secure.nature.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Nature Publishing Group (test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nature.com/npg_/company_info/index.html"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Macmillan Publishers Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYTCCAkmgAwIBAgIEEtvGRDANBgkqhkiG9w0BAQsFADBhMQswCQYDVQQGEwJV\n\t\t\t\t\t\tSzEPMA0GA1UEBxMGTG9uZG9uMRIwEAYDVQQKEwlNYWNtaWxsYW4xDDAKBgNVBAsT\n\t\t\t\t\t\tA05QRzEfMB0GA1UEAxMWdGVzdC1zZWN1cmUubmF0dXJlLmNvbTAeFw0xNTAzMTMw\n\t\t\t\t\t\tNDMwMDNaFw0yNTAzMTAwNDMwMDNaMGExCzAJBgNVBAYTAlVLMQ8wDQYDVQQHEwZM\n\t\t\t\t\t\tb25kb24xEjAQBgNVBAoTCU1hY21pbGxhbjEMMAoGA1UECxMDTlBHMR8wHQYDVQQD\n\t\t\t\t\t\tExZ0ZXN0LXNlY3VyZS5uYXR1cmUuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\n\t\t\t\t\t\tMIIBCgKCAQEAypds9PRwonxwlhtZHpjlmr/eIbF5UeEkXn3FU6FrjxOGJIlbqrI5\n\t\t\t\t\t\t1UCMhNAQ/YDI1BKCu/865DTWy5qezeWDbJ5QybVHlfSqpnLu6OxufrBb0oQEEzGD\n\t\t\t\t\t\tdM6BjMrPNagW4h8o8JwXC3vE0AIcmlrGWSl/a1jUXBag3tPm+6c8qr44gf9YyYcb\n\t\t\t\t\t\tQnrIApdojwC3pxJpekz2k+wYDo52/meiFlQK6OYVTk/OlYIM31o+bLIW7nucrPl3\n\t\t\t\t\t\tTJz9+Bmyenvh4qzZbqycmpQYL62z0cp5oa9SrupPVk8MWi1Xr8cxvu5TBbZZCbtR\n\t\t\t\t\t\tuwRu3LmyvQVQejuR5VzHGJII2ktGQQwX6QIDAQABoyEwHzAdBgNVHQ4EFgQUHBsn\n\t\t\t\t\t\tw1SEAY+N9dCCaqIDtBQpgIowDQYJKoZIhvcNAQELBQADggEBABCYwuoU2vsW0hk6\n\t\t\t\t\t\tle8Ho83OQ8EAZTI5yGCcDecuQUru0MZJo3KfZbDpKKHrW7mpDpq9kLeu/MSKA/fg\n\t\t\t\t\t\tp+eodmkQOZRdVUUw6EU0cfW34iUyHl+HbZjbqsToZfsH+VTSmTpMgtl0USpP5nzC\n\t\t\t\t\t\tKe6J0nxG735cQN08JRACzZsETdMfvAuf8Oxl61yKpVNwDWMpsysJfu86VNL/MfGo\n\t\t\t\t\t\tkX13GFA7+EqYZaZEPXZXjq4EKhwMQfZDabw3ENuijJ4JAq2n4ikVmLRBCkqElxuA\n\t\t\t\t\t\tfnksTUIwbxyHGAEh+bqqgcm1tQi/auufi2bQHPQ77DJSGuVzUgz/qbZU8CJ7uATR\n\t\t\t\t\t\twsW5loM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://test-secure.nature.com/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://test-secure.nature.com/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test-secure.nature.com/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test-secure.nature.com/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.epfl.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "EPFL Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@epfl.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAI"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "EPFL Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@epfl.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAI"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.epfl.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2016-04-11T12:36:00Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAM2y4eON2PnqMA0GCSqGSIb3DQEBCwUAMBYxFDASBgNV\nBAMTC2lkcC5lcGZsLmNoMB4XDTE2MDMyOTEzMzQzM1oXDTE5MDMyOTEzMzQzM1ow\nFjEUMBIGA1UEAxMLaWRwLmVwZmwuY2gwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQDD7LOez3zrlr+A6IpY1G9Qp5VIA++bAUEe+zZMu7HbkISrqPLAqFWb\nO5cF1vgqfQQKmGYfeITgI2HxeizfXWtF662vI1K18yDX73K+tl0zCy7jmvCKqmeF\ngi31OSbHk2bZR2F9HUwGGkcenidhMKn+kDrEypxelzUjhFUqfw6s7lmxUogOoDdf\nxEQaYKfsCiOIsecI6JJ7VUgm0M3dAqXMmMs3B5K3O4QIjLaFsIRb+joCANL9TUz9\nHFwUZmaR69s5zreWi/FVQF/mMEDeMXTfzyClu692FpWQ7fJns6quoaavSyOBGcOY\nma8NtVkmkxgO8JjtlwIDqwAWkH8ML6aRAgMBAAGjXTBbMDoGA1UdEQQzMDGCC2lk\ncC5lcGZsLmNohiJodHRwczovL2lkcC5lcGZsLmNoL2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBRe/zKjyhGnk+X89C9ynWEPakNhJjANBgkqhkiG9w0BAQsFAAOCAQEA\nidtG/yOJo1kQVkWxFdD1mO6AY8JbTuJCwbxHUKsWFuyvk/rN74TI1SmYKmt01v7G\nZnRnrxEiP8nm0+tMZC8GMoBe65XTpa1L6jVD2xK2gVc1R/8GviL5/wfYa652uUCB\niduzNGuKgsRUqOIXCdRZpnSTazvnKvSE1pwWWbWqvK64IjdZPPc0JLpUx2z1z2YP\nCH9vvkQUa54Z82a+lRLl/JXSGApYETFxBD/mxuL6DyhhcZ/eMniejll/iBZMs2TQ\nq4Uf4QOFWwomWhTzbJ9RoW5PqxmujfI4twlL0SAifiRur90Wd2+wm2QT5LHgEaLL\npTA8OOnOcAQgmsJXODtWzw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "epfl.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.epfl.ch:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.epfl.ch:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.epfl.ch/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.epfl.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.epfl.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.epfl.ch/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.epfl.ch:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.epfl.ch:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "epfl.ch"
              },
              {
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Eidgen\u00f6ssische Technische Hochschule Lausanne"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Swiss Federal Institute of Technology Lausanne"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ecole Polytechnique F\u00e9d\u00e9rale de Lausanne"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAe0lEQVQ4Ed2QUQqAMAxDq3j/K08ymhDKnGz4pSBLu/SRLuJXX8ttcPL3Bb1Hb5w2dJibWsa8Y19WAtQw4eYKkg0AXLpZl0UMPbMEZX5czgCPsR1FAMw+QI3Y1Dx9Pq6s6n5vtSBMoMaq+ATge64E6G+ym4Bv1AjYSdEhN3OaFRR7lkw7AAAAAElFTkSuQmCC",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EPFL - EPF Lausanne"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EPFL - EPF Lausanne"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EPFL - EPF Lausanne"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "epfl.ch"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:46.520515,6.565576"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:620:618::/48"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.28.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.28.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "128.178.0.0/15"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.29.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "128.178.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.30.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "128.179.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.31.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.32.0/20"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.32.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.33.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.34.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.35.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.36.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.37.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.38.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.39.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.40.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.41.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.42.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.43.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.44.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.46.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.26.47.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.192.0/20"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.208.0/22"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "error_url": "http://support-it.epfl.ch/",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAM2y4eON2PnqMA0GCSqGSIb3DQEBCwUAMBYxFDASBgNV\nBAMTC2lkcC5lcGZsLmNoMB4XDTE2MDMyOTEzMzQzM1oXDTE5MDMyOTEzMzQzM1ow\nFjEUMBIGA1UEAxMLaWRwLmVwZmwuY2gwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQDD7LOez3zrlr+A6IpY1G9Qp5VIA++bAUEe+zZMu7HbkISrqPLAqFWb\nO5cF1vgqfQQKmGYfeITgI2HxeizfXWtF662vI1K18yDX73K+tl0zCy7jmvCKqmeF\ngi31OSbHk2bZR2F9HUwGGkcenidhMKn+kDrEypxelzUjhFUqfw6s7lmxUogOoDdf\nxEQaYKfsCiOIsecI6JJ7VUgm0M3dAqXMmMs3B5K3O4QIjLaFsIRb+joCANL9TUz9\nHFwUZmaR69s5zreWi/FVQF/mMEDeMXTfzyClu692FpWQ7fJns6quoaavSyOBGcOY\nma8NtVkmkxgO8JjtlwIDqwAWkH8ML6aRAgMBAAGjXTBbMDoGA1UdEQQzMDGCC2lk\ncC5lcGZsLmNohiJodHRwczovL2lkcC5lcGZsLmNoL2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBRe/zKjyhGnk+X89C9ynWEPakNhJjANBgkqhkiG9w0BAQsFAAOCAQEA\nidtG/yOJo1kQVkWxFdD1mO6AY8JbTuJCwbxHUKsWFuyvk/rN74TI1SmYKmt01v7G\nZnRnrxEiP8nm0+tMZC8GMoBe65XTpa1L6jVD2xK2gVc1R/8GviL5/wfYa652uUCB\niduzNGuKgsRUqOIXCdRZpnSTazvnKvSE1pwWWbWqvK64IjdZPPc0JLpUx2z1z2YP\nCH9vvkQUa54Z82a+lRLl/JXSGApYETFxBD/mxuL6DyhhcZ/eMniejll/iBZMs2TQ\nq4Uf4QOFWwomWhTzbJ9RoW5PqxmujfI4twlL0SAifiRur90Wd2+wm2QT5LHgEaLL\npTA8OOnOcAQgmsJXODtWzw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EPFL - EPF Lausanne"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EPFL - EPF Lausanne"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EPFL - EPF Lausanne"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.epfl.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.epfl.ch/"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.epfl.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "epfl.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://vm-jorum.ds.man.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ryan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Benjamin.ryan@manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ben"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ryan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Benjamin.ryan@manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ben"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://vm-jorum.ds.man.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-06-08T09:08:36Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The University of Manchester: Jorum Staging Server"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jorum.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Manchester"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vm-jorum.ds.man.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://staging.resourceshare.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://webstaging.jorum.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "3"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Through Jorum, you can find and share open learning and teaching resources."
                  }
                ],
                "logo": [
                  {
                    "text": "https://census.mimas.ac.uk/jorum_logo_blue20mm.gif",
                    "height": "236",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "236"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The University of Manchester: Jorum Staging Server"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vm-jorum.ds.man.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://staging.resourceshare.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://webstaging.jorum.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://vm-jorum.ds.man.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://staging.resourceshare.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://webstaging.jorum.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLTCCAhWgAwIBAgIJALvdFCXrleHwMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\n\t\t\t\t\t\tBAMTFHNoaWJ0ZXN0LmpvcnVtLmFjLnVrMB4XDTEyMTIxMjEyNTEyMFoXDTE3MTIx\n\t\t\t\t\t\tMTEyNTEyMFowHzEdMBsGA1UEAxMUc2hpYnRlc3Quam9ydW0uYWMudWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC4A9nXwKbBwc2kBco7STxNshEWvwDU\n\t\t\t\t\t\tKo9gyYVeny7EBti3FnyexaKdx5kSDOM0JLHO+gQKx/GVl0ZMqelZxnBqKsPN62d5\n\t\t\t\t\t\tKSj2OsDPzlvYiyBHZybhyUKnjkOXB8/6Ndffu7wea1vTtSZPoNRjtQEDVCX7Qltd\n\t\t\t\t\t\tmniATHBHsgLgbQX9WxxM27qC8+pw9G/a0Z+X3UZQBpsIJZE4EnY/oOOP3jbYlOSY\n\t\t\t\t\t\t8hdAEKws3B8zd4R4/4fRkLqapi1h1qbTYRS+zozwdTr/yU7BeL4Av61thl3mMdhL\n\t\t\t\t\t\twolSWbwmZUTYmr3oEnajjQr2wCk0X4cuA4OchGIYAN+p5qkwap6Qigv/AgMBAAGj\n\t\t\t\t\t\tbDBqMEkGA1UdEQRCMECCFHNoaWJ0ZXN0LmpvcnVtLmFjLnVrhihodHRwczovL3Zt\n\t\t\t\t\t\tLWpvcnVtLmRzLm1hbi5hYy51ay9zaGliYm9sZXRoMB0GA1UdDgQWBBQRO5UtVirW\n\t\t\t\t\t\tXHM8XRY62cJN2fv9jDANBgkqhkiG9w0BAQUFAAOCAQEAVKfQ1b09D/qMa0bm1dRY\n\t\t\t\t\t\tvnKo9sJb55b2HsORAnrBGatOA+/3UvJB2RHRpGZxIXxqQAkTxch1K2GsOfnEKvz/\n\t\t\t\t\t\ttVxZbxWasiVe184HZaYjvudaf7RneW+2MVq+OugsXH+kVXtXPZd189ZO0XmhFTZX\n\t\t\t\t\t\tjZy2DqL9aG3qvGX7/yX1uLEzltywMo0ba+imB4klXQgD0ZEH8qBaHcPjKaWSSAS/\n\t\t\t\t\t\tizsVtVnLjEyZ91V2gHyMMKDm6y2eoZTQOisMfhf+ef6rjMIhwBxLNtf0GbsQc2BG\n\t\t\t\t\t\tIGN531pXBsZhIwlrO13Z5laL4pqG9NDuYWeETHWNpRYRXp8TDLugPCQbkRMGf+wq\n\t\t\t\t\t\tJw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vm-jorum.ds.man.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vm-jorum.ds.man.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vm-jorum.ds.man.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vm-jorum.ds.man.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vm-jorum.ds.man.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vm-jorum.ds.man.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://staging.resourceshare.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://staging.resourceshare.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://staging.resourceshare.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://staging.resourceshare.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://staging.resourceshare.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://staging.resourceshare.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webstaging.jorum.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://webstaging.jorum.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://webstaging.jorum.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://webstaging.jorum.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://webstaging.jorum.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://webstaging.jorum.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "18"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.renata.edu.co/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hernan Garcia"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "elcira@renata.edu.co"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Javier Enrique Lizarazo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tecnico@renata.edu.co"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.renata.edu.co/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "es",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://colfire.co/Politica_IdP.pdf"
              }
            ],
            "registration_instant": "2014-01-01T00:00:00Z",
            "registration_authority": "http://colfire.co",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIG3jCCBcagAwIBAgIQA7a3wqJ79UaLPv5KuUFPwzANBgkqhkiG9w0BAQsFADBN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\nFtZcGPmpg9fHry1cbwDW0660J/yOZsUbhNuUu5xv06SOqA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.co"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.renata.edu.co:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.renata.edu.co:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.renata.edu.co/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.renata.edu.co/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.renata.edu.co:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.renata.edu.co/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.renata.edu.co/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.renata.edu.co/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.renata.edu.co/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.renata.edu.co:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.renata.edu.co:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.co"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.renata.edu.co"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.renata.edu.co"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "RENATA - Red Nacional Academica de Tecnologia Avanzada"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "RENATA - Red Nacional Academica de Tecnologia Avanzada"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RENATA - Red Nacional Academica de Tecnologia Avanzada"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RENATA - Red Nacional Academica de Tecnologia Avanzada"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIG3jCCBcagAwIBAgIQA7a3wqJ79UaLPv5KuUFPwzANBgkqhkiG9w0BAQsFADBN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\nFtZcGPmpg9fHry1cbwDW0660J/yOZsUbhNuUu5xv06SOqA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RENATA - Red Nacional Acad\u00e9mica de Tecnolog\u00eda Avanzada"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RENATA - Red Nacional Acad\u00e9mica de Tecnolog\u00eda Avanzada"
          }
        ],
        "organization_url": [
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.renata.edu.co"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.renata.edu.co"
          }
        ],
        "organization_name": [
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RENATA - Red Nacional Acad\u00e9mica de Tecnolog\u00eda Avanzada"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RENATA - Red Nacional Acad\u00e9mica de Tecnolog\u00eda Avanzada"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://daisy2.dsv.su.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Olofsson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pelle@dsv.su.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Per"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://daisy2.dsv.su.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://daisy2.dsv.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://daisy2.dsv.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://daisy2.dsv.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://daisy2.dsv.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://daisy2.dsv.su.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://daisy2.dsv.su.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://daisy2.dsv.su.se/Shibboleth.sso/Login/SU",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://daisy2.dsv.su.se/Shibboleth.sso/DS/DSV",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://daisy2.dsv.su.se/Shibboleth.sso/DS/DSV",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://daisy2.dsv.su.se/Shibboleth.sso/DS/SU",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://daisy2.dsv.su.se/Shibboleth.sso/DS/SU",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://daisy2.dsv.su.se/Shibboleth.sso/DS/SWAMID",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://daisy2.dsv.su.se/Shibboleth.sso/DS/SWAMID",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt system f\u00f6r data- och systemvetenskap vid Stockholms universitet och ICT-skolan vid KTH."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administrative system for education used by the Department of Computer and Systems Sciences (DSV) at Stockholm University and the School of Information and Communication Technology (ICT) at KTH."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Daisy testservern"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Daisy test server"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "bart.dsv.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJALjx35GfDy2+MA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDmJhcnQuZHN2LnN1LnNlMB4XDTE0MDYwMzA5MDAwN1oXDTI0MDUzMTA5MDAw\nN1owGTEXMBUGA1UEAxMOYmFydC5kc3Yuc3Uuc2UwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDDH72IoX3FN1q8C/wi/nBGI7JPqYhqfCPRgIMyhbUc91mm\nE9TmCDpLlph5AUmrnWZePnCVDPdmMNeXk9q6AUAJ7Fb8+ncqlC7b9eK0htyVgKim\nhMcUYIYhAqVh0i0bEPJPlVz9C/ZWPKSCXalzbazlzB2T4Oe8dPIZUwqsqrxq2y/t\nyuo2g5S/c+lQaoQNcmpIqOhij1PkzfqDqJkjKrAPB8jZ4LevI0eaqD/ph7qScKoT\nNld5qC1aOkl6m3IUPlSOYzmYuMAf05ZqWxl7WQSEMUCl3z0/GwaabJoixBG0Nzeo\n0z7Qa+xvovUDOLIbLPkaxuNlnLUA4ZVAfI4b8e0RAgMBAAGjPDA6MBkGA1UdEQQS\nMBCCDmJhcnQuZHN2LnN1LnNlMB0GA1UdDgQWBBS354c+HiRqrQIeJlT8Rd8W8GKx\nsjANBgkqhkiG9w0BAQUFAAOCAQEANBuBABm9/fJISdj+lPJzqG8XEwm9gQezZk/w\nGOKfFIZ2S/U/L1YbzRQlVE9P0ftArETqVTaIwBTK4NL6FYIuAhi2eoUit4V1dYOl\nUfNTFCu4UR07pmatB5T6ndcPJBPt2opBQLETpnP7f4TGLGc3r6zKDpdFHp2cs13R\nP7IQEHTAW2zgQXXuycIIeYwBEKeA0x5rJxu7nU6l+7X2Ee0UTX7pKK09pdkYZuj+\ncqQUpkIYPZGrZ0QgxPAAtyTiVDflXrL7i7CQ0ZJL2z4HP6a4qexoy7txCYPZtHf5\nz5YBnMaQJe+rBcMSFlxo5Iw8sVICkj3tKC9gROCAXNqi0/w1RA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=bart.dsv.su.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://daisy2.dsv.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://daisy2.dsv.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://daisy2.dsv.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://daisy2.dsv.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://daisy2.dsv.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://daisy2.dsv.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://daisy2.dsv.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://daisy2.dsv.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://daisy2.dsv.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp2.rfh-koeln.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Beckhausen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:beckhausen@rfh-koeln.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Volker"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "RZSERVICE"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rzservice@rfh-koeln.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "RZSERVICE"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp2.rfh-koeln.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-06-26T13:51:54Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp2.rfh-koeln.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIHJTCCBg2gAwIBAgIHGaorpPBPojANBgkqhkiG9w0BAQsFADCBuzELMAkGA1UE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\nmZ/qmmwB8wRz"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp2.rfh-koeln.de,OU=Rechenzentrum,O=Rheinische Fachhochschule Koeln gGmbH,L=Koeln,ST=Nordrhein-Westfalen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rfh-koeln.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.rfh-koeln.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.rfh-koeln.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2.rfh-koeln.de/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.rfh-koeln.de/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.rfh-koeln.de:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp2.rfh-koeln.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.rfh-koeln.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp2.rfh-koeln.de/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2.rfh-koeln.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.rfh-koeln.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.rfh-koeln.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rfh-koeln.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.rfh-koeln.de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.rfh-koeln.de/index_eng.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rheinische Fachhochschule K\u00f6ln gGmbH"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rheinische Fachhochschule K\u00f6ln gGmbH"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider der RFH K\u00f6ln"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Rheinische Fachhochschule K\u00f6ln gGmbH, University of Applied Sciences, Sibboleth-Identity Provider"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp2.rfh-koeln.de/rfh-logo_shib_klein.gif",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp2.rfh-koeln.de/logo-64x150px.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.rfh-koeln.de/impressum/index_ger.html"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.rfh-koeln.de/imprint/index_eng.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp2.rfh-koeln.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIHJTCCBg2gAwIBAgIHGaorpPBPojANBgkqhkiG9w0BAQsFADCBuzELMAkGA1UE\nBhMCREUxHDAaBgNVBAgTE05vcmRyaGVpbi1XZXN0ZmFsZW4xDjAMBgNVBAcTBUtv\nZWxuMS4wLAYDVQQKEyVSaGVpbmlzY2hlIEZhY2hob2Noc2NodWxlIEtvZWxuIGdH\nbWJIMRYwFAYDVQQLEw1SZWNoZW56ZW50cnVtMRUwEwYDVQQDEwxSRkggS29lbG4g\nQ0ExHzAdBgkqhkiG9w0BCQEWEHBraUByZmgta29lbG4uZGUwHhcNMTUwNjI0MTMx\nODEzWhcNMTgwOTIwMTMxODEzWjCBnzELMAkGA1UEBhMCREUxHDAaBgNVBAgME05v\ncmRyaGVpbi1XZXN0ZmFsZW4xDjAMBgNVBAcMBUtvZWxuMS4wLAYDVQQKDCVSaGVp\nbmlzY2hlIEZhY2hob2Noc2NodWxlIEtvZWxuIGdHbWJIMRYwFAYDVQQLDA1SZWNo\nZW56ZW50cnVtMRowGAYDVQQDDBFpZHAyLnJmaC1rb2Vsbi5kZTCCAiIwDQYJKoZI\nhvcNAQEBBQADggIPADCCAgoCggIBAMd4FiJgA3//s13pX0vq13lLd+t91MCueeUI\n5Z+TAB7EaZK6DrQXqdeFKULkXcPjnIU1y+DEyUHYujIdUJgbq/xgWAUEIK3uHO3e\ngDd6psc08hIg7TkXB9OPL1F1hChURaxuYPgexuxcsBr3Ou+U4/tLI4vgmjHM8nzY\nTcPHksJbQSqfCuBX1IRJzdc7iX+kaud2GWqxg2a0LZpZxMf3hasYGX1zDNkxMkr8\ncBf2hwu9oVSImH/gU6bfBHCIlLSRONi1A/K2TGQe8EYyEDL1GtCM7MUj7o7OIEqq\npH2IibPXHQjFt/bh6iFpseZjS8HwUGZE04m5FZ+G3/ECFdq6DPkTxCV0rNasCLqM\ndKVQPsJl/M8pWrOrVoWpMiKErOVjZH+bH/XecJP/CtcrmEL7L4F6ZQaqoOxwOeBc\npXsEfdaMBauoQpRsRxCHYcfebprR30bpOfxOlebbN7K8p/Pv/5SASY6ocuNtJElz\ncDQ/pxT7R6iEE+BbNH4h5CAEk4oc1AsXoBWdUUdY0hc5NHrnfuUDtzJDJfocG06B\nt46IXppa3QWGC8cJK8JWTjKr1xHrfGnrYPfg1f9DlqWPCro5HsClVvJfP3BIT+oz\nMeOVjaEeimJBpDBO7BR+52Ax1iqllPz8pSsX+Bik4ZLjBGVd2Dfp049m1QUEyHA4\nzaz+xs+bAgMBAAGjggJGMIICQjBPBgNVHSAESDBGMBEGDysGAQQBga0hgiwBAQQD\nAzARBg8rBgEEAYGtIYIsAgEEAwEwDwYNKwYBBAGBrSGCLAEBBDANBgsrBgEEAYGt\nIYIsHjAJBgNVHRMEAjAAMAsGA1UdDwQEAwIF4DAdBgNVHSUEFjAUBggrBgEFBQcD\nAgYIKwYBBQUHAwEwHQYDVR0OBBYEFFPwyjZagygVUiGYVVxy3+QI3TfSMB8GA1Ud\nIwQYMBaAFDEjMbZNNf9hivJNXA+Jny9LdmtGMBwGA1UdEQQVMBOCEWlkcDIucmZo\nLWtvZWxuLmRlMIGDBgNVHR8EfDB6MDugOaA3hjVodHRwOi8vY2RwMS5wY2EuZGZu\nLmRlL3JmaC1rb2Vsbi1jYS9wdWIvY3JsL2NhY3JsLmNybDA7oDmgN4Y1aHR0cDov\nL2NkcDIucGNhLmRmbi5kZS9yZmgta29lbG4tY2EvcHViL2NybC9jYWNybC5jcmww\ngdMGCCsGAQUFBwEBBIHGMIHDMDMGCCsGAQUFBzABhidodHRwOi8vb2NzcC5wY2Eu\nZGZuLmRlL09DU1AtU2VydmVyL09DU1AwRQYIKwYBBQUHMAKGOWh0dHA6Ly9jZHAx\nLnBjYS5kZm4uZGUvcmZoLWtvZWxuLWNhL3B1Yi9jYWNlcnQvY2FjZXJ0LmNydDBF\nBggrBgEFBQcwAoY5aHR0cDovL2NkcDIucGNhLmRmbi5kZS9yZmgta29lbG4tY2Ev\ncHViL2NhY2VydC9jYWNlcnQuY3J0MA0GCSqGSIb3DQEBCwUAA4IBAQCjnjXKGnVP\nhd3Do1HsnPZTwRQ+SmrYoZOjT8rDtmCl1XWgcMMxkZrL7GZoBniBT0/D53LZj8l5\n/4DEH8BRDDEFk8lJxeW7STGC62Wq5KCzCDHzh/Tg3uapyn8+Spa/ozZ2tHVQNL5m\nW1hmLJHYykwITjVpUQRrQHMIterNiWVLPUiJW6lZaEmUPHlIM4hbb5b/4rxySrCk\nRSyaXcHkY/vFUfPyc77H5RnGnKi+PCoFzTEOMWPqfs5IrSe2qLYXmoY1xgFaZa8u\nWfCA0DKwsEbCD5XXjPzmUaAUSUf1iAEh16iZ8+QNLhyDq4dqjVaLYkFu1JlhKiU3\nmZ/qmmwB8wRz"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp2.rfh-koeln.de,OU=Rechenzentrum,O=Rheinische Fachhochschule Koeln gGmbH,L=Koeln,ST=Nordrhein-Westfalen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Rheinische Fachhochschule K\u00f6ln gGmbH"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Rheinische Fachhochschule K\u00f6ln gGmbH"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rfh-koeln.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rfh-koeln.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e336"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e336"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://giasso.univr.it/idp/idem",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sistemi@ateneo.univr.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://giasso.univr.it/idp/idem",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2016-03-18T13:41:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://giasso.univr.it:443/opensso/IDPSloRedirect/metaAlias/idem/idp1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://giasso.univr.it:443/opensso/IDPSloPOST/metaAlias/idem/idp1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://giasso.univr.it:443/opensso/IDPSloSoap/metaAlias/idem/idp1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://giasso.univr.it:443/opensso/SSORedirect/metaAlias/idem/idp1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://giasso.univr.it:443/opensso/SSOPOST/metaAlias/idem/idp1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://giasso.univr.it:443/opensso/SSOSoap/metaAlias/idem/idp1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://giasso.univr.it:443/opensso/ArtifactResolver/metaAlias/idem/idp1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univr.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univr.it/main?ent=servizioaol&serv=285&lang=en"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univr.it/main?ent=servizioaol&serv=285&lang=it"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Verona (nuovo)"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universita' di Verona (nuovo)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for University of Verona users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider per gli utenti della Universita' di Verona"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.univr.it/image/logo-univr.png",
                    "lang": "it",
                    "height": "75",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "310"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.univr.it/main?ent=servizioaol&serv=285&lang=en"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.univr.it/main?ent=servizioaol&serv=285&lang=it"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID7jCCAtagAwIBAgIEVuvfvTANBgkqhkiG9w0BAQUFADCBuDELMAkGA1UEBhMC\nSVQxDzANBgNVBAgTBlZlcm9uYTEPMA0GA1UEBxMGVmVyb25hMSowKAYDVQQKEyFV\nbml2ZXJzaXRhJyBkZWdsaSBTdHVkaSBkaSBWZXJvbmExOTA3BgNVBAsTMERpcmV6\naW9uZSBPcmdhbml6emF6aW9uZSBkZWwgU2lzdGVtYSBJbmZvcm1hdGl2bzEgMB4G\nA1UEAxMXSWRlbnRpdHkgUHJvdmlkZXIgVU5JVlIwHhcNMTYwMzE4MTEwMDEzWhcN\nNDYwMzE4MTEwMDEzWjCBuDELMAkGA1UEBhMCSVQxDzANBgNVBAgTBlZlcm9uYTEP\nMA0GA1UEBxMGVmVyb25hMSowKAYDVQQKEyFVbml2ZXJzaXRhJyBkZWdsaSBTdHVk\naSBkaSBWZXJvbmExOTA3BgNVBAsTMERpcmV6aW9uZSBPcmdhbml6emF6aW9uZSBk\nZWwgU2lzdGVtYSBJbmZvcm1hdGl2bzEgMB4GA1UEAxMXSWRlbnRpdHkgUHJvdmlk\nZXIgVU5JVlIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCtZWj2R7kv\n66hq2T0+wtkVFgeF9s33KE3ecKuVxzY9PWWKdV6BMrlVBgp7NkgdDZZeDmnD04pG\nBVnw8v8FOu427IBTpAQVV4cjS2ScxrnXqBv4+u4KRVy2Nhggg3W5FZmwfRhUf9k+\ndXQKa6oOprNhZefHnWItVzNKJVmmZsPwyvfpVqbvB1YWmSe0MLYo4MKb8nUgAoVq\nB93DtKkQ3uios+eLgrXlVtPFvU5smo9PKyc7NEFPm/AZESB+qCcePd9zOsVoE7wP\nDxO1ErF5/9F0llYHK0H14xK/Q5He/fu3479ylA2dIE0oztUBbnN+c8hSDRFjj2dy\n51tH92DlgMJLAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBACFPbHOcvYIkvDAoZ49e\nQFrFy15v8Yz5J+/OjszZJ6EPlKiVXwGjW0ICPlTJdsnJBDZyM2kH30dYe2Vqf/yB\ny6e7fXpVu/1zSmxY6ycYqe/qbZoMtYvnB2s2fJHcI46Hj1pWWf2b9ANPj7Mi4chE\nzmO5TSw3h3+HFC7hOz8azEvES5KwESKZ7YhJrU/uDU/2nz3EQ+1PUe9Z6SU3/1QM\nrWFdtmj7JA3IYnZ7Oogt3xmsYFdzhW34Va5PX4N5cGNSo9R9/LXqS7Xs+Bsmf2v6\nXerQYIjqR4imMWrHd6nBCrW1i/OPIuaqhlr+0Za6w+I1327QamlbrJm4ZzoIB4Ku\nwEI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universita' di Verona (nuovo)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Verona (nuovo)"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univr.it/jsp/index.jsp?lang=it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univr.it/jsp/index.jsp?lang=en"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universita' di Verona"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Verona"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://verify.dmu.ac.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Troy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kevin.troy@digitary.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kevin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Troy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kevin.troy@digitary.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kevin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://verify.dmu.ac.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-12-13T10:28:12Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "DARE service for De Montfort University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.digitary.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Digitary"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://verify.dmu.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://verify.dmu.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://verify.dmu.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://verify.dmu.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://verify.dmu.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://verify.dmu.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAKvu+ZotXOBYMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGGRpZ2l0YXJ5LmRhcmUudWxjYy5hYy51azAeFw0xMjA0MTIxNTA4MDhaFw0y\n\t\t\t\t\t\tMjA0MTAxNTA4MDhaMCMxITAfBgNVBAMTGGRpZ2l0YXJ5LmRhcmUudWxjYy5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAONwiFdIwZkaerJXg8Wm\n\t\t\t\t\t\t47ddT4dPw4AYVWgk2Uy64qQvAgbaSQi1mknnR27bhWyg5iCA3z9IrfLtLmF6O4do\n\t\t\t\t\t\tQ5nMjXcnCVivz0hubTlFLgqtbo1XXddm+WYrpsoBhATbgLcz8XG/TdQWzqPjf6xR\n\t\t\t\t\t\tjslpbjf8YTDCigoLpxnrBfJeY8ns81RaxtDOS/eg5JgjpohSbnJK5kum4twpEVPK\n\t\t\t\t\t\t/Z6EmoIKsCQ2YTzcn1PmlxT3czYxBS5Hr54tt1W7JUtZPlrWyMJnQVof7MZSTeLr\n\t\t\t\t\t\tpiH74BxtfbN1n7AwWvGSdj7D8saRahKv9YzexaGKNggAlXE7lwDSRAagh/MKIX4V\n\t\t\t\t\t\toasCAwEAAaNGMEQwIwYDVR0RBBwwGoIYZGlnaXRhcnkuZGFyZS51bGNjLmFjLnVr\n\t\t\t\t\t\tMB0GA1UdDgQWBBQJeESLMMOvuBxCw/egquAAUDHR2zANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAPF1yxkncDbJ0WwRpnleXV2P7GGDKenIbcIH69ad+0IARiyCvKJxX1vpfkD2C\n\t\t\t\t\t\tFmis9+MURBeMMpRUpRsIGh9O2SMMQT/aTMHqoSWOMGiJW9fM6PCS18Z5Zx4aTgyq\n\t\t\t\t\t\tO1ez0wHjbR1vW/TfSM/b6A2ovLqR+6bbbaymu0wu5UbNofG1uSRgkKT9kgeiGLWq\n\t\t\t\t\t\tVqagedqlmGej4hnCq2/+hMGTdeRiCrgFwUwVL8ZLfs8YptRka8WPuEsXieI7m7rf\n\t\t\t\t\t\tTzJxScFtn4xmZUOrC5VFdXH5j4S8/6M6kYiw2iQAbpSBBn1Azow1sWj2JzY4yUMZ\n\t\t\t\t\t\tJXxZbc0L9R3Upa90FjFH8QnxXg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://verify.dmu.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://verify.dmu.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://verify.dmu.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://verify.dmu.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://verify.dmu.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://verify.dmu.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-23.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-23.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;23"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;23"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-23.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-23.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJANMaJQIHvD4NMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0yMy5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTQ0NDI3WhcNMjQx\nMDA0MTQ0NDI3WjAhMR8wHQYDVQQDExZsYWRvazMtMjMubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2cGiumvjdyZKuwTntxWlX3x4\n5LV7nqUJGz0GlJ2qvKV2OD9DPc0as0BC5HvUpEd9T3gLojW0B7HOJDgOUVPEdgGB\nyGMyVdle/Ig3HD3S1AnupDL1bqvMZn/hU/sGRqDyJRUf8k+pFo39sAYqt5OeOXQu\nXJdCYfGCRBtu3kmG9kxNHjt/9FHzwiwefKZW0Nn0Wtc5cgMhDpx0iOCPc6Ckn0kq\n/KVcSlm8SnlGjMVzIJfUef2IkCw0qA0Wnt2CcCycK7OQXyP0YwLh9WPHZXRTKQxi\npaIeotdgZkccXEDFYA05l1deS1MtqiLoxarUFIgcM3X6kThHRmpOufMRLWBjKwID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMjMubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0yMy5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUODngsWRqAupbWEp7N9nRquKqkAQwDQYJKoZIhvcNAQEFBQADggEB\nAJmntLsSPqmmFcmrZJ4XixCDYsYlG88e0l0ii8FpEwCInneYjroLbrb5Od1JkHXR\nW+q6O1GMQfaFSW9YN5xcHoLtK20tRscCufVTlA5rj+Xks6vGT841Wf/pn8kEF6hW\n6RN+FBsEkFu1ACgbieyw4npngpYB8diJe5Ttcsvl/wRP7zjD7roP9K7cpvC5s694\nJO0lwUmaPXqAh5Jqh29w5EN+59O3xWJ9Ec37tCY5IkkcGnB5uAfP93K5eyMafX9V\ncA8Pb/ntxkRoZoGUw/oqpGrIpZMvGOFxehGdzOd+ZTpf9L0R37byGM94pTq6gz33\n69ezgM07kER3QrJpPLCrLT0="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-23.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp-co.calstate.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "iamadmin@calstate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marcus Mizushima"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "iamadmin@calstate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Eli Pham"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-co.calstate.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-co.calstate.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-co.calstate.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPjCCAiagAwIBAgIJAPBOOrypT78oMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE2lkcC1jby5jYWxzdGF0ZS5lZHUwHhcNMTEwMzIxMTYwMTIzWhcNMjEwMzE4\nMTYwMTIzWjAeMRwwGgYDVQQDExNpZHAtY28uY2Fsc3RhdGUuZWR1MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA24Qp4dSLiG0FbRIgM+3tHcdzJDRgYrpO\nYrvyl411IEKqxN3BeibppRp1nejlnsLa5IW2zl46XJeoH3XVtdZbwYlfas4JX5lo\nkso+lDBmss1KuTi2kKA9tCZXPuErPV8/U/pMqGxSSMZLW6SoVn2hy906FJVloEPe\nZ4awPZp/IAHnGaXRoZByr7qyagWdeXYX++zQ6AayTi8fhBkJC+WQnHjQY1mNuVBP\nzghI8H+5Osgpo3lCEBCMg9XcS/y/tku4ByRybWjsL2YXmFvhL87CCSy5CACuhVK1\nmN+xtDqA6IjWTLCN7u3q/FlirD9x0MUHGr+ceedWiQJtE79dYjQMWwIDAQABo38w\nfTAdBgNVHQ4EFgQUBZHCC43QDl6aonyzJnPBiaQTTnowTgYDVR0jBEcwRYAUBZHC\nC43QDl6aonyzJnPBiaQTTnqhIqQgMB4xHDAaBgNVBAMTE2lkcC1jby5jYWxzdGF0\nZS5lZHWCCQDwTjq8qU+/KDAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IB\nAQAm/080HwIDQhVaCqqnt2JVECLaX3pU9fBBjAPa8p7/VoUYjgFh9dOkvwng4x9K\nga2E+p0YXl4Uj/F+MOo2+Rot9DBYUHHYJZIMUsEdYNXnL8esXGoTxASVP0cmW7/D\nHXtAk5cK81Wle/tZBD5tNgeMgE6GzoVsmzaNS9/qW6tirp8Zy5rXj8mqIKmH5wHo\n5wWVD6IrsVOFFRrtNCkfpb5YoXRGIix01iYiHFLSkzdSiIAGu9m0DUwmFPpzOmGu\nomaVi3Po04oaAqKFo9NnTmwoMRtoqm1kWFf27pah+JkibTMLoiHKe5F94v9Sbm7s\ngDk7zgM8NwgZL2Yr9kJ/Yhr5"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "co.calstate.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-co.calstate.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-co.calstate.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-co.calstate.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-co.calstate.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPjCCAiagAwIBAgIJAPBOOrypT78oMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE2lkcC1jby5jYWxzdGF0ZS5lZHUwHhcNMTEwMzIxMTYwMTIzWhcNMjEwMzE4\nMTYwMTIzWjAeMRwwGgYDVQQDExNpZHAtY28uY2Fsc3RhdGUuZWR1MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA24Qp4dSLiG0FbRIgM+3tHcdzJDRgYrpO\nYrvyl411IEKqxN3BeibppRp1nejlnsLa5IW2zl46XJeoH3XVtdZbwYlfas4JX5lo\nkso+lDBmss1KuTi2kKA9tCZXPuErPV8/U/pMqGxSSMZLW6SoVn2hy906FJVloEPe\nZ4awPZp/IAHnGaXRoZByr7qyagWdeXYX++zQ6AayTi8fhBkJC+WQnHjQY1mNuVBP\nzghI8H+5Osgpo3lCEBCMg9XcS/y/tku4ByRybWjsL2YXmFvhL87CCSy5CACuhVK1\nmN+xtDqA6IjWTLCN7u3q/FlirD9x0MUHGr+ceedWiQJtE79dYjQMWwIDAQABo38w\nfTAdBgNVHQ4EFgQUBZHCC43QDl6aonyzJnPBiaQTTnowTgYDVR0jBEcwRYAUBZHC\nC43QDl6aonyzJnPBiaQTTnqhIqQgMB4xHDAaBgNVBAMTE2lkcC1jby5jYWxzdGF0\nZS5lZHWCCQDwTjq8qU+/KDAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IB\nAQAm/080HwIDQhVaCqqnt2JVECLaX3pU9fBBjAPa8p7/VoUYjgFh9dOkvwng4x9K\nga2E+p0YXl4Uj/F+MOo2+Rot9DBYUHHYJZIMUsEdYNXnL8esXGoTxASVP0cmW7/D\nHXtAk5cK81Wle/tZBD5tNgeMgE6GzoVsmzaNS9/qW6tirp8Zy5rXj8mqIKmH5wHo\n5wWVD6IrsVOFFRrtNCkfpb5YoXRGIix01iYiHFLSkzdSiIAGu9m0DUwmFPpzOmGu\nomaVi3Po04oaAqKFo9NnTmwoMRtoqm1kWFf27pah+JkibTMLoiHKe5F94v9Sbm7s\ngDk7zgM8NwgZL2Yr9kJ/Yhr5"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "co.calstate.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "California State University, Office of the Chancellor"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California State University, Office of the Chancellor"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.calstate.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California State University, Office of the Chancellor"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://testidp.nottingham.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itservicedesk@nottingham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "University of Nottingham IT Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Betts"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Craig.Betts@nottingham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Craig"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://testidp.nottingham.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-02-22T16:32:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEpDCCA4ygAwIBAgIJAPJoOXh5jZZuMA0GCSqGSIb3DQEBBQUAMIHSMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEYMBYGA1UECBMPTm90dGluZ2hhbXNoaXJlMRMwEQYDVQQHEwpOb3R0\n\t\t\t\t\t\taW5naGFtMSUwIwYDVQQKExxUaGUgVW5pdmVyc2l0eSBvZiBOb3R0aW5naGFtMR0w\n\t\t\t\t\t\tGwYDVQQLExRJbmZvcm1hdGlvbiBTZXJ2aWNlczEhMB8GA1UEAxMYdGVzdGlkcC5u\n\t\t\t\t\t\tb3R0aW5naGFtLmFjLnVrMSswKQYJKoZIhvcNAQkBFhxjcmFpZy5iZXR0c0Bub3R0\n\t\t\t\t\t\taW5naGFtLmFjLnVrMB4XDTE1MTExODE0MDIwOVoXDTI1MTExNTE0MDIwOVowgdIx\n\t\t\t\t\t\tCzAJBgNVBAYTAkdCMRgwFgYDVQQIEw9Ob3R0aW5naGFtc2hpcmUxEzARBgNVBAcT\n\t\t\t\t\t\tCk5vdHRpbmdoYW0xJTAjBgNVBAoTHFRoZSBVbml2ZXJzaXR5IG9mIE5vdHRpbmdo\n\t\t\t\t\t\tYW0xHTAbBgNVBAsTFEluZm9ybWF0aW9uIFNlcnZpY2VzMSEwHwYDVQQDExh0ZXN0\n\t\t\t\t\t\taWRwLm5vdHRpbmdoYW0uYWMudWsxKzApBgkqhkiG9w0BCQEWHGNyYWlnLmJldHRz\n\t\t\t\t\t\tQG5vdHRpbmdoYW0uYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCd7jf9JyWXG2cZFcseqidGD90cIOQ/VXEwP0rYgkE1d93JBcKVB1gIHZWcRR1m\n\t\t\t\t\t\t6C1yJDT59ELfG6lW+lWiwl0mz+eSe1H/qHWvRYclN1d4idwjGH0+HI2Z6wCcI7AE\n\t\t\t\t\t\tB+KtkNmmyll6UnKZCmaLTlA7RZldngNBnm4j+rse5Y6PzM09lFSUkI6uPd/pKOn7\n\t\t\t\t\t\tbQ2GZxRe6XIvYXy5I+YPXA0KepdD+q6aMvcqfAnyBuNeYEBUWmp96FKkyDOq6U0O\n\t\t\t\t\t\t2pcJsyk2afhYKfxgUr2xDKMGkV9aQ2lo2lKj/uOzeJrBkLLUFBfzX+hcsbNpog7L\n\t\t\t\t\t\tbokGDaTrqteA+2GrMb4o3r61AgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4\n\t\t\t\t\t\tQgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBR+\n\t\t\t\t\t\tP4B1PFw8wFWK77RhxhNqJRWqZjAfBgNVHSMEGDAWgBR+P4B1PFw8wFWK77RhxhNq\n\t\t\t\t\t\tJRWqZjANBgkqhkiG9w0BAQUFAAOCAQEAThuXjvL1gTZD3zvYWg6wQ8jc1CuVk+Av\n\t\t\t\t\t\tkW03jrIn3G86ccKflFOlxqUea9hno7fFnTRI+Hkw6pLUbpomiXc2EfNsEqJCM9Mu\n\t\t\t\t\t\tXyFchYKv8PAfMg9229uJbm8OwUAXY1C4t83h4usuu08rLvm3VUUV9lGMePSjkI6G\n\t\t\t\t\t\tL0gMXhO1qS6b+14oG8BwxjMXkK80aDlB1NDwRxTpBCBNQNRBG3H1CUwZuPLYrnGJ\n\t\t\t\t\t\tsGNabQO4+KddI+mjILyUTXkJmairCoNWz8TdyAvK/kcWjVku8pA3I75NUucMb254\n\t\t\t\t\t\t7oz4jJB8gYgsY42b/0ls6sHuUILxKUZ4gTneeYN6L/MPfCAO74kEAQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nottingham.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://testidp.nottingham.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://testidp.nottingham.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://testidp.nottingham.ac.uk/shibboleth-idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://testidp.nottingham.ac.uk/shibboleth-idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://testidp.nottingham.ac.uk/shibboleth-idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://testidp.nottingham.ac.uk/shibboleth-idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://testidp.nottingham.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://testidp.nottingham.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nottingham.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEpDCCA4ygAwIBAgIJAPJoOXh5jZZuMA0GCSqGSIb3DQEBBQUAMIHSMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEYMBYGA1UECBMPTm90dGluZ2hhbXNoaXJlMRMwEQYDVQQHEwpOb3R0\n\t\t\t\t\t\taW5naGFtMSUwIwYDVQQKExxUaGUgVW5pdmVyc2l0eSBvZiBOb3R0aW5naGFtMR0w\n\t\t\t\t\t\tGwYDVQQLExRJbmZvcm1hdGlvbiBTZXJ2aWNlczEhMB8GA1UEAxMYdGVzdGlkcC5u\n\t\t\t\t\t\tb3R0aW5naGFtLmFjLnVrMSswKQYJKoZIhvcNAQkBFhxjcmFpZy5iZXR0c0Bub3R0\n\t\t\t\t\t\taW5naGFtLmFjLnVrMB4XDTE1MTExODE0MDIwOVoXDTI1MTExNTE0MDIwOVowgdIx\n\t\t\t\t\t\tCzAJBgNVBAYTAkdCMRgwFgYDVQQIEw9Ob3R0aW5naGFtc2hpcmUxEzARBgNVBAcT\n\t\t\t\t\t\tCk5vdHRpbmdoYW0xJTAjBgNVBAoTHFRoZSBVbml2ZXJzaXR5IG9mIE5vdHRpbmdo\n\t\t\t\t\t\tYW0xHTAbBgNVBAsTFEluZm9ybWF0aW9uIFNlcnZpY2VzMSEwHwYDVQQDExh0ZXN0\n\t\t\t\t\t\taWRwLm5vdHRpbmdoYW0uYWMudWsxKzApBgkqhkiG9w0BCQEWHGNyYWlnLmJldHRz\n\t\t\t\t\t\tQG5vdHRpbmdoYW0uYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCd7jf9JyWXG2cZFcseqidGD90cIOQ/VXEwP0rYgkE1d93JBcKVB1gIHZWcRR1m\n\t\t\t\t\t\t6C1yJDT59ELfG6lW+lWiwl0mz+eSe1H/qHWvRYclN1d4idwjGH0+HI2Z6wCcI7AE\n\t\t\t\t\t\tB+KtkNmmyll6UnKZCmaLTlA7RZldngNBnm4j+rse5Y6PzM09lFSUkI6uPd/pKOn7\n\t\t\t\t\t\tbQ2GZxRe6XIvYXy5I+YPXA0KepdD+q6aMvcqfAnyBuNeYEBUWmp96FKkyDOq6U0O\n\t\t\t\t\t\t2pcJsyk2afhYKfxgUr2xDKMGkV9aQ2lo2lKj/uOzeJrBkLLUFBfzX+hcsbNpog7L\n\t\t\t\t\t\tbokGDaTrqteA+2GrMb4o3r61AgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4\n\t\t\t\t\t\tQgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBR+\n\t\t\t\t\t\tP4B1PFw8wFWK77RhxhNqJRWqZjAfBgNVHSMEGDAWgBR+P4B1PFw8wFWK77RhxhNq\n\t\t\t\t\t\tJRWqZjANBgkqhkiG9w0BAQUFAAOCAQEAThuXjvL1gTZD3zvYWg6wQ8jc1CuVk+Av\n\t\t\t\t\t\tkW03jrIn3G86ccKflFOlxqUea9hno7fFnTRI+Hkw6pLUbpomiXc2EfNsEqJCM9Mu\n\t\t\t\t\t\tXyFchYKv8PAfMg9229uJbm8OwUAXY1C4t83h4usuu08rLvm3VUUV9lGMePSjkI6G\n\t\t\t\t\t\tL0gMXhO1qS6b+14oG8BwxjMXkK80aDlB1NDwRxTpBCBNQNRBG3H1CUwZuPLYrnGJ\n\t\t\t\t\t\tsGNabQO4+KddI+mjILyUTXkJmairCoNWz8TdyAvK/kcWjVku8pA3I75NUucMb254\n\t\t\t\t\t\t7oz4jJB8gYgsY42b/0ls6sHuUILxKUZ4gTneeYN6L/MPfCAO74kEAQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Nottingham: TEST"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nottingham.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Nottingham"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.refme.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hello@refme.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support contact"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:productivity@refme.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical contact"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.refme.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-02-08T09:57:02Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RefME"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.refme.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RefME Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.refme.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.refme.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.refme.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.refme.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.refme.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sp.refme.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp.refme.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Accurate, automated citations in over 7,500 styles. The leading smart reference management tool"
                  }
                ],
                "logo": [
                  {
                    "text": "https://sp.refme.com/shibboleth-sp/refme.png",
                    "height": "70",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "220"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RefME"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6zCCAdOgAwIBAgIJAKDqrd6tuFRoMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\n\t\t\t\t\t\tBAMTDHNwLnJlZm1lLmNvbTAeFw0xNjAyMDMxNDUyMDJaFw0yNjAxMzExNDUyMDJa\n\t\t\t\t\t\tMBcxFTATBgNVBAMTDHNwLnJlZm1lLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBAMNcP5n7JK1LY87i9pjKexZO8tqoHIw62CIktYuS2PVGdVaPGJNJ\n\t\t\t\t\t\tDCqqjrUW7CkiCUVccax7LO9Kew6wqQmsTesa4BaGjqvKQaxzXi9dIKJTD3jlg9Xk\n\t\t\t\t\t\td1CwbSoeCsVErnHwcnUXWxkCMUmwHYr/MJNftRiWC6ItZ2Qs7yPGLSCTK7HFk9QX\n\t\t\t\t\t\tBH38Zlt+fotMOQeo5G1oTGUV9Jdet4VOl6X6QcEzr7csfijLNYFUzJHVTXa/BR1j\n\t\t\t\t\t\tCVGahNMP2sXpLfqWNrricLGa4/hlcrYqRXyy49/qkaHqzBeiLl0GH8MJ4QpwFg2f\n\t\t\t\t\t\tIsBQCZW6DBdYH3PbzkkccBjxEOVxJOpw3LMCAwEAAaM6MDgwFwYDVR0RBBAwDoIM\n\t\t\t\t\t\tc3AucmVmbWUuY29tMB0GA1UdDgQWBBQL3DBAVitR/K57X+BYz8SK2TsYWDANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAIMtgvxnFgS0js/FT3mSo1wH6MCLRjvrxORHqETaEeFCV\n\t\t\t\t\t\tclc/cUyzpNF6QGoX7TY0iam2Hfu4khJAIv7Bzn2ZnDxMqAxhJlkFjCok7wyH91Ed\n\t\t\t\t\t\tjkiKLd2hySBXk7f3dTpml1Pm2WFtj70ci/edGXR+3u6cquZvavZMhC8xIGN38fE5\n\t\t\t\t\t\tqflluoHekq3i8vnTA8sDz5+OYGPuNv4uswc7QXgmZWI01dIhOKPBeD7M0aVULs3n\n\t\t\t\t\t\t6wBdaSG/rj+CjUHXTvjop42zY53H4daC0afDALEK3B9g2OpeDVOTsZwCMTI7gZHW\n\t\t\t\t\t\txtvfwBO3xVnetZqHnVDunjMewZwlU0/UVpfUmhGi/g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.refme.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp.refme.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.refme.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp.refme.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp.refme.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp.refme.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "RefME"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonTargetedID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://lincbattels.linc.ox.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:help@lincoln.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Help"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@lincoln.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://lincbattels.linc.ox.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-03-03T12:03:46Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Oxford, Lincoln College Battels Payments"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lincoln.ox.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Oxford"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lincbattelsnew.linc.ox.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lincbattelsnew.linc.ox.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lincbattelsnew.linc.ox.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lincbattelsnew.linc.ox.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lincbattelsnew.linc.ox.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://lincbattelsnew.linc.ox.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Payments gateway for Lincoln College, Oxford"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Oxford, Lincoln College Battels Payments"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6DCCAdCgAwIBAgIJAJw2qNx2ggkaMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\n\t\t\t\t\t\tBAMTC2xpbmNiYXR0ZWxzMB4XDTE2MDMwMTEwNTY0MFoXDTI2MDIyNzEwNTY0MFow\n\t\t\t\t\t\tFjEUMBIGA1UEAxMLbGluY2JhdHRlbHMwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQDigdUkA9vd9d3li5sBzHL6j05BuAJZvceBFLJ4Yw19cs6FD0FA8zwf\n\t\t\t\t\t\tnqHWRYHzwzvrFgcVYkxtkoduACnb9I4y9ycUXmHq/YYcpYh/szpVGzY5Wi+N7xup\n\t\t\t\t\t\tWjw4Bkc0DjiisYnh6Zy+UcnJPdX5VemO2a30J0SCHTLYN1Z0pk+1bbx/uUe7w/7E\n\t\t\t\t\t\tDEfl0xp/IqGyNaSI/E0GtzVy6F+PLCYXs4TyGrwHkQhUQPKMiOVQCiTj5OCUzUOC\n\t\t\t\t\t\tz8bw6HgJfF5V0ZsmnLuz3OOdIo4FLaTqxIUM+x+Nw453JrLo72R5kZ4mQKwEgu1A\n\t\t\t\t\t\tJZwkN9btwsEUcICpfamy5EZtHgCE+nrfAgMBAAGjOTA3MBYGA1UdEQQPMA2CC2xp\n\t\t\t\t\t\tbmNiYXR0ZWxzMB0GA1UdDgQWBBQeslKn+QrNoN4zsVMPtKgXCa49cjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAxd9do8Q3pztodwtkArpOvyHc/cmlfTlrj7+6Yh9nEsmTMZ/H\n\t\t\t\t\t\tvT7HdZV6eMGkj2X7ay2PAyDLJnoM+sS6iBMb5nWl/pwUkjFi1UC8OR6Fb79o2YMc\n\t\t\t\t\t\teTRGhqP3eIM6qoiVVQz7FKF5Ej7QbjaxHCsO+TtsFrgngCE3H+rYVME3VYNW6vWL\n\t\t\t\t\t\tYFuhC4loFyaVZtyCkMLKBSQ29FR6P/L3DRA0WlNSmb2y/k+D7S8aymeFgVaXudT4\n\t\t\t\t\t\tKBtpPH0FaQ/KbAqyHVF1Sg5wvoJnw8zKMKEdAf76zO3QY6TYkeR9tR9UzGbyYbyW\n\t\t\t\t\t\t2nZllHItz1LVOeER46d3rCUD42UfZWJx0nFG/w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lincbattelsnew.linc.ox.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://lincbattelsnew.linc.ox.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lincbattelsnew.linc.ox.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://lincbattelsnew.linc.ox.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://lincbattelsnew.linc.ox.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://lincbattelsnew.linc.ox.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp2.hua.gr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Piperidis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kpiperidhs@hua.gr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Konstantinos"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Piperidis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kpiperidhs@hua.gr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Konstantinos"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp2.hua.gr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEmzCCA4OgAwIBAgIRANQlWe4RJ07BgbSF+F+w/jEwDQYJKoZIhvcNAQEFBQAw\n                            NjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n                            IFNTTCBDQTAeFw0xMTA1MzEwMDAwMDBaFw0xNDA1MzAyMzU5NTlaMG0xCzAJBgNV\n                            BAYTAkdSMQ8wDQYDVQQIEwZBdHRpa2kxDzANBgNVBAcTBkF0aGVuczEnMCUGA1UE\n                            ChMeSGFyb2tvcGlvIFVuaXZlcnNpdHkgb2YgQXRoZW5zMRMwEQYDVQQDEwppZHAu\n                            aHVhLmdyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAruot1FGyNNP7\n                            VdnQMt3didkog3AguzGJ/9oB4MDnWeskNIIPW/X4FKDHhICwO7nKD/jPoYS2xrBp\n                            74VOXW8u3RL7H554E3fFXJMi00MN294Ba3vi02nuCNFwdY7HTxFaCOzZaAhG5kYa\n                            TWypaQw0W87HIaVVgvjnhvf1PPJCMi+YBMvnmXNasSs57N40BfJBLDgto/UBWK/2\n                            Pgx/zvUvL7Hln/a79ehlsaH+aT5ewllpO+yVde2rC9R1sJMFAStOLhtOL7JlKkEJ\n                            AQPtjEqBiJZlYgbGNNe9F1ikfCcdmzt33y2T8gyUTxbPRve1PEEjcPYLNnmAkK13\n                            TPvft0w/lQIDAQABo4IBazCCAWcwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH\n                            6pDjue0wHQYDVR0OBBYEFBJc0q0dwVcOZFxUxHnpldmmeM88MA4GA1UdDwEB/wQE\n                            AwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcD\n                            AjAYBgNVHSAEETAPMA0GCysGAQQBsjEBAgIdMDoGA1UdHwQzMDEwL6AtoCuGKWh0\n                            dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3JsMG0GCCsGAQUF\n                            BwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3MudGVyZW5hLm9yZy9U\n                            RVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9vY3NwLnRjcy50ZXJl\n                            bmEub3JnMCMGA1UdEQQcMBqCCmlkcC5odWEuZ3KCDGxvZ2luLmh1YS5ncjANBgkq\n                            hkiG9w0BAQUFAAOCAQEAbfA5ENIlPCsvxmQuMVGL/mnwO1MDKYpij/1DywTO+JBS\n                            I65ViCF0Irv4Vpuc9bVIL/nC/9zlUpcWFC1Rvq4BdSTZwnYVJsq71r8g78ZbFY6u\n                            nsogzG6sspPj77HYXbUcUnz+DwmgPPHTNKikhPXenQSMIgTGkZRKaEj6CbhTWxpU\n                            9y43i3EObg6zxcqwyIaawldvSwKTBbUuiepWzDASHeGBW4r2uLPHnNc6gwPwdei5\n                            mBFTKd3S15BA5RiJ2Z+u1X5fzgGuyyEI5VnAdC7SBqhh7bm90mVoHLoWjTS378xQ\n                            Oy3Soy1kO0DpSfaKXP7Ss8TN2ndbGpO1UhaBeVwMTg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hua.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.hua.gr:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.hua.gr:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.hua.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.hua.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.hua.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.hua.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.hua.gr:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.hua.gr:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hua.gr"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.hua.gr/"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.hua.gr/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.hua.gr/logo.png",
                    "height": "81",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "83"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Harokopio University"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u03a7\u03b1\u03c1\u03bf\u03ba\u03cc\u03c0\u03b5\u03b9\u03bf \u03a0\u03b1\u03bd\u03b5\u03c0\u03b9\u03c3\u03c4\u03ae\u03bc\u03b9\u03bf"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "hua.gr"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:37.96118327,23.70823603"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.130.90.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.251.30.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "83.212.240.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "83.212.242.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEmzCCA4OgAwIBAgIRANQlWe4RJ07BgbSF+F+w/jEwDQYJKoZIhvcNAQEFBQAw\n                            NjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n                            IFNTTCBDQTAeFw0xMTA1MzEwMDAwMDBaFw0xNDA1MzAyMzU5NTlaMG0xCzAJBgNV\n                            BAYTAkdSMQ8wDQYDVQQIEwZBdHRpa2kxDzANBgNVBAcTBkF0aGVuczEnMCUGA1UE\n                            ChMeSGFyb2tvcGlvIFVuaXZlcnNpdHkgb2YgQXRoZW5zMRMwEQYDVQQDEwppZHAu\n                            aHVhLmdyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAruot1FGyNNP7\n                            VdnQMt3didkog3AguzGJ/9oB4MDnWeskNIIPW/X4FKDHhICwO7nKD/jPoYS2xrBp\n                            74VOXW8u3RL7H554E3fFXJMi00MN294Ba3vi02nuCNFwdY7HTxFaCOzZaAhG5kYa\n                            TWypaQw0W87HIaVVgvjnhvf1PPJCMi+YBMvnmXNasSs57N40BfJBLDgto/UBWK/2\n                            Pgx/zvUvL7Hln/a79ehlsaH+aT5ewllpO+yVde2rC9R1sJMFAStOLhtOL7JlKkEJ\n                            AQPtjEqBiJZlYgbGNNe9F1ikfCcdmzt33y2T8gyUTxbPRve1PEEjcPYLNnmAkK13\n                            TPvft0w/lQIDAQABo4IBazCCAWcwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH\n                            6pDjue0wHQYDVR0OBBYEFBJc0q0dwVcOZFxUxHnpldmmeM88MA4GA1UdDwEB/wQE\n                            AwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcD\n                            AjAYBgNVHSAEETAPMA0GCysGAQQBsjEBAgIdMDoGA1UdHwQzMDEwL6AtoCuGKWh0\n                            dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3JsMG0GCCsGAQUF\n                            BwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3MudGVyZW5hLm9yZy9U\n                            RVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9vY3NwLnRjcy50ZXJl\n                            bmEub3JnMCMGA1UdEQQcMBqCCmlkcC5odWEuZ3KCDGxvZ2luLmh1YS5ncjANBgkq\n                            hkiG9w0BAQUFAAOCAQEAbfA5ENIlPCsvxmQuMVGL/mnwO1MDKYpij/1DywTO+JBS\n                            I65ViCF0Irv4Vpuc9bVIL/nC/9zlUpcWFC1Rvq4BdSTZwnYVJsq71r8g78ZbFY6u\n                            nsogzG6sspPj77HYXbUcUnz+DwmgPPHTNKikhPXenQSMIgTGkZRKaEj6CbhTWxpU\n                            9y43i3EObg6zxcqwyIaawldvSwKTBbUuiepWzDASHeGBW4r2uLPHnNc6gwPwdei5\n                            mBFTKd3S15BA5RiJ2Z+u1X5fzgGuyyEI5VnAdC7SBqhh7bm90mVoHLoWjTS378xQ\n                            Oy3Soy1kO0DpSfaKXP7Ss8TN2ndbGpO1UhaBeVwMTg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Harokopio University"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u03a7\u03b1\u03c1\u03bf\u03ba\u03cc\u03c0\u03b5\u03b9\u03bf \u03a0\u03b1\u03bd\u03b5\u03c0\u03b9\u03c3\u03c4\u03ae\u03bc\u03b9\u03bf"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hua.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hua.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Harokopio University"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u03a7\u03b1\u03c1\u03bf\u03ba\u03cc\u03c0\u03b5\u03b9\u03bf \u03a0\u03b1\u03bd\u03b5\u03c0\u03b9\u03c3\u03c4\u03ae\u03bc\u03b9\u03bf"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.cc.uga.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "keith.martin@uga.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Keith Martin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cc.uga.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.cc.uga.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cc.uga.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cc.uga.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cc.uga.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cc.uga.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uga.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Shibboleth 2.x"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Georgia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRjCCAi4CCQD0C+UOJQz5qjANBgkqhkiG9w0BAQUFADBlMRgwFgYDVQQDDA9p\nZHAuZGV2LnVnYS5lZHUxHjAcBgNVBAoMFVVuaXZlcnNpdHkgb2YgR2VvcmdpYTEL\nMAkGA1UEBhMCVVMxCzAJBgNVBAgMAkdBMQ8wDQYDVQQHDAZBdGhlbnMwHhcNMTUw\nMzEzMTU0ODI3WhcNMTYwMzEyMTU0ODI3WjBlMRgwFgYDVQQDDA9pZHAuZGV2LnVn\nYS5lZHUxHjAcBgNVBAoMFVVuaXZlcnNpdHkgb2YgR2VvcmdpYTELMAkGA1UEBhMC\nVVMxCzAJBgNVBAgMAkdBMQ8wDQYDVQQHDAZBdGhlbnMwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQC39mQdrZiYhMAfLcMQCWDUU2IySnIbro+xWE29UKZl\n3OAjD2UjjDBOs77YDk2TmUsKucG7vEogVIPPAtWK+RCuIkLMUFs+v3ZPvYuRqBDY\n9ComFpsuVqXaopaYRcddAIkHf+bgNwLCMYe4E8xGdumr95EnV7qdPPZqoju72VL5\nUgSris8FMoXFkkh5SEgvchV2voeKVySi8XjP3U4lubqhAyP6s0Kl5EgVNeha3JXI\nwdWBcAizE7vO/tgClDNdcgN0lOghNX7neWxkT8I7JACKnn277kQPNOiXq0z2EEzl\nAFDvGbzhEHDCq31hJ1XH2DujLoN2EfSPlGZsu/YGMF63AgMBAAEwDQYJKoZIhvcN\nAQEFBQADggEBAJUXilMXABVFYbaEvptvMvuoN5yvxu6U1xhGKJ6RHNqcF32Kq8M8\ncn4VsbTaT4OmaP77TcbnaoxbYwA9kmQI/s0I7IRkYnGSFm7fIjmttLHwci9Ve8lN\nRI44IKzN3h2IENCq86zLpu0t9eBb6FRT1QBxr42p6Gv+PwNyDfthxW85bO2sSVDd\n1DOzxzmOfWekXdypSsC/FKqtk2+bordT5n9A61x8xfKG8LtM1ThhHqAO/0j8fd8N\nKi/S+qS1S8KfxPmHlUYIw7dHs3xrAJXmKadkZK30KhT5nw2dJ6iLDoOMRV7Xq18W\nPod/7K5BxkdiDL8kTktbtYDFm1OdZXo/isk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAggCCQDYTLE1vTqdiTANBgkqhkiG9w0BAQUFADBSMRcwFQYDVQQDDA5p\nZHAuY2MudWdhLmVkdTEMMAoGA1UECgwDVUdBMQswCQYDVQQGEwJVUzELMAkGA1UE\nCAwCR0ExDzANBgNVBAcMBkF0aGVuczAeFw0xNTAzMjMxNDM0NTlaFw0xNjAzMjIx\nNDM0NTlaMFIxFzAVBgNVBAMMDmlkcC5jYy51Z2EuZWR1MQwwCgYDVQQKDANVR0Ex\nCzAJBgNVBAYTAlVTMQswCQYDVQQIDAJHQTEPMA0GA1UEBwwGQXRoZW5zMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsD6dDssY48p9YeR/G+zoJEqvaFKz\nWaCdYLsFxfGf7wF/ChgAtRZd29s6Flz9acht+2zhiuf8jIdvuB8OX2Bvq+CkJDNi\n3SU46W3e7meY4Hzs7kLcOFh03lbcrInGJbnDYR9yxLhrLINVhOzaLD0qf8dxLt/N\ng0Jr96atvpHmY4hv8BIbuqDO8ViR0Qckoe6qcR8S6Ezca4vWZNwrvBPuorn5kVFV\nXJqNciwsIE1d3cHpjb2s5jrEW7JsliHjXrtcj0/u5TFtyNmH0Wme9jQTeEy88iO0\nnIxx683zS7OEWYRzidJY7iXnHC9ulc8fY5cE2ZEWjz23LPDctMiITP51zQIDAQAB\nMA0GCSqGSIb3DQEBBQUAA4IBAQABXOtGnkLzWTHFcRPpwOIrkN1vytQKk2UTFEvt\ns2orodiL7j8yoXViYogxzyQuRk1wJmDS8arUHNDMa/ph0+1aWV4kg1AgvnSCMIg+\n2PdyCVklbI+CRoDbSUonlC9PtKlCkxUK8BBM+P+qrxJ6I703pDR/wEfI3OoxLv8T\nBGrzVttkbT455bMbCQC/PBdpVRuEpUMiXQCMOymr2Jw2yOaazS8u0k3JCA4LOCDU\nAJ9/YMkcjWB3NvaXhpKoeYlvMHEsxvSZT0mqNXImDI7VttSVS3Oxm05/JRGfdqRa\nM/mm6iec1w/QK2k+0r/xVKB8C6q9AYPPhXQsPnS6xhugQNWn"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Georgia"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uga.edu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Georgia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.highwire.org/entity/rupjnls",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.highwire.org/entity/rupjnls",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-07-22T16:56:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Stanford University: Rockefeller University Press Organization"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rupress.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HighWire Press, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.highwire.org/applications/rupjnls/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.highwire.org/applications/rupjnls/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIJAMTRVlqTJ11lMA0GCSqGSIb3DQEBBQUAMIG+MQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBD\n\t\t\t\t\t\taXR5MRcwFQYDVQQKEw5IaWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUx\n\t\t\t\t\t\tIDAeBgNVBAMTF3NoaWJib2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkB\n\t\t\t\t\t\tFiZzaGliYm9sZXRoLWFkbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTAeFw0xNDA0\n\t\t\t\t\t\tMTUxOTQzMDNaFw0yNDA0MTIxOTQzMDNaMIG+MQswCQYDVQQGEwJVUzETMBEGA1UE\n\t\t\t\t\t\tCBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBDaXR5MRcwFQYDVQQKEw5I\n\t\t\t\t\t\taWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUxIDAeBgNVBAMTF3NoaWJi\n\t\t\t\t\t\tb2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkBFiZzaGliYm9sZXRoLWFk\n\t\t\t\t\t\tbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALPB99M9iWjentrddY/rLgzKn1X0j4Ao191iyiowBBt/r/pmn2oz\n\t\t\t\t\t\tfrbONkkTVBB++mNtiufK6jyKnBM5mffPOkXHRo+K1DQec7TvpQ1PmLv/BpBgPrr9\n\t\t\t\t\t\tldViOSUnYJuB0IgJVV8oylgeH2Ay0XRkNPlBUjBA2fUPWVpXcvFe+aD2tLdVR9uO\n\t\t\t\t\t\tXvfTMxAEGqzxTU+OxO6pW2sBXNBmGvZQ0TRyovQh5+pTURY/lm0V/iWvRmRe51WE\n\t\t\t\t\t\tO/nhYyvRuMmNj8EL38o10S9TXuCkVzY00hK5cclaFge7gz/tfjmadVVcbe8xCVxc\n\t\t\t\t\t\tnb1lhmt1kH2XtKvU5hyZMTO+VUfXQvqcQyECAwEAAaN7MHkwCQYDVR0TBAIwADAs\n\t\t\t\t\t\tBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYD\n\t\t\t\t\t\tVR0OBBYEFJpUZq/XaW9/bPvjffkxX0IDvuPiMB8GA1UdIwQYMBaAFJpUZq/XaW9/\n\t\t\t\t\t\tbPvjffkxX0IDvuPiMA0GCSqGSIb3DQEBBQUAA4IBAQCq/FF56ZB1cL3KbniEJP99\n\t\t\t\t\t\tU9wTD6KpOrWxvqNbUSV1cefLf5cYHonOjy6oAJSSBSNuP7U5Q//0tXtkvlJoqGUY\n\t\t\t\t\t\tvqngmeg9wLZ/Fla3tXcDdTj0n1F+NZOx9vBDacIk0Ua4aHXDA4bdytzkV1QyZDRq\n\t\t\t\t\t\tQ8vq7RoQ8E5IF7Cll+kt2dZXQk8o6Qp3w2ppoMRtYdKOQassqn+V1MYcMPgdxZkS\n\t\t\t\t\t\tDrcgzktR/JMb5OmPrp4mSy1OWDGrFvUIigsLBPZV9tw1f7y42lnbmQas3RCS30yr\n\t\t\t\t\t\tCtUPT/PQDkCdBRViGmmMkYwjdaOTiHOJveWtrVXu8vLvO36pqFF4Kft0pgqlfvAE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.highwire.org/applications/rupjnls/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.highwire.org/applications/rupjnls/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.highwire.org/applications/rupjnls/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.highwire.org/applications/rupjnls/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.shipley.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.shipley.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/shipley.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/shipley.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "shipley.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Shipley College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.shipley.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://play.oru.se",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "saml_admin@kaltura.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://play.oru.se",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ORU Play"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://play.oru.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ORU Play"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://play.oru.se/user/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Detta \u00e4r \u00d6rebro universitets play tj\u00e4nst"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is \u00d6rebro University's streaming service"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Oru play"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Oru play"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.oru.se/user/authenticate",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.creativeclub.co.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:CreativeClub.CustomerSupport@ebiquity.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Creative Club Client Services"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wong"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:antony.wong@ebiquity.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Anthony"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.creativeclub.co.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-07-20T11:44:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ebiquity plc: Creative Club"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ebiquity.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ebiquity plc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.creativeclub.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.creativeclub.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.creativeclub.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.creativeclub.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "1",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJAJNBy2AlSZCeMA0GCSqGSIb3DQEBBQUAMC4xLDAqBgNV\n\t\t\t\t\t\tBAMTI3VrLWJyby1paXMtMS50aG9tc29uLWludGVybWVkaWEubmV0MB4XDTA5MDYz\n\t\t\t\t\t\tMDA5NTAzMFoXDTE5MDYyODA5NTAzMFowLjEsMCoGA1UEAxMjdWstYnJvLWlpcy0x\n\t\t\t\t\t\tLnRob21zb24taW50ZXJtZWRpYS5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQCfJy+boHJDh9FkG5nnjeFbooXmLO8jzEemA+Y4IOaHnLkLVwVG6EKS\n\t\t\t\t\t\t6rfM6vx+xrCxiVmRw9MZ4OaIuvLs6zMup8GfWWA4b2nBX47m4LOMZ8o24iSTkzV+\n\t\t\t\t\t\trIerApEnAtTWZeVrVlt+iXwtOG0vRQnsnUEQfc7bWNi2MbOiAnGGu3mInOQRSRKd\n\t\t\t\t\t\tJ++owbwu6swr/BMPV2VbtnaHlqS5oB53K4VcmyWDa1L5bwoljHMR++kjnoaYMfD3\n\t\t\t\t\t\tBY5ptVSPnXzLuP7PhKiT2Q4ZtuovQQiRRRauZjh15l3h4zcpiBrVP1hWYS67WMW/\n\t\t\t\t\t\tL/dousPDjtTSZHw4sMp1xZnYMuJ2GVDFAgMBAAGjUTBPMC4GA1UdEQQnMCWCI3Vr\n\t\t\t\t\t\tLWJyby1paXMtMS50aG9tc29uLWludGVybWVkaWEubmV0MB0GA1UdDgQWBBQ4E1v3\n\t\t\t\t\t\tu6BpS67jBb9VGJdSo3CNcDANBgkqhkiG9w0BAQUFAAOCAQEAcU4fTT8j/+B5Br48\n\t\t\t\t\t\t7gTwG6cjyc/YFcfvWkPeQ1ZnhnXm/rQ0vy5WZL4KZ3EIRopfVuNbmudu2etoM569\n\t\t\t\t\t\tuoVzMdbSdRkFAJK61lViEqtBrbpNgFVIEBWJzzQQWfrc9NOQrbFU/lzQSw9YS2a9\n\t\t\t\t\t\tAaNlVgSAo0o7auuZQP/dVXQ4SPXRxatszMWhU0EcrGwULFZ0eVu4NoICCnqR1c8p\n\t\t\t\t\t\t/+Ja7rfVNsWnCNjjj0BS3sb/6w/TjEuC0Y6BfDRXmj8Q10/2JGsrHzKhf5ohsjlt\n\t\t\t\t\t\tWLqvM4GE7PTvOXAdB18th+p8IreWjHR/Qz0CuhhrHXZtFyu68QBLBPvLikydoYvM\n\t\t\t\t\t\t3mQlrA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJAJNBy2AlSZCeMA0GCSqGSIb3DQEBBQUAMC4xLDAqBgNV\n\t\t\t\t\t\tBAMTI3VrLWJyby1paXMtMS50aG9tc29uLWludGVybWVkaWEubmV0MB4XDTA5MDYz\n\t\t\t\t\t\tMDA5NTAzMFoXDTE5MDYyODA5NTAzMFowLjEsMCoGA1UEAxMjdWstYnJvLWlpcy0x\n\t\t\t\t\t\tLnRob21zb24taW50ZXJtZWRpYS5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQCfJy+boHJDh9FkG5nnjeFbooXmLO8jzEemA+Y4IOaHnLkLVwVG6EKS\n\t\t\t\t\t\t6rfM6vx+xrCxiVmRw9MZ4OaIuvLs6zMup8GfWWA4b2nBX47m4LOMZ8o24iSTkzV+\n\t\t\t\t\t\trIerApEnAtTWZeVrVlt+iXwtOG0vRQnsnUEQfc7bWNi2MbOiAnGGu3mInOQRSRKd\n\t\t\t\t\t\tJ++owbwu6swr/BMPV2VbtnaHlqS5oB53K4VcmyWDa1L5bwoljHMR++kjnoaYMfD3\n\t\t\t\t\t\tBY5ptVSPnXzLuP7PhKiT2Q4ZtuovQQiRRRauZjh15l3h4zcpiBrVP1hWYS67WMW/\n\t\t\t\t\t\tL/dousPDjtTSZHw4sMp1xZnYMuJ2GVDFAgMBAAGjUTBPMC4GA1UdEQQnMCWCI3Vr\n\t\t\t\t\t\tLWJyby1paXMtMS50aG9tc29uLWludGVybWVkaWEubmV0MB0GA1UdDgQWBBQ4E1v3\n\t\t\t\t\t\tu6BpS67jBb9VGJdSo3CNcDANBgkqhkiG9w0BAQUFAAOCAQEAcU4fTT8j/+B5Br48\n\t\t\t\t\t\t7gTwG6cjyc/YFcfvWkPeQ1ZnhnXm/rQ0vy5WZL4KZ3EIRopfVuNbmudu2etoM569\n\t\t\t\t\t\tuoVzMdbSdRkFAJK61lViEqtBrbpNgFVIEBWJzzQQWfrc9NOQrbFU/lzQSw9YS2a9\n\t\t\t\t\t\tAaNlVgSAo0o7auuZQP/dVXQ4SPXRxatszMWhU0EcrGwULFZ0eVu4NoICCnqR1c8p\n\t\t\t\t\t\t/+Ja7rfVNsWnCNjjj0BS3sb/6w/TjEuC0Y6BfDRXmj8Q10/2JGsrHzKhf5ohsjlt\n\t\t\t\t\t\tWLqvM4GE7PTvOXAdB18th+p8IreWjHR/Qz0CuhhrHXZtFyu68QBLBPvLikydoYvM\n\t\t\t\t\t\t3mQlrA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.creativeclub.co.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.creativeclub.co.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.creativeclub.co.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.creativeclub.co.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.creativeclub.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.creativeclub.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.creativeclub.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.creativeclub.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.creativeclub.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.creativeclub.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib.zcu.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Grolmus"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "indy@civ.zcu.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.zcu.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2010-09-22T14:22:17Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/university"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUCDrOzILCIUYr3TrnUQPEsHWa+wMwDQYJKoZIhvcNAQEF\nBQAwFjEUMBIGA1UEAxMLc2hpYi56Y3UuY3owHhcNMTIwNjE1MTIwNzE1WhcNMzIw\nNjE1MTIwNzE1WjAWMRQwEgYDVQQDEwtzaGliLnpjdS5jejCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAIZDgPqv9Pzl5boNk7nXJpoxPt4AVs++zbuJNPU8\nkJWFdeXrjB2m2wGSDm+1X33NrnkGs2LrNqSqjfXdoPM7UwBKUzqZx6qNSsDssrKt\nS3vK8RfyOss31NXhY6tgG4nw1YhO4324spqFIA7oXMR/QxuPXHnRxUMZjln0XgeM\nhAeHcJJYU/c8ZbLPr4M7eVeQSnzccvkdIc1Hil5qpsdpvb48yvUCOKl7Flm/iVLM\nOKlj1i4IKGSQNd8cUnZZukWK62/H1pr7Al6368zJqkYKvUJbRNfRiXEeV3c9pcg/\n/bx/j66ebUulE4A4ITpE5oQvMpgx/1w2h76mY9rHzTHBMp0CAwEAAaNdMFswOgYD\nVR0RBDMwMYILc2hpYi56Y3UuY3qGImh0dHBzOi8vc2hpYi56Y3UuY3ovaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFHLlm9ZAYoCIoT1NQsdo7sPzShFWMA0GCSqGSIb3\nDQEBBQUAA4IBAQAHtEngv7KaSiRJxFaLn3VdzH6f3SC4xNGKTPyGVq0pBrwUitf4\nkMl17K3Hg73ef1D+wInl3+9IuoCDsTH2wKKD3tUSZsL+xgekRGiIu3LIFcoa+U+o\n5n1nnfZ7xfvh8lgmsRZ7TVC3dXFl9wU+BmsVvOWEjneOA5oZQ2MUkKDC9+5sh6jV\nBXl4hMGBSLfs19/xa81PR7nkC9e6N0ri6nq6rT/SwoXXsAxHMHRz9M9gSq5lwxYO\nd+orcDxYVF3fdNbigr2b4qcgMeVygTsdcroU8EncIRMRLw0Wdb5Pk86KmCj74dRq\nC9OOk807XNhUC499735YXOv2kFUlCx5mZeOk"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "zcu.cz"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gapps.zcu.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.zcu.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.zcu.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.zcu.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.zcu.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.zcu.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.zcu.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.zcu.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.zcu.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "zcu.cz"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gapps.zcu.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.zcu.cz/en/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.zcu.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for students and staff of the University of West Bohemia."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro studenty a zam\u011bstance Z\u00e1pado\u010desk\u00e9 univerzity v Plzni."
                  }
                ],
                "logo": [
                  {
                    "text": "https://shib.zcu.cz/icons/zcu_logo_40px.png",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "40"
                  },
                  {
                    "text": "https://shib.zcu.cz/icons/zcu_logo.png",
                    "height": "102",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "102"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of West Bohemia"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Z\u00e1pado\u010desk\u00e1 univerzita v Plzni"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUCDrOzILCIUYr3TrnUQPEsHWa+wMwDQYJKoZIhvcNAQEF\nBQAwFjEUMBIGA1UEAxMLc2hpYi56Y3UuY3owHhcNMTIwNjE1MTIwNzE1WhcNMzIw\nNjE1MTIwNzE1WjAWMRQwEgYDVQQDEwtzaGliLnpjdS5jejCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAIZDgPqv9Pzl5boNk7nXJpoxPt4AVs++zbuJNPU8\nkJWFdeXrjB2m2wGSDm+1X33NrnkGs2LrNqSqjfXdoPM7UwBKUzqZx6qNSsDssrKt\nS3vK8RfyOss31NXhY6tgG4nw1YhO4324spqFIA7oXMR/QxuPXHnRxUMZjln0XgeM\nhAeHcJJYU/c8ZbLPr4M7eVeQSnzccvkdIc1Hil5qpsdpvb48yvUCOKl7Flm/iVLM\nOKlj1i4IKGSQNd8cUnZZukWK62/H1pr7Al6368zJqkYKvUJbRNfRiXEeV3c9pcg/\n/bx/j66ebUulE4A4ITpE5oQvMpgx/1w2h76mY9rHzTHBMp0CAwEAAaNdMFswOgYD\nVR0RBDMwMYILc2hpYi56Y3UuY3qGImh0dHBzOi8vc2hpYi56Y3UuY3ovaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFHLlm9ZAYoCIoT1NQsdo7sPzShFWMA0GCSqGSIb3\nDQEBBQUAA4IBAQAHtEngv7KaSiRJxFaLn3VdzH6f3SC4xNGKTPyGVq0pBrwUitf4\nkMl17K3Hg73ef1D+wInl3+9IuoCDsTH2wKKD3tUSZsL+xgekRGiIu3LIFcoa+U+o\n5n1nnfZ7xfvh8lgmsRZ7TVC3dXFl9wU+BmsVvOWEjneOA5oZQ2MUkKDC9+5sh6jV\nBXl4hMGBSLfs19/xa81PR7nkC9e6N0ri6nq6rT/SwoXXsAxHMHRz9M9gSq5lwxYO\nd+orcDxYVF3fdNbigr2b4qcgMeVygTsdcroU8EncIRMRLw0Wdb5Pk86KmCj74dRq\nC9OOk807XNhUC499735YXOv2kFUlCx5mZeOk"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of West Bohemia"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Z\u00e1pado\u010desk\u00e1 univerzita v Plzni"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.zcu.cz/en/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.zcu.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of West Bohemia"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Z\u00e1pado\u010desk\u00e1 univerzita v Plzni"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sa-test.ted.is.ed.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:is.helpline@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-certs@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Apps Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sa-test.ted.is.ed.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-04-18T08:51:42Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Student Allocator - TEST Environment"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sa-test.ted.is.ed.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sa-test.ted.is.ed.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sa-test.ted.is.ed.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sa-test.ted.is.ed.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sa-test.ted.is.ed.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sa-test.ted.is.ed.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sa-test.ted.is.ed.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAPiFnX/AGXS/MA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\n\t\t\t\t\t\tBAMTFHNhdC1zYS1hdDF0LmVkLmFjLnVrMB4XDTEzMDIyMjEyMDcyMFoXDTIzMDIy\n\t\t\t\t\t\tMDEyMDcyMFowHzEdMBsGA1UEAxMUc2F0LXNhLWF0MXQuZWQuYWMudWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDZWzFApufviUmWOb4eZ/Rf/2U1+0at\n\t\t\t\t\t\tEFW/52W/u2Iw9m//9VQ6Cmyd/mRwVLyA9czHl7kfMVcjotbhi4VHQwgN+HyNcZUW\n\t\t\t\t\t\tbI7WaVCtHyQyzBOpMM4Wv7+i7qI3sdkXqmKKu6MCmr4k3rLiVObuGADn2INLZ48Y\n\t\t\t\t\t\txS1wg9mnJX8/2WtzjL3E6aW3ehXozsQ9PGD6zFMfnxpZcO+b5iHQ74opo8fcwajF\n\t\t\t\t\t\tXg9d9xo4sdUbxvNnUDrE7+GXm7LQUErwpKnz1rqQFrK3xwt3D1kWs9dqc0nx+0As\n\t\t\t\t\t\tghF3QkXLrUc99DmZAcYIhiwCd/KIqtqml3WkMvE8g6A1aK9A/Cdx9E7pAgMBAAGj\n\t\t\t\t\t\tQjBAMB8GA1UdEQQYMBaCFHNhdC1zYS1hdDF0LmVkLmFjLnVrMB0GA1UdDgQWBBTD\n\t\t\t\t\t\tM6QITNYO3b7WJKWqUPckzkpzzjANBgkqhkiG9w0BAQUFAAOCAQEAKo+YeiJkib22\n\t\t\t\t\t\tEcMLNrtDi6ehAheTWZUT//zUfKYA7tcCbVaVlloDjcqkVciqFIt5z0eX/c7pXzR6\n\t\t\t\t\t\t1ljp6Rv1NIrNu4qxS3PLlCP4WHiGwvQDvbvVnk3Y/iYkUcdnRKnGWQUDOmecK1Mb\n\t\t\t\t\t\tq44Etl9/3KCm+Tq4VPDTfBYaAGk/GTR2AFdYm7rTcKhB3ngzRKkNU5hCLkeDgZPD\n\t\t\t\t\t\tCx/5AlRbCnfNhNDUrEv60WPdmwE21yV4R7tXWfuToTw/ubrc06yf+akxOPvd0y9m\n\t\t\t\t\t\t1YWgivRKg2HaES0eeVEq9sbJEY8rit1UQnOfZ/FGpt+EgYI9F/E9ZHGN2ukKJWIO\n\t\t\t\t\t\tjau5581/Rw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sa-test.ted.is.ed.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sa-test.ted.is.ed.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sa-test.ted.is.ed.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sa-test.ted.is.ed.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sa-test.ted.is.ed.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sa-test.ted.is.ed.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://verify.sheffield.ac.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:xiang.chen@digitary.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Xiang"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Troy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kevin.troy@digitary.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kevin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://verify.sheffield.ac.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-07-11T16:20:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Digitary DARE Service"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.digitary.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Digitary"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://verify.sheffield.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://verify.sheffield.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://verify.sheffield.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://verify.sheffield.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://verify.sheffield.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://verify.sheffield.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAKvu+ZotXOBYMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGGRpZ2l0YXJ5LmRhcmUudWxjYy5hYy51azAeFw0xMjA0MTIxNTA4MDhaFw0y\n\t\t\t\t\t\tMjA0MTAxNTA4MDhaMCMxITAfBgNVBAMTGGRpZ2l0YXJ5LmRhcmUudWxjYy5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAONwiFdIwZkaerJXg8Wm\n\t\t\t\t\t\t47ddT4dPw4AYVWgk2Uy64qQvAgbaSQi1mknnR27bhWyg5iCA3z9IrfLtLmF6O4do\n\t\t\t\t\t\tQ5nMjXcnCVivz0hubTlFLgqtbo1XXddm+WYrpsoBhATbgLcz8XG/TdQWzqPjf6xR\n\t\t\t\t\t\tjslpbjf8YTDCigoLpxnrBfJeY8ns81RaxtDOS/eg5JgjpohSbnJK5kum4twpEVPK\n\t\t\t\t\t\t/Z6EmoIKsCQ2YTzcn1PmlxT3czYxBS5Hr54tt1W7JUtZPlrWyMJnQVof7MZSTeLr\n\t\t\t\t\t\tpiH74BxtfbN1n7AwWvGSdj7D8saRahKv9YzexaGKNggAlXE7lwDSRAagh/MKIX4V\n\t\t\t\t\t\toasCAwEAAaNGMEQwIwYDVR0RBBwwGoIYZGlnaXRhcnkuZGFyZS51bGNjLmFjLnVr\n\t\t\t\t\t\tMB0GA1UdDgQWBBQJeESLMMOvuBxCw/egquAAUDHR2zANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAPF1yxkncDbJ0WwRpnleXV2P7GGDKenIbcIH69ad+0IARiyCvKJxX1vpfkD2C\n\t\t\t\t\t\tFmis9+MURBeMMpRUpRsIGh9O2SMMQT/aTMHqoSWOMGiJW9fM6PCS18Z5Zx4aTgyq\n\t\t\t\t\t\tO1ez0wHjbR1vW/TfSM/b6A2ovLqR+6bbbaymu0wu5UbNofG1uSRgkKT9kgeiGLWq\n\t\t\t\t\t\tVqagedqlmGej4hnCq2/+hMGTdeRiCrgFwUwVL8ZLfs8YptRka8WPuEsXieI7m7rf\n\t\t\t\t\t\tTzJxScFtn4xmZUOrC5VFdXH5j4S8/6M6kYiw2iQAbpSBBn1Azow1sWj2JzY4yUMZ\n\t\t\t\t\t\tJXxZbc0L9R3Upa90FjFH8QnxXg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://verify.sheffield.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://verify.sheffield.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://verify.sheffield.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://verify.sheffield.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://verify.sheffield.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://verify.sheffield.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.test.uppfoljning.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.test.uppfoljning.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.test.uppfoljning.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.test.uppfoljning.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.test.uppfoljning.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.test.uppfoljning.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.test.uppfoljning.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.test.uppfoljning.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.test.uppfoljning.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.test.uppfoljning.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.test.uppfoljning.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.test.uppfoljning.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.test.uppfoljning.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.test.uppfoljning.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFTDCCAzSgAwIBAgIJAJwQ1AOzvzh4MA0GCSqGSIb3DQEBBQUAMCgxJjAkBgNV\nBAMTHXd3dy50ZXN0LnVwcGZvbGpuaW5nLmxhZG9rLnNlMB4XDTE2MDExMzA5MzYy\nM1oXDTI2MDExMDA5MzYyM1owKDEmMCQGA1UEAxMdd3d3LnRlc3QudXBwZm9sam5p\nbmcubGFkb2suc2UwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQClXTeW\n/wJJQsTLzSeJ753U+8cwpv7FOwkUpCcHH6bb7nVIdcJDuYQOw8JVBl9S69cEXXcG\n+VevlFNf4qU9bKEGQKnd15YiybR5sus4x25dG4aGk7p6ZapsDoSg/CKwrbhmOjYT\nOCCjHUrsUdBEe0spS4qBGo5QVgMBMBWEhL85pxFxO95j80iU7LSQIKZSMWBZzm37\nouSxsXT/x52Ao6HtlWK17BF0m9kW3uLW38wlaP7JTWTnve1CMaOMVEbDliw3ysX7\nuO6fKvTWTkpzG62offlKKExCbyH340X5TI8dOhyYOlFyrpccdSCQkcSviSJ4oL0j\nXAO+rCV1PngoecLThIidN8sSqIwL5nFDULCNURYIpd7w15wu01I5y8dy9NUOvZ3b\nXZ16mPKQpL2nGJe1wRS1jSpooeG5TAxvOwdKBLgzeqZ4I1FC0Dha70FfmWrJ0Opt\nsYTQ2jbCxtDx6tBHK1dw9OX/flxqmnxsvNJ/ALuzxbRMJL/j/Yi4SAHnAUtdOFqo\nVK/FxqVwqRRB7igCVIuviZbA7GeODnwah+Llv12vvfis+wipQQ5aKA9DpbK+KwP6\nOsgOZSBhvCCKvMGuxgVifzxSJeQxG2WoehEtuhnUCao+L7WE+NLY5hOUowsQLN+a\n/jlCye3nnQ0lb7ZOxHREazCbztPgO4VX/O40EwIDAQABo3kwdzBWBgNVHREETzBN\ngh13d3cudGVzdC51cHBmb2xqbmluZy5sYWRvay5zZYYsaHR0cHM6Ly93d3cudGVz\ndC51cHBmb2xqbmluZy5sYWRvay5zZS9ndWktc3AwHQYDVR0OBBYEFK9iv5wSca5C\n+6vltre0Ko+Z9X98MA0GCSqGSIb3DQEBBQUAA4ICAQBlidVziryz78l+6jlhxif+\nAXSJBQDeNoJ2ApxD9mBdJcXb4O/Huy2o5Ijo19vP0RPM6svK9TafHaOuGR1ZmlJe\nlQY+z+Decit9NsugZTaq2n2eMCqFhDy/Ybu8IEurJ9E09t2o5itqhGUgwJpG3BhV\nfdbKJSwoF2JSAn/PDZaNo9IdOGqxqHvVds4A6WzYVsDl0XiTqeMhb5My3K4nz8ER\n9VdsdldJTRqGp06pxkr2XLUSkX36yyV5uf2M1SR1aNl1WTVmB6/LePSOTgsUCV2r\nXr6/QoflBFXZySNWV7f1klzl3MnmfOyWaBUILGh2Ke4/L2azEXil5jApeVnt+y6e\nQl0ZjEruBkDpCkltdew1vaDRuJAPd5NC6LPXWjozZYNx8dNcze/yJTjoWwPltvf8\n0pAU9qPKqLrlX3ZWmtWh6ymT2XnK4mINjpcS3uDZDSkgMZAsgs8SpTdrgtE89sLz\nVqAUw5BQrZQYhV+AtqWCOnQcxaC9mLkdB6wpfZu5xrgWgQGcAvJM0lnOP/LAQPny\njiCPF0Mux4hPUalhs5RJfQhUZBIo5c0PZSohzHn2pNIWMkppphOMEMrc/HBuDbAZ\nOGHgoQN0dxACvHw1YMHvyFWI+NYO1070o6sY9/MwGyrCClplXiMnDmfbyIsfvq6u\nqqt+VY+dgL11MGCZOGpJVg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.test.uppfoljning.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.test.uppfoljning.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.test.uppfoljning.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.test.uppfoljning.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.test.uppfoljning.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.test.uppfoljning.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.test.uppfoljning.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.test.uppfoljning.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.test.uppfoljning.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.test.uppfoljning.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://strong.renater.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@renater.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://strong.renater.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-10-06T11:04:46Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://strong.renater.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://strong.renater.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://strong.renater.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "renater.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.renater.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "RENATER 2FA authentication Identity Provider"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Fournisseur d'identit\u00e9s \u00e0 authentification forte pour le personnel du GIP RENATER"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "15",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RENATER - 2FA"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "GIP RENATER - Authentification forte"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAKDRx8im6zJdLQ5NHz5dmbcaOBjOMA0GCSqGSIb3DQEB\nBQUAMBwxGjAYBgNVBAMMEXN0cm9uZy5yZW5hdGVyLmZyMB4XDTE0MTAwNjA3NDIx\nOFoXDTM0MTAwNjA3NDIxOFowHDEaMBgGA1UEAwwRc3Ryb25nLnJlbmF0ZXIuZnIw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCcmKoiaTCP4jY9v53P+M5I\nvUAbcaFievc311/2CTLBAucCceVTZ9VwVoucZiQ9ZOebD2DtrxLqNJb/RMh5pyXj\nQzr86Hwv5Yk3+BVpru02HiOzzGbBqWVjwgZ1HFTSfnqwAYP4zZsu7nx8X/SK+ZJV\nSjxiSpe/Y6Rm+t7gWBfZXYSWvKGu01fbywcVqaeGrGz/UQdi0jvhGwNbK7AUCb+J\n/zSw+tkxxAoDdf/8/uk1LScWt2Uim3HqL9a9E9jrrz6b0s2+6ws8asCL1TD3uAXQ\nIPZAmm3F+TZeJv89+VnI1UM7WsdQaCpZBZXLDXuVDnFFZ/j0Ol+rSTdnYVaws+ev\nAgMBAAGjaTBnMB0GA1UdDgQWBBR7MXxBw9coUGjDO8AWpl+AODh4EDBGBgNVHREE\nPzA9ghFzdHJvbmcucmVuYXRlci5mcoYoaHR0cHM6Ly9zdHJvbmcucmVuYXRlci5m\nci9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAVdeiyyjO1mbphNLM\npc9tRSsPVeKkxBv7GFN4FaOivBJn5jTLKgCR3AEulI6ySreL9sgrMsN6LggFsFpW\nkjf4iyilbXeH0EQD05teoVCuaZf0JmT+bfbLGLZuHJckOJQW9WqIh8mog8g58chu\ngk019fVk/DFoPIZXyJZDD8FWLuZk9im8KlCBXNbGAwjwz5tfNkWlMAbaVUqdEvr1\nrlzS4uoe3sVAeC3OBKLjHEWy4/NybEmhfjFbIlqrPc579lsn6mJKvrf82Gx6PDry\nOnHGNIjw12pVU5I3hY1A7X/xRZLG0U90KdPekhyE4KXeutJumdwGYj/pC21jsOzy\ngshHXw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GIP RENATER - Authentification forte"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.renater.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GIP RENATER - Authentification forte"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://scotlandonscreen.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ciarrocca"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:web@scottishfilm.scot"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paolo"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ciarrocca"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:web@scottishfilm.scot"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paolo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://scotlandonscreen.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-01-19T16:04:50Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Scotland on Screen"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://scotlandonscreen.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Scottish Film Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://scotlandonscreen.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://scotlandonscreen.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://scotlandonscreen.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://scotlandonscreen.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://scotlandonscreen.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://scotlandonscreen.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://scotlandonscreen.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Access to hundreds of historical Scottish film clips from the NLS Moving Image Archive."
                  }
                ],
                "logo": [
                  {
                    "text": "https://scotlandonscreen.org.uk/sites/default/files/SOS-UK-Federation-SSO-Logo.png",
                    "height": "120",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "320"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Scotland on Screen"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4jCCAcqgAwIBAgIJALvpeqGCbrAQMA0GCSqGSIb3DQEBBQUAMBQxEjAQBgNV\n\t\t\t\t\t\tBAMTCWxvY2FsaG9zdDAeFw0xNjAxMTkxNTEyMjFaFw0yNjAxMTYxNTEyMjFaMBQx\n\t\t\t\t\t\tEjAQBgNVBAMTCWxvY2FsaG9zdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAM5SsuMdGSD8tkkEq6thm77ZbSDuB4idZrhgFu9pRwJ5c6YqrOhPxQEjNjVZ\n\t\t\t\t\t\tKXOuEJRHlgWc2evrvn8Cx+ofJGbTrwGMG6ueWxC+6Nfkd5QGKeI3y+4XbWv0o/Bu\n\t\t\t\t\t\tS5HuzxqcuCvFOX4ZCsCPyl7ruYzI/mI76/wqPARQpt+du1qqLM579CDDBe/ozd2R\n\t\t\t\t\t\t8buo6Kx/0JTKdNHwMFJaZ1QA1+6kWzFTbqLwRluHnOepOOtbVioKXE1qom1gtcoV\n\t\t\t\t\t\takKXtbNhAFEVC+GyiSD//Eiz+5Oey+t/XFoYHVImoHytHvt8Vwshbz624ADyBcmS\n\t\t\t\t\t\tznilw+6WkPiRVPBo5qD6jZKmzekCAwEAAaM3MDUwFAYDVR0RBA0wC4IJbG9jYWxo\n\t\t\t\t\t\tb3N0MB0GA1UdDgQWBBRT/yO7ueYOX/mF++TAc1dUz5sVozANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAN/YX3n+LpBWiByVxrBYkLl8dJDMjUy6Aqn4gYjCtY2Ljia5USA70tqy9\n\t\t\t\t\t\tfQ8fIynCIFMVl6JpxxVE9olv63qIT0kGF4Q3wBZn3SyyqG60HSH7CyjpKM7jFzC7\n\t\t\t\t\t\tsZYgGhTOna/N7I+3Mmo0v4gOVwHOcEpQZdcXbrV4t539NKa8kO7vrmp8CbYircd1\n\t\t\t\t\t\thqPtZldMR6qoV+kwL1MT1AdOMxS6AMtkZHkoGBC7G0BXHhYZxAdDloSNZ7Clbl10\n\t\t\t\t\t\t3Fh80Lk8STk4KhOTz/TCixAzlwYWnvQta3rwkjutFhmMCNmInc8+W4zpQ3GO26Y2\n\t\t\t\t\t\t3BS6l6Hdh67Mi3kGZWtG6W0K3ehc3g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://scotlandonscreen.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://scotlandonscreen.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://scotlandonscreen.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://scotlandonscreen.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://scotlandonscreen.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://scotlandonscreen.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://csus.infoready4.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jtesta@inforeadycorp.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Testa"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://csus.infoready4.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "InfoReady Corp"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.infoready4.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "InfoReady Corp"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://csus.infoready4.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://csus.infoready4.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://csusb.infoready4.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://csus.infoready4.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "InfoReady Review - Sacramento State"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6zCCAdOgAwIBAgIJAOO9wmxE2PCSMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDGluZm9yZHl3aW4wMjAeFw0xMzEwMjkwNjE0NDlaFw0yMzEwMjcwNjE0NDla\nMBcxFTATBgNVBAMTDGluZm9yZHl3aW4wMjCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAMpdE35LzF2eEaAhLfxtotv6XhMXfkOMbugHq8xk5rhyx7RKS+Ku\nt9wW8Mv2rG7NAJw+8167dP6N2RQKpRBn17FIOhm/cuSNtiTBJtA9QiTEkyN5D1ma\nykJjlD95ymo0XdRDWwz/6IP5v+d95BlfbnlkswWOGOMLxCtaWCSZQ00RJFDKudL5\nIrK+2A1KwF4O+DxqivhdLsd/yA+IjX1efYnT7MPsd7Yyh5wKXKkGbKEg9yAW65Dt\nx2xbBCjDT2PCBhJ4ZuRfUv8whBCT2qgH6+pQ5JBN9ZDz1iGDFp8XfQ27UtzlFdBc\ncjvWmtOh/V35fBXl5LIbJdU/ypJMBwehxbcCAwEAAaM6MDgwFwYDVR0RBBAwDoIM\naW5mb3JkeXdpbjAyMB0GA1UdDgQWBBQTyklRhSLuL0VcI0Nv4tQhZYqHITANBgkq\nhkiG9w0BAQUFAAOCAQEAJyNYKdKAFdp7xvqnjszw+AF3dYl3HQKe5bC0M+gu7G+2\nhJL2D70cFCXXi2bNcdyLsFVPiecMo69QinOP3kqCPNL7S5pSjm48T9bTiRr4WNy1\nhkxJ7nCV++z696YqbE7WYec9LEpcNDnDnmDfQOxvxzdtpIyM3Egw+koKEZu13ebw\nzAs2xgBj3V5YWmzS7nk1wPPJBKpr+9W5xixEGfaKfrrQXayP/LVyN+u/3BjZCZfE\nbfqmalH+rjpJ7ZCck4CQFxCvnLhwl+L5DEuEFXmgTzk7EDb65no+rXaZQd3/IEre\nsazovBHNw8FPYGiOCi2757flvBsb6gW+FbN0SPmtSQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://csus.infoready4.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://csus.infoready4.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://csus.infoready4.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://csus.infoready4.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "InfoReady Review - Sacramento State"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://dun-shib.hosted.exlibrisgroup.com/shib",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bieber"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:frank.bieber@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Frank"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bieber"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:frank.bieber@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Frank"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dun-shib.hosted.exlibrisgroup.com/shib",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-07-24T15:45:02Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Dundee - Primo"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.exlibrisgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ex Libris (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dun-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dun-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dun-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dun-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dun-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dun-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dun-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is an Ex Libris Primo Hosted SP on behalf of the University of Dundee"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Dundee - Primo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAJQ23rWbODdWMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB2FpbzAwMDQwHhcNMTQwNzE4MDkyNTEyWhcNMjQwNzE1MDkyNTEyWjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdhaW8wMDA0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\t5glgMq+fQ29qwkY7AJ+/uzOPwA1tLN5SptMA6+f0IolQ0HFpxZO8EeRGFCcSzJuA\n\t\t\t\t\t\t5Hpqu7Nlw3w7Xr168dryTwlbGmk2bEe+kVIyExCSumaJnTDBKkfk2snt88BMyKjZ\n\t\t\t\t\t\t20v8hgLWCQZRdDFkeNj8WJaaoh2NW2Mj5o/PLStyV5PRvDdd3NY6rwXaeEzU+DBG\n\t\t\t\t\t\toDBuyaW+55KCARSRk7G7jkVFpKFhpEfV3ZBoBHv2aK+8goph+1P2C6VvmuR20o91\n\t\t\t\t\t\tmkw/4/wK/U/2XrQP+Ofjbko/R2/avHDXnURioval7bMqw79Cnoyv0jAlwA4MqRB2\n\t\t\t\t\t\tx/OeHn0J9A1ThP7xJ6g11wIDAQABozUwMzASBgNVHREECzAJggdhaW8wMDA0MB0G\n\t\t\t\t\t\tA1UdDgQWBBTAa8dYEU0eoa5tnDvh5Vw1bCHlbTANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tLLadg5+o6PZfG4zc/sp21OQJqVEg2bWRzvDxH1uWmRomROwoi9rLLU2aTc1JyGxi\n\t\t\t\t\t\tzeBFZ9eU1zzpehoZU0bXoO6jriAEk+y2iGVNnDbNxFT+ZRnwhqLKXiMcCYsBSUr7\n\t\t\t\t\t\tm+PE4dX9adMSg6Cbj3qBMeHhf7ldHlpbhl1mWF8gP8B89k0naEkPj++iXVdB8Mfc\n\t\t\t\t\t\tTi1c523T/2nNmxXcbV1bTFOTr0HqwqHfVPhaW9FJYhVcJUJbzxSE81NMw+mj1/Wg\n\t\t\t\t\t\tq4siWF12Yd75zPaunEP9b6LSH9+jslVmnSHpbdS7wLa4wQuKifo6N8PteKoR1Aps\n\t\t\t\t\t\trWT//SBgFvxK3ozSue4Nlg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dun-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dun-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dun-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dun-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dun-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dun-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibby.wmc.ac.uk/shibboleth-idp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fogarty"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ian.fogarty@wmc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fogarty"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ian.fogarty@wmc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibby.wmc.ac.uk/shibboleth-idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-11-16T13:29:41Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAJm8LRnbbTtCyAebesXC3JGiCv8lMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBsxGTAXBgNVBAMTEHNoaWJieS53bWMuYWMudWswHhcNMTIxMTAyMTYxNDQx\n\t\t\t\t\t\tWhcNMzIxMTAyMTYxNDQxWjAbMRkwFwYDVQQDExBzaGliYnkud21jLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmB+fHJr1LUyR9Z4JroVqJhPy\n\t\t\t\t\t\tOkmecEdAqw1uuIFVlyZ+XH4yxYE8fcOww4aKm0vEs6QRvrMHwr4w0ndRb2W/iWHK\n\t\t\t\t\t\tBGBfsafixfxI/aS40pc3OTzoXpo11535MsOzg4yTzulhKwi5MgYqX+Zb9Q/XaLFd\n\t\t\t\t\t\tmAkZC45yIjpPQvzjgHLHNW27dlfQiCdy9lzsL68FrYVHuZTV3AVAEyczC33HoRUA\n\t\t\t\t\t\tReCN5EJFpvbYL1NfsqaAQF7C9Yyga0WCTSjKugWEi3gjOePo6MFztyHYU8LvDeYx\n\t\t\t\t\t\t6vBtcnI1VjIycVHgI1g/t6MPm7buiaEJPl9230fcHZIG15/M8UqLxzM2Phru7wID\n\t\t\t\t\t\tAQABo2cwZTBEBgNVHREEPTA7ghBzaGliYnkud21jLmFjLnVrhidodHRwczovL3No\n\t\t\t\t\t\taWJieS53bWMuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFMcgJtREB6nk\n\t\t\t\t\t\tHiCQfshoRqRshvq6MA0GCSqGSIb3DQEBBQUAA4IBAQAp8LRX6cOK/u0y/bA8HCt7\n\t\t\t\t\t\t3PyZAwXyAGN905x9Yd7PCdnRxiI+WMKmuD01M71FM6apJFsHHkHv8IgvTZb10yXm\n\t\t\t\t\t\tbIbgE1718NiZTL33E08l+QAPUp/5AsEv4HFOmVgyOO5149w2pdwft/z23acf2fVV\n\t\t\t\t\t\tddz5OPjsJSdkZP//qO0C6lKsE+rlRXdBkuUVKopVPGLWV5xzk2yCzeIj6V/nzDbf\n\t\t\t\t\t\tfrMvrz8BJyqOnVn3ZPPCnURELyep6IyLChkzQv34g7hdewKWzF/fvrz1XAD2e3RO\n\t\t\t\t\t\tLf2uU4A+RncCtsGT3wOKNjecHAfQ5rZy+MGd3LT9iRDeWeHwF0+dYV2vSb43n90e"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wmc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibby.wmc.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibby.wmc.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibby.wmc.ac.uk/shibboleth-idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibby.wmc.ac.uk/shibboleth-idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibby.wmc.ac.uk/shibboleth-idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibby.wmc.ac.uk/shibboleth-idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibby.wmc.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibby.wmc.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wmc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAJm8LRnbbTtCyAebesXC3JGiCv8lMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBsxGTAXBgNVBAMTEHNoaWJieS53bWMuYWMudWswHhcNMTIxMTAyMTYxNDQx\n\t\t\t\t\t\tWhcNMzIxMTAyMTYxNDQxWjAbMRkwFwYDVQQDExBzaGliYnkud21jLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmB+fHJr1LUyR9Z4JroVqJhPy\n\t\t\t\t\t\tOkmecEdAqw1uuIFVlyZ+XH4yxYE8fcOww4aKm0vEs6QRvrMHwr4w0ndRb2W/iWHK\n\t\t\t\t\t\tBGBfsafixfxI/aS40pc3OTzoXpo11535MsOzg4yTzulhKwi5MgYqX+Zb9Q/XaLFd\n\t\t\t\t\t\tmAkZC45yIjpPQvzjgHLHNW27dlfQiCdy9lzsL68FrYVHuZTV3AVAEyczC33HoRUA\n\t\t\t\t\t\tReCN5EJFpvbYL1NfsqaAQF7C9Yyga0WCTSjKugWEi3gjOePo6MFztyHYU8LvDeYx\n\t\t\t\t\t\t6vBtcnI1VjIycVHgI1g/t6MPm7buiaEJPl9230fcHZIG15/M8UqLxzM2Phru7wID\n\t\t\t\t\t\tAQABo2cwZTBEBgNVHREEPTA7ghBzaGliYnkud21jLmFjLnVrhidodHRwczovL3No\n\t\t\t\t\t\taWJieS53bWMuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFMcgJtREB6nk\n\t\t\t\t\t\tHiCQfshoRqRshvq6MA0GCSqGSIb3DQEBBQUAA4IBAQAp8LRX6cOK/u0y/bA8HCt7\n\t\t\t\t\t\t3PyZAwXyAGN905x9Yd7PCdnRxiI+WMKmuD01M71FM6apJFsHHkHv8IgvTZb10yXm\n\t\t\t\t\t\tbIbgE1718NiZTL33E08l+QAPUp/5AsEv4HFOmVgyOO5149w2pdwft/z23acf2fVV\n\t\t\t\t\t\tddz5OPjsJSdkZP//qO0C6lKsE+rlRXdBkuUVKopVPGLWV5xzk2yCzeIj6V/nzDbf\n\t\t\t\t\t\tfrMvrz8BJyqOnVn3ZPPCnURELyep6IyLChkzQv34g7hdewKWzF/fvrz1XAD2e3RO\n\t\t\t\t\t\tLf2uU4A+RncCtsGT3wOKNjecHAfQ5rZy+MGd3LT9iRDeWeHwF0+dYV2vSb43n90e"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Wirral Metropolitan College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://wmc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Wirral Metropolitan College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.sbcc.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mghens@sbcc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael Ghens"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.sbcc.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sbcc.edu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sbcc.edu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sbcc.edu:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.sbcc.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sbcc.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sbcc.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sbcc.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sbcc.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sbcc.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Santa Barbara City College Shibboleth and CAS server"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.sbcc.edu/boardoftrustees/files/policies/AP%203720%20Electronic%20Communication%20Procedures.pdf"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Santa Barbara City College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUMMHZfx7g7KGhvDSG44Watjbf8nAwDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMaWRwLnNiY2MuZWR1MB4XDTExMDMzMDIyMDY0MFoXDTMx\nMDMzMDIyMDY0MFowFzEVMBMGA1UEAxMMaWRwLnNiY2MuZWR1MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnN6Qeae3fzGRYjbIsNuoubXFOkVBMxfmiMcJ\nuPqH7PD9/RIBXbma48lGpv3WeRCj9BBYP3hVwfiPWizfPDwyAO5PJo2zui8qy2Zl\nRdGOU2UI0JbrOVpEh+g/Xbr4P/EDdWVzMnUHvmIy6HW9i1rQ5qhLB5XXOjSM7Sv/\n/VisHiQ9+SyBhc7cayaWjcoLmSW+YDswLcy6GFQekEVyYXDwIUFiVXmT+uV98S3k\nDReV+SHQFPIR+vYofJqDYooYDFnLS0MAGtGzkO+VplZHo9AgEIK9QuqQ8LZ0nQ8J\nIyEUCqucCKcReLAY5DCNF+6pOwTFFGEV6Zpi8AtcYSdUriASWQIDAQABo18wXTA8\nBgNVHREENTAzggxpZHAuc2JjYy5lZHWGI2h0dHBzOi8vaWRwLnNiY2MuZWR1L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBQgNUz2RZi0aiVIoJRvVBRop3HLuzANBgkq\nhkiG9w0BAQUFAAOCAQEAXLqTc1GdORqZeoYeclmR+RniXnTpqOfcLoTqMVRH3bpU\nDJqLgRWRLL3lreQlfrOo414xm7ubNFLWklC8/vwFadaKSRXRNSm3xc/kTd/18SKc\nYMfdmVSVhIsaS+y9G+Z4JcrogXNp9VU9JRKog0t5cngrOTyNMn1C3Raw4H2L9WkL\nmKGlFTzgPur0sqyyd86chFfmtkTvOPsTBaGuBoz4L9Pnl+moxlzMhQBC2Mxmr/FG\neOKM7YKGt4+pqKx5cp4GeYWHYS8d0/XRF2vyCLwdLLOTai0cRqx+LRNtpEAV6z74\nQnbddsPUWZfmg0tNJbc8OhZPVC6Z0dq++C4sZqhJjw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Santa Barbara City College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sbcc.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Santa Barbara City College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://jira.it.su.se/Shibboleth.sso",
    {
      "entity_id": "https://jira.it.su.se/Shibboleth.sso",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jira.it.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://jira.it.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jira.it.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://jira.it.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jira.it.su.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://jira.it.su.se/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://jira.it.su.se/Shibboleth.sso/WAYF/wavelan",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "jira-prod-app1"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJAKO40oiNNokAMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDmppcmEtcHJvZC1hcHAxMB4XDTEwMDgyMzEwMDkwOFoXDTIwMDgyMDEwMDkw\nOFowGTEXMBUGA1UEAxMOamlyYS1wcm9kLWFwcDEwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDK1jIyprLcwZSC0tZxTwUerRm0igvgtt0WP5SeETSOtioh\naBURLewSZ1Z+ea2WLaOIn6tW5jgKykVRcSMeaJ5JkW59KrzJo9+qJgJkd+izp4HF\nw3jSubP1Xo3OADW6Vf4LsH3FTIcFaGfWaAI0hfX2R+N4Llwwnci4l/0Yth65sZPH\nxufMzH7b/JJf1ZGHpVsYiX6VVz0QCZM5n4dLJUxwpdmR1IsyVmuABo9i130MlBjt\nOt1aXWWf/XlhajMUkeuqFdEfpBqiBOSzV7nkRP7IAnxbzCE8z5hac5OAB+o8ueOu\nGztmeB/n+7lwOiN4MtqdoYlNpJRig42qIlwimtSDAgMBAAGjPDA6MBkGA1UdEQQS\nMBCCDmppcmEtcHJvZC1hcHAxMB0GA1UdDgQWBBQNbTCMshQI1Adr7JFGtx1Q8beG\nsTANBgkqhkiG9w0BAQUFAAOCAQEAN1YvkrZ45WXs56AUGcykmQ2m3YMjueiQP0Zt\ncyUJmJ6OMomhTA6eSoNvqv5h/g1dgVnF25wpsDhgwhJM1zgP6gArad02PfWrWVfx\nr/RrT2wGIYiqAnceTgtSJ7jbqKn2q2KZ6a4TKWiJDfYCPfA/ZLHgHanDCOaV8w12\n/JaEWVZldvm+MMLd9/pc8mr3TskEtunCs88mTT+xESt0alNJHnZX76ZPBQOVvzE9\nTSPz6L4JJM7OYEx92swJuDyjcGUWx6SHiumZtFh6t5FxlpIi2+bnV3iw9QP6M5dd\nFdYOem7PdnMNtROBFXZZ+vv1hrOfYBy7FrvBe49J9Yub+jaHWw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=jira-prod-app1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "jira-prod-app1"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJAKO40oiNNokAMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDmppcmEtcHJvZC1hcHAxMB4XDTEwMDgyMzEwMDkwOFoXDTIwMDgyMDEwMDkw\nOFowGTEXMBUGA1UEAxMOamlyYS1wcm9kLWFwcDEwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDK1jIyprLcwZSC0tZxTwUerRm0igvgtt0WP5SeETSOtioh\naBURLewSZ1Z+ea2WLaOIn6tW5jgKykVRcSMeaJ5JkW59KrzJo9+qJgJkd+izp4HF\nw3jSubP1Xo3OADW6Vf4LsH3FTIcFaGfWaAI0hfX2R+N4Llwwnci4l/0Yth65sZPH\nxufMzH7b/JJf1ZGHpVsYiX6VVz0QCZM5n4dLJUxwpdmR1IsyVmuABo9i130MlBjt\nOt1aXWWf/XlhajMUkeuqFdEfpBqiBOSzV7nkRP7IAnxbzCE8z5hac5OAB+o8ueOu\nGztmeB/n+7lwOiN4MtqdoYlNpJRig42qIlwimtSDAgMBAAGjPDA6MBkGA1UdEQQS\nMBCCDmppcmEtcHJvZC1hcHAxMB0GA1UdDgQWBBQNbTCMshQI1Adr7JFGtx1Q8beG\nsTANBgkqhkiG9w0BAQUFAAOCAQEAN1YvkrZ45WXs56AUGcykmQ2m3YMjueiQP0Zt\ncyUJmJ6OMomhTA6eSoNvqv5h/g1dgVnF25wpsDhgwhJM1zgP6gArad02PfWrWVfx\nr/RrT2wGIYiqAnceTgtSJ7jbqKn2q2KZ6a4TKWiJDfYCPfA/ZLHgHanDCOaV8w12\n/JaEWVZldvm+MMLd9/pc8mr3TskEtunCs88mTT+xESt0alNJHnZX76ZPBQOVvzE9\nTSPz6L4JJM7OYEx92swJuDyjcGUWx6SHiumZtFh6t5FxlpIi2+bnV3iw9QP6M5dd\nFdYOem7PdnMNtROBFXZZ+vv1hrOfYBy7FrvBe49J9Yub+jaHWw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=jira-prod-app1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jira.it.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://jira.it.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jira.it.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://jira.it.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://jira.it.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://jira.it.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jira.it.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://jira.it.su.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://jira.it.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://jira.it.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ap-hm.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "systunix@ap-hm.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ap-hm.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-10-23T17:04:52Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ap-hm.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ap-hm.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ap-hm.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aphm.ap-hm.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://fr.ap-hm.fr/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "French public hospital of Marseille"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Employ\u00e9s de l'Assistance Publique H\u00f4pitaux de Marseille (AP-HM)"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/x-icon;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Assistance Publique - H\u00f4pitaux de Marseille"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Assistance Publique - H\u00f4pitaux de Marseille"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAOhqE6xG9Jim8D5otVZZ5i3uzRwKMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMMDGlkcC5hcC1obS5mcjAeFw0xNTEwMTUxMzU4NDZaFw0z\nNTEwMTUxMzU4NDZaMBcxFTATBgNVBAMMDGlkcC5hcC1obS5mcjCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAIY+rUb89aEIChTwFLs99gcGQ5EtHJaulqox\nMSUiWmEXfCCBQKGFS1mAU+ZguVmKgO/6m9l0Yo1PtR5w8w0+RpA3MYoodWbLbYeX\noZwjBpfUuExo33jVXLE/mfp5qIWkXx3U48znJaeBvSsE+V2zhobM1bgMcRCLTYOz\nBbyO+BjUeWO0RMw1iEy3T1sRXE/R73x7gYllpDmL7KSLg7HV5p7IGWyRicVtkzZd\nCBtt8mvvsYfRUcU+bSL0Ihjg6V34WG7WfvKNyxOkA/6hEB/2uV0VQpT+Y+YLJIgi\neq8CUbZIuopfiUP/cRDuLfZHQX+zjGLG4zALWo4C5nEPgMH0PS8CAwEAAaNfMF0w\nHQYDVR0OBBYEFG9t3xe+StEVwDkJANyAvP/sZft8MDwGA1UdEQQ1MDOCDGlkcC5h\ncC1obS5mcoYjaHR0cHM6Ly9pZHAuYXAtaG0uZnIvaWRwL3NoaWJib2xldGgwDQYJ\nKoZIhvcNAQEFBQADggEBAGK9aEzoWXWZioZQ0977aE6liNJ7gtaNEvzJ/5nJ/l2R\nEe/zTfDr7kZCtwSga+cJMONNM6DIh6yIceHo8iIQYARQJ8FbsZkr0wMUDqeSva4I\ndUzkSiFNLDl0G/pQHnpc9zjtVAkGGRxyF4FH4UQw5Dk2Mw6EJbQumh4YXaeZ2zrP\nfv3rQ2OiSWaCaqlaS3NZ5FrBQ3qak8qdgbEEJMfXZn5Sktz8x+HgaSw8VaJy/9eo\n1lDRwcJL6+TF26PhCgpxAuG57NVtKW/HFGtvKdQ5ViHJ/8KfSErtB4l9akt7cHYW\ndmh1bRX6hc+FqDavw7bMJS6CyMnsnGL6oVO75Q3H/Is="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Assistance Publique - H\u00f4pitaux de Marseille"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://fr.ap-hm.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Assistance Publique - H\u00f4pitaux de Marseille"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayf.minibib.dk/dab",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayf.minibib.dk/dab",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2010-10-28T09:45:22Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayf.minibib.dk/dab/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dab.minibib.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Det Administrative Bibliotek"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The Administrative Library"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "dab.minibib.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICwDCCAagCAQcwDQYJKoZIhvcNAQELBQAwJjEkMCIGA1UEAwwbaHR0cHM6Ly93\nYXlmLm1pbmliaWIuZGsvZGFiMB4XDTE1MDEwMTAwMDAwMFoXDTI1MTIzMTIzNTk1\nOVowJjEkMCIGA1UEAwwbaHR0cHM6Ly93YXlmLm1pbmliaWIuZGsvZGFiMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAx4gMCmoQU7iOGfiCda4DnhIggst2\n0fUCHtwaQrHoxQlOa0s5FgDalbnNTw36dCXSGYaz17JgyUDJonTwhjyA0CqPm5Pm\nn9/hFBUvyP/t+bEgV9r3/odQx72VfY7M55qUlY6ex2f1qD1gcpFgSTtADlZswec5\nWqpEt+ie+vsMXq8HabhMVZ2EjXe90vgMk/xGfrVwDvupUPBS/2DJSZ1JEmkqi0hx\nctNQ9qgTZmEcAaQkuv3VGcsYtLeY/IISlA+ARzmVWr5+uSetnCXV4jnDEclACKee\nxl0Ky+tyra4yHF3Xavgmcmebd+xHVDiM+No6BXMu9zBTp7cp5ShLzsNQSQIDAQAB\nMA0GCSqGSIb3DQEBCwUAA4IBAQBZTLirpYuda3idsPDunSvgdGVDzAayHmhLENyI\nchRBHPJRV/fQKacjhbVnGGFjMOMDPrl7IdEkBZOcHwuEJml1vnXuZTOiC1A7AVzt\nlYyNdPAGwHGM0SLvAQXzVKnoqjqwBLe8eQJ6LGkUD8QoXSttzpFqR9cE+OJygCyn\nlRBzNCIm1IZkQuafkF06Ldbfn6usiJ4SbjT1Hot8Gef9PpI9qeDDToHY6o+lbrCP\naK8DxD18GwuVB0JFLjBNxqk4rJlYnB7k/q9JGrDqay8yfmFIAX9xoSpmz7qgHzK4\nv93+XEHzeHHw5pwvSa0YWMs2hXkVYFnHrTicG9bEV6qKoNYG"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Det Administrative Bibliotek"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Administrative Library"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dab.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://dab.dk/introduction-in-english/introduction-in-english"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Det Administrative Bibliotek"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Administrative Library"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dlib-schoolsidp.edina.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:edina@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EDINA Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:edina.infrastructure@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EDINA Infrastructure"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ukfed.infrastructure@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UK federation infrastructure"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dlib-schoolsidp.edina.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVzCCAj+gAwIBAgIUO/h0MjhhFFYR9sFrpG5zi9vVo64wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJjEkMCIGA1UEAxMbZGxpYi1zY2hvb2xzaWRwLmVkaW5hLmFjLnVrMB4XDTA5\n\t\t\t\t\t\tMDgwNjEyMjAwOFoXDTI5MDgwNjEyMjAwOFowJjEkMCIGA1UEAxMbZGxpYi1zY2hv\n\t\t\t\t\t\tb2xzaWRwLmVkaW5hLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\n\t\t\t\t\t\tAQEAvqi4P3wG3B/dkzSoOMs0ssqK4xB7bMh3nF+JGo2KqGjxDYyRJtWY5FwRsAI6\n\t\t\t\t\t\tY9rXPs16cGQSRb9l+RZhzO9Lg9wiC9z29pKCINyBbb7Ii97n+YS/6NBq3TiKCznp\n\t\t\t\t\t\tDJWbNIuvCLt1r6pDo833XZvnQhaQkIAOPLaC3bpNBeIbo1NJHN07RLz6fHxBAkK8\n\t\t\t\t\t\tKpjmUv2Ak1G99GdMWmCmtbpoW0t1gWCJBxGp5ZppWuOqvUDDxjs3D3hvnxw9Xpb7\n\t\t\t\t\t\tVaBMkZKjwsitadeBKHBUyy7OxfSe9bInSwk3iT0VxX2Sx6ohB0K9yejJo7Mbe1hp\n\t\t\t\t\t\tlm2mrAyaunzmICuPrrupZfPsoQIDAQABo30wezBaBgNVHREEUzBRghtkbGliLXNj\n\t\t\t\t\t\taG9vbHNpZHAuZWRpbmEuYWMudWuGMmh0dHBzOi8vZGxpYi1zY2hvb2xzaWRwLmVk\n\t\t\t\t\t\taW5hLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTtud1yQh+7MhTkM1bI\n\t\t\t\t\t\t5x7oBcMJwTANBgkqhkiG9w0BAQUFAAOCAQEAp1x7CEh3Tbv+sS/Y0dxd74FvQYRk\n\t\t\t\t\t\te1r9+iAbXjs4vGGQHM+qpM3Ts7KoY3AXvUeCjTuLJ5/95EgFkX8isKBu2k+hWBzD\n\t\t\t\t\t\tWiOeL9JhTjv7gULtUUaMf607R6r3h1EtwUMlSE5/6sGs+leVx7B23fcAMm0yxTzw\n\t\t\t\t\t\tx06n46KjdnXotpL7tt+chfIeNPba166WSj8iG7kBljgXRYnvXhI3GUhGqITsfA9T\n\t\t\t\t\t\tq1kGDVnHXsoaaZqHiNuZ0SYGo705GUzDmz5xrmINfGkNDwNpuvuVFfhPwmqUjXwe\n\t\t\t\t\t\thdMmtC9GkxRq1Rd/PEN3POsJHTeFZbO59d1n9Fp2MzloG5f5K2+GcRwKZA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "schools.edina.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://dlib-schoolsidp.edina.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-schoolsidp.edina.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://dlib-schoolsidp.edina.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dlib-schoolsidp.edina.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dlib-schoolsidp.edina.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dlib-schoolsidp.edina.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://dlib-schoolsidp.edina.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-schoolsidp.edina.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "schools.edina.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVzCCAj+gAwIBAgIUO/h0MjhhFFYR9sFrpG5zi9vVo64wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJjEkMCIGA1UEAxMbZGxpYi1zY2hvb2xzaWRwLmVkaW5hLmFjLnVrMB4XDTA5\n\t\t\t\t\t\tMDgwNjEyMjAwOFoXDTI5MDgwNjEyMjAwOFowJjEkMCIGA1UEAxMbZGxpYi1zY2hv\n\t\t\t\t\t\tb2xzaWRwLmVkaW5hLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\n\t\t\t\t\t\tAQEAvqi4P3wG3B/dkzSoOMs0ssqK4xB7bMh3nF+JGo2KqGjxDYyRJtWY5FwRsAI6\n\t\t\t\t\t\tY9rXPs16cGQSRb9l+RZhzO9Lg9wiC9z29pKCINyBbb7Ii97n+YS/6NBq3TiKCznp\n\t\t\t\t\t\tDJWbNIuvCLt1r6pDo833XZvnQhaQkIAOPLaC3bpNBeIbo1NJHN07RLz6fHxBAkK8\n\t\t\t\t\t\tKpjmUv2Ak1G99GdMWmCmtbpoW0t1gWCJBxGp5ZppWuOqvUDDxjs3D3hvnxw9Xpb7\n\t\t\t\t\t\tVaBMkZKjwsitadeBKHBUyy7OxfSe9bInSwk3iT0VxX2Sx6ohB0K9yejJo7Mbe1hp\n\t\t\t\t\t\tlm2mrAyaunzmICuPrrupZfPsoQIDAQABo30wezBaBgNVHREEUzBRghtkbGliLXNj\n\t\t\t\t\t\taG9vbHNpZHAuZWRpbmEuYWMudWuGMmh0dHBzOi8vZGxpYi1zY2hvb2xzaWRwLmVk\n\t\t\t\t\t\taW5hLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTtud1yQh+7MhTkM1bI\n\t\t\t\t\t\t5x7oBcMJwTANBgkqhkiG9w0BAQUFAAOCAQEAp1x7CEh3Tbv+sS/Y0dxd74FvQYRk\n\t\t\t\t\t\te1r9+iAbXjs4vGGQHM+qpM3Ts7KoY3AXvUeCjTuLJ5/95EgFkX8isKBu2k+hWBzD\n\t\t\t\t\t\tWiOeL9JhTjv7gULtUUaMf607R6r3h1EtwUMlSE5/6sGs+leVx7B23fcAMm0yxTzw\n\t\t\t\t\t\tx06n46KjdnXotpL7tt+chfIeNPba166WSj8iG7kBljgXRYnvXhI3GUhGqITsfA9T\n\t\t\t\t\t\tq1kGDVnHXsoaaZqHiNuZ0SYGo705GUzDmz5xrmINfGkNDwNpuvuVFfhPwmqUjXwe\n\t\t\t\t\t\thdMmtC9GkxRq1Rd/PEN3POsJHTeFZbO59d1n9Fp2MzloG5f5K2+GcRwKZA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EDINA services for schools"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://edina.ac.uk/index.shtml"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ucreative.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gravestock"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:JGravestock@ucreative.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jill"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gravestock"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:JGravestock@ucreative.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jill"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ucreative.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-06-23T10:43:07Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ucreative.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ucreative.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucreative.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYjCCAkqgAwIBAgIIJo1biNwPrSgwDQYJKoZIhvcNAQEFBQAwSDEoMCYGA1UE\n\t\t\t\t\t\tCgwfVW5pdmVyc2l0eSBvZiB0aGUgQ3JlYXRpdmUgQXJ0czEcMBoGA1UEAwwTaWRw\n\t\t\t\t\t\tLnVjcmVhdGl2ZS5hYy51azAeFw0xNDA2MTgwOTU4MDRaFw0yNDA2MTgwOTU4MDRa\n\t\t\t\t\t\tMEgxKDAmBgNVBAoMH1VuaXZlcnNpdHkgb2YgdGhlIENyZWF0aXZlIEFydHMxHDAa\n\t\t\t\t\t\tBgNVBAMME2lkcC51Y3JlYXRpdmUuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IB\n\t\t\t\t\t\tDwAwggEKAoIBAQDDWJ5V75TP17ft7xWNE1OLty4PKX6Ntd+4HurvVjZ8UU9T3zII\n\t\t\t\t\t\tYgYbccWNaakLxM8cbrJFJuyTPKryfT/KQQlXaMj1f3dKYEWHZwoMrcNL+RRyoSFJ\n\t\t\t\t\t\trOuMFvC7xH7RF/ZoXZM1IQrHuYmlHW8YzQ7Gq/266/lDLCLEAt5zw2icTBeeSXzX\n\t\t\t\t\t\tPSvywT6WnSPBKACLvJ/n2HbDDj6wi+pPHvkDeBVPVt7jH0KaDNpQtcoVbXBeRv3S\n\t\t\t\t\t\twwOfr7lDWB5ydebEDgZjCfB+7P0EOQyGmylT4+TxGKyEOZMNaZ6X4sgSCUOHq//4\n\t\t\t\t\t\tnrZw23XxPrPgbJ4anXKKjI4CuJQv8oH1eV5VAgMBAAGjUDBOMB0GA1UdDgQWBBQF\n\t\t\t\t\t\t0udRgqvg95A7Qo+xph4DcxCsnzAfBgNVHSMEGDAWgBQF0udRgqvg95A7Qo+xph4D\n\t\t\t\t\t\tcxCsnzAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAPT/cxiwyp9PeO\n\t\t\t\t\t\t8Y9oo/VlxzvwwElBDfs7Z0t+jLIB9xnybKv/6+SBlaHLJjekuF2Or1M0GODTZM6E\n\t\t\t\t\t\tBhlKYkPnR458hEVH4Tvfxvxz8szkM10f2qttwW1fJ521SrUDpjkbzAhvQWWDHuKG\n\t\t\t\t\t\tT6/P5OqeESsgRHQxP15jOBIR9dUrw23fKdRqCQKnFrv5th67uiOTzQohI8j5Tm96\n\t\t\t\t\t\tzbQVayzUvXTkXa+WFk69R/wu5UJqvsSV/5aMvGFxtS0PHTvJvbbw7ZGllRiaTVP8\n\t\t\t\t\t\twzgmWpHQcWolIchFx3IdrXQA5DjbSGerGgvcqpi6aAo1Q8mJNUAAsMT8y2qhYp1z\n\t\t\t\t\t\tXcWw+FBE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYjCCAkqgAwIBAgIIJo1biNwPrSgwDQYJKoZIhvcNAQEFBQAwSDEoMCYGA1UE\n\t\t\t\t\t\tCgwfVW5pdmVyc2l0eSBvZiB0aGUgQ3JlYXRpdmUgQXJ0czEcMBoGA1UEAwwTaWRw\n\t\t\t\t\t\tLnVjcmVhdGl2ZS5hYy51azAeFw0xNDA2MTgwOTU4MDRaFw0yNDA2MTgwOTU4MDRa\n\t\t\t\t\t\tMEgxKDAmBgNVBAoMH1VuaXZlcnNpdHkgb2YgdGhlIENyZWF0aXZlIEFydHMxHDAa\n\t\t\t\t\t\tBgNVBAMME2lkcC51Y3JlYXRpdmUuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IB\n\t\t\t\t\t\tDwAwggEKAoIBAQDDWJ5V75TP17ft7xWNE1OLty4PKX6Ntd+4HurvVjZ8UU9T3zII\n\t\t\t\t\t\tYgYbccWNaakLxM8cbrJFJuyTPKryfT/KQQlXaMj1f3dKYEWHZwoMrcNL+RRyoSFJ\n\t\t\t\t\t\trOuMFvC7xH7RF/ZoXZM1IQrHuYmlHW8YzQ7Gq/266/lDLCLEAt5zw2icTBeeSXzX\n\t\t\t\t\t\tPSvywT6WnSPBKACLvJ/n2HbDDj6wi+pPHvkDeBVPVt7jH0KaDNpQtcoVbXBeRv3S\n\t\t\t\t\t\twwOfr7lDWB5ydebEDgZjCfB+7P0EOQyGmylT4+TxGKyEOZMNaZ6X4sgSCUOHq//4\n\t\t\t\t\t\tnrZw23XxPrPgbJ4anXKKjI4CuJQv8oH1eV5VAgMBAAGjUDBOMB0GA1UdDgQWBBQF\n\t\t\t\t\t\t0udRgqvg95A7Qo+xph4DcxCsnzAfBgNVHSMEGDAWgBQF0udRgqvg95A7Qo+xph4D\n\t\t\t\t\t\tcxCsnzAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAPT/cxiwyp9PeO\n\t\t\t\t\t\t8Y9oo/VlxzvwwElBDfs7Z0t+jLIB9xnybKv/6+SBlaHLJjekuF2Or1M0GODTZM6E\n\t\t\t\t\t\tBhlKYkPnR458hEVH4Tvfxvxz8szkM10f2qttwW1fJ521SrUDpjkbzAhvQWWDHuKG\n\t\t\t\t\t\tT6/P5OqeESsgRHQxP15jOBIR9dUrw23fKdRqCQKnFrv5th67uiOTzQohI8j5Tm96\n\t\t\t\t\t\tzbQVayzUvXTkXa+WFk69R/wu5UJqvsSV/5aMvGFxtS0PHTvJvbbw7ZGllRiaTVP8\n\t\t\t\t\t\twzgmWpHQcWolIchFx3IdrXQA5DjbSGerGgvcqpi6aAo1Q8mJNUAAsMT8y2qhYp1z\n\t\t\t\t\t\tXcWw+FBE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University for the Creative Arts (Testing)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ucreative.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University for the Creative Arts"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://blender.c3se.chalmers.se/a",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://blender.c3se.chalmers.se/a",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://blender.c3se.chalmers.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://blender.c3se.chalmers.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://blender.c3se.chalmers.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://blender.c3se.chalmers.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://blender.c3se.chalmers.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://blender.c3se.chalmers.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://blender.c3se.chalmers.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Testserver (Blender) f\u00f6r SNIC User and Project Repository (SUPR)."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Test server (Blender) for the SNIC User and Project Repository (SUPR)."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SUPR testserver Blender"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SUPR test server Blender"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "blender"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJANNMJ7yc9qvmMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\nBAMTB2JsZW5kZXIwHhcNMTQxMDIyMTI0NzU1WhcNMjQxMDE5MTI0NzU1WjASMRAw\nDgYDVQQDEwdibGVuZGVyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\nycq1F54xhth3uUvpr4lxftTZAE84k6LFlFkDBCtULpfyRhyMaQfJaDzxFlOVJkIn\n03WzAxkrL7iP+jFnix2RNFLJ3kH7PRk8M0riDNTsbOYQu363lZR7Ncs3udEo/XCa\nRKFDwy1kciUo7hReXqRm02ksFFKK1C6w7qtaacaHchkM0dxB/Ayo+qk2fndxkGf6\nvsZpSMRGv4bMUP/aDdltQKmfm5L7NJtRFJpalmGxAei+nBob3Y7NFSU5sCEJdqiW\nX7EEHd/XmtZBmtac4ra1sFNchEkSOK1Ck5r2V4UnkE+9jaCzZsEcR4WZ5IO/ylY9\nMFmyq679QnU/9MQkh6ehCwIDAQABozUwMzASBgNVHREECzAJggdibGVuZGVyMB0G\nA1UdDgQWBBRE3li20My8oEktpqJ99fJtpS9vEzANBgkqhkiG9w0BAQUFAAOCAQEA\nBe88ex3VQoUdYc59jamJyYFvI7OQlJTSqoT580xIQGOEIBAguNqx4jDMR1J/yktR\nkvmDsyTk4K+ffUH+FImgyxFxncIDG6qel8ZvZFEQEJE7cfkOEdpcW9C40wzKXpdg\n9v8yAk0EVgjXiZH3qpOmtz24T6odd9df7TFz8Ra8xW9rcRWs1X/7ddEstAKb5zAv\niRZMW9h3/0zvnfiotCSWcyRlvaC4W34Jon2JOdG/dDn7dx71OKBWnVIvojMR97NY\nl7/8pvi1GPfE2Nswhi8G5dZLNWNh2+mNO1E/zMRaYZPZJW+3Pw7hmF8kCVFXNBeA\nwtfo4cuUZJ2I0K9K0VcFYQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=blender"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://blender.c3se.chalmers.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://blender.c3se.chalmers.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://blender.c3se.chalmers.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://blender.c3se.chalmers.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://blender.c3se.chalmers.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://blender.c3se.chalmers.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://blender.c3se.chalmers.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://blender.c3se.chalmers.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://blender.c3se.chalmers.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.luu.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.luu.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-02-05T11:23:35Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Leeds University Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.luu.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.luu.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.luu.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.luu.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.luu.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.luu.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.luu.org.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.luu.org.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.luu.org.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.luu.org.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.luu.org.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.luu.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.luu.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.luu.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.luu.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.luu.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.luu.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://login.airhead.io/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gibbons"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:anthony@airhead-education.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Anthony"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Davidson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:fraser@airhead-education.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Fraser"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.airhead.io/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-03-16T14:06:25Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Airhead"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.airhead-education.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Airhead Education Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.airhead.io/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.airhead.io/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.airhead.io/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.airhead.io/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.airhead.io/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://login.airhead.io/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://login.airhead.io/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The award-winning platform for education."
                  }
                ],
                "logo": [
                  {
                    "text": "https://cdn.airhead.io/public/img/airhead-logo-blue.png",
                    "height": "122",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "137"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Airhead"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAhCgAwIBAgIQoOJCTVTKALBDuVQdpeQa8jAJBgUrDgMCHQUAMC0xKzAp\n\t\t\t\t\t\tBgNVBAMTIkFpcmhlYWQgUHJvZHVjdGlvbiBJbnRlcm1lZGlhdGUgQ0EwHhcNMTQw\n\t\t\t\t\t\tNjI0MTA1MTU3WhcNMzkxMjMxMjM1OTU5WjAmMSQwIgYDVQQDExtsb2dpbi5wcm9k\n\t\t\t\t\t\tLmFpcmhlYWRjbG91ZC5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCeNj30rE16NspRChDY3tFrRHA1CCu/+XoUy/xGVy4VbYwFM6tMEYmTBGnpzHnm\n\t\t\t\t\t\ttJ9SyS77P9mSZY0ZD0KXC1CbQSdnMdGLKefheUrcO46W3napMNsY/BsJz3IKkxiP\n\t\t\t\t\t\tg775TYBn1v0WyPPBCudrwQhk/99jXdUr9BF4hNkk2S9CbO7TMb3mZyEGiJlGgjWM\n\t\t\t\t\t\tYay1MA9yre6/OZfnSH4392qgg6MWNzB3eCftVKS1mKWgoyobeG5EIbaGBsV7hM5v\n\t\t\t\t\t\t184OZ9+K3ZqZ5p+0vQ03yDsd61nMkZQ1o25SQkq8MDX759JoFc7DZVBxsFufgf8n\n\t\t\t\t\t\t3rJvgD81ax0nmGV9V2Pt5Z43AgMBAAGjTzBNMEsGA1UdAQREMEKAEBI0ZRxUq6yh\n\t\t\t\t\t\tpsA7AvxlvrChHDAaMRgwFgYDVQQDEw9BaXJoZWFkIFJvb3QgQ0GCEHZ2tw2/6qyV\n\t\t\t\t\t\tTVMUElpq4EUwCQYFKw4DAh0FAAOCAQEAdQ764oFVpsnxh2w16Cf+5tWErxjsxsJi\n\t\t\t\t\t\t/F6h3IsP7X0pzIKhTDsQuue5odFBt7PllvWNZlWA/+M9mYLlv+zg3ZRGUMbYMI5k\n\t\t\t\t\t\t+aGwjzRimvy5vKaszST5+mRhkMy2Bh5OByAgNkEdGePwK1oHj0tdclPblfwXYEjb\n\t\t\t\t\t\tEn36X/es6SaJTxIAE8qF4I8JT3ZYCoBtDxBBi62pbiMGtY5kEorUsgSMMnCD7qsl\n\t\t\t\t\t\t/c70n+btqrMJbjz5N4CdW1S9tDrC40eEeVU2X8+bN5nP5J67glGc+i3Ypm8ojayS\n\t\t\t\t\t\t+8QbhGAot/z38FpozABMxuPrPgQpzd7UzSpez59dlmrOyEOJUnkY3g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.airhead.io/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.airhead.io/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.airhead.io/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://login.airhead.io/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.airhead.io/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.airhead.io/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.kidderminster.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dalton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jdalton@kidderminster.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jon"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mason"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:gmason@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Graham"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.kidderminster.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-07-07T10:38:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDfjCCAmYCCQC1lEqsdKl1pjANBgkqhkiG9w0BAQUFADCBgDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFzAVBgNVBAgMDldvcmNlc3RlcnNoaXJlMRYwFAYDVQQHDA1LaWRkZXJtaW5z\n\t\t\t\t\t\tdGVyMR4wHAYDVQQKDBVLaWRkZXJtaW5zdGVyIENvbGxlZ2UxIDAeBgNVBAMMF2lk\n\t\t\t\t\t\tcC5raWRkZXJtaW5zdGVyLmFjLnVrMB4XDTE0MDUyMjEzMTkzNloXDTM0MDUxNzEz\n\t\t\t\t\t\tMTkzNlowgYAxCzAJBgNVBAYTAkdCMRcwFQYDVQQIDA5Xb3JjZXN0ZXJzaGlyZTEW\n\t\t\t\t\t\tMBQGA1UEBwwNS2lkZGVybWluc3RlcjEeMBwGA1UECgwVS2lkZGVybWluc3RlciBD\n\t\t\t\t\t\tb2xsZWdlMSAwHgYDVQQDDBdpZHAua2lkZGVybWluc3Rlci5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBANRe5zKGcnY7gv70p75rc68Wrj+q5Zkl\n\t\t\t\t\t\tk12zx44THBleZAnLqwGRPh8cI1+zEHCJkFYZ+Jb6JUhLMTA4qalwr/Xsnba3e4vF\n\t\t\t\t\t\tCaSL5IaXT6L08pVj56z3JbOuJSEe1G9seJWpXi6EV7NFWMKV+oBofs7pbvy9TzA1\n\t\t\t\t\t\tfBGnJ6IAicdaFtlZALeYyGnF1w/QazoxYP0jg/3+l8DT4hQ8+xnyKIiw7F9lvD0z\n\t\t\t\t\t\tQ+pm0vZavGHT7QXdgLzPFrgS8o07hoQlw5a0uLv0n46MHwZQh5LWj9LCXrspjZ7I\n\t\t\t\t\t\tSLSOz5XUREIysOTkc+n4HwFDg6oU66eSG7i0+4sMGhufUwwuLpUtp6ECAwEAATAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEATtVSFphRCI0ZcS+bbndukADAg2wWXZr1XK9ZeAQY\n\t\t\t\t\t\tOv2mCxPxeTq1xUW+y2XvTyKzpO5pEmSgcPgLWWAI7DitZZdSjHQF2Tp+611GclqP\n\t\t\t\t\t\t4RCmSiR6oLFMppbKAoIlt9rM/9YVBUMmg/1UkHfRRl5B3fCEGP6a6gjkFyY3tREr\n\t\t\t\t\t\tzlRZAqczHRN6KlO+XGd4V2GLEr+5afKgOQ7v6PY8SY2A9aPkb7VXayF9ce6Cp8fM\n\t\t\t\t\t\tiI7pdvffghmNIpB/5M6m3Pt0ZPCWOTUbAlBt34zSVFfrDIHBHru0D9/ZBjY74j54\n\t\t\t\t\t\tTr/tGMotauH4aEa18dgsPJ3fiAlCAOcfTKDJKfzyX7FkIw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kidderminster.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.kidderminster.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.kidderminster.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.kidderminster.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.kidderminster.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.kidderminster.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.kidderminster.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.kidderminster.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.kidderminster.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kidderminster.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDfjCCAmYCCQC1lEqsdKl1pjANBgkqhkiG9w0BAQUFADCBgDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFzAVBgNVBAgMDldvcmNlc3RlcnNoaXJlMRYwFAYDVQQHDA1LaWRkZXJtaW5z\n\t\t\t\t\t\tdGVyMR4wHAYDVQQKDBVLaWRkZXJtaW5zdGVyIENvbGxlZ2UxIDAeBgNVBAMMF2lk\n\t\t\t\t\t\tcC5raWRkZXJtaW5zdGVyLmFjLnVrMB4XDTE0MDUyMjEzMTkzNloXDTM0MDUxNzEz\n\t\t\t\t\t\tMTkzNlowgYAxCzAJBgNVBAYTAkdCMRcwFQYDVQQIDA5Xb3JjZXN0ZXJzaGlyZTEW\n\t\t\t\t\t\tMBQGA1UEBwwNS2lkZGVybWluc3RlcjEeMBwGA1UECgwVS2lkZGVybWluc3RlciBD\n\t\t\t\t\t\tb2xsZWdlMSAwHgYDVQQDDBdpZHAua2lkZGVybWluc3Rlci5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBANRe5zKGcnY7gv70p75rc68Wrj+q5Zkl\n\t\t\t\t\t\tk12zx44THBleZAnLqwGRPh8cI1+zEHCJkFYZ+Jb6JUhLMTA4qalwr/Xsnba3e4vF\n\t\t\t\t\t\tCaSL5IaXT6L08pVj56z3JbOuJSEe1G9seJWpXi6EV7NFWMKV+oBofs7pbvy9TzA1\n\t\t\t\t\t\tfBGnJ6IAicdaFtlZALeYyGnF1w/QazoxYP0jg/3+l8DT4hQ8+xnyKIiw7F9lvD0z\n\t\t\t\t\t\tQ+pm0vZavGHT7QXdgLzPFrgS8o07hoQlw5a0uLv0n46MHwZQh5LWj9LCXrspjZ7I\n\t\t\t\t\t\tSLSOz5XUREIysOTkc+n4HwFDg6oU66eSG7i0+4sMGhufUwwuLpUtp6ECAwEAATAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEATtVSFphRCI0ZcS+bbndukADAg2wWXZr1XK9ZeAQY\n\t\t\t\t\t\tOv2mCxPxeTq1xUW+y2XvTyKzpO5pEmSgcPgLWWAI7DitZZdSjHQF2Tp+611GclqP\n\t\t\t\t\t\t4RCmSiR6oLFMppbKAoIlt9rM/9YVBUMmg/1UkHfRRl5B3fCEGP6a6gjkFyY3tREr\n\t\t\t\t\t\tzlRZAqczHRN6KlO+XGd4V2GLEr+5afKgOQ7v6PY8SY2A9aPkb7VXayF9ce6Cp8fM\n\t\t\t\t\t\tiI7pdvffghmNIpB/5M6m3Pt0ZPCWOTUbAlBt34zSVFfrDIHBHru0D9/ZBjY74j54\n\t\t\t\t\t\tTr/tGMotauH4aEa18dgsPJ3fiAlCAOcfTKDJKfzyX7FkIw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Kidderminster College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kidderminster.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NCG Corporation"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.newvic.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Overt Software Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Miah"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:amiah@newvic.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Akik"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.newvic.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-10-01T11:40:17Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUc68eei2OkuHHobEIjasrgMJSBp4wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGzEZMBcGA1UEAxMQaWRwLm5ld3ZpYy5hYy51azAeFw0xNDAzMDcwOTMyMTJa\n\t\t\t\t\t\tFw0zNDAzMDcwOTMyMTJaMBsxGTAXBgNVBAMTEGlkcC5uZXd2aWMuYWMudWswggEi\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCIgYP2Zg400N4Z1zX9txCaEtQt\n\t\t\t\t\t\t+42Tc6dKndjl44UctLUg1UNNRMkoEAY+6HqwdE3DgVqd0YMN1wVBkv8EYCqz/TAU\n\t\t\t\t\t\tWqSIfAEjZDeMJalVoKu1pfdW7mB3aciH8rddMQ1LYQHmEPeNrzC2MjJEJgQ9hOXD\n\t\t\t\t\t\tow+hyE+cWhlr4kjJB4gYhfGCiAMkVCi5h6MJvDVARDz/eX75J5yBOsBXYAnEeyG1\n\t\t\t\t\t\tWArxEwPgfGf0dv0IJxI/gacJg2aeltyhPoTsi074C4L4w2e0S6DGpSDPr2wQO0T2\n\t\t\t\t\t\tGKrrBfplb/f2z3NqA0FQixn9U9igN59TB3SVcWHmVCGvXJ8MAfMBIKe3K6f7AgMB\n\t\t\t\t\t\tAAGjZzBlMEQGA1UdEQQ9MDuCEGlkcC5uZXd2aWMuYWMudWuGJ2h0dHBzOi8vaWRw\n\t\t\t\t\t\tLm5ld3ZpYy5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUVc2r4NVHJPsT\n\t\t\t\t\t\tHhMYmvd+VlvxnwcwDQYJKoZIhvcNAQEFBQADggEBAAv+49iJGalruBtUdV2g6lFY\n\t\t\t\t\t\tXpZcFIAAbS5AmBigEalNZJqp1BiWNHitdq+6G0JJzSzMlLlsvRjWRP59E2veuqm6\n\t\t\t\t\t\tCJchy6WsFPg4aGT77Q28WEbVFSOABF7TLHYeqTBuLUACKlpIdkM/pQxPyPlUg1IV\n\t\t\t\t\t\tiIeWjqCxVj9glgmPHDpK9gkKXyOhd1b8NhxeBJ/xVId3OosQCIPh++Nc00LRpHqu\n\t\t\t\t\t\tgqBLVoEVcJJVnarmoxxabzVBfVeG9/x3PbjE0rlJ64l4kp1VM8RKGW1C3RI8bxNN\n\t\t\t\t\t\tvIEuNvfpiGOHrzJP801TYK1JLfAGxuEqpRictkktztc/gU5mjgoPsMRm6V6r0Zk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "newvic.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.newvic.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.newvic.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.newvic.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.newvic.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.newvic.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.newvic.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.newvic.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.newvic.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.newvic.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.newvic.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.newvic.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "newvic.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUc68eei2OkuHHobEIjasrgMJSBp4wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGzEZMBcGA1UEAxMQaWRwLm5ld3ZpYy5hYy51azAeFw0xNDAzMDcwOTMyMTJa\n\t\t\t\t\t\tFw0zNDAzMDcwOTMyMTJaMBsxGTAXBgNVBAMTEGlkcC5uZXd2aWMuYWMudWswggEi\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCIgYP2Zg400N4Z1zX9txCaEtQt\n\t\t\t\t\t\t+42Tc6dKndjl44UctLUg1UNNRMkoEAY+6HqwdE3DgVqd0YMN1wVBkv8EYCqz/TAU\n\t\t\t\t\t\tWqSIfAEjZDeMJalVoKu1pfdW7mB3aciH8rddMQ1LYQHmEPeNrzC2MjJEJgQ9hOXD\n\t\t\t\t\t\tow+hyE+cWhlr4kjJB4gYhfGCiAMkVCi5h6MJvDVARDz/eX75J5yBOsBXYAnEeyG1\n\t\t\t\t\t\tWArxEwPgfGf0dv0IJxI/gacJg2aeltyhPoTsi074C4L4w2e0S6DGpSDPr2wQO0T2\n\t\t\t\t\t\tGKrrBfplb/f2z3NqA0FQixn9U9igN59TB3SVcWHmVCGvXJ8MAfMBIKe3K6f7AgMB\n\t\t\t\t\t\tAAGjZzBlMEQGA1UdEQQ9MDuCEGlkcC5uZXd2aWMuYWMudWuGJ2h0dHBzOi8vaWRw\n\t\t\t\t\t\tLm5ld3ZpYy5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUVc2r4NVHJPsT\n\t\t\t\t\t\tHhMYmvd+VlvxnwcwDQYJKoZIhvcNAQEFBQADggEBAAv+49iJGalruBtUdV2g6lFY\n\t\t\t\t\t\tXpZcFIAAbS5AmBigEalNZJqp1BiWNHitdq+6G0JJzSzMlLlsvRjWRP59E2veuqm6\n\t\t\t\t\t\tCJchy6WsFPg4aGT77Q28WEbVFSOABF7TLHYeqTBuLUACKlpIdkM/pQxPyPlUg1IV\n\t\t\t\t\t\tiIeWjqCxVj9glgmPHDpK9gkKXyOhd1b8NhxeBJ/xVId3OosQCIPh++Nc00LRpHqu\n\t\t\t\t\t\tgqBLVoEVcJJVnarmoxxabzVBfVeG9/x3PbjE0rlJ64l4kp1VM8RKGW1C3RI8bxNN\n\t\t\t\t\t\tvIEuNvfpiGOHrzJP801TYK1JLfAGxuEqpRictkktztc/gU5mjgoPsMRm6V6r0Zk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Newham Sixth Form College (Shibboleth)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.newvic.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Newham Sixth Form College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dev2.qmplus.qmul.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:its-aa@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Academic Applications"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:moodle-support@ulcc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Moodle Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:its-aa@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Academic Applications"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dev2.qmplus.qmul.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-07-07T11:58:09Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Queen Mary and Westfield College: Development2 QMPlus service"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qmul.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Queen Mary and Westfield College, University of London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev2.qmplus.qmul.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev2.qmplus.qmul.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJAKIXgZKgUS02MA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\n\t\t\t\t\t\tBAMTFmRldjIucW1wbHVzLnFtdWwuYWMudWswHhcNMTQwMTEzMTE1MDE0WhcNMjQw\n\t\t\t\t\t\tMTExMTE1MDE0WjAhMR8wHQYDVQQDExZkZXYyLnFtcGx1cy5xbXVsLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArfTNUnzPGeKks0JEURWVUhz+\n\t\t\t\t\t\tfNsXrghIj4a0LpAEl5ez2kyU0q7mAc+uoeBJqNGs2CeOkar9YZseXi/pNXGjpRPS\n\t\t\t\t\t\tRwGYYdG89vLgnAervT5U8ixW2egPGijU40Yc2pSldnhArOlYnwsILKCF9dDo5opG\n\t\t\t\t\t\tKDTdEqcl6lCh2UsbAZTpRj1CSPcrPlbw42fWVsRWaxsPtwd2cMn5ioA/ijh3t4eN\n\t\t\t\t\t\t3ZjpL3/lNhTdkp/CADiKfk1i+QTA0Y00Rc8GWrgh4beg83FEU2cpVbEb/c6tpHCe\n\t\t\t\t\t\t+OXc1ORX3k928DMLcPMogv1Y8Cbb4LUNWpePrbdmK4EwXng/A0Vphgopx97heQID\n\t\t\t\t\t\tAQABo0QwQjAhBgNVHREEGjAYghZkZXYyLnFtcGx1cy5xbXVsLmFjLnVrMB0GA1Ud\n\t\t\t\t\t\tDgQWBBQqyXbyEctK4flSrdXeud1vaiYVqjANBgkqhkiG9w0BAQUFAAOCAQEAo1Xd\n\t\t\t\t\t\tXXodRs7vG6pZVj1zphCQ18aCxKhyJwxhJXigZ4hSVCKhdt363N/DqrasXC80z1pj\n\t\t\t\t\t\tL5FNmbl5hYqOO4dboLSNxSccW0gDl6SA16EfSACt6YQukiMsi4O1GiKYNFpC2uhp\n\t\t\t\t\t\tspxt8IkaPUx5l5uwYr5iZGyMf5vLnJxMURcDTxT/YQT0PBLBktlkHOZuiCAvvnb3\n\t\t\t\t\t\tBVmXbM2lPBT022q/vcrBjnh1jYlX29wh7fJfewNj7GDhIABwTtGjFJBAyY/Dh6jv\n\t\t\t\t\t\tVvZoqdpyca2qXnwU8ndOaWizxzCA9JkcAxz5kl/Kd80KOplSaaXtvhazKHnCGPVx\n\t\t\t\t\t\t6723v/DV2JeGagBADw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev2.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dev2.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev2.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dev2.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dev2.qmplus.qmul.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dev2.qmplus.qmul.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.uoa.gr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "University of Athens Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk.idp@noc.uoa.gr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "University of Athens Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk.idp@noc.uoa.gr"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uoa.gr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFATCCA+mgAwIBAgIIEms+5gN0OgUwDQYJKoZIhvcNAQEFBQAwgZIxCzAJBgNV\n                            BAYTAkdSMUQwQgYDVQQKEztIZWxsZW5pYyBBY2FkZW1pYyBhbmQgUmVzZWFyY2gg\n                            SW5zdGl0dXRpb25zIENlcnQuIEF1dGhvcml0eTE9MDsGA1UEAxM0TmF0aW9uYWwg\n                            YW5kIEthcG9kaXN0cmlhbiBVbml2ZXJzaXR5IG9mIEF0aGVucyBDQSBSMTAeFw0x\n                            NDA1MjcwMDAwMDBaFw0xNjA1MjYxMDUzNDlaMGAxCzAJBgNVBAYTAkdSMTcwNQYD\n                            VQQKEy5OYXRpb25hbCBhbmQgS2Fwb2Rpc3RyaWFuIFVuaXZlcnNpdHkgb2YgQXRo\n                            ZW5zMRgwFgYDVQQDEw9VT0EgaWRwIHNlcnZpY2UwggEiMA0GCSqGSIb3DQEBAQUA\n                            A4IBDwAwggEKAoIBAQCpFnIjMy+Hp7ZBii7LIm+FqVlRiL9tGew8L2gmevWvDTkH\n                            yTnIvAfOr4hmaZ075R44FqEDL03tiZMsMyFbsDL1uYuJA1bJY4cM66I88+aIWwaL\n                            MKuI1voOvClbx08y4c+gI5+epurxju0NaVcVqgUJuLzAcnbIHmaSiC9NEuvlYo9Z\n                            tkFX8g1nFoUatPEoZseJfukdyufqyb59hGsNtlw9cHnY+gy+69Y4ZmxU7uXmm7oE\n                            0IRoQDBeCp7hiGJePYcQeJHNxWZiO3/SgP6p9G3qO9oSHu892DZ8uPP3CrvwgpW0\n                            6uVGR+7i8IGjjMOdFiTTWtlvfFJmJ/ETKYe3511JAgMBAAGjggGKMIIBhjALBgNV\n                            HQ8EBAMCBaAwHQYDVR0lBBYwFAYIKwYBBQUHAwIGCCsGAQUFBwMBMB0GA1UdDgQW\n                            BBSt7IktXk4pgSt+ECuSqC4RSNQG1zAfBgNVHSMEGDAWgBTWQ2tZXkiPvrW/wHtw\n                            u/Sr8SNBizBrBggrBgEFBQcBAQRfMF0wIQYIKwYBBQUHMAGGFWh0dHA6Ly9vY3Nw\n                            LmhhcmljYS5ncjA4BggrBgEFBQcwAoYsaHR0cDovL3d3dy5oYXJpY2EuZ3IvY2Vy\n                            dHMvSGFyaWNhVW9hQ0FSMS5wZW0wQwYDVR0fBDwwOjA4oDagNIYyaHR0cDovL2Ny\n                            bHYxLmhhcmljYS5nci9IYXJpY2FVb2FDQVIxL2NybHYxLmRlci5jcmwwTwYDVR0g\n                            BEgwRjBEBgwrBgEEAYHPEQEAAgcwNDAyBggrBgEFBQcCARYmaHR0cDovL3d3dy5o\n                            YXJpY2EuZ3IvZG9jdW1lbnRzL0NQUy5waHAwFQYDVR0RBA4wDIIKaWRwLnVvYS5n\n                            cjANBgkqhkiG9w0BAQUFAAOCAQEAaSENditQfkHEUNah+TqAhJziq/UC6UMh11PR\n                            1MIHmmQ7rTEiusr1E2sKkYqJA3UPD9aWhre6aNVNqCuViEfTvbc3YwytTu0vPqMt\n                            h23lNL4RQQHLpPpeUUDoN0vV/PlFUNeHnh/o7JtrCOTcdS7mQgkJvxq6kWwdDuQx\n                            0ZLgZQfyCHUlUToinr5oNCG7FAy2LRjXrzyOKGurX3WSY2FPAvWe1KSqdUS8/ZgI\n                            Jo0dRg7bs242O3GkczYeCobJ57vAwmiOPpHWyLq0QNPOQpJteMRRbDyDPEJxmZqL\n                            fFv23NJu+qiTMvSS1Z89Vph7AOEvYlV+m/BDv+Md9K41XM8i1g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uoa.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uoa.gr:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uoa.gr:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.uoa.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uoa.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.uoa.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uoa.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uoa.gr:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uoa.gr:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uoa.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFATCCA+mgAwIBAgIIEms+5gN0OgUwDQYJKoZIhvcNAQEFBQAwgZIxCzAJBgNV\n                            BAYTAkdSMUQwQgYDVQQKEztIZWxsZW5pYyBBY2FkZW1pYyBhbmQgUmVzZWFyY2gg\n                            SW5zdGl0dXRpb25zIENlcnQuIEF1dGhvcml0eTE9MDsGA1UEAxM0TmF0aW9uYWwg\n                            YW5kIEthcG9kaXN0cmlhbiBVbml2ZXJzaXR5IG9mIEF0aGVucyBDQSBSMTAeFw0x\n                            NDA1MjcwMDAwMDBaFw0xNjA1MjYxMDUzNDlaMGAxCzAJBgNVBAYTAkdSMTcwNQYD\n                            VQQKEy5OYXRpb25hbCBhbmQgS2Fwb2Rpc3RyaWFuIFVuaXZlcnNpdHkgb2YgQXRo\n                            ZW5zMRgwFgYDVQQDEw9VT0EgaWRwIHNlcnZpY2UwggEiMA0GCSqGSIb3DQEBAQUA\n                            A4IBDwAwggEKAoIBAQCpFnIjMy+Hp7ZBii7LIm+FqVlRiL9tGew8L2gmevWvDTkH\n                            yTnIvAfOr4hmaZ075R44FqEDL03tiZMsMyFbsDL1uYuJA1bJY4cM66I88+aIWwaL\n                            MKuI1voOvClbx08y4c+gI5+epurxju0NaVcVqgUJuLzAcnbIHmaSiC9NEuvlYo9Z\n                            tkFX8g1nFoUatPEoZseJfukdyufqyb59hGsNtlw9cHnY+gy+69Y4ZmxU7uXmm7oE\n                            0IRoQDBeCp7hiGJePYcQeJHNxWZiO3/SgP6p9G3qO9oSHu892DZ8uPP3CrvwgpW0\n                            6uVGR+7i8IGjjMOdFiTTWtlvfFJmJ/ETKYe3511JAgMBAAGjggGKMIIBhjALBgNV\n                            HQ8EBAMCBaAwHQYDVR0lBBYwFAYIKwYBBQUHAwIGCCsGAQUFBwMBMB0GA1UdDgQW\n                            BBSt7IktXk4pgSt+ECuSqC4RSNQG1zAfBgNVHSMEGDAWgBTWQ2tZXkiPvrW/wHtw\n                            u/Sr8SNBizBrBggrBgEFBQcBAQRfMF0wIQYIKwYBBQUHMAGGFWh0dHA6Ly9vY3Nw\n                            LmhhcmljYS5ncjA4BggrBgEFBQcwAoYsaHR0cDovL3d3dy5oYXJpY2EuZ3IvY2Vy\n                            dHMvSGFyaWNhVW9hQ0FSMS5wZW0wQwYDVR0fBDwwOjA4oDagNIYyaHR0cDovL2Ny\n                            bHYxLmhhcmljYS5nci9IYXJpY2FVb2FDQVIxL2NybHYxLmRlci5jcmwwTwYDVR0g\n                            BEgwRjBEBgwrBgEEAYHPEQEAAgcwNDAyBggrBgEFBQcCARYmaHR0cDovL3d3dy5o\n                            YXJpY2EuZ3IvZG9jdW1lbnRzL0NQUy5waHAwFQYDVR0RBA4wDIIKaWRwLnVvYS5n\n                            cjANBgkqhkiG9w0BAQUFAAOCAQEAaSENditQfkHEUNah+TqAhJziq/UC6UMh11PR\n                            1MIHmmQ7rTEiusr1E2sKkYqJA3UPD9aWhre6aNVNqCuViEfTvbc3YwytTu0vPqMt\n                            h23lNL4RQQHLpPpeUUDoN0vV/PlFUNeHnh/o7JtrCOTcdS7mQgkJvxq6kWwdDuQx\n                            0ZLgZQfyCHUlUToinr5oNCG7FAy2LRjXrzyOKGurX3WSY2FPAvWe1KSqdUS8/ZgI\n                            Jo0dRg7bs242O3GkczYeCobJ57vAwmiOPpHWyLq0QNPOQpJteMRRbDyDPEJxmZqL\n                            fFv23NJu+qiTMvSS1Z89Vph7AOEvYlV+m/BDv+Md9K41XM8i1g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "National and Kapodistrian University of Athens"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u0395\u03b8\u03bd\u03b9\u03ba\u03cc \u039a\u03b1\u03c0\u03bf\u03b4\u03b9\u03c3\u03c4\u03c1\u03b9\u03b1\u03ba\u03cc \u03a0\u03b1\u03bd\u03b5\u03c0\u03b9\u03c3\u03c4\u03ae\u03bc\u03b9\u03bf \u0391\u03b8\u03b7\u03bd\u03ce\u03bd"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uoa.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uoa.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National and Kapodistrian University of Athens"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u0395\u03b8\u03bd\u03b9\u03ba\u03cc \u039a\u03b1\u03c0\u03bf\u03b4\u03b9\u03c3\u03c4\u03c1\u03b9\u03b1\u03ba\u03cc \u03a0\u03b1\u03bd\u03b5\u03c0\u03b9\u03c3\u03c4\u03ae\u03bc\u03b9\u03bf \u0391\u03b8\u03b7\u03bd\u03ce\u03bd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.sandwell.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:operations@sandwell.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Network Operations"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:operations@sandwell.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Network Operations"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.sandwell.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAPG65DBJJFPh5Jipeuryxop1mT/zMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB0xGzAZBgNVBAMTEmlkcC5zYW5kd2VsbC5hYy51azAeFw0xMjExMjgxMjQ3\n\t\t\t\t\t\tMDFaFw0zMjExMjgxMjQ3MDFaMB0xGzAZBgNVBAMTEmlkcC5zYW5kd2VsbC5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIAfYb8Pu2uYwPgeHKrf\n\t\t\t\t\t\tlPAMO1suHci3KBE5i22esUbqgDb7THIbKO8Hbd+z9tdphWZc6PhmEFeOwD0BE/qO\n\t\t\t\t\t\thDlRj9NwqggXezX5ecLWIR4/oYku5O8AD2B6DeksDdUX/zbaDeyDa/guxMbMLzJj\n\t\t\t\t\t\tPNzS0QR2/wId7sZOnMGhAzyUnMokziGb5H3w0qv121bywNxCBncJpY83RwSy5D14\n\t\t\t\t\t\t0bsDxkWWwaHTFy3bl9Nl28WfcC294UOIMO/5y2BW6oWGfPo9Bkl4+/Co8Agidk2Q\n\t\t\t\t\t\tMRWVzp6vtYBWVYASGYmNDw4uiyJ+A+sV3YNCTDwqiuqesPR2saqzIrxjYfYcapJg\n\t\t\t\t\t\t+gcCAwEAAaNrMGkwSAYDVR0RBEEwP4ISaWRwLnNhbmR3ZWxsLmFjLnVrhilodHRw\n\t\t\t\t\t\tczovL2lkcC5zYW5kd2VsbC5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n\t\t\t\t\t\thFHU5vFeYLlzBNR6FTzu937oV18wDQYJKoZIhvcNAQEFBQADggEBADx5fmZ91UY0\n\t\t\t\t\t\tUljRC24uNiX0nHOmAwVZDDUdO7UUkTboKh2u+AmiLEAh/3hX4S3GnYKW8p0Q0QNS\n\t\t\t\t\t\t32eDTMKf/7SWfflBVIhEUWo8DN4rZF4iL7Qoc7DiLt9QtQAPLlRGdenASN6WHpab\n\t\t\t\t\t\tnH6mBdrLtGZ+EKS6H9DE1+9JVib+CUnLYbzfiWfCXrzHQa2/1GPi8H3vLsC0+s/y\n\t\t\t\t\t\txt4afWbbFiZgb0Jkj51pYOzvBJXeHuea8BvlfRb+2KalvimeFsCb2Vd+cmoewYMo\n\t\t\t\t\t\tHXt7U0zNsoKb3p7Jbx5SlDztMdz52mSSYLa4SuFbE1u6ooMYb7lFWfL1rlDv0SiT\n\t\t\t\t\t\tMA3XVUiG45c="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sandwell.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sandwell.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sandwell.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.sandwell.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sandwell.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.sandwell.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sandwell.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sandwell.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sandwell.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sandwell.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAPG65DBJJFPh5Jipeuryxop1mT/zMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB0xGzAZBgNVBAMTEmlkcC5zYW5kd2VsbC5hYy51azAeFw0xMjExMjgxMjQ3\n\t\t\t\t\t\tMDFaFw0zMjExMjgxMjQ3MDFaMB0xGzAZBgNVBAMTEmlkcC5zYW5kd2VsbC5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIAfYb8Pu2uYwPgeHKrf\n\t\t\t\t\t\tlPAMO1suHci3KBE5i22esUbqgDb7THIbKO8Hbd+z9tdphWZc6PhmEFeOwD0BE/qO\n\t\t\t\t\t\thDlRj9NwqggXezX5ecLWIR4/oYku5O8AD2B6DeksDdUX/zbaDeyDa/guxMbMLzJj\n\t\t\t\t\t\tPNzS0QR2/wId7sZOnMGhAzyUnMokziGb5H3w0qv121bywNxCBncJpY83RwSy5D14\n\t\t\t\t\t\t0bsDxkWWwaHTFy3bl9Nl28WfcC294UOIMO/5y2BW6oWGfPo9Bkl4+/Co8Agidk2Q\n\t\t\t\t\t\tMRWVzp6vtYBWVYASGYmNDw4uiyJ+A+sV3YNCTDwqiuqesPR2saqzIrxjYfYcapJg\n\t\t\t\t\t\t+gcCAwEAAaNrMGkwSAYDVR0RBEEwP4ISaWRwLnNhbmR3ZWxsLmFjLnVrhilodHRw\n\t\t\t\t\t\tczovL2lkcC5zYW5kd2VsbC5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n\t\t\t\t\t\thFHU5vFeYLlzBNR6FTzu937oV18wDQYJKoZIhvcNAQEFBQADggEBADx5fmZ91UY0\n\t\t\t\t\t\tUljRC24uNiX0nHOmAwVZDDUdO7UUkTboKh2u+AmiLEAh/3hX4S3GnYKW8p0Q0QNS\n\t\t\t\t\t\t32eDTMKf/7SWfflBVIhEUWo8DN4rZF4iL7Qoc7DiLt9QtQAPLlRGdenASN6WHpab\n\t\t\t\t\t\tnH6mBdrLtGZ+EKS6H9DE1+9JVib+CUnLYbzfiWfCXrzHQa2/1GPi8H3vLsC0+s/y\n\t\t\t\t\t\txt4afWbbFiZgb0Jkj51pYOzvBJXeHuea8BvlfRb+2KalvimeFsCb2Vd+cmoewYMo\n\t\t\t\t\t\tHXt7U0zNsoKb3p7Jbx5SlDztMdz52mSSYLa4SuFbE1u6ooMYb7lFWfL1rlDv0SiT\n\t\t\t\t\t\tMA3XVUiG45c="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Sandwell College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sandwell.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Sandwell College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.ifgoiano.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Frederico Pereira da Cunha"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "frederico.pereira@ifgoiano.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.ifgoiano.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEOjCCAyICAQAwDQYJKoZIhvcNAQEFBQAwgeIxLDAqBgNVBAoTI0lGR09JQU5P\nIC0gSW5zdGl0dXRvIEZlZGVyYWwgR29pYW5vMT0wOwYDVQQLFDRER1RJIC0gRGly\nZXRvcmlhIEdlcmFsIGRlIFRlY25vbG9naWEgZGEgSW5mb3JtYcOnw6NvMSMwIQYJ\nKoZIhvcNAQkBFhRkZ3RpQGlmZ29pYW5vLmVkdS5icjERMA8GA1UEBxQIR29pw6Ju\naWExDzANBgNVBAgUBkdvacOhczELMAkGA1UEBhMCQlIxHTAbBgNVBAMTFHNoaWIu\naWZnb2lhbm8uZWR1LmJyMB4XDTE0MDQxMDIxMDc1MFoXDTE5MDQwOTIxMDc1MFow\ngeIxLDAqBgNVBAoTI0lGR09JQU5PIC0gSW5zdGl0dXRvIEZlZGVyYWwgR29pYW5v\nMT0wOwYDVQQLFDRER1RJIC0gRGlyZXRvcmlhIEdlcmFsIGRlIFRlY25vbG9naWEg\nZGEgSW5mb3JtYcOnw6NvMSMwIQYJKoZIhvcNAQkBFhRkZ3RpQGlmZ29pYW5vLmVk\ndS5icjERMA8GA1UEBxQIR29pw6JuaWExDzANBgNVBAgUBkdvacOhczELMAkGA1UE\nBhMCQlIxHTAbBgNVBAMTFHNoaWIuaWZnb2lhbm8uZWR1LmJyMIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAq2egNizK29vvUL0C4Iju9kh6RJ4OE3QjcNHY\nZh+JmAi+yb81E5CF8/dhBQRZ8Nqqp7DfpqipfD9P8pWUo1FsKeAmgfYGUr0gwYXY\nfQX7E5fOjSLeZegi5J6PYs7UveFRle4WIlD55CP5ERIVZ0QWFEnSXFAX3+xp1Zb7\nL0CASlxgi2UunN5jjpJWSW27A2rUwo3QPoJKPvBLh0tSTB5VAAuO/ksHULLDvDGl\nDdWrDRADXxQCnFKRrAYYfklnnGjegu8MNx1bMTxXHdeuZZEmWzes+FZ/aoZY2/vu\nNGsmNvHhoUTiT+BJRDskEICJ7gLTW9iWEg+tCpX2wuEqqHqkQwIDAQABMA0GCSqG\nSIb3DQEBBQUAA4IBAQAdb1hHAUd7k8uxZn48i38WEK/EteeVDFnK5rNsSpmXBNQn\nVE2McbYxHWpObBmavcG54nlrjgbKz/O8AHoD+uygRmEm70iyXO8La1SqmEaIppWF\n+Aydp01u0EC9VE50ZFYphNpdtKv695D3wvwsQGQ/kV+5xKyHQ8thXD97bVIj9oMR\nm8XXI7eDPZ2s/B0UoEZbvIAy68id7h/EtRyWbYyD8P5TNQ5JUs2I57orOEHfSbTz\n0+MpDn1u65HRka+3/3thgXdHyoyS+kkP9TjNdcnRxhsHpwwB0gvCfFXHS899/zsI\nt4gFfnXOhqI5mhEXE9m9l5n5bX6+LGLBxvNF1Qbt"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.ifgoiano.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.ifgoiano.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.ifgoiano.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.ifgoiano.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.ifgoiano.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.ifgoiano.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.ifgoiano.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.ifgoiano.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifgoiano.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifgoiano.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFGOIANO - Instituto Federal Goiano"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFGOIANO - Instituto Federal Goiano"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFGOIANO - Instituto Federal Goiano"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFGOIANO - Instituto Federal Goiano"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEOjCCAyICAQAwDQYJKoZIhvcNAQEFBQAwgeIxLDAqBgNVBAoTI0lGR09JQU5P\nIC0gSW5zdGl0dXRvIEZlZGVyYWwgR29pYW5vMT0wOwYDVQQLFDRER1RJIC0gRGly\nZXRvcmlhIEdlcmFsIGRlIFRlY25vbG9naWEgZGEgSW5mb3JtYcOnw6NvMSMwIQYJ\nKoZIhvcNAQkBFhRkZ3RpQGlmZ29pYW5vLmVkdS5icjERMA8GA1UEBxQIR29pw6Ju\naWExDzANBgNVBAgUBkdvacOhczELMAkGA1UEBhMCQlIxHTAbBgNVBAMTFHNoaWIu\naWZnb2lhbm8uZWR1LmJyMB4XDTE0MDQxMDIxMDc1MFoXDTE5MDQwOTIxMDc1MFow\ngeIxLDAqBgNVBAoTI0lGR09JQU5PIC0gSW5zdGl0dXRvIEZlZGVyYWwgR29pYW5v\nMT0wOwYDVQQLFDRER1RJIC0gRGlyZXRvcmlhIEdlcmFsIGRlIFRlY25vbG9naWEg\nZGEgSW5mb3JtYcOnw6NvMSMwIQYJKoZIhvcNAQkBFhRkZ3RpQGlmZ29pYW5vLmVk\ndS5icjERMA8GA1UEBxQIR29pw6JuaWExDzANBgNVBAgUBkdvacOhczELMAkGA1UE\nBhMCQlIxHTAbBgNVBAMTFHNoaWIuaWZnb2lhbm8uZWR1LmJyMIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAq2egNizK29vvUL0C4Iju9kh6RJ4OE3QjcNHY\nZh+JmAi+yb81E5CF8/dhBQRZ8Nqqp7DfpqipfD9P8pWUo1FsKeAmgfYGUr0gwYXY\nfQX7E5fOjSLeZegi5J6PYs7UveFRle4WIlD55CP5ERIVZ0QWFEnSXFAX3+xp1Zb7\nL0CASlxgi2UunN5jjpJWSW27A2rUwo3QPoJKPvBLh0tSTB5VAAuO/ksHULLDvDGl\nDdWrDRADXxQCnFKRrAYYfklnnGjegu8MNx1bMTxXHdeuZZEmWzes+FZ/aoZY2/vu\nNGsmNvHhoUTiT+BJRDskEICJ7gLTW9iWEg+tCpX2wuEqqHqkQwIDAQABMA0GCSqG\nSIb3DQEBBQUAA4IBAQAdb1hHAUd7k8uxZn48i38WEK/EteeVDFnK5rNsSpmXBNQn\nVE2McbYxHWpObBmavcG54nlrjgbKz/O8AHoD+uygRmEm70iyXO8La1SqmEaIppWF\n+Aydp01u0EC9VE50ZFYphNpdtKv695D3wvwsQGQ/kV+5xKyHQ8thXD97bVIj9oMR\nm8XXI7eDPZ2s/B0UoEZbvIAy68id7h/EtRyWbYyD8P5TNQ5JUs2I57orOEHfSbTz\n0+MpDn1u65HRka+3/3thgXdHyoyS+kkP9TjNdcnRxhsHpwwB0gvCfFXHS899/zsI\nt4gFfnXOhqI5mhEXE9m9l5n5bX6+LGLBxvNF1Qbt"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFGOIANO - Instituto Federal Goiano"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFGOIANO - Instituto Federal Goiano"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifgoiano.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifgoiano.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFGOIANO - Instituto Federal Goiano"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFGOIANO - Instituto Federal Goiano"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.unistra.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jean Benoit"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jean@unistra.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Eric Decornod"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "decornod@unistra.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.unistra.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2010-11-30T02:21:54Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unistra.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unistra.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.unistra.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "u-strasbg.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unistra.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unistra.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Strasbourg"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Strasbourg"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAJL1uSgdsDY7/9L6gFGKRCNK7RlQMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC51bmlzdHJhLmZyMB4XDTEwMTEzMDAxMDc0NFoX\nDTMwMTEzMDAxMDc0NFowGTEXMBUGA1UEAxMOaWRwLnVuaXN0cmEuZnIwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCfZvr54LdhidtcpIinb+VVc0nvNi7G\nRzVhLGmaWBEe2l/imU0NK+p8Sci4O06Dl17fSfEYh/ymT/X8fzs0ZBL67kmRjKW/\n4LrdaKPISuuBdAQu1ecMw6o5nHvPm8lChQs7+FPuKyHEOdGXU6YJdYcGVZWHGvm3\nYK0qZ5HocND7LYGhcTob083wQPtUm8TVisZSBBw/aY4uxQ3aPHqp20vLVlIWpyQH\nGBVusUsL30y4phRpvGMOhbBUjowba3Ig6cLGxhjmx2z42FoG95nF6NDRyPImp6cP\ndY3MFGFGOHb7o0eTkp2VpaCNwLDKUZq7IxxEg51BjAISYr4RlclDRlC1AgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC51bmlzdHJhLmZyhiVodHRwczovL2lkcC51bmlz\ndHJhLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTwSTX+NtpwVFWBJtPaXA23\nOEBp1jANBgkqhkiG9w0BAQUFAAOCAQEAhb+7SoxpdMH42J5nFMEXwNAxpPWKVjPq\nW5zgM3a3W3NSrL6R4j149IMn8YC+WrrfUnWiPYMO0+tEzTxvmL/SQRnV2kQumXN9\nQ32B6gTG1pinL1lcxrkO0FI1zcj/adE+2LkrTy3krQu2hkpO2CRYqE+ddzRNWdXd\nZ6Ym1zSD1ELYVcd6rOjyMA4yXW+8EM9K3P83Xy+o3SkIKd9tZzGv0qfy3CPW+v7V\n2Onsdu1A6uvdXVKl8r10oLIRXNp3LzhqFwhyiFzcRmgfOStZPHXzxSM/N9T8d+We\ngN8WbEdGuWT0j11MYdJkWDRArMdtVtI8aHXkmMCvAuttFvJib8Nzog=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Strasbourg"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unistra.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Strasbourg"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://devidp.nottingham.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Betts"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:craig.betts@nottingham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Craig"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Betts"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:craig.betts@nottingham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Craig"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://devidp.nottingham.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-11-26T11:29:38Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://devidp.nottingham.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://devidp.nottingham.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://devidp.nottingham.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://devidp.nottingham.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://devidp.nottingham.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://devidp.nottingham.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nottingham.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRzCCAi+gAwIBAgIUPod7Sbr/56mHA3U++HPjhmWY37wwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwIjEgMB4GA1UEAwwXZGV2aWRwLm5vdHRpbmdoYW0uYWMudWswHhcNMTUxMTA0\n\t\t\t\t\t\tMTMxNDAzWhcNMzUxMTA0MTMxNDAzWjAiMSAwHgYDVQQDDBdkZXZpZHAubm90dGlu\n\t\t\t\t\t\tZ2hhbS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIUmA1Je\n\t\t\t\t\t\turaCsBviSJhTzCsEiO9rLF1wFC79ZdKMM8+cRsBV8Wg2J3NTEsXdP3RDwaV7DU1i\n\t\t\t\t\t\tDvqH0kkHd1TeTVWTBLy5tE5oSBI+XrUMWlW1+oKVRRgxuWwJinG9OzJGkLk3kPiC\n\t\t\t\t\t\twvmnh2oP/CvvBQFR7jXwzLETMX+ReJo8Qrm/i3uIatYnC+QjqXtiq32q+HrWm3/m\n\t\t\t\t\t\tkbmbomaLhI/4eWAhyeCgbfkzJUm/J6/omhonCF2cTT9mAYTj/zEPkaIfOEsz/YoX\n\t\t\t\t\t\tGZ1C3oJxMboECHwlXKrov4UBxcWybejM/w2tZ9hy+Dz98HBa9ktj8D+YGj17j44v\n\t\t\t\t\t\tblKdnIvLNLeB2AECAwEAAaN1MHMwHQYDVR0OBBYEFOVrC+SsmuraLXapXXAJ1KiG\n\t\t\t\t\t\tp0KlMFIGA1UdEQRLMEmCF2RldmlkcC5ub3R0aW5naGFtLmFjLnVrhi5odHRwczov\n\t\t\t\t\t\tL2RldmlkcC5ub3R0aW5naGFtLmFjLnVrL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBCwUAA4IBAQCE/hCKcHULJtiEIvbaWVj/cJ/5djjVOq5yWp3SKqXr7QuNXhH3\n\t\t\t\t\t\tvcyDRlSRAgM5sYztCetRizr8wvir6uQg8yThQ7a2haSKDpSSvrDlsbiN25QNcSPy\n\t\t\t\t\t\ttHxbV/cmcPuBJqVuoSLGhl56Ak8cWcu+Gsv49f57ZwWdPry6nNxojf9T6QZ5Yjue\n\t\t\t\t\t\tCRXV9/nKPeMyud0L9DOs6Fwv5PvVfGRqck+3GzLqFLqqd9bMEBizSqxOtitRkI6E\n\t\t\t\t\t\tXX4b72sjaXxZmhZKx9OJDc+qb5JKIfPAhy/WMU5j8nvV1lMXA7ADQHEc6z0wcQAB\n\t\t\t\t\t\tW6z4doMJR/vjhdSNsL+BscENO7S8TLwNerEG"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAJByt+Pqvd0AQkDuileWY3HzdFCuMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMCIxIDAeBgNVBAMMF2RldmlkcC5ub3R0aW5naGFtLmFjLnVrMB4XDTE1MTEw\n\t\t\t\t\t\tNDEzMTQwMFoXDTM1MTEwNDEzMTQwMFowIjEgMB4GA1UEAwwXZGV2aWRwLm5vdHRp\n\t\t\t\t\t\tbmdoYW0uYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCFjocT\n\t\t\t\t\t\thMLkbIhipB+LoOS6gnhQ926P+lwkbjm4L1k1z7L9Br1+FWy6y9A87C27vjl3NVmn\n\t\t\t\t\t\tMb3bOJoSWzO4zhCTXKIXwsGE4p/xU27tkJrhmWSiaGIgI0yIpgJ9VqffiylMYsbB\n\t\t\t\t\t\tTMdJZKnRCkcsT3u9hNCrZTFciX6dCuTx1eG/O/gnP1Tsv1VgZNDGkIpQ2FGyGvqf\n\t\t\t\t\t\tCnDsoYauqQboetyMbi35kNtzyHEeQlFGdf0TzcRu4+M9Iu8m8gdysHwVI6ooNgCh\n\t\t\t\t\t\trPkqsiRqN8QxLehGbb2iUkCBUm1ozIJ6gI/ISju9NU2rPvnGvEDIhdahN8he+SBB\n\t\t\t\t\t\tnWIyYSigzFIiKRB1AgMBAAGjdTBzMB0GA1UdDgQWBBSecvscFzbVdcNqNo6BYvId\n\t\t\t\t\t\tPbEB5DBSBgNVHREESzBJghdkZXZpZHAubm90dGluZ2hhbS5hYy51a4YuaHR0cHM6\n\t\t\t\t\t\tLy9kZXZpZHAubm90dGluZ2hhbS5hYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG\n\t\t\t\t\t\t9w0BAQsFAAOCAQEANDNxfMHsXfT3qTlrHhHtqA+POFxFXmbVIl8eVyaRWDYt6CSh\n\t\t\t\t\t\tASNdkJ5JeAqyH+hi99ck/uEBHDOwkPbDz9mS5sXYQWlM/flJgPvfQhdH39x5I+89\n\t\t\t\t\t\tE65VMCpVXIxSOimcv2e2T/6wN8LfeVxrdX/xqxTlwgMFITWiH0CBV32BYwnSTyWv\n\t\t\t\t\t\tuA//1B+e5rrZieEDFpPIKp88kllHPI65gOM5BtM/7e7dSrP6DDFGQ9Cka2PKJN42\n\t\t\t\t\t\tMSspvYO5t2896ElI8y5uo+WqEJJYQK5tUMEWHrEv4iKJBMh6o1RF0IKPsqfdbDXh\n\t\t\t\t\t\t/pucELdoD3QB/+Y00gYUkW0ahafVQHPPmbXEhg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVALhfnz8SVgCdbIxwq62snEekShFkMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMCIxIDAeBgNVBAMMF2RldmlkcC5ub3R0aW5naGFtLmFjLnVrMB4XDTE1MTEw\n\t\t\t\t\t\tNDEzMTQwMloXDTM1MTEwNDEzMTQwMlowIjEgMB4GA1UEAwwXZGV2aWRwLm5vdHRp\n\t\t\t\t\t\tbmdoYW0uYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCvP2BQ\n\t\t\t\t\t\twMB007chmstkFdsSMgy+3t2LrsKrUWGCp12ERHXsOygz3FtIXtJ9m2qQBAoyeEUE\n\t\t\t\t\t\tku93NCN8EdwMA8RItP6aN2rjqDkYNsI4Lf9R/cRLxdIKWHxV0uZa8bW7NCluhcY3\n\t\t\t\t\t\t/rNPC3ulk+mAkB2Yk6e3sVMuvHNVRzbXKjEaHQ4k42FR+m+t4eMUp9lFsaWtTNBG\n\t\t\t\t\t\tAt7z2kwRPTVgCoeSP6QKParhLw2OQLDkswPsnmxjx/eUfzMZk+1p2QaqlNzb3Byw\n\t\t\t\t\t\tmXbFdw89vJixXTMsEE9LBGt3xAig+wBL4KdXIVVUxeH4SvzsRJ5eesM3BzEsYR8O\n\t\t\t\t\t\tqA2z6+g2/OERpldfAgMBAAGjdTBzMB0GA1UdDgQWBBRkhkF1SOCADGY5xIRUHCoJ\n\t\t\t\t\t\tbLvqtTBSBgNVHREESzBJghdkZXZpZHAubm90dGluZ2hhbS5hYy51a4YuaHR0cHM6\n\t\t\t\t\t\tLy9kZXZpZHAubm90dGluZ2hhbS5hYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG\n\t\t\t\t\t\t9w0BAQsFAAOCAQEAmiN8jb5MMsq9+lawIyf/OXd1wdAQ22Difv6/Q9zd1H1xzk84\n\t\t\t\t\t\tokxYfdw3zH/F4ciK6MgEs4t/CUR4X9vMmA70uTKpcQjm5t9BScVvXftRGb2grGHs\n\t\t\t\t\t\tPDeuuzCs4g9U4AdyxqrdxHZlz9rcT9XboWw61MFZIeklZRUjHU6lz6mVdxqKAoRY\n\t\t\t\t\t\tM97HPqVv54uHdf5JrxSoN788L0nro+0Pk/ntS2YP6vNMkQ9JERnK1x3cONyJ8W6X\n\t\t\t\t\t\tyv5xY3TkUJD4Q0hiiZ0L5uw1uDqXL6s2rHH6eQBPcr1Ju78t6hK0AfxGTalhlCiH\n\t\t\t\t\t\tLBzKoSgVjHzieZ11lJXFwnCZmBIpMeK5rouxOg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Nottingham : Development"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nottingham.ac.uk/is/about/index.aspx/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Nottingham"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://darlfam.darlington.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Stockdale"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dstockdale@darlington.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dean"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mussell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jmussell@darlington.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeremy"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://darlfam.darlington.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDfjCCAmYCCQCfd04ndbp77DANBgkqhkiG9w0BAQUFADCBgDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxDzANBgNVBAgTBkRVUkhBTTETMBEGA1UEBxMKREFSTElOR1RPTjEbMBkGA1UE\n\t\t\t\t\t\tChMSREFSTElOR1RPTiBDT0xMRUdFMQswCQYDVQQLEwJJVDEhMB8GA1UEAxMYZGFy\n\t\t\t\t\t\tbGZhbS5kYXJsaW5ndG9uLmFjLnVrMB4XDTEzMDIyNzEzMDAwOFoXDTIzMDIyNTEz\n\t\t\t\t\t\tMDAwOFowgYAxCzAJBgNVBAYTAkdCMQ8wDQYDVQQIEwZEVVJIQU0xEzARBgNVBAcT\n\t\t\t\t\t\tCkRBUkxJTkdUT04xGzAZBgNVBAoTEkRBUkxJTkdUT04gQ09MTEVHRTELMAkGA1UE\n\t\t\t\t\t\tCxMCSVQxITAfBgNVBAMTGGRhcmxmYW0uZGFybGluZ3Rvbi5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBALf2S6/2r5IbxIWlR7SVi1/ba7sgWKa5\n\t\t\t\t\t\t/GKP8XSwAc38MLyj4/kgLZ0dTN59VM5icjOPvpJaUdkDVecR5B6WpPABCsQ7L/vx\n\t\t\t\t\t\tK0sQaf1arynMl2ZbAJLNeab7wzVIlmY6mF2EgV/Od/DujnC9tK9bUX7xdrR0IAE6\n\t\t\t\t\t\tgeCst6x/iAPCHWRs0rlabxzR3uuY8dva3VRy5Q1E3wZPLsd61Y70kDUiVsU/Wj8B\n\t\t\t\t\t\tSKqM9xGp3ciNzJozqPwNKbO9+0y+W6dOv2qZP2w8kLeCRJ9/Gwq2+S2Yrjb0GoBK\n\t\t\t\t\t\tVV/2oXnX4Q0lFeAzySTV8DzugCEmGzAbNnzwLGv2RiodnKIc9c2iQWMCAwEAATAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAsTzNvSkDG0Ldj0orl7Y4GgKi+GvxLJ9ZNWSrYl3+\n\t\t\t\t\t\tXjjjx7uKgvaz2mM80d8gUdrFOklykZyDQ80PQW/4KYUC7i+Mgrrdj8RkE3UdGErV\n\t\t\t\t\t\tlFGZ8+TU7jDrdmmK9JtKDkrCXs7N22lFSTZs7e72pQcez2aq+B17+CV2fuJZeWDb\n\t\t\t\t\t\taJGf9FUS7ggB3GD+EtCwkhxQU1vGoDs9HxUbBMsD3T9ce2DryPYOqsSsdACvFil+\n\t\t\t\t\t\tOBPR70odKIk4LhmIfx8Nc3MzXilS/XVMw9JG68sXalkYQDjBT3/YR9DrywbE5zVe\n\t\t\t\t\t\tkhhFuq8lOaH+cpW82kov+HN3rQQLklwtd3AEAlaM+w4jiQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "darlington.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://darlfam.darlington.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://darlfam.darlington.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://darlfam.darlington.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://darlfam.darlington.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://darlfam.darlington.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://darlfam.darlington.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://darlfam.darlington.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://darlfam.darlington.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "darlington.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDfjCCAmYCCQCfd04ndbp77DANBgkqhkiG9w0BAQUFADCBgDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxDzANBgNVBAgTBkRVUkhBTTETMBEGA1UEBxMKREFSTElOR1RPTjEbMBkGA1UE\n\t\t\t\t\t\tChMSREFSTElOR1RPTiBDT0xMRUdFMQswCQYDVQQLEwJJVDEhMB8GA1UEAxMYZGFy\n\t\t\t\t\t\tbGZhbS5kYXJsaW5ndG9uLmFjLnVrMB4XDTEzMDIyNzEzMDAwOFoXDTIzMDIyNTEz\n\t\t\t\t\t\tMDAwOFowgYAxCzAJBgNVBAYTAkdCMQ8wDQYDVQQIEwZEVVJIQU0xEzARBgNVBAcT\n\t\t\t\t\t\tCkRBUkxJTkdUT04xGzAZBgNVBAoTEkRBUkxJTkdUT04gQ09MTEVHRTELMAkGA1UE\n\t\t\t\t\t\tCxMCSVQxITAfBgNVBAMTGGRhcmxmYW0uZGFybGluZ3Rvbi5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBALf2S6/2r5IbxIWlR7SVi1/ba7sgWKa5\n\t\t\t\t\t\t/GKP8XSwAc38MLyj4/kgLZ0dTN59VM5icjOPvpJaUdkDVecR5B6WpPABCsQ7L/vx\n\t\t\t\t\t\tK0sQaf1arynMl2ZbAJLNeab7wzVIlmY6mF2EgV/Od/DujnC9tK9bUX7xdrR0IAE6\n\t\t\t\t\t\tgeCst6x/iAPCHWRs0rlabxzR3uuY8dva3VRy5Q1E3wZPLsd61Y70kDUiVsU/Wj8B\n\t\t\t\t\t\tSKqM9xGp3ciNzJozqPwNKbO9+0y+W6dOv2qZP2w8kLeCRJ9/Gwq2+S2Yrjb0GoBK\n\t\t\t\t\t\tVV/2oXnX4Q0lFeAzySTV8DzugCEmGzAbNnzwLGv2RiodnKIc9c2iQWMCAwEAATAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAsTzNvSkDG0Ldj0orl7Y4GgKi+GvxLJ9ZNWSrYl3+\n\t\t\t\t\t\tXjjjx7uKgvaz2mM80d8gUdrFOklykZyDQ80PQW/4KYUC7i+Mgrrdj8RkE3UdGErV\n\t\t\t\t\t\tlFGZ8+TU7jDrdmmK9JtKDkrCXs7N22lFSTZs7e72pQcez2aq+B17+CV2fuJZeWDb\n\t\t\t\t\t\taJGf9FUS7ggB3GD+EtCwkhxQU1vGoDs9HxUbBMsD3T9ce2DryPYOqsSsdACvFil+\n\t\t\t\t\t\tOBPR70odKIk4LhmIfx8Nc3MzXilS/XVMw9JG68sXalkYQDjBT3/YR9DrywbE5zVe\n\t\t\t\t\t\tkhhFuq8lOaH+cpW82kov+HN3rQQLklwtd3AEAlaM+w4jiQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Darlington College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.darlington.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Darlington College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sb.nemji.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "M\u00e1lek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "malekp@nemji.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sb.nemji.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2015-11-03T10:24:02Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/hospital"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sb.nemji.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sb.nemji.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sb.nemji.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sb.nemji.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sb.nemji.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sb.nemji.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nemji.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.nemji.cz/en/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.nemji.cz"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for staff of Hospital Jihlava"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance Nemocnice Jihlava, p.o."
                  }
                ],
                "logo": [
                  {
                    "text": "https://sb.nemji.cz/idp/images/logo_nemji.jpg",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "92"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hospital Jihlava"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Nemocnice Jihlava, p.o."
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAKZp9gwp4ueLeX2+eB2CvUUrnDkkMA0GCSqGSIb3DQEB\nCwUAMBYxFDASBgNVBAMMC3NiLm5lbWppLmN6MB4XDTE1MDkyODIwMjY1N1oXDTM1\nMDkyODIwMjY1N1owFjEUMBIGA1UEAwwLc2IubmVtamkuY3owggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCxEbAEO17PWjk7G9OzJCz6FoEyGF6wdBerSeHS\noX+Seoj79HKldam3D1FaWfyvrbSATJtgdBeVkGKAL/YQ/I6t6W7XSkFsOfuJBPLu\nStWLVCIIJokaeNUMf1Hvj/C1vbl0X7ooRtR9Bw37BEAMY2Z4iEf1Os72q5RMpheG\nvSWHewbobbz9jJ8ztjvaoODvzC8QsldWA6WaFz71uvFTDQbT2CrmTKB59vPCpMAO\nO2UllJeZYm6XfCWQKc4yswfKUz7T+LsuN3rNXIVNAbInPtguqKzThzLmrXRdEVwK\nlezivULBZcl6F3y7VT9bUCEwmAmxPdtlcfpCfKgMwyR/koPZAgMBAAGjXTBbMB0G\nA1UdDgQWBBQWvRy9bMJ66wgZUWbx7GkUHDxZ6zA6BgNVHREEMzAxggtzYi5uZW1q\naS5jeoYiaHR0cHM6Ly9zYi5uZW1qaS5jei9pZHAvc2hpYmJvbGV0aDANBgkqhkiG\n9w0BAQsFAAOCAQEALC7n4vEu4XHlUdwts5szUfOXRv9J1cBRfFfkhv4XZpmaK6sj\ny4ATddyBMH7qRkuIQtpgSNuUFXaeDPYaWl14S8UcDXvPJRiuESFcNAVwfhA50BYo\nWhSRu859mA8oiDf+vS8w5MsSFp0ypBRAfc7gDZlHNxSb0JjL8rDv2lb/xtyIcBeP\nxRTQTJkWnQl6/yFldSIS1vjyq4gRDeSAbEamdB9kZYXpso/6+Xci56RGkF2jqhYG\njBnhOQm9pZ5ExPvfJg8t0uM2JkUPFWXPemvekrOsruK03/aI5fSi1xpDPXagFeTX\nduJQgq77OjeYG4HDOE+/Q1Mc78ihrQGiMt1mQA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAKPyelTVA+LxLwVx00WMBX1JLVLrMA0GCSqGSIb3DQEB\nCwUAMBYxFDASBgNVBAMMC3NiLm5lbWppLmN6MB4XDTE1MDkyODIwMjY1NloXDTM1\nMDkyODIwMjY1NlowFjEUMBIGA1UEAwwLc2IubmVtamkuY3owggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQC/boFss3wDxrlwMYgyZqe4vaMxxCzlIbHFRMTI\nF5V3x4aPqwmEzPlgI5DwrMZCPZRMllzL15yjKx3aKbPSuwUjVBeS1licKD3TUqeQ\nOOeihaGQB5LMfB+pUeknOp5IDQqSc0FhRD9RBd0HQ0RQmrguzfmvFQUgnJSivwG4\nQxdVBTOoAtjlmEDC6eI01cRlRnw/NgsHj+P3r2123O7G9FQEzuu61BVU7RBBPzbm\njVW+o3SbgAJn8Sk5mOVKTpqq0LP4XADpL26U08wMUTri7wO27qkRH3ARda55ubhV\nybexhPPFFHz3FXAr56xgaQbr+p66ktvdJ4u/h4M/7qfd58tnAgMBAAGjXTBbMB0G\nA1UdDgQWBBST/dnWs3qZybPk3IUtEIfUujodWzA6BgNVHREEMzAxggtzYi5uZW1q\naS5jeoYiaHR0cHM6Ly9zYi5uZW1qaS5jei9pZHAvc2hpYmJvbGV0aDANBgkqhkiG\n9w0BAQsFAAOCAQEAYNb4VPXPlVhJVygSeVl3D2cc413M5icp+1y3tL7VTcRKp0/B\n8c5j1iJR9QcnEUZwe7zrAaXT18BNNb1DMZT470BEhYNfO13tqJMA5/07gzUN/cOH\n5FkT+/cUCDXYTVS2GCnGmeOPNgzbuF/oUEQEcsyZ2Lg6TFWcQ6SoCyQpzCiruGuW\nXtGqoecT2BBbSIpCBnIeffIW4Lri+DSVxE1zDpnbE80VcAF+A5TP2qRNN+KHMbro\nmbbg8OPDJqbEV4TpRiTv1dMW/7Bl3gwslK+RRYC612P8EZxFnjsLBkVzmWXv/Uje\n/5e/14K2hCSYVIQY8/gqbfJYMErJJ8XsW+0SqQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUVFD+QoaYzxD5W4xBkA9MJtVvnREwDQYJKoZIhvcNAQEL\nBQAwFjEUMBIGA1UEAwwLc2IubmVtamkuY3owHhcNMTUwOTI4MjAyNjU2WhcNMzUw\nOTI4MjAyNjU2WjAWMRQwEgYDVQQDDAtzYi5uZW1qaS5jejCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAIGmupHI9HsQgayLrbTRTrbEDGZDVHQ0ruefPbhJ\nrTDVcg+30Y31w01s+pkE8JgQY8pY2I2vHpWc15aiqc8bOkPLv8aRO/d4AzJcipY8\n2A9SKeAgQwDldUj2l4d05JjxS81ZTRO4Zz8/CVsn5u2HBoX4DXexiXcnmiuZayET\nK0RJ3pt20tOITKecV5l7nZqPifkflLg+v0g0KsJLVIb4u1UyJcGNX0Y9G622Xoe0\nUP3ffB376fPXKxeDJTl6HQCT/cauTUnWcOKDWsExF0pMO4b3JAmZub+03EgwgXrr\nTxBmw9ngbPimD5NFppaMKqygXJ/nYB7NXdMFPPsihYPevGkCAwEAAaNdMFswHQYD\nVR0OBBYEFKxXcto1nYeWQ4ghK/SWd20gxuBkMDoGA1UdEQQzMDGCC3NiLm5lbWpp\nLmN6hiJodHRwczovL3NiLm5lbWppLmN6L2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3\nDQEBCwUAA4IBAQARxvTSjMwUgaX7z0uKrsYykwoXW6ZHLQAooYsTZrRoFR4s8DY5\nu5WbcM8jkFdqxbvDBdkZ//5XQyf45X7t9m3gFzojvNwu5Ms6AzOwNDLKEqFIn2gO\nb0J0ahHtxEvwZ5OO5C+U/A5y56D9VpGkvdKyW102m+pTGuBI1PChyXqtbZOPW2oe\nGS4qzsVOlYnXW8FZgftgaPqNwu/+EtSlkRtvYQdNSjs6oVXnHgO+5JYTMDgvf0xS\nPq2qFEC0TqaooIgKbPI9IKAg7WhwSuakyV2FIRtLpbRSZfcwSmzWnYcsmkxTGVnI\ngP5HZMJJz+FjDqHEOLAg0b82EJgLbqzVuBXy"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Nemocnice Jihlava, p.o."
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hospital Jihlava"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nemji.cz/en/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nemji.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Nemocnice Jihlava, p.o."
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hospital Jihlava"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth-idp.don.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gold"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sue.gold@don.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sue"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lettin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pete.lettin@don.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pete"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth-idp.don.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-05-07T11:17:05Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAK8RPs/u00+SAcNWs4bMNfrk/CKcMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBgxFjAUBgNVBAMTDWlkcC5kb24uYWMudWswHhcNMTUwNTE5MDkyODMyWhcN\n\t\t\t\t\t\tMzUwNTE5MDkyODMyWjAYMRYwFAYDVQQDEw1pZHAuZG9uLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsyZDjYtG71spcGTQfuxeMqEbhPbLyLb1\n\t\t\t\t\t\tPfUjkpcgL4XEuoSokBL6xUqAHsnsGx43l/CKqagSOrYcj9cLldjhUTTkaXIEGeMe\n\t\t\t\t\t\t2HDLSUiCin5P4OamFRYtKd6ZA2mZTgwhhUnfMU58XvcLvPJKa0xbFtvg5fW3Zunh\n\t\t\t\t\t\tX8MQ3RW51rS8OA+gvmiz6ObL4eKdGFBMGwGJGFSuM271LLeW63urNLNx+SFKgy8g\n\t\t\t\t\t\t/w4+PjLUO6yT7aw1SI9D67ZsEHYluuXt8TJI8cexndKLbULGTfylX/0XeO/IWL6v\n\t\t\t\t\t\tFLhDcbYMQ6YufuX+TWbznTsVtUT32wxige7QcKfq3EfwGVaPqIeUEQIDAQABo2Ew\n\t\t\t\t\t\tXzA+BgNVHREENzA1gg1pZHAuZG9uLmFjLnVrhiRodHRwczovL2lkcC5kb24uYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFBXefJlUvzYENqK4j4ELocNrbEo7\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQAr6JWW4s83L4uE+aOGa1UMmdb2Q9jbYvFXJrwz\n\t\t\t\t\t\tUopzS0DxVSjwqvUmXFKiHMQxTBWyRFzPSyxx/hANezDAMW0UnwTx88xUP8JbP64d\n\t\t\t\t\t\tbqWGyrDpJ/ZFbE5pROKdCWoNUW+NRgeKb8bZoQmzD4wJAoieX2NFrzVkJpO0iXdc\n\t\t\t\t\t\tOYX+o5NvQwjSkXSXTCMNBeg+kXvSG0dRFnbkQu5q0BMTflpj3WdOE8ct5qUOU2WU\n\t\t\t\t\t\tKvqnIkQMB3AcvJYLArP7zNO8S0DqvzvCDvOVHo+CyB5mSafRyZNgH4XG8gJ/T0xw\n\t\t\t\t\t\tPbMaTnddQBczEWuq39LDslvq0BICEP8cCrrdPq0U/LyGeeg+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "don.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.don.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.don.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.don.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.don.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.don.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.don.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.don.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.don.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "don.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAK8RPs/u00+SAcNWs4bMNfrk/CKcMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBgxFjAUBgNVBAMTDWlkcC5kb24uYWMudWswHhcNMTUwNTE5MDkyODMyWhcN\n\t\t\t\t\t\tMzUwNTE5MDkyODMyWjAYMRYwFAYDVQQDEw1pZHAuZG9uLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsyZDjYtG71spcGTQfuxeMqEbhPbLyLb1\n\t\t\t\t\t\tPfUjkpcgL4XEuoSokBL6xUqAHsnsGx43l/CKqagSOrYcj9cLldjhUTTkaXIEGeMe\n\t\t\t\t\t\t2HDLSUiCin5P4OamFRYtKd6ZA2mZTgwhhUnfMU58XvcLvPJKa0xbFtvg5fW3Zunh\n\t\t\t\t\t\tX8MQ3RW51rS8OA+gvmiz6ObL4eKdGFBMGwGJGFSuM271LLeW63urNLNx+SFKgy8g\n\t\t\t\t\t\t/w4+PjLUO6yT7aw1SI9D67ZsEHYluuXt8TJI8cexndKLbULGTfylX/0XeO/IWL6v\n\t\t\t\t\t\tFLhDcbYMQ6YufuX+TWbznTsVtUT32wxige7QcKfq3EfwGVaPqIeUEQIDAQABo2Ew\n\t\t\t\t\t\tXzA+BgNVHREENzA1gg1pZHAuZG9uLmFjLnVrhiRodHRwczovL2lkcC5kb24uYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFBXefJlUvzYENqK4j4ELocNrbEo7\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQAr6JWW4s83L4uE+aOGa1UMmdb2Q9jbYvFXJrwz\n\t\t\t\t\t\tUopzS0DxVSjwqvUmXFKiHMQxTBWyRFzPSyxx/hANezDAMW0UnwTx88xUP8JbP64d\n\t\t\t\t\t\tbqWGyrDpJ/ZFbE5pROKdCWoNUW+NRgeKb8bZoQmzD4wJAoieX2NFrzVkJpO0iXdc\n\t\t\t\t\t\tOYX+o5NvQwjSkXSXTCMNBeg+kXvSG0dRFnbkQu5q0BMTflpj3WdOE8ct5qUOU2WU\n\t\t\t\t\t\tKvqnIkQMB3AcvJYLArP7zNO8S0DqvzvCDvOVHo+CyB5mSafRyZNgH4XG8gJ/T0xw\n\t\t\t\t\t\tPbMaTnddQBczEWuq39LDslvq0BICEP8cCrrdPq0U/LyGeeg+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Doncaster College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.don.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Doncaster College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.vu.lt/SSO/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "SSO Admin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso-admin@vu.lt"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "VU"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.vu.lt/SSO/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://fedi.litnet.lt/en/policy"
              },
              {
                "lang": "lt",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://fedi.litnet.lt/lt/informacija/tvarka"
              }
            ],
            "registration_instant": "2010-09-27T06:35:00Z",
            "registration_authority": "https://fedi.litnet.lt",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.vu.lt/SSO/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.vu.lt/SSO/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vu.lt"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.vu.lt"
                  },
                  {
                    "lang": "lt",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.vu.lt"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "VU Single Sign On"
                  },
                  {
                    "lang": "lt",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "VU Vieningo prisijungimo sistema"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.ittc.vu.lt/images/vu_logo.jpg",
                    "height": "73",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "66"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Vilnius University"
                  },
                  {
                    "lang": "lt",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Vilniaus universitetas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID5zCCAs+gAwIBAgIJAOXB1LH43Dw1MA0GCSqGSIb3DQEBBQUAMIGJMQswCQYD\nVQQGEwJMVDEQMA4GA1UECAwHVmlsbml1czEQMA4GA1UEBwwHVmlsbml1czEkMCIG\nA1UECgwbVmlsbml1cyBVbml2ZXJzaXR5IC8gTElUTkVUMRAwDgYDVQQDDAdBcm1p\nbmFzMR4wHAYJKoZIhvcNAQkBFg9zc28tYWRtaW5AdnUubHQwHhcNMTQwODI5MTE0\nNTAxWhcNMjQwODI4MTE0NTAxWjCBiTELMAkGA1UEBhMCTFQxEDAOBgNVBAgMB1Zp\nbG5pdXMxEDAOBgNVBAcMB1ZpbG5pdXMxJDAiBgNVBAoMG1ZpbG5pdXMgVW5pdmVy\nc2l0eSAvIExJVE5FVDEQMA4GA1UEAwwHQXJtaW5hczEeMBwGCSqGSIb3DQEJARYP\nc3NvLWFkbWluQHZ1Lmx0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n1GmvMRKfSzqMuE+VmmkJswqKyFuALLRnYFeXUnkzK2W0ASATmp72hgphCg974bWs\nU/Vv9Mko1MEb9uvDLPhlnaNywClnQf/lwKAVcVz+fJALUjKVR5hhqQaeeUvikqXc\nklrgB1cLRtRxdXvHkhnbEwciR8QVqL/RdxfZ/U8QTeYnAQ1y5RsBYdhc5Sfk1PyV\ntylliDen0RJc1IOO98GxXZ2kHAeqyfNFj+69iC3DPFoqMOyS0ShJtMsZKonI25ie\nDPaCwnZsjotzu7S2umkhykJ1mH1PbCXJDnHuiO7cD/pD5XfpZMyDZHEcS/GGiEQm\n15vCUuyTV6z/RQZuhCxD2wIDAQABo1AwTjAdBgNVHQ4EFgQUkTQvHIDtX6Xr9zZg\nPFDvJ9OAAvwwHwYDVR0jBBgwFoAUkTQvHIDtX6Xr9zZgPFDvJ9OAAvwwDAYDVR0T\nBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEACiNtCh1swzMUbf6DG5DoTQuzvtwa\nUw8T/8lBfb2ncyiilFZ0pwfOh5W3FxQDHWQ+Be40WHWCO7Om8Mw0OVFyYN9DLfT4\nWne/3BTt+8SGDEaWlMl7G5fYtNc++U7lCzg+8HPTo4lBwMP4f+mbf5uYxwQXCoLs\n0b46tiNv61wXfncCReykBfYk6xXu4Toh1BmUn5hrNq11DjsaIpbCtczINnuj0ojl\nJOz7+J41MHf7QuwLCUdx66rbegfSV7t1QaTvgtGTFnl2hInXtrRmgC/tkmo4hiLx\nypUW4JChUxDyAuRqBVkP2pGiL6cf3vru8eEPdS+3QTBqmmbEZ1uVqw8VjQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID5zCCAs+gAwIBAgIJAOXB1LH43Dw1MA0GCSqGSIb3DQEBBQUAMIGJMQswCQYD\nVQQGEwJMVDEQMA4GA1UECAwHVmlsbml1czEQMA4GA1UEBwwHVmlsbml1czEkMCIG\nA1UECgwbVmlsbml1cyBVbml2ZXJzaXR5IC8gTElUTkVUMRAwDgYDVQQDDAdBcm1p\nbmFzMR4wHAYJKoZIhvcNAQkBFg9zc28tYWRtaW5AdnUubHQwHhcNMTQwODI5MTE0\nNTAxWhcNMjQwODI4MTE0NTAxWjCBiTELMAkGA1UEBhMCTFQxEDAOBgNVBAgMB1Zp\nbG5pdXMxEDAOBgNVBAcMB1ZpbG5pdXMxJDAiBgNVBAoMG1ZpbG5pdXMgVW5pdmVy\nc2l0eSAvIExJVE5FVDEQMA4GA1UEAwwHQXJtaW5hczEeMBwGCSqGSIb3DQEJARYP\nc3NvLWFkbWluQHZ1Lmx0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n1GmvMRKfSzqMuE+VmmkJswqKyFuALLRnYFeXUnkzK2W0ASATmp72hgphCg974bWs\nU/Vv9Mko1MEb9uvDLPhlnaNywClnQf/lwKAVcVz+fJALUjKVR5hhqQaeeUvikqXc\nklrgB1cLRtRxdXvHkhnbEwciR8QVqL/RdxfZ/U8QTeYnAQ1y5RsBYdhc5Sfk1PyV\ntylliDen0RJc1IOO98GxXZ2kHAeqyfNFj+69iC3DPFoqMOyS0ShJtMsZKonI25ie\nDPaCwnZsjotzu7S2umkhykJ1mH1PbCXJDnHuiO7cD/pD5XfpZMyDZHEcS/GGiEQm\n15vCUuyTV6z/RQZuhCxD2wIDAQABo1AwTjAdBgNVHQ4EFgQUkTQvHIDtX6Xr9zZg\nPFDvJ9OAAvwwHwYDVR0jBBgwFoAUkTQvHIDtX6Xr9zZgPFDvJ9OAAvwwDAYDVR0T\nBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEACiNtCh1swzMUbf6DG5DoTQuzvtwa\nUw8T/8lBfb2ncyiilFZ0pwfOh5W3FxQDHWQ+Be40WHWCO7Om8Mw0OVFyYN9DLfT4\nWne/3BTt+8SGDEaWlMl7G5fYtNc++U7lCzg+8HPTo4lBwMP4f+mbf5uYxwQXCoLs\n0b46tiNv61wXfncCReykBfYk6xXu4Toh1BmUn5hrNq11DjsaIpbCtczINnuj0ojl\nJOz7+J41MHf7QuwLCUdx66rbegfSV7t1QaTvgtGTFnl2hInXtrRmgC/tkmo4hiLx\nypUW4JChUxDyAuRqBVkP2pGiL6cf3vru8eEPdS+3QTBqmmbEZ1uVqw8VjQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "lt",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Vilniaus universitetas"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Vilnius University"
          }
        ],
        "organization_url": [
          {
            "lang": "lt",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vu.lt"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vu.lt"
          }
        ],
        "organization_name": [
          {
            "lang": "lt",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Vilniaus universitetas"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Vilnius University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.accross.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Visser"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cvisser@accross.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Carol"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Shipway"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mshipway@accross.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.accross.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-09-22T16:16:19Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.accross.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.accross.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.accross.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.accross.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.accross.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.accross.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "accross.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://idp.accross.ac.uk/images/accross-logo-80x60.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idp.accross.ac.uk/images/accross-logo-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Accrington & Rossendale College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAMq0Vv+YzRX5vh1Y4Lz5r1/3SHdQMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMBwxGjAYBgNVBAMMEWlkcC5hY2Nyb3NzLmFjLnVrMB4XDTE1MTAyNzE1MTEz\n\t\t\t\t\t\tMloXDTM1MTAyNzE0MTEzMlowHDEaMBgGA1UEAwwRaWRwLmFjY3Jvc3MuYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDEf3f2kDlcQudZo2BnnfZT\n\t\t\t\t\t\to+vRcMMqKaQUOZNtQD0iivKzOYrXPcDm+CMAEpN87i1RCFJy1M9QiQ8Mtxmz7vsI\n\t\t\t\t\t\tbo+zvEag/AXcYeHw2MJ2dPosbcMAyvpACm+ggaiP8ztSDNHBoPlMO2G/CEVHDwSa\n\t\t\t\t\t\txR/sYYwY2hBsx7R0qj0YjjFOHN2oxOLl38ZhJRMysJlIY/u/e+/2ILn8PP/db7yW\n\t\t\t\t\t\tpz3IBqa3ZMiLVuG5nor7fDi0H9197SUho0jxOfSa2w21Z3Zdrx63Ka/X62N1eLac\n\t\t\t\t\t\tIr8DCMGfZpteEU66nPic1M8Xzy1LPopRZfS/ZLBIav0wTXvTH7HDYaprV4fjVg2/\n\t\t\t\t\t\tAgMBAAGjZTBjMB0GA1UdDgQWBBT3IpR0IYKNNbwPaxuzlDSfVa3rNjBCBgNVHREE\n\t\t\t\t\t\tOzA5ghFpZHAuYWNjcm9zcy5hYy51a4YkaHR0cHM6Ly9pZHAuYWNjcm9zcy5hYy51\n\t\t\t\t\t\tay9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQAbTKEBm/sKKxkxLAjL7LTx\n\t\t\t\t\t\tqE9AVbOg/uvlmTL4pxbnThjx8fd2TgmfcRMBwP9LD+lVm/+pGL+g1Soh89B7cKlD\n\t\t\t\t\t\tHQBfNfaO0fNonctx6BSm4guSCWHY36kJpGPpIEHGddDrodFKoUYr/O31xOlSY7Xf\n\t\t\t\t\t\tioOjA5atLkYpYe4x5hRnbqQqnYrHpbO8MQU+zMXjI08WOfYKuOKRdu1NlE65f8cI\n\t\t\t\t\t\ttHR3hAmLNxQ4sbUmRJV6QzY9lbrEyI1fpwSFW0ly/RrvzaDSXeaCvfe8OzVcLubM\n\t\t\t\t\t\t4S3BP+CQStlZdm89skKfpQuf+o7uQWXoM1IYlPfkjUY2sTh6y4fl7HAjLXoLWDa5"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUL734gRp+xFc7syC52EK33icqG0wwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwHDEaMBgGA1UEAwwRaWRwLmFjY3Jvc3MuYWMudWswHhcNMTUxMDI3MTUxMTMw\n\t\t\t\t\t\tWhcNMzUxMDI3MTQxMTMwWjAcMRowGAYDVQQDDBFpZHAuYWNjcm9zcy5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKiskedri/4S0ZaAkzb04v4J\n\t\t\t\t\t\tr4lZrQRE6Eva7bOHswGhr8OjOHOOFJEp8kQCj6ESQDevjWXNo8bIBKH2OV2cq0V8\n\t\t\t\t\t\tCBzquhgLS037NWR1ay11YowkUxbSvv7LbVbqu3itrtciCtENmILDRWi+Al7tC0iY\n\t\t\t\t\t\tjQ9UJH7A3L0vXagu+UWR9t7H5zkDzoMOaTETq+kU4Jz2vF5YiIEBMwpSnA0QibtV\n\t\t\t\t\t\tXLUbKm5eyuxmIPD4Z+uYUpZi5vCssFh5Aanr8ZOIzAzywgFuQzY7bb76JY4NS5W2\n\t\t\t\t\t\tW7uST4/DdcQbmDP337oj/wFieSPwhtGmozic0s+155NqN1NKvXB6O6keQaYDje0C\n\t\t\t\t\t\tAwEAAaNlMGMwHQYDVR0OBBYEFG2PqgAQLBQ38kIwFP0AH2CMSnL1MEIGA1UdEQQ7\n\t\t\t\t\t\tMDmCEWlkcC5hY2Nyb3NzLmFjLnVrhiRodHRwczovL2lkcC5hY2Nyb3NzLmFjLnVr\n\t\t\t\t\t\tL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAD8z8ok3fxo9p6cQfkMNcFxN\n\t\t\t\t\t\tg8iADZJoS5Mqdpfu/BR+s0Z0LFELHsAJux7DIWwxqMnY4pd4LpyhN5HZhSG8pCQw\n\t\t\t\t\t\tzkDO1S1Bxew7VjM+FNpMonQduCZSQ7EZmvJ+zSrotdy1XfuNmn3PnPs9ku7MzJEq\n\t\t\t\t\t\tSCodGjndUk+PMY7u6GAhkEUv0nS6gXSqJBe9sdq0Vt/Oe6O4Bp4sZa+arc+3U/QK\n\t\t\t\t\t\tHH7m3nc5OkK4HzPj+3ttOdXsoM7prcEziHkXbO/yxUp0j3s2oLgqZWHOwEqzY0a+\n\t\t\t\t\t\tIRRswVGPP8t4dQnVn8iyvb3Omzzk/tgM/VO4yfA+vG5ILv/moWR9ppjEaeHdj+Y="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVALHFYHDwuzoc1vC86QChN5nghZOFMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMBwxGjAYBgNVBAMMEWlkcC5hY2Nyb3NzLmFjLnVrMB4XDTE1MTAyNzE1MTEz\n\t\t\t\t\t\tMloXDTM1MTAyNzE0MTEzMlowHDEaMBgGA1UEAwwRaWRwLmFjY3Jvc3MuYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCob8/Gmg9U/DPhw8H9PXG1\n\t\t\t\t\t\tmEyn+QNb3c33qcyIZXw/0UWs2HKZXCOF8QjXYgZW1zIhC9ibvLkbvdZbOmH1FJYL\n\t\t\t\t\t\tnm4A1rORc5Ow5nOHkHdN56dwwgbaJsR1rTmuP3WGU6Pvua+Nqjbg4ndzRdUcwbWl\n\t\t\t\t\t\tW8JAoGZrbLT0HddsS4nMYmRLYKlN6/Es3nICz2mCsdz36C0mNCYMwBXAoxGmOqaE\n\t\t\t\t\t\tR68Z1lIZCD8ywzOYke8fBsMztyK8UXytKkz/CGDrJWhvOlsaoBdbpZqeCr0GFoTL\n\t\t\t\t\t\tGJ1cKXD7Td+NMsAtRBh1Wxo5buyqTTxjddLayVAYgMwkjc3xVRPXP4n3qPYw/spv\n\t\t\t\t\t\tAgMBAAGjZTBjMB0GA1UdDgQWBBQYskrYA5h5kOnt5tEJzmD1Sd3/OzBCBgNVHREE\n\t\t\t\t\t\tOzA5ghFpZHAuYWNjcm9zcy5hYy51a4YkaHR0cHM6Ly9pZHAuYWNjcm9zcy5hYy51\n\t\t\t\t\t\tay9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQBolSV/bXek2SBV8CgbLm0z\n\t\t\t\t\t\tDuT+eMdm6f+qJ2FkosenPbM/0s68vxf3/ryr25n1RTggANdD5BZGUYDZzxAB9t9s\n\t\t\t\t\t\tZssCldB6LApXDZhUtnGbgnynlY8v2SrMvBGbDfS+A/3CMJ+VWZVQ348Dge7m03ty\n\t\t\t\t\t\tyFhzTModCkKjDd5E9xHt9cSfImH6vYIWvenDdSUhQqf9SUXk44+mk7vuo4bykIhW\n\t\t\t\t\t\tpI/E1tMBlsPPGnq2dJWNouCPVS8VeIrYX4mmdBp2pW7GY5QsUp+zjM7J8xSLLuiO\n\t\t\t\t\t\tP2UJp9bK8uFepWiwmKCO4nroELlmRYJOpJebxeA8OI8dGguscbzpHCJLDQEJIp2G"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Accrington & Rossendale College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.accross.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Accrington and Rossendale College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso.sron.nl/nidp/saml2/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.sron.nl/nidp/saml2/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2016-04-13T11:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/71006b868fab1717d248f85576cced01",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SRON Netherlands Institute for Space Research"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SRON Netherlands Institute for Space Research"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/sron.png",
                    "height": "42",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "120"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SRON Netherlands Institute for Space Research"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SRON Netherlands Institute for Space Research"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SRON Netherlands Institute for Space Research"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SRON Netherlands Institute for Space Research"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sron.nl/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sron.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SRON Netherlands Institute for Space Research"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SRON Netherlands Institute for Space Research"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibbo.ec-nantes.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cri-sys@ec-nantes.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibbo.ec-nantes.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-07-08T10:59:42Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibbo.ec-nantes.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibbo.ec-nantes.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibbo.ec-nantes.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ec-nantes.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ec-nantes.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Centrale de Nantes"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Centrale de Nantes"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAJo2ABzrdqEuYQPEMg3AUqxh974mMA0GCSqGSIb3DQEB\nBQUAMB4xHDAaBgNVBAMTE3NoaWJiby5lYy1uYW50ZXMuZnIwHhcNMDkwNjIzMTUy\nMzQ4WhcNMjkwNjIzMTUyMzQ4WjAeMRwwGgYDVQQDExNzaGliYm8uZWMtbmFudGVz\nLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkKdUKM4/DHJDjU4M\nwYoBAjsKU+LuXIELLk25O2l2qdHDvvXNli+i5dlCo87w+os/v7eUadHxCe+76G6b\nHiUuiMYVGuL1G27QA1AUOG1vAC0mbBIetw3ovME+LkiBwXQqTOlshYq7FaizifwX\nHGvn3qskkAHg29ZKvBsVyFka891bwvUAbiFjho+dwT/v+A4nXJWzv6vvsGw+u16m\nXhMyUpZjxGek9/7LpOjK+j9DNWn0wP9LAiEbLr3n7jguPLBBAC6f70U671Zdnf3R\nmBJkAYRe+YdpYuuVGA5/oIPZGcNb6VBYEH0wxgP+7BpiPoYUqVpiCsKc9FVuFKWG\neZzi6wIDAQABo20wazBKBgNVHREEQzBBghNzaGliYm8uZWMtbmFudGVzLmZyhipo\ndHRwczovL3NoaWJiby5lYy1uYW50ZXMuZnIvaWRwL3NoaWJib2xldGgwHQYDVR0O\nBBYEFKJXfKXL/okbKTLodXy6vDPmJc8BMA0GCSqGSIb3DQEBBQUAA4IBAQBKmvA3\nm29NOTfsDcF2X2zSok+1L9aDG/EGK28kVuojf2hp3GQMpdjXQ/05CtqYtcNDNBOt\n2rcopaZQsIRdiaU/hcxT/6JUsacFrowdBbpkNxAAuZ9ZJGUwEosSL61TkX9oaaFP\nNCaSmFdeleFd7KVMhtOkDy5+BQC9tJyraO5MqPUm5Q0QwXQN84al67IlnhIg0sNc\ntuTqkhqTxNCAnLzSCtBB/QB36Ao/0hwAHxo6AbFVGQDd2BRhsqQpcApZpb1oDFEh\nbhRZNLT/IXdDvj9i4zhAYNSRRVQ1vmyZOCoyk8wHLcWSRnurt8bbK2V2DxI0TKZh\n+LPVwWXes1OQooJD"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ecole Centrale de Nantes"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ec-nantes.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ecole Centrale de Nantes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://vsp2.edina.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:edina@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EDINA HelpDesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Soares"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ben.soares@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ben"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://vsp2.edina.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EDINA VSP2 Default"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://edina.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vsp2.edina.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vsp2.edina.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vsp2.edina.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vsp2.edina.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vsp2.edina.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://vsp2.edina.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIESDCCAzCgAwIBAgIJAKrBnZO7TvNTMA0GCSqGSIb3DQEBBQUAMIGkMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjERMA8GA1UECBMIU2NvdGxhbmQxEjAQBgNVBAcTCUVkaW5idXJnaDEk\n\t\t\t\t\t\tMCIGA1UEChMbVGhlIFVuaXZlcnNpdHkgb2YgRWRpbmJ1cmdoMQ4wDAYDVQQLEwVF\n\t\t\t\t\t\tRElOQTEZMBcGA1UEAxMQdnNwMi5lZGluYS5hYy51azEdMBsGCSqGSIb3DQEJARYO\n\t\t\t\t\t\tZWRpbmFAZWQuYWMudWswHhcNMTAwMjAxMTY0OTI1WhcNMjAwMTMwMTY0OTI1WjCB\n\t\t\t\t\t\tpDELMAkGA1UEBhMCR0IxETAPBgNVBAgTCFNjb3RsYW5kMRIwEAYDVQQHEwlFZGlu\n\t\t\t\t\t\tYnVyZ2gxJDAiBgNVBAoTG1RoZSBVbml2ZXJzaXR5IG9mIEVkaW5idXJnaDEOMAwG\n\t\t\t\t\t\tA1UECxMFRURJTkExGTAXBgNVBAMTEHZzcDIuZWRpbmEuYWMudWsxHTAbBgkqhkiG\n\t\t\t\t\t\t9w0BCQEWDmVkaW5hQGVkLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAynwMFgT8x37YBNpxAGTtLJxF3iG1adpqRmin40XS86HdJP21dzsH7JD1\n\t\t\t\t\t\tRanxUJJOWU8wud9e//ZZTC58TZbc8Zp0JRc5hlTOmLRksYt4B0QxrCqJ4EmFKlIM\n\t\t\t\t\t\tigE5ZNgoR+lwS1ENKikIHibnVcNF9IpIkX8sTzCY18JcileM8Yz5b+R91yoha1MU\n\t\t\t\t\t\tasRefMf2j7RR6kldAJw2Xj63aFtN0NXL6Z+HiLyg4JNslJTH9c3Ha88tI+6Ce1Q6\n\t\t\t\t\t\trG7rztkpHAD5Rd+ovQMysk9ihA3RN18X0Uu8LqExH2tUqq51Fmd+KQ04hyjE4gx+\n\t\t\t\t\t\tw2T6MwPmdp6zLQSXFf6x9CeRai7MwwIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCG\n\t\t\t\t\t\tSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4E\n\t\t\t\t\t\tFgQU59hHQ8+jwnn2x3Yz4BDaEaDHUrswHwYDVR0jBBgwFoAU59hHQ8+jwnn2x3Yz\n\t\t\t\t\t\t4BDaEaDHUrswDQYJKoZIhvcNAQEFBQADggEBAB5CEE4B61l2mn/sBlc7+qN+obOW\n\t\t\t\t\t\tgZURJvs/EeIlfR7LpWRITMSn4pE5mPR4R96tL0vNXc1jl5c2sTV9dtztazWmU+Z1\n\t\t\t\t\t\tu3rniEM6jETPFqlmYhOPFzYWoQTB0LGv3Id0NR4dCFDtFNl+EPaQAug9C39gkOCN\n\t\t\t\t\t\tiLZJlzOZxUALuUvebPbZMfqSTo8SdFT1Cv2No0hQIBjvlO1OimSjAWgkFR3snW8b\n\t\t\t\t\t\txzZ/lWUqrLDZYSo5LXQad3yNfhwi4dMJ5PRuAuTH1akdwlVf4AIeIQDm3QBKJIhj\n\t\t\t\t\t\tTOGrFRiCdlp4cIQwN66UelzUH2KjlI/iQXYLbq5uUHN/EI47I/E0gpnYr5E="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIESDCCAzCgAwIBAgIJAKrBnZO7TvNTMA0GCSqGSIb3DQEBBQUAMIGkMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjERMA8GA1UECBMIU2NvdGxhbmQxEjAQBgNVBAcTCUVkaW5idXJnaDEk\n\t\t\t\t\t\tMCIGA1UEChMbVGhlIFVuaXZlcnNpdHkgb2YgRWRpbmJ1cmdoMQ4wDAYDVQQLEwVF\n\t\t\t\t\t\tRElOQTEZMBcGA1UEAxMQdnNwMi5lZGluYS5hYy51azEdMBsGCSqGSIb3DQEJARYO\n\t\t\t\t\t\tZWRpbmFAZWQuYWMudWswHhcNMTAwMjAxMTY0OTI1WhcNMjAwMTMwMTY0OTI1WjCB\n\t\t\t\t\t\tpDELMAkGA1UEBhMCR0IxETAPBgNVBAgTCFNjb3RsYW5kMRIwEAYDVQQHEwlFZGlu\n\t\t\t\t\t\tYnVyZ2gxJDAiBgNVBAoTG1RoZSBVbml2ZXJzaXR5IG9mIEVkaW5idXJnaDEOMAwG\n\t\t\t\t\t\tA1UECxMFRURJTkExGTAXBgNVBAMTEHZzcDIuZWRpbmEuYWMudWsxHTAbBgkqhkiG\n\t\t\t\t\t\t9w0BCQEWDmVkaW5hQGVkLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAynwMFgT8x37YBNpxAGTtLJxF3iG1adpqRmin40XS86HdJP21dzsH7JD1\n\t\t\t\t\t\tRanxUJJOWU8wud9e//ZZTC58TZbc8Zp0JRc5hlTOmLRksYt4B0QxrCqJ4EmFKlIM\n\t\t\t\t\t\tigE5ZNgoR+lwS1ENKikIHibnVcNF9IpIkX8sTzCY18JcileM8Yz5b+R91yoha1MU\n\t\t\t\t\t\tasRefMf2j7RR6kldAJw2Xj63aFtN0NXL6Z+HiLyg4JNslJTH9c3Ha88tI+6Ce1Q6\n\t\t\t\t\t\trG7rztkpHAD5Rd+ovQMysk9ihA3RN18X0Uu8LqExH2tUqq51Fmd+KQ04hyjE4gx+\n\t\t\t\t\t\tw2T6MwPmdp6zLQSXFf6x9CeRai7MwwIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCG\n\t\t\t\t\t\tSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4E\n\t\t\t\t\t\tFgQU59hHQ8+jwnn2x3Yz4BDaEaDHUrswHwYDVR0jBBgwFoAU59hHQ8+jwnn2x3Yz\n\t\t\t\t\t\t4BDaEaDHUrswDQYJKoZIhvcNAQEFBQADggEBAB5CEE4B61l2mn/sBlc7+qN+obOW\n\t\t\t\t\t\tgZURJvs/EeIlfR7LpWRITMSn4pE5mPR4R96tL0vNXc1jl5c2sTV9dtztazWmU+Z1\n\t\t\t\t\t\tu3rniEM6jETPFqlmYhOPFzYWoQTB0LGv3Id0NR4dCFDtFNl+EPaQAug9C39gkOCN\n\t\t\t\t\t\tiLZJlzOZxUALuUvebPbZMfqSTo8SdFT1Cv2No0hQIBjvlO1OimSjAWgkFR3snW8b\n\t\t\t\t\t\txzZ/lWUqrLDZYSo5LXQad3yNfhwi4dMJ5PRuAuTH1akdwlVf4AIeIQDm3QBKJIhj\n\t\t\t\t\t\tTOGrFRiCdlp4cIQwN66UelzUH2KjlI/iQXYLbq5uUHN/EI47I/E0gpnYr5E="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vsp2.edina.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vsp2.edina.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vsp2.edina.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vsp2.edina.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vsp2.edina.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vsp2.edina.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vsp2.edina.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vsp2.edina.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vsp2.edina.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vsp2.edina.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vsp3.edina.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vsp3.edina.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vsp3.edina.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vsp3.edina.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vsp3.edina.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vsp3.edina.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vsp4.edina.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vsp4.edina.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vsp4.edina.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vsp4.edina.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vsp4.edina.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vsp4.edina.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "18"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.edina.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "19"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://auth.edina.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "20"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://auth.edina.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "21"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://auth.edina.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "22"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://auth.edina.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "23"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://auth.edina.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "24"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vsp2a.edina.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "25"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vsp2a.edina.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "26"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vsp2a.edina.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "27"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vsp2a.edina.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "28"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vsp2a.edina.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "29"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vsp2a.edina.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "30"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sso.utu.fi/sso-idp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Honkala"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hakajasen@utu.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tuomas"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Teraspuro"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hakajasen@utu.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petri"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Toivanen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hakajasen@utu.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Elina"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.utu.fi/sso-idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.csc.fi/english/institutions/haka/instructions/join/eduGAINRegistrationStatement/"
              }
            ],
            "registration_authority": "http://www.csc.fi/haka",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.utu.fi:443/sso/SSORedirect/metaAlias/utu/sso-idp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utu.fi"
              },
              {
                "display_name": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Turun yliopisto"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u00c5bo universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Turku"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIHPjCCBiagAwIBAgIQCIdeZB1qcIkU4tTDCYnlyjANBgkqhkiG9w0BAQsFADB1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\nsvl3XMWQ/VvQVSDEFjiZHOWDKJSxYtqL2mvzXRfEdY74Pw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Turun yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Turku"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u00c5bo universitet"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utu.fi/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utu.fi/"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utu.fi/"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Turun yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Turku"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u00c5bo universitet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://account.ki.se/shibboleth",
    {
      "entity_id": "https://account.ki.se/shibboleth",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Karolinska Institutet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ki.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "KI"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://account.ki.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://account.ki.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://account.ki.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://account.ki.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://account.ki.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://account.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Kontohantering/aktivering f\u00f6r anst\u00e4llda, studenter, m.fl. som har konto p\u00e5 KI"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Account management/activation for employees, students and others with accounts at KI"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "KI Account"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "KI Account"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "kiaccount01"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6DCCAdCgAwIBAgIJAPm1WTsF+HElMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC2tpYWNjb3VudDAxMB4XDTE1MTAwMjExNTcwOVoXDTI1MDkyOTExNTcwOVow\nFjEUMBIGA1UEAxMLa2lhY2NvdW50MDEwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQCqdDtxEF6CDHC7CarMpa5PbjGZUIj4nytb8UqkVt5/w8KfEsCgFpcl\nPFG76MJJEUO8sIxZ0Ro7ZgjYL+P/YG96MvipuIRTVt3pstvY87Rynz+nfN26fVk/\n9dtvXjUVO5q5KavxH8J1kE5L2xAcBGIaWKUC82lGp3t9CS6IrjwwNH5q4TIsExOg\nxXWXV/9wE+EOug6dAZfO0ro4jYtFfQOi3scKALA1r25LPxqSMROj4tL7xGO5Gq7N\nECFiGAZ5dGa0OQpP0gkYwqF+Qr1QkTzttH51thwiesnrPI3nhvfhF3GnitpqtcFQ\nF9yayGRUcKsderZ1hOP2dBN+6eLAPKhhAgMBAAGjOTA3MBYGA1UdEQQPMA2CC2tp\nYWNjb3VudDAxMB0GA1UdDgQWBBTymiOPZeOC0H1SXdTbsmc5Ue4+ljANBgkqhkiG\n9w0BAQUFAAOCAQEAgftgX+vyjz3HjlSJGE/LP4nFKnKR0JWIhwvQlGyLBurziWdf\nhjRMnEWKMRB2m4JPQvFjaHS/Nz2Z7hLWo2RiQ8oGNh1O1SOJO1+E9LWEkRkI9ao6\na1DlMy94+T4CfI0Ym/MmCa2y87OA8U89W7T3D48wYwbuU8PyV1LvwDiDtVXP0VF+\n/hbLWw7mPaVeCURTUnawlr1jeqyBNAsorE1DOlx7ttwzTRK/XHNaRNNdxM8C3J28\ney1LQlvL+twmMUq3Z6QenChnUCgX/OKXmILiz2eVRYLT5ME3tZcajXGEjmql9y54\nby1aSVWUQIH6Oc7ldFbWXyM1eke2mb6vlL94ww=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=kiaccount01"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://account.ki.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://account.ki.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://account.ki.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://account.ki.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://account.ki.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://journalarchives.jisc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:journalarchives@mimas.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Journal Archives Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mimas-shib-tech@listserv.manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mimas Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://journalarchives.jisc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-11-28T11:24:58Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Journal Archives"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://mimas.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Jisc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://journalarchives.jisc.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://journalarchives.jisc.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://journalarchives.jisc.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://journalarchives.jisc.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://journalarchives.jisc.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://journalarchives.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://journalarchives.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Journal archives from a range of publishers and societies"
                  }
                ],
                "logo": [
                  {
                    "text": "https://journalarchives.jisc.ac.uk/Login/journalarchives.png",
                    "height": "78",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "258"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Journal Archives"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEETCCAvmgAwIBAgIJAKgxolJV/8T9MA0GCSqGSIb3DQEBBQUAMHsxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRMwEQYDVQQIEwpNYW5jaGVzdGVyMRMwEQYDVQQHEwpNYW5jaGVzdGVy\n\t\t\t\t\t\tMQ0wCwYDVQQKEwRKaXNjMQ4wDAYDVQQLEwVNaW1hczEjMCEGA1UEAxMaam91cm5h\n\t\t\t\t\t\tbGFyY2hpdmVzLmppc2MuYWMudWswHhcNMTQxMTEwMTUzOTAyWhcNMjQxMTA3MTUz\n\t\t\t\t\t\tOTAyWjB7MQswCQYDVQQGEwJHQjETMBEGA1UECBMKTWFuY2hlc3RlcjETMBEGA1UE\n\t\t\t\t\t\tBxMKTWFuY2hlc3RlcjENMAsGA1UEChMESmlzYzEOMAwGA1UECxMFTWltYXMxIzAh\n\t\t\t\t\t\tBgNVBAMTGmpvdXJuYWxhcmNoaXZlcy5qaXNjLmFjLnVrMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAsM9KyvNgUEVD6RBVV5FbcVgnkltHhgegfpVTJ8xR\n\t\t\t\t\t\tbzpRTekHIp6FvTzX0uF7NK3hnG7q0reo15cqJldDRNjUKoLrTrjSPbu+8zL+Z3l+\n\t\t\t\t\t\tJnaTiy6HowB30hHc/YydK+X8GA3r6LNRmtAdciS+lkZQHdn4JIUosYPfS2PcgMDD\n\t\t\t\t\t\tl9ck/CxG58jWR/GhD/Tx9exu902PEr5sXsaOJkoPLWqXOvxLLd867HA5JbUN6qZe\n\t\t\t\t\t\tls1Mtvpvj2GC1kU8aU7bBjmX9Cz7lQYJijDK3BC6VbKdHI6p7OH3r6cIPUwWkYKJ\n\t\t\t\t\t\tytg40bQwHX3TatBgsS+43yQc7Lky3+XzYp5v2XekTjufnQIDAQABo4GXMIGUMAkG\n\t\t\t\t\t\tA1UdEwQCMAAwCwYDVR0PBAQDAgSwMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEF\n\t\t\t\t\t\tBQcDAjAlBgNVHREEHjAcghpqb3VybmFsYXJjaGl2ZXMuamlzYy5hYy51azA0BgNV\n\t\t\t\t\t\tHRIELTArgSltaW1hcy1zaGliLXRlY2hAbGlzdHNlcnYubWFuY2hlc3Rlci5hYy51\n\t\t\t\t\t\tazANBgkqhkiG9w0BAQUFAAOCAQEAeHESBFlQcPHfRo7eU/SA2dAZpq0V0brrtF+D\n\t\t\t\t\t\tKq+A5/lbscUP6q5g5wA46JapB3NpKBgMK2WTa4Ms/OTv1y49YWqCDSPC+L5+rxZ6\n\t\t\t\t\t\tiLypmPXb6tUNS6CuJV27Lm26mx2ecHTvwB1wXjoLZ27BJneN0hfA4hWhXIBGYjKh\n\t\t\t\t\t\tWz8zmrlfqu4WFQQojXIc5tVLSoqEnaUYcvo03OpXyq3pGDoN6+ipoZ03PyXHbDLS\n\t\t\t\t\t\t9HoL2DVz9hb4oJf8j5nolo8C/Kcve9hdMeA84NgWZc0RJV19OBLr/2FNUPsb8csF\n\t\t\t\t\t\tlUdHvWbKrO6c0VrEQ9nI9+A2GvR9SRsaUJRnEUBnw+ZwSjXlfQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://journalarchives.jisc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://journalarchives.jisc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://journalarchives.jisc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://journalarchives.jisc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://journalarchives.jisc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://journalarchives.jisc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-p00.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-p00.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p00.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p00.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p00.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p00.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p00.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-p00.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-p00.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;p00"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;p00"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-p00.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-p00.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIJALrB0xU/Xw/gMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2xhZG9rMy1wMDAubGFkb2sudW11LnNlMB4XDTEyMTAwMTExMzIyOFoXDTIy\nMDkyOTExMzIyOFowIjEgMB4GA1UEAxMXbGFkb2szLXAwMC5sYWRvay51bXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCpbAeLhpRp3k4YRgZev5r0\nH0Qp5DJT2GFGwG0u2rKGx8PRQH9VEcQs+hwoWjRf+ubNgkGRfQlg76FaIg5WLxf3\norhS1rPRGvLWOocBwq+w9pSLQBSL6NXI0MyQtXx1zTrruPC0Ps5gZ9dxinLg42al\n8Z43IOJpzlxV/og1sk/54r/mRYWr8EO2WZc/m6PkUK5/tJVf2fW5y/uXp9lEd8G3\nSzWicsN5QPnQyjoNUArtJOtdqGraP8Z+f/abB1a0vMoBZIwNj+2/6uC0tVvEE+hQ\nqcVm7KBafsaZnsNNDw847NY7062NiqSotc4k10O9d46lh1l6DUWBVwT1SaJqdFPt\nAgMBAAGjbTBrMEoGA1UdEQRDMEGCF2xhZG9rMy1wMDAubGFkb2sudW11LnNlhiZo\ndHRwczovL2xhZG9rMy1wMDAubGFkb2sudW11LnNlL2d1aS1zcDAdBgNVHQ4EFgQU\njIZiZRgSHi+Tg9++uEVPoqO0PnIwDQYJKoZIhvcNAQEFBQADggEBAGo8rWUyUsFE\nRnG4ja0Jr6CvmUCDEE8Hf2NR9X2pArHz4jZPN8Y+DJQxXA9z2f3tZyV16gRisz2n\nRyO30vCBYEeoblggXnrpJCHntSTXq+4wGT2nsXQf+OCELx4Fpge0EyHtruZcre+F\n4BT/hr1Zv/bgWYgK3HrD/a7Viez16powiAsO5ScHyXr0ayrwgI/y1v/HdK8jonpz\nEs66FG7elAYpYzzuiIlFApPK7+Bqc/AMklmzVWfB2+XQxnkKQ7B69NvuYldtUChv\nv0hYJMxInGifhVs86hcWvWCc9Cv65UAVGTvCW2KdtFe8n7xuux3KljOXlv8ECcLZ\nvt1mkOs1sbw="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-p00.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p00.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p00.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p00.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p00.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p00.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p00.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-p00.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-p00.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-p00.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibidp.cit.cornell.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "hy93@cornell.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hong Ye"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "security@cornell.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "University Security Office"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "se10@cornell.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve Edgar"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idmgmt@cornell.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Identity Management"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibidp.cit.cornell.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.cit.cornell.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.cit.cornell.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAOZ8NfBem6sHcI7F39sYmD/JG4YDMA0GCSqGSIb3DQEB\nBQUAMCIxIDAeBgNVBAMTF3NoaWJpZHAuY2l0LmNvcm5lbGwuZWR1MB4XDTA5MTEy\nMzE4NTI0NFoXDTI5MTEyMzE4NTI0NFowIjEgMB4GA1UEAxMXc2hpYmlkcC5jaXQu\nY29ybmVsbC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCTURo9\n90uuODo/5ju3GZThcT67K3RXW69jwlBwfn3png75Dhyw9Xa50RFv0EbdfrojH1P1\n9LyfCjubfsm9Z7FYkVWSVdPSvQ0BXx7zQxdTpE9137qj740tMJr7Wi+iWdkyBQS/\nbCNhuLHeNQor6NXZoBgX8HvLy4sCUb/4v7vbp90HkmP3FzJRDevzgr6PVNqWwNqp\ntZ0vQHSF5D3iBNbxq3csfRGQQyVi729XuWMSqEjPhhkf1UjVcJ3/cG8tWbRKw+W+\nOIm71k+99kOgg7IvygndzzaGDVhDFMyiGZ4njMzEJT67sEq0pMuuwLMlLE/86mSv\nuGwO2Qacb1ckzjodAgMBAAGjdTBzMFIGA1UdEQRLMEmCF3NoaWJpZHAuY2l0LmNv\ncm5lbGwuZWR1hi5odHRwczovL3NoaWJpZHAuY2l0LmNvcm5lbGwuZWR1L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBSQgitoP2/rJMDepS1sFgM35xw19zANBgkqhkiG\n9w0BAQUFAAOCAQEAaFrLOGqMsbX1YlseO+SM3JKfgfjBBL5TP86qqiCuq9a1J6B7\nYv+XYLmZBy04EfV0L7HjYX5aGIWLDtz9YAis4g3xTPWe1/bjdltUq5seRuksJjyb\nprGI2oAv/ShPBOyrkadectHzvu5K6CL7AxNTWCSXswtfdsuxcKo65tO5TRO1hWlr\n7Pq2F+Oj2hOvcwC0vOOjlYNe9yRE9DjJAzv4rrZUg71R3IEKNjfOF80LYPAFD2Sp\np36uB6TmSYl1nBmS5LgWF4EpEuODPSmy4sIV6jl1otuyI/An2dOcNqcgu7tYEXLX\nC8N6DXggDWPtPRdpk96UW45huvXudpZenrcd7A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cornell.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibidp.cit.cornell.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.cit.cornell.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.cit.cornell.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.cit.cornell.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.cit.cornell.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cornell.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Cornell University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAOZ8NfBem6sHcI7F39sYmD/JG4YDMA0GCSqGSIb3DQEB\nBQUAMCIxIDAeBgNVBAMTF3NoaWJpZHAuY2l0LmNvcm5lbGwuZWR1MB4XDTA5MTEy\nMzE4NTI0NFoXDTI5MTEyMzE4NTI0NFowIjEgMB4GA1UEAxMXc2hpYmlkcC5jaXQu\nY29ybmVsbC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCTURo9\n90uuODo/5ju3GZThcT67K3RXW69jwlBwfn3png75Dhyw9Xa50RFv0EbdfrojH1P1\n9LyfCjubfsm9Z7FYkVWSVdPSvQ0BXx7zQxdTpE9137qj740tMJr7Wi+iWdkyBQS/\nbCNhuLHeNQor6NXZoBgX8HvLy4sCUb/4v7vbp90HkmP3FzJRDevzgr6PVNqWwNqp\ntZ0vQHSF5D3iBNbxq3csfRGQQyVi729XuWMSqEjPhhkf1UjVcJ3/cG8tWbRKw+W+\nOIm71k+99kOgg7IvygndzzaGDVhDFMyiGZ4njMzEJT67sEq0pMuuwLMlLE/86mSv\nuGwO2Qacb1ckzjodAgMBAAGjdTBzMFIGA1UdEQRLMEmCF3NoaWJpZHAuY2l0LmNv\ncm5lbGwuZWR1hi5odHRwczovL3NoaWJpZHAuY2l0LmNvcm5lbGwuZWR1L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBSQgitoP2/rJMDepS1sFgM35xw19zANBgkqhkiG\n9w0BAQUFAAOCAQEAaFrLOGqMsbX1YlseO+SM3JKfgfjBBL5TP86qqiCuq9a1J6B7\nYv+XYLmZBy04EfV0L7HjYX5aGIWLDtz9YAis4g3xTPWe1/bjdltUq5seRuksJjyb\nprGI2oAv/ShPBOyrkadectHzvu5K6CL7AxNTWCSXswtfdsuxcKo65tO5TRO1hWlr\n7Pq2F+Oj2hOvcwC0vOOjlYNe9yRE9DjJAzv4rrZUg71R3IEKNjfOF80LYPAFD2Sp\np36uB6TmSYl1nBmS5LgWF4EpEuODPSmy4sIV6jl1otuyI/An2dOcNqcgu7tYEXLX\nC8N6DXggDWPtPRdpk96UW45huvXudpZenrcd7A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cornell University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cornell.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cornell University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.motherwell.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jennings"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:stephen.jennings@nclan.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stephen"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jennings"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:stephen.jennings@nclan.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stephen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.motherwell.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDbDCCAlQCCQCYnW4c5CPhFjANBgkqhkiG9w0BAQUFADB4MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjETMBEGA1UECBMKTW90aGVyd2VsbDETMBEGA1UEBxMKTW90aGVyd2VsbDEgMB4G\n\t\t\t\t\t\tA1UEChMXTmV3IENvbGxlZ2UgTGFuYXJrc2hpcmUxHTAbBgNVBAMTFGlkcC5tb3Ro\n\t\t\t\t\t\tZXJ3ZWxsLmNvLnVrMB4XDTE0MDUwNzEzMjUwN1oXDTM0MDUwMjEzMjUwN1oweDEL\n\t\t\t\t\t\tMAkGA1UEBhMCR0IxEzARBgNVBAgTCk1vdGhlcndlbGwxEzARBgNVBAcTCk1vdGhl\n\t\t\t\t\t\tcndlbGwxIDAeBgNVBAoTF05ldyBDb2xsZWdlIExhbmFya3NoaXJlMR0wGwYDVQQD\n\t\t\t\t\t\tExRpZHAubW90aGVyd2VsbC5jby51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\n\t\t\t\t\t\tAQoCggEBAOigdZo6jqFEwLsAI0rsABIfdOcGaOplDLGe58NaeY3Rhz0Yb9jlqy0X\n\t\t\t\t\t\tlWtcHYMkSMqaCG8HyX9I/HO4BNLcBG2WieAQwWda0ZDO6e1EpuMgZOZv1EMgCUTZ\n\t\t\t\t\t\tbtxqNIDjAK2DhuHQd+hqWmMORm5w24C2yZa4GHi0DatKUEOufEH6nXArRtRI5AAt\n\t\t\t\t\t\tOXkDUwnGwLMjkrxLWhPWBHQwoNlHLjIorNixYizvd5uaAA4RtOk9iYmnq2bf2/42\n\t\t\t\t\t\tMzeuqSf1S3gtpmooQrCDCJr2NOXrrCwtnekdbo77f/BT7KXhhICXF6qw2RM30/Im\n\t\t\t\t\t\toJmIaRKuPpZuZ4wi/b49QgM9xiXxFjMCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tBXmDILeWGVL4u+dT06/PdDsxSF40ojSWLNS2/gbKIStMUv2Ndj9VayfXR5pjPD0Z\n\t\t\t\t\t\tp6lwOtnTQ0WDMi3rFn2s2KXzD6JtWnSO42DTZELnfJhE790kO4u7tdNT4VMltjVK\n\t\t\t\t\t\tDvZcBFufCIU19hc7iAefKvZMFgS9vBhpo8VwoC9B3E8dgD+0BytsjQggdCvN4xwk\n\t\t\t\t\t\tbsY7NWo0A1FehMIKVHCPqjFfobfg2KYc3ARB6VDTSX8bxiLeR7nmwVI8OPCvbLhY\n\t\t\t\t\t\tzeCIZ0ypZsxScQBRzsZ9aoS70pV6aQTT4mfGvOaLtOsSg9+43cDUPb1dR7G+VZlx\n\t\t\t\t\t\tMOK0vjPGiv0YbkI+n6sWVw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "motherwell.co.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.motherwell.co.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.motherwell.co.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.motherwell.co.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.motherwell.co.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.motherwell.co.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.motherwell.co.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.motherwell.co.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.motherwell.co.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "motherwell.co.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDbDCCAlQCCQCYnW4c5CPhFjANBgkqhkiG9w0BAQUFADB4MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjETMBEGA1UECBMKTW90aGVyd2VsbDETMBEGA1UEBxMKTW90aGVyd2VsbDEgMB4G\n\t\t\t\t\t\tA1UEChMXTmV3IENvbGxlZ2UgTGFuYXJrc2hpcmUxHTAbBgNVBAMTFGlkcC5tb3Ro\n\t\t\t\t\t\tZXJ3ZWxsLmNvLnVrMB4XDTE0MDUwNzEzMjUwN1oXDTM0MDUwMjEzMjUwN1oweDEL\n\t\t\t\t\t\tMAkGA1UEBhMCR0IxEzARBgNVBAgTCk1vdGhlcndlbGwxEzARBgNVBAcTCk1vdGhl\n\t\t\t\t\t\tcndlbGwxIDAeBgNVBAoTF05ldyBDb2xsZWdlIExhbmFya3NoaXJlMR0wGwYDVQQD\n\t\t\t\t\t\tExRpZHAubW90aGVyd2VsbC5jby51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\n\t\t\t\t\t\tAQoCggEBAOigdZo6jqFEwLsAI0rsABIfdOcGaOplDLGe58NaeY3Rhz0Yb9jlqy0X\n\t\t\t\t\t\tlWtcHYMkSMqaCG8HyX9I/HO4BNLcBG2WieAQwWda0ZDO6e1EpuMgZOZv1EMgCUTZ\n\t\t\t\t\t\tbtxqNIDjAK2DhuHQd+hqWmMORm5w24C2yZa4GHi0DatKUEOufEH6nXArRtRI5AAt\n\t\t\t\t\t\tOXkDUwnGwLMjkrxLWhPWBHQwoNlHLjIorNixYizvd5uaAA4RtOk9iYmnq2bf2/42\n\t\t\t\t\t\tMzeuqSf1S3gtpmooQrCDCJr2NOXrrCwtnekdbo77f/BT7KXhhICXF6qw2RM30/Im\n\t\t\t\t\t\toJmIaRKuPpZuZ4wi/b49QgM9xiXxFjMCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tBXmDILeWGVL4u+dT06/PdDsxSF40ojSWLNS2/gbKIStMUv2Ndj9VayfXR5pjPD0Z\n\t\t\t\t\t\tp6lwOtnTQ0WDMi3rFn2s2KXzD6JtWnSO42DTZELnfJhE790kO4u7tdNT4VMltjVK\n\t\t\t\t\t\tDvZcBFufCIU19hc7iAefKvZMFgS9vBhpo8VwoC9B3E8dgD+0BytsjQggdCvN4xwk\n\t\t\t\t\t\tbsY7NWo0A1FehMIKVHCPqjFfobfg2KYc3ARB6VDTSX8bxiLeR7nmwVI8OPCvbLhY\n\t\t\t\t\t\tzeCIZ0ypZsxScQBRzsZ9aoS70pV6aQTT4mfGvOaLtOsSg9+43cDUPb1dR7G+VZlx\n\t\t\t\t\t\tMOK0vjPGiv0YbkI+n6sWVw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "New College Lanarkshire"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.motherwell.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "New College Lanarkshire"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso.uah.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "william.eubank@uah.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "William Eubank"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jill.casey@uah.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jill Casey"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ciso@uah.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CISO"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.uah.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.uah.edu/cas/logout.jsp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso.uah.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.uah.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.uah.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.uah.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.uah.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uah.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://uah.edusupportcenter.com/sims/helpcenter/layoutSix/SelfhelpArticleView.seam?source=Selfhelp&amp;parature_id=8572-8231-5478&amp;inst_name=uah&amp;cid=16749"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Alabama in Huntsville"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Alabama in Huntsville"
                  }
                ],
                "logo": [
                  {
                    "text": "https://sso.uah.edu/cas/images/UAH_4c_blue_small.png",
                    "lang": "en",
                    "height": "48",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "120"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.uah.edu/oit/policies/computer-use"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAIi9i4vXOYWFrAIWOwFcSA6H38ANMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC3Nzby51YWguZWR1MB4XDTEzMDQyNTIwNTEwMloXDTMz\nMDQyNTIwNTEwMlowFjEUMBIGA1UEAxMLc3NvLnVhaC5lZHUwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCjB9njLDs75zuxZkase3vquRjujMbQ37D4md16\n3miA88AGPR/hZ+J1Jfuc9uozGHJmO8++w7rpWEzSjKlIm7w9HX0uz/yhrLdLGDYK\naQqcljr1qDqmKB4W2uSvWj0Jd4wR+AMkJAwGpgdm0/PcgjNqfu8+cFg+kGmej9bO\nHt8NyzdhOGWbEhjGYLtQ9bYf1qZc8xoL+oAE1mCZ5O6ffO/P807hmF6c8jnCK8c2\nVQ5YHHV5Wzv2J63lNDbSzrbRFiLO8/mXZtDqTLgs0ZPSGaUjOagIjcv5E2hPB2AV\nxZ0z2sd9uqMOdkQXMQWfEXeeT+djIxlozqO+j3QkOJx5uJA9AgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC3Nzby51YWguZWR1hiJodHRwczovL3Nzby51YWguZWR1L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBTr1s8Z0jpuey7jYP14ICmRs17xuzANBgkqhkiG\n9w0BAQUFAAOCAQEAljsJKhHYgBfOiuqCWFKtiI6B1hMR+O+WYPIU7FKZJZrhahX7\ni6zfk/p2LMpMKDvHX61w4rS493MJ8p2iJMaYWr7MI42vhkuzm1gHquH0FAydMvOu\nDG57qCLosevGU8c/3yGXqDbLiXf5aqMerP1j/7WgS+v+BuLvQmwutXD2+jAlWxNS\nMLt/DOZ9iEoSSQ6OQPcrTF4wUGG7Ni4xEOT7Jm5ahUo3t4IuCaD0U8PwlLC2PS3c\nKJVYNsyf9Jo0eapWbBe5PJmeu3ZwiOVuDkk0PYn6Y2bu7XDYeyYaK0/zKD1erhoQ\nzGnfCmQ4c7IwxqAs5KghmtZqrZRjTWvX7Da3wQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Alabama in Huntsville"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uah.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Alabama in Huntsville"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.itam.cas.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Van\u00ed\u010dek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vanicekp@utia.cas.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.itam.cas.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2014-10-24T16:47:06Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/avcr"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUEsBKg0xdOetjiFaXL+mfQFs6ERcwDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPaWRwLml0YW0uY2FzLmN6MB4XDTE0MTAyMjA3MDMxOFoX\nDTM0MTAyMjA3MDMxOFowGjEYMBYGA1UEAxMPaWRwLml0YW0uY2FzLmN6MIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxAvwUCh/S8mxj1tvJq+Q+wssQ91g\nV83jKtGHeZnM+ADZ2iFNglHPE+BBBYb1bj9pqsP2BRwWIPWHeJ8bz1sLVeC90t23\nxLOudYs1ACIskNK7gvcKF1QBGGopHlUXmAgxibLTT+4+ZcBbzOdCMakBlxQd4wr5\ngSB35AD8SR7Qe5t3PoE5SQ3PK224l6DALOW9YdZ5bI0VfUJAqQjiDp9/hfmBXaod\nKzx2N+G12Jyay7VTnq7HCqUCwkWmMk2ZPmRUFwJ5abxOQtO3ClfDRoGHgVQSlR9O\nLwe0Ee3wFxvcCvGlTFdJ6WHgV5mhIB4PHxGyHADIW1BGG3Vd8WgX3w/2oQIDAQAB\no2UwYzBCBgNVHREEOzA5gg9pZHAuaXRhbS5jYXMuY3qGJmh0dHBzOi8vaWRwLml0\nYW0uY2FzLmN6L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQ34hoPcWC9wTBNpEun\nP6HH6dsWFDANBgkqhkiG9w0BAQUFAAOCAQEAJ0emvpLRJ3uJgfwgdXNI56Gi7zw/\nVtqXMmeuioY4Hqn3il10yOxvyM9FJCbgsGmCSpyUiIQzvMbZhJXjG/XSM17G3OdB\nt0gXjqSZ8XUzQ76xxGi4pBVlqTr50XpC6tlbOxZ8GflFX5DCGNTOSW/QKZUjnqB/\nttna9+UdDjmShQa2JBMmJ+mRM6m8RFEy2WQZplChLZkoZqLIWD48YY3GjGtOQ6FP\n2qO9lehSxJNgnAqM7raKBHwJIsZqYuTMaDU1Xm7JVg0eD9ht2Lvzmax69VjL1soY\nG0bWc5sh8gUEJyktAyE0P2pKMYNPDEfIv8LruQtOG9uU2F62xtvp+hJoyg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "itam.cas.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.itam.cas.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.itam.cas.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.itam.cas.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.itam.cas.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.itam.cas.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.itam.cas.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.itam.cas.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.itam.cas.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.itam.cas.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.itam.cas.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.itam.cas.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "itam.cas.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.itam.cas.cz/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.itam.cas.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider ITAM AS CR employees."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance \u00daTAM AV \u010cR"
                  }
                ],
                "logo": [
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-itam-44.png",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "42"
                  },
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-itam-1095.png",
                    "height": "1095",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "1044"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Theoretical and Applied Mechanics AS CR"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u00dastav teoretick\u00e9 a aplikovan\u00e9 mechaniky AV \u010cR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUEsBKg0xdOetjiFaXL+mfQFs6ERcwDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPaWRwLml0YW0uY2FzLmN6MB4XDTE0MTAyMjA3MDMxOFoX\nDTM0MTAyMjA3MDMxOFowGjEYMBYGA1UEAxMPaWRwLml0YW0uY2FzLmN6MIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxAvwUCh/S8mxj1tvJq+Q+wssQ91g\nV83jKtGHeZnM+ADZ2iFNglHPE+BBBYb1bj9pqsP2BRwWIPWHeJ8bz1sLVeC90t23\nxLOudYs1ACIskNK7gvcKF1QBGGopHlUXmAgxibLTT+4+ZcBbzOdCMakBlxQd4wr5\ngSB35AD8SR7Qe5t3PoE5SQ3PK224l6DALOW9YdZ5bI0VfUJAqQjiDp9/hfmBXaod\nKzx2N+G12Jyay7VTnq7HCqUCwkWmMk2ZPmRUFwJ5abxOQtO3ClfDRoGHgVQSlR9O\nLwe0Ee3wFxvcCvGlTFdJ6WHgV5mhIB4PHxGyHADIW1BGG3Vd8WgX3w/2oQIDAQAB\no2UwYzBCBgNVHREEOzA5gg9pZHAuaXRhbS5jYXMuY3qGJmh0dHBzOi8vaWRwLml0\nYW0uY2FzLmN6L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQ34hoPcWC9wTBNpEun\nP6HH6dsWFDANBgkqhkiG9w0BAQUFAAOCAQEAJ0emvpLRJ3uJgfwgdXNI56Gi7zw/\nVtqXMmeuioY4Hqn3il10yOxvyM9FJCbgsGmCSpyUiIQzvMbZhJXjG/XSM17G3OdB\nt0gXjqSZ8XUzQ76xxGi4pBVlqTr50XpC6tlbOxZ8GflFX5DCGNTOSW/QKZUjnqB/\nttna9+UdDjmShQa2JBMmJ+mRM6m8RFEy2WQZplChLZkoZqLIWD48YY3GjGtOQ6FP\n2qO9lehSxJNgnAqM7raKBHwJIsZqYuTMaDU1Xm7JVg0eD9ht2Lvzmax69VjL1soY\nG0bWc5sh8gUEJyktAyE0P2pKMYNPDEfIv8LruQtOG9uU2F62xtvp+hJoyg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Theoretical and Applied Mechanics AS CR, v.v.i."
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u00dastav teoretick\u00e9 a aplikovan\u00e9 mechaniky AV \u010cR, v.v.i."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.itam.cas.cz/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.itam.cas.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Theoretical and Applied Mechanics AS CR"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u00dastav teoretick\u00e9 a aplikovan\u00e9 mechaniky AV \u010cR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://de.dariah.eu/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Schloer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:bernd.schloer@sub.uni-goettingen.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bernd"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:register@dariah.eu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dariah"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://de.dariah.eu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2014-04-11T07:20:08Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Gesellschaft f\u00fcr wissenschaftliche Datenverarbeitung mbH"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Gesellschaft f\u00fcr wissenschaftliche Datenverarbeitung mbH"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gwdg.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gwdg.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e112"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e112"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://de.dariah.eu/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://de.dariah.eu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://de.dariah.eu/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://de.dariah.eu/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://de.dariah.eu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.dariah.eu"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.dariah.eu"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "DARIAH DE Portal"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "DARIAH DE Portal"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://de.dariah.eu/ServicePrivacyPolicy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DARIAH DE Portal"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DARIAH DE Portal"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "de.dariah.eu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGCjCCBPKgAwIBAgIHGFSpht2+vDANBgkqhkiG9w0BAQsFADCBrjELMAkGA1UE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\nbbk9N8FTzwSN4uy7DG4="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=de.dariah.eu,O=Georg-August-Universitaet Goettingen,L=Goettingen,ST=Niedersachsen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "de.dariah.eu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGCjCCBPKgAwIBAgIHGFSpht2+vDANBgkqhkiG9w0BAQsFADCBrjELMAkGA1UE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\nbbk9N8FTzwSN4uy7DG4="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=de.dariah.eu,O=Georg-August-Universitaet Goettingen,L=Goettingen,ST=Niedersachsen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://de.dariah.eu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://de.dariah.eu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://de.dariah.eu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://de.dariah.eu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://de.dariah.eu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "DARIAH DE Portal"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "DARIAH DE Portal"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "DARIAH DE Portal"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "DARIAH DE Portal"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "http://saml.ps-ui-test.qalab.geant.net",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it@geant.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "G\u00c9ANT IT"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it@geant.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "G\u00c9ANT IT"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://saml.ps-ui-test.qalab.geant.net",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-07-01T15:25:50Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "G\u00c9ANT Limited"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.geant.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "G\u00c9ANT Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "response_location": "http://ps-ui-test.qalab.geant.net/perfsonar-ui/saml/LogoutServiceHTTPRedirectResponse",
              "location": "https://ps-ui-test.qalab.geant.net/perfsonar-ui/saml/LogoutServiceHTTPRedirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ps-ui-test.qalab.geant.net/perfsonar-ui/saml/LogoutServiceSOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "G\u00c9ANT perfSONAR UI - testing instance"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "G\u00c9ANT perfSONAR UI Test"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRjCCAi6gAwIBAgIJAJOr6D3n/9SDMA0GCSqGSIb3DQEBBQUAMCUxIzAhBgNV\n\t\t\t\t\t\tBAMTGnBzLXVpLXRlc3QucWFsYWIuZ2VhbnQubmV0MB4XDTE0MDYxMDE3MTA0OFoX\n\t\t\t\t\t\tDTE3MDYxMDE3MTA0OFowJTEjMCEGA1UEAxMacHMtdWktdGVzdC5xYWxhYi5nZWFu\n\t\t\t\t\t\tdC5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC6yykwlB/6E0us\n\t\t\t\t\t\tmtnDv6wniXzry26DbtIv8I5Bn588caVmJmYgeDQSn5ED8riG9BJgYUcOuIZBANfL\n\t\t\t\t\t\tIzpuKgl91Hr8fAnBJ9TgssX623YkoQ1LFoXul9mfW9FrwyZQSxp3FzyKg9mKLsXJ\n\t\t\t\t\t\teDXOi1VFfHUhYnlPrnc0auSNDnBZ9tcMYSY9Q3xNDCsIsg2Mlqqp2p9l99oxMHIi\n\t\t\t\t\t\ttFT0SXvjDYP+pBiVBfaXDHRPKlTdBeO1HR7TZLpjEA7gPKmNXTTK/wNMP/al9MOw\n\t\t\t\t\t\tK/93kvcQePV3mb1JugDF9yuZIJOzAAdxXSb5vS9ijRg1MOW6O2XtxyCGGr7rrf09\n\t\t\t\t\t\tsCpO1kR5AgMBAAGjeTB3MFYGA1UdEQRPME2CGnBzLXVpLXRlc3QucWFsYWIuZ2Vh\n\t\t\t\t\t\tbnQubmV0hi9odHRwczovL3BzLXVpLXRlc3QucWFsYWIuZ2VhbnQubmV0L3BlcmZz\n\t\t\t\t\t\tb25hci11aTAdBgNVHQ4EFgQUfw6mrDLe+r53jDsgfKCkYTxXAnYwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAFqcGCSPmdl+S/e4GRWSNVEfe9XEf7z/YKMe6j8fnOTpO6WPFOZX\n\t\t\t\t\t\tbTYctAUCwoefVBj9aKb17kotmg4jPL8SABR9zk24D4pudXUmlTTPeJDZyC6TVIyL\n\t\t\t\t\t\tjOTIpR3K6nGXu644BjE0ofUv0BJV/kTepdbjKXD1NJRSJQIdEbGZcQMKhdBk+5+y\n\t\t\t\t\t\tWPSLKAT9q9ZQLPCammS1mXbwWe3yhLt5vkVfmimQd9C7zuFwVmW/MBiEFcsEbArb\n\t\t\t\t\t\tL7qgb1CfXuXWFY/Ec1yYFAviHb8LFe92VaTrrdme6Qqba3eryueU4FvjtYfWy6+K\n\t\t\t\t\t\tKMdsLHnE6yUSj1WUz0AHzZUPDcM9drnKw/k="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRjCCAi6gAwIBAgIJAJOr6D3n/9SDMA0GCSqGSIb3DQEBBQUAMCUxIzAhBgNV\n\t\t\t\t\t\tBAMTGnBzLXVpLXRlc3QucWFsYWIuZ2VhbnQubmV0MB4XDTE0MDYxMDE3MTA0OFoX\n\t\t\t\t\t\tDTE3MDYxMDE3MTA0OFowJTEjMCEGA1UEAxMacHMtdWktdGVzdC5xYWxhYi5nZWFu\n\t\t\t\t\t\tdC5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC6yykwlB/6E0us\n\t\t\t\t\t\tmtnDv6wniXzry26DbtIv8I5Bn588caVmJmYgeDQSn5ED8riG9BJgYUcOuIZBANfL\n\t\t\t\t\t\tIzpuKgl91Hr8fAnBJ9TgssX623YkoQ1LFoXul9mfW9FrwyZQSxp3FzyKg9mKLsXJ\n\t\t\t\t\t\teDXOi1VFfHUhYnlPrnc0auSNDnBZ9tcMYSY9Q3xNDCsIsg2Mlqqp2p9l99oxMHIi\n\t\t\t\t\t\ttFT0SXvjDYP+pBiVBfaXDHRPKlTdBeO1HR7TZLpjEA7gPKmNXTTK/wNMP/al9MOw\n\t\t\t\t\t\tK/93kvcQePV3mb1JugDF9yuZIJOzAAdxXSb5vS9ijRg1MOW6O2XtxyCGGr7rrf09\n\t\t\t\t\t\tsCpO1kR5AgMBAAGjeTB3MFYGA1UdEQRPME2CGnBzLXVpLXRlc3QucWFsYWIuZ2Vh\n\t\t\t\t\t\tbnQubmV0hi9odHRwczovL3BzLXVpLXRlc3QucWFsYWIuZ2VhbnQubmV0L3BlcmZz\n\t\t\t\t\t\tb25hci11aTAdBgNVHQ4EFgQUfw6mrDLe+r53jDsgfKCkYTxXAnYwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAFqcGCSPmdl+S/e4GRWSNVEfe9XEf7z/YKMe6j8fnOTpO6WPFOZX\n\t\t\t\t\t\tbTYctAUCwoefVBj9aKb17kotmg4jPL8SABR9zk24D4pudXUmlTTPeJDZyC6TVIyL\n\t\t\t\t\t\tjOTIpR3K6nGXu644BjE0ofUv0BJV/kTepdbjKXD1NJRSJQIdEbGZcQMKhdBk+5+y\n\t\t\t\t\t\tWPSLKAT9q9ZQLPCammS1mXbwWe3yhLt5vkVfmimQd9C7zuFwVmW/MBiEFcsEbArb\n\t\t\t\t\t\tL7qgb1CfXuXWFY/Ec1yYFAviHb8LFe92VaTrrdme6Qqba3eryueU4FvjtYfWy6+K\n\t\t\t\t\t\tKMdsLHnE6yUSj1WUz0AHzZUPDcM9drnKw/k="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://ps-ui-test.qalab.geant.net/perfsonar-ui/saml/SAMLAssertionConsumer",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "index": "1",
              "location": "https://ps-ui-test.qalab.geant.net/perfsonar-ui/saml/SAMLAssertionConsumer",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "false"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "G\u00c9ANT perfSONAR UI - testing instance"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "G\u00c9ANT perfSONAR UI Test"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.wellcome.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mitchell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:n.mitchell@wellcome.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Niraj"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mitchell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:n.mitchell@wellcome.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Niraj"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.wellcome.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDjDCCAnQCCQDSxQ0pkFszHTANBgkqhkiG9w0BAQUFADCBhzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEDAOBgNVBAgTB0VuZ2xhbmQxDzANBgNVBAcTBkxvbmRvbjEbMBkGA1UEChMS\n\t\t\t\t\t\tVGhlIFdlbGxjb21lIFRydXN0MRswGQYDVQQLExJTaGliYm9sZXRoIFByb2plY3Qx\n\t\t\t\t\t\tGzAZBgNVBAMTEmlkcC53ZWxsY29tZS5hYy51azAeFw0xMzA2MTkwODQ1MzVaFw0z\n\t\t\t\t\t\tMzA2MTQwODQ1MzVaMIGHMQswCQYDVQQGEwJHQjEQMA4GA1UECBMHRW5nbGFuZDEP\n\t\t\t\t\t\tMA0GA1UEBxMGTG9uZG9uMRswGQYDVQQKExJUaGUgV2VsbGNvbWUgVHJ1c3QxGzAZ\n\t\t\t\t\t\tBgNVBAsTElNoaWJib2xldGggUHJvamVjdDEbMBkGA1UEAxMSaWRwLndlbGxjb21l\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA6MfUt+kgNykR\n\t\t\t\t\t\t8E2o8xQg67Td9sUz3Xh/4q8jDZTlbblsWn0xCHnpoglT0+dMX2roLWoU1wj2WhyR\n\t\t\t\t\t\t0aV/gIc1HsFePGvg0/AzKhAFniWUygPTU8lRICZYr6L09gjk1cioiG/b6JQbkhup\n\t\t\t\t\t\tq68Os3mAWcmndLw64TuY90BdxjCSd+lgAFpPmHhhtQSrhTCWwQFmzGkERTLMRchY\n\t\t\t\t\t\tWZRGNc66TuCzYfGoiaEfdZzxxm+/VDVJked1vUH4x91fcVEFAuEl2nEpu5pq3gjT\n\t\t\t\t\t\tu2TVkVZ4tvokZdcGQ4rXjU6Sam/o7Xbj+nz8UsjyyrlYjB8YokgPR87pONi+KmFk\n\t\t\t\t\t\t0vu6NLuOCwIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQBX91XErSfqgmH8RVxMtZQu\n\t\t\t\t\t\t0KWQZB/US90cJhlUa/1CyrCaMVOLDD5tphz588Gkq12cDaoZ9gBSAf92XsDuQqlM\n\t\t\t\t\t\tDsU2p1OwqAiQ/Qt7eRUnealBsG/FT+ZDPd0Ieec0l42cltp45FaqpZqniaqMNhW6\n\t\t\t\t\t\tjeZBsl3D8nPC0YLFMdnT81GX+BKxoX4h5BcJzYzpYB/GtcSSbUTZBEfb46K216wo\n\t\t\t\t\t\tl4tAQPXq7W/jhQ2fGiSDIAPDxUnMaCak1DXL5T/3nyA6F9RbC8z9FPvP7sAjgfdE\n\t\t\t\t\t\tQTLzavN+fHNlz6ykEglkseHbRs19a1x/EP7tNR8juq3QBCnIpLDFzPt7OQE7mrre"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wellcome.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.wellcome.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.wellcome.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.wellcome.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.wellcome.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.wellcome.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.wellcome.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.wellcome.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.wellcome.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wellcome.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDjDCCAnQCCQDSxQ0pkFszHTANBgkqhkiG9w0BAQUFADCBhzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEDAOBgNVBAgTB0VuZ2xhbmQxDzANBgNVBAcTBkxvbmRvbjEbMBkGA1UEChMS\n\t\t\t\t\t\tVGhlIFdlbGxjb21lIFRydXN0MRswGQYDVQQLExJTaGliYm9sZXRoIFByb2plY3Qx\n\t\t\t\t\t\tGzAZBgNVBAMTEmlkcC53ZWxsY29tZS5hYy51azAeFw0xMzA2MTkwODQ1MzVaFw0z\n\t\t\t\t\t\tMzA2MTQwODQ1MzVaMIGHMQswCQYDVQQGEwJHQjEQMA4GA1UECBMHRW5nbGFuZDEP\n\t\t\t\t\t\tMA0GA1UEBxMGTG9uZG9uMRswGQYDVQQKExJUaGUgV2VsbGNvbWUgVHJ1c3QxGzAZ\n\t\t\t\t\t\tBgNVBAsTElNoaWJib2xldGggUHJvamVjdDEbMBkGA1UEAxMSaWRwLndlbGxjb21l\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA6MfUt+kgNykR\n\t\t\t\t\t\t8E2o8xQg67Td9sUz3Xh/4q8jDZTlbblsWn0xCHnpoglT0+dMX2roLWoU1wj2WhyR\n\t\t\t\t\t\t0aV/gIc1HsFePGvg0/AzKhAFniWUygPTU8lRICZYr6L09gjk1cioiG/b6JQbkhup\n\t\t\t\t\t\tq68Os3mAWcmndLw64TuY90BdxjCSd+lgAFpPmHhhtQSrhTCWwQFmzGkERTLMRchY\n\t\t\t\t\t\tWZRGNc66TuCzYfGoiaEfdZzxxm+/VDVJked1vUH4x91fcVEFAuEl2nEpu5pq3gjT\n\t\t\t\t\t\tu2TVkVZ4tvokZdcGQ4rXjU6Sam/o7Xbj+nz8UsjyyrlYjB8YokgPR87pONi+KmFk\n\t\t\t\t\t\t0vu6NLuOCwIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQBX91XErSfqgmH8RVxMtZQu\n\t\t\t\t\t\t0KWQZB/US90cJhlUa/1CyrCaMVOLDD5tphz588Gkq12cDaoZ9gBSAf92XsDuQqlM\n\t\t\t\t\t\tDsU2p1OwqAiQ/Qt7eRUnealBsG/FT+ZDPd0Ieec0l42cltp45FaqpZqniaqMNhW6\n\t\t\t\t\t\tjeZBsl3D8nPC0YLFMdnT81GX+BKxoX4h5BcJzYzpYB/GtcSSbUTZBEfb46K216wo\n\t\t\t\t\t\tl4tAQPXq7W/jhQ2fGiSDIAPDxUnMaCak1DXL5T/3nyA6F9RbC8z9FPvP7sAjgfdE\n\t\t\t\t\t\tQTLzavN+fHNlz6ykEglkseHbRs19a1x/EP7tNR8juq3QBCnIpLDFzPt7OQE7mrre"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Wellcome Trust"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wellcome.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Wellcome Trust"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://cafe.cnen.gov.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Emerson Antunes Coimbra"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "emerson@cnen.gov.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.cnen.gov.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEFjCCAv4CAQAwDQYJKoZIhvcNAQEFBQAwgdAxNTAzBgNVBAoULENORU4gLSBD\nb21pc3PDo28gTmFjaW9uYWwgZGUgRW5lcmdpYSBOdWNsZWFyMQ0wCwYDVQQLEwRD\nR1RJMSIwIAYJKoZIhvcNAQkBFhNlbWVyc29uQGNuZW4uZ292LmJyMRcwFQYDVQQH\nEw5SaW8gZGUgSmFuZWlybzEXMBUGA1UECBMOUmlvIGRlIEphbmVpcm8xCzAJBgNV\nBAYTAkJSMSUwIwYDVQQDExxjYWZlLmNuZW4uZ292LmJyLmNuZW4uZ292LmJyMB4X\nDTE1MTAyMDE2MzYyNFoXDTE4MTAxOTE2MzYyNFowgdAxNTAzBgNVBAoULENORU4g\nLSBDb21pc3PDo28gTmFjaW9uYWwgZGUgRW5lcmdpYSBOdWNsZWFyMQ0wCwYDVQQL\nEwRDR1RJMSIwIAYJKoZIhvcNAQkBFhNlbWVyc29uQGNuZW4uZ292LmJyMRcwFQYD\nVQQHEw5SaW8gZGUgSmFuZWlybzEXMBUGA1UECBMOUmlvIGRlIEphbmVpcm8xCzAJ\nBgNVBAYTAkJSMSUwIwYDVQQDExxjYWZlLmNuZW4uZ292LmJyLmNuZW4uZ292LmJy\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAu7jpAzHc6YPI8OlzUZ0K\nQupnUGDgg6XDAHhyO34gr0RVw23wA23comT1INiM0aBbnbs30pZlVm1EVyqI4Mrs\nqS5pkBd6GuZRFpwvFvC0kNY2nSDFgrB4CjZANiz6x1l/WdgyoJOQXEzCY+r2gb5E\nczsubWdjJtmIgQte81lPJ8eGRCEfCqBWWZZRnso3LSfdiBft8Zd2islKgsd6Kodm\nB+2pVyOsWPstUYctSn8DIufRHyqserTR6nHU1Y/uZJt09GMjStcCVJsbiMkCwaP3\nF7hYUU1MpK/V0DwyCTbnq1q3cYD28czgRZ52yL9CNbCjhW9IIIUGgu/ZjMF1MzRi\nfQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQBmsSusVoImAwRu8SWZQ2XD5YUxEqkj\nw3eLnxE94kp8buhgS478XKJELNFwDXAQfW6AzNkMgZF9KETYIGb2IEqb0MdFarjY\nrhT4PqEv2xZa/k2QUrYjEaJ+4uwIQStU0fx+2L//iVjApjeMhSf1RImzrkKyLLjc\nO3sWxrQWMNaoZnpLTfWuLPz+GKCSySo0dMYlmrUfXKhKx1LBpFl4LVv/BEfHRJoF\nek7juaxmfEIX/q2uIto6gIJLYwW/s6zkfJlD3sIVeP5EqcwheuZhmKNiFoaCtw6R\nLDx/9w6rhEYQbiIsW6NDa4Si/8p6x6UuG6zPFJ8uOIjD2yvEd0ap3S9+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gov.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.cnen.gov.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.cnen.gov.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.cnen.gov.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.cnen.gov.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.cnen.gov.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.cnen.gov.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.cnen.gov.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.cnen.gov.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gov.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.cnen.gov.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.cnen.gov.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CNEN - Comissao Nacional de Energia Nuclear"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CNEN - Comissao Nacional de Energia Nuclear"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CNEN - Comissao Nacional de Energia Nuclear"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CNEN - Comissao Nacional de Energia Nuclear"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEFjCCAv4CAQAwDQYJKoZIhvcNAQEFBQAwgdAxNTAzBgNVBAoULENORU4gLSBD\nb21pc3PDo28gTmFjaW9uYWwgZGUgRW5lcmdpYSBOdWNsZWFyMQ0wCwYDVQQLEwRD\nR1RJMSIwIAYJKoZIhvcNAQkBFhNlbWVyc29uQGNuZW4uZ292LmJyMRcwFQYDVQQH\nEw5SaW8gZGUgSmFuZWlybzEXMBUGA1UECBMOUmlvIGRlIEphbmVpcm8xCzAJBgNV\nBAYTAkJSMSUwIwYDVQQDExxjYWZlLmNuZW4uZ292LmJyLmNuZW4uZ292LmJyMB4X\nDTE1MTAyMDE2MzYyNFoXDTE4MTAxOTE2MzYyNFowgdAxNTAzBgNVBAoULENORU4g\nLSBDb21pc3PDo28gTmFjaW9uYWwgZGUgRW5lcmdpYSBOdWNsZWFyMQ0wCwYDVQQL\nEwRDR1RJMSIwIAYJKoZIhvcNAQkBFhNlbWVyc29uQGNuZW4uZ292LmJyMRcwFQYD\nVQQHEw5SaW8gZGUgSmFuZWlybzEXMBUGA1UECBMOUmlvIGRlIEphbmVpcm8xCzAJ\nBgNVBAYTAkJSMSUwIwYDVQQDExxjYWZlLmNuZW4uZ292LmJyLmNuZW4uZ292LmJy\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAu7jpAzHc6YPI8OlzUZ0K\nQupnUGDgg6XDAHhyO34gr0RVw23wA23comT1INiM0aBbnbs30pZlVm1EVyqI4Mrs\nqS5pkBd6GuZRFpwvFvC0kNY2nSDFgrB4CjZANiz6x1l/WdgyoJOQXEzCY+r2gb5E\nczsubWdjJtmIgQte81lPJ8eGRCEfCqBWWZZRnso3LSfdiBft8Zd2islKgsd6Kodm\nB+2pVyOsWPstUYctSn8DIufRHyqserTR6nHU1Y/uZJt09GMjStcCVJsbiMkCwaP3\nF7hYUU1MpK/V0DwyCTbnq1q3cYD28czgRZ52yL9CNbCjhW9IIIUGgu/ZjMF1MzRi\nfQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQBmsSusVoImAwRu8SWZQ2XD5YUxEqkj\nw3eLnxE94kp8buhgS478XKJELNFwDXAQfW6AzNkMgZF9KETYIGb2IEqb0MdFarjY\nrhT4PqEv2xZa/k2QUrYjEaJ+4uwIQStU0fx+2L//iVjApjeMhSf1RImzrkKyLLjc\nO3sWxrQWMNaoZnpLTfWuLPz+GKCSySo0dMYlmrUfXKhKx1LBpFl4LVv/BEfHRJoF\nek7juaxmfEIX/q2uIto6gIJLYwW/s6zkfJlD3sIVeP5EqcwheuZhmKNiFoaCtw6R\nLDx/9w6rhEYQbiIsW6NDa4Si/8p6x6UuG6zPFJ8uOIjD2yvEd0ap3S9+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CNEN - Comissao Nacional de Energia Nuclear"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CNEN - Comissao Nacional de Energia Nuclear"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cnen.gov.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cnen.gov.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CNEN - Comissao Nacional de Energia Nuclear"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CNEN - Comissao Nacional de Energia Nuclear"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://coco.aai.niif.hu/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NIIFI AAI"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@niif.hu"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NIIFI AAI"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@niif.hu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NIIFI AAI"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@niif.hu"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://coco.aai.niif.hu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-test"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:geant:niif.hu:eduid.hu:entity-attributes:processing-info",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NIIF - Nemzeti Inform\u00e1ci\u00f3s Infrastrukt\u00fara Fejleszt\u00e9si Int\u00e9zet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NIIF Institute - National Information Infrastructure Development"
          }
        ],
        "organization_url": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.niif.hu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.niif.hu/en"
          }
        ],
        "organization_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NIIF - Nemzeti Inform\u00e1ci\u00f3s Infrastrukt\u00fara Fejleszt\u00e9si Int\u00e9zet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NIIF Institute - National Information Infrastructure Development"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://coco.aai.niif.hu/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://coco.aai.niif.hu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://coco.aai.niif.hu/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://coco.aai.niif.hu/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://earc.eduid.hu/"
                  }
                ],
                "description": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SP for eduGAIN attribute release checker - CoCo"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SP for eduGAIN attribute release checker - CoCo"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SP for eduGAIN attribute release checker - CoCo"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://earc.eduid.hu/privacy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SP for eduGAIN attribute release checker - CoCo"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SP for eduGAIN attribute release checker - CoCo"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SP for eduGAIN attribute release checker - CoCo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "coco.aai.niif.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://coco.aai.niif.hu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://coco.aai.niif.hu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://coco.aai.niif.hu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://coco.aai.niif.hu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "hu",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SP for eduGAIN attribute release checker - CoCo"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SP for eduGAIN attribute release checker - CoCo"
                },
                {
                  "lang": "el",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SP for eduGAIN attribute release checker - CoCo"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibbox.lpplus.net/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mehta"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Sandip.mehta@lpplus.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sandip"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mehta"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Sandip.mehta@lpplus.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sandip"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibbox.lpplus.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-06-13T11:11:20Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "LP+ Limited: Shibboleth single signon"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lpplus.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LP+ Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibbox.lpplus.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibbox.lpplus.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibbox.lpplus.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibbox.lpplus.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibbox.lpplus.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibbox.lpplus.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibbox.lpplus.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEjCCAfqgAwIBAgIJAKnfC0bVM4B8MA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\n\t\t\t\t\t\tBAMTGWxwZTFiMTEtZHBtLTAxLmxwcGx1cy5uZXQwHhcNMTUwNjExMTE0NjI3WhcN\n\t\t\t\t\t\tMjUwNjA4MTE0NjI3WjAkMSIwIAYDVQQDExlscGUxYjExLWRwbS0wMS5scHBsdXMu\n\t\t\t\t\t\tbmV0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0t2ADfnkC5lKAdtO\n\t\t\t\t\t\tuGrMgyt9x/j95jLgtMs6bYBjVaYKohOErBqL8kAFcjxY5VWkLy/P8untgOyrnJtU\n\t\t\t\t\t\tI1EF6Qgt1Bo7+DY18htb01Ceu9F3S7bzNFaT2H8GXsTG1QopqZ1wkYgLpzw19DQY\n\t\t\t\t\t\tj1p8xp5RbXTtF6TiMWVeMY+hWG3ZO/kmAwo+yTvgGEkMRwvress/xxiA3GqhQ+jV\n\t\t\t\t\t\tvGylCpInNAr7dfjLTZrZriICAChHGs7/QaNsiLHn6Bzql0vFeqpujJ4K8AqJUyr7\n\t\t\t\t\t\tEEdpCiRiufzrtVKA9s0mB9W/adauX5TxQXE1gfjLkt5aeV16TW627DC1kXEZfGqa\n\t\t\t\t\t\tZrnZNQIDAQABo0cwRTAkBgNVHREEHTAbghlscGUxYjExLWRwbS0wMS5scHBsdXMu\n\t\t\t\t\t\tbmV0MB0GA1UdDgQWBBRAwEiU9cL90DldsrLKolQybKjBzTANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAzEzxKuMTgVWsY0u7ATfTfq+pP/CvHsdqXIr5g84amDBZY8YzQuPgIeV2\n\t\t\t\t\t\tfZrh688P1jqHP9JwHe3Ud6FN3e5NjArwZcKsWjzE2su0K/OsecJs5SdCfpos+VhY\n\t\t\t\t\t\tDz6KqWF7IBx3PV/86rdIWau/JG3t+jeJONQE/LjU9oQ/RILzDg1nqc+VRrpLWWKt\n\t\t\t\t\t\tdeaPMCAoStjlcjQqetfL/S6znYL10i8+zw3p7jACUO0HFvvdbnu/ZRlUUCjNZrHx\n\t\t\t\t\t\tuLJGy1P1ZbNhvLrcFsfa9DWPvDNmg2BxLs0GTv84b2Tqfc09muz7IEQbeRv5IVzJ\n\t\t\t\t\t\t+mCa8NQYKoO0Gn2O/HMlYdnqjqw/Hw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibbox.lpplus.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibbox.lpplus.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibbox.lpplus.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibbox.lpplus.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibbox.lpplus.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibbox.lpplus.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://adfs.nwo.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs.nwo.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-07-08T11:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/8e1798a9aacb6918015ddf5cbce658bc",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "De Nederlandse Organisatie voor wetenschappelijk Onderzoek (NWO) financiert wetenschappelijk onderzoek en stimuleert kwaliteit en vernieuwing in de wetenschap."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Netherlands Organisation for Scientific Research (NWO) is the Dutch national research council and promotes quality and innovation in science."
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/nwo.png",
                    "height": "251",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "500"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NWO"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NWO"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Netherlands Organisation for Scientific Research"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Netherlands Organisation for Scientific Research"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nwo.nl/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nwo.nl/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Nederlandse Organisatie voor Wetenschappelijk Onderzoek"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Nederlandse Organisatie voor Wetenschappelijk Onderzoek"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://cafe.unisc.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cristiano Maynart"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rede@unisc.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.unisc.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID4DCCAsgCAQAwDQYJKoZIhvcNAQEFBQAwgbUxMjAwBgNVBAoTKVVuaXNjIC0g\nVW5pdmVyc2lkYWRlIGRlIFNhbnRhIENydXogZG8gU3VsMQ0wCwYDVQQLEwRTaW5m\nMRwwGgYJKoZIhvcNAQkBFg1yZWRlQHVuaXNjLmJyMRowGAYDVQQHExFTYW50YSBD\ncnV6IGRvIHN1bDEaMBgGA1UECBMRUmlvIEdyYW5kZSBkbyBTdWwxCzAJBgNVBAYT\nAkJSMQ0wCwYDVQQDEwRjYWZlMB4XDTE0MDQxNzEzMTIyM1oXDTE5MDQxNjEzMTIy\nM1owgbUxMjAwBgNVBAoTKVVuaXNjIC0gVW5pdmVyc2lkYWRlIGRlIFNhbnRhIENy\ndXogZG8gU3VsMQ0wCwYDVQQLEwRTaW5mMRwwGgYJKoZIhvcNAQkBFg1yZWRlQHVu\naXNjLmJyMRowGAYDVQQHExFTYW50YSBDcnV6IGRvIHN1bDEaMBgGA1UECBMRUmlv\nIEdyYW5kZSBkbyBTdWwxCzAJBgNVBAYTAkJSMQ0wCwYDVQQDEwRjYWZlMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvEDiskDVSzfG170Jdhxh+TEf+SY6\nwTWP030Gpxy5ZXzBJW4yRDxXwkNICb4zK9dOy7pzCGgZ5Zm278PAXO9LBfy9pdex\nIUUrH5YHpC2Y6pZfasRyfpnqcY0TjW9spgfzGbvWB7js1tMuSUkyXomdHypdqOvh\n7ApHiZyxnSbFrfGKLtovPkx54TRNBPg31hfyiQTwUAM1MKHducLt4RyNiGBs/vVU\nNlEkW4ceIiaf68ETZ1+wsXyxFZszyGFSRR9kS7fPmsNy2MfpNd92RYPYNTWRFKl3\npnFuqgmwGthMZGUs3zcKQ2z+kzI/fJDYJDn/weEfkyHuqBG48DYedbJ73QIDAQAB\nMA0GCSqGSIb3DQEBBQUAA4IBAQA8U3vYfawqzdWKtXKlFBJDe/cyGt35ZaS3STUp\nuMJCyF5+LHZ0Wg63F7p/rCe2K3I1n4YEOsc7838Egj2SQTBDamk+JkjKkBlXJTeZ\nc/q1x5wFGcYe1cPPWaN9IRomPWV1PBejZGqRAhuE1iU/jMX26OL9ll1UpHa3TFSb\nqgLKYYAOySR6bHBjKyTWhzb+7J19MkWfJlQelwJmMQN2oWhmTyzp24dVCwaRVO16\n7vKl+BQtSYOdanuO0JBC0/91A5GvLH6/O2Dkb0bI18KZPamN+9gBKu14fiK0j+Fp\nnj+u1r3qFps5kydBvlBDl3JOZA34f1F5ZkrjnWjRokMdjiXl"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unisc.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.unisc.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.unisc.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.unisc.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.unisc.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.unisc.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.unisc.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.unisc.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.unisc.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unisc.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unisc.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unisc.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNISC - Universidade de Santa Cruz do Sul"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNISC - Universidade de Santa Cruz do Sul"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNISC - Universidade de Santa Cruz do Sul"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNISC - Universidade de Santa Cruz do Sul"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID4DCCAsgCAQAwDQYJKoZIhvcNAQEFBQAwgbUxMjAwBgNVBAoTKVVuaXNjIC0g\nVW5pdmVyc2lkYWRlIGRlIFNhbnRhIENydXogZG8gU3VsMQ0wCwYDVQQLEwRTaW5m\nMRwwGgYJKoZIhvcNAQkBFg1yZWRlQHVuaXNjLmJyMRowGAYDVQQHExFTYW50YSBD\ncnV6IGRvIHN1bDEaMBgGA1UECBMRUmlvIEdyYW5kZSBkbyBTdWwxCzAJBgNVBAYT\nAkJSMQ0wCwYDVQQDEwRjYWZlMB4XDTE0MDQxNzEzMTIyM1oXDTE5MDQxNjEzMTIy\nM1owgbUxMjAwBgNVBAoTKVVuaXNjIC0gVW5pdmVyc2lkYWRlIGRlIFNhbnRhIENy\ndXogZG8gU3VsMQ0wCwYDVQQLEwRTaW5mMRwwGgYJKoZIhvcNAQkBFg1yZWRlQHVu\naXNjLmJyMRowGAYDVQQHExFTYW50YSBDcnV6IGRvIHN1bDEaMBgGA1UECBMRUmlv\nIEdyYW5kZSBkbyBTdWwxCzAJBgNVBAYTAkJSMQ0wCwYDVQQDEwRjYWZlMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvEDiskDVSzfG170Jdhxh+TEf+SY6\nwTWP030Gpxy5ZXzBJW4yRDxXwkNICb4zK9dOy7pzCGgZ5Zm278PAXO9LBfy9pdex\nIUUrH5YHpC2Y6pZfasRyfpnqcY0TjW9spgfzGbvWB7js1tMuSUkyXomdHypdqOvh\n7ApHiZyxnSbFrfGKLtovPkx54TRNBPg31hfyiQTwUAM1MKHducLt4RyNiGBs/vVU\nNlEkW4ceIiaf68ETZ1+wsXyxFZszyGFSRR9kS7fPmsNy2MfpNd92RYPYNTWRFKl3\npnFuqgmwGthMZGUs3zcKQ2z+kzI/fJDYJDn/weEfkyHuqBG48DYedbJ73QIDAQAB\nMA0GCSqGSIb3DQEBBQUAA4IBAQA8U3vYfawqzdWKtXKlFBJDe/cyGt35ZaS3STUp\nuMJCyF5+LHZ0Wg63F7p/rCe2K3I1n4YEOsc7838Egj2SQTBDamk+JkjKkBlXJTeZ\nc/q1x5wFGcYe1cPPWaN9IRomPWV1PBejZGqRAhuE1iU/jMX26OL9ll1UpHa3TFSb\nqgLKYYAOySR6bHBjKyTWhzb+7J19MkWfJlQelwJmMQN2oWhmTyzp24dVCwaRVO16\n7vKl+BQtSYOdanuO0JBC0/91A5GvLH6/O2Dkb0bI18KZPamN+9gBKu14fiK0j+Fp\nnj+u1r3qFps5kydBvlBDl3JOZA34f1F5ZkrjnWjRokMdjiXl"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNISC - Universidade de Santa Cruz do Sul"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNISC - Universidade de Santa Cruz do Sul"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unisc.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unisc.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNISC - Universidade de Santa Cruz do Sul"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNISC - Universidade de Santa Cruz do Sul"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.strasbourg.archi.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "informatique@strasbourg.archi.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.strasbourg.archi.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-05-13T15:09:26Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.strasbourg.archi.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.strasbourg.archi.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "strasbourg.archi.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.strasbourg.archi.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ENSAS' students, teachers and staff"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Etudiants, enseignants et personnel ATOS de l'ENSAS"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/x-icon;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENSA Strasbourg"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Nationale Sup\u00e9rieure d'Architecture de Strasbourg"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRzCCAi+gAwIBAgIUXRRxYrjEVT64C9zybFH9tlnZ/5wwDQYJKoZIhvcNAQEF\nBQAwIjEgMB4GA1UEAxMXaWRwLnN0cmFzYm91cmcuYXJjaGkuZnIwHhcNMTQwNDE3\nMDk1OTQ1WhcNMzQwNDE3MDk1OTQ1WjAiMSAwHgYDVQQDExdpZHAuc3RyYXNib3Vy\nZy5hcmNoaS5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAI3xKVOB\n+X93VcOG42g8BWvY1oGgIYKmz8YwXVN3I2+mr2u4ahYEU95LpHVKKlAU1uDhcH8I\n99sRaSzY+Z2kz3SLcAut6dMHPeB1Rc4Jcp4CTkZYmhiVzVIyg+R7OqkbHCJIbj5H\nq6nho7r2Mx2iyTUg1z9R3dWFwFJN2nP31dJiSkW1nuz7Jv6P1zH642aV/IkaCgF0\nFlAnrZsdn3gWkw2uOaf6TDEddVxg1u9UwCJDS3IIP7uOAE0UErosp4cDXVCqtOjh\nYacOoGbH3qzu9DPpqgaPflbyoLcbQ4ngyUL/Uvh7UEEYIEVtnnXUNjrvw71kfHI7\nT0OaVGiNQtFSrD0CAwEAAaN1MHMwUgYDVR0RBEswSYIXaWRwLnN0cmFzYm91cmcu\nYXJjaGkuZnKGLmh0dHBzOi8vaWRwLnN0cmFzYm91cmcuYXJjaGkuZnIvaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFNdbgXFZ9tQW5IBHY2TKpAJpxYXPMA0GCSqGSIb3\nDQEBBQUAA4IBAQAyI1QQ9zGC5oABzuuM7OkyjjABsIN2JktmH9KpeykkLWRvNEAY\nNco1T5fGqAEmvA46F0KmbwO/B7wZB9TILJtXXE/CK9FU2Ti19+3GDdFrPY1JeIR9\nGleK7iSCQTb+vRmb+2rPr4LKczGICnEoGjAQF0ixMBpOnFX5Wzr+gMerm+DETZup\nbiEhRmJIckZgK3axgHcpzrrv6TJME0JsZNbh9nNjWu5ahjhxzGXzw7W1MzSWzaqk\n5YjDMooSN+djy/xITu54R3DfPFnXp7nGCqEq7mIO6kQQHVUK//ViMGcJ0hQSh54v\nrtnbjNGSrgbwkVabvcN+Gtc2+uEO8c/ozrhm"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEezCCA2OgAwIBAgIQFl8uHwbutP9D8H8eK6oUajANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQxNzAwMDAwMFoXDTE3MDQxNjIzNTk1OVowRTEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMSAwHgYDVQQDExdpZHAuc3RyYXNi\nb3VyZy5hcmNoaS5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMEW\n0E5QGJCSB3Ba7fVLIk1yCGEqE26Toca9CPHo6wio489qJYKcvvpcZZmONMEU1uL5\nZ5gCONsRfISTnlZu8R0RJLA4+nFiK3pnl5Qxb8GumPfo4Zy09qq1ldqQZ0aQ5p9l\neekm9cjui6trtn23gYADfL3lgcdXbkkENvxQiSPC4Wy+TnQHKZzscbTfvPn2YAnD\nzTURuz0egxuJts1IPgfhGpyNL2nXMRJtEAUGAh6hEztZClJU1CZcP+gwfOYc0tdp\n95+rjQ9nl9+ECw+dPA7n4JP9+R3gRmh0hsf1Kwra5UHB97lBoTj6k4DnOJaHKYcW\nthOStNfuJHAy/uzBTr0CAwEAAaOCAXQwggFwMB8GA1UdIwQYMBaAFAy9k2gM896r\no0lrKzdXR+qQ47ntMB0GA1UdDgQWBBQORU9i5o45EyY7F8g9y3s3qyy+jTAOBgNV\nHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYI\nKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYD\nVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFT\nU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0\nLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0\ncDovL29jc3AudGNzLnRlcmVuYS5vcmcwIgYDVR0RBBswGYIXaWRwLnN0cmFzYm91\ncmcuYXJjaGkuZnIwDQYJKoZIhvcNAQEFBQADggEBADcUZO7J6TsDIcHiWvf8Uoyz\nN0XZHA5XAN/AJAphS/Vz7HTLFjXfXrx0Khcg2OLlQyBC4c8h1ns1YZoFa1dvF89H\nneK+NGkypljJSB7V8V4jIH38Y40YRsHo4rh0labd+mQ0vwRXrVdHzSVU//gngaeD\nICFIMEAht/4ZWBBBgV+WuAq/8l5s+dF5tNpX1mKZaB9n2Id5QqVQGK9vhNzfRhYx\nUZEkRNOijgmcRNgjllmGqE3kD69a7KxcvedRPDRt3bweBdgFw2Gw2hLjYxn4ojMm\nade38YYscP19cjJ5xgSciH1tHTO7eNq7iirrjgxn9nM1Cxpq716Kv1DwnyFT9IA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ecole Nationale Sup\u00e9rieure d'Architecture de Strasbourg"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.strasbourg.archi.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ecole Nationale Sup\u00e9rieure d'Architecture de Strasbourg"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp01.sjsu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "atul.pala@sjsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Atul Pala"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp01.sjsu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp01.sjsu.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp01.sjsu.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAMn9JCLBoBmGCMcPMiQh214qaACSMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcDAxLnNqc3UuZWR1MB4XDTEwMDEyOTIzNTU1OVoX\nDTMwMDEyOTIzNTU1OVowGTEXMBUGA1UEAxMOaWRwMDEuc2pzdS5lZHUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDZqash2iGpYAoRusNEwfpM723akgZV\nq/3WVHlLOzY3SkL41HZYkT35LbdmAEpSUKpjcQXwsMxrSY4O51jXYINDj4vEiMV4\nNkjCne6IpAUQxmj1qaXyz/DpTfE2ufPls9kHRChcBiVWKikmu0k7lr7Sp8+fSj6T\nz2XWPHtGfjfm4oOKEQTzd0fuTJK9KTtRg38JYBcffyZVtIzBI2hkXJZZ0bYgxDHM\npudyHQCzsZzCLRa1L78qZl7JC02IERuPa2xlhjrA8BUY0c/S2qMLgvnRpRIG3u9S\n+sUJj5hPdXEVdmHjdHjOkQk4XzwBpTxCm+amdq9yoEM/NsQhFXnPxI4bAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcDAxLnNqc3UuZWR1hiVodHRwczovL2lkcDAxLnNq\nc3UuZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBR9udFAQ1LxMc3z2J98LoAb\nadve8zANBgkqhkiG9w0BAQUFAAOCAQEAD0/rgpSTUTkATD6J7P7F9hytDUZfwPBQ\nRTFilo3kLd6kZMzL48v8Ju5Vz8xXoFUi1ESaWFsdJgMcmhd189kjDtS4WzUsvPJj\nPFJZclPr/oJFR/RdKY6gytdINg43UivBqvPATLXKfZ1mjITNdfv+NEvBXzU5038t\ncpFlgJM0Uad00A88037gPo13fDh6kpydA2VwQbiE9JFfGOno3UlrdO9vMBiEgSCc\nhnbUY3LRoqUIGm6wfs3K6qNvpaF7cQ6WcZv3o4OlV2M/Eu8l9/Mv1EGwSOgfB1jG\n4g4nIYbPZdoTb/jPsSNwoNhTR9O/vGMzDFIUaU+zKQpFtlcylov+kA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sjsu.edu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "students.sjsu.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp01.sjsu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp01.sjsu.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp01.sjsu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp01.sjsu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp01.sjsu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp01.sjsu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sjsu.edu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "students.sjsu.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "San Jose State University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAMn9JCLBoBmGCMcPMiQh214qaACSMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcDAxLnNqc3UuZWR1MB4XDTEwMDEyOTIzNTU1OVoX\nDTMwMDEyOTIzNTU1OVowGTEXMBUGA1UEAxMOaWRwMDEuc2pzdS5lZHUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDZqash2iGpYAoRusNEwfpM723akgZV\nq/3WVHlLOzY3SkL41HZYkT35LbdmAEpSUKpjcQXwsMxrSY4O51jXYINDj4vEiMV4\nNkjCne6IpAUQxmj1qaXyz/DpTfE2ufPls9kHRChcBiVWKikmu0k7lr7Sp8+fSj6T\nz2XWPHtGfjfm4oOKEQTzd0fuTJK9KTtRg38JYBcffyZVtIzBI2hkXJZZ0bYgxDHM\npudyHQCzsZzCLRa1L78qZl7JC02IERuPa2xlhjrA8BUY0c/S2qMLgvnRpRIG3u9S\n+sUJj5hPdXEVdmHjdHjOkQk4XzwBpTxCm+amdq9yoEM/NsQhFXnPxI4bAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcDAxLnNqc3UuZWR1hiVodHRwczovL2lkcDAxLnNq\nc3UuZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBR9udFAQ1LxMc3z2J98LoAb\nadve8zANBgkqhkiG9w0BAQUFAAOCAQEAD0/rgpSTUTkATD6J7P7F9hytDUZfwPBQ\nRTFilo3kLd6kZMzL48v8Ju5Vz8xXoFUi1ESaWFsdJgMcmhd189kjDtS4WzUsvPJj\nPFJZclPr/oJFR/RdKY6gytdINg43UivBqvPATLXKfZ1mjITNdfv+NEvBXzU5038t\ncpFlgJM0Uad00A88037gPo13fDh6kpydA2VwQbiE9JFfGOno3UlrdO9vMBiEgSCc\nhnbUY3LRoqUIGm6wfs3K6qNvpaF7cQ6WcZv3o4OlV2M/Eu8l9/Mv1EGwSOgfB1jG\n4g4nIYbPZdoTb/jPsSNwoNhTR9O/vGMzDFIUaU+zKQpFtlcylov+kA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "San Jose State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sjsu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "San Jose State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ecole-navale.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "postmaster"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "postmaster@ecole-navale.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ecole-navale.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-02-12T14:48:14Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ecole-navale.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ecole-navale.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ecole-navale.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ecole-navale.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ecole-navale.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ecole Navale"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ecole Navale"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Navale"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Navale"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIHFDCCBfygAwIBAgIRAN/99OwB6bXHosvP+tqCI94wDQYJKoZIhvcNAQEFBQAw                                                                                                          \nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B                                                                                                          \nIFNTTCBDQTAeFw0xNDA0MTgwMDAwMDBaFw0xNzA0MTcyMzU5NTlaMEExITAfBgNV                                                                                                          \nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEcMBoGA1UEAxMTd3d3LmVjb2xl                                                                                                          \nLW5hdmFsZS5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALsw+dln                                                                                                          \nsBBhHCxtW6vz2ty64+0kFZ+Wzi7mb3bj+jAs1ybeABQxtMtmULlYGmmve/AKrdfc                                                                                                          \nRuoZw2/CnO9pqrVtd3d2dZecyC+BFLwbn5ZfQUvgQBeU6W7DlTUIs33o2nvB5Th8                                                                                                          \n1hkdNkT0hnOu2firWt7GZt6opzsvC/DK4HFMECoAbZkxwSdr0wqPFJlrDy/Zesu0                                                                                                          \nVgZ9DHpbdKlqu1FIN3Y7oQ6HxTqh4zJkgRuIKEAc5Qk9qEOGXtD3ONpmu4J5n8KH                                                                                                          \nwqm0tKItMlso1u/w8Bo4SmqnCzYv8CHN+WoO+V/77VShmGUwNG3zqoXUzJnqWrd8                                                                                                          \ngivD+8yzm+2Tb70CAwEAAaOCBBAwggQMMB8GA1UdIwQYMBaAFAy9k2gM896ro0lr                                                                                                          \nKzdXR+qQ47ntMB0GA1UdDgQWBBTge8meqqavoNPKBO/AxAmtOhOvADAOBgNVHQ8B                                                                                                          \nAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYB                                                                                                          \nBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0f                                                                                                          \nBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xD\nQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRj\ncy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDov\nL29jc3AudGNzLnRlcmVuYS5vcmcwggK8BgNVHREEggKzMIICr4ITd3d3LmVjb2xl\nLW5hdmFsZS5mcoIVYWlnbGUuZWNvbGUtbmF2YWxlLmZyghhhbm51YWlyZS5lY29s\nZS1uYXZhbGUuZnKCGmFzc2lzdGFuY2UuZWNvbGUtbmF2YWxlLmZyghRhdXRoLmVj\nb2xlLW5hdmFsZS5mcoIVY291cnMuZWNvbGUtbmF2YWxlLmZyghlkaWZmdXNpb24u\nZWNvbGUtbmF2YWxlLmZyghhkb2xpYmFyci5lY29sZS1uYXZhbGUuZnKCFWZpbGV6\nLmVjb2xlLW5hdmFsZS5mcoIVZm9ydW0uZWNvbGUtbmF2YWxlLmZyghdnZXN0aW9u\nLmVjb2xlLW5hdmFsZS5mcoITaWRwLmVjb2xlLW5hdmFsZS5mcoIWamFwcGl4LmVj\nb2xlLW5hdmFsZS5mcoIWbGlzdGVzLmVjb2xlLW5hdmFsZS5mcoIUbGl2ZS5lY29s\nZS1uYXZhbGUuZnKCFW1lZGlhLmVjb2xlLW5hdmFsZS5mcoIbbWVzZmljaGllcnMu\nZWNvbGUtbmF2YWxlLmZyghVwaG90by5lY29sZS1uYXZhbGUuZnKCG3Bob3RvdGhl\ncXVlLmVjb2xlLW5hdmFsZS5mcoIYcGlsb3RhZ2UuZWNvbGUtbmF2YWxlLmZyghhw\nbGFubmluZy5lY29sZS1uYXZhbGUuZnKCF3JlZG1pbmUuZWNvbGUtbmF2YWxlLmZy\nghtyZXNlcnZhdGlvbi5lY29sZS1uYXZhbGUuZnKCF3NlY291cnMuZWNvbGUtbmF2\nYWxlLmZyghhzb25kYWdlcy5lY29sZS1uYXZhbGUuZnKCE3N2bi5lY29sZS1uYXZh\nbGUuZnKCF3dlYm1haWwuZWNvbGUtbmF2YWxlLmZyghR3aWtpLmVjb2xlLW5hdmFs\nZS5mcjANBgkqhkiG9w0BAQUFAAOCAQEAKpU8yupf4hYd+QxSmgNJ+J9nWT3FUnMv\ns/EOxEm2Olexxu7avf9ywoQ7ejCPZIJ+cuFq7yfQnOpxFOYemeTw7jMkNMrO9f7p\ndG8EUqxt7PuyvbYm/f5/QbM/Xy/1y078y7wgElgS4j+Sls9FKe6soQuQP+1KIAbF\n2Lgz6hNu74TPcEBL4BaEjRSXeexkE77+JIYnF1CYqluXAaCnswAdtQoK7BXwJ3DA\n94YNbKlwTl4fjBHo0j4uvMoSjvfg6NBeNDjix2WlKqyhQ8A0HT3qz6EJAwdJLl7J\nONfoXgNShfdvleuZQiM4FXhXxPY28yXrGT0cc7dSZe2HVJdgMU1Lcw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ecole Navale"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ecole-navale.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ecole Navale"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.oniris-nantes.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Didier ROY"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "didier.roy@oniris-nantes.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gregory LEFRANC"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "gregory.lefranc@oniris-nantes.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.oniris-nantes.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-11-13T11:01:44Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.oniris-nantes.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.oniris-nantes.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.oniris-nantes.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oniris-nantes.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.oniris-nantes.fr/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Teachers, students"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Les enseignants, les \u00e9tudiants"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/ico;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ONIRIS"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ONIRIS"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAOz8cFkBTLbxVln29ynPAKgeQJHNMA0GCSqGSIb3DQEB\nBQUAMB8xHTAbBgNVBAMMFGlkcC5vbmlyaXMtbmFudGVzLmZyMB4XDTE1MDkxODE0\nMjA1MVoXDTM1MDkxODE0MjA1MVowHzEdMBsGA1UEAwwUaWRwLm9uaXJpcy1uYW50\nZXMuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCN+nrKBD7GWB/T\naJGUh8V98CXhBXVcZLdOvyssCD7FmjDISGEimgaAFRCnExN+0XoZWutK37Mthtn7\nfAPFF92sucimPRluwEFniPHyHGd2Fl1kP5NJM+I0SfyYF/QH3yg/D9ZVd7x4XLFL\nEnH3aPxL+cmUcdAcct26PuvuKiUDXPnAALgUwDaHHN/sPcgmXuJbskka7fzN9eZI\nXAzjP+pHnqZI3gBujQmUeRf5FK12mEcNdL+gYJVjUhnpOj9bgnIA9gB0yxtd+wXo\nzwNc0w2rbu3EuSo58izreXEaiy3CFZrhB+sr8GRqV7YUdNACuxZhRq1PC2rqbdZm\nrd9LylwxAgMBAAGjbzBtMB0GA1UdDgQWBBTZTZo/XqVYLds0PI9G9SObpiScSzBM\nBgNVHREERTBDghRpZHAub25pcmlzLW5hbnRlcy5mcoYraHR0cHM6Ly9pZHAub25p\ncmlzLW5hbnRlcy5mci9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEA\nQZvGx+m1HA5knbytovMAYLsstIryni09aHxCdP99Ak++pSXWTevvb4DukifIKgfv\nU8vleBoAortLhq+25dAZUsDL45st8tHx2umUOR/0xrujAPzMetZ+eFt1YdgYH1f+\n7d6IVwhObN7FiaV+/D+WZ40eAZT+3nY8V+XnpkP5H6rrauZ7RIJVjGXUW1PuNnAT\nyfFkeSjliStwTQZGY6qn28he9NDqOq7M4ye6zihzbtSa0Md9bYS/OlJHU7UNqbaD\nujowHlafOBa/eC9WGKT2m2VT2yjF7opAf0d5Y+rIgM4pDglCV2/p9Sz5GGGbO1Fe\nZKXiB3CTQrnXASQ6EfUC+w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ONIRIS"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oniris-nantes.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ONIRIS"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dev-sso.knewknovel.com/entry/uk_federation/Metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Crisler"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.crisler@elsevier.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cheung"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kops@knovel.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Johnny"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dev-sso.knewknovel.com/entry/uk_federation/Metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-06-21T13:15:39Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Knovel Corporation: Phoenix Dev-SSO Test"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://why.knovel.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Knovel Corporation"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev-sso.knewknovel.com/saml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dev-sso.knewknovel.com/saml/module.php/saml/sp/discoresp.php",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Knovel website integrates technical reference information with analytical and search tools for engineers."
                  }
                ],
                "logo": [
                  {
                    "text": "https://dev-content.knewknovel.com/web/integration/ukfed/images/logo_350_115.png",
                    "height": "115",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Knovel Corporation: Phoenix Dev-SSO Test"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKDCCAxCgAwIBAgIJAKxWU5hufa29MA0GCSqGSIb3DQEBCwUAMIGUMQswCQYD\n\t\t\t\t\tVQQGEwJVUzELMAkGA1UECAwCTlkxDDAKBgNVBAcMA05ZQzEUMBIGA1UECgwLS25v\n\t\t\t\t\tdmVsIENvcnAxCzAJBgNVBAsMAklUMScwJQYDVQQDDB5odHRwczovL2Rldi1zc28u\n\t\t\t\t\ta25ld2tub3ZlbC5jb20xHjAcBgkqhkiG9w0BCQEWD2tvcHNAa25vdmVsLmNvbTAe\n\t\t\t\t\tFw0xNTA4MTkyMDUzMDdaFw0yNTA4MTYyMDUzMDdaMIGUMQswCQYDVQQGEwJVUzEL\n\t\t\t\t\tMAkGA1UECAwCTlkxDDAKBgNVBAcMA05ZQzEUMBIGA1UECgwLS25vdmVsIENvcnAx\n\t\t\t\t\tCzAJBgNVBAsMAklUMScwJQYDVQQDDB5odHRwczovL2Rldi1zc28ua25ld2tub3Zl\n\t\t\t\t\tbC5jb20xHjAcBgkqhkiG9w0BCQEWD2tvcHNAa25vdmVsLmNvbTCCASIwDQYJKoZI\n\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBANmMaTuO4pe4qBkuTtqCeD24Nll4NZK6WDsa\n\t\t\t\t\tKLsbuoyubRHwH+UAWiqxDAtwYcwkF/GA31mpXgSAHF5o2K94OSHlfV8NlBsFvcTa\n\t\t\t\t\tm5ibH3gWxPnSPZ6RZmDORZGou+fcjPmEaNHp3N4fr477CpU3DRByF7NbCjxu45pM\n\t\t\t\t\tevQXrmNPL5xrZ4150KqfYLLW0J3vcVAX1isjATD9rZ9NexrJGyrfKmBedRRjGY8c\n\t\t\t\t\tOOGi8P+EZ7AZp2Rl1n6KaDqZxi4GyL9Idu2F+YDhs8n9l4WDru9xkS5Yj/aZ/BOO\n\t\t\t\t\txPnZoBGdG6PwjMOOvv2HDtCg+SBoexd43J0FVXdE8TDBVsin8BECAwEAAaN7MHkw\n\t\t\t\t\tCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2Vy\n\t\t\t\t\tdGlmaWNhdGUwHQYDVR0OBBYEFIiT/cFvKveYIGRbT62j05zG00X1MB8GA1UdIwQY\n\t\t\t\t\tMBaAFIiT/cFvKveYIGRbT62j05zG00X1MA0GCSqGSIb3DQEBCwUAA4IBAQBbR8dI\n\t\t\t\t\tgeLZtbSE81w42AX4rj+G/2l5aq2Uqk+9YFP1q6L2CwX1Fd1mYPeZ8vhuZo1wTxBp\n\t\t\t\t\tSrIUpP5xS/5zB+0PdKCc469Ygb2O0QIwmgpVyLfqp8CRH6ZfWNpHkTbm85wvR6L2\n\t\t\t\t\tpOih0rQf5M63+/Vz/jJ8Q8pB9miW5xJeHk9tga4SRqqX9gDCTVpOURQwlY9rH3HW\n\t\t\t\t\tAOfBMik79ajJTtdFzNTHcXRsMECGcUPpwhYO6hoCnKZuKno/Mv3m65V0D8QFSpo9\n\t\t\t\t\tH3cR++PC2D/SXJ/gScby4KoZ/btjYgtQVFx0Zw0gy6O04HsTLaS8dvYaDh9KtG5Y\n\t\t\t\t\tvGswy+4N6R+gM1ov"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKDCCAxCgAwIBAgIJAKxWU5hufa29MA0GCSqGSIb3DQEBCwUAMIGUMQswCQYD\n\t\t\t\t\tVQQGEwJVUzELMAkGA1UECAwCTlkxDDAKBgNVBAcMA05ZQzEUMBIGA1UECgwLS25v\n\t\t\t\t\tdmVsIENvcnAxCzAJBgNVBAsMAklUMScwJQYDVQQDDB5odHRwczovL2Rldi1zc28u\n\t\t\t\t\ta25ld2tub3ZlbC5jb20xHjAcBgkqhkiG9w0BCQEWD2tvcHNAa25vdmVsLmNvbTAe\n\t\t\t\t\tFw0xNTA4MTkyMDUzMDdaFw0yNTA4MTYyMDUzMDdaMIGUMQswCQYDVQQGEwJVUzEL\n\t\t\t\t\tMAkGA1UECAwCTlkxDDAKBgNVBAcMA05ZQzEUMBIGA1UECgwLS25vdmVsIENvcnAx\n\t\t\t\t\tCzAJBgNVBAsMAklUMScwJQYDVQQDDB5odHRwczovL2Rldi1zc28ua25ld2tub3Zl\n\t\t\t\t\tbC5jb20xHjAcBgkqhkiG9w0BCQEWD2tvcHNAa25vdmVsLmNvbTCCASIwDQYJKoZI\n\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBANmMaTuO4pe4qBkuTtqCeD24Nll4NZK6WDsa\n\t\t\t\t\tKLsbuoyubRHwH+UAWiqxDAtwYcwkF/GA31mpXgSAHF5o2K94OSHlfV8NlBsFvcTa\n\t\t\t\t\tm5ibH3gWxPnSPZ6RZmDORZGou+fcjPmEaNHp3N4fr477CpU3DRByF7NbCjxu45pM\n\t\t\t\t\tevQXrmNPL5xrZ4150KqfYLLW0J3vcVAX1isjATD9rZ9NexrJGyrfKmBedRRjGY8c\n\t\t\t\t\tOOGi8P+EZ7AZp2Rl1n6KaDqZxi4GyL9Idu2F+YDhs8n9l4WDru9xkS5Yj/aZ/BOO\n\t\t\t\t\txPnZoBGdG6PwjMOOvv2HDtCg+SBoexd43J0FVXdE8TDBVsin8BECAwEAAaN7MHkw\n\t\t\t\t\tCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2Vy\n\t\t\t\t\tdGlmaWNhdGUwHQYDVR0OBBYEFIiT/cFvKveYIGRbT62j05zG00X1MB8GA1UdIwQY\n\t\t\t\t\tMBaAFIiT/cFvKveYIGRbT62j05zG00X1MA0GCSqGSIb3DQEBCwUAA4IBAQBbR8dI\n\t\t\t\t\tgeLZtbSE81w42AX4rj+G/2l5aq2Uqk+9YFP1q6L2CwX1Fd1mYPeZ8vhuZo1wTxBp\n\t\t\t\t\tSrIUpP5xS/5zB+0PdKCc469Ygb2O0QIwmgpVyLfqp8CRH6ZfWNpHkTbm85wvR6L2\n\t\t\t\t\tpOih0rQf5M63+/Vz/jJ8Q8pB9miW5xJeHk9tga4SRqqX9gDCTVpOURQwlY9rH3HW\n\t\t\t\t\tAOfBMik79ajJTtdFzNTHcXRsMECGcUPpwhYO6hoCnKZuKno/Mv3m65V0D8QFSpo9\n\t\t\t\t\tH3cR++PC2D/SXJ/gScby4KoZ/btjYgtQVFx0Zw0gy6O04HsTLaS8dvYaDh9KtG5Y\n\t\t\t\t\tvGswy+4N6R+gM1ov"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDyjCCArKgAwIBAgIJALW6A/BUfZ3FMA0GCSqGSIb3DQEBBQUAMGYxCzAJBgNV\n\t\t\t\t\tBAYTAlVTMQswCQYDVQQIEwJOWTEMMAoGA1UEBxMDTllDMRswGQYDVQQKExJLbm92\n\t\t\t\t\tZWwgQ29ycG9yYXRpb24xHzAdBgNVBAMTFmRldi1zc28ua25ld2tub3ZlbC5jb20w\n\t\t\t\t\tHhcNMTQwNDE0MTMxMjU1WhcNMzQwNDA5MTMxMjU1WjBmMQswCQYDVQQGEwJVUzEL\n\t\t\t\t\tMAkGA1UECBMCTlkxDDAKBgNVBAcTA05ZQzEbMBkGA1UEChMSS25vdmVsIENvcnBv\n\t\t\t\t\tcmF0aW9uMR8wHQYDVQQDExZkZXYtc3NvLmtuZXdrbm92ZWwuY29tMIIBIjANBgkq\n\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnX01rHw3vO6lIPsCouVCUF7ypKNSk9Gu\n\t\t\t\t\tIXCKZ1P+bt4dtd0QE+8HyLkyk6e55Yx+sxsHuD0laHbzvuv35GdhT5Prgct2UMYN\n\t\t\t\t\tUpChSHticrmfOV854FzKDJEfmbeLpS23GhMeHo1x0KFsFOM1tPYGjmxkRDMN5Cvv\n\t\t\t\t\tz9mXmknF/0WEipOWBR4I9aUcmziiZZpqentVdEpYiodVJaOu0hSqOlXs1mDtB4tF\n\t\t\t\t\tKOSzlvDS8qjlA2fynvwe1qAqUd8khp5w5jvVkh4NTPFSl2fIwrQc4irI6NM6Kw7o\n\t\t\t\t\tizflkVuLV2aW2qb1IldI81g2qqOpeP1YYSGrFxDJ3XdEevoza4ozDwIDAQABo3sw\n\t\t\t\t\teTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBD\n\t\t\t\t\tZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUjcBQ9UtvvI+ytSMztbS5Z1hnz/cwHwYDVR0j\n\t\t\t\t\tBBgwFoAUjcBQ9UtvvI+ytSMztbS5Z1hnz/cwDQYJKoZIhvcNAQEFBQADggEBAF00\n\t\t\t\t\tMyzrFcM0daBiKqxG3dm7rw3noJF/wQkXNqtRWJvxnB3WpuWNJYn8g1s3m9HhNVNQ\n\t\t\t\t\t8lFfIVzxMHhtZbj2AJSxB+3CtLlxEI+Ek+V4fbIcoAsTfe61OMuNVAJbyvdjjxSC\n\t\t\t\t\tEwv9B71RSXuU9nZw/Zl0Z3bO0vLvbgtlEKlO/M2U749PxqLjvIPTGL0k+nScpC4y\n\t\t\t\t\tfuVAi8o5ufW2OccVaeMd5WupA7PhJHGGdAN4qszavFkTsE2JIheNdk4Zewob61iu\n\t\t\t\t\tXWQKqMUCvhHMPkCVBWqbAJzSOIE0gqqbsWDxoOhWv6FDj15iOpPxmzc2g1v5g9N5\n\t\t\t\t\tPCaBwus+SIk+uZ5o3uU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev-sso.knewknovel.com/saml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dev-sso.knewknovel.com/saml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev-sso.knewknovel.com/saml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dev-sso.knewknovel.com/saml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://carmenwiki.osu.edu/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ritter.18@osu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Travis Ritter"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "8help@osu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "webauth-admin@lists.service.ohio-state.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Web Authentication Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://carmenwiki.osu.edu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ohio State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.osu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Ohio State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://carmenwiki.osu.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://carmenwiki.it.ohio-state.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://carmenwiki.osu.edu/Shibboleth.sso/Clear",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://carmenwiki.it.ohio-state.edu/Shibboleth.sso/Clear",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "4"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://ocio.osu.edu/services/view/carmenwiki-wiki-services"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CarmenWiki"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Enterprise Wiki Service at the Ohio State University."
                  }
                ],
                "logo": [
                  {
                    "text": "https://carmenwiki.osu.edu/download/attachments/9666561/global.logo",
                    "lang": "en",
                    "height": "85",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "141"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://carmenwiki.osu.edu/x/jyLeAQ"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIJANI+yGM0M1N2MA0GCSqGSIb3DQEBBQUAMCcxJTAjBgNV\nBAMTHGx0Y2F3aWtpMDEuaXQub2hpby1zdGF0ZS5lZHUwHhcNMTAwNzA3MjI0MzA1\nWhcNMjAwNzA0MjI0MzA1WjAnMSUwIwYDVQQDExxsdGNhd2lraTAxLml0Lm9oaW8t\nc3RhdGUuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA5fsEv25M\nr9wfa48qfjn8m40yB/lwimJ8dSnYw2erd/tfB+sPESw42Is5Lv2B3pI3mj9a0PT0\nGf1VgUoQW0RCT6L4VOW50WsPFv/RKPfT/AIRl00dTCqb440PgotGbrK9ivZqlvkz\nlSGUKuFcg2gLj+CJlbMcwEneSwn0FE1xKEGpMDUk91lZH1XxmnIDDOQn1G5qul4q\nAbXITMpLi2MlsHAEXxnLrthFFas6zDrviTwHcqGXq9zJJkPHDcbu1qg6AUT7bRJr\nqszxxktSV6mFclkgLPpcVkigMR8RNVMQkWaaWSnfBkFy2iAe3xw3DNp7obtzgItY\ni9N8U6K5qorSkQIDAQABo0owSDAnBgNVHREEIDAeghxsdGNhd2lraTAxLml0Lm9o\naW8tc3RhdGUuZWR1MB0GA1UdDgQWBBR32XnCliG78DdyTtZhyIQSHChtyjANBgkq\nhkiG9w0BAQUFAAOCAQEAVEweCxPElHGmam4Iv2QeJsGE7m4de7axp3epAJb7uVbN\nZ2P1S/s4GZQhmGsUoGoxwqca3wyQ+C1ZkpQJdyFl5s1tFc26D+Z0KTDo174GzO9i\nI9SeQ4YSp3FNhZqxn4xH3DULzzHwoVSwFr5irLPAVtrqK8H/rzBREhqOse2VSJ/1\nPkI+p7lUiElIzMiObLGjumF2fDOPkXOSMNyC4c5oCCJtcrip/BaLo6bqdqn3DKP8\nonMw/lHZQolyVsupuhGsSX13WVJ0uyGvuA7hiHnGEkpDmskUd3TsriyQAt47RZzY\ntTupO/NdWvz8SvXU1qIOk9CTQ0D2b2OOftfUW+FuAQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://carmenwiki.osu.edu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://carmenwiki.osu.edu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://carmenwiki.it.ohio-state.edu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://carmenwiki.it.ohio-state.edu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://carmenwiki.osu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://carmenwiki.osu.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://carmenwiki.it.ohio-state.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://carmenwiki.it.ohio-state.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://carmenwiki.osu.edu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://carmenwiki.it.ohio-state.edu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CarmenWiki"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Enterprise Wiki Service at the Ohio State University."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cgticafe.fiocruz.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "infracgti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "infracgti@fiocruz.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cgticafe.fiocruz.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID7DCCAtQCAQAwDQYJKoZIhvcNAQEFBQAwgbsxKDAmBgNVBAoTH0ZJT0NSVVog\nLSBGVU5EQUNBTyBPU1dBTERPIENSVVoxDTALBgNVBAsTBENHVEkxIzAhBgkqhkiG\n9w0BCQEWFGluZnJhY2d0aUBmaW9jcnV6LmJyMRcwFQYDVQQHEw5SaW8gZGUgSmFu\nZWlybzEXMBUGA1UECBMOUmlvIGRlIGphbmVpcm8xCzAJBgNVBAYTAkJSMRwwGgYD\nVQQDExNjZ3RpY2FmZS5maW9jcnV6LmJyMB4XDTE1MDkyMTE2NTYwNloXDTE4MDky\nMDE2NTYwNlowgbsxKDAmBgNVBAoTH0ZJT0NSVVogLSBGVU5EQUNBTyBPU1dBTERP\nIENSVVoxDTALBgNVBAsTBENHVEkxIzAhBgkqhkiG9w0BCQEWFGluZnJhY2d0aUBm\naW9jcnV6LmJyMRcwFQYDVQQHEw5SaW8gZGUgSmFuZWlybzEXMBUGA1UECBMOUmlv\nIGRlIGphbmVpcm8xCzAJBgNVBAYTAkJSMRwwGgYDVQQDExNjZ3RpY2FmZS5maW9j\ncnV6LmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAyWG4cgj+Osnf\nkt3wuPV8OPuOK3ImAzHCL9yXvspZxASSmIZ+F6TOQ7r7YfDEHhEx9YgLGoSc5pQ8\n85hDKOSdwcej/1B9NDyBIl++bT0yD6p6JOVtC8z/D8/JqdH+uWgbyRpofRMhPsBM\n7AfBRZ6ar9M5qxJUx5NQU7j0qkKmBiI442qxhuIXscnU6zdokCLkbioUny7d0J/m\n9YmWvv0DGgLIUltMveJyqIuJtYIw6FFRbxwjqp0biDe0FxvCgq7h2PsZ7+r6N43A\neoNPJnByFGv45iu727WS3oKLTsCvTamyBKuX+1b2vH9nDqqRbM1SmKwoEi6vUaFt\nNpuWv33tPQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQAQ0jXA8TKDFUzsDX63gqbB\nT+noOyQ5rdk1ao95pWBdquaTfmq0kybYW155UA1CGzxXNf6hWu3PBQZKiy/2rkty\ne5ml0b0s1/V57JtvtB/E6NuqoitAXq8O1okiy7RS93Fo3dz8sDSoAOK2/slGJwBO\nPrqsMoYTjfhSVUa2wiXre89eMsIy0UV1ifEtEOLU5dPI3cgabJsQC+PAZS7J60mb\nGjIjFTwcQ4eHU3fB2d3tswTCZpcOxdEvrXCvXmca//R5ilUoHq45Ne3yShxE8ivm\nm6PLcFE3BHA2WBnbwZt8ylTcHvJxL0Fafywu71AusQcAJz1p7NScH6wuCxqdiuN+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fiocruz.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cgticafe.fiocruz.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cgticafe.fiocruz.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cgticafe.fiocruz.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cgticafe.fiocruz.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cgticafe.fiocruz.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cgticafe.fiocruz.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cgticafe.fiocruz.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cgticafe.fiocruz.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fiocruz.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://portal.fiocruz.br/pt-br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://portal.fiocruz.br/pt-br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "FIOCRUZ - FUNDACAO OSWALDO CRUZ"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "FIOCRUZ - FUNDACAO OSWALDO CRUZ"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FIOCRUZ - FUNDACAO OSWALDO CRUZ"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FIOCRUZ - FUNDACAO OSWALDO CRUZ"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID7DCCAtQCAQAwDQYJKoZIhvcNAQEFBQAwgbsxKDAmBgNVBAoTH0ZJT0NSVVog\nLSBGVU5EQUNBTyBPU1dBTERPIENSVVoxDTALBgNVBAsTBENHVEkxIzAhBgkqhkiG\n9w0BCQEWFGluZnJhY2d0aUBmaW9jcnV6LmJyMRcwFQYDVQQHEw5SaW8gZGUgSmFu\nZWlybzEXMBUGA1UECBMOUmlvIGRlIGphbmVpcm8xCzAJBgNVBAYTAkJSMRwwGgYD\nVQQDExNjZ3RpY2FmZS5maW9jcnV6LmJyMB4XDTE1MDkyMTE2NTYwNloXDTE4MDky\nMDE2NTYwNlowgbsxKDAmBgNVBAoTH0ZJT0NSVVogLSBGVU5EQUNBTyBPU1dBTERP\nIENSVVoxDTALBgNVBAsTBENHVEkxIzAhBgkqhkiG9w0BCQEWFGluZnJhY2d0aUBm\naW9jcnV6LmJyMRcwFQYDVQQHEw5SaW8gZGUgSmFuZWlybzEXMBUGA1UECBMOUmlv\nIGRlIGphbmVpcm8xCzAJBgNVBAYTAkJSMRwwGgYDVQQDExNjZ3RpY2FmZS5maW9j\ncnV6LmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAyWG4cgj+Osnf\nkt3wuPV8OPuOK3ImAzHCL9yXvspZxASSmIZ+F6TOQ7r7YfDEHhEx9YgLGoSc5pQ8\n85hDKOSdwcej/1B9NDyBIl++bT0yD6p6JOVtC8z/D8/JqdH+uWgbyRpofRMhPsBM\n7AfBRZ6ar9M5qxJUx5NQU7j0qkKmBiI442qxhuIXscnU6zdokCLkbioUny7d0J/m\n9YmWvv0DGgLIUltMveJyqIuJtYIw6FFRbxwjqp0biDe0FxvCgq7h2PsZ7+r6N43A\neoNPJnByFGv45iu727WS3oKLTsCvTamyBKuX+1b2vH9nDqqRbM1SmKwoEi6vUaFt\nNpuWv33tPQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQAQ0jXA8TKDFUzsDX63gqbB\nT+noOyQ5rdk1ao95pWBdquaTfmq0kybYW155UA1CGzxXNf6hWu3PBQZKiy/2rkty\ne5ml0b0s1/V57JtvtB/E6NuqoitAXq8O1okiy7RS93Fo3dz8sDSoAOK2/slGJwBO\nPrqsMoYTjfhSVUa2wiXre89eMsIy0UV1ifEtEOLU5dPI3cgabJsQC+PAZS7J60mb\nGjIjFTwcQ4eHU3fB2d3tswTCZpcOxdEvrXCvXmca//R5ilUoHq45Ne3yShxE8ivm\nm6PLcFE3BHA2WBnbwZt8ylTcHvJxL0Fafywu71AusQcAJz1p7NScH6wuCxqdiuN+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "FIOCRUZ - FUNDACAO OSWALDO CRUZ"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "FIOCRUZ - FUNDACAO OSWALDO CRUZ"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://portal.fiocruz.br/pt-br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://portal.fiocruz.br/pt-br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "FIOCRUZ - FUNDACAO OSWALDO CRUZ"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "FIOCRUZ - FUNDACAO OSWALDO CRUZ"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ayrcoll.ac.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ayrcoll.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/ayrcoll.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/ayrcoll.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ayrcoll.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ayrshire College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ayrshire.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://adfs3prod.aventus.nl/adfs/services/trust",
    {
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/7999608342368fe274d574d8ff34a63b",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ROC Aventus"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ROC Aventus"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/aventus3.png",
                    "height": "300",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "500"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ROC Aventus"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ROC Aventus"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs3prod.aventus.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-04-24T12:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      }
    }
  ],
  [
    "urn:mace:cru.fr:federation:unice.fr",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jean-Charles GODIEN"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Jean-Charles.Godien@unice.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Richard Manas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Richard.Manas@unice.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:cru.fr:federation:unice.fr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-08-07T17:06:18Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unice.fr/renater/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unice.fr/renater/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.unice.fr/renater/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unice.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unice.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Staff and students"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnels et \u00e9tudiants"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Nice Sophia Antipolis"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 Nice Sophia Antipolis"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGjCCAgICCQDEc1geh13qYjANBgkqhkiG9w0BAQUFADBPMQswCQYDVQQGEwJG\nUjEpMCcGA1UEChMgVW5pdmVyc2l0ZSBOaWNlIFNvcGhpYSBBbnRpcG9saXMxFTAT\nBgNVBAMTDGlkcC51bmljZS5mcjAeFw0xNTAzMzAxNDA2MzRaFw0yNTAzMzAxNDA2\nMzRaME8xCzAJBgNVBAYTAkZSMSkwJwYDVQQKEyBVbml2ZXJzaXRlIE5pY2UgU29w\naGlhIEFudGlwb2xpczEVMBMGA1UEAxMMaWRwLnVuaWNlLmZyMIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAwumrRwZ1MgiLeMdx/swZ6vKgjeaUlAH/SCuc\nV2wiInFt02DOUhJfpXeB2jPkh6UJKgKSOvp6Nf+vkmiHA9YyJMp84c0NR2NVOEDk\nyhMSp0grvoSz/zn9njWbOAS4mM85v1OyB7+ZdkQULzjS9U73JbA2ZZkYqGr0CPoD\n4Dkh8OLjhJaT0gflc9Mb2Hsd4+c9UQZ9IARQVOpGg0xwcThjBoawAZYytvAr1gi9\nQiZw2Oqsi3D2DQ3RqP5EN3pnBxq8J3Lg3xiziZclgWoLKxIz9mpZhJEg6bhdfGc6\n8tE5iW9cVv58baBY0v+j2reSrqjbzsIJhVkav6q210T9ZvWWBQIDAQABMA0GCSqG\nSIb3DQEBBQUAA4IBAQBHE870+VQEJsa1MLTQNOdbd0jbCAuF0Y95ZtHgczjhOKoE\nED9ZBuKmlhgYffU313dwmMw+1wd5oJxsPVRqoe6KTskhTEzL00ZcJz+fZTmsDHd3\nUYynPT8DUvSg2/8HPxsUo8jqRTHBDjJsrUwdDwAPmNi+ao2JVGnfqaiACM1NMvqs\nXjLrB1uWCc0DIq8UadXJrQCK34zYwpx+V13pch1/GfiNibgXipIdL5pLnjf1HXwQ\nqmTeKX7MGcrmSXwqoRkufJvN96w5RsZwq+c82x8w3DA9o7S9BfCj7RqFUywuaS+G\nocmAdFFE3FlU7n+j9x4StI4bTezYKVTQPa4Pcw18"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEkjCCA3qgAwIBAgIQfx/AsWyTjGxfLF7+a+MU3DANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMjAeFw0xNTAzMjYwMDAwMDBaFw0xODAzMjcyMzU5NTlaMDoxITAfBgNVBAsT\nGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEVMBMGA1UEAxMMaWRwLnVuaWNlLmZy\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxIQ1GJUzszvZgeA5nbEO\nf03rKTvkLmCKRZSVFDwsycZkpkJSY4t5RT6E8JqFVMgh6M1RuhATiridAK+KCklK\n4GsLrlRDwcQpzla5E9FPjvxclIIm1p6VtmBnOFT3mJT/OnSI9ODqSbkGlWoiCtO1\nclHBzY6Lukbf9h+mSkxcyWTqsswsAcA8qdChnH0gBUnWst5dmb4TLI+zV2qhlTVd\nncjICgvoFF73SFQc8eb6LQ5rhsMedldAxjkRjP/7EfRY0x1mD0UVmwKEXZmeYbzl\nLTgoIe9BDdRX1Admq6gIyoErXh6jK8qwZvVZlevGYR2dnj5nv1jJdkbkdVLV+u9e\nCQIDAQABo4IBaDCCAWQwHwYDVR0jBBgwFoAUW9CKHJoyW+C13ZZUG+GGKLD9tr0w\nHQYDVR0OBBYEFB/ELteTIN9PlhnJuKtHbij0AfYxMA4GA1UdDwEB/wQEAwIFoDAM\nBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNV\nHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAxMC+gLaAr\nhilodHRwOi8vY3JsLnVzZXJ0cnVzdC5jb20vVEVSRU5BU1NMQ0EyLmNybDBsBggr\nBgEFBQcBAQRgMF4wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudXNlcnRydXN0LmNv\nbS9URVJFTkFTU0xDQTIuY3J0MCUGCCsGAQUFBzABhhlodHRwOi8vb2NzcC51c2Vy\ndHJ1c3QuY29tMBcGA1UdEQQQMA6CDGlkcC51bmljZS5mcjANBgkqhkiG9w0BAQsF\nAAOCAQEAZBO8x0QGYb5cHxcNyoI7fdjNGAoZzttbomVT/q9clVtzW7EgEKtaKQNo\nGPCUb5pbOQQhGkOUz/oV75TI0gSHBUzFxPXbNgA4TGeqdwmLxMHJfRtAF5uaPh8w\npr68ZZphOAZjNmv04z+KGXk4m1t/Ui1YANJbCgAItqOSRTy+bRmN4KtMWlds/7MT\nY7hQVSNM+vGWd2dx0Ax7qlF9I00YAzKXSw94tvrL8XeXJ1W7nZ6K/DqSuWwpFE9L\nT41tULnrHJS9hPhwtG33O35uW3WpQLwsWJZDCXaQNf31PNsjaPhrV6qBsEz0/vwL\nXAU685+5ngtQMo1C+QYwfpEV9fZZVw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 Nice Sophia Antipolis"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unice.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 Nice Sophia Antipolis"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://crowd.it.helsinki.fi/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Niemi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:atk-autentikointi@helsinki.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Juha"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Niemi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:atk-autentikointi@helsinki.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Juha"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://crowd.it.helsinki.fi/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.csc.fi/english/institutions/haka/instructions/join/eduGAINRegistrationStatement/"
              }
            ],
            "registration_authority": "http://www.csc.fi/haka",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Helsingin yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Helsinki"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Helsingfors universitet"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.helsinki.fi/yliopisto/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.helsinki.fi/yliopisto/"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.helsinki.fi/yliopisto/"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Helsingin yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Helsinki"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Helsingfors universitet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://crowd.it.helsinki.fi/Shibboleth.sso/HAKALogin",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Helsingin yliopiston Crowd-kirjautumispalvelu"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Helsingfors universitets Crowd authentication service"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Helsinki Crowd authentication service"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://crowd.it.helsinki.fi/tietosuojaseloste.html"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://crowd.it.helsinki.fi/tietosuojaseloste.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Helsingin yliopiston Crowd"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Helsingfors universitets Crowd"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Helsinki Crowd"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEozCCA4ugAwIBAgIRAKhneRs8CMQxhTAehEkaF4MwDQYJKoZIhvcNAQELBQAw\nZDELMAkGA1UEBhMCTkwxFjAUBgNVBAgTDU5vb3JkLUhvbGxhbmQxEjAQBgNVBAcT\nCUFtc3RlcmRhbTEPMA0GA1UEChMGVEVSRU5BMRgwFgYDVQQDEw9URVJFTkEgU1NM\nIENBIDIwHhcNMTUwMTEzMDAwMDAwWhcNMTgwMTEyMjM1OTU5WjBCMSEwHwYDVQQL\nExhEb21haW4gQ29udHJvbCBWYWxpZGF0ZWQxHTAbBgNVBAMTFGNyb3dkLml0Lmhl\nbHNpbmtpLmZpMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtp7HsMe+\nlqyUoaD1+QQRCONqGPSwNkYrEkDN06dJtpy+9xDLJQiKSBmF0vB57MTnkjQ+fOJo\nbWd/lx2bdJIvna0y5l9X7AGUqesgfQO5joOpqUvK8Q8xwXDnFxhz3kohpV8epdpB\nwo2gB0Nb8/k8shP3JQe87w4S4tDR4hMDk6tePuts60NhiU6f7ciJL5bPaw8YXreu\nMARuTai58KR58+8ud2WGaI3itjNWPWe7XRA5Jei66UWibY2tIvxWmw0tbod53bPR\nzPoA4WMVPOb4m31/ahOB64Dcq5x/A15UEP9K1tued8z4bEZHBSgAZ5QGrP+AxFQO\nRLClBDsC9LAMswIDAQABo4IBcDCCAWwwHwYDVR0jBBgwFoAUW9CKHJoyW+C13ZZU\nG+GGKLD9tr0wHQYDVR0OBBYEFJAQIP+LACil6S/u1HMtsCM/66+7MA4GA1UdDwEB\n/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEF\nBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8E\nMzAxMC+gLaArhilodHRwOi8vY3JsLnVzZXJ0cnVzdC5jb20vVEVSRU5BU1NMQ0Ey\nLmNybDBsBggrBgEFBQcBAQRgMF4wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudXNl\ncnRydXN0LmNvbS9URVJFTkFTU0xDQTIuY3J0MCUGCCsGAQUFBzABhhlodHRwOi8v\nb2NzcC51c2VydHJ1c3QuY29tMB8GA1UdEQQYMBaCFGNyb3dkLml0LmhlbHNpbmtp\nLmZpMA0GCSqGSIb3DQEBCwUAA4IBAQCWvzoK8rdJEHu+001banb0d8RdoJtbkGMe\n/tkr52yuCwovVkzgUv5eeHC9FYQ9xOcyg5ba+lx/AOQYODMHAuKH8GsN99cg6kZq\ngTc7OH07yNuRweMuMtBvOfjZpzLSlqRHWKMpwVDbPe07iMdeiA2WYD5OPO+AA4Qz\n0e+ZNIPZfgD/K75NcQOVkuNP82Wo6EC6agThXtfP3CkCV/YPRcFRzFvysSzGUl15\naaMR5bVucUkVAQdHrcs46UL4s8gccFZvaWnW8kW9HKU6+IptlIPVg0NK4uoRdf3/\nF4VVG/swiKEnK9hhdQZiawFzSCyfU5r719MkFZF1fbwBWTMsnRFf"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://crowd.it.helsinki.fi/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Helsingin yliopiston Crowd-kirjautumispalvelu"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "University of Helsinki Crowd authentication service"
                },
                {
                  "lang": "sv",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Helsingfors universitets Crowd authentication service"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Helsingin yliopiston Crowd"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "University of Helsinki Crowd"
                },
                {
                  "lang": "sv",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Helsingfors universitets Crowd"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://kib-shib.hosted.exlibrisgroup.com/shib",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://kib-shib.hosted.exlibrisgroup.com/shib",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://kib-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://kib-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://ki.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://ki.se/en"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Primo -Karolinska Institutet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Primo - Karolinska Institute"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Tj\u00e4nstef\u00f6retag f\u00f6r Primo@Primo@Karolinska Institutet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Service Provider for Primo@Karolinska Institute"
                  }
                ],
                "logo": [
                  {
                    "text": "https://kiidp.ki.se/images/ki_logo_292x146.png",
                    "height": "146",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "292"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.exlibrisgroup.com/category/PrimoCookiePolicy"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.exlibrisgroup.com/category/PrimoCookiePolicy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "aio0016"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAOXm3o6EW0rUMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\nBAMTB2FpbzAwMTYwHhcNMTUwMTI3MjMxNzU0WhcNMjUwMTI0MjMxNzU0WjASMRAw\nDgYDVQQDEwdhaW8wMDE2MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n65y6cc8ubMBJa7aybnFzJ10pQ4UJ3dZAH1J2zUYiAf+Axp/kymRNzPTVg+dGVusf\nj6oswRgFAaO/mFCEwgGPQSCVXYdTciZTzqGTy7+/GvBwK8jttS6l8ybXjmgStb1p\nH6CL8MkG2LX21B8pf3te4KMRICJPk3OVHnEaXY0Jt9BYD9cnvkJW8BTGqmTlplA+\nshr+PpHY25JFeIzfCHDMT5/m/HBG3jGHQQZ8q1+7Lpgb9AssI1e8EtuB5e8OE8Zc\nNGJpdV8pwCzEx8jA7Wlihd1fn6jo0kZq/Be9trZZOZoVUnbMYtV03QN67KDDeASP\n4zH4IJBHguRDWC83EdrkcwIDAQABozUwMzASBgNVHREECzAJggdhaW8wMDE2MB0G\nA1UdDgQWBBS4hic1cEvjyX+ooZI/YdwlKpY+UTANBgkqhkiG9w0BAQUFAAOCAQEA\njYKQlzfHqVqVBTdQ21kWYu0DYvf5C6MBsQD85/lKRyfHCMtRu9491IdsSGd88KQp\nCPkz6Pgmx59KFID+tyWhJMWHgcKqjFrzvL8tW2we5DTarPxJ7GQSyK1Sdzm62rAi\nO/9y6+m/Pu+1DAwa8uvzDoFbU6iTKZNZwi3bH8h8pda1H3YNRWhAKkFTMxQCQkQC\njx0Yna6SnHAAnfNWNtioLzCOOWn1WQXeOhWvtl9uRFpH0XfCwN672QP8eXGNrEFb\nAge0Hip95wHHpGG21U5wSYyQCBTNVq7w2aVzGh7A2COc3vG5hipfkCifvsstCEJC\n/9OZvnhlsRzInh73TSEFvQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=aio0016"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://kib-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://kib-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://kib-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://tcs-escience.sunet.se/simplesamlphp/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "LIS Unix"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lis-unix@uvt.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UvT"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://tcs-escience.sunet.se/simplesamlphp/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish University Network (SUNET)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sunet.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SUNET"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://tcs-escience.sunet.se/simplesamlphp/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://tcs-escience.sunet.se/simplesamlphp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://tcs-escience.sunet.se/simplesamlphp/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://tcs-escience.sunet.se/simplesamlphp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://tcs-escience.sunet.se/simplesamlphp/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sid.kent.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@kent.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Slowe"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:M.Slowe@kent.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matthew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sid.kent.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUFTvaqDYnEQRtqGKyg61iRHS6DSMwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHDEaMBgGA1UEAwwRam9yZGFuLmtlbnQuYWMudWswHhcNMTYwMTA0MTAxMTEw\n\t\t\t\t\t\tWhcNMzYwMTA0MTAxMTEwWjAcMRowGAYDVQQDDBFqb3JkYW4ua2VudC5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAPTxfRvmsz9ZUZ/XJ/YEvjWj\n\t\t\t\t\t\tB5eBdqEekSIeQxPX9Sag5dviyteNEWYn+VQT0CEfWt3gnRrZicaMI4z11kT1lH8E\n\t\t\t\t\t\tVis1tmOhchvQqeA3JMH8ASUnv5PpvjQ+D+xrsVmNf+K6ZuaHw9iV5509ndazEC0q\n\t\t\t\t\t\tp/MceBtvE359Gsx3LN/VQjP/i5FflbzjPFvaTZfPq8LcNLYCZRZOs8lIfKd2cKFk\n\t\t\t\t\t\t4kczBdfRdUtirK6zXYPxdL1aGl0rZkAy6f6rNTFA9/nPbHcMkRJYJAkQaoBnI7mE\n\t\t\t\t\t\trUsFsN8zLSQtmtMocmYFN3y16lQtgStOjZFqgg+ngHdqBuWBaG/r8AteHAgEyasC\n\t\t\t\t\t\tAwEAAaNpMGcwHQYDVR0OBBYEFFuFstjVrT6bJ3asam2XRxCk1BYCMEYGA1UdEQQ/\n\t\t\t\t\t\tMD2CEWpvcmRhbi5rZW50LmFjLnVrhihodHRwczovL2pvcmRhbi5rZW50LmFjLnVr\n\t\t\t\t\t\tL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBBQUAA4IBAQC1EXf13aibZ6FUdPQa\n\t\t\t\t\t\tGC/dvmHAVOWHSBB3jGfXCh5r3rJxMzy0pEk3/rmSFyFal/nYR1GxlK6MOB3PxpKZ\n\t\t\t\t\t\tSe8Ne1/79MFnXamPtZumumIJ90Duo8IpJnGpznd1xMARZuh5rmy611lTJVsbdEeC\n\t\t\t\t\t\tSB4oepAPrk1DYqAUodRdT8ZdJKK1KavYVkVDzlEvV6utEx3MWJUMx8Q82s2uiV/5\n\t\t\t\t\t\tdQPzWrErw8Gs+/eXIP4upOzSNTJPMb3DGqjol90Zva5b4gDtBaKBEfT+FqJmIeup\n\t\t\t\t\t\tj6vg6TghDxdXZTqf631sCMtZHCiuSE1ErlrleXwIi6GCCSoDjCEWG36E8Yi/291n\n\t\t\t\t\t\tLkgY"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kent.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://jordan.kent.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jordan.kent.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://jordan.kent.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jordan.kent.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://jordan.kent.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://jordan.kent.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://jordan.kent.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jordan.kent.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kent.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://jordan.kent.ac.uk/images/logo.png",
                    "height": "177",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "236"
                  },
                  {
                    "text": "https://jordan.kent.ac.uk/images/icon-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Kent"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "kent.ac.uk"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.29861,1.07059"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.39781,0.54197"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.19263,0.27140"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:48.841877,2.331676"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:50.82142,4.39169"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "129.12.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.195.86.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.195.88.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.195.89.0/26"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.195.89.128/25"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUFTvaqDYnEQRtqGKyg61iRHS6DSMwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHDEaMBgGA1UEAwwRam9yZGFuLmtlbnQuYWMudWswHhcNMTYwMTA0MTAxMTEw\n\t\t\t\t\t\tWhcNMzYwMTA0MTAxMTEwWjAcMRowGAYDVQQDDBFqb3JkYW4ua2VudC5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAPTxfRvmsz9ZUZ/XJ/YEvjWj\n\t\t\t\t\t\tB5eBdqEekSIeQxPX9Sag5dviyteNEWYn+VQT0CEfWt3gnRrZicaMI4z11kT1lH8E\n\t\t\t\t\t\tVis1tmOhchvQqeA3JMH8ASUnv5PpvjQ+D+xrsVmNf+K6ZuaHw9iV5509ndazEC0q\n\t\t\t\t\t\tp/MceBtvE359Gsx3LN/VQjP/i5FflbzjPFvaTZfPq8LcNLYCZRZOs8lIfKd2cKFk\n\t\t\t\t\t\t4kczBdfRdUtirK6zXYPxdL1aGl0rZkAy6f6rNTFA9/nPbHcMkRJYJAkQaoBnI7mE\n\t\t\t\t\t\trUsFsN8zLSQtmtMocmYFN3y16lQtgStOjZFqgg+ngHdqBuWBaG/r8AteHAgEyasC\n\t\t\t\t\t\tAwEAAaNpMGcwHQYDVR0OBBYEFFuFstjVrT6bJ3asam2XRxCk1BYCMEYGA1UdEQQ/\n\t\t\t\t\t\tMD2CEWpvcmRhbi5rZW50LmFjLnVrhihodHRwczovL2pvcmRhbi5rZW50LmFjLnVr\n\t\t\t\t\t\tL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBBQUAA4IBAQC1EXf13aibZ6FUdPQa\n\t\t\t\t\t\tGC/dvmHAVOWHSBB3jGfXCh5r3rJxMzy0pEk3/rmSFyFal/nYR1GxlK6MOB3PxpKZ\n\t\t\t\t\t\tSe8Ne1/79MFnXamPtZumumIJ90Duo8IpJnGpznd1xMARZuh5rmy611lTJVsbdEeC\n\t\t\t\t\t\tSB4oepAPrk1DYqAUodRdT8ZdJKK1KavYVkVDzlEvV6utEx3MWJUMx8Q82s2uiV/5\n\t\t\t\t\t\tdQPzWrErw8Gs+/eXIP4upOzSNTJPMb3DGqjol90Zva5b4gDtBaKBEfT+FqJmIeup\n\t\t\t\t\t\tj6vg6TghDxdXZTqf631sCMtZHCiuSE1ErlrleXwIi6GCCSoDjCEWG36E8Yi/291n\n\t\t\t\t\t\tLkgY"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Kent"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kent.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Kent"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://gidp.geant.net",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:edugain-ot@geant.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "eduGAIN OT"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:edugain-ot@geant.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "eduGAIN OT"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://gidp.geant.net",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-05-14T11:50:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://gidp.geant.net/simplesamlphp/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://gidp.geant.net/simplesamlphp/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gidp.geant.net"
              },
              {
                "logo": [
                  {
                    "text": "https://www.edugain.org/GIdP.png",
                    "height": "69",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "199"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "G\u00c9ANT Guest Identity Provider"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEkzCCA3ugAwIBAgIRAMu+xHPPachtpqZqP5LsTqswDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzEyMTMwMDAwMDBaFw0xNjEyMTIyMzU5NTlaMDwxITAfBgNV\n\t\t\t\t\t\tBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEXMBUGA1UEAxMOZ2lkcC5nZWFu\n\t\t\t\t\t\tdC5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDGyGX8egmFqg1S\n\t\t\t\t\t\tBpnwdMh7Gwco3avst57R/6TTgnGeajqjk5q7E6kzT33UHXG37kXJehuA2NBIhwoo\n\t\t\t\t\t\tS8vBpMfsdhgj1ta98d9VdpjM84vJI8qj5zdOV1t+rQ1RejXxla5Fp0Rpj7BoKFye\n\t\t\t\t\t\tWQ/vKrdk/G9rhpZS8DiIKqmNtkakxigm9aGse5r3zaYE6rb2Pb7VXBGkEVq96s5v\n\t\t\t\t\t\tZ/iN6eGWfGy28XopRKboHpjVdR/AkyMARfFd1qLtGh3OddXykKgkwbKfYY3sKUYK\n\t\t\t\t\t\trqoeq1J6vF3KYYc1WlHuldnW0X+YjskiwX40USuZklxbv2mXublmhk1H5IgN7F2D\n\t\t\t\t\t\tX8jJ124bAgMBAAGjggGUMIIBkDAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3V0fq\n\t\t\t\t\t\tkOO57TAdBgNVHQ4EFgQUCsQex91m+Wk7E+C4/38Sf3T80yAwDgYDVR0PAQH/BAQD\n\t\t\t\t\t\tAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMC\n\t\t\t\t\t\tMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1UdHwQzMDEw\n\t\t\t\t\t\tL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3Js\n\t\t\t\t\t\tMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3MudGVy\n\t\t\t\t\t\tZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9vY3Nw\n\t\t\t\t\t\tLnRjcy50ZXJlbmEub3JnMEIGA1UdEQQ7MDmCDmdpZHAuZ2VhbnQubmV0ghNwcm9k\n\t\t\t\t\t\tLWdpZHAuZ2VhbnQubmV0ghJ1YXQtZ2lkcC5nZWFudC5uZXQwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQADggEBAB3iJ9REvIWq6OkRaiGMBN5wrH8RY0QulseOufbf7Cclx58+Y5hqf+bZ\n\t\t\t\t\t\t1gNQQfGQB8wFw2HaHg/X7RyHA6GRPgjz2w6hLQqI5aWdoKpF26jSbfnQ0Ia+Ko6J\n\t\t\t\t\t\t9JTawaCJzEqDOYO0vfdK19sOtouZoMpFyj5IGKUhJQfnXl4IxRAKbxOsdmZnlKfC\n\t\t\t\t\t\tMHfKZ3Hkd137e5Vl6PPCD1SgKKyxklGL7kvUJLaI5H+fmyUZhYdLkabuViam16ok\n\t\t\t\t\t\tulsPPNORMXuSAaPbctgKJYdjK3D608c8SiZpm3hV/XBMYgDBb5NBTq3UZBbUsYRm\n\t\t\t\t\t\tdDPF827oNvkbCcANbb1YmRBmFHWFe+E="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEkzCCA3ugAwIBAgIRAMu+xHPPachtpqZqP5LsTqswDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzEyMTMwMDAwMDBaFw0xNjEyMTIyMzU5NTlaMDwxITAfBgNV\n\t\t\t\t\t\tBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEXMBUGA1UEAxMOZ2lkcC5nZWFu\n\t\t\t\t\t\tdC5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDGyGX8egmFqg1S\n\t\t\t\t\t\tBpnwdMh7Gwco3avst57R/6TTgnGeajqjk5q7E6kzT33UHXG37kXJehuA2NBIhwoo\n\t\t\t\t\t\tS8vBpMfsdhgj1ta98d9VdpjM84vJI8qj5zdOV1t+rQ1RejXxla5Fp0Rpj7BoKFye\n\t\t\t\t\t\tWQ/vKrdk/G9rhpZS8DiIKqmNtkakxigm9aGse5r3zaYE6rb2Pb7VXBGkEVq96s5v\n\t\t\t\t\t\tZ/iN6eGWfGy28XopRKboHpjVdR/AkyMARfFd1qLtGh3OddXykKgkwbKfYY3sKUYK\n\t\t\t\t\t\trqoeq1J6vF3KYYc1WlHuldnW0X+YjskiwX40USuZklxbv2mXublmhk1H5IgN7F2D\n\t\t\t\t\t\tX8jJ124bAgMBAAGjggGUMIIBkDAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3V0fq\n\t\t\t\t\t\tkOO57TAdBgNVHQ4EFgQUCsQex91m+Wk7E+C4/38Sf3T80yAwDgYDVR0PAQH/BAQD\n\t\t\t\t\t\tAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMC\n\t\t\t\t\t\tMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1UdHwQzMDEw\n\t\t\t\t\t\tL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3Js\n\t\t\t\t\t\tMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3MudGVy\n\t\t\t\t\t\tZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9vY3Nw\n\t\t\t\t\t\tLnRjcy50ZXJlbmEub3JnMEIGA1UdEQQ7MDmCDmdpZHAuZ2VhbnQubmV0ghNwcm9k\n\t\t\t\t\t\tLWdpZHAuZ2VhbnQubmV0ghJ1YXQtZ2lkcC5nZWFudC5uZXQwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQADggEBAB3iJ9REvIWq6OkRaiGMBN5wrH8RY0QulseOufbf7Cclx58+Y5hqf+bZ\n\t\t\t\t\t\t1gNQQfGQB8wFw2HaHg/X7RyHA6GRPgjz2w6hLQqI5aWdoKpF26jSbfnQ0Ia+Ko6J\n\t\t\t\t\t\t9JTawaCJzEqDOYO0vfdK19sOtouZoMpFyj5IGKUhJQfnXl4IxRAKbxOsdmZnlKfC\n\t\t\t\t\t\tMHfKZ3Hkd137e5Vl6PPCD1SgKKyxklGL7kvUJLaI5H+fmyUZhYdLkabuViam16ok\n\t\t\t\t\t\tulsPPNORMXuSAaPbctgKJYdjK3D608c8SiZpm3hV/XBMYgDBb5NBTq3UZBbUsYRm\n\t\t\t\t\t\tdDPF827oNvkbCcANbb1YmRBmFHWFe+E="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "G\u00c9ANT Guest Identity Provider"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.geant.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "G\u00c9ANT Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://vph3.crous-caen.fr",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "service.informatique@crous-caen.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://vph3.crous-caen.fr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2016-03-29T11:48:45Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/metier"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/local"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS de Caen"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.crous-caen.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS de Caen"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://vph3.crous-caen.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Plateforme Heberg3 Crous Caen Normandie"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Plateforme Heberg3 Crous Caen Normandie"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "http://vph3.crous-caen.fr"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Plateforme Heberg3 du CROUS de Caen"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEAzCCAuugAwIBAgIJAJVg+Nww7wK7MA0GCSqGSIb3DQEBBQUAMIGXMQswCQYD\nVQQGEwJGUjEPMA0GA1UECAwGRlJBTkNFMQ0wCwYDVQQHDARDQUVOMRYwFAYDVQQKDA1Dcm91cyBkZSBDYWVuMQ4wDAYDVQQLDAVjaXRldTENMAsGA1UEAwwEdnBoMzEx\nMC8GCSqGSIb3DQEJARYic2VydmljZS1pbmZvcm1hdGlxdWVAY3JvdXMtY2Flbi5m\ncjAeFw0xNjAyMTIxMDU2MDRaFw00NzA4MDcxMDU2MDRaMIGXMQswCQYDVQQGEwJG\nUjEPMA0GA1UECAwGRlJBTkNFMQ0wCwYDVQQHDARDQUVOMRYwFAYDVQQKDA1Dcm91cyBkZSBDYWVuMQ4wDAYDVQQLDAVjaXRldTENMAsGA1UEAwwEdnBoMzExMC8GCSqG\nSIb3DQEJARYic2VydmljZS1pbmZvcm1hdGlxdWVAY3JvdXMtY2Flbi5mcjCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKyAl56+4cPeRjI06AAtU2jc46Tb\ntqBW/oFNHyEvLJQ6tPgZR99aLZ/nuiMCgxRCm6TZ1ykM8JUM3hoUJ1dJK7z3F3sI\nvYQAksTciF95/n7bnpV0QXS1LkZGjlTRv+NFPk7W+2v7YISBPHG1cm3Bf0QvzuN1\nRvtFnvXnB8nqmwNmxJ57ZrkNqeNfcrHj5Ssk2rVwxfBagrXnrUccsgIz1Y9/6y9C\ngW7/3aqzqC5E1fuHGWscSTeKf/6bW2CeoNaBuVQy6ChyK+YJvkbUzyfgBUy1J6Eu\npspCi/i9qmzbFWQt1hMLxLDrQx7spp1whHXuFk/TdTLBNpLcIA1bb9u6d0sCAwEA\nAaNQME4wHQYDVR0OBBYEFPyXyj0/As+lmmevMSEmvTk6zI0SMB8GA1UdIwQYMBaA\nFPyXyj0/As+lmmevMSEmvTk6zI0SMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEF\nBQADggEBAAxO2xd1D+mV476MEqanj3Hz/BEbRheLbsHt/lKOuyVnus5PuDkr7c7i\n2QzybkRf++jaQZF32wj7RjB75JTFevlUeLdbJhmQ+P3VNDeF7cvSzM0+TLHYITA2\n/8D/J5D8DoWROJX8uVXu9Vnb7soJHcUCVIBVAC8gOlwynWgw5tDHbWxm6/brRvBu\n9MtTOuvgE3QXe9pKiD54Y9UGsqkUL6lGsNHv8zsYTWu6C658oamUKrfH+TI5eVXb\nNB/eC8fAfv0wEgjYXgONiPWyoWQAcIbWSGgBHAlO+3L67i+8/nYhbJB2D1laSJoE\nfkymJDb8szoEXufaaDkRmm7tqOfAtCU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEAzCCAuugAwIBAgIJAJVg+Nww7wK7MA0GCSqGSIb3DQEBBQUAMIGXMQswCQYD\nVQQGEwJGUjEPMA0GA1UECAwGRlJBTkNFMQ0wCwYDVQQHDARDQUVOMRYwFAYDVQQKDA1Dcm91cyBkZSBDYWVuMQ4wDAYDVQQLDAVjaXRldTENMAsGA1UEAwwEdnBoMzEx\nMC8GCSqGSIb3DQEJARYic2VydmljZS1pbmZvcm1hdGlxdWVAY3JvdXMtY2Flbi5m\ncjAeFw0xNjAyMTIxMDU2MDRaFw00NzA4MDcxMDU2MDRaMIGXMQswCQYDVQQGEwJG\nUjEPMA0GA1UECAwGRlJBTkNFMQ0wCwYDVQQHDARDQUVOMRYwFAYDVQQKDA1Dcm91cyBkZSBDYWVuMQ4wDAYDVQQLDAVjaXRldTENMAsGA1UEAwwEdnBoMzExMC8GCSqG\nSIb3DQEJARYic2VydmljZS1pbmZvcm1hdGlxdWVAY3JvdXMtY2Flbi5mcjCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKyAl56+4cPeRjI06AAtU2jc46Tb\ntqBW/oFNHyEvLJQ6tPgZR99aLZ/nuiMCgxRCm6TZ1ykM8JUM3hoUJ1dJK7z3F3sI\nvYQAksTciF95/n7bnpV0QXS1LkZGjlTRv+NFPk7W+2v7YISBPHG1cm3Bf0QvzuN1\nRvtFnvXnB8nqmwNmxJ57ZrkNqeNfcrHj5Ssk2rVwxfBagrXnrUccsgIz1Y9/6y9C\ngW7/3aqzqC5E1fuHGWscSTeKf/6bW2CeoNaBuVQy6ChyK+YJvkbUzyfgBUy1J6Eu\npspCi/i9qmzbFWQt1hMLxLDrQx7spp1whHXuFk/TdTLBNpLcIA1bb9u6d0sCAwEA\nAaNQME4wHQYDVR0OBBYEFPyXyj0/As+lmmevMSEmvTk6zI0SMB8GA1UdIwQYMBaA\nFPyXyj0/As+lmmevMSEmvTk6zI0SMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEF\nBQADggEBAAxO2xd1D+mV476MEqanj3Hz/BEbRheLbsHt/lKOuyVnus5PuDkr7c7i\n2QzybkRf++jaQZF32wj7RjB75JTFevlUeLdbJhmQ+P3VNDeF7cvSzM0+TLHYITA2\n/8D/J5D8DoWROJX8uVXu9Vnb7soJHcUCVIBVAC8gOlwynWgw5tDHbWxm6/brRvBu\n9MtTOuvgE3QXe9pKiD54Y9UGsqkUL6lGsNHv8zsYTWu6C658oamUKrfH+TI5eVXb\nNB/eC8fAfv0wEgjYXgONiPWyoWQAcIbWSGgBHAlO+3L67i+8/nYhbJB2D1laSJoE\nfkymJDb8szoEXufaaDkRmm7tqOfAtCU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "http://vph3.crous-caen.fr/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://vph3.crous-caen.fr/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Plateforme Heberg3 du CROUS de Caen"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "http://vph3.crous-caen.fr"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Plateforme Heberg3 Crous Caen Normandie"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Plateforme Heberg3 Crous Caen Normandie"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.inha.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "admin@inha.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.inha.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-07-04T12:21:05Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.inha.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.inha.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.inha.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "inha.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.inha.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INHA - Institut National de l'Histoire de l'Art"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INHA - Institut National de l'Histoire de l'Art"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAO4pV7sAz3uXoZSchrwj2d0PI981MA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2lkcC5pbmhhLmZyMB4XDTEzMDUyNzEzMjk0OVoXDTMz\nMDUyNzEzMjk0OVowFjEUMBIGA1UEAxMLaWRwLmluaGEuZnIwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDa2e5fujqS/ViLxvdM+Enmgf5YlLTbv42SVoZ/\neRbfyjEN50ykyYGrf3TD2a/qzFjOtTWnJFIEkf6jAQj79+axkYST5DxcE6G9q51k\nXmBUbxAOo3qP9an19B1sPuDz9gGZE33Iwu2qcOw8Z0dH69DWF4wNdu1mHZFeXS66\nWyJeww00xeARXo+flW8RvSTLCoU+TcFjYRP0OyGs+5YwMFw+wHQOJuR5hQakp9Lm\nM56083ADhpEXeQvyZUOxyd1QFhVFlUX6e6l6ww7svLStHCB1r5AVZff2qMIHe7v8\nkmfOYWbNgfajUWML3uI0gV84Ye5eHvhAgH/K75UYiL5A759rAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2lkcC5pbmhhLmZyhiJodHRwczovL2lkcC5pbmhhLmZyL2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBT6ICU4qeViyJcpEbrb0Zafyr/q3TANBgkqhkiG\n9w0BAQUFAAOCAQEADTAcGw7sH3vRJyCfv7kdWEzefxYx9nQPmeAY1z7/nL0qV865\nizTHDW7x9CMcQBnbapyuNB+uQbmJzovNW/eLjxNzFoqy4DVCYf2oFq4DX3RpPZj8\na0Qsmll/OC6LZ1OnsSTg2F38fN+WwhHP9AEPdktsIxt1D0v7qr3gPzipdj1Bz3Z7\nmd+a7DpGG/GPiczhrHZbrlwfMsbWTvfM6q4NqEHUWohV5TdJz3SVXnF7VWYjkgy2\ndk/zNZ/MGrjW4UnPGRTom36a+nElGRuRkIoyiOGzXuPyYZv6Phauwd3T5TmT1xi2\nBOkRf1b1DqBCezZIc9+vQAydDa2NLP0u415mxA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INHA - Institut National de l'Histoire de l'Art"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.inha.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INHA - Institut National de l'Histoire de l'Art"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp-test.shibboleth.ox.ac.uk/shibboleth-idp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:team@sysdev.oucs.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Services IAM Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:team@sysdev.oucs.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Services IAM Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-test.shibboleth.ox.ac.uk/shibboleth-idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-01-26T13:38:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWzCCAkOgAwIBAgIJAJndjhMuiIt3MA0GCSqGSIb3DQEBBQUAMCcxJTAjBgNV\n\t\t\t\t\t\tBAMTHGlkcC10ZXN0LnNoaWJib2xldGgub3guYWMudWswHhcNMTMxMjEzMTIwNTM3\n\t\t\t\t\t\tWhcNMzMxMjA4MTIwNTM3WjAnMSUwIwYDVQQDExxpZHAtdGVzdC5zaGliYm9sZXRo\n\t\t\t\t\t\tLm94LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0+4POi97\n\t\t\t\t\t\tyt16S/kjeolw+uj6SEdMFqfgQhgwd/AC05Fp9MQ8pPNIQR5DhIRPFi6L4H0ea/Uk\n\t\t\t\t\t\tfrc0twJtfrqEx7tp0eCe0wB6LecKxx6+DnYtmfyz/tCjvvvFmfbrJ14ubrMHmF1u\n\t\t\t\t\t\tRfeWSQBtg36lcpPV9QIQM1FAwab9CLREmxsZ72zZSuZCeNRmaCrdQd43NgfHzFYb\n\t\t\t\t\t\txnvKP8D806OEEniSBFcPpwzKPp2ctho+NNmsJT/8GyVTbrKzSpvZjf5zgsPK+O0R\n\t\t\t\t\t\tkH7qZ8cExZkSDktyRyhCNi95FXbnPrANI6oSVs8+ouhe9J/6bnO04FyFecA893hJ\n\t\t\t\t\t\tpxNXNrmpXhZgFQIDAQABo4GJMIGGMB0GA1UdDgQWBBQMsSajqoz91UxUUJ52fzjF\n\t\t\t\t\t\tn5Gy/TBXBgNVHSMEUDBOgBQMsSajqoz91UxUUJ52fzjFn5Gy/aErpCkwJzElMCMG\n\t\t\t\t\t\tA1UEAxMcaWRwLXRlc3Quc2hpYmJvbGV0aC5veC5hYy51a4IJAJndjhMuiIt3MAwG\n\t\t\t\t\t\tA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAFjpOucHm+eFuvP/AhCEd4ei\n\t\t\t\t\t\t3VUoKeVNUdtX1qpbv+ZH/ftkJaeRsRan4DAx4MWcEYED/+2DfYa+IWrNLVqp/ikl\n\t\t\t\t\t\tomdSgjL+KHjIUh+YZR3M/Citl60RLQp8x1leC1jInfafS8S/MJLAwCRtKlgcVHeL\n\t\t\t\t\t\ts1Tsvt1k++uaB4uKV/lWE8PS0H3hFnzE4i1S94HNWhC3S+2XB7AE6MXUCHQTknep\n\t\t\t\t\t\tBxEOB8wOhHyZdUMLGDMf1Vh8FsLeBbEyTSufmCMElvvhyypcf6OeRkoorvg6DO5z\n\t\t\t\t\t\tmLIz9BqxkSzMZ08i2sFYDzsN1brrua9J38vP2UXhUBER7f4jaituaTx0ZA1vYJs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ox.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-test.shibboleth.ox.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-test.shibboleth.ox.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-test.shibboleth.ox.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-test.shibboleth.ox.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-test.shibboleth.ox.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-test.shibboleth.ox.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-test.shibboleth.ox.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-test.shibboleth.ox.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ox.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWzCCAkOgAwIBAgIJAJndjhMuiIt3MA0GCSqGSIb3DQEBBQUAMCcxJTAjBgNV\n\t\t\t\t\t\tBAMTHGlkcC10ZXN0LnNoaWJib2xldGgub3guYWMudWswHhcNMTMxMjEzMTIwNTM3\n\t\t\t\t\t\tWhcNMzMxMjA4MTIwNTM3WjAnMSUwIwYDVQQDExxpZHAtdGVzdC5zaGliYm9sZXRo\n\t\t\t\t\t\tLm94LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0+4POi97\n\t\t\t\t\t\tyt16S/kjeolw+uj6SEdMFqfgQhgwd/AC05Fp9MQ8pPNIQR5DhIRPFi6L4H0ea/Uk\n\t\t\t\t\t\tfrc0twJtfrqEx7tp0eCe0wB6LecKxx6+DnYtmfyz/tCjvvvFmfbrJ14ubrMHmF1u\n\t\t\t\t\t\tRfeWSQBtg36lcpPV9QIQM1FAwab9CLREmxsZ72zZSuZCeNRmaCrdQd43NgfHzFYb\n\t\t\t\t\t\txnvKP8D806OEEniSBFcPpwzKPp2ctho+NNmsJT/8GyVTbrKzSpvZjf5zgsPK+O0R\n\t\t\t\t\t\tkH7qZ8cExZkSDktyRyhCNi95FXbnPrANI6oSVs8+ouhe9J/6bnO04FyFecA893hJ\n\t\t\t\t\t\tpxNXNrmpXhZgFQIDAQABo4GJMIGGMB0GA1UdDgQWBBQMsSajqoz91UxUUJ52fzjF\n\t\t\t\t\t\tn5Gy/TBXBgNVHSMEUDBOgBQMsSajqoz91UxUUJ52fzjFn5Gy/aErpCkwJzElMCMG\n\t\t\t\t\t\tA1UEAxMcaWRwLXRlc3Quc2hpYmJvbGV0aC5veC5hYy51a4IJAJndjhMuiIt3MAwG\n\t\t\t\t\t\tA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAFjpOucHm+eFuvP/AhCEd4ei\n\t\t\t\t\t\t3VUoKeVNUdtX1qpbv+ZH/ftkJaeRsRan4DAx4MWcEYED/+2DfYa+IWrNLVqp/ikl\n\t\t\t\t\t\tomdSgjL+KHjIUh+YZR3M/Citl60RLQp8x1leC1jInfafS8S/MJLAwCRtKlgcVHeL\n\t\t\t\t\t\ts1Tsvt1k++uaB4uKV/lWE8PS0H3hFnzE4i1S94HNWhC3S+2XB7AE6MXUCHQTknep\n\t\t\t\t\t\tBxEOB8wOhHyZdUMLGDMf1Vh8FsLeBbEyTSufmCMElvvhyypcf6OeRkoorvg6DO5z\n\t\t\t\t\t\tmLIz9BqxkSzMZ08i2sFYDzsN1brrua9J38vP2UXhUBER7f4jaituaTx0ZA1vYJs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Oxford Test IdP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oucs.ox.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Oxford"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://authest.bathspa.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:serverteam@bathspa.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Server Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:serverteam@bathspa.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Server Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://authest.bathspa.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_instant": "2013-06-14T11:36:22Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://authtest.bathspa.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://authtest.bathspa.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bathspa.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIIRqiLzGQHQaswDQYJKoZIhvcNAQEFBQAwPzEcMBoGA1UE\n\t\t\t\t\tCgwTQmF0aCBTcGEgVW5pdmVyc2l0eTEfMB0GA1UEAwwWYXV0aHRlc3QuYmF0aHNw\n\t\t\t\t\tYS5hYy51azAeFw0xMzA2MTIxMjAwMzNaFw0yMzA2MTIxMjAwMzNaMD8xHDAaBgNV\n\t\t\t\t\tBAoME0JhdGggU3BhIFVuaXZlcnNpdHkxHzAdBgNVBAMMFmF1dGh0ZXN0LmJhdGhz\n\t\t\t\t\tcGEuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCW6aSWgT8R\n\t\t\t\t\tZcWJ4CPCq+q+Q7HkmVwkLmrzq6EGKw2iWsv5julaNTOl6WAx2+xQecNWag+3rfGp\n\t\t\t\t\tuanS2frS+R7hO0x04VW4uBqfBKycUEvjJ9IeSaKifuVqui42YrUvypUAiMD0dyC1\n\t\t\t\t\t2GxkuAPsnpUyIiiFf/+jB29HaOhHl55ZJL7PLU79X63qoLGOcEfx3JpXzWZknp1o\n\t\t\t\t\t0+b3B6xWFTBElAuh/V7ZVwMnlQb6FDXdwURpP4Lfn2eNvEA5lj8nRgxqlFon0kGH\n\t\t\t\t\t2FPhlJ61nAcS15eSaaTCnsfz8pVgjPdd1nZq3SajTeJaZq4Fb4LB6NkdSN4eDNrN\n\t\t\t\t\tuQb4KDq96epdAgMBAAGjUDBOMB0GA1UdDgQWBBQem211nEnqC/c1sA/RIhSaKiOP\n\t\t\t\t\tgzAfBgNVHSMEGDAWgBQem211nEnqC/c1sA/RIhSaKiOPgzAMBgNVHRMEBTADAQH/\n\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQAvZz0attopvGO1nP/afw1/j/5AaWTZVgE6aQqA\n\t\t\t\t\tPq5krYkN0eDdEh0pYuSOGE9yj2ol7GfDJJdVqg5XK6xmwRnXgLKYjo7wiHq6U+mf\n\t\t\t\t\ttX2QESmKS5qiKc8GXZ7TB/Rzc4Q3pKcDC6ugMLPx3s4fKctttM2KU8FZ7YwA+esy\n\t\t\t\t\tSV6EThbdpCA4FFpTyMOK8ITuoeUyq6YK6sEIxMkq2gE/R+cB4VL1z/rpVC/FgN/G\n\t\t\t\t\t/MEIfzzKv+htixan0Vo0Gx5I6BPRvVi3Jk8mRjvw052p+1muveeBjeCvnBiXkkiT\n\t\t\t\t\t2z1owf0akLc7gonqQhWx3mwrj9WXKUxSwI/KU9QyJ7+g24GQ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIIRqiLzGQHQaswDQYJKoZIhvcNAQEFBQAwPzEcMBoGA1UE\n\t\t\t\t\tCgwTQmF0aCBTcGEgVW5pdmVyc2l0eTEfMB0GA1UEAwwWYXV0aHRlc3QuYmF0aHNw\n\t\t\t\t\tYS5hYy51azAeFw0xMzA2MTIxMjAwMzNaFw0yMzA2MTIxMjAwMzNaMD8xHDAaBgNV\n\t\t\t\t\tBAoME0JhdGggU3BhIFVuaXZlcnNpdHkxHzAdBgNVBAMMFmF1dGh0ZXN0LmJhdGhz\n\t\t\t\t\tcGEuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCW6aSWgT8R\n\t\t\t\t\tZcWJ4CPCq+q+Q7HkmVwkLmrzq6EGKw2iWsv5julaNTOl6WAx2+xQecNWag+3rfGp\n\t\t\t\t\tuanS2frS+R7hO0x04VW4uBqfBKycUEvjJ9IeSaKifuVqui42YrUvypUAiMD0dyC1\n\t\t\t\t\t2GxkuAPsnpUyIiiFf/+jB29HaOhHl55ZJL7PLU79X63qoLGOcEfx3JpXzWZknp1o\n\t\t\t\t\t0+b3B6xWFTBElAuh/V7ZVwMnlQb6FDXdwURpP4Lfn2eNvEA5lj8nRgxqlFon0kGH\n\t\t\t\t\t2FPhlJ61nAcS15eSaaTCnsfz8pVgjPdd1nZq3SajTeJaZq4Fb4LB6NkdSN4eDNrN\n\t\t\t\t\tuQb4KDq96epdAgMBAAGjUDBOMB0GA1UdDgQWBBQem211nEnqC/c1sA/RIhSaKiOP\n\t\t\t\t\tgzAfBgNVHSMEGDAWgBQem211nEnqC/c1sA/RIhSaKiOPgzAMBgNVHRMEBTADAQH/\n\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQAvZz0attopvGO1nP/afw1/j/5AaWTZVgE6aQqA\n\t\t\t\t\tPq5krYkN0eDdEh0pYuSOGE9yj2ol7GfDJJdVqg5XK6xmwRnXgLKYjo7wiHq6U+mf\n\t\t\t\t\ttX2QESmKS5qiKc8GXZ7TB/Rzc4Q3pKcDC6ugMLPx3s4fKctttM2KU8FZ7YwA+esy\n\t\t\t\t\tSV6EThbdpCA4FFpTyMOK8ITuoeUyq6YK6sEIxMkq2gE/R+cB4VL1z/rpVC/FgN/G\n\t\t\t\t\t/MEIfzzKv+htixan0Vo0Gx5I6BPRvVi3Jk8mRjvw052p+1muveeBjeCvnBiXkkiT\n\t\t\t\t\t2z1owf0akLc7gonqQhWx3mwrj9WXKUxSwI/KU9QyJ7+g24GQ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bath Spa University Test IdP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bathspa.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Bath Spa University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.upmf-grenoble.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sysadm-dsiu2@upmf-grenoble.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.upmf-grenoble.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-11-07T16:44:49Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.upmf-grenoble.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.upmf-grenoble.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.upmf-grenoble.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "upmf-grenoble.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.upmf-grenoble.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Staff and students of Grenoble 2 University"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnels et \u00e9tudiants de l\u2019universit\u00e9 Grenoble 2"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Grenoble 2 University - UPMF"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Grenoble 2 UPMF"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVzCCAj+gAwIBAgIUO1f61l32R6TuA6rB5vgAXHLdHFMwDQYJKoZIhvcNAQEF\nBQAwJjEkMCIGA1UEAxMbc2hpYmJvbGV0aC51cG1mLWdyZW5vYmxlLmZyMB4XDTEy\nMDYwNjEzNTYxMVoXDTMyMDYwNjEzNTYxMVowJjEkMCIGA1UEAxMbc2hpYmJvbGV0\naC51cG1mLWdyZW5vYmxlLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEApxQzW/bnlgZAvW5YGo5kkUHGQ7kmIH68l7JQJs/lpKGiFJ9J1dker2NpZAeM\nO4DXoPky5GYaLIUW7gB+rwV5rn/xdPcHXEoM6fk4Fo+UdAvAoCfy5+td7H2Vh9FN\nW01HShLqyP6L1t2wNRYYybSn6d1Bn8fmifPaj70AwpTjnIPcfzfoLJQ7cZ2FEiIs\nwncAb2WGIwUpVWff/i8tPFQFb17+DB9iZJZcuBNNutR+XL8ieEqKn1iRMFOacs0m\nlH5g4Upv5s2V+43DJY08+KhNT4ZTAuPDeeduHsR6xWaPJXMr1zIE8kojoI7xWVfi\nueki9ESCMgGRdo1gxHvSAr0hZQIDAQABo30wezBaBgNVHREEUzBRghtzaGliYm9s\nZXRoLnVwbWYtZ3Jlbm9ibGUuZnKGMmh0dHBzOi8vc2hpYmJvbGV0aC51cG1mLWdy\nZW5vYmxlLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBS7nbtER24yD2pjgXdT\nK9fyXANcdTANBgkqhkiG9w0BAQUFAAOCAQEAWC0ENJVG41ftYyD19+p0d1Ij0kfQ\nXz86gMzPL/738R1fdrfgDG33nm95lR98v0+MrxwANS7ah9173mxGFY+otLFCwMdb\n5A8+SFx3HTdJmCyiQ0cE7KcWKp2H7t+Y/9rpF9YCw2DQ9SjsdmqdPHnmrNlYBtQN\n7TXRykcIk9vJpCtq5G265MQ9fVkvutx0dFmhkwIB03HwX91V7EQyKFPS7BsMfu50\ni4Rso8QVUsjhRyUPu+LGdANROT8v+NgRL9ef7xDu4VdjMUHJKqxjQ+ahQdEu7+Lb\nzZ6QCFpB0/4tW9KCEPrLa+D/keEg+5vWKfMF+e5TMX4H4d2MW4in6HfySw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Grenoble 2 UPMF"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.upmf-grenoble.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Grenoble 2 UPMF"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idem.mulino.it/module.php/saml/sp/metadata.php/mulino-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Casarini"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paolo.casarini@mulino.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paolo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idem.mulino.it/module.php/saml/sp/metadata.php/mulino-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2016-01-27T15:36:26Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Societ\u00e0 editrice il Mulino"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Societ\u00e0 editrice il Mulino"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.mulino.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.mulino.it"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Societ\u00e0 editrice il Mulino"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Societ\u00e0 editrice il Mulino"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idem.mulino.it/module.php/saml/sp/saml2-logout.php/mulino-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.mulino.it/en/idem"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.mulino.it/it/idem"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Societ\u00e0 editrice il Mulino SP"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Societ\u00e0 editrice il Mulino SP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Societ\u00e0 editrice il Mulino SP"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Societ\u00e0 editrice il Mulino SP"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.mulino.it/images/Main/idem/sp_16x16",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://www.mulino.it/images/Main/idem/sp_16x16",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idem.mulino.it/logo-mul.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idem.mulino.it/logo-mul.png",
                    "lang": "it",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.mulino.it/en/privacy"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.mulino.it/it/privacy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID8zCCAtugAwIBAgIJAMkbEmZqjeSbMA0GCSqGSIb3DQEBCwUAMIGPMQswCQYD\nVQQGEwJJVDEOMAwGA1UECAwFSXRhbHkxEDAOBgNVBAcMB0JvbG9nbmExJjAkBgNV\nBAoMHVNvY2lldMODwqAgZWRpdHJpY2UgaWwgTXVsaW5vMQ0wCwYDVQQDDARJZGVt\nMScwJQYJKoZIhvcNAQkBFhhwYW9sby5jYXNhcmluaUBtdWxpbm8uaXQwHhcNMTYw\nMTE1MTAyOTQ1WhcNNDYwMTA3MTAyOTQ1WjCBjzELMAkGA1UEBhMCSVQxDjAMBgNV\nBAgMBUl0YWx5MRAwDgYDVQQHDAdCb2xvZ25hMSYwJAYDVQQKDB1Tb2NpZXTDg8Kg\nIGVkaXRyaWNlIGlsIE11bGlubzENMAsGA1UEAwwESWRlbTEnMCUGCSqGSIb3DQEJ\nARYYcGFvbG8uY2FzYXJpbmlAbXVsaW5vLml0MIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAu/oIHORTEHIuKBKCMHxdWo8QSYicJGU1dFM9fK4mVD918JQd\ncukm3jDJr6O/zPeCY7fjImhZu9AhbOyKAjb+F9ePiiMKSW/lR5wJFR9sdsq5ruIe\nSYiCwiiU2hFWKM6coTvhVlY5my1icIvOMAgbrIfq0I044qdpqPFoGATywqOYQ2ym\nvY7UDSa5QC6t3b0VbdWtXv+igjm0q1emdYkPLIjrbtcFvF58b3XEVMQZFFj4KJRI\nFH5c6oXwa/JiGalc95VnTshwnbgKPE/VgOLlMT1ZIz2x7q9jTMudkB9bjzGpqve4\nn6ku5uqzWjwcQ6jcaMaOP4feyitotqRjk2Y3JwIDAQABo1AwTjAdBgNVHQ4EFgQU\nk7K8lXmrFrnc4264epIGWVEhfiAwHwYDVR0jBBgwFoAUk7K8lXmrFrnc4264epIG\nWVEhfiAwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAQEAji+or0FcWfI3\n1X/DTNRXDYF0kphCSa6vhYKYBcF7RfRuLPPDP0uYEvEUnJyOajdiPL2BWtc9Y1VH\nUt9l/9SJOAMeSz0xyR1E61YZ6rUQ1U2rqzdbY5in82bgZR9aUIJRXzBBm5kkEp54\ndyRjDBY2ZEmYz03l0POIMokZrw/lNGxU0kdZhycWyyoXZ7hF6FDRh3e/TT+iwJVW\njqlRwwFEinIYD/GeIp298yaTDWoX4zRZKZScvuNKY/XhYTZB5h+TZIYopI6fHOAd\nj8NeTmS08jATxXA+WqAVswLYUA5LZQOWUl8Ue04T5p7lN72KuR0Had7K5DjaUV8r\ngDj9yuSzmw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID8zCCAtugAwIBAgIJAMkbEmZqjeSbMA0GCSqGSIb3DQEBCwUAMIGPMQswCQYD\nVQQGEwJJVDEOMAwGA1UECAwFSXRhbHkxEDAOBgNVBAcMB0JvbG9nbmExJjAkBgNV\nBAoMHVNvY2lldMODwqAgZWRpdHJpY2UgaWwgTXVsaW5vMQ0wCwYDVQQDDARJZGVt\nMScwJQYJKoZIhvcNAQkBFhhwYW9sby5jYXNhcmluaUBtdWxpbm8uaXQwHhcNMTYw\nMTE1MTAyOTQ1WhcNNDYwMTA3MTAyOTQ1WjCBjzELMAkGA1UEBhMCSVQxDjAMBgNV\nBAgMBUl0YWx5MRAwDgYDVQQHDAdCb2xvZ25hMSYwJAYDVQQKDB1Tb2NpZXTDg8Kg\nIGVkaXRyaWNlIGlsIE11bGlubzENMAsGA1UEAwwESWRlbTEnMCUGCSqGSIb3DQEJ\nARYYcGFvbG8uY2FzYXJpbmlAbXVsaW5vLml0MIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAu/oIHORTEHIuKBKCMHxdWo8QSYicJGU1dFM9fK4mVD918JQd\ncukm3jDJr6O/zPeCY7fjImhZu9AhbOyKAjb+F9ePiiMKSW/lR5wJFR9sdsq5ruIe\nSYiCwiiU2hFWKM6coTvhVlY5my1icIvOMAgbrIfq0I044qdpqPFoGATywqOYQ2ym\nvY7UDSa5QC6t3b0VbdWtXv+igjm0q1emdYkPLIjrbtcFvF58b3XEVMQZFFj4KJRI\nFH5c6oXwa/JiGalc95VnTshwnbgKPE/VgOLlMT1ZIz2x7q9jTMudkB9bjzGpqve4\nn6ku5uqzWjwcQ6jcaMaOP4feyitotqRjk2Y3JwIDAQABo1AwTjAdBgNVHQ4EFgQU\nk7K8lXmrFrnc4264epIGWVEhfiAwHwYDVR0jBBgwFoAUk7K8lXmrFrnc4264epIG\nWVEhfiAwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAQEAji+or0FcWfI3\n1X/DTNRXDYF0kphCSa6vhYKYBcF7RfRuLPPDP0uYEvEUnJyOajdiPL2BWtc9Y1VH\nUt9l/9SJOAMeSz0xyR1E61YZ6rUQ1U2rqzdbY5in82bgZR9aUIJRXzBBm5kkEp54\ndyRjDBY2ZEmYz03l0POIMokZrw/lNGxU0kdZhycWyyoXZ7hF6FDRh3e/TT+iwJVW\njqlRwwFEinIYD/GeIp298yaTDWoX4zRZKZScvuNKY/XhYTZB5h+TZIYopI6fHOAd\nj8NeTmS08jATxXA+WqAVswLYUA5LZQOWUl8Ue04T5p7lN72KuR0Had7K5DjaUV8r\ngDj9yuSzmw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idem.mulino.it/module.php/saml/sp/saml2-acs.php/mulino-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://idem.mulino.it/module.php/saml/sp/saml1-acs.php/mulino-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://idem.mulino.it/module.php/saml/sp/saml2-acs.php/mulino-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://idem.mulino.it/module.php/saml/sp/saml1-acs.php/mulino-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Societ\u00e0 editrice il Mulino SP"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Societ\u00e0 editrice il Mulino SP"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Societ\u00e0 editrice il Mulino SP"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Societ\u00e0 editrice il Mulino SP"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonOrgDN",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "email",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "telephoneNumber",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.20",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mobile",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.41",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idem.ced.inaf.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Nanni"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.nanni@ira.inaf.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mauro"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tinarelli"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:f.tinarelli@ira.inaf.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Franco"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:inaf-idem@ced.inaf.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idem.ced.inaf.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2011-03-22T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUC8sYEfq/qhT3iv/2z9PwJsH/ZLgwDQYJKoZIhvcNAQEF\nBQAwGzEZMBcGA1UEAxMQaWRlbS5jZWQuaW5hZi5pdDAeFw0xMDEwMDgxMzExNTFa\nFw0zMDEwMDgxMzExNTFaMBsxGTAXBgNVBAMTEGlkZW0uY2VkLmluYWYuaXQwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCEbHJhnfBE+5sri7Pw8QW6xscD\n2mDzd9WaDDzQMBVXljRzjxZ81/DeqFnwVdMFdZHM+ipUFGIUlmc21AtC+6rrSvDu\nLeYL/5F7JRu9LxAT7GRrQS3dkJkDC3QzGC3BW9SQO8hoXir2QqE5bwkTBy0F8V/F\neDq8c9cPFd1HlnO7D2K7An3OMI/hkZWOx41e0Vdsr1nUTcnLnLeZ/JXRMfFO8mD6\nrTCLq0XWZA2oRUd1QKeINLk8ERZqfp9MYh0pjfFFlFyFuWKafQtPV1lb+BKua4kn\ncFCn6QS7BpyAb6UGy84ag2Qk/2JumjZqzxfJ+L7mbuogOO+gt+JNuiZbsA2DAgMB\nAAGjZzBlMEQGA1UdEQQ9MDuCEGlkZW0uY2VkLmluYWYuaXSGJ2h0dHBzOi8vaWRl\nbS5jZWQuaW5hZi5pdC9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUypTVjZYa6twi\nvL+dwAqyQszxAZ4wDQYJKoZIhvcNAQEFBQADggEBAEiu9EK1DdBA6V8ZuszZnYLs\n3v983CaxOcMYv8rgAUavlI+hGa/1MPCDgmNsMHjfOvG3aBelwkCK302u+veFwQRa\nje20+UOa2xpYLGaZ8HTEU0qEEip4VHoWHBxLCdfIlBhf5sziVpWdZCwF968QHoFX\nE2fGE0imJGT9OzsZ54C/426VfH8SyiWeQjDkKGPfju5l/DtSKO4p74p2Ak8tTTDp\nV8mh1c6bJCaBrl4PCK/jZeIs+czIeWW5QvizGnIgDlBzXzaXHpkn66jLhzzO3cHs\nS7SNwUd0JmQ3xk5iZ/fzodAp/nzAOXGdcESNdtkrvaOKuVdg112uD1XR/rA4Jmw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "inaf.it"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ira.inaf.it"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iasfbo.inaf.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idem.ced.inaf.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idem.ced.inaf.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idem.ced.inaf.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idem.ced.inaf.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idem.ced.inaf.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idem.ced.inaf.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idem.ced.inaf.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idem.ced.inaf.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "inaf.it"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ira.inaf.it"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iasfbo.inaf.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ced.inaf.it/idem-info"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "National Institute for Astrophysics - INAF"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Istituto Nazionale di Astrofisica - INAF"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "National Institute for Astrophysics - INAF"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Istituto Nazionale di Astrofisica - INAF"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idem.ced.inaf.it/LogoINAF60.png",
                    "lang": "it",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  },
                  {
                    "text": "https://idem.ced.inaf.it/LogoINAF100.png",
                    "lang": "it",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.ced.inaf.it/idem-info/idp-privacy.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUC8sYEfq/qhT3iv/2z9PwJsH/ZLgwDQYJKoZIhvcNAQEF\nBQAwGzEZMBcGA1UEAxMQaWRlbS5jZWQuaW5hZi5pdDAeFw0xMDEwMDgxMzExNTFa\nFw0zMDEwMDgxMzExNTFaMBsxGTAXBgNVBAMTEGlkZW0uY2VkLmluYWYuaXQwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCEbHJhnfBE+5sri7Pw8QW6xscD\n2mDzd9WaDDzQMBVXljRzjxZ81/DeqFnwVdMFdZHM+ipUFGIUlmc21AtC+6rrSvDu\nLeYL/5F7JRu9LxAT7GRrQS3dkJkDC3QzGC3BW9SQO8hoXir2QqE5bwkTBy0F8V/F\neDq8c9cPFd1HlnO7D2K7An3OMI/hkZWOx41e0Vdsr1nUTcnLnLeZ/JXRMfFO8mD6\nrTCLq0XWZA2oRUd1QKeINLk8ERZqfp9MYh0pjfFFlFyFuWKafQtPV1lb+BKua4kn\ncFCn6QS7BpyAb6UGy84ag2Qk/2JumjZqzxfJ+L7mbuogOO+gt+JNuiZbsA2DAgMB\nAAGjZzBlMEQGA1UdEQQ9MDuCEGlkZW0uY2VkLmluYWYuaXSGJ2h0dHBzOi8vaWRl\nbS5jZWQuaW5hZi5pdC9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUypTVjZYa6twi\nvL+dwAqyQszxAZ4wDQYJKoZIhvcNAQEFBQADggEBAEiu9EK1DdBA6V8ZuszZnYLs\n3v983CaxOcMYv8rgAUavlI+hGa/1MPCDgmNsMHjfOvG3aBelwkCK302u+veFwQRa\nje20+UOa2xpYLGaZ8HTEU0qEEip4VHoWHBxLCdfIlBhf5sziVpWdZCwF968QHoFX\nE2fGE0imJGT9OzsZ54C/426VfH8SyiWeQjDkKGPfju5l/DtSKO4p74p2Ak8tTTDp\nV8mh1c6bJCaBrl4PCK/jZeIs+czIeWW5QvizGnIgDlBzXzaXHpkn66jLhzzO3cHs\nS7SNwUd0JmQ3xk5iZ/fzodAp/nzAOXGdcESNdtkrvaOKuVdg112uD1XR/rA4Jmw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Istituto Nazionale di Astrofisica - INAF"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "National Institute for Astrophysics - INAF"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.inaf.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.inaf.it/en"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Istituto Nazionale di Astrofisica (INAF)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National Institute for Astrophysics (INAF)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://agata.suz.cvut.cz/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kanovsky"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kanovsky@suz.cvut.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tomas"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://agata.suz.cvut.cz/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2013-08-16T09:51:28Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u010cesk\u00e9 vysok\u00e9 u\u010den\u00ed technick\u00e9 v Praze"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Czech Technical University in Prague"
          }
        ],
        "organization_url": [
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cvut.cz/cs"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cvut.cz/en"
          }
        ],
        "organization_name": [
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u010cVUT"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CTU"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://agata.suz.cvut.cz/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://agata.suz.cvut.cz/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://agata.suz.cvut.cz/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://agata.suz.cvut.cz/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://agata.suz.cvut.cz/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://agata.suz.cvut.cz/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://agata.suz.cvut.cz/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.suz.cvut.cz/en/the-facilities-administration-department-of-the-czech-technical-university-in-prague"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.suz.cvut.cz/sprava-ucelovych-zarizeni-cvut"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Canteens of CTU in Prague"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Menzy \u010cVUT v Praze"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp2.civ.cvut.cz/idp/images/logo_cvut_40pix.png",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "53"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Czech Technical University in Prague"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u010cesk\u00e9 vysok\u00e9 u\u010den\u00ed technick\u00e9 v Praze"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "agata.suz.cvut.cz"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEcDCCA1igAwIBAgIRAJSnezeeSwDm9u6PQ2mCUPswDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xMzA3MDEwMDAwMDBaFw0xNjA2MzAyMzU5NTlaMD8xITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEaMBgGA1UEAxMRYWdhdGEuc3V6\nLmN2dXQuY3owggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCkNwyaiPvQ\nfx1lS9AYlyR5VAYOwy/1KBC3FhSdGLMVpYYFIvVCEK5yDqQs6D7edBnjvqoDkIkU\ncbb6LZGz0bmiSMOE5toxMb1r8XzNcjzXe4Rn8NtFbO2lSUp77eTvMt4sTdmq1Krg\n7n5XuS0SrbIcWTh4M81QazVCIpD4L/elNCgyptKWw77EbRYe6as5lJsCcujSDCHD\ngO+gOqCM3fvOLSoCZv6zDnBAS4BVnfOOB4yRZgW5koIMFVnuXkMmyrqSc9kUiWp4\nEjghtgPuVsuhf+KWHegH63HfRBA7wp6Ukz/gkkBmRRIg4ogPUkBQJpTIBmCFHune\nhMUcueegHqRfAgMBAAGjggFuMIIBajAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3\nV0fqkOO57TAdBgNVHQ4EFgQUWeCB62InMSMtp9LL306vFP2jVsgwDgYDVR0PAQH/\nBAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUF\nBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1UdHwQz\nMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0Eu\nY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3Mu\ndGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9v\nY3NwLnRjcy50ZXJlbmEub3JnMBwGA1UdEQQVMBOCEWFnYXRhLnN1ei5jdnV0LmN6\nMA0GCSqGSIb3DQEBBQUAA4IBAQCb5NX/OotQMluDW6r3mCtXGnkSHRikC75D8+ua\nZEobB7MQHoeJg6ked7FlkatHkoqH2CZL7B66y9mhFJUFSHhRqjmudWRrJBW4SnME\nqnYLXX2q6NSmac3fH7P6BL7FyhED9+T+zfHI99A8oplvnXf4Vws/89hbzopCoI0+\nb++srMBwK/0XLocTzlTHhzCeNKflpEsP5YlNRvj4S25FhCb82Cmd+hL2OQen5000\nC0SakbhPqTeJv59bCJOjYhLfDW90dnn3HjdManRagoyE2zGCa88C7vSqwxabi7fj\nBie8tt/8TZ/a7EDN0YLJRmmMLKKCTwebuCYsUFiMOLdqCK2+"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=agata.suz.cvut.cz,OU=Domain Control Validated"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://agata.suz.cvut.cz/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://agata.suz.cvut.cz/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://agata.suz.cvut.cz/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://agata.suz.cvut.cz/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://agata.suz.cvut.cz/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://agata.suz.cvut.cz/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.sauws.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.sauws.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-09-03T11:49:17Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Students' Association of the University of the West of Scotland"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sauws.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.sauws.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.sauws.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.sauws.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.sauws.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.sauws.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.sauws.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.sauws.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.sauws.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.sauws.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.sauws.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.sauws.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.sauws.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.sauws.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.southstaffs.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Booth"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:gary.booth@southstaffs.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gary"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Booth"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:gary.booth@southstaffs.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gary"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.southstaffs.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEADCCAugCCQDq7fzogZjavTANBgkqhkiG9w0BAQUFADCBwTELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFjAUBgNVBAgTDVN0YWZmb3Jkc2hpcmUxETAPBgNVBAcTCFRhbXdvcnRoMSQw\n\t\t\t\t\t\tIgYDVQQKExtTb3V0aCBTdGFmZm9yZHNoaXJlIENvbGxlZ2UxFDASBgNVBAsTC0lU\n\t\t\t\t\t\tIFNlcnZpY2VzMR4wHAYDVQQDExVpZHAuc291dGhzdGFmZnMuYWMudWsxKzApBgkq\n\t\t\t\t\t\thkiG9w0BCQEWHGdhcnkuYm9vdGhAc291dGhzdGFmZnMuYWMudWswHhcNMTUxMDAx\n\t\t\t\t\t\tMDgzMzQwWhcNMjUwOTI4MDgzMzQwWjCBwTELMAkGA1UEBhMCR0IxFjAUBgNVBAgT\n\t\t\t\t\t\tDVN0YWZmb3Jkc2hpcmUxETAPBgNVBAcTCFRhbXdvcnRoMSQwIgYDVQQKExtTb3V0\n\t\t\t\t\t\taCBTdGFmZm9yZHNoaXJlIENvbGxlZ2UxFDASBgNVBAsTC0lUIFNlcnZpY2VzMR4w\n\t\t\t\t\t\tHAYDVQQDExVpZHAuc291dGhzdGFmZnMuYWMudWsxKzApBgkqhkiG9w0BCQEWHGdh\n\t\t\t\t\t\tcnkuYm9vdGhAc291dGhzdGFmZnMuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IB\n\t\t\t\t\t\tDwAwggEKAoIBAQDpAtyHcloEmBjnBzQxRdtiwfRNrvh+ByEyU/ztDHg4dLD8IbqX\n\t\t\t\t\t\tAInffLFXEZu7WPLaHwzxx/qcbQY0CvTXSt5+ggzfgJAxw2GjzgC9GQ3ExCBFcA+n\n\t\t\t\t\t\tgfQ7hmpizd21ik6NLAlG84fqGWgJuL/tRbfuIVQxTdImd/h4ryi0B1GjmF6/VFQI\n\t\t\t\t\t\tSXNWPGVgiAgjLZTozAHkO/WjDXXhLQZYcqlKNHm89SJlfi+VF4TgYW2a98B89fET\n\t\t\t\t\t\tdfWLkidV4KUUwDkv6FMHnqv7mfjJ9MoRU8mpfX8JDK0/lUozn0QLFQ3AO8OxrZoA\n\t\t\t\t\t\t6sewDKvIMhl56nqegL/l+kLSbYkaJ/bKGS4LAgMBAAEwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAAbies8SwJ46Nnck7OY9OAWV1WQqrVzgHFBjahn7Izt2keXy+VEW86mBA4Kg\n\t\t\t\t\t\ta6QevrGHRbGgcKpZAXrnDj2z0UCQXqIUQbLEUubPYEVbbhf3QSHOWaJnYCwGnAhD\n\t\t\t\t\t\t+XkBqp0BnwFsF51vO8SegX8S9YCsfA681W0fy7z3zkIwCQCfZHzpw7n1c4Q6KV4o\n\t\t\t\t\t\tBRNn2y+oMFH3d+zhShhQAa+wS+byfkw7/7D+FpZqg/PViTgmhYSkJH0S+xZWqn/R\n\t\t\t\t\t\tHGMSdGf19+/k58X3xxk+amHzW1QWkXJzWmjds5vuG/ni8EQyAnkV3Jx0+XblP4f6\n\t\t\t\t\t\tfwNx1H4ChYP4eEBqGjsRQKkDWr0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "southstaffs.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.southstaffs.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.southstaffs.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.southstaffs.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.southstaffs.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.southstaffs.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.southstaffs.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.southstaffs.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.southstaffs.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "southstaffs.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEADCCAugCCQDq7fzogZjavTANBgkqhkiG9w0BAQUFADCBwTELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFjAUBgNVBAgTDVN0YWZmb3Jkc2hpcmUxETAPBgNVBAcTCFRhbXdvcnRoMSQw\n\t\t\t\t\t\tIgYDVQQKExtTb3V0aCBTdGFmZm9yZHNoaXJlIENvbGxlZ2UxFDASBgNVBAsTC0lU\n\t\t\t\t\t\tIFNlcnZpY2VzMR4wHAYDVQQDExVpZHAuc291dGhzdGFmZnMuYWMudWsxKzApBgkq\n\t\t\t\t\t\thkiG9w0BCQEWHGdhcnkuYm9vdGhAc291dGhzdGFmZnMuYWMudWswHhcNMTUxMDAx\n\t\t\t\t\t\tMDgzMzQwWhcNMjUwOTI4MDgzMzQwWjCBwTELMAkGA1UEBhMCR0IxFjAUBgNVBAgT\n\t\t\t\t\t\tDVN0YWZmb3Jkc2hpcmUxETAPBgNVBAcTCFRhbXdvcnRoMSQwIgYDVQQKExtTb3V0\n\t\t\t\t\t\taCBTdGFmZm9yZHNoaXJlIENvbGxlZ2UxFDASBgNVBAsTC0lUIFNlcnZpY2VzMR4w\n\t\t\t\t\t\tHAYDVQQDExVpZHAuc291dGhzdGFmZnMuYWMudWsxKzApBgkqhkiG9w0BCQEWHGdh\n\t\t\t\t\t\tcnkuYm9vdGhAc291dGhzdGFmZnMuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IB\n\t\t\t\t\t\tDwAwggEKAoIBAQDpAtyHcloEmBjnBzQxRdtiwfRNrvh+ByEyU/ztDHg4dLD8IbqX\n\t\t\t\t\t\tAInffLFXEZu7WPLaHwzxx/qcbQY0CvTXSt5+ggzfgJAxw2GjzgC9GQ3ExCBFcA+n\n\t\t\t\t\t\tgfQ7hmpizd21ik6NLAlG84fqGWgJuL/tRbfuIVQxTdImd/h4ryi0B1GjmF6/VFQI\n\t\t\t\t\t\tSXNWPGVgiAgjLZTozAHkO/WjDXXhLQZYcqlKNHm89SJlfi+VF4TgYW2a98B89fET\n\t\t\t\t\t\tdfWLkidV4KUUwDkv6FMHnqv7mfjJ9MoRU8mpfX8JDK0/lUozn0QLFQ3AO8OxrZoA\n\t\t\t\t\t\t6sewDKvIMhl56nqegL/l+kLSbYkaJ/bKGS4LAgMBAAEwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAAbies8SwJ46Nnck7OY9OAWV1WQqrVzgHFBjahn7Izt2keXy+VEW86mBA4Kg\n\t\t\t\t\t\ta6QevrGHRbGgcKpZAXrnDj2z0UCQXqIUQbLEUubPYEVbbhf3QSHOWaJnYCwGnAhD\n\t\t\t\t\t\t+XkBqp0BnwFsF51vO8SegX8S9YCsfA681W0fy7z3zkIwCQCfZHzpw7n1c4Q6KV4o\n\t\t\t\t\t\tBRNn2y+oMFH3d+zhShhQAa+wS+byfkw7/7D+FpZqg/PViTgmhYSkJH0S+xZWqn/R\n\t\t\t\t\t\tHGMSdGf19+/k58X3xxk+amHzW1QWkXJzWmjds5vuG/ni8EQyAnkV3Jx0+XblP4f6\n\t\t\t\t\t\tfwNx1H4ChYP4eEBqGjsRQKkDWr0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "South Staffordshire College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.southstaffs.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "South Staffordshire College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.sympa.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sympa-authors@listes.renater.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.sympa.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-01-21T14:53:29Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/web"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/community"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GIP RENATER"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.renater.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GIP RENATER"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.sympa.org"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Sympa mailing list software website. The user manual can be edited by subscribers to sympa-users@listes.renater.fr"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Le wiki http://www.sympa.org est accessible aux contributeurs issus des universit\u00e9s. Les abonn\u00e9s \u00e0 sympa-fr@listes.renater.fr peuvent l'\u00e9diter."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.sympa.org/coco.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sympa.org - le site web"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sympa.org - le site web"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6zCCAdOgAwIBAgIJAOHudP2hFB4CMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDHZlc3BhLmNydS5mcjAeFw0xNTEwMDgxMjQwNTJaFw0yNTEwMDUxMjQwNTJa\nMBcxFTATBgNVBAMTDHZlc3BhLmNydS5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAO1tGvktL1ZEgQfLlUP1EIFIJuECoObOk+TLx5y3Rr7pEQDVpeEf\nYKMcqkjsvYKUDfUX9EwfjHh8e5kgVRQHi1Lr8lgC+e0VwUu4pRlxkwYLUd4o/nJh\nFLqTlddTwmR5vuQ9HVHUUqDPRrm7N+wf/J1D3v0/JRyEYbQaz/AY5GjawkXB+ioN\nHguk6jaYC72W79fQlBem1KSy7TeQXvPsHp1RiYeTqPOWWrB/Fmc22nQrf69gVUNA\nes9/l3b0dv8Dr3qjFKsdK/jMdSJGN2HN7CqfTrBLC7c2e43ZuUGe1+UOqqMyNpYP\n/QThy0tubqQdSGOqc8LqJSp81yR5HsQhSs8CAwEAAaM6MDgwFwYDVR0RBBAwDoIM\ndmVzcGEuY3J1LmZyMB0GA1UdDgQWBBQ9Qo9CfGWq0U/7Ouy8ChZr0vi+yDANBgkq\nhkiG9w0BAQUFAAOCAQEAKlKD1Nwj0vltOGgrmW0Q3bef8YDb3p9GSKtXEjrx8hSj\nYkHq77pE9Me8EMMKRa6/s/CX186El/dIu4o7SwNEn8alktut0tVwx/UujI7E9YtG\nHyIWBiI0QbiVz3xnU8q7oDa+2679yDZeiB1VEGM6fH8xePe/zysseNt38R+LZFaN\nW2Re4EiVyTm7cyC0db/eBPCPzd09FXdYFJiHuTOXfNB7Nwe+6QuIrNr59YXbISXi\nLB62PE5cL3gx719J0ga1Lze3M0QxvGi+gJibdoEne8np8EQUZ2ipdx+S2q6aFo0m\nBT0r1p+WzgcEohiQNP8sn1rNIh1JfKl3BIlXGFXLcg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6zCCAdOgAwIBAgIJAOHudP2hFB4CMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDHZlc3BhLmNydS5mcjAeFw0xNTEwMDgxMjQwNTJaFw0yNTEwMDUxMjQwNTJa\nMBcxFTATBgNVBAMTDHZlc3BhLmNydS5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAO1tGvktL1ZEgQfLlUP1EIFIJuECoObOk+TLx5y3Rr7pEQDVpeEf\nYKMcqkjsvYKUDfUX9EwfjHh8e5kgVRQHi1Lr8lgC+e0VwUu4pRlxkwYLUd4o/nJh\nFLqTlddTwmR5vuQ9HVHUUqDPRrm7N+wf/J1D3v0/JRyEYbQaz/AY5GjawkXB+ioN\nHguk6jaYC72W79fQlBem1KSy7TeQXvPsHp1RiYeTqPOWWrB/Fmc22nQrf69gVUNA\nes9/l3b0dv8Dr3qjFKsdK/jMdSJGN2HN7CqfTrBLC7c2e43ZuUGe1+UOqqMyNpYP\n/QThy0tubqQdSGOqc8LqJSp81yR5HsQhSs8CAwEAAaM6MDgwFwYDVR0RBBAwDoIM\ndmVzcGEuY3J1LmZyMB0GA1UdDgQWBBQ9Qo9CfGWq0U/7Ouy8ChZr0vi+yDANBgkq\nhkiG9w0BAQUFAAOCAQEAKlKD1Nwj0vltOGgrmW0Q3bef8YDb3p9GSKtXEjrx8hSj\nYkHq77pE9Me8EMMKRa6/s/CX186El/dIu4o7SwNEn8alktut0tVwx/UujI7E9YtG\nHyIWBiI0QbiVz3xnU8q7oDa+2679yDZeiB1VEGM6fH8xePe/zysseNt38R+LZFaN\nW2Re4EiVyTm7cyC0db/eBPCPzd09FXdYFJiHuTOXfNB7Nwe+6QuIrNr59YXbISXi\nLB62PE5cL3gx719J0ga1Lze3M0QxvGi+gJibdoEne8np8EQUZ2ipdx+S2q6aFo0m\nBT0r1p+WzgcEohiQNP8sn1rNIh1JfKl3BIlXGFXLcg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICejCCAeOgAwIBAgIJAJnxdJGVfGAeMA0GCSqGSIb3DQEBBQUAMDMxCzAJBgNV\nBAYTAkZSMQwwCgYDVQQKEwNDUlUxFjAUBgNVBAMTDXd3dy5zeW1wYS5vcmcwHhcN\nMDgwMzIwMTQ0NTQ4WhcNMjgwMzE1MTQ0NTQ4WjAzMQswCQYDVQQGEwJGUjEMMAoG\nA1UEChMDQ1JVMRYwFAYDVQQDEw13d3cuc3ltcGEub3JnMIGfMA0GCSqGSIb3DQEB\nAQUAA4GNADCBiQKBgQChP31mNdgalD3PWJHh/P+O1KHVhRCLXOVXVMSg8VHI+0rR\nfX6Ajc2ux7WurpelXmo4nafAGEKoz5Y8m9Ph/Zgtb/PXQC3ydWvDD4DIPfKC2jhR\naEbZSstXhU3pZY0lLgu7ZHe8RuWmuZT11RKCQXDu2IFBSGIg51TnJuUjSw0sYQID\nAQABo4GVMIGSMB0GA1UdDgQWBBQ295bivnTKDVtbzYASdob7fDrnUjBjBgNVHSME\nXDBagBQ295bivnTKDVtbzYASdob7fDrnUqE3pDUwMzELMAkGA1UEBhMCRlIxDDAK\nBgNVBAoTA0NSVTEWMBQGA1UEAxMNd3d3LnN5bXBhLm9yZ4IJAJnxdJGVfGAeMAwG\nA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADgYEAlB3jg+IyBkO45Wo61YE32N6O\n0+pVQaMGMf3jCwxRrM96dSJHj0NhTor3ZIsqzhRYZDRR67wJzk0D7QQCnOW90mlg\nd99p9wFKc5VN5aKrlDrU5guLjbl4avX/IEi1Sjj2eio6sKE/E5JsUs0ct3edtkXB\nQfGIdEliJJoWsN5ba6I="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.sympa.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.sympa.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Sympa.org - le site web"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Le wiki http://www.sympa.org est accessible aux contributeurs issus des universit\u00e9s. Les abonn\u00e9s \u00e0 sympa-fr@listes.renater.fr peuvent l'\u00e9diter."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Sympa mailing list software website. The user manual can be edited by subscribers to sympa-users@listes.renater.fr"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://registry.swamid.se/saml2/metadata/",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lordal"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "anders.lordal@hig.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "SWAMID"
          },
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Anders"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lordal"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "anders.lordal@hig.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "SWAMID"
          },
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Anders"
          }
        }
      ],
      "entity_id": "https://registry.swamid.se/saml2/metadata/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SWAMID"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SWAMID"
          }
        ],
        "organization_url": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.swamid.se"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.swamid.se"
          }
        ],
        "organization_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SWAMID"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SWAMID"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://registry.swamid.se/saml2/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SWAMID metadata registry"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SWAMID metadata registry"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SWAMID PEER"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SWAMID PEER"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDTCCAfWgAwIBAgIJALBwBoyJSdS3MA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMMEnJlZ2lzdHJ5LnN3YW1pZC5zZTAeFw0xNDA5MjkxMzQ2MTZaFw0yNDA5MjYx\nMzQ2MTZaMB0xGzAZBgNVBAMMEnJlZ2lzdHJ5LnN3YW1pZC5zZTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALAmfWTwfXf3O85urmVux9wO0zgrIBWzUEEb\ngGNN0yKgYjvYR4w69b3olXKKTjCaJsCHksc7belAl3pqVShGdKmmDSN/E6+jl5ul\nGSYwFx52AlaMEMoPv7slVZbN1kcoPvaJ5t93vcM17JDaa8bROPb63MbCMcmAMgUm\nZmSZrv1fu1cq08XVMHTQJ5BW7NmW7PaA+tbRckLI764L8Tv9aqewi3aRRp3OO2eX\nlGu/6tz6MhOGv8gdY5Y3XKuGanJQmt+FgTkcEKvlTvk7tYActi8SY6PiLXlMfoJF\nbSGSu1irUT/hC7x9kSCOPYH3vXJx+Z0PS3cRcYlyHi6/W/qqQJkCAwEAAaNQME4w\nHQYDVR0OBBYEFF3t1ekJ/iTlxpQSy9uKYOxAW8GsMB8GA1UdIwQYMBaAFF3t1ekJ\n/iTlxpQSy9uKYOxAW8GsMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEB\nACWRN5N5AfJSehnb6io22WftigC/HtY+yr2iaFtZfJXoLwtTHxffK7SKC84Ac6bu\nrovh0FUgfj4QWgQ06IL906ENaqEWNDRzUI9xWe+RCNEFVWvKyU5jh9j6JGG8JUYh\nY84CiK5LlMi9XtAmNhClbOUP//3a5UHARhNmFcRxxiwfRY2k0sMNmhlk31xh+gwb\nCuQ36pkExudxFaHv+Vjv09LXtJxRnfvffGXFlT/DUeddhqC2vKtVoIg8S8295rOk\njkl44jhVvXLSythVxryo/Mf7b8QbicsObxpxFMb9ifVbWyi5ri0WLgvQAXpyw/MH\n3lQIb3o7ibN/Oix1Wq0WXuA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://registry.swamid.se/saml2/acs/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "PEER SP"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://birk.wayf.dk/birk.php/sso.basyd.dk/adfs/services/trust",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://birk.wayf.dk/birk.php/sso.basyd.dk/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2015-06-14T14:50:42Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/sso.basyd.dk/adfs/ls",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "basyd.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Erhvervsakademi Kolding"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "International Business Academy"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "basyd.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC2DCCAcACAQcwDQYJKoZIhvcNAQELBQAwMjEwMC4GA1UEAwwnaHR0cDovL3Nz\nby5iYXN5ZC5kay9hZGZzL3NlcnZpY2VzL3RydXN0MB4XDTE1MDEwMTAwMDAwMFoX\nDTI1MTIzMTIzNTk1OVowMjEwMC4GA1UEAwwnaHR0cDovL3Nzby5iYXN5ZC5kay9h\nZGZzL3NlcnZpY2VzL3RydXN0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAx4gMCmoQU7iOGfiCda4DnhIggst20fUCHtwaQrHoxQlOa0s5FgDalbnNTw36\ndCXSGYaz17JgyUDJonTwhjyA0CqPm5Pmn9/hFBUvyP/t+bEgV9r3/odQx72VfY7M\n55qUlY6ex2f1qD1gcpFgSTtADlZswec5WqpEt+ie+vsMXq8HabhMVZ2EjXe90vgM\nk/xGfrVwDvupUPBS/2DJSZ1JEmkqi0hxctNQ9qgTZmEcAaQkuv3VGcsYtLeY/IIS\nlA+ARzmVWr5+uSetnCXV4jnDEclACKeexl0Ky+tyra4yHF3Xavgmcmebd+xHVDiM\n+No6BXMu9zBTp7cp5ShLzsNQSQIDAQABMA0GCSqGSIb3DQEBCwUAA4IBAQA2XXwl\nDO1ZW0pfyw3c5a6DAswHvWyTadziKIbu1udaLKYRgkFK6bK5xQw8fzQIyUvFdXOI\nKFnkkGHby4k3rQ4p/JvbjwDvKYGDOfhHbx71KX7wJebXKZdp6fWMgkoWVtimd0nh\nyPXrCZt6Q3y1cmCmnjMdRoWcVqQp4nU6c7RoO0i4d8EqkRt33M8L/F9cdNJHHUp+\nzNrZFpjq+t2fsk+X2klKZdHjETj38dq4hf7k9JRN/aRHWdj7TRgOn6Tpu4vRvBLR\nd7il/TmlRJpZCHPzgpx8gbIJwIruwlvCeGbKJnNsjbB08wG8Uw92fPIhTxQutgvt\nh8V01qfDTMmw4ASc"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Erhvervsakademi Kolding"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "International Business Academy"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iba.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iba.dk/internationalstudies"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Erhvervsakademi Kolding"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "International Business Academy"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.informit.com.au/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@rmitpublishing.com.au"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Informit Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Crowther"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dominic.crowther@rmit.edu.au"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dominic"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pham"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dominic.crowther@rmit.edu.au"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Loan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.informit.com.au/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-12-23T10:04:29Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Informit"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.informit.com.au/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RMIT Training Pty Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.informit.com.au/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.informit.com.au/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.informit.com.au/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.informit.com.au/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.informit.com.au/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Informit is the premier source of core research and resources from the Australasian region."
                  }
                ],
                "logo": [
                  {
                    "text": "https://search.informit.com.au/images-v4/logo-informit.gif",
                    "height": "43",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "136"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Informit"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib.informit.com.au/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shib.informit.com.au/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib.informit.com.au/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shib.informit.com.au/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib.informit.com.au/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib.informit.com.au/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib.informit.com.au/Shibboleth.sso/UKfedWAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shib.informit.com.au/Shibboleth.sso/UKfedWAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEjCCAfqgAwIBAgIJAMJQ7W9dNntWMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\n\t\t\t\t\t\tBAMTGXNoaWJwcmR3czAxLnJtaXQuaW50ZXJuYWwwHhcNMTYwMjE1MjMwNjM0WhcN\n\t\t\t\t\t\tMjYwMjEyMjMwNjM0WjAkMSIwIAYDVQQDExlzaGlicHJkd3MwMS5ybWl0LmludGVy\n\t\t\t\t\t\tbmFsMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsl8OCJqga3lb7Nw6\n\t\t\t\t\t\tXgS5YrzMz7HOZKQ5FtuveFyESrQ2YkmJm4NVxXYQ74ahdYpKfjT/I7aSY5Fo0Zfs\n\t\t\t\t\t\tRQ08ZhXLppQSaOBkPkfGzZJFAoGo5jZUzS29INjPo/vutRd787CfUwSVM/fG7CBH\n\t\t\t\t\t\ty6LK5+yU4NaxfPu7cgXyLdT9id9vXCanktDf+8MwBcHAQDW1mDw1eqqhED6+50zS\n\t\t\t\t\t\tp7HlZjcHlJ4O8CBmi/STrLNNIChFFYFWWhfq0dNBas4br5ro8bSmFNPXpkoK17t3\n\t\t\t\t\t\tCM2IVKvQOnRpSy/xuun7w7uTpB3bVBiWYO5l8hZ06PDiLaGujiebV23jL35DrtGl\n\t\t\t\t\t\tEAUvbQIDAQABo0cwRTAkBgNVHREEHTAbghlzaGlicHJkd3MwMS5ybWl0LmludGVy\n\t\t\t\t\t\tbmFsMB0GA1UdDgQWBBT0PhB6XxNLt7dLIwr0nlxbJ9z72DANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAdN5GfXlrkG1x4ygh1/ZwBtNgQPiaWCIBTNVSLBZCLZYU3FFPZoK26W3U\n\t\t\t\t\t\tqj8db4lHSlm46ExSmYR4mPsFUfqmRAD6yQwVFLGll4J88Mt7iVu6M9kyBxhQJ7X/\n\t\t\t\t\t\tUfJhnRxzYLyoDtLjp3ayynkE36f7KRnlVeukYminUnlURyW0+RR5FVgv2WBn3RRk\n\t\t\t\t\t\tNmi1/D0NwnlH72Pj+hfblBuhfF1eWlYWEAdC+t9LUCU32Ocox0GP8WNNDz5x41Yt\n\t\t\t\t\t\tEKhu2M87LgaVdkNX7Byh25ha8ELXFBxMcv/uMmImAT53C9rd/4UTLaHQffFVDD1C\n\t\t\t\t\t\tjMB14stpA71j1X9hdeFzaL/T/NYkww=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.informit.com.au/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.informit.com.au/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.informit.com.au/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shib.informit.com.au/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shib.informit.com.au/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shib.informit.com.au/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.cornwall.ac.uk/shibboleth-idp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@cornwall.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wright"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jon.wright@cornwall.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cornwall.ac.uk/shibboleth-idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-08-05T14:38:25.779805Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAOk7GwlKWRg+w8gK7LWBuLRrQts1MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB0xGzAZBgNVBAMTEmlkcC5jb3Jud2FsbC5hYy51azAeFw0xMzA5MDIxMDE4\n\t\t\t\t\t\tMjdaFw0zMzA5MDIxMDE4MjdaMB0xGzAZBgNVBAMTEmlkcC5jb3Jud2FsbC5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJLIUX5+M6fr44ZuLex4\n\t\t\t\t\t\tm4EfwVdRt6Wm/9Cj7uxUXcYKoVHdpKWeyWKD27Fuc/eI7b5B2v1MO0i/IpeT1o2H\n\t\t\t\t\t\ttSmty0gKcYt6+7FMfydazu8MFVgHklElFeFtMxOLsnnIS618gcP5uwbiWkba4BN6\n\t\t\t\t\t\t80XHQyECDqKf6XOPAls+ZDqm85IzLZc9+EyFNJBGrNzC6nUASXuJjU5Ws1BdVn/r\n\t\t\t\t\t\teD9XQH6n5IjEB9ZJdmyuD8PyAoEDhmAG67A8BiAx6mLLWbBc32yvNuVRoOOWxLSA\n\t\t\t\t\t\tAi+huqmGrkrk48QGiF9IIyC1FjdYsjhWbnx+cJJInuxi+8R6f4i9vUOG8OOcTcYx\n\t\t\t\t\t\tp78CAwEAAaNrMGkwSAYDVR0RBEEwP4ISaWRwLmNvcm53YWxsLmFjLnVrhilodHRw\n\t\t\t\t\t\tczovL2lkcC5jb3Jud2FsbC5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n\t\t\t\t\t\tuT8cKbmugXbKgJV02McvjAUP1N8wDQYJKoZIhvcNAQEFBQADggEBABvVUiY2qgLg\n\t\t\t\t\t\tSI27b2IFdRhGorAJ9Ed/hCOO/lE0ICRzb6qksRiKCyWEm9uEG7TSQfsjJ2s6KaT3\n\t\t\t\t\t\tFWdt3UaVomeaVyuu/jDO1kxIO8CCZXl/m9nrK/3AazVwlfgGvE5jDi13Gw2iS69I\n\t\t\t\t\t\t7hZL/RId3JYKJUAiXyaUOojiyL36A2M5/ZJgwrZJlgUiJX/eonzUznVRLGW9hU1q\n\t\t\t\t\t\tQLN5cohidCL6W7v51hKwIxs1FdB1kRHuqNjF3DLwgf8tx4+a4W5LMKOlgMZzfVCj\n\t\t\t\t\t\troP2vsH3YT6V9Ecg5BeGCcLX1qjv5SYA7mPpmo8n9a75raAoRKYxdHLiB5RNCAfk\n\t\t\t\t\t\tcbka+/2Fop4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cornwall.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cornwall.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cornwall.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.cornwall.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cornwall.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.cornwall.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cornwall.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cornwall.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cornwall.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cornwall.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAOk7GwlKWRg+w8gK7LWBuLRrQts1MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB0xGzAZBgNVBAMTEmlkcC5jb3Jud2FsbC5hYy51azAeFw0xMzA5MDIxMDE4\n\t\t\t\t\t\tMjdaFw0zMzA5MDIxMDE4MjdaMB0xGzAZBgNVBAMTEmlkcC5jb3Jud2FsbC5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJLIUX5+M6fr44ZuLex4\n\t\t\t\t\t\tm4EfwVdRt6Wm/9Cj7uxUXcYKoVHdpKWeyWKD27Fuc/eI7b5B2v1MO0i/IpeT1o2H\n\t\t\t\t\t\ttSmty0gKcYt6+7FMfydazu8MFVgHklElFeFtMxOLsnnIS618gcP5uwbiWkba4BN6\n\t\t\t\t\t\t80XHQyECDqKf6XOPAls+ZDqm85IzLZc9+EyFNJBGrNzC6nUASXuJjU5Ws1BdVn/r\n\t\t\t\t\t\teD9XQH6n5IjEB9ZJdmyuD8PyAoEDhmAG67A8BiAx6mLLWbBc32yvNuVRoOOWxLSA\n\t\t\t\t\t\tAi+huqmGrkrk48QGiF9IIyC1FjdYsjhWbnx+cJJInuxi+8R6f4i9vUOG8OOcTcYx\n\t\t\t\t\t\tp78CAwEAAaNrMGkwSAYDVR0RBEEwP4ISaWRwLmNvcm53YWxsLmFjLnVrhilodHRw\n\t\t\t\t\t\tczovL2lkcC5jb3Jud2FsbC5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n\t\t\t\t\t\tuT8cKbmugXbKgJV02McvjAUP1N8wDQYJKoZIhvcNAQEFBQADggEBABvVUiY2qgLg\n\t\t\t\t\t\tSI27b2IFdRhGorAJ9Ed/hCOO/lE0ICRzb6qksRiKCyWEm9uEG7TSQfsjJ2s6KaT3\n\t\t\t\t\t\tFWdt3UaVomeaVyuu/jDO1kxIO8CCZXl/m9nrK/3AazVwlfgGvE5jDi13Gw2iS69I\n\t\t\t\t\t\t7hZL/RId3JYKJUAiXyaUOojiyL36A2M5/ZJgwrZJlgUiJX/eonzUznVRLGW9hU1q\n\t\t\t\t\t\tQLN5cohidCL6W7v51hKwIxs1FdB1kRHuqNjF3DLwgf8tx4+a4W5LMKOlgMZzfVCj\n\t\t\t\t\t\troP2vsH3YT6V9Ecg5BeGCcLX1qjv5SYA7mPpmo8n9a75raAoRKYxdHLiB5RNCAfk\n\t\t\t\t\t\tcbka+/2Fop4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cornwall College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cornwall.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cornwall College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.eurecom.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@eurecom.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.eurecom.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-03-20T18:45:57Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.eurecom.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.eurecom.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.eurecom.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eurecom.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.eurecom.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Any student, researcher and personal users authenticated by directory server of EURECOM."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Tout utilisateur de type \u00e9tudiant, chercheur et personnel authentifi\u00e9 par l'annuaire d'EURECOM."
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EURECOM"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EURECOM"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAL0+FcNd+RBrqwXsGlutpKVVG5BzMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC5ldXJlY29tLmZyMB4XDTEzMTIxMjA5NTcyN1oX\nDTMzMTIxMjA5NTcyN1owGTEXMBUGA1UEAxMOaWRwLmV1cmVjb20uZnIwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDGYpCW+8So7j9MDPjvSzK7ThwTHigN\n9XSgt3xydTOSJdZ2R/0JkZ7mSMoNhb21ZPnOlMntPTG7I5iWKh9O02rHj2/01JzU\n6PmD+hNHI2XWrA6yCarO+6/t38seOPAoBJZJ067UTWQ/Wup7v1aWZ3fgu3Meay0s\n6iwlfUZMVXfDH1DO1kvnhirlXxCBVXwhsXIksje2gsECayHpvPQ7ZyD9pIRGo74I\nNEqXPj5Z9F3XtXngMHdMvDJlWHo3oZ1p/WrQa2jHx0rynFYleEGzms9gtsBWQmtP\nG7JNlLntBsDa2WDmCYc4JoyeH29IVgRSCF8DqHTQpRnFUx1uokFfJjcnAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC5ldXJlY29tLmZyhiVodHRwczovL2lkcC5ldXJl\nY29tLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQXXN9yiNpwBniygQ4M8be1\nVW+n0jANBgkqhkiG9w0BAQUFAAOCAQEAb1oFFcqPKv/IGgsUQCHrHNB5dG3lWCMC\nRotaqTqIQORT0ittxS8JAv53j+tEo/C5BbdHqX2lwJb6qlqpzOb9IRHsJfAhKuXc\nuIgTN3Hp9gdSnT0sFqlffmdqL09u56nJYpgGXx78IcxZ7Q6uVXvjj9/r72i6cMbF\nyQVYEVSEnTGb6XI/Lk/bF5t5KZPhnNWM3cVC+4qLwcuJTKcO9/mJyU3y0QczeCaR\nDCkMZEunkZO+fnPbVEaY4/a7rRKebhMty9gcJASrTF9seG5IfME0Nz61+Mbjre9V\nwYMMzOpBYP7tCdxld40eG8UXU7Hzw9smDW1QErZqbMYm3Z7Qss1p0Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EURECOM"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eurecom.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "EURECOM"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shfed.augusta.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "andsmith@augusta.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew Smith"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "roneil@augusta.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ryan O'Neil"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cpeavler@augusta.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris Peavler"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shfed.augusta.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shfed.augusta.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shfed.augusta.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shfed.augusta.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUQ0k0DvqYzUB+2FqlbJ6wSij4ChMwDQYJKoZIhvcNAQEL\nBQAwHDEaMBgGA1UEAwwRc2hmZWQuYXVndXN0YS5lZHUwHhcNMTYwMzAyMTQxNTE2\nWhcNMzYwMzAyMTQxNTE2WjAcMRowGAYDVQQDDBFzaGZlZC5hdWd1c3RhLmVkdTCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALtPKXvOZAOcUd/rl1ylabyr\nOs4SNoTXBk8aopYsO5+ntwqCMsdZxlJ+rFKcocM0CabbNL+bEQO6UvOO5wv0Xwnf\nJdzynGcW5Acxp4due88HEOO2d6pRlK5RP9zv4SBN+3V/7rBy7OXQYJ5o877ctsHV\nHvi6buwZuoypAdkhs6bRPNrVssRfzIVwoUq3D8qgH/h6HecGg/rCJBQ7LtExK2ed\nL41LsFGiXWmlV+BGwJAFEfpcP4QY9VzKbzGz3LquZX8OnrGJl+xaiUwou4wUp9uv\nmZKO3UcUjwl8TKrb5MJnk4nvEAL7faUxKCThyUgtflmu8FitHSKewobg5NAuoK0C\nAwEAAaNpMGcwHQYDVR0OBBYEFJ5ci1HmOu2QmzDHUU5EPPd/9wWVMEYGA1UdEQQ/\nMD2CEXNoZmVkLmF1Z3VzdGEuZWR1hihodHRwczovL3NoZmVkLmF1Z3VzdGEuZWR1\nL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQAuW6vDVLs7R0PmfVSM\nPwZ6360LeEJ1I2nf+dQNaK/bPywzC9795EVVf9WOPTGdsUKXSG29LD+Jt+NGX55q\nno86JHjkDymlTS2cU8FdVWVk6yH/+LFc2NAyVORH4YlFcihyCkxu6Rjh5+GiUBY1\nkxMxh4weCpeKdYkVWeAds27123As+m2O8f36bqzhLFKhmYzKpdIIiB+NuljiQJBd\n2b6MB5V/n8z6xmjaHwlosuaB6/BDv6M8g7aECQqAwIzHekyFrHU7UwOe5pU1UsuN\nVdqdJzZoyuqY6gMBf5LpbGYHDDu1PuJrmwKJYxGVz7lTEQxMS5G9/gpYUIcpXf/B\nHzYL"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "augusta.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Augusta University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Augusta University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.augusta.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Augusta University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:kuleuven.be:kulassoc:kuleuven.be",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shib@kuleuven.be"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAI team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "servicepunt@icts.kuleuven.be"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ICTS Servicepunt"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:kuleuven.be:kulassoc:kuleuven.be",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://federation.belnet.be/files/Belnet-metadata-registration-practice-statement.txt"
              }
            ],
            "registration_instant": "2012-03-27T12:00:00Z",
            "registration_authority": "http://federation.belnet.be/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUJCkaCLjPZevQdbFbyV/aX8+ObfEwDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPaWRwLmt1bGV1dmVuLmJlMB4XDTEwMTIwNjEwMzY1MFoX\nDTMwMTIwNjEwMzY1MFowGjEYMBYGA1UEAxMPaWRwLmt1bGV1dmVuLmJlMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoIYa2FxhIfJ7Sy1RhWTmUObGUJRO\nWkyRuQ8colNagd7LgtmV1QMtzO7ZBrzUtJYtl65JJdGa0bN3k2UotpvB2qu77n8g\nCenFr2QgOxbf+7uadVkxAYaow0GA1u3a9c4TaHn4Y8WazR1SN386VKGwZcKEGGsV\nKWnC3gXGLar2p1Oqd69l68nSXQ98O6GgmGbnDVbN/VgNI2Vqe5dpu4tAQQoH6gPH\nGPl4xTeffAI/Vcy7OveAEXlz1nGTxJlwZ9/+RmEV8ub553ZYeojaceMqrHDSpkzu\nd8fwWsifjdZS7jfxFuhlbiPh67aa4y1jskGmviWOENCNZU246TyPuSE9nQIDAQAB\no2UwYzBCBgNVHREEOzA5gg9pZHAua3VsZXV2ZW4uYmWGJmh0dHBzOi8vaWRwLmt1\nbGV1dmVuLmJlL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQ3Wq3jKozzu+nRqPAm\nllWj/cBVAjANBgkqhkiG9w0BAQUFAAOCAQEANGAtqMje2/kEPetXA0AOesJ0OYxh\nAaKIAawXwUQcvAEW+uO879UEppsq3VMXrX9VqXrXY47o5B2+/NtvSls7U0FeA/QE\nvBEeFteBO7NxKY7VasCCfYI7mT0LUr3MgIPDnENq4ymNyLVgAhxOK4Vu43mtPz8D\n+yUwJwUPelIPJsW994v3EXGFSN8XYoxZcWfub41JBTSCcUPEeRllizGgTgFpZdGw\nyBBF0f9qs7xieTqsGGijXddW2178IDQV0l3abTnhZZW+FWO5pKOYwkRaLD092RVh\n5WD5+lg0EzoMXE00cBUlt6+K8JNWQARxL7MYUMX0ciUUP+XCSFsiYVHX4w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kuleuven.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "groept.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hubkaho.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "odisee.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucll.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vives.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "luca-arts.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "khlim.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "khleuven.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "thomasmore.be"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.kuleuven.be:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.kuleuven.be:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.kuleuven.be/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.kuleuven.be/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.kuleuven.be/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.kuleuven.be/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.kuleuven.be:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.kuleuven.be:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kuleuven.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "groept.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hubkaho.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "odisee.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucll.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vives.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "luca-arts.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "khlim.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "khleuven.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "thomasmore.be"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://associatie.kuleuven.be/eng"
                  },
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://associatie.kuleuven.be/over"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "KU Leuven and the associated university colleges"
                  },
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "KU Leuven en de geassocieerde hogescholen"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "75",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "153"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "KU Leuven Association"
                  },
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Associatie KU Leuven"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "kuleuven.be"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:50.9378101,4.0409517000000505"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.2194475,4.40246430000002"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.209348,3.2246995000000424"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:50.84999999999999,4.350000000000023"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:50.91083,5.4133600000000115"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:50.98965,5.050160000000005"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:50.8464506,4.262063000000012"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.16257,4.990839999999935"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.0543422,3.717424299999948"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:50.93069,5.332480000000032"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:50.8194776,3.2577263000000584"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:50.87822088437878,4.702697216918987"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.1302138,4.571509200000037"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.0258761,4.477536200000031"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.2166667,2.8999999999999772"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:50.94990869999999,3.129447099999993"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:50.8674164,4.377298099999962"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.07045,4.53135999999995"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.1558839,4.15444100000002"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:50.940892,4.904695599999968"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.06498,3.101570000000038"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.3216509,4.93755770000007"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.2025247,4.770882700000016"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:50.8134333,4.324834399999986"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "134.58.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.168.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.176.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.180.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.253.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.146.160/27"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.57.0/26"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.57.192/27"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.57.224/27"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.58.0/26"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.59.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.255.0/25"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.138.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.191.187.0/25"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.77.0/26"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.224.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.225.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.130.128/26"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2a02:2c40::/32"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUJCkaCLjPZevQdbFbyV/aX8+ObfEwDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPaWRwLmt1bGV1dmVuLmJlMB4XDTEwMTIwNjEwMzY1MFoX\nDTMwMTIwNjEwMzY1MFowGjEYMBYGA1UEAxMPaWRwLmt1bGV1dmVuLmJlMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoIYa2FxhIfJ7Sy1RhWTmUObGUJRO\nWkyRuQ8colNagd7LgtmV1QMtzO7ZBrzUtJYtl65JJdGa0bN3k2UotpvB2qu77n8g\nCenFr2QgOxbf+7uadVkxAYaow0GA1u3a9c4TaHn4Y8WazR1SN386VKGwZcKEGGsV\nKWnC3gXGLar2p1Oqd69l68nSXQ98O6GgmGbnDVbN/VgNI2Vqe5dpu4tAQQoH6gPH\nGPl4xTeffAI/Vcy7OveAEXlz1nGTxJlwZ9/+RmEV8ub553ZYeojaceMqrHDSpkzu\nd8fwWsifjdZS7jfxFuhlbiPh67aa4y1jskGmviWOENCNZU246TyPuSE9nQIDAQAB\no2UwYzBCBgNVHREEOzA5gg9pZHAua3VsZXV2ZW4uYmWGJmh0dHBzOi8vaWRwLmt1\nbGV1dmVuLmJlL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQ3Wq3jKozzu+nRqPAm\nllWj/cBVAjANBgkqhkiG9w0BAQUFAAOCAQEANGAtqMje2/kEPetXA0AOesJ0OYxh\nAaKIAawXwUQcvAEW+uO879UEppsq3VMXrX9VqXrXY47o5B2+/NtvSls7U0FeA/QE\nvBEeFteBO7NxKY7VasCCfYI7mT0LUr3MgIPDnENq4ymNyLVgAhxOK4Vu43mtPz8D\n+yUwJwUPelIPJsW994v3EXGFSN8XYoxZcWfub41JBTSCcUPEeRllizGgTgFpZdGw\nyBBF0f9qs7xieTqsGGijXddW2178IDQV0l3abTnhZZW+FWO5pKOYwkRaLD092RVh\n5WD5+lg0EzoMXE00cBUlt6+K8JNWQARxL7MYUMX0ciUUP+XCSFsiYVHX4w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "KU Leuven / Associatie KU Leuven"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "KU Leuven / KU Leuven Association"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kuleuven.be"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kuleuven.be"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "KU Leuven / Associatie KU Leuven"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "KU Leuven / KU Leuven Association"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://neo236.neocase-software.net/connexion_neocase",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "eszczesuil@neocasesoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Eileen Szczesuil"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "npetcu@neocasesoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nicoleta Petcu"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://neo236.neocase-software.net/connexion_neocase",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Neocase Software Inc."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.neocasesoftware.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Neocase Software Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://neo236.neocase-software.net/connexion_neocase/SAML/AssertionConsumerService.aspx",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID2TCCAsGgAwIBAgIJAPfTg+MQTPE0MA0GCSqGSIb3DQEBCwUAMIGCMQswCQYD\nVQQGEwJVUzELMAkGA1UECAwCTUExDzANBgNVBAcMBk5ld3RvbjEZMBcGA1UECgwQ\nTmVvY2FzZSBTb2Z0d2FyZTEcMBoGA1UECwwTU2FhUyBBZG1pbmlzdHJhdGlvbjEc\nMBoGA1UEAwwTbmVvY2FzZXNvZnR3YXJlLmNvbTAeFw0xNjAxMDUyMTA1NDdaFw0y\nNjAxMDQyMTA1NDdaMIGCMQswCQYDVQQGEwJVUzELMAkGA1UECAwCTUExDzANBgNV\nBAcMBk5ld3RvbjEZMBcGA1UECgwQTmVvY2FzZSBTb2Z0d2FyZTEcMBoGA1UECwwT\nU2FhUyBBZG1pbmlzdHJhdGlvbjEcMBoGA1UEAwwTbmVvY2FzZXNvZnR3YXJlLmNv\nbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM7XdqdPd3gJj2ow3N9c\nrft+GPEnR9Ff8SNhGxeIug6778pnjCLK90Vs+wFNfKPchFDiKZkvBm/e/wnSFrCC\nRrWcBZXjkS4ejoKWumHE56CGRugJCxxyA3Ez2BhEfaYM9bwqLYDxbSVTAMTMywLl\n257CpOfc+ePTk3ph9+gBLhJ7nk8OuW0NPFK6Nbvn9ozX0eTAs60JTOW0lxnGyTx8\nw19Ni7TX51fUP5XPq0i2yxjBhqDL6lz3P6+kl4ciXVRCHZcB+D8HaJz5VtPSXIsF\nehtjzo2WdaMnmq12kv8BtcrqUjjEby43XuXIg5ijNC/3YOqSC9JfkQJzLVon+rNJ\nQNcCAwEAAaNQME4wHQYDVR0OBBYEFPkmpy2nziy4mpCL9lITpwnlSATpMB8GA1Ud\nIwQYMBaAFPkmpy2nziy4mpCL9lITpwnlSATpMAwGA1UdEwQFMAMBAf8wDQYJKoZI\nhvcNAQELBQADggEBABE4tYVRpgv1GMTVPpVybTrmE6ltK+XOtzdgQxmB9yc2KKYK\nufvstQy4S8IF/7/f8niQUOEt3XTjJyYJAYiM0feO/tk/9r3xhSLNBPoDlnPkL/ce\nGJr6Ol5ROoVI/m5YMXDKo3UrsdgcJ//R/Oiqe4vAQsyTdRtFB8BFZkfZlgjIT+OB\nPsyFdVd0AeqkvbUZkZhNlax0u0AJv2oircEYNiZllrvDOraTBJkfI8fEyEEdYe18\nciAugVZ5HD8JlVy+ARFOaQiqh2UmipYv+T2sFWOaXilbIkL8aPPPsM18xL6/ZE3Y\ng5bEi3lvWxUKBMOgNB+BW/+09dAvBdLuR2JSlaU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PennStateBackoffice"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://dourado.ufs.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rodrigus Oliveira Feitosa"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rodrigus@ufs.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dourado.ufs.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIjCCAgoCAQAwDQYJKoZIhvcNAQEFBQAwVzEoMCYGA1UEChMfVW5pdmVyc2lk\nYWRlIEZlZGVyYWwgZGUgU2VyZ2lwZTEMMAoGA1UECxMDTlRJMQswCQYDVQQGEwJC\nUjEQMA4GA1UEAxMHZG91cmFkbzAeFw0xNTA1MTUxNDI4MDJaFw0xODA1MTQxNDI4\nMDJaMFcxKDAmBgNVBAoTH1VuaXZlcnNpZGFkZSBGZWRlcmFsIGRlIFNlcmdpcGUx\nDDAKBgNVBAsTA05USTELMAkGA1UEBhMCQlIxEDAOBgNVBAMTB2RvdXJhZG8wggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDFff+p/RDQabbgSlBQLdM0vDaf\nqHQcuFVjejHxOuYTYP76mjAovqQfdumR6zWD9cw6X/KsrD+Au/oRnSzSqE0R3dB5\nhPFIj/sIslDJ0YO5kHTGYVzsqdGp5sbIJ3N06+1g3tkk+hW/1pftIU5X4PgCN1WL\n5Ib+kqs7BjPjOPwhnR1VSwGp31WU8KfRihSvBDnQugH51dPIUHm3UeVbPo4cS5/S\npGDO5zbpG5FB6Mj571G71szB3sxU2fGFbcp6xM0ZMLXHmWYHXwPKM05IOgNRan3b\nXtbj0Ca4aMV5xMpx59CeoLBirYwH2/psTkeQbZL7qTAi92oDb5v9Wh5lFNWdAgMB\nAAEwDQYJKoZIhvcNAQEFBQADggEBAKPnwQGVt9Fe3x5FyIp6PXbqmZxvO2vELwNw\nL0w5lrI6p3l1hSTwIfhynEOUBoLnuQOgKa4lNEfe0I5/LRdUVvvvDpWri1DuGEtl\n28xH4m8Buwbs6NOed7zc/6sAi13t1CG1oJ8TgjGHVMH0K3bE+AHE086qLsndxVvf\n6ccAOSBncTRv9xqESUX8tveu5JS5VR4SlRzTUvE+6zDQknLuT7gjuiCOEDX9IOso\nh2KToeZCA4/5zJzRpYL6Yh7m1SVptKtpi9zn+QVPdpZi3cUhWeNE96uifumvXt6M\n4nVAfP2nR1ImFjXDZPD1cf+m1ylSz40jEbkpowOXXiWowojAjbw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufs.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dourado.ufs.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://dourado.ufs.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dourado.ufs.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dourado.ufs.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://dourado.ufs.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dourado.ufs.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dourado.ufs.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://dourado.ufs.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufs.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufs.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufs.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFS - Universidade Federal de Sergipe"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFS - Universidade Federal de Sergipe"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFS - Universidade Federal de Sergipe"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFS - Universidade Federal de Sergipe"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIjCCAgoCAQAwDQYJKoZIhvcNAQEFBQAwVzEoMCYGA1UEChMfVW5pdmVyc2lk\nYWRlIEZlZGVyYWwgZGUgU2VyZ2lwZTEMMAoGA1UECxMDTlRJMQswCQYDVQQGEwJC\nUjEQMA4GA1UEAxMHZG91cmFkbzAeFw0xNTA1MTUxNDI4MDJaFw0xODA1MTQxNDI4\nMDJaMFcxKDAmBgNVBAoTH1VuaXZlcnNpZGFkZSBGZWRlcmFsIGRlIFNlcmdpcGUx\nDDAKBgNVBAsTA05USTELMAkGA1UEBhMCQlIxEDAOBgNVBAMTB2RvdXJhZG8wggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDFff+p/RDQabbgSlBQLdM0vDaf\nqHQcuFVjejHxOuYTYP76mjAovqQfdumR6zWD9cw6X/KsrD+Au/oRnSzSqE0R3dB5\nhPFIj/sIslDJ0YO5kHTGYVzsqdGp5sbIJ3N06+1g3tkk+hW/1pftIU5X4PgCN1WL\n5Ib+kqs7BjPjOPwhnR1VSwGp31WU8KfRihSvBDnQugH51dPIUHm3UeVbPo4cS5/S\npGDO5zbpG5FB6Mj571G71szB3sxU2fGFbcp6xM0ZMLXHmWYHXwPKM05IOgNRan3b\nXtbj0Ca4aMV5xMpx59CeoLBirYwH2/psTkeQbZL7qTAi92oDb5v9Wh5lFNWdAgMB\nAAEwDQYJKoZIhvcNAQEFBQADggEBAKPnwQGVt9Fe3x5FyIp6PXbqmZxvO2vELwNw\nL0w5lrI6p3l1hSTwIfhynEOUBoLnuQOgKa4lNEfe0I5/LRdUVvvvDpWri1DuGEtl\n28xH4m8Buwbs6NOed7zc/6sAi13t1CG1oJ8TgjGHVMH0K3bE+AHE086qLsndxVvf\n6ccAOSBncTRv9xqESUX8tveu5JS5VR4SlRzTUvE+6zDQknLuT7gjuiCOEDX9IOso\nh2KToeZCA4/5zJzRpYL6Yh7m1SVptKtpi9zn+QVPdpZi3cUhWeNE96uifumvXt6M\n4nVAfP2nR1ImFjXDZPD1cf+m1ylSz40jEbkpowOXXiWowojAjbw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFS - Universidade Federal de Sergipe"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFS - Universidade Federal de Sergipe"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufs.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufs.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFS - Universidade Federal de Sergipe"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFS - Universidade Federal de Sergipe"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayf.supportcenter.dk/sska/saml2/idp/metadata.php?unit=sska",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayf.supportcenter.dk/sska/saml2/idp/metadata.php?unit=sska",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2010-08-17T13:59:09Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayf.supportcenter.dk/sska/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sska.itsf.dk"
              },
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "\u00c5rhus Social- og Sundhedsskole"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Aarhus Basic Health Care College"
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u00c5rhus Social- og Sundhedsskole"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Aarhus Basic Health Care College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "sska.itsf.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEDCCAfgCAQcwDQYJKoZIhvcNAQELBQAwTjFMMEoGA1UEAwxDaHR0cHM6Ly93\nYXlmLnN1cHBvcnRjZW50ZXIuZGsvc3NrYS9zYW1sMi9pZHAvbWV0YWRhdGEucGhw\nP3VuaXQ9c3NrYTAeFw0xNTAxMDEwMDAwMDBaFw0yNTEyMzEyMzU5NTlaME4xTDBK\nBgNVBAMMQ2h0dHBzOi8vd2F5Zi5zdXBwb3J0Y2VudGVyLmRrL3Nza2Evc2FtbDIv\naWRwL21ldGFkYXRhLnBocD91bml0PXNza2EwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQDHiAwKahBTuI4Z+IJ1rgOeEiCCy3bR9QIe3BpCsejFCU5rSzkW\nANqVuc1PDfp0JdIZhrPXsmDJQMmidPCGPIDQKo+bk+af3+EUFS/I/+35sSBX2vf+\nh1DHvZV9jsznmpSVjp7HZ/WoPWBykWBJO0AOVmzB5zlaqkS36J76+wxerwdpuExV\nnYSNd73S+AyT/EZ+tXAO+6lQ8FL/YMlJnUkSaSqLSHFy01D2qBNmYRwBpCS6/dUZ\nyxi0t5j8ghKUD4BHOZVavn65J62cJdXiOcMRyUAIp57GXQrL63KtrjIcXddq+CZy\nZ5t37EdUOIz42joFcy73MFOntynlKEvOw1BJAgMBAAEwDQYJKoZIhvcNAQELBQAD\nggEBAAyD1cpJoUahK2bvD9zlY8VfNYMQcEeO5IHwNH4iJMfv9z9vg2xDhF31t3IS\nUeV70zxxdfv2M788QEfPVyDdgYWhA5JPW1GvFqAEUXsg4xmX4XW+y18J7hrLXOkd\n6A1yuoMfctlzAIau4okc00sKCz8MBz+JAD0nnvgsVBbGK5LW2iZduY3epSiboF94\nuG3KAf4qdZjszTkVIuXDT5X4pWens6utwaMchUGiUZJ+Fed8WfNcd6bCwLc75qbI\njgAbEmy59eNPzKOLA/dSKhLyL0/46d9DI4BhkxSb6sahKfFRQxVYxPALYc9Vwm3X\nq1H8RSir+nACRQ/fLPgySCU97iU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u00c5rhus Social- og Sundhedsskole"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Aarhus Basic Health Care College"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sosuaarhus.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sosuaarhus.dk"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u00c5rhus Social- og Sundhedsskole"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Aarhus Basic Health Care College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www-falcon.csx.cam.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:falcon-support@ucs.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Falcon Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:falcon-support@ucs.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Falcon Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www-falcon.csx.cam.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-12-15T15:21:15Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Cambridge: Falcon CMS"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cam.ac.uk/cs/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Cambridge"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www-falcon.csx.cam.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www-falcon.csx.cam.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www-falcon.csx.cam.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www-falcon.csx.cam.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www-falcon.csx.cam.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www-falcon.csx.cam.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www-falcon.csx.cam.ac.uk/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www-falcon.csx.cam.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www-falcon.csx.cam.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAOB8D/FajzX8MA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHd3dy1mYWxjb24uY3N4LmNhbS5hYy51azAeFw0xMDAxMTgxMTAwMDdaFw0y\n\t\t\t\t\t\tMDAxMTYxMTAwMDdaMCMxITAfBgNVBAMTGHd3dy1mYWxjb24uY3N4LmNhbS5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKpU2AuemKJSIeDmgjkZ\n\t\t\t\t\t\ttPgKaPPkM5CKu3QUHm5JzmtnG3UFMxbOumt6sxWWF72ceXQNPgBNGqFI/sFdaCIo\n\t\t\t\t\t\tHxZj+Z2i+k7/IVXhc4wjs72YUfrjvTMDhHHzndm3KkJS8imsIYQ8/bBnJEF93zVJ\n\t\t\t\t\t\tgPYTrX1C8JxqF/wfY/XCGbEqHgJtqDrSEvK+vLF7LaYI4oTotZOg/vhN7uwaEa7n\n\t\t\t\t\t\tGU2+bKuhcAL+rolEM6sbdrQAj3KarTafacfh9IiAclzyOQTA6pfjFWrucNIuWXc4\n\t\t\t\t\t\tYhaEPyOMubMsp+0eXZAwEPTJ61x+nQZd3UAf7Rm5v7agrzRAdqdwpnqb4yyprJlI\n\t\t\t\t\t\t+lkCAwEAAaNGMEQwIwYDVR0RBBwwGoIYd3d3LWZhbGNvbi5jc3guY2FtLmFjLnVr\n\t\t\t\t\t\tMB0GA1UdDgQWBBTz/ES/EvNaSsqqXUxLuIFc9YHi/TANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAAvFTJS2L6StZuqKA935AD3bBOHe5pg+LCF6ydHdTuyWEJYIWBRJ1WXsKMyaG\n\t\t\t\t\t\tyvdlX60XziJARq2UiYxt4yRjuGLAjQl9kNdrlqeb2AJFnA5E1Mt56FtzPiwu2zrC\n\t\t\t\t\t\tTQlklC4Xfie1Yaw2kEVO2vAoRfg9bgSBfyvFC4oR3vCery3Z687oCeQqDp7LPRcn\n\t\t\t\t\t\t+k5qQD8pout57IYzwyo7GPeVkYEPb3GO2KYmoENlDR/xah2VcsTZF7aIsMBFxaPv\n\t\t\t\t\t\tO+oqrQcnQXTviY9yWLbAlSrPPqGNYDxayVHn+zDSO4scLlOoqZJ8iC5NboNKqFyB\n\t\t\t\t\t\tRsenNm/aXp0wIU+jHVmi/GAPCQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www-falcon.csx.cam.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www-falcon.csx.cam.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www-falcon.csx.cam.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www-falcon.csx.cam.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www-falcon.csx.cam.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www-falcon.csx.cam.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www-falcon.csx.cam.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www-falcon.csx.cam.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www-falcon.csx.cam.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www-falcon.csx.cam.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sourcesup.cru.fr/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@renater.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sourcesup.cru.fr/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-01-21T15:50:35Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/collaboratif"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/national"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GIP RENATER"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.renater.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GIP RENATER"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://sourcesup.renater.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SourceSup is a forge hosting development projects for the French HiEd community"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SourceSup est un site d'h\u00e9bergement de projets de d\u00e9veloppement logiciel pour la communaut\u00e9 enseignement sup\u00e9rieur et recherche fran\u00e7aise."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RENATER - software forge for RENATER community"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RENATER - la plateforme SourceSup"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEjCCAfqgAwIBAgIJAOiUbftDbrjWMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\nBAMTGXByb2Qtc291cmNlc3VwLnJlbmF0ZXIuZnIwHhcNMTQxMjE4MTQwNjMyWhcN\nMjQxMjE1MTQwNjMyWjAkMSIwIAYDVQQDExlwcm9kLXNvdXJjZXN1cC5yZW5hdGVy\nLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoDkTHv1kV24iHZz5\nTixIlPuOPUSlOBZHlOVl/FDcWeIXErAtne6s5e7CDuwMCVhc9nFikYz8fXvoHrmL\nxWmeEKFn1HcKX/EFmZzW32lGkt7mVvawFwvA1xhA5UgEeyxMkMUDK9pqAOv8rRrw\nAVqHeae+rTfm3ByRmwrirvu2yX08LzjMTSXaVyofGbRgQBKrtJ+4YgTrznTDbkcI\nljSY5Ia2yA/FyDMNBnCPd0zeAFFN0DDp9yTjYpFcGKPocSgGCxUNTViqi3BP0/QT\nOebHMKy2iPOMPhuraHPtGzfpB2WsNrIj1/MyUDhvSgL8+Jb5EuhzuUW/4Nf7hggI\ngQwmzQIDAQABo0cwRTAkBgNVHREEHTAbghlwcm9kLXNvdXJjZXN1cC5yZW5hdGVy\nLmZyMB0GA1UdDgQWBBT0gDsgE5GBO7ONrYHRLmDGeQj49DANBgkqhkiG9w0BAQUF\nAAOCAQEANXCISKQFikmoLiCTkh9FQb2JH0diznFpyw3bNjwJJMbpa7dRhE3ovbpw\nqFKdTdClvARZqvVrS8H5+vG3TLlw/VaFbadtDWDcrBy9fPar22GButx2QtSDHUN1\n8v6UYlUDc5aYHXP9kHrWe4jQbspUk//ra6kEc/VSTmmRbDEYZRnA1GP+cYh5fK2L\nfGATL7uXdhzPwDjo1kpd9TeuZ1JvWHQqgXgtIG4xnNCLERS0FYT+Hw3sXxyoNmcO\nfHoVLzXiO+cyO8ju79HLsrI28go6UlY+I2nAXmDolYqOwUgjqkXnC9GnX40zZCMw\nCpyHcHTaVxqS+lxgQHejUBXGYLXNSg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEjCCAfqgAwIBAgIJAOiUbftDbrjWMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\nBAMTGXByb2Qtc291cmNlc3VwLnJlbmF0ZXIuZnIwHhcNMTQxMjE4MTQwNjMyWhcN\nMjQxMjE1MTQwNjMyWjAkMSIwIAYDVQQDExlwcm9kLXNvdXJjZXN1cC5yZW5hdGVy\nLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoDkTHv1kV24iHZz5\nTixIlPuOPUSlOBZHlOVl/FDcWeIXErAtne6s5e7CDuwMCVhc9nFikYz8fXvoHrmL\nxWmeEKFn1HcKX/EFmZzW32lGkt7mVvawFwvA1xhA5UgEeyxMkMUDK9pqAOv8rRrw\nAVqHeae+rTfm3ByRmwrirvu2yX08LzjMTSXaVyofGbRgQBKrtJ+4YgTrznTDbkcI\nljSY5Ia2yA/FyDMNBnCPd0zeAFFN0DDp9yTjYpFcGKPocSgGCxUNTViqi3BP0/QT\nOebHMKy2iPOMPhuraHPtGzfpB2WsNrIj1/MyUDhvSgL8+Jb5EuhzuUW/4Nf7hggI\ngQwmzQIDAQABo0cwRTAkBgNVHREEHTAbghlwcm9kLXNvdXJjZXN1cC5yZW5hdGVy\nLmZyMB0GA1UdDgQWBBT0gDsgE5GBO7ONrYHRLmDGeQj49DANBgkqhkiG9w0BAQUF\nAAOCAQEANXCISKQFikmoLiCTkh9FQb2JH0diznFpyw3bNjwJJMbpa7dRhE3ovbpw\nqFKdTdClvARZqvVrS8H5+vG3TLlw/VaFbadtDWDcrBy9fPar22GButx2QtSDHUN1\n8v6UYlUDc5aYHXP9kHrWe4jQbspUk//ra6kEc/VSTmmRbDEYZRnA1GP+cYh5fK2L\nfGATL7uXdhzPwDjo1kpd9TeuZ1JvWHQqgXgtIG4xnNCLERS0FYT+Hw3sXxyoNmcO\nfHoVLzXiO+cyO8ju79HLsrI28go6UlY+I2nAXmDolYqOwUgjqkXnC9GnX40zZCMw\nCpyHcHTaVxqS+lxgQHejUBXGYLXNSg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAKFZlPlWzzteMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFHNvdXJjZXN1cC5yZW5hdGVyLmZyMB4XDTE0MTAxNTE0NTAwMVoXDTI0MTAx\nMjE0NTAwMVowHzEdMBsGA1UEAxMUc291cmNlc3VwLnJlbmF0ZXIuZnIwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDmTMazqkrQ4bXYeC9QVeNhrsGdiblc\nQadYtbfOaXthSjbb+r3jXFUb6TY7/oaHFak+KltcgpzaRMRKicIB81rHBjp3eaXz\nAB1kBU1goo7qznlODkyTso3wftIstcXF8SEZGB5jHTBcZloZsNVJEO9ZsUDNfiI6\nZBjvgKxKuhfMaH2rsIuv+ioOyTtsIyKq0OWSI4zcVranZw8/rctYRJ3uOH0VJ49u\nPKVteO2gp5vC+y1gDA1WnFfSi13IUwqk0IQliDPX53kV267M+Zk6GpbL2GJMu2lg\n8jdaa7+r739i0EoUk7qwHBqVNnT2M8Gu1a3ipxK4HduUKGYD1ynfkzGVAgMBAAGj\nQjBAMB8GA1UdEQQYMBaCFHNvdXJjZXN1cC5yZW5hdGVyLmZyMB0GA1UdDgQWBBQK\nFmZfmEm0YVmRRt+HIA11jgYFIzANBgkqhkiG9w0BAQUFAAOCAQEAeGrTotOtswlQ\nftuvhhyLALdVDNXSner08S2A51MbI97REIYpvBmGPzWpcBY0mTnI4YHExtgMjcis\nS5lWSg6a8WZgABRIGJpaOMzUrp6LToRyL0qWpcSR91nUZum6gHaZKfuNc3q7n4C7\nQW4WCvzD+mT2H+gVFpkcmkFsViZ+jWJPzNhmY6O5YZolcF9dhAz9hBSTbCRqhOjo\niqiun1xo89/hxIYaIvlQpRAXlmykiBs8DeEooIP9KiUPhloaEcFkfx73JqT59b6/\nQ6I7TVBscvDAl+9Q9oB9akTeqhktBupWmJUgOxqeFOPlorir8ezn/AX+WSwZ9fPo\n6e4sAmYv7w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sourcesup.renater.fr/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sourcesup.renater.fr/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "RENATER - la plateforme SourceSup"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "RENATER - software forge for RENATER community"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "SourceSup est un site d'h\u00e9bergement de projets de d\u00e9veloppement logiciel pour la communaut\u00e9 enseignement sup\u00e9rieur et recherche fran\u00e7aise."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "SourceSup is a forge hosting development projects for the French HiEd community"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.eusa.ed.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.eusa.ed.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Edinburgh University Students Association"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eusa.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.eusa.ed.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.eusa.ed.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.eusa.ed.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.eusa.ed.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.eusa.ed.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.eusa.ed.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.eusa.ed.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.eusa.ed.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.eusa.ed.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.eusa.ed.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.eusa.ed.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.eusa.ed.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.eusa.ed.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.eusa.ed.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.eusa.ed.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.goucher.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rpfeffer@goucher.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rob Pfeffer"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rpfeffer@goucher.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rob Pfeffer"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.goucher.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.goucher.edu:9443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.goucher.edu:9443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAigCCQD9EXATFfpNHTANBgkqhkiG9w0BAQUFADBiMRgwFgYDVQQDDA9p\nZHAuZ291Y2hlci5lZHUxGDAWBgNVBAoMD0dvdWNoZXIgQ29sbGVnZTELMAkGA1UE\nBhMCVVMxCzAJBgNVBAgMAk1EMRIwEAYDVQQHDAlCYWx0aW1vcmUwHhcNMTIwMjAy\nMTg0MDMwWhcNMTMwMjAxMTg0MDMwWjBiMRgwFgYDVQQDDA9pZHAuZ291Y2hlci5l\nZHUxGDAWBgNVBAoMD0dvdWNoZXIgQ29sbGVnZTELMAkGA1UEBhMCVVMxCzAJBgNV\nBAgMAk1EMRIwEAYDVQQHDAlCYWx0aW1vcmUwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQDGCDPliCbx4QcxYEVBjwMRd/4R6L1LcZ21PIBu9qKlfJTp+44p\nRMFFQkvHQgtQnWKBSMK39vG6H7+wBFIdFfavxT9DcPkiqvoe7++VyYm2VWZt6HCQ\ncYK5Nwg2AGOIodIIpwncUJhnHNJ8YHKkdwwFcexEKrcvurTMok1BYlGsr6uX5p0C\nooZmsdX7sffjSiZI0+/kZgI0gSQOjk6hGyY1QZz47q3aTbAn63eZv9zbwLqdBtr3\nmQGDtZ6C0N7Z8H2PiMgeKHqXXHna+XEVk1/lZjVJbLf0x1og8RgvDmXvFyE7hmxE\ndmljVWwHsKWzfaWYX0WTgO5D6+vNQopqoOPdAgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBAE1hv6gGPVcFulSyyNpmBd8hPZUI4Ibnqc7dBFgCdljB6jrBj+6iEE3pd0eW\nbEDAlpT9kyNweZY0qjzKK2gvjMAUTcGUo/W8Nfmoi8py07GZYdBglNIL69xY1qoe\n0rltvb47yAL+1A6eeBGlgsj5/o9wkV1fXOJ7ojKV2S7CbTJpgr1MdWSrTSI3+Jwl\niCflXm96nzl+CxorqVb0yJB2jmRd6WAAOunl4dIL8J7lkkrqBv42TaKExkUcf3eT\nyosKfff3G3KPsQzaU1kDWVGhbhS322uy7gjy929RALCmoUD6QQXRidkRYacCMHXC\noL1bvJlGv+az8jFu7bFvQ6WA7Lc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDhDCCAmwCCQDipYp7QAFE6DANBgkqhkiG9w0BAQUFADCBgzELMAkGA1UEBhMC\nVVMxCzAJBgNVBAgMAk1EMRIwEAYDVQQHDAlCYWx0aW1vcmUxGDAWBgNVBAoMD0dv\ndWNoZXIgQ29sbGVnZTEfMB0GA1UECwwWSW5mb3JtYXRpb24gVGVjaG5vbG9neTEY\nMBYGA1UEAwwPaWRwLmdvdWNoZXIuZWR1MB4XDTEzMDExNjE2MjI0MVoXDTIzMDEx\nNDE2MjI0MVowgYMxCzAJBgNVBAYTAlVTMQswCQYDVQQIDAJNRDESMBAGA1UEBwwJ\nQmFsdGltb3JlMRgwFgYDVQQKDA9Hb3VjaGVyIENvbGxlZ2UxHzAdBgNVBAsMFklu\nZm9ybWF0aW9uIFRlY2hub2xvZ3kxGDAWBgNVBAMMD2lkcC5nb3VjaGVyLmVkdTCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALelEr2mpG/5wjI/aR2JgfEz\njwrfenWU3A9yqS0bsNI1Y9lVoAe0vIyqTC1glkcEApIHUVumFpbrmmJQngt84l+C\nuz/n1bHELjM0oRJ0rIxhPrEiiLX8HabCOWPtXNUAQgJUSw+xjoOwEJfYRXDkcSQQ\n1S2GKvDTGDZhBOG2Ov4OjVyRQkMQO/aOBjd8VZKthlMBGUg6yD2AklIRUBuPOEN4\nmyOk2fWHttPNSj7cfcTnSszLPrYOE7bHOSYILnDcu4lbTjnR3EqkrtSzXligebKJ\nhxqFYf0caTEu+RMPKttHdEf7u4j2G6i+6euj7yWnbYDs7piFKsl0TFnEUWpaGR0C\nAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAdgn6vRTI37/8+I8I5+9yrUXqU6aVftp8\nP53nVPUB41JeZUb3Dfj1Mswg51DY99LT+xAh1oxDKNUzrnXr2af8YIFQ0N2rNV55\n1LODkspwP5kYzyT5cyINEsfUs4wqjwMI65RYeOwd14adVcUMFFyedlSsoIWyzrO1\nucIe40Y2h8mhtRsWqMH8e220dYf2QMueJo7zt9xruOUTT7Jn+mGQUtH2tYlhOREU\nD6X8ax3ngFyLz8Cte0qDYPQpZU93xd8tuQTWRBeGA+AxJMQ3/Gn78uKZJDNUqdhf\nU9RfcD99MmNTz6iedYMFbAIs1113GJVjiRe15qyz74tLxexzwiPxXA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "goucher.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.goucher.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.goucher.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.goucher.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.goucher.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.goucher.edu:9443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.goucher.edu:9443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "goucher.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Goucher College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAigCCQD9EXATFfpNHTANBgkqhkiG9w0BAQUFADBiMRgwFgYDVQQDDA9p\nZHAuZ291Y2hlci5lZHUxGDAWBgNVBAoMD0dvdWNoZXIgQ29sbGVnZTELMAkGA1UE\nBhMCVVMxCzAJBgNVBAgMAk1EMRIwEAYDVQQHDAlCYWx0aW1vcmUwHhcNMTIwMjAy\nMTg0MDMwWhcNMTMwMjAxMTg0MDMwWjBiMRgwFgYDVQQDDA9pZHAuZ291Y2hlci5l\nZHUxGDAWBgNVBAoMD0dvdWNoZXIgQ29sbGVnZTELMAkGA1UEBhMCVVMxCzAJBgNV\nBAgMAk1EMRIwEAYDVQQHDAlCYWx0aW1vcmUwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQDGCDPliCbx4QcxYEVBjwMRd/4R6L1LcZ21PIBu9qKlfJTp+44p\nRMFFQkvHQgtQnWKBSMK39vG6H7+wBFIdFfavxT9DcPkiqvoe7++VyYm2VWZt6HCQ\ncYK5Nwg2AGOIodIIpwncUJhnHNJ8YHKkdwwFcexEKrcvurTMok1BYlGsr6uX5p0C\nooZmsdX7sffjSiZI0+/kZgI0gSQOjk6hGyY1QZz47q3aTbAn63eZv9zbwLqdBtr3\nmQGDtZ6C0N7Z8H2PiMgeKHqXXHna+XEVk1/lZjVJbLf0x1og8RgvDmXvFyE7hmxE\ndmljVWwHsKWzfaWYX0WTgO5D6+vNQopqoOPdAgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBAE1hv6gGPVcFulSyyNpmBd8hPZUI4Ibnqc7dBFgCdljB6jrBj+6iEE3pd0eW\nbEDAlpT9kyNweZY0qjzKK2gvjMAUTcGUo/W8Nfmoi8py07GZYdBglNIL69xY1qoe\n0rltvb47yAL+1A6eeBGlgsj5/o9wkV1fXOJ7ojKV2S7CbTJpgr1MdWSrTSI3+Jwl\niCflXm96nzl+CxorqVb0yJB2jmRd6WAAOunl4dIL8J7lkkrqBv42TaKExkUcf3eT\nyosKfff3G3KPsQzaU1kDWVGhbhS322uy7gjy929RALCmoUD6QQXRidkRYacCMHXC\noL1bvJlGv+az8jFu7bFvQ6WA7Lc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDhDCCAmwCCQDipYp7QAFE6DANBgkqhkiG9w0BAQUFADCBgzELMAkGA1UEBhMC\nVVMxCzAJBgNVBAgMAk1EMRIwEAYDVQQHDAlCYWx0aW1vcmUxGDAWBgNVBAoMD0dv\ndWNoZXIgQ29sbGVnZTEfMB0GA1UECwwWSW5mb3JtYXRpb24gVGVjaG5vbG9neTEY\nMBYGA1UEAwwPaWRwLmdvdWNoZXIuZWR1MB4XDTEzMDExNjE2MjI0MVoXDTIzMDEx\nNDE2MjI0MVowgYMxCzAJBgNVBAYTAlVTMQswCQYDVQQIDAJNRDESMBAGA1UEBwwJ\nQmFsdGltb3JlMRgwFgYDVQQKDA9Hb3VjaGVyIENvbGxlZ2UxHzAdBgNVBAsMFklu\nZm9ybWF0aW9uIFRlY2hub2xvZ3kxGDAWBgNVBAMMD2lkcC5nb3VjaGVyLmVkdTCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALelEr2mpG/5wjI/aR2JgfEz\njwrfenWU3A9yqS0bsNI1Y9lVoAe0vIyqTC1glkcEApIHUVumFpbrmmJQngt84l+C\nuz/n1bHELjM0oRJ0rIxhPrEiiLX8HabCOWPtXNUAQgJUSw+xjoOwEJfYRXDkcSQQ\n1S2GKvDTGDZhBOG2Ov4OjVyRQkMQO/aOBjd8VZKthlMBGUg6yD2AklIRUBuPOEN4\nmyOk2fWHttPNSj7cfcTnSszLPrYOE7bHOSYILnDcu4lbTjnR3EqkrtSzXligebKJ\nhxqFYf0caTEu+RMPKttHdEf7u4j2G6i+6euj7yWnbYDs7piFKsl0TFnEUWpaGR0C\nAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAdgn6vRTI37/8+I8I5+9yrUXqU6aVftp8\nP53nVPUB41JeZUb3Dfj1Mswg51DY99LT+xAh1oxDKNUzrnXr2af8YIFQ0N2rNV55\n1LODkspwP5kYzyT5cyINEsfUs4wqjwMI65RYeOwd14adVcUMFFyedlSsoIWyzrO1\nucIe40Y2h8mhtRsWqMH8e220dYf2QMueJo7zt9xruOUTT7Jn+mGQUtH2tYlhOREU\nD6X8ax3ngFyLz8Cte0qDYPQpZU93xd8tuQTWRBeGA+AxJMQ3/Gn78uKZJDNUqdhf\nU9RfcD99MmNTz6iedYMFbAIs1113GJVjiRe15qyz74tLxexzwiPxXA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Goucher College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://goucher.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Goucher College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://play.gu.se",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "saml_admin@kaltura.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://play.gu.se",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GU Play"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://play.gu.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GU Play"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://play.gu.se/user/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is the University of Gothenburg's streaming service."
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Detta \u00e4r G\u00f6teborgs universitets play tj\u00e4nst"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Gothenburg Play service"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "G\u00f6teborgs universitets Play tj\u00e4nst"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.gu.se/user/authenticate",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://adfs.philau.edu/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "oit-networking-d@philau.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Network and Systems"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@philau.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technology Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "oit-networking-d@philau.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Network and Systems"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs.philau.edu/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://adfs.philau.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://adfs.philau.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://adfs.philau.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://adfs.philau.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://adfs.philau.edu/adfs/services/trust/artifactresolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "philau.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.philau.edu/oir/Policies/incommonfederation.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Philadelphia University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Philadelphia University"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.philau.edu/inc/img/img_footer_logo.png",
                    "lang": "en",
                    "height": "126",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "134"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.philau.edu/oir/Policies/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC2jCCAcKgAwIBAgIQRHBN4pvQap1LpNI5geCgczANBgkqhkiG9w0BAQsFADAp\nMScwJQYDVQQDEx5BREZTIFNpZ25pbmcgLSBhZGZzLnBoaWxhdS5lZHUwHhcNMTUw\nMjAyMDIwMjU1WhcNMjAwMjAxMDIwMjU1WjApMScwJQYDVQQDEx5BREZTIFNpZ25p\nbmcgLSBhZGZzLnBoaWxhdS5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQCyDfbSvl30ofeRv7AQCChNRyfpvYhODupt5S+3ymHdartBHiDJkM5J1aNL\nvFs+7a5tb0GCbJReByokNWxPtdkqStD+/0NLXv6VnFB67IlT0xctB0J1IxkLkXAF\nT/FSNLvuoSlsD4FXV9p1Q1HjjTE5udOLYsSHtef2RXfsiLv0LPBOO794tkzZ4ozt\nD1kF/bgTeYpeyR/kfNCi0m7Dn+/oJix4wV/UHxFP+K6VoHvHui08qxOHmnea/0/H\nLR96u2Us7kNxt1mfv4jecyXawfXS6ndzui6MFtZIh9OJzc7/82hWTNkV7mWxeK4G\n/p+hBHoDY984EyY8mKn3aPCVDTEPAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAKdX\n8Sft+u4OQCSxo1SuM+AIL0/vNzBseLzqmOQPGwGAx6TFz/wQt3/qH5BcOtYLDroC\nVBoq97NnYqoXTCi+R7yG0Is7/i0TQiuApsMwiXzcI2ZBreLuzxdAidZQYR94OQm7\nofXKfQ/ZlicsXvOg27h1W9KCqfnzPLTP+UsK4/BXMKUrdzJKl3Hrzw6CIF+6QWyl\nYWUwwDqL9m2mXXhKQGblwaU2yUC2pEdOextItEHMexD6qkSi0ALnEN9NLk6yrxT5\n6BZR18jVlYvNQRLTkzfplNmb8GWM/xYoTs4eJKFx2TMRbRBk1PtMV7+0ZGgFCFZ2\nCvcd3WYYf9glQNGfltI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Philadelphia University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.philau.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Philadelphia University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://rns.aai.niif.hu/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NIIFI AAI"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@niif.hu"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NIIFI AAI"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@niif.hu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NIIFI AAI"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@niif.hu"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://rns.aai.niif.hu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NIIF - Nemzeti Inform\u00e1ci\u00f3s Infrastrukt\u00fara Fejleszt\u00e9si Int\u00e9zet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NIIF Institute - National Information Infrastructure Development"
          }
        ],
        "organization_url": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.niif.hu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.niif.hu/en"
          }
        ],
        "organization_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NIIF - Nemzeti Inform\u00e1ci\u00f3s Infrastrukt\u00fara Fejleszt\u00e9si Int\u00e9zet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NIIF Institute - National Information Infrastructure Development"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://rns.aai.niif.hu/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://rns.aai.niif.hu/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://rns.aai.niif.hu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://rns.aai.niif.hu/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://earc.eduid.hu/"
                  }
                ],
                "description": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SP for eduGAIN attribute release checker - r&s"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SP for eduGAIN attribute release checker - r&s"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://earc.eduid.hu/privacy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SP for eduGAIN attribute release checker - r&s"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SP for eduGAIN attribute release checker - r&s"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "rns.aai.niif.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://rns.aai.niif.hu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://rns.aai.niif.hu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://rns.aai.niif.hu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://rns.aai.niif.hu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "hu",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SP for eduGAIN attribute release checker - r&s"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SP for eduGAIN attribute release checker - r&s"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ensma.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Edouard MOREAU"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "edouard.moreau@ensma.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Patrice ALLARY"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "patrice.allary@ensma.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ensma.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-12-05T14:28:28Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ensma.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ensma.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ensma.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ensma.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ensma.fr"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENSMA - Ecole Nationale Sup\u00e9rieure de M\u00e9canique et d'A\u00e9rotechnique"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENSMA - Ecole Nationale Sup\u00e9rieure de M\u00e9canique et d'A\u00e9rotechnique"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAONDoCnsNCIcCqPLaGuGULtVfBEkMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDGlkcC5lbnNtYS5mcjAeFw0xMzA5MDMxNTMzNDlaFw0z\nMzA5MDMxNTMzNDlaMBcxFTATBgNVBAMTDGlkcC5lbnNtYS5mcjCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBANogeeITK3rs1Zr84TOyih09tiR3YRSUNJ9A\n+Zy0IIcIk4qo8XA8j6IVUcjFcWJ6pg/Dted7Sc8O/FF9PGfPROPkWZiV6PVGtfYX\nfQR2x5w7ZrtBNIX5np+b5HlHgQQ8k4RfUmXbG6LolvBb5cHrgtHcdK7fHD2119J2\nsXN/JcF0ybdCJuRdvE05lPMVjMtgBd0Q6OovJBbJDQ6idEJj0j2yxf6jfqDEQaO1\nonzunPr65wMxBqYxhE1q8OC6uymLGwWfboKbPFwrxP5sa53UXHlMuvd7UPEG4mSQ\nVNZnwkGxIWU/RfuBi2mcRVKHP2CwhsPxQXJCFhc/nFELtsqm9/sCAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMaWRwLmVuc21hLmZyhiNodHRwczovL2lkcC5lbnNtYS5mci9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUuIffU6QF5T/auaaGjizZ2SlOp8cwDQYJ\nKoZIhvcNAQEFBQADggEBAKmtZ8NR9PcNGoFqlyD2oWq6FtufoSD7zOs8eaPJfaOa\nZA1m7QwZ0znQnO2eU7d4+2eMtuHRW2g7zYNyRglX1CrkJLAtnOMue/cvWHtj1I42\nj+8FkTeCD1YKFjuXJz28GAivPF77ddBADJny1s+KW5SgNcqi2mpQ+S2wVglyTsJZ\nE02BPdMEqjjPsPpcO7B0HfPQfTk75REehiQGC/i5lR1OJ/9orUpJ8kc/YxOngp0I\n5tAzXV2kr8vn71UxzT2V9Le8UTrbtj4pIusrH7ngHOOt1W733OwN5JJE8iAozyVN\nLsxS0mdANFdLn6+QSsxJcvgWdJIwcB6mBawpewLxXmw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ENSMA - Ecole Nationale Sup\u00e9rieure de M\u00e9canique et d'A\u00e9rotechnique"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ensma.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ENSMA - Ecole Nationale Sup\u00e9rieure de M\u00e9canique et d'A\u00e9rotechnique"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://epoq.compilatio.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ent@compilatio.net"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://epoq.compilatio.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-02-24T11:36:09Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/collaboratif"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/local"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "COMPILATIO"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.compilatio.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "COMPILATIO"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://epoq.compilatio.net/shibboleth"
                  }
                ],
                "description": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Service payant d'analyse de document en ligne mis \u00e0 la disposition de l'enseignement sup\u00e9rieur et permettant la d\u00e9tection de plagiat dans les travaux \u00e9tudiants ..."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Compilatio - Pr\u00e9vention du plagiat"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Compilatio - Pr\u00e9vention du plagiat"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPjCCAiYCCQDLkvKzyxmCozANBgkqhkiG9w0BAQsFADBgMQswCQYDVQQGEwJG\nUjEUMBIGA1UEBwwLU2FpbnQgRmVsaXgxEzARBgNVBAoMCkNvbXBpbGF0aW8xCzAJ\nBgNVBAsMAklUMRkwFwYDVQQDDBAqLmNvbXBpbGF0aW8ubmV0MCAXDTE1MTAwMTE0\nNTIyNloYDzIxMTUwOTA3MTQ1MjI2WjBgMQswCQYDVQQGEwJGUjEUMBIGA1UEBwwL\nU2FpbnQgRmVsaXgxEzARBgNVBAoMCkNvbXBpbGF0aW8xCzAJBgNVBAsMAklUMRkw\nFwYDVQQDDBAqLmNvbXBpbGF0aW8ubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEAxU1Kzma74qazOCj/66wzcyZHB7XtSgIFEw1LtLq/9OA5efe/5yL6\nnK6H0pZoEpWGDLSzQkQJFP1OlozStQAAf/U0N5mWY5JUqwJce+Y58bA7jg2JIDp8\nzPDvKMJ3izkeJUxBdYiV6aZW3aRjt22tTlxlXgU3wovicu+acSY9YAZLMWkvNoVH\nfNTmXZA8rzMif2qPSHnv2HIu+vUiTmD39BPxHfbunvCjmmFZWM2fO/QEyG2n4/Yu\nttEzNd9yhU7t++KFiK+D1vlCbRRnjffyhQfEhcj6zauCDtfOzadtO+LzMSdS+g/B\n3mx2ic9ixgC0ml2Mw7De29XHzcbhcYuD/wIDAQABMA0GCSqGSIb3DQEBCwUAA4IB\nAQASeEiw1b+IblGOSrqTaJhCHmkOTKpaVl5+ARTc4J1f1zWZm6gmf2mGSJZthlsn\ni+MjdeE6mHsX0B4ZRQdyEXaj2d90lnJXQ3Hy4YUht1T3Q+rm4+DPIKpCLZxIYMXW\nCGD9S73G7vS1npUIP0g5TAk808UzaYDPtbTKsTk7YNnvlr7o1aJLBq4EGURHzwKs\nur5AvNBhBVh3NqjhsDb5JzYkgncMR0jhlF79yeUQ0hJN3dsArkRW8hfFKkmMg/vV\nb3MlBBOGsobwQbkN5sUxaZF1vPtLD0THGTJDUYY4F3bySOFBaxIhORL8fiHKQr9J\n4oI8R2FqqBAcrToXFmQESE/i"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPjCCAiYCCQDLkvKzyxmCozANBgkqhkiG9w0BAQsFADBgMQswCQYDVQQGEwJG\nUjEUMBIGA1UEBwwLU2FpbnQgRmVsaXgxEzARBgNVBAoMCkNvbXBpbGF0aW8xCzAJ\nBgNVBAsMAklUMRkwFwYDVQQDDBAqLmNvbXBpbGF0aW8ubmV0MCAXDTE1MTAwMTE0\nNTIyNloYDzIxMTUwOTA3MTQ1MjI2WjBgMQswCQYDVQQGEwJGUjEUMBIGA1UEBwwL\nU2FpbnQgRmVsaXgxEzARBgNVBAoMCkNvbXBpbGF0aW8xCzAJBgNVBAsMAklUMRkw\nFwYDVQQDDBAqLmNvbXBpbGF0aW8ubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEAxU1Kzma74qazOCj/66wzcyZHB7XtSgIFEw1LtLq/9OA5efe/5yL6\nnK6H0pZoEpWGDLSzQkQJFP1OlozStQAAf/U0N5mWY5JUqwJce+Y58bA7jg2JIDp8\nzPDvKMJ3izkeJUxBdYiV6aZW3aRjt22tTlxlXgU3wovicu+acSY9YAZLMWkvNoVH\nfNTmXZA8rzMif2qPSHnv2HIu+vUiTmD39BPxHfbunvCjmmFZWM2fO/QEyG2n4/Yu\nttEzNd9yhU7t++KFiK+D1vlCbRRnjffyhQfEhcj6zauCDtfOzadtO+LzMSdS+g/B\n3mx2ic9ixgC0ml2Mw7De29XHzcbhcYuD/wIDAQABMA0GCSqGSIb3DQEBCwUAA4IB\nAQASeEiw1b+IblGOSrqTaJhCHmkOTKpaVl5+ARTc4J1f1zWZm6gmf2mGSJZthlsn\ni+MjdeE6mHsX0B4ZRQdyEXaj2d90lnJXQ3Hy4YUht1T3Q+rm4+DPIKpCLZxIYMXW\nCGD9S73G7vS1npUIP0g5TAk808UzaYDPtbTKsTk7YNnvlr7o1aJLBq4EGURHzwKs\nur5AvNBhBVh3NqjhsDb5JzYkgncMR0jhlF79yeUQ0hJN3dsArkRW8hfFKkmMg/vV\nb3MlBBOGsobwQbkN5sUxaZF1vPtLD0THGTJDUYY4F3bySOFBaxIhORL8fiHKQr9J\n4oI8R2FqqBAcrToXFmQESE/i"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFNjCCBB6gAwIBAgIDEF5UMA0GCSqGSIb3DQEBCwUAMDwxCzAJBgNVBAYTAlVT\nMRcwFQYDVQQKEw5HZW9UcnVzdCwgSW5jLjEUMBIGA1UEAxMLUmFwaWRTU0wgQ0Ew\nHhcNMTQwMTI4MDM0MzI2WhcNMTYwMjI5MTgwMDU1WjCBvzEpMCcGA1UEBRMgOW5L\nLXA1Zkpsam1leVg1aXREZTFMS2VnTHB1WWJtVUQxEzARBgNVBAsTCkdUMjgzMzcw\nOTIxMTAvBgNVBAsTKFNlZSB3d3cucmFwaWRzc2wuY29tL3Jlc291cmNlcy9jcHMg\nKGMpMTQxLzAtBgNVBAsTJkRvbWFpbiBDb250cm9sIFZhbGlkYXRlZCAtIFJhcGlk\nU1NMKFIpMRkwFwYDVQQDDBAqLmNvbXBpbGF0aW8ubmV0MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAxU1Kzma74qazOCj/66wzcyZHB7XtSgIFEw1LtLq/\n9OA5efe/5yL6nK6H0pZoEpWGDLSzQkQJFP1OlozStQAAf/U0N5mWY5JUqwJce+Y5\n8bA7jg2JIDp8zPDvKMJ3izkeJUxBdYiV6aZW3aRjt22tTlxlXgU3wovicu+acSY9\nYAZLMWkvNoVHfNTmXZA8rzMif2qPSHnv2HIu+vUiTmD39BPxHfbunvCjmmFZWM2f\nO/QEyG2n4/YuttEzNd9yhU7t++KFiK+D1vlCbRRnjffyhQfEhcj6zauCDtfOzadt\nO+LzMSdS+g/B3mx2ic9ixgC0ml2Mw7De29XHzcbhcYuD/wIDAQABo4IBuzCCAbcw\nHwYDVR0jBBgwFoAUa2k9ahhCSt2PAmU5/TUkhniRFjAwDgYDVR0PAQH/BAQDAgWg\nMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjArBgNVHREEJDAighAqLmNv\nbXBpbGF0aW8ubmV0gg5jb21waWxhdGlvLm5ldDBDBgNVHR8EPDA6MDigNqA0hjJo\ndHRwOi8vcmFwaWRzc2wtY3JsLmdlb3RydXN0LmNvbS9jcmxzL3JhcGlkc3NsLmNy\nbDAdBgNVHQ4EFgQURW26V/eSqhDZz4+cUahkSIp9/XgwDAYDVR0TAQH/BAIwADB4\nBggrBgEFBQcBAQRsMGowLQYIKwYBBQUHMAGGIWh0dHA6Ly9yYXBpZHNzbC1vY3Nw\nLmdlb3RydXN0LmNvbTA5BggrBgEFBQcwAoYtaHR0cDovL3JhcGlkc3NsLWFpYS5n\nZW90cnVzdC5jb20vcmFwaWRzc2wuY3J0MEwGA1UdIARFMEMwQQYKYIZIAYb4RQEH\nNjAzMDEGCCsGAQUFBwIBFiVodHRwOi8vd3d3Lmdlb3RydXN0LmNvbS9yZXNvdXJj\nZXMvY3BzMA0GCSqGSIb3DQEBCwUAA4IBAQAXnQ0EXVz77PiovvYKBMjktoylywL0\nhHKQDl//Uogoq9bTLvp91pfTMagvmGBZwL5l+9CPtal+yJc6ogh2cCjddqWleSAQ\nF2ikd/QRMXaolcSNofFG9M+cmJHPmhFIJPOOqHdfTbcaM54swrgdEXhsKCd56t3X\nhUSa267XqAf+UgSVXa5/9+7niYKbPm6S7ENEdzmJBjzC6xZ3o0IpncmQpC1cPNOy\nv6m7bak466pL1Vevz4zJrf1D/GO7tuEr1UKaACEO7dN9s48BIszFS876vdltnwqo\n6Y+OhZYur/8jg4W7AsT50u4Nm1YhbT4O+wl3P1dAZTirIjdcLJPi1Igc"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://epoq.compilatio.net/shibboleth/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://epoq.compilatio.net/shibboleth/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Compilatio - Pr\u00e9vention du plagiat"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Service payant d'analyse de document en ligne mis \u00e0 la disposition de l'enseignement sup\u00e9rieur et permettant la d\u00e9tection de plagiat dans les travaux \u00e9tudiants ..."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrimaryAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.5",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "supannEntiteAffectationPrincipale",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.7135.1.2.1.13",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "supannEtablissement",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.7135.1.2.1.14",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "supannOrganisme",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.7135.1.2.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "supannEntiteAffectation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.7135.1.2.1.8",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "http://idp.chalmers.se/adfs/services/trust",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 31 772 8658"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT-system"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:biorn@chalmers.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Chalmers"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 31 772 6000"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT-support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@chalmers.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Chalmers"
          }
        }
      ],
      "entity_id": "http://idp.chalmers.se/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oasis:names:tc:SAML:attribute:assurance-certification",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.chalmers.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.chalmers.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.chalmers.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.chalmers.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.chalmers.se/adfs/services/trust/artifactresolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "chalmers.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.chalmers.se/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.chalmers.se/en/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r Chalmers"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Chalmers"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Chalmers"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Chalmers"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "chalmers.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:57.6899722,11.9774444"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "129.16.0.0/16"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute": [
            {
              "friendly_name": "E-Mail Address",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/emailaddress",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Given Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/givenname",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/name",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "UPN",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/upn",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Common Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/CommonName",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "AD FS 1.x E-Mail Address",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/EmailAddress",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Group",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/Group",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "AD FS 1.x UPN",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/UPN",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Role",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/role",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Surname",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/surname",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "PPID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/privatepersonalidentifier",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Name ID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/nameidentifier",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Authentication time stamp",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/authenticationinstant",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Authentication method",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/authenticationmethod",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Deny only group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/denyonlysid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Deny only primary SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/denyonlyprimarysid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Deny only primary group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/denyonlyprimarygroupsid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/groupsid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Primary group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/primarygroupsid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Primary SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/primarysid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Windows account name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/windowsaccountname",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            }
          ],
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Chalmers"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Chalmers"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.chalmers.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CHALMERS"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.chalmers.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.chalmers.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://idp.chalmers.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://idp.chalmers.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.chalmers.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://umbrella.psi.ch/",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41563103509"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Abt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:bjoern.abt@psi.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bj\u00f6rn"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41563103509"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Abt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:bjoern.abt@psi.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bj\u00f6rn"
          }
        }
      ],
      "entity_id": "https://umbrella.psi.ch/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2014-03-18T09:41:16Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "friendly_name": "swissEduPersonHomeOrganization",
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "psi.ch"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:2.16.756.1.2.5.1.1.4",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "friendly_name": "swissEduPersonHomeOrganizationType",
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "others"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:2.16.756.1.2.5.1.1.5",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PSI - Paul Scherrer Institut"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PSI - Paul Scherrer Institute"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.psi.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.psi.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "psi.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Umbrella Test Service Provider for developing  bridging between eduGain and Umbrella Federation"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Umbrella Test Service Provider"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJAPuvSPAzAC6mMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD3VtYnJlbGxhLnBzaS5jaDAeFw0xMzExMjgxMDQ2MjBaFw0xNjExMjcxMDQ2\nMjBaMBoxGDAWBgNVBAMTD3VtYnJlbGxhLnBzaS5jaDCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAMHaKoQKIBkNpDp0I5R2yZ7uy2WShKsDm9IMxz+D0EzL\nS7k/KCKIt15E6iksEvy6KhKQUmHDjx0T/W9D+hZkAj3NaSytBCB3phGrMUFSotw9\n/GSt0e/C4x0Bju/SD5OwLOAX5QvMJllMlkGTUXQ+T6LcNBcA5kSL/jza2vssAOC0\n9vz0zK7uAxGG2/IrZ55UGL6RFB5lV4m+45DLjd/bnmk0KzPDbfCgpnq+kc4NUFov\nECrZUJ+CkOUdS6x+Jg4wsUyYWHAMA77JoQtJUWYzLMlaN/hfWoIwsG049Wp20+w3\naxkrc0u/Bd+YQB2e66sv+gzMfpxkoxs78qv9uJGaNo0CAwEAAaNhMF8wPgYDVR0R\nBDcwNYIPdW1icmVsbGEucHNpLmNohiJodHRwczovL3VtYnJlbGxhLnBzaS5jaC9z\naGliYm9sZXRoMB0GA1UdDgQWBBSycOrbvoq6pE/JYBQQAso92I6NXDANBgkqhkiG\n9w0BAQUFAAOCAQEAfarU3Y9Fi2+2Om89eMvkGB/29lZZnR+7w78sVyu6dZlMcJzT\nSJPNQXVbqAJfPEQLmSxBXxVwvoqEJH80c95xjt59p3CMuXKMxGZ+elpCin9fePrP\npDkU/CXfNNSU1OIZnSttk6Yh6uQ814ZtxqZES1zDP63Ajm/aM9L2mrxD1UJ2OWAh\nRMaDxuEU6fZCZk9ej8os9Kf2k5XmJ8x5v9cJJ3dXFxEz7tGhb7wMSBlFIsdt+j3l\nmB0SSH6Wh64W+Tkwp4HES9XCdEWbuSeJEO+0MEC8kBR13YlXLIsGU95Q5694eeun\njXaHZDgEhAR+tFkQFgpQhGcJTs1bLugCxSjdrA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://umbrella.psi.ch/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://umbrella.psi.ch/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://umbrella.psi.ch/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://umbrella.psi.ch/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://umbrella.psi.ch/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://umbrella.psi.ch/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Umbrella Test Service Provider"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Umbrella Test Service Provider for developing  bridging between eduGain and Umbrella Federation"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://dev.lobber.se/shibboleth",
    {
      "entity_id": "https://dev.lobber.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.lobber.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev.lobber.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.lobber.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.lobber.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.lobber.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "dev.lobber.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJAKINT3sa5ZpkMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDWRldi5sb2JiZXIuc2UwHhcNMTAxMDI4MTEyNDI0WhcNMjAxMDI1MTEyNDI0\nWjAYMRYwFAYDVQQDEw1kZXYubG9iYmVyLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAuekKnkVirTk0wu+y0EYnCQAbLGX7QJXkQHgS98TNs/UCygLM\npI+Y05caeru2WDA8hYYCdULx6zHiOTW1+0evqJS1FgLoNJcIob/xfZs/Ie2ClQj+\nQyjvJ7DlsoeZnF+1IHH3qKtOgRGhdDPJkwtvM1YqT/ztg/ljjqpZiIl5ZDKl5hzP\nyqfpj8qygfdhOlhXG00+pX8YdAZT/EvVmYU6nPAt4SrW2WONv8D5RYv2DyW550JV\nUjTv5WI2uw5QG8EmjOYMaSWr36VSuYUydNJVJs+tl/gqt6dByLN6uCB/hocQH1xZ\n1tEg0wNZwZ+W3jHQxVfumQjZipZxhx0KpMnObwIDAQABozswOTAYBgNVHREEETAP\ngg1kZXYubG9iYmVyLnNlMB0GA1UdDgQWBBSpg+Gao6u/rM08SBPJlKKb9DFfJTAN\nBgkqhkiG9w0BAQUFAAOCAQEAANTCJlMnWje5vOHwz6n5koNkNo7glFE1vg3Q5vKS\ncIE1RDlJMmMaC0txi4Rz/LkYMHAf4w2E52/MRcATfjdXEYnxA5HtA7JLY3fS/Jkr\nTYGhWzeC73rIb9uJqvau7vW5yj/IIV7V3TiraMdwwH1aXce2r+VGFj62Y80HoDBM\nEyQVg0dtbf5cmo5u0LIyaUi+x6tfKcq7cdVDqfB4whDSB0buU7SsyU1w+oRgOOuc\nrmBs7EHePMu15nh8kZZlHt0XPi8FstIZ4gPwZPwM73DZ7XH5APB7kFkZNrNEIQCG\nHmi0jDCgx97asTKIuyfGrHl3p3JNN2AJSdTtOSDntnuOYQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=dev.lobber.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "dev.lobber.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJAKINT3sa5ZpkMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDWRldi5sb2JiZXIuc2UwHhcNMTAxMDI4MTEyNDI0WhcNMjAxMDI1MTEyNDI0\nWjAYMRYwFAYDVQQDEw1kZXYubG9iYmVyLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAuekKnkVirTk0wu+y0EYnCQAbLGX7QJXkQHgS98TNs/UCygLM\npI+Y05caeru2WDA8hYYCdULx6zHiOTW1+0evqJS1FgLoNJcIob/xfZs/Ie2ClQj+\nQyjvJ7DlsoeZnF+1IHH3qKtOgRGhdDPJkwtvM1YqT/ztg/ljjqpZiIl5ZDKl5hzP\nyqfpj8qygfdhOlhXG00+pX8YdAZT/EvVmYU6nPAt4SrW2WONv8D5RYv2DyW550JV\nUjTv5WI2uw5QG8EmjOYMaSWr36VSuYUydNJVJs+tl/gqt6dByLN6uCB/hocQH1xZ\n1tEg0wNZwZ+W3jHQxVfumQjZipZxhx0KpMnObwIDAQABozswOTAYBgNVHREEETAP\ngg1kZXYubG9iYmVyLnNlMB0GA1UdDgQWBBSpg+Gao6u/rM08SBPJlKKb9DFfJTAN\nBgkqhkiG9w0BAQUFAAOCAQEAANTCJlMnWje5vOHwz6n5koNkNo7glFE1vg3Q5vKS\ncIE1RDlJMmMaC0txi4Rz/LkYMHAf4w2E52/MRcATfjdXEYnxA5HtA7JLY3fS/Jkr\nTYGhWzeC73rIb9uJqvau7vW5yj/IIV7V3TiraMdwwH1aXce2r+VGFj62Y80HoDBM\nEyQVg0dtbf5cmo5u0LIyaUi+x6tfKcq7cdVDqfB4whDSB0buU7SsyU1w+oRgOOuc\nrmBs7EHePMu15nh8kZZlHt0XPi8FstIZ4gPwZPwM73DZ7XH5APB7kFkZNrNEIQCG\nHmi0jDCgx97asTKIuyfGrHl3p3JNN2AJSdTtOSDntnuOYQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=dev.lobber.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.lobber.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev.lobber.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.lobber.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.lobber.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.lobber.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dev.lobber.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.lobber.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dev.lobber.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dev.lobber.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dev.lobber.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ung.si/idp/20111102",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Zavrtanik"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:danilo.zavrtanik@ung.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Danilo"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:bojan.korecic@ung.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kore\u010di\u010d"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:bojan.korecic@ung.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bojan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ung.si/idp/20111102",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_general.pdf"
              },
              {
                "lang": "sl",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_splosni_pogoji.pdf"
              }
            ],
            "registration_instant": "2015-10-22T11:10:11Z",
            "registration_authority": "http://aai.arnes.si",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ung.si/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ung.si/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ung.si"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ung.si"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ung.si"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for organization University of Nova Gorica"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ponudnik identitet organizacije Univerza v Novi Gorici"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "261",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "258"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Nova Gorica"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Univerza v Novi Gorici"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Univerza v Novi Gorici"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Univerza v Novi Gorici"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ung.si"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ung.si"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Univerza v Novi Gorici"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Univerza v Novi Gorici"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso.hsc.edu/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tpugh@hsc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Todd Pugh"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "traisbeck@sycomtech.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tom Raisbeck"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.hsc.edu/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.hsc.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.hsc.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.hsc.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.hsc.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hsc.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hampden-Sydney College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC0jCCAbqgAwIBAgIQMVbE9OvX1phCDtqNX/GNcDANBgkqhkiG9w0BAQsFADAl\nMSMwIQYDVQQDExpBREZTIFNpZ25pbmcgLSBzc28uaHNjLmVkdTAeFw0xNTA2MTgx\nNjA3MzhaFw0xNjA2MTcxNjA3MzhaMCUxIzAhBgNVBAMTGkFERlMgU2lnbmluZyAt\nIHNzby5oc2MuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAyy8Z\nekJKSclzO68X/aOO2x2onbiFc07T2pHty+wpUCqlrbyLXPJ5uA794GByv2HUcRo9\nT+Ulce6rACi2FBdVPPfGSioHUeyS6a2HM6H9HToNjN1GoK76Zl46OBkOVGPQhWUg\ns1Ophadi7yVmTav/MOgyc4+m0zmvMSKxlbN+QUvDIESBsJjp9/5ausmimTHTneKn\nvOyLh4UPGmwH+dkPR4UEMFAgsY6o65N3Hg+ZB7CpTLg/d4Mq+nAi3//H63hjkhAE\nPrysxl8o4MzIktKek+ZukBDFjFYGiJJfO2g3FxUncG0TxcMC+t3TVKqUfkYTYCTU\nCBUSQnCCu8q+bXOJGwIDAQABMA0GCSqGSIb3DQEBCwUAA4IBAQB2CvVWlOvoM/qQ\nIwU3OY6sIXSGdr4GKxGgztPOE0CY8mpoVV3YtGfq8lNt/72x+iUkh3fMmynMR6gJ\n/S2dclcOoJ5WUJjtsYU+0oVSCHaar7ei3xKutV3STrEPWNo3p+BmRPo24/G7PAhk\n7ZLA0vVaxhw7/t47mCZeGEQHqj2wF7OxvB6Lk9o+/4ZmZyzuXqGgEX10RBm+gZTI\nxeWDHu0oHrKhg0Gs/mBwEvb0KDyKx9tHKswqt1/9sd+auBg1meE8zEfIe83pMaHw\nOvoT768NOgsXeSGCu11mAjjxek36EyTV99dg2vloqXzQtliKIIomQfWOc8qcwUpY\nrAFrZ5o1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hampden-Sydney College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hsc.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hampden-Sydney College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://nagios.nordu.net/shibboleth",
    {
      "entity_id": "https://nagios.nordu.net/shibboleth",
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nagios.nordu.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nagios.nordu.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nagios.nordu.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nagios.nordu.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nagios.nordu.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://nagios.nordu.net/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "nagios"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC2TCCAcGgAwIBAgIJAOYa1BbBCe+lMA0GCSqGSIb3DQEBBQUAMBExDzANBgNV\nBAMTBm5hZ2lvczAeFw0xMjAxMjUxMzMxMDlaFw0yMjAxMjIxMzMxMDlaMBExDzAN\nBgNVBAMTBm5hZ2lvczCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANN1\nC+QdzDedN7C9wdTr61sJ9GgBbuWYCssGswZoa8loS3x7vnldyY2qcGRLamB0MUQ7\nT+xJMroALVl5dkM5H6sbfc5mXHoptLmWEpiP9PfctiWZxoeDMD9AitKUN4IBOdp8\nSz/NC3tbzugrfsPjXsPHyi53W/zy3Obj0Kvd/0+NR9xekxRLDCyPs7RNWVW0Beg/\nbIvYCtSDAN9hyeh3B/3qqjbT+tOOgTCTECoAkGyffE79VAJqKGveU8aV+TJgCPCp\nQ4H3hXFzAqvNDjTEAYKK6R/ik5BDVmMmmzmBlfPuKazqIhYyrv8YF3uAkXWDMSrq\nTXjF8Z3/kZOvHEbdI6UCAwEAAaM0MDIwEQYDVR0RBAowCIIGbmFnaW9zMB0GA1Ud\nDgQWBBR/qpporP9Dp7ROA03roTFyo2ziXTANBgkqhkiG9w0BAQUFAAOCAQEAmuQf\nlX/pkGS+jJYNJ7Hq0tHxk/SmZ3/352tXiYsInawiRzO0IgUTVL1weHR7UQzwWgIM\n+awow3BYc97T5ql4o1L1r2/BQRvZJZCGj0dW54GekNx2kFxiDePvaTuUuTsSInCb\nGj6YYhagaEqh7FgEWDb8BX4RozM2nuxN8s34XmdrY3xaM5HiH0QPExuk+a2yjuNQ\nm5ENIQmilN5KXbQtV5DLKO22/hfM+hjOXpO2LAyEK+uv9EgjIrHQhg2C+j1roEpF\ncmaSodg/QWPC0dJFDMtQhEx5sJTHL0ZYvfAlP9ldmsaUr4bg+vzq8ItixgX1+0D5\nJ2FYmoN42tc/5eQBmQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=nagios"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "nagios"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC2TCCAcGgAwIBAgIJAOYa1BbBCe+lMA0GCSqGSIb3DQEBBQUAMBExDzANBgNV\nBAMTBm5hZ2lvczAeFw0xMjAxMjUxMzMxMDlaFw0yMjAxMjIxMzMxMDlaMBExDzAN\nBgNVBAMTBm5hZ2lvczCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANN1\nC+QdzDedN7C9wdTr61sJ9GgBbuWYCssGswZoa8loS3x7vnldyY2qcGRLamB0MUQ7\nT+xJMroALVl5dkM5H6sbfc5mXHoptLmWEpiP9PfctiWZxoeDMD9AitKUN4IBOdp8\nSz/NC3tbzugrfsPjXsPHyi53W/zy3Obj0Kvd/0+NR9xekxRLDCyPs7RNWVW0Beg/\nbIvYCtSDAN9hyeh3B/3qqjbT+tOOgTCTECoAkGyffE79VAJqKGveU8aV+TJgCPCp\nQ4H3hXFzAqvNDjTEAYKK6R/ik5BDVmMmmzmBlfPuKazqIhYyrv8YF3uAkXWDMSrq\nTXjF8Z3/kZOvHEbdI6UCAwEAAaM0MDIwEQYDVR0RBAowCIIGbmFnaW9zMB0GA1Ud\nDgQWBBR/qpporP9Dp7ROA03roTFyo2ziXTANBgkqhkiG9w0BAQUFAAOCAQEAmuQf\nlX/pkGS+jJYNJ7Hq0tHxk/SmZ3/352tXiYsInawiRzO0IgUTVL1weHR7UQzwWgIM\n+awow3BYc97T5ql4o1L1r2/BQRvZJZCGj0dW54GekNx2kFxiDePvaTuUuTsSInCb\nGj6YYhagaEqh7FgEWDb8BX4RozM2nuxN8s34XmdrY3xaM5HiH0QPExuk+a2yjuNQ\nm5ENIQmilN5KXbQtV5DLKO22/hfM+hjOXpO2LAyEK+uv9EgjIrHQhg2C+j1roEpF\ncmaSodg/QWPC0dJFDMtQhEx5sJTHL0ZYvfAlP9ldmsaUr4bg+vzq8ItixgX1+0D5\nJ2FYmoN42tc/5eQBmQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=nagios"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nagios.nordu.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nagios.nordu.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nagios.nordu.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nagios.nordu.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nagios.nordu.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://nagios.nordu.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nagios.nordu.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://nagios.nordu.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://nagios.nordu.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://nagios.nordu.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ligo.org/ligovirgo/cbcnote/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "scott.koranda@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Scott Koranda"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "warren.anderson@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Warren Anderson"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rt-auth@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LIGO Identity Management Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lsc-seccomm@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LIGO Security Committee"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://ligo.org/ligovirgo/cbcnote/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "LIGO Scientific Collaboration"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ligo.caltech.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LIGO Scientific Collaboration"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.lsc-group.phys.uwm.edu/ligovirgo/cbcnote/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://dcc.ligo.org/cgi-bin/DocDB/ShowDocument?docid=89286"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "LIGO CBC Wiki"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Wiki for the LIGO/Virgo Compact Binary Coalescence Data Analysis Working Group"
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.ligo.org/SAML2/metadata/ui/ligologo80x60.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://dcc.ligo.org/cgi-bin/DocDB/ShowDocument?docid=89243"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEbzCCA1egAwIBAgIBLDANBgkqhkiG9w0BAQUFADCBhzETMBEGCgmSJomT8ixk\nARkWA29yZzEUMBIGCgmSJomT8ixkARkWBGxpZ28xDTALBgNVBAoTBExJR08xIDAe\nBgNVBAsTF0NlcnRpZmljYXRlIEF1dGhvcml0aWVzMRUwEwYDVQQLEwxXZWIgU2Vy\ndmljZXMxEjAQBgNVBAMTCUxJR08gQ0EgMTAeFw0xMTAxMDYyMzI0NTJaFw0yMTAx\nMDUyMzI0NTJaMHYxEzARBgoJkiaJk/IsZAEZFgNvcmcxFDASBgoJkiaJk/IsZAEZ\nFgRsaWdvMQ0wCwYDVQQKEwRMSUdPMRUwEwYDVQQLEwxXZWIgU2VydmljZXMxIzAh\nBgNVBAMTGnd3dy5sc2MtZ3JvdXAucGh5cy51d20uZWR1MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAuecfG1v+W0aaj7hPyPMuomjqJhV2cRndqwqckQlP\nV8CpGTEUZo1p1xX/Inx3lX7hUYkiGD+0pN120FSI79umMM5mgiRUPqqKYMiQZoS6\nq7P7gm8NNitjhlt3vwlMO2Spsfe84jjy+KkgJRV2ReRpxn6P+A4DkEUn88Ct+BmS\nF3YYh5hPlJJ/uGqVIG+XxgMyii2y1W11GZJuxls5u4aOnWGnZbgimmUJfQ3Ymjme\n1AM2JOp0B2xCJFVY4j0GsHCRKIy6lKisMTsXMhnPL8gL1y/OxqGSs0J2vMnNRqxO\nrNajrq/EPuyxAWp/53fptT8ZMDSKyXuFk7lG23vvKywIuQIDAQABo4H1MIHyMAwG\nA1UdEwEB/wQCMAAwDgYDVR0PAQH/BAQDAgSwMB0GA1UdJQQWMBQGCCsGAQUFBwMB\nBggrBgEFBQcDAjAZBgNVHSAEEjAQMA4GDCsGAQQBgfpGAgECATA5BgNVHR8EMjAw\nMC6gLKAqhihodHRwOi8vY2EubGlnby5vcmcvNTQxNDA0YzMvNTQxNDA0YzMuY3Js\nMB8GA1UdIwQYMBaAFFJu3Xuqb4VcCCLTl5+tfyNWHmrRMDwGA1UdEQQ1MDOCMXd3\ndy5sc2MtZ3JvdXAucGh5cy51d20uZWR1OnNjb3R0LmtvcmFuZGFAbGlnby5vcmcw\nDQYJKoZIhvcNAQEFBQADggEBAC8RMkc5TrNWkNJ8yMVS6NFIKRSV7H6J2NToTu8h\n1X4zHC1o2tb2kh5Kcg1rhAKtUKpLHnsrZ+OYGY1kJ/NpfUQWHDoYq/2NGnIUAFod\nzJvIT/a/9ENSVVEe0TUwz6oI7EC0TYmggHL6kdkKXB237ah1NLQrSZ3xEJaoK0I3\nDe6W4llFiV5Dls+j6EpHzuCET/e6s1cMclB7OMjcdNdecBX0xCGCm91u3OtEQGKM\nrzjVenErOkaR2hlPpssGfuLrGE8XT0qOvouycF+tC4MCElQnRQUjv5Gm7rnDnCFo\nabdn3KRVra6I57DBgGlc3hNW7pWrWcB+roy1O73/Cb/ZIpo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.lsc-group.phys.uwm.edu/ligovirgo/cbcnote/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.lsc-group.phys.uwm.edu/ligovirgo/cbcnote/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.lsc-group.phys.uwm.edu/ligovirgo/cbcnote/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.lsc-group.phys.uwm.edu/ligovirgo/cbcnote/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "LIGO CBC Wiki"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Wiki for the LIGO/Virgo Compact Binary Coalescence Data Analysis Working Group"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:givenName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:sn",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.unical.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Arcuri"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem-support@unical.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ferdinando"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Curci"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem-support@unical.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Walter"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.unical.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2015-08-18T09:50:49Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAL8L6FVmAKzC+THRIlDhT8LSevXmMA0GCSqGSIb3DQEB\nBQUAMBgxFjAUBgNVBAMMDWlkcC51bmljYWwuaXQwHhcNMTQxMjMxMDkwOTMxWhcN\nMzQxMjMxMDkwOTMxWjAYMRYwFAYDVQQDDA1pZHAudW5pY2FsLml0MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAlDcrPcuEiQa4Xfj2fqWYz2U2yZ9A3jeL\nAy9TTfnjvUnCIsxn91nZ/oKOqguDIHfCMgIHuqh2j8SBhgK9XRH99Pw2Rkyxh3mP\nBXODvlX8p1R1irOKEEd5oqNwEgE778vkznyRDvozQ2jDfb0Wu9f3/tbArNZf/H1z\n2xNUyygHQ5b+GmAkcBWlG9hvdbYNmUtHgfrbDZZS9tFGuz/38vPGW7kK2Ix4cuT7\npc7Toc8c6kz4n5v7OgraCilnZ/G/gKltTVrkpFVuGiKbaOXnSjD39p2vkDtMGGJt\nDb3wIJDDYnbmIqm8Kb2N8+e8PzA1UVicNKh62VO5FCoJuS69avG4+QIDAQABo2Ew\nXzAdBgNVHQ4EFgQUKnbFFsMucKsmi72fGJ8YytDd0GwwPgYDVR0RBDcwNYINaWRw\nLnVuaWNhbC5pdIYkaHR0cHM6Ly9pZHAudW5pY2FsLml0L2lkcC9zaGliYm9sZXRo\nMA0GCSqGSIb3DQEBBQUAA4IBAQAOgtL4MsqXajq8MSDAZ8gx6DC/OdEhinRciYNj\nsMNiDkJhdHp/hgU1PqKBsiw0L4NZYnUweSvkoARzl90LOc7gnTaMF/vF1tcvYFF4\n4lSnQsGeDn09CeJ24N/mAjjiiARoGI0N7ouqtDs8piWEXv/wUFwTCLxc/CHkvRsx\n4GAPwKs+UXU2PcW6sP2qqYPFS+cv2ZXb4gf8mVS0IFbbtLpUxM8M4BoBa5jxnMUX\n+BtpYUkJLCO302UkQygIJBPbnPWRdAJWdQmqpi326apWLQl3XgUWkLpeGPrguo9J\nZ1yQ0FMZWZ/qgnNEvOC4oDUkACRrs4AMyPBb64WlSs4w2O7O"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unical.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unical.it/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unical.it/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unical.it/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unical.it/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unical.it:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.unical.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unical.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.unical.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unical.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unical.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unical.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unical.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.unical.it/idem"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.unical.it/idem"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for University of Calabria users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider per gli utenti dell'Universit\u00e0 della Calabria"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.unical.it/idem/privacy"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.unical.it/idem/privacy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Calabria"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 della Calabria"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "unical.it"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:39.357911,16.225530"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "160.97.0.0/16"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAL8L6FVmAKzC+THRIlDhT8LSevXmMA0GCSqGSIb3DQEB\nBQUAMBgxFjAUBgNVBAMMDWlkcC51bmljYWwuaXQwHhcNMTQxMjMxMDkwOTMxWhcN\nMzQxMjMxMDkwOTMxWjAYMRYwFAYDVQQDDA1pZHAudW5pY2FsLml0MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAlDcrPcuEiQa4Xfj2fqWYz2U2yZ9A3jeL\nAy9TTfnjvUnCIsxn91nZ/oKOqguDIHfCMgIHuqh2j8SBhgK9XRH99Pw2Rkyxh3mP\nBXODvlX8p1R1irOKEEd5oqNwEgE778vkznyRDvozQ2jDfb0Wu9f3/tbArNZf/H1z\n2xNUyygHQ5b+GmAkcBWlG9hvdbYNmUtHgfrbDZZS9tFGuz/38vPGW7kK2Ix4cuT7\npc7Toc8c6kz4n5v7OgraCilnZ/G/gKltTVrkpFVuGiKbaOXnSjD39p2vkDtMGGJt\nDb3wIJDDYnbmIqm8Kb2N8+e8PzA1UVicNKh62VO5FCoJuS69avG4+QIDAQABo2Ew\nXzAdBgNVHQ4EFgQUKnbFFsMucKsmi72fGJ8YytDd0GwwPgYDVR0RBDcwNYINaWRw\nLnVuaWNhbC5pdIYkaHR0cHM6Ly9pZHAudW5pY2FsLml0L2lkcC9zaGliYm9sZXRo\nMA0GCSqGSIb3DQEBBQUAA4IBAQAOgtL4MsqXajq8MSDAZ8gx6DC/OdEhinRciYNj\nsMNiDkJhdHp/hgU1PqKBsiw0L4NZYnUweSvkoARzl90LOc7gnTaMF/vF1tcvYFF4\n4lSnQsGeDn09CeJ24N/mAjjiiARoGI0N7ouqtDs8piWEXv/wUFwTCLxc/CHkvRsx\n4GAPwKs+UXU2PcW6sP2qqYPFS+cv2ZXb4gf8mVS0IFbbtLpUxM8M4BoBa5jxnMUX\n+BtpYUkJLCO302UkQygIJBPbnPWRdAJWdQmqpi326apWLQl3XgUWkLpeGPrguo9J\nZ1yQ0FMZWZ/qgnNEvOC4oDUkACRrs4AMyPBb64WlSs4w2O7O"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNICAL - Universit\u00e0 della Calabria"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNICAL - University of Calabria"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unical.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unical.it/portale/international/"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 della Calabria"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Calabria"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.geo-zs.si/idp/20110325",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Komac"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:marko.komac@geo-zs.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marko"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@geo-zs.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Po\u017ear"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mitja.pozar@geo-zs.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mitja"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sinigoj"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jasna.sinigoj@geo-zs.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jasna"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "\u0160inigoj"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jasna.sinigoj@geo-zs.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jasna"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.geo-zs.si/idp/20110325",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_general.pdf"
              },
              {
                "lang": "sl",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_splosni_pogoji.pdf"
              }
            ],
            "registration_instant": "2014-11-07T14:11:09Z",
            "registration_authority": "http://aai.arnes.si",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.geo-zs.si/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.geo-zs.si/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "geo-zs.si"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.geo-zs.si/eng/"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.geo-zs.si"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for organization Gological Survey of Slovenia"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ponudnik identitet organizacije Geolo\u0161ki zavod Slovenije"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "150",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "129"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Gological Survey of Slovenia"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Geolo\u0161ki zavod Slovenije"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Geolo\u0161ki zavod Slovenije"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Geolo\u0161ki zavod Slovenije"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.geo-zs.si/eng/"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.geo-zs.si"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Geolo\u0161ki zavod Slovenije"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Geolo\u0161ki zavod Slovenije"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ens.fr/idp/idp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Julien Moutel"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "julien.moutel@ens.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jean-Fran\u00e7ois Barb\u00e9"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jean-francois.barbe@ens.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ens.fr/idp/idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-01-18T15:41:42Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ens.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ens.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ens.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ens.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ens.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAQAAAC1+jfqAAAAAmJLR0QA/4ePzL8AAAAJcEhZcwAAAEgAAABIAEbJaz4AAAAJdnBBZwAAABAAAAAQAFzGrcMAAACESURBVCjPzY8xCoNQEETfFytBSBHsgiiSTkjtabxQEHKOHMAbBNIJqexTpRAESx0L/WCifXzVsjMMM/B/jD0kgIEBdxJmxV267xyJCLejJCnTRxO17H+RUFAgHpQ4xOsOTx0IuOKTEnNed2h40ZNT0fIm2Vpx40TExQrmx9DJ+95v2A0jM8olr6uCeR8AAAAldEVYdGRhdGU6Y3JlYXRlADIwMTUtMDctMjBUMTA6NDg6NTkrMDI6MDDmguK/AAAAJXRFWHRkYXRlOm1vZGlmeQAyMDE1LTA3LTIwVDEwOjQ4OjU5KzAyOjAwl99aAwAAAABJRU5ErkJggg==",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole normale sup\u00e9rieure"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole normale sup\u00e9rieure"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEzCCAfugAwIBAgIUUlGCB1tXdKMlojKQasf9KdmcqBkwDQYJKoZIhvcNAQEF\nBQAwFTETMBEGA1UEAxMKaWRwLmVucy5mcjAeFw0xMTA4MDMwOTIzMDdaFw0zMTA4\nMDMwOTIzMDdaMBUxEzARBgNVBAMTCmlkcC5lbnMuZnIwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQC7h6xC+WGiUlpC70MJcuYS8Oc9FhxbVbg33IE1bM4R\n4bLY6ve5nNq4yE2EaTtYy1qskb3B55l6M1nSGKxl3Ey5ovh4cBE5r6fd2fjwlkgB\n5hqNxAbZhA9NPoval38EMYlepR6QtJny+faKWmCe9h4G9MRD+I8tP35z7Gq+3bPT\nivLLgzBjGumdyj0ggNN/qvd1EisO3TPB+DHR9ygtRm6iNcV7om25k4QZVMHqNyKL\n8J/XDkBkyqqZPJv30xM5xfBP6dK6eRYOLXOCvdwuWNwqS5mtItc+b8S3Oj5K5AcR\nEuDXjgEMCRXo8eNxkjbJlGkgD0l2O0pXJhZFjr+ygsclAgMBAAGjWzBZMDgGA1Ud\nEQQxMC+CCmlkcC5lbnMuZnKGIWh0dHBzOi8vaWRwLmVucy5mci9pZHAvc2hpYmJv\nbGV0aDAdBgNVHQ4EFgQUHX2nM2/snLOaYle+MS5sYYpqXWAwDQYJKoZIhvcNAQEF\nBQADggEBAE09V2ugOzVp7Ow5RQWnsKEgkdIqcNiXcjZTLqCTmbHmG3kGlRG6h0vx\ngy83fcPTkzdaI6ZwVWQF8b+T4Pl+0o1x9vk9CrGHMP0I2smHc1vp/Xqsk+d03tRx\nD2hRBVIDMR95A1pa4yFD2NrWQSLcpfzo3I1TyktpQsncW6LGr7DFi0WwiUAKXO2n\n1Vb9HK0GFd1U2HbFaF5Qc0Hu7rB0UCCmMBzu8brmlMsBgI9Y66zu19Rhmbyx/PdM\nxwVSXwnkIA97hjG91++g6nE8RqtobQ6nIiz3Gv/JjedaSpF5QuRNM8nJYS8Uhmpn\nW+Qzc6tGLNnwcdwm81JXYmMju+ipIhM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ecole normale sup\u00e9rieure"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ens.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ecole normale sup\u00e9rieure"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.antagning.se/ecs-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.antagning.se/ecs-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.antagning.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.antagning.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.antagning.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.antagning.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.antagning.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.antagning.se/ecs-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.antagning.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJALH2RsMw05H0MA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEHd3dy5hbnRhZ25pbmcuc2UwHhcNMTEwMTI3MTU0NTQzWhcNMjEwMTI0MTU0\nNTQzWjAbMRkwFwYDVQQDExB3d3cuYW50YWduaW5nLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAo0zS8/OY0J8MaPznZX+4vVWnGKTR1SDd4euzuQo/\nKq+JDCb3T+r4/9JQ21kXSVeU15F9JimK1Le+RiTNw/S0j/7GME+74kUnvaVCCHof\n2wCwdu1opbHSnuubuvFpq/09vzrJx+BnJKCaAkTtFQWptaPgP8X8dl+uIfBk1XnP\nW8G2ks9kxBDLDgaeLsw9XVVmvx2agQ+DvyLCweV65EzkyE5Q0E3lNB3o/7bbFwks\nylF0ck83sZs0xZmGZGSJA/3Nq0DY9WQqzuzzRN/EE8tMlzzBtBPFO+8UXfVcGNrE\nJi05WLEotSz7J7isienC7ZGeFSgL4RUZ8yD3smzs3pywQwIDAQABo18wXTA8BgNV\nHREENTAzghB3d3cuYW50YWduaW5nLnNlhh9odHRwczovL3d3dy5hbnRhZ25pbmcu\nc2UvZWNzLXNwMB0GA1UdDgQWBBRcKrtBUd27dOJHOQu/XU22WJXa1TANBgkqhkiG\n9w0BAQUFAAOCAQEAnWdP39natg/Qa/8/3EKsPsriH3sUdX2gDFqUjPEOLX+eDhT8\n6TKl3q6nEhpe+Zgb+ER08TSEp+BrBtAR/SG+Du4Lni7Jo8d7sgJe4oUxvnQOuaPH\nGosRhbRqhfHL0Ww8w0x7V/KRQkupwcXNQ4gga9dy2uZQjg/UK45r3ii5XUogzfVJ\nEclAXOodZ846vzq972yn0Uwn2YsZo/3po42QF5aw2YRjxxN7XIaWshKrv9r82voj\nVJd+cPOTem5oBZpfu5nzSrDRGdKYqO2W0Y9kesTFue14NutKgjXaPLdUNFNhGB7b\nmemQErWscT6OYxV3jxV31wEP2PzMsYzF5LXJEQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.antagning.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.antagning.se/ecs-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.antagning.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJALH2RsMw05H0MA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEHd3dy5hbnRhZ25pbmcuc2UwHhcNMTEwMTI3MTU0NTQzWhcNMjEwMTI0MTU0\nNTQzWjAbMRkwFwYDVQQDExB3d3cuYW50YWduaW5nLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAo0zS8/OY0J8MaPznZX+4vVWnGKTR1SDd4euzuQo/\nKq+JDCb3T+r4/9JQ21kXSVeU15F9JimK1Le+RiTNw/S0j/7GME+74kUnvaVCCHof\n2wCwdu1opbHSnuubuvFpq/09vzrJx+BnJKCaAkTtFQWptaPgP8X8dl+uIfBk1XnP\nW8G2ks9kxBDLDgaeLsw9XVVmvx2agQ+DvyLCweV65EzkyE5Q0E3lNB3o/7bbFwks\nylF0ck83sZs0xZmGZGSJA/3Nq0DY9WQqzuzzRN/EE8tMlzzBtBPFO+8UXfVcGNrE\nJi05WLEotSz7J7isienC7ZGeFSgL4RUZ8yD3smzs3pywQwIDAQABo18wXTA8BgNV\nHREENTAzghB3d3cuYW50YWduaW5nLnNlhh9odHRwczovL3d3dy5hbnRhZ25pbmcu\nc2UvZWNzLXNwMB0GA1UdDgQWBBRcKrtBUd27dOJHOQu/XU22WJXa1TANBgkqhkiG\n9w0BAQUFAAOCAQEAnWdP39natg/Qa/8/3EKsPsriH3sUdX2gDFqUjPEOLX+eDhT8\n6TKl3q6nEhpe+Zgb+ER08TSEp+BrBtAR/SG+Du4Lni7Jo8d7sgJe4oUxvnQOuaPH\nGosRhbRqhfHL0Ww8w0x7V/KRQkupwcXNQ4gga9dy2uZQjg/UK45r3ii5XUogzfVJ\nEclAXOodZ846vzq972yn0Uwn2YsZo/3po42QF5aw2YRjxxN7XIaWshKrv9r82voj\nVJd+cPOTem5oBZpfu5nzSrDRGdKYqO2W0Y9kesTFue14NutKgjXaPLdUNFNhGB7b\nmemQErWscT6OYxV3jxV31wEP2PzMsYzF5LXJEQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.antagning.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.antagning.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.antagning.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.antagning.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.antagning.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.antagning.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.antagning.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.antagning.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.antagning.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.antagning.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.antagning.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cafe.ifrs.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Suporte CAFe IFRS"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cafe@ifrs.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.ifrs.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEADCCAugCAQAwDQYJKoZIhvcNAQEFBQAwgcUxNjA0BgNVBAoTLUlGUlMgLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkbyBSaW8gR3JhbmRlIGRvIFN1bDEMMAoGA1UECxMD\nQ1BEMR8wHQYJKoZIhvcNAQkBFhBjYWZlQGlmcnMuZWR1LmJyMRgwFgYDVQQHEw9C\nZW50byBHb25jYWx2ZXMxGjAYBgNVBAgTEVJpbyBHcmFuZGUgZG8gU3VsMQswCQYD\nVQQGEwJCUjEZMBcGA1UEAxMQY2FmZS5pZnJzLmVkdS5icjAeFw0xNTA3MDcxODIx\nMTFaFw0xODA3MDYxODIxMTFaMIHFMTYwNAYDVQQKEy1JRlJTIC0gSW5zdGl0dXRv\nIEZlZGVyYWwgZG8gUmlvIEdyYW5kZSBkbyBTdWwxDDAKBgNVBAsTA0NQRDEfMB0G\nCSqGSIb3DQEJARYQY2FmZUBpZnJzLmVkdS5icjEYMBYGA1UEBxMPQmVudG8gR29u\nY2FsdmVzMRowGAYDVQQIExFSaW8gR3JhbmRlIGRvIFN1bDELMAkGA1UEBhMCQlIx\nGTAXBgNVBAMTEGNhZmUuaWZycy5lZHUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQDW0sT6IptdPSgeFZD82tHmfg5a2W3bmAqblRCtvZglNdLgpL5W\nNJMcgolvbumWM709Hv8cX5y1vwCFByV4hrDReU5YEgsKWvA5Eovh5LntWK5euKd/\nyALTEOH3k4b+ktF7TPIwCfsIpY3wcaBdGIGtNaqAJq9Vbmms9KgNmLmNNGtk8LF6\nQLT1IuLj9uGJrvTTtrD9aBhj0qbWtLtBbE7zHCUiPCK4sqHZon1xzHbBNy2BpTCn\ngclxri3xKElFqEpEiNfzSBfx8uicN1CYofKMMuMY2dHmGQeYl/oas3VVCo/CebR6\nE6a7MYZfQklnLYWh1UGwr3oUyuB+xF5SwL1rAgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBAJszIng6ixxwRUsyMzHkpBuM6t9JsdfqHP3OtXQu3l2rru6Q1aatTA40H0sq\n+ODSTIkvmbXrH1Sa0eobjwRCgIohzPxiK6xbxEnT/EnIBPoYNgJEXdfdM26Hi158\nd4ON/+NcLw2+WXtQJ3p1nyqpVP5ZDh+seCjYNGYCwm0Hv/X8MMoZ1X12ONwbDKzF\nnJMHAVlQBn6KfZ5hnLHCM7AMGzbmvNguvBKSHgASBCCHSm2y0dOMy47ynr1P/Srh\niC7HCSCn/egq36udHpw14Zh1AW12yr0P5TWT0YY3Fony8MVpT6VO0W+lNwJ084DB\n4PBfkm2ud0+t4T9K/ym4hghmfHQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.ifrs.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.ifrs.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.ifrs.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.ifrs.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.ifrs.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.ifrs.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.ifrs.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.ifrs.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifrs.edu.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifrs.edu.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFRS - Instituto Federal do Rio Grande do Sul"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFRS - Instituto Federal do Rio Grande do Sul"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFRS - Instituto Federal do Rio Grande do Sul"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFRS - Instituto Federal do Rio Grande do Sul"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEADCCAugCAQAwDQYJKoZIhvcNAQEFBQAwgcUxNjA0BgNVBAoTLUlGUlMgLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkbyBSaW8gR3JhbmRlIGRvIFN1bDEMMAoGA1UECxMD\nQ1BEMR8wHQYJKoZIhvcNAQkBFhBjYWZlQGlmcnMuZWR1LmJyMRgwFgYDVQQHEw9C\nZW50byBHb25jYWx2ZXMxGjAYBgNVBAgTEVJpbyBHcmFuZGUgZG8gU3VsMQswCQYD\nVQQGEwJCUjEZMBcGA1UEAxMQY2FmZS5pZnJzLmVkdS5icjAeFw0xNTA3MDcxODIx\nMTFaFw0xODA3MDYxODIxMTFaMIHFMTYwNAYDVQQKEy1JRlJTIC0gSW5zdGl0dXRv\nIEZlZGVyYWwgZG8gUmlvIEdyYW5kZSBkbyBTdWwxDDAKBgNVBAsTA0NQRDEfMB0G\nCSqGSIb3DQEJARYQY2FmZUBpZnJzLmVkdS5icjEYMBYGA1UEBxMPQmVudG8gR29u\nY2FsdmVzMRowGAYDVQQIExFSaW8gR3JhbmRlIGRvIFN1bDELMAkGA1UEBhMCQlIx\nGTAXBgNVBAMTEGNhZmUuaWZycy5lZHUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQDW0sT6IptdPSgeFZD82tHmfg5a2W3bmAqblRCtvZglNdLgpL5W\nNJMcgolvbumWM709Hv8cX5y1vwCFByV4hrDReU5YEgsKWvA5Eovh5LntWK5euKd/\nyALTEOH3k4b+ktF7TPIwCfsIpY3wcaBdGIGtNaqAJq9Vbmms9KgNmLmNNGtk8LF6\nQLT1IuLj9uGJrvTTtrD9aBhj0qbWtLtBbE7zHCUiPCK4sqHZon1xzHbBNy2BpTCn\ngclxri3xKElFqEpEiNfzSBfx8uicN1CYofKMMuMY2dHmGQeYl/oas3VVCo/CebR6\nE6a7MYZfQklnLYWh1UGwr3oUyuB+xF5SwL1rAgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBAJszIng6ixxwRUsyMzHkpBuM6t9JsdfqHP3OtXQu3l2rru6Q1aatTA40H0sq\n+ODSTIkvmbXrH1Sa0eobjwRCgIohzPxiK6xbxEnT/EnIBPoYNgJEXdfdM26Hi158\nd4ON/+NcLw2+WXtQJ3p1nyqpVP5ZDh+seCjYNGYCwm0Hv/X8MMoZ1X12ONwbDKzF\nnJMHAVlQBn6KfZ5hnLHCM7AMGzbmvNguvBKSHgASBCCHSm2y0dOMy47ynr1P/Srh\niC7HCSCn/egq36udHpw14Zh1AW12yr0P5TWT0YY3Fony8MVpT6VO0W+lNwJ084DB\n4PBfkm2ud0+t4T9K/ym4hghmfHQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFRS - Instituto Federal do Rio Grande do Sul"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFRS - Instituto Federal do Rio Grande do Sul"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifrs.edu.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifrs.edu.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFRS - Instituto Federal de Educacao, Ciencia e Tecnologia do Rio Grande do Sul"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFRS - Instituto Federal de Educacao, Ciencia e Tecnologia do Rio Grande do Sul"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.imperialhomesolutions.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Borman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve@studentpad.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Steven"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Darren@studentpad.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Darren"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Borman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve@studentpad.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Steven"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Darren@studentpad.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Darren"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.imperialhomesolutions.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-04-22T11:21:23Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Studentpad.co.uk Limited: Imperial Home Solutions Student Accommodation Search"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.studentpad.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Studentpad.co.uk Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.imperialhomesolutions.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.imperialhomesolutions.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.imperialhomesolutions.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.imperialhomesolutions.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.imperialhomesolutions.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.imperialhomesolutions.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.imperialhomesolutions.co.uk/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.imperialhomesolutions.co.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.imperialhomesolutions.co.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC5TCCAc2gAwIBAgIJAPDeYJ9fK7sUMA0GCSqGSIb3DQEBBQUAMBUxEzARBgNV\n\t\t\t\t\t\tBAMTCmNwNS0zNTM0OTQwHhcNMTQwNDIyMDc0MzU1WhcNMjQwNDE5MDc0MzU1WjAV\n\t\t\t\t\t\tMRMwEQYDVQQDEwpjcDUtMzUzNDk0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAut1QMxWT6HWYp+apapBDYazxaeutbzmKH4LpLgnsLQQtNgWqx3Fer888\n\t\t\t\t\t\t0h7vp0nMYKeZaB0kTliyBIxzYLc0CsfaKqm20QiOWfTlg53cdikVrtGDLc4id9zv\n\t\t\t\t\t\tDQJhMjwgUXKvs0XwJN7yKsq8eSOCYyCE1TpJfK0VT4HHfh/Wn17QFNTDoR+jJ2i7\n\t\t\t\t\t\t4bpxnaAOPI+/4vyW56fTDpLV9XwhtVv179zkloHfccbDRc57QvRrxMy3I7uQtU79\n\t\t\t\t\t\tcr8QQ7CjpzjG43D1ncI741lVQcUimn2DDy282cgcFTaIif3mjVx51qIbrRqYfKsd\n\t\t\t\t\t\t3rAMy5Bj2bleoOnpTwK0wJFbCNBkaQIDAQABozgwNjAVBgNVHREEDjAMggpjcDUt\n\t\t\t\t\t\tMzUzNDk0MB0GA1UdDgQWBBQNe+WX17m5BA+2JOe1ipAKtySOTDANBgkqhkiG9w0B\n\t\t\t\t\t\tAQUFAAOCAQEAIWpKD5IuImla1LnqP8sZn9NyKlYAKKZ36eiU6oTGGnGiWf4Wtd78\n\t\t\t\t\t\tf/OP+hHUs05Jb6a1+JpoJhe5JUkadcNOizXtpp6xfq2Tb3C/iO+m68V+Og9K2fm3\n\t\t\t\t\t\tyzOlWWQjfaiZUuf20Y+UCjP7IGHUyhAHve0ECYcqway3Kbz82KiopbhcoQJK93qf\n\t\t\t\t\t\thFPMyE5VqqCHA4B/rUj6ZsaBjGxTGZ0bopaAScMsUJpZ5LP4+NK+6aO1V4RZtve1\n\t\t\t\t\t\tZF05+Alc7GbNsb53cAOFAehJEZiZOjbPtTkVTU/yZk0sTAXALQXnNjMBKFbn7dyB\n\t\t\t\t\t\tvB9Gj0YneP92oYbUZ7AooBDGTwcCKxiM4A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.imperialhomesolutions.co.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.imperialhomesolutions.co.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.imperialhomesolutions.co.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.imperialhomesolutions.co.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.imperialhomesolutions.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.imperialhomesolutions.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.imperialhomesolutions.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.imperialhomesolutions.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.imperialhomesolutions.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.imperialhomesolutions.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://birk.wayf.dk/birk.php/federation.ku.dk/adfs/services/trust",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://birk.wayf.dk/birk.php/federation.ku.dk/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2014-05-06T13:32:41Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/federation.ku.dk/adfs/ls/auth/integrated/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ku.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "K\u00f8benhavns Universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Copenhagen"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "ku.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4DCCAcgCAQcwDQYJKoZIhvcNAQELBQAwNjE0MDIGA1UEAwwraHR0cDovL2Zl\nZGVyYXRpb24ua3UuZGsvYWRmcy9zZXJ2aWNlcy90cnVzdDAeFw0xNTAxMDEwMDAw\nMDBaFw0yNTEyMzEyMzU5NTlaMDYxNDAyBgNVBAMMK2h0dHA6Ly9mZWRlcmF0aW9u\nLmt1LmRrL2FkZnMvc2VydmljZXMvdHJ1c3QwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQDHiAwKahBTuI4Z+IJ1rgOeEiCCy3bR9QIe3BpCsejFCU5rSzkW\nANqVuc1PDfp0JdIZhrPXsmDJQMmidPCGPIDQKo+bk+af3+EUFS/I/+35sSBX2vf+\nh1DHvZV9jsznmpSVjp7HZ/WoPWBykWBJO0AOVmzB5zlaqkS36J76+wxerwdpuExV\nnYSNd73S+AyT/EZ+tXAO+6lQ8FL/YMlJnUkSaSqLSHFy01D2qBNmYRwBpCS6/dUZ\nyxi0t5j8ghKUD4BHOZVavn65J62cJdXiOcMRyUAIp57GXQrL63KtrjIcXddq+CZy\nZ5t37EdUOIz42joFcy73MFOntynlKEvOw1BJAgMBAAEwDQYJKoZIhvcNAQELBQAD\nggEBAEvxBAwGchmDrza6RWllwgsJ1l7CAINKJyWBDE6kIMPKPj7DI1T/lpiowC8/\neCulHBgEIGW/bWSiNkYIaJrPuCIGigjl8UE7ZRmF5OxVr7/hY7slJD9qYLbNf9Hw\nklvYtmH0I5uyI5Fbo+wEHk1g98JUmXYiVX+bvsOHBA/c5C+55ZwqNKyXEXTN/8n2\nf3tX4Vm31Tn0Y6Rh2h42g6vKkAt70WsUlfSzIKWfBHo29GPQYbr/JOiKfJWbPJbb\n5qorAtuuCSoh5XXMU6qGcpPa9aSnfP5BNskgQWFj/8TmDp6fox9KKNwpBKpQLuHy\noDZnFjBuo5Hw31Z+O4L9t4eVzBM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "K\u00f8benhavns Universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Copenhagen"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://ku.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ku.dk/english"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "K\u00f8benhavns Universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Copenhagen"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://beta.asm.pub2web.ingenta.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:service@asmusa.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Service"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Arbuthnott"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:openathens@publishingtechnology.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Peter"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://beta.asm.pub2web.ingenta.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-07-31T15:28:31Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ASM Science Beta"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.asmscience.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Publishing Technology plc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDnDCCAoSgAwIBAgIEUe5jgTANBgkqhkiG9w0BAQUFADCBjzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFDASBgNVBAgTC094Zm9yZHNoaXJlMQ8wDQYDVQQHEwZPeGZvcmQxHjAcBgNV\n\t\t\t\t\t\tBAoTFVB1Ymxpc2hpbmcgVGVjaG5vbG9neTEZMBcGA1UECxMQU2Nob2xhcmx5IE9u\n\t\t\t\t\t\tbGluZTEeMBwGA1UEAxMVUHVibGlzaGluZyBUZWNobm9sb2d5MB4XDTEzMDcyMzEx\n\t\t\t\t\t\tMDUzN1oXDTE2MDcyMjExMDUzN1owgY8xCzAJBgNVBAYTAkdCMRQwEgYDVQQIEwtP\n\t\t\t\t\t\teGZvcmRzaGlyZTEPMA0GA1UEBxMGT3hmb3JkMR4wHAYDVQQKExVQdWJsaXNoaW5n\n\t\t\t\t\t\tIFRlY2hub2xvZ3kxGTAXBgNVBAsTEFNjaG9sYXJseSBPbmxpbmUxHjAcBgNVBAMT\n\t\t\t\t\t\tFVB1Ymxpc2hpbmcgVGVjaG5vbG9neTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\n\t\t\t\t\t\tAQoCggEBAKz4tWwjcP2+Ld9vIqdI9ssmUF7yJVnDUoJqAPhejPOFSvrEZrjvofnY\n\t\t\t\t\t\t6VIcPcL3tyUADrD/vTRCb3T1FuQKsRnXgYzYI9o84hK6IZyTVzzD1G3Kil5ivsNq\n\t\t\t\t\t\tndv5hcMNfbH5kjGLfKvgHixrkR5HkLfITBghQydtCur4Yze0+u3mFu4OTabmqILH\n\t\t\t\t\t\thcnWlLPohznyRtx5F3fTtFFC/cUHAonymmH8OG3xQOhLFR1dSK5i2oGoRdqme6mR\n\t\t\t\t\t\tFiFHS8832tGjqsb072rFdpxKSmPLxz0vBxoa/YVw0RP6OYgt5Gze6mPOv1rFE5jq\n\t\t\t\t\t\tnMegHU7gLilsR6AS9GQoE+KUNiBeYhsCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tOlI/iGvczpy+BZErTXPBvizoKvFJzoi5Ri+zRRu+49qR67uMrnpKAQ51Weae6kj8\n\t\t\t\t\t\ttz0+iQIcKbyOO/9A+7Iu55PWruI4w0Qe4c8cCmFg5crORj2Orel3IMrT5s4XXOZ2\n\t\t\t\t\t\tMHweTl9+ZGFpshUYbSdPvj2vN8RhpC1c644lHVK0xceVxd3pFZA6VdtKfrnjyfXH\n\t\t\t\t\t\tt2m6Pzr00zEvxcvZch5rXdtH/tdSp8fRQzAoAWB1MBXTLBL1xztRSTacPMJYdiNP\n\t\t\t\t\t\tetGuGMwdTlZcDiknmfJT4zwcf6U1kXLon29n9b+6/Yq9wo+XYXd+HjGNmaJAhZm3\n\t\t\t\t\t\tmWuKjo4lfM11tPcrL+QV0g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDnDCCAoSgAwIBAgIEUe5jgTANBgkqhkiG9w0BAQUFADCBjzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFDASBgNVBAgTC094Zm9yZHNoaXJlMQ8wDQYDVQQHEwZPeGZvcmQxHjAcBgNV\n\t\t\t\t\t\tBAoTFVB1Ymxpc2hpbmcgVGVjaG5vbG9neTEZMBcGA1UECxMQU2Nob2xhcmx5IE9u\n\t\t\t\t\t\tbGluZTEeMBwGA1UEAxMVUHVibGlzaGluZyBUZWNobm9sb2d5MB4XDTEzMDcyMzEx\n\t\t\t\t\t\tMDUzN1oXDTE2MDcyMjExMDUzN1owgY8xCzAJBgNVBAYTAkdCMRQwEgYDVQQIEwtP\n\t\t\t\t\t\teGZvcmRzaGlyZTEPMA0GA1UEBxMGT3hmb3JkMR4wHAYDVQQKExVQdWJsaXNoaW5n\n\t\t\t\t\t\tIFRlY2hub2xvZ3kxGTAXBgNVBAsTEFNjaG9sYXJseSBPbmxpbmUxHjAcBgNVBAMT\n\t\t\t\t\t\tFVB1Ymxpc2hpbmcgVGVjaG5vbG9neTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\n\t\t\t\t\t\tAQoCggEBAKz4tWwjcP2+Ld9vIqdI9ssmUF7yJVnDUoJqAPhejPOFSvrEZrjvofnY\n\t\t\t\t\t\t6VIcPcL3tyUADrD/vTRCb3T1FuQKsRnXgYzYI9o84hK6IZyTVzzD1G3Kil5ivsNq\n\t\t\t\t\t\tndv5hcMNfbH5kjGLfKvgHixrkR5HkLfITBghQydtCur4Yze0+u3mFu4OTabmqILH\n\t\t\t\t\t\thcnWlLPohznyRtx5F3fTtFFC/cUHAonymmH8OG3xQOhLFR1dSK5i2oGoRdqme6mR\n\t\t\t\t\t\tFiFHS8832tGjqsb072rFdpxKSmPLxz0vBxoa/YVw0RP6OYgt5Gze6mPOv1rFE5jq\n\t\t\t\t\t\tnMegHU7gLilsR6AS9GQoE+KUNiBeYhsCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tOlI/iGvczpy+BZErTXPBvizoKvFJzoi5Ri+zRRu+49qR67uMrnpKAQ51Weae6kj8\n\t\t\t\t\t\ttz0+iQIcKbyOO/9A+7Iu55PWruI4w0Qe4c8cCmFg5crORj2Orel3IMrT5s4XXOZ2\n\t\t\t\t\t\tMHweTl9+ZGFpshUYbSdPvj2vN8RhpC1c644lHVK0xceVxd3pFZA6VdtKfrnjyfXH\n\t\t\t\t\t\tt2m6Pzr00zEvxcvZch5rXdtH/tdSp8fRQzAoAWB1MBXTLBL1xztRSTacPMJYdiNP\n\t\t\t\t\t\tetGuGMwdTlZcDiknmfJT4zwcf6U1kXLon29n9b+6/Yq9wo+XYXd+HjGNmaJAhZm3\n\t\t\t\t\t\tmWuKjo4lfM11tPcrL+QV0g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://beta.asm.pub2web.ingenta.com/session/shib",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://beta.asm.pub2web.ingenta.com/session/shib",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-demo-p01.its.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-demo-p01.its.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-p01.its.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-p01.its.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-p01.its.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-p01.its.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-p01.its.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-demo-p01.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-demo-p01.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;demo-p01"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;demo-p01"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-demo-p01.its.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-demo-p01.its.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIJAItajS+f73baMA0GCSqGSIb3DQEBBQUAMCUxIzAhBgNV\nBAMTGmxhZG9rMy1kZW1vLXAwMS5pdHMudW11LnNlMB4XDTE1MDIxNjA5MTcxMVoX\nDTI1MDIxMzA5MTcxMVowJTEjMCEGA1UEAxMabGFkb2szLWRlbW8tcDAxLml0cy51\nbXUuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDIg/AbltGbCIwl\nigV19B1LvI/LsxwShwfBMlwddIZKcXpiKr6CCHQcIy/s4jJmP9VcEAn5IcTiJ3uQ\n3192Xfr05GP49cgjYlTaCocYClec1beKmh/xtNEUMQNBV1smlFHAimOpkAi2e+8f\nbgNk+yL4YWuF3A81jl1FDLJePEmqvKpUt+/vVShZWS5YQ1SJIdvWCDNZLsQK6PNa\nOlPzYN+m71eySTbX4YG63Jc5+94vv02QgiMgvD++l7gEOLKTm2Q4/YjuKbxT1BbI\ngOhK52SRyKSBowdyumhWQ5Zc7263D0IhuQS28MvyNlOMTwy3LNjphESXPV/3AW7W\nhgMEDxJZAgMBAAGjczBxMFAGA1UdEQRJMEeCGmxhZG9rMy1kZW1vLXAwMS5pdHMu\ndW11LnNlhilodHRwczovL2xhZG9rMy1kZW1vLXAwMS5pdHMudW11LnNlL2d1aS1z\ncDAdBgNVHQ4EFgQUt0RFw19QKtNR3Z9ZT/Dn1XwOZVUwDQYJKoZIhvcNAQEFBQAD\nggEBAH0B53Xko14pBj+d04Gd6eJysSiphI0G40e7nSCuVWMw1p/gFB4jH5dH8F81\nWza/CuL/s07jy7ja8FLPMUSnWljWkMfApte3nIWUGGzRTtF7hTwwWjD06z2hz6ro\ny8mnHpKpOsKigmNMUlmKPvl1HH+vpZF2wrmf8flMkC6rzVgUtYSERAJKJXRtB6EG\nPb3b35NFMV+POeazhTLrL7uK14rPVpbJ7A9kHHolUti9GY5jmMRkJWXMm0bb/A/o\nd6zDyVH57UjisqGw7DbtNJ7fwDB6eO7QoIUmWfu7PnjOs4qzs1sSCkulJ7AYM7lG\n8iUhoKemz/OPmccMOhAACT8eUh4="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-demo-p01.its.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-p01.its.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-p01.its.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-p01.its.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-p01.its.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-p01.its.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-p01.its.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-demo-p01.its.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-demo-p01.its.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-demo-p01.its.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp-test.it.su.se/Shibboleth.sso",
    {
      "entity_id": "https://sp-test.it.su.se/Shibboleth.sso",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp-test.it.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp-test.it.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp-test.it.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp-test.it.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp-test.it.su.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp-test.it.su.se/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp-test.it.su.se/Shibboleth.sso/WAYF-test",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp-test.it.su.se/Shibboleth.sso/WAYF/wavelan",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp-test.it.su.se/Shibboleth.sso/WAYF/wavelan-test",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "4"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp-test.it.su.se/Shibboleth.sso/SWAMID",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "5"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shib-test-sp1"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJAMvj0WHMV86oMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDXNoaWItdGVzdC1zcDEwHhcNMTAxMDExMDkzMDE5WhcNMjAxMDA4MDkzMDE5\nWjAYMRYwFAYDVQQDEw1zaGliLXRlc3Qtc3AxMIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAwY+eWytRTYPU10j0R+GjbKQzJ09YeYGgSuIzNZhLdH0zy6By\nYyEtIITGsTorlL5HBYUtpFugc3jjoBuTv+QZoVnAsNfpbO1KM17cB3iX31drfYyU\nXSY20OZEaOuDoaE9Zt7YawDJ39vkwOLKEyglaqVzSdhH6gZoHEPSd0GOE/O5pMsu\nigmKs/dWoUhjS/u9R83jen7lOS39NJXKW23ghyZ36lgmSieACWCz5hMOKJ9ZnPys\nVa85dCMsNbaSDC/vm++jP7qY2I9aDJJHZhOEso+jqQPbRFjhy+pNSQYx2Z99r6ns\nfn1tJEgfKv+xfon4QkrrJ0CEySGVPfcEJw2xgwIDAQABozswOTAYBgNVHREEETAP\ngg1zaGliLXRlc3Qtc3AxMB0GA1UdDgQWBBTctR7mjh7i3u2cHU+rm99Fte/SdDAN\nBgkqhkiG9w0BAQUFAAOCAQEAFX12BjrajUciwGg79uHajf+oL1hYalnydk5fBqJ3\nWOebDsv/4Z1mcHH1WlT/fHf8KkjETiaAr0uuiLyIvFsMY4WASxZaqa4MTcTtJzHA\n9JrpGAscSKg2fIO8T6cmpKCPuMnH+e05NjWTdmxnR0bJGyn87NQdNNdhw9bgmRD4\nB/md9BUYzkXna3WPi1biNcqSgIwevoSb7JRPMu9LhrlkJyK325uGyblVcg0WCeZ0\nZZ++pFd6COZSWkvz3O0kbDXKOANgr4ZylWIxYz+Fj1y8i5PN5C85ojDAIvzZ93J5\n95GMOhu7uHgsRb4w5VyuXMlgrvHKh2S1C7zrtt86XKW2fw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=shib-test-sp1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shib-test-sp1"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJAMvj0WHMV86oMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDXNoaWItdGVzdC1zcDEwHhcNMTAxMDExMDkzMDE5WhcNMjAxMDA4MDkzMDE5\nWjAYMRYwFAYDVQQDEw1zaGliLXRlc3Qtc3AxMIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAwY+eWytRTYPU10j0R+GjbKQzJ09YeYGgSuIzNZhLdH0zy6By\nYyEtIITGsTorlL5HBYUtpFugc3jjoBuTv+QZoVnAsNfpbO1KM17cB3iX31drfYyU\nXSY20OZEaOuDoaE9Zt7YawDJ39vkwOLKEyglaqVzSdhH6gZoHEPSd0GOE/O5pMsu\nigmKs/dWoUhjS/u9R83jen7lOS39NJXKW23ghyZ36lgmSieACWCz5hMOKJ9ZnPys\nVa85dCMsNbaSDC/vm++jP7qY2I9aDJJHZhOEso+jqQPbRFjhy+pNSQYx2Z99r6ns\nfn1tJEgfKv+xfon4QkrrJ0CEySGVPfcEJw2xgwIDAQABozswOTAYBgNVHREEETAP\ngg1zaGliLXRlc3Qtc3AxMB0GA1UdDgQWBBTctR7mjh7i3u2cHU+rm99Fte/SdDAN\nBgkqhkiG9w0BAQUFAAOCAQEAFX12BjrajUciwGg79uHajf+oL1hYalnydk5fBqJ3\nWOebDsv/4Z1mcHH1WlT/fHf8KkjETiaAr0uuiLyIvFsMY4WASxZaqa4MTcTtJzHA\n9JrpGAscSKg2fIO8T6cmpKCPuMnH+e05NjWTdmxnR0bJGyn87NQdNNdhw9bgmRD4\nB/md9BUYzkXna3WPi1biNcqSgIwevoSb7JRPMu9LhrlkJyK325uGyblVcg0WCeZ0\nZZ++pFd6COZSWkvz3O0kbDXKOANgr4ZylWIxYz+Fj1y8i5PN5C85ojDAIvzZ93J5\n95GMOhu7uHgsRb4w5VyuXMlgrvHKh2S1C7zrtt86XKW2fw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=shib-test-sp1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp-test.it.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp-test.it.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp-test.it.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp-test.it.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp-test.it.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp-test.it.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp-test.it.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp-test.it.su.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp-test.it.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp-test.it.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://rcn.idm.oclc.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Support Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Support Desk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://rcn.idm.oclc.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-12T12:35:02Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Royal College of Nursing Hosted EZProxy"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oclc.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "OCLC (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://login.rcn.idm.oclc.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.rcn.idm.oclc.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.rcn.idm.oclc.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.rcn.idm.oclc.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEFzCCAv+gAwIBAgIBAjANBgkqhkiG9w0BAQUFADBgMRswGQYDVQQDFBIqLnJj\n\t\t\t\t\t\tbi5pZG0ub2NsYy5vcmcxCzAJBgNVBAYTAlVLMQ0wCwYDVQQKEwRPQ0xDMSUwIwYJ\n\t\t\t\t\t\tKoZIhvcNAQkBFhZjYXJsLnByZW50aWNlQG9jbGMub3JnMB4XDTE2MDQxMTEzNDQz\n\t\t\t\t\t\tOVoXDTI2MDQxMTEzNDQzOVowYDEbMBkGA1UEAxQSKi5yY24uaWRtLm9jbGMub3Jn\n\t\t\t\t\t\tMQswCQYDVQQGEwJVSzENMAsGA1UEChMET0NMQzElMCMGCSqGSIb3DQEJARYWY2Fy\n\t\t\t\t\t\tbC5wcmVudGljZUBvY2xjLm9yZzCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAMXWL7bjTexVVPiI831U717qpqfi3aMLpqcdGEV2J06Bb8odT78zJYiyRngz\n\t\t\t\t\t\tDqQ7W4XURyV/Delos6poAsBVTcYKyF1Wql9MEsUwlmy7Mz2OvPRJzGenms8NEiZV\n\t\t\t\t\t\t0QjVl2BuDxZvLthJ8aB/gCGpfdM3df1y3U0VR7ym27+TC+gan2IacjpvIYEBxov8\n\t\t\t\t\t\tFczYhIEmHixpjhM6UB/HzpaN51LIkrj+UNrIiegAUOOazILBn5mw2Ys9bpaV2Qgl\n\t\t\t\t\t\t9b6anOXHWCtvjaylDBCaq33ggoeatFLKhah/TUDCX5I1ArgTpvR6YYoqOn8Q49P+\n\t\t\t\t\t\tZbpT7voKx9hf5vLamFslVTjXOa0CAwEAAaOB2zCB2DAdBgNVHQ4EFgQUHxsxUqQC\n\t\t\t\t\t\t9AcG09pN54mao1Mn6LUwgYkGA1UdIwSBgTB/gBQfGzFSpAL0BwbT2k3niZqjUyfo\n\t\t\t\t\t\ttaFkpGIwYDEbMBkGA1UEAxQSKi5yY24uaWRtLm9jbGMub3JnMQswCQYDVQQGEwJV\n\t\t\t\t\t\tSzENMAsGA1UEChMET0NMQzElMCMGCSqGSIb3DQEJARYWY2FybC5wcmVudGljZUBv\n\t\t\t\t\t\tY2xjLm9yZ4IBAjAMBgNVHRMEBTADAQH/MB0GA1UdEQQWMBSCEioucmNuLmlkbS5v\n\t\t\t\t\t\tY2xjLm9yZzANBgkqhkiG9w0BAQUFAAOCAQEAZouYj67gSFTN8UQo2ciUachtCF0m\n\t\t\t\t\t\tkdFxc8lzKSf7YMXycxB4bhMR7z5Mpd9U6fNE19k3HOIFk4rOHFHHR6scS1CAMXtp\n\t\t\t\t\t\tjYAlaUd287OWBuV9SR/1I2SvOOcdU/3QkE12aUx+nYRN2LZOg+ItCfbcCHrjqcPO\n\t\t\t\t\t\tKhZKE9dBU3wC9kxd1mOjQb9J0sfnx9UPO/tJ0omsYLu5Oo2ipJXLcIpp+c+DhSsj\n\t\t\t\t\t\twz9rC6xduJUyMzKdnHtXbjzqOHkyz7PifkloWGPghtcbE9EbLfKtcnifJy471Qj7\n\t\t\t\t\t\t29nmJEWFadGcpOrHzgA7pkSGD7vG155lmsu/4XrD4qBY2gs/VToTDp9epg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://login.rcn.idm.oclc.org/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://ladok3-14.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-14.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-14.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-14.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-14.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-14.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-14.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-14.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-14.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;14"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;14"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-14.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-14.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJAMraIxt6r4wIMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0xNC5sYWRvay51bXUuc2UwHhcNMTQwOTAxMTQ0NTE5WhcNMjQw\nODI5MTQ0NTE5WjAhMR8wHQYDVQQDExZsYWRvazMtMTQubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuneYM2u3q9KfrDJ3Br05CDvX\nMXDNJEqoEOvlS5wJKTS/27k/xnJ5ZbBr0QloMMEwPJmCDGN8k/CZnkRJxZy14NM9\nREuw3oFnRaMdx2WTtEsZtp+v0FfpZY8RZhiO5/HeV6Y3tmqFjjLPFJQ/pVaa9Sy/\naR73B0CBYGKbD2wbx5HPw677ZsefIUTLu6Iq6kP/5Q9jQIuY/DyqqR5g3hf7HWJu\no1Ou/mS6Mu9+/7EKkzRz2N4mAgIkyXVEGliXowO28uJRnp7NfLtjDsXTB7p3AO7V\n3dknIaWdErLpz7iacWLFVE5p0AM4cW03y/OQYifdtbA8k9y1ZPdy4GcR50YtUQID\nAQABo2swaTBIBgNVHREEQTA/ghZsYWRvazMtMTQubGFkb2sudW11LnNlhiVodHRw\nczovL2xhZG9rMy0xNC5sYWRvay51bXUuc2UvZ3VpLXNwMB0GA1UdDgQWBBTi4gO+\nP0+jMRiwvLuKWPJcN/EdVzANBgkqhkiG9w0BAQUFAAOCAQEAACYcglylGp+N5gwl\nkmgNj42YadDudq/eyCuHrpU7KZ3hIqOZ8wwIKmU+9D8UL12sCfYd70XklJB3c+Ni\nau2puZbkI/1Ct8rLAmZ92MJq+a2a1JPSv/sRh0u0oDoLCHYMy5K0yyl7ts8ubftk\nZBssdObqa2ARYLJPQDanEUICxEKmmLiEulBi6QfhT78T2WifCiqa4tcsNV7gy6qP\n4Jarl2nQZwi0Qy+Ve5tuupzF+iI+ApUJ9PRUiFZdMHVXrBuETXMMHsGPzGxQamz0\nZawaB8LDSq/DJSsnlbgx1vvzjoM+VK7YcZrulavQvskO8NW3PeUnA3/HIHFNsTwD\no+yvpw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-14.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-14.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-14.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-14.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-14.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-14.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-14.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-14.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-14.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-14.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.korp.csc.fi/",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lind\u00e9n"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:fin-clarin@helsinki.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Krister"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Matthiesen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kielipankki@csc.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Aalto"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kielipankki@csc.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tero"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Niemi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jyrki.niemi@helsinki.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jyrki"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.korp.csc.fi/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.csc.fi/english/institutions/haka/instructions/join/eduGAINRegistrationStatement/"
              }
            ],
            "registration_authority": "http://www.csc.fi/haka",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CSC - Tieteen tietotekniikan keskus Oy"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CSC - IT Center for Science Ltd."
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CSC - Tieteen tietotekniikan keskus Oy"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csc.fi"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csc.fi"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csc.fi"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CSC - Tieteen tietotekniikan keskus Oy"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CSC - IT Center for Science Ltd."
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CSC - Tieteen tietotekniikan keskus Oy"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://korp.csc.fi/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://spraakbanken.gu.se/swe/korp-info"
                  }
                ],
                "display_name": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Konkordanssihakuohjelma tekstiaineistolle"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Concordance search service for text corpora"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "T\u00e4ll\u00e4 ty\u00f6kalulla voit tutkia tekstikorpuksia."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "With this service you can study text corpora."
                  }
                ],
                "logo": [
                  {
                    "text": "https://korp.csc.fi/img/korplogo.png",
                    "height": "66",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "168"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://korp.csc.fi/privacy-policy.html"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://korp.csc.fi/privacy-policy.html"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://korp.csc.fi/privacy-policy.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEYzCCA0ugAwIBAgIQTmDBZrbiqJFnGKHn80dL1zANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMTIxMzAwMDAwMFoXDTE2MTIxMjIzNTk1OVowOTEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRQwEgYDVQQDEwtrb3JwLmNzYy5m\naTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANU16/1jE06KKH6uErmq\ne2wE5u+8SkWqR4Gks+iH67OiPTgoPSVfx1t55FHDUl1zQjijwcvejH26lYIpS7Ts\njs1MGcjcgEt1qFDDQ/eC6931hIg1jRa0PF/cxFjP9qEcd/I7UxuyM5QJga4pfl/o\nIHSL9oPYi5iCJ6qoC3dgNy0glMiisLkKyOKOHIXYzfAdMlIfRAMGCDAnDj3Kw4wK\nzv+RCWSGPEKHxfnPZwY8fgUs0vugICJBfQkSliUQm9P9l9Pt/8PP3XoIzgfXmxKK\nVQg/3EW+u2dnAzV1OKNrbJAajCJYL4VuGejWE7y8x+ixTqFCCPBT1cFZFWgFnzsh\nYi0CAwEAAaOCAWgwggFkMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdXR+qQ47nt\nMB0GA1UdDgQWBBTkZV9BIXGhYb67UVmwNByxJxsAITAOBgNVHQ8BAf8EBAMCBaAw\nDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwIgYD\nVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0fBDMwMTAvoC2g\nK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcmwwbQYI\nKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50ZXJlbmEu\nb3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29jc3AudGNz\nLnRlcmVuYS5vcmcwFgYDVR0RBA8wDYILa29ycC5jc2MuZmkwDQYJKoZIhvcNAQEF\nBQADggEBAJClAngseLp5qnRUj2iFSlNVccoP9KZKhLaeqiUk6vvwNdyetfMu9Txi\nvllrbfIaoVMvcA3nE5lfWEAlpvoqnQO/wmDv3ObX/XLJpXqSFpNpDOllhEbVeylT\nv8qqjG84Y4OUAd46zhiFpXr+6InhbkahABizqoXs2/aLm3nutf8rWzwFQqm+8YLE\neLvEROIn209q+8M0V95avRxK1/wTTqwTnEGlGfRU5aTct+hLpJIRQS1DsAJpVDLU\neeQKhPUjOTj9UPCeCE8rjrLqJ3pBtqlfhwUkfbIpUeGbYh9FI3zJNDKLmwCGS0g+\n5G7muSfVNRBDgubGawMy3pYMrrCOxB4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGKjCCBRKgAwIBAgIQCxa0kBsonBX338rpeuui2DANBgkqhkiG9w0BAQsFADBk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"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://korp.csc.fi/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Korp on kielitutkijoille tarkoitettu tyokalu, jolla voi tutkia tekstiaineistoja."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Korp is a user interface for language researchers to examine text material."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Korp - hakuohjelma tekstiaineistoille"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Korp - search service for text material"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://elearning.asnet.am/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hayrapetyan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:andranik@ipia.sci.am"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andranik"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://elearning.asnet.am/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2015-08-22T12:52:43Z",
            "registration_authority": "https://aai.asnet.am",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ASNET-AM"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.asnet.am/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Academic Scientific Network of Armenia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://elearning.asnet.am/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://elearning.asnet.am/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://elearning.asnet.am/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://elearning.asnet.am/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://elearning.asnet.am/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://elearning.asnet.am/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://elearning.asnet.am/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://elearning.asnet.am/moodle/"
                  }
                ],
                "description": [
                  {
                    "lang": "hy",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ASNET-AM E-Learning  service provides online courses for the students of the National Academy of Sciences of the Republic of Armenia and beyond in Moodle. Moodle is a learning platform designed to provide educators, administrators and learners with a single robust, secure and integrated system to create personalised learning environments."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ASNET-AM E-Learning Platform"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "elearning.asnet.am"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.elearning.asnet.am"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFpjCCBI6gAwIBAgIRALYbJfMx2YKNrR/xrgIpYdYwDQYJKoZIhvcNAQELBQAw\ngZAxCzAJBgNVBAYTAkdCMRswGQYDVQQIExJHcmVhdGVyIE1hbmNoZXN0ZXIxEDAO\nBgNVBAcTB1NhbGZvcmQxGjAYBgNVBAoTEUNPTU9ETyBDQSBMaW1pdGVkMTYwNAYD\nVQQDEy1DT01PRE8gUlNBIERvbWFpbiBWYWxpZGF0aW9uIFNlY3VyZSBTZXJ2ZXIg\nQ0EwHhcNMTUwNTE4MDAwMDAwWhcNMTgwNTE3MjM1OTU5WjCBoDEhMB8GA1UECxMY\nRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMUkwRwYDVQQLE0BIb3N0ZWQgYnkgSW5z\ndGl0dXRlIGZvciBJbmZvcm1hdGljcyBhbmQgQXV0b21hdGlvbiBQcm9ibGVtcyBO\nQVMuMRMwEQYDVQQLEwpDT01PRE8gU1NMMRswGQYDVQQDExJlbGVhcm5pbmcuYXNu\nZXQuYW0wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDEXMgh+DkGHpsu\nYD8CDbvKzAK9IGgmxviLfBCtGZi4E0EAwyoJfgLEGNH8wxWQkAPhhiaBiJqPjZAX\nJ4RqON8Y3RDFY0zAt2fqF7WRjmHfrVWoc3m6nusGdRLV/MZC/iuE7lVaHQ+tSqS6\nzLib4lO6WtXsBz+CazYCOAi7qE88zFwTsanaa/ule6RxuTBjpIKrS9igN5yhDgFx\nsZIJNIKrksfpzhsiIk2uIA+pql3GE+z3CEsRAJemCoUyv3qm8VvXh/+H15PZqK/i\n6Iwb6R1GubkBilA5cVocxKA1pc4NHhh3Y+Q02EmP6FE0mVVnDqf0RAlBpnkj3DCD\nJ13UyO1rAgMBAAGjggHnMIIB4zAfBgNVHSMEGDAWgBSQr2o6lFoL2JDqElZz30O0\nOija5zAdBgNVHQ4EFgQU3NLawTnsQzZy5tclxTYAwXdl868wDgYDVR0PAQH/BAQD\nAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMC\nME8GA1UdIARIMEYwOgYLKwYBBAGyMQECAgcwKzApBggrBgEFBQcCARYdaHR0cHM6\nLy9zZWN1cmUuY29tb2RvLmNvbS9DUFMwCAYGZ4EMAQIBMFQGA1UdHwRNMEswSaBH\noEWGQ2h0dHA6Ly9jcmwuY29tb2RvY2EuY29tL0NPTU9ET1JTQURvbWFpblZhbGlk\nYXRpb25TZWN1cmVTZXJ2ZXJDQS5jcmwwgYUGCCsGAQUFBwEBBHkwdzBPBggrBgEF\nBQcwAoZDaHR0cDovL2NydC5jb21vZG9jYS5jb20vQ09NT0RPUlNBRG9tYWluVmFs\naWRhdGlvblNlY3VyZVNlcnZlckNBLmNydDAkBggrBgEFBQcwAYYYaHR0cDovL29j\nc3AuY29tb2RvY2EuY29tMDUGA1UdEQQuMCyCEmVsZWFybmluZy5hc25ldC5hbYIW\nd3d3LmVsZWFybmluZy5hc25ldC5hbTANBgkqhkiG9w0BAQsFAAOCAQEAQxf5uG7Q\n8WZOmAvDH46Zsn8AmgBe45xtpVpqipYyaVwYvkIAYsPBCA7m8sjeJjGyafLxBn4t\nj+p+aLdLQG1TAcsZZkMya4ELgvYpx4q0b1hhxel3dnV/gr1dhmTehSaNM2R4FOL9\ndGguvuqP9EnVqEexXN0AG2XRDQhn7LpwjGj1EjDlQ8+8lYBFvXh1RPsdWi7/U4Yp\n9zM1sUMRewMmlDlpizbjRL9y3YdQU0eG7z7b02n+Ym+atm6A6giXA9YfuCf/4xP7\nz1vrYPooAcnln7HnvUGEQ1mw32N/nRkJA8dDxVaU8d0WFH4QVUuJXt0pdNpVJ3Uh\n4ilH5zaIpJbAkg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFpjCCBI6gAwIBAgIRALYbJfMx2YKNrR/xrgIpYdYwDQYJKoZIhvcNAQELBQAw\ngZAxCzAJBgNVBAYTAkdCMRswGQYDVQQIExJHcmVhdGVyIE1hbmNoZXN0ZXIxEDAO\nBgNVBAcTB1NhbGZvcmQxGjAYBgNVBAoTEUNPTU9ETyBDQSBMaW1pdGVkMTYwNAYD\nVQQDEy1DT01PRE8gUlNBIERvbWFpbiBWYWxpZGF0aW9uIFNlY3VyZSBTZXJ2ZXIg\nQ0EwHhcNMTUwNTE4MDAwMDAwWhcNMTgwNTE3MjM1OTU5WjCBoDEhMB8GA1UECxMY\nRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMUkwRwYDVQQLE0BIb3N0ZWQgYnkgSW5z\ndGl0dXRlIGZvciBJbmZvcm1hdGljcyBhbmQgQXV0b21hdGlvbiBQcm9ibGVtcyBO\nQVMuMRMwEQYDVQQLEwpDT01PRE8gU1NMMRswGQYDVQQDExJlbGVhcm5pbmcuYXNu\nZXQuYW0wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDEXMgh+DkGHpsu\nYD8CDbvKzAK9IGgmxviLfBCtGZi4E0EAwyoJfgLEGNH8wxWQkAPhhiaBiJqPjZAX\nJ4RqON8Y3RDFY0zAt2fqF7WRjmHfrVWoc3m6nusGdRLV/MZC/iuE7lVaHQ+tSqS6\nzLib4lO6WtXsBz+CazYCOAi7qE88zFwTsanaa/ule6RxuTBjpIKrS9igN5yhDgFx\nsZIJNIKrksfpzhsiIk2uIA+pql3GE+z3CEsRAJemCoUyv3qm8VvXh/+H15PZqK/i\n6Iwb6R1GubkBilA5cVocxKA1pc4NHhh3Y+Q02EmP6FE0mVVnDqf0RAlBpnkj3DCD\nJ13UyO1rAgMBAAGjggHnMIIB4zAfBgNVHSMEGDAWgBSQr2o6lFoL2JDqElZz30O0\nOija5zAdBgNVHQ4EFgQU3NLawTnsQzZy5tclxTYAwXdl868wDgYDVR0PAQH/BAQD\nAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMC\nME8GA1UdIARIMEYwOgYLKwYBBAGyMQECAgcwKzApBggrBgEFBQcCARYdaHR0cHM6\nLy9zZWN1cmUuY29tb2RvLmNvbS9DUFMwCAYGZ4EMAQIBMFQGA1UdHwRNMEswSaBH\noEWGQ2h0dHA6Ly9jcmwuY29tb2RvY2EuY29tL0NPTU9ET1JTQURvbWFpblZhbGlk\nYXRpb25TZWN1cmVTZXJ2ZXJDQS5jcmwwgYUGCCsGAQUFBwEBBHkwdzBPBggrBgEF\nBQcwAoZDaHR0cDovL2NydC5jb21vZG9jYS5jb20vQ09NT0RPUlNBRG9tYWluVmFs\naWRhdGlvblNlY3VyZVNlcnZlckNBLmNydDAkBggrBgEFBQcwAYYYaHR0cDovL29j\nc3AuY29tb2RvY2EuY29tMDUGA1UdEQQuMCyCEmVsZWFybmluZy5hc25ldC5hbYIW\nd3d3LmVsZWFybmluZy5hc25ldC5hbTANBgkqhkiG9w0BAQsFAAOCAQEAQxf5uG7Q\n8WZOmAvDH46Zsn8AmgBe45xtpVpqipYyaVwYvkIAYsPBCA7m8sjeJjGyafLxBn4t\nj+p+aLdLQG1TAcsZZkMya4ELgvYpx4q0b1hhxel3dnV/gr1dhmTehSaNM2R4FOL9\ndGguvuqP9EnVqEexXN0AG2XRDQhn7LpwjGj1EjDlQ8+8lYBFvXh1RPsdWi7/U4Yp\n9zM1sUMRewMmlDlpizbjRL9y3YdQU0eG7z7b02n+Ym+atm6A6giXA9YfuCf/4xP7\nz1vrYPooAcnln7HnvUGEQ1mw32N/nRkJA8dDxVaU8d0WFH4QVUuJXt0pdNpVJ3Uh\n4ilH5zaIpJbAkg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://elearning.asnet.am/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://elearning.asnet.am/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://elearning.asnet.am/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://elearning.asnet.am/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://elearning.asnet.am/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://elearning.asnet.am/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ASNET-AM E-Learning Platform"
                }
              ],
              "service_description": [
                {
                  "lang": "hy",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "ASNET-AM E-Learning  service provides online courses for the students of the National Academy of Sciences of the Republic of Armenia and beyond in Moodle. Moodle is a learning platform designed to provide educators, administrators and learners with a single robust, secure and integrated system to create personalised learning environments."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "uid",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ncirl.ie/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Duncan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:robert.duncan@ncirl.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Duncan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:robert.duncan@ncirl.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Duncan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:robert.duncan@ncirl.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ncirl.ie/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.heanet.ie/services/identity-access/edugate#join"
              }
            ],
            "registration_instant": "2011-02-09T00:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ncirl.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ncirl.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ncirl.ie/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ncirl.ie/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ncirl.ie/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ncirl.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://nci360.ncirl.ie/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "National College of Ireland"
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/nci.png",
                    "height": "124",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "124"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "National College of Ireland"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "ncirl.ie"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.34900526916922,-6.243662238121033"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.1.209.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUDymT+0qnFpj+1wBK67kpD4GOwBQwDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMaWRwLm5jaXJsLmllMB4XDTE0MDExNTEzNTQ0NloXDTM0\nMDExNTEzNTQ0NlowFzEVMBMGA1UEAxMMaWRwLm5jaXJsLmllMIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAypTiVM40mgEF79m5GylKgp+UZRRghVs6iPOc\ndClQNg52UCyORYQ/N5PPOJzJRUR97zeqlmNeH9su0tAgfZgbncw/vXklXJIAxIcL\nnwGyaZdTGyj/VDBtnxj5u8hLm5/5WwqEw2Jo6Jma5qfBmNFpSAOTfkSvtMxWCtqe\no8h1ni0AN4jKHaijAjrzLMutrlwHpgZDN+21s/9InCTdrWGlfUp3Mbl0yCxizPax\nIH3gGsO6nFt55/CNsA4ZTXVK1NzYWpuAubWzeuqM4DMLw0lMCOxCZ0/TTKNKft3p\n2gftS6oJriXVcd05tLVG0Th2bAQicl1mZ+OXkFc/a13kcR368wIDAQABo18wXTA8\nBgNVHREENTAzggxpZHAubmNpcmwuaWWGI2h0dHBzOi8vaWRwLm5jaXJsLmllL2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBQ1LNq1zEuMDzz7DnnOZ6nDSsxoVTANBgkq\nhkiG9w0BAQUFAAOCAQEAxaOejgfPiAEhBHErNLiWdvmzaxtjRp6zKfrIFVcFKEQx\neex6fyCNQ0XQMfPeber7EtAuk2AdidMxlYAgBMNp57oZnBuvYipO8LVn6qPpotoQ\nuqMQX4MYtEcIHnDdwZErO3CzKWG76PC5C5CM2G9eh7sahmP2F7EZshX+Wz45il1j\nvELnlgNrvB9nRAbI8OfYuUhrHCEQpoEcvGNoXtZfbRCYoA0RSKZzoLMP8+mtgrMN\nQoD56UPu/9sTcUyhMp+wrXLZE2YuAru5feZwGSOWMk+CKosq75DBJ6xlJKMEMpYe\nEpAWVSexjo2IWj8KAOEJOpUl5z8XsVybIWIR1IUvYw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "National College of Ireland"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://nci360.ncirl.ie"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National College of Ireland"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://confluence.its.umu.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://confluence.its.umu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://confluence.its.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://confluence.its.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://confluence.its.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://confluence.its.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://confluence.its.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://confluence.its.umu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://confluence.its.umu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://confluence.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "jira-confluence.its.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFTCCAf2gAwIBAgIJANANTmUUPjEwMA0GCSqGSIb3DQEBBQUAMCUxIzAhBgNV\nBAMTGmppcmEtY29uZmx1ZW5jZS5pdHMudW11LnNlMB4XDTEzMDgxNTA1NTcxNloX\nDTIzMDgxMzA1NTcxNlowJTEjMCEGA1UEAxMaamlyYS1jb25mbHVlbmNlLml0cy51\nbXUuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDtbJysWzyFP5Br\nIO8hMNjwARMQcNKErQBjlOm+ZZx/dFKLMPwxdpOlwvwFDcHnn+AohVM5dUygkFwk\nvGciClOR6QCnnubp93rvjZHVTGRJ5ZlzraVCOCl5lUkKSNIzCqDGfCbvyRvHcg1t\nbGBVJJbwWbXaqb3ZT/p2OI7+XP9uTzazIkDNbA9JL6xjRBnE2AljfCnmKTrS81Su\n/x7lmG+4Ji/H37jcJAdbtda05t2ARURwFKIXFIYr8CJklCTAxnh+T5qaV4n8apq/\nAceIfYiTc8FYlK9ptMkEFy2VkyQm/9Q+RU5ZDHLqPzqWnwDlx4kjnyWRBaB63zOY\nRe+R2A2nAgMBAAGjSDBGMCUGA1UdEQQeMByCGmppcmEtY29uZmx1ZW5jZS5pdHMu\ndW11LnNlMB0GA1UdDgQWBBTQvicuhivjhvST66h9a8LuowqZMDANBgkqhkiG9w0B\nAQUFAAOCAQEAMwQCeECnIAKZTd4mwWumokjmTEHaPR7njWVHsIdJZ36pKv9eIYZ+\nVAddlrhUH7LoQF0RgxkN4zoAlyDYlmcdVtmA58WAPdUFxziMznSGsV4MKrWZosIa\niYMLbcnsX7O3TJydO9nZZf8X7MWOMPHLEHB8+cInXHnAZqT+kZOiACJ5MQr4oSk4\nABpmWvKs9qsEa0DqR7wnaV4f3fS3xwbwTUb25v4ATi9vi5wkIUJwatVMNvJV4g/B\ndb1zTPxnsz/JyD/9EGp3qd1utQPgn1XZv+wDtIJwQ+8Kx31za5Cxnc7bxP2yhitT\nkcpkPw96Zj9HfRw2XGwo0pM+nRwYuw9WpA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=jira-confluence.its.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://confluence.its.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://confluence.its.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://confluence.its.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://confluence.its.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://confluence.its.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://confluence.its.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://confluence.its.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://confluence.its.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://confluence.its.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ukfed.ukpressonline.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mellis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alasdair@digitorial.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alasdair"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Raison"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dawn@digitorial.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dawn"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ukfed.ukpressonline.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-08-27T16:32:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UKPressOnline"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ukpressonline.co.uk/ukpressonline/open/aboutus.jsp"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Digitorial Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ukfed.ukpressonline.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ukfed.ukpressonline.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ukfed.ukpressonline.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ukfed.ukpressonline.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ukfed.ukpressonline.co.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHjCCAgagAwIBAgIJAPiDlYs5S2Y2MA0GCSqGSIb3DQEBBQUAMCgxJjAkBgNV\n\t\t\t\t\t\tBAMTHWRpZ2ktd2ViLXN2ci5kaWdpdG9yaWFsLmNvLnVrMB4XDTE0MDcwMTExMTY0\n\t\t\t\t\t\tNVoXDTM0MDYyNjExMTY0NVowKDEmMCQGA1UEAxMdZGlnaS13ZWItc3ZyLmRpZ2l0\n\t\t\t\t\t\tb3JpYWwuY28udWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDJqtxk\n\t\t\t\t\t\tXLaWpCtU00hwXbdTdF0bAXa5qA9NNHoD3Pc2SD+QAZCHFSNYUn5LkI2MNzKuD9Lo\n\t\t\t\t\t\tjF+R6dun5C6jaU8vtSJHaVLWJwNn6vfTLFidCyKAa/0fY+qSB46NNjSiXwmFNpiI\n\t\t\t\t\t\tSgy5HwDOJpC4avgA0nlO57BLs7Qal1is7/goZWodTwIPIzDU3bwmlNm0gJxR2UkX\n\t\t\t\t\t\tmZvmx6LPozYL6lbSfuY3MKfbRpfrCXAgH8xYW3F7jBxIhJuv7Rou6zAXhBj+Ss8h\n\t\t\t\t\t\t3bONUquNMZmQ0K0ngp2G4+XIJy99GDDZfCUKxeliu0OjA42B6iJJq+QRQo3PLyUz\n\t\t\t\t\t\t3h1Vaw5jqt9lQJc/AgMBAAGjSzBJMCgGA1UdEQQhMB+CHWRpZ2ktd2ViLXN2ci5k\n\t\t\t\t\t\taWdpdG9yaWFsLmNvLnVrMB0GA1UdDgQWBBTTnfZ7sgdhNZp0vUUtK2ZWGR9tqjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAtMa03ENgZE9c8LgdaiK4lLjbxXGEr16QAkScjodF\n\t\t\t\t\t\tVm0mO/Ohda2avbqFtRXU3u987dcZ9InQ+dCrtfXnU8qRjXc68YYA+ZrKhnMQXmMA\n\t\t\t\t\t\t9y9pDu8QxhMR+kQLTVAcseX1sStZYoxA7zboO3CZ/aDUvdvkVFHH5mlEZuzBeQys\n\t\t\t\t\t\t/7kzMosrFpe4dwQiHE9zk+tJjMHoEiHbN0xevID70j7rcO8NHUsYl6vkvqZRKcEJ\n\t\t\t\t\t\taMNyvJmu5u9z7IUYGESPox+4a4B4epdkdwHcOFw7/01URXfb19HfTNtKhS/tHw42\n\t\t\t\t\t\tC7xMZ7c4p7rZOnaeqwso9Zpf+yP9/7sNh9iKvS3kEvITAg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ukfed.ukpressonline.co.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ukfed.ukpressonline.co.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ukfed.ukpressonline.co.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ukfed.ukpressonline.co.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ukfed.ukpressonline.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ukfed.ukpressonline.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ukfed.ukpressonline.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ukfed.ukpressonline.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ukfed.ukpressonline.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ukfed.ukpressonline.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.upatras.gr/shibboleth-idp/",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "University of Patras NOC"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@upatras.gr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "University of Patras Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@upatras.gr"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.upatras.gr/shibboleth-idp/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGUTCCBbqgAwIBAgIDEyAFMA0GCSqGSIb3DQEBBQUAMIIBEjELMAkGA1UEBhMC\n                            RVMxEjAQBgNVBAgTCUJhcmNlbG9uYTESMBAGA1UEBxMJQmFyY2Vsb25hMSkwJwYD\n                            VQQKEyBJUFMgQ2VydGlmaWNhdGlvbiBBdXRob3JpdHkgcy5sLjEuMCwGA1UEChQl\n                            Z2VuZXJhbEBpcHNjYS5jb20gQy5JLkYuICBCLUI2MjIxMDY5NTEuMCwGA1UECxMl\n                            aXBzQ0EgQ0xBU0VBMSBDZXJ0aWZpY2F0aW9uIEF1dGhvcml0eTEuMCwGA1UEAxMl\n                            aXBzQ0EgQ0xBU0VBMSBDZXJ0aWZpY2F0aW9uIEF1dGhvcml0eTEgMB4GCSqGSIb3\n                            DQEJARYRZ2VuZXJhbEBpcHNjYS5jb20wHhcNMDkwOTIzMTIwMjUzWhcNMTEwOTIz\n                            MTIwMjUzWjCBjDELMAkGA1UEBhMCR1IxDzANBgNVBAgTBkFjaGFpYTEPMA0GA1UE\n                            BxMGUGF0cmFzMQ4wDAYDVQQKEwVVcG5ldDEQMA4GA1UECxMHVXBhdHJhczEVMBMG\n                            A1UEAxMMaWRwLnVwbmV0LmdyMSIwIAYJKoZIhvcNAQkBFhNob3N0bWFzdGVyQHVw\n                            bmV0LmdyMIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQDcF0nSwccAhSaiw6uK\n                            VdwSeROrjuy9TcmAA6U9dDZpK6gBNa0O9+T+ZnqjMliqeAAIlh552PGIvIy7rr8C\n                            vCKABjkiLBNVQbXDx7T7S6WCV5cNpMgNhKgrEkxaEcbtpZWkyG3bmnUxfKLVxAxf\n                            aHj0gVQzCFIQKekWpi3zEL6ogQIDAQABo4IDNjCCAzIwCQYDVR0TBAIwADARBglg\n                            hkgBhvhCAQEEBAMCBkAwCwYDVR0PBAQDAgP4MBMGA1UdJQQMMAoGCCsGAQUFBwMB\n                            MB0GA1UdDgQWBBSCuyH0W6XiqEAXs9WuxFiwM/0vKjAfBgNVHSMEGDAWgBQOB2DU\n                            OckbW12QeyPI0jSdSppGOTAeBgNVHREEFzAVgRNob3N0bWFzdGVyQHVwbmV0Lmdy\n                            MBwGA1UdEgQVMBOBEWdlbmVyYWxAaXBzY2EuY29tMHIGCWCGSAGG+EIBDQRlFmNP\n                            cmdhbml6YXRpb24gSW5mb3JtYXRpb24gTk9UIFZBTElEQVRFRC4gQ0xBU0VBMSBT\n                            ZXJ2ZXIgQ2VydGlmaWNhdGUgaXNzdWVkIGJ5IGh0dHBzOi8vd3d3Lmlwc2NhLmNv\n                            bS8wLwYJYIZIAYb4QgECBCIWIGh0dHBzOi8vd3d3Lmlwc2NhLmNvbS9pcHNjYTIw\n                            MDIvMEMGCWCGSAGG+EIBBAQ2FjRodHRwczovL3d3dy5pcHNjYS5jb20vaXBzY2Ey\n                            MDAyL2lwc2NhMjAwMkNMQVNFQTEuY3JsMEYGCWCGSAGG+EIBAwQ5FjdodHRwczov\n                            L3d3dy5pcHNjYS5jb20vaXBzY2EyMDAyL3Jldm9jYXRpb25DTEFTRUExLmh0bWw/\n                            MEMGCWCGSAGG+EIBBwQ2FjRodHRwczovL3d3dy5pcHNjYS5jb20vaXBzY2EyMDAy\n                            L3JlbmV3YWxDTEFTRUExLmh0bWw/MEEGCWCGSAGG+EIBCAQ0FjJodHRwczovL3d3\n                            dy5pcHNjYS5jb20vaXBzY2EyMDAyL3BvbGljeUNMQVNFQTEuaHRtbDCBgwYDVR0f\n                            BHwwejA5oDegNYYzaHR0cDovL3d3dy5pcHNjYS5jb20vaXBzY2EyMDAyL2lwc2Nh\n                            MjAwMkNMQVNFQTEuY3JsMD2gO6A5hjdodHRwOi8vd3d3YmFjay5pcHNjYS5jb20v\n                            aXBzY2EyMDAyL2lwc2NhMjAwMkNMQVNFQTEuY3JsMDIGCCsGAQUFBwEBBCYwJDAi\n                            BggrBgEFBQcwAYYWaHR0cDovL29jc3AuaXBzY2EuY29tLzANBgkqhkiG9w0BAQUF\n                            AAOBgQB7m5FR2tW+N/Iskdwfm18UsEPPowadokIKZrc4ml5d2q1hXAp2rBXs8Sv/\n                            NmnkmRIH/+c0gm0Ya7Ydomx9mEJZImb6rf1OlwZ6lnTw0U/5jPxcN8nA1TFipZGu\n                            +8nkhyWprjhjKQ0fRTEAgF8aDolvFrF3wcS10jiaXnBO3JP2TQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "upatras.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.upnet.gr:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.upnet.gr:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.upnet.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.upnet.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.upnet.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.upnet.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.upnet.gr:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.upnet.gr:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "upatras.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGUTCCBbqgAwIBAgIDEyAFMA0GCSqGSIb3DQEBBQUAMIIBEjELMAkGA1UEBhMC\n                            RVMxEjAQBgNVBAgTCUJhcmNlbG9uYTESMBAGA1UEBxMJQmFyY2Vsb25hMSkwJwYD\n                            VQQKEyBJUFMgQ2VydGlmaWNhdGlvbiBBdXRob3JpdHkgcy5sLjEuMCwGA1UEChQl\n                            Z2VuZXJhbEBpcHNjYS5jb20gQy5JLkYuICBCLUI2MjIxMDY5NTEuMCwGA1UECxMl\n                            aXBzQ0EgQ0xBU0VBMSBDZXJ0aWZpY2F0aW9uIEF1dGhvcml0eTEuMCwGA1UEAxMl\n                            aXBzQ0EgQ0xBU0VBMSBDZXJ0aWZpY2F0aW9uIEF1dGhvcml0eTEgMB4GCSqGSIb3\n                            DQEJARYRZ2VuZXJhbEBpcHNjYS5jb20wHhcNMDkwOTIzMTIwMjUzWhcNMTEwOTIz\n                            MTIwMjUzWjCBjDELMAkGA1UEBhMCR1IxDzANBgNVBAgTBkFjaGFpYTEPMA0GA1UE\n                            BxMGUGF0cmFzMQ4wDAYDVQQKEwVVcG5ldDEQMA4GA1UECxMHVXBhdHJhczEVMBMG\n                            A1UEAxMMaWRwLnVwbmV0LmdyMSIwIAYJKoZIhvcNAQkBFhNob3N0bWFzdGVyQHVw\n                            bmV0LmdyMIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQDcF0nSwccAhSaiw6uK\n                            VdwSeROrjuy9TcmAA6U9dDZpK6gBNa0O9+T+ZnqjMliqeAAIlh552PGIvIy7rr8C\n                            vCKABjkiLBNVQbXDx7T7S6WCV5cNpMgNhKgrEkxaEcbtpZWkyG3bmnUxfKLVxAxf\n                            aHj0gVQzCFIQKekWpi3zEL6ogQIDAQABo4IDNjCCAzIwCQYDVR0TBAIwADARBglg\n                            hkgBhvhCAQEEBAMCBkAwCwYDVR0PBAQDAgP4MBMGA1UdJQQMMAoGCCsGAQUFBwMB\n                            MB0GA1UdDgQWBBSCuyH0W6XiqEAXs9WuxFiwM/0vKjAfBgNVHSMEGDAWgBQOB2DU\n                            OckbW12QeyPI0jSdSppGOTAeBgNVHREEFzAVgRNob3N0bWFzdGVyQHVwbmV0Lmdy\n                            MBwGA1UdEgQVMBOBEWdlbmVyYWxAaXBzY2EuY29tMHIGCWCGSAGG+EIBDQRlFmNP\n                            cmdhbml6YXRpb24gSW5mb3JtYXRpb24gTk9UIFZBTElEQVRFRC4gQ0xBU0VBMSBT\n                            ZXJ2ZXIgQ2VydGlmaWNhdGUgaXNzdWVkIGJ5IGh0dHBzOi8vd3d3Lmlwc2NhLmNv\n                            bS8wLwYJYIZIAYb4QgECBCIWIGh0dHBzOi8vd3d3Lmlwc2NhLmNvbS9pcHNjYTIw\n                            MDIvMEMGCWCGSAGG+EIBBAQ2FjRodHRwczovL3d3dy5pcHNjYS5jb20vaXBzY2Ey\n                            MDAyL2lwc2NhMjAwMkNMQVNFQTEuY3JsMEYGCWCGSAGG+EIBAwQ5FjdodHRwczov\n                            L3d3dy5pcHNjYS5jb20vaXBzY2EyMDAyL3Jldm9jYXRpb25DTEFTRUExLmh0bWw/\n                            MEMGCWCGSAGG+EIBBwQ2FjRodHRwczovL3d3dy5pcHNjYS5jb20vaXBzY2EyMDAy\n                            L3JlbmV3YWxDTEFTRUExLmh0bWw/MEEGCWCGSAGG+EIBCAQ0FjJodHRwczovL3d3\n                            dy5pcHNjYS5jb20vaXBzY2EyMDAyL3BvbGljeUNMQVNFQTEuaHRtbDCBgwYDVR0f\n                            BHwwejA5oDegNYYzaHR0cDovL3d3dy5pcHNjYS5jb20vaXBzY2EyMDAyL2lwc2Nh\n                            MjAwMkNMQVNFQTEuY3JsMD2gO6A5hjdodHRwOi8vd3d3YmFjay5pcHNjYS5jb20v\n                            aXBzY2EyMDAyL2lwc2NhMjAwMkNMQVNFQTEuY3JsMDIGCCsGAQUFBwEBBCYwJDAi\n                            BggrBgEFBQcwAYYWaHR0cDovL29jc3AuaXBzY2EuY29tLzANBgkqhkiG9w0BAQUF\n                            AAOBgQB7m5FR2tW+N/Iskdwfm18UsEPPowadokIKZrc4ml5d2q1hXAp2rBXs8Sv/\n                            NmnkmRIH/+c0gm0Ya7Ydomx9mEJZImb6rf1OlwZ6lnTw0U/5jPxcN8nA1TFipZGu\n                            +8nkhyWprjhjKQ0fRTEAgF8aDolvFrF3wcS10jiaXnBO3JP2TQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Patras"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u03a0\u03b1\u03bd\u03b5\u03c0\u03b9\u03c3\u03c4\u03ae\u03bc\u03b9\u03bf \u03a0\u03ac\u03c4\u03c1\u03b1\u03c2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.upatras.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.upatras.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Patras"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u03a0\u03b1\u03bd\u03b5\u03c0\u03b9\u03c3\u03c4\u03ae\u03bc\u03b9\u03bf \u03a0\u03ac\u03c4\u03c1\u03b1\u03c2"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://helium.jcu.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Marek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jmarek@jcu.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://helium.jcu.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2010-09-15T12:40:35Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/university"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUT352/cuSCyIoBXXvytfYj0l2xeAwDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNaGVsaXVtLmpjdS5jejAeFw0xMDA1MDMwOTQ1MDZaFw0z\nMDA1MDMwOTQ1MDZaMBgxFjAUBgNVBAMTDWhlbGl1bS5qY3UuY3owggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCVeR3QqDjqBUa8PvQHUCAYk16vc/tCuGH0\n330jNRPCXp4/OBBH8Z/jNe1ikVgzYXnN8qgf8ZqVXMDhdZD4T2Ewhhg1ZoqasCIV\n8lGFGCdGkQlTfM1NZWLcXtC/aB99EtV9yXowIHWZiggW5PLB2ggGxn4hk7EMEywa\nIKJ+rUSzx0cXgxNQMrHTcYtCVOlwKWbAk8l9ZlKllSgekwyhXknx9kXAIkr12N3h\nwHixnVqaMNAHkb4Ghcx66HTByRQhvh5g5mDcGV9ZhwSTPrXsfRyD06P7fVzCZjV8\nFiuNxgdNQ9Q+PvZcy/sH5Gxdu1i4VaJvPK9Gk3jCnDaXmBTT/UwlAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDWhlbGl1bS5qY3UuY3qGJGh0dHBzOi8vaGVsaXVtLmpjdS5j\nei9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUl6GU8/XvLl9I4+OaJjqAEW22yY8w\nDQYJKoZIhvcNAQEFBQADggEBAC5Rgn6IZByCrNOSqggl7j1T254ZzUKauG7joWW8\nHvrPcYWQsl4OU+FHErx4GAwOq9YpKpoJzcLGX3XBCJyo+Pw9ohbqWAgyBCYyBTQh\nmWV8+7BTWEZ6RCnGKcWfNRGg8mEMB6y+7YNdm+60YdCrbVasOstlDKoqTOa1gwD8\nfKpd1AzFldX7PwxwagGWYycYkSDXoS7nADEFzgn3cGlU9QnW4YtBBp30sOJjGgTj\nQm2JkTDk/UKsYKYDrHoZ4vk71XTFLAgsCfBE2/2VJpIkOutXtqz78E07C4y2+4O3\nFcCuzEOMSqDr2DwNtwLU1t+o7IUndlfTGRBD+LfXQBWxuEo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "jcu.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://helium.jcu.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://helium.jcu.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://helium.jcu.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://helium.jcu.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://helium.jcu.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://helium.jcu.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://helium.jcu.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://helium.jcu.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://helium.jcu.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://helium.jcu.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://helium.jcu.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "jcu.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.jcu.cz/?set_language=en"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.jcu.cz"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for SBU in Cesk\u00e9 Budejovice"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro J\u010cU v \u010cesk\u00fdch Bud\u011bjovic\u00edch"
                  }
                ],
                "logo": [
                  {
                    "text": "http://helium.jcu.cz/logo-ju-40.png",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "38"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of South Bohemia in Ceske Budejovice"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Jiho\u010desk\u00e1 univerzita v \u010cesk\u00fdch Bud\u011bjovic\u00edch"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUT352/cuSCyIoBXXvytfYj0l2xeAwDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNaGVsaXVtLmpjdS5jejAeFw0xMDA1MDMwOTQ1MDZaFw0z\nMDA1MDMwOTQ1MDZaMBgxFjAUBgNVBAMTDWhlbGl1bS5qY3UuY3owggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCVeR3QqDjqBUa8PvQHUCAYk16vc/tCuGH0\n330jNRPCXp4/OBBH8Z/jNe1ikVgzYXnN8qgf8ZqVXMDhdZD4T2Ewhhg1ZoqasCIV\n8lGFGCdGkQlTfM1NZWLcXtC/aB99EtV9yXowIHWZiggW5PLB2ggGxn4hk7EMEywa\nIKJ+rUSzx0cXgxNQMrHTcYtCVOlwKWbAk8l9ZlKllSgekwyhXknx9kXAIkr12N3h\nwHixnVqaMNAHkb4Ghcx66HTByRQhvh5g5mDcGV9ZhwSTPrXsfRyD06P7fVzCZjV8\nFiuNxgdNQ9Q+PvZcy/sH5Gxdu1i4VaJvPK9Gk3jCnDaXmBTT/UwlAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDWhlbGl1bS5qY3UuY3qGJGh0dHBzOi8vaGVsaXVtLmpjdS5j\nei9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUl6GU8/XvLl9I4+OaJjqAEW22yY8w\nDQYJKoZIhvcNAQEFBQADggEBAC5Rgn6IZByCrNOSqggl7j1T254ZzUKauG7joWW8\nHvrPcYWQsl4OU+FHErx4GAwOq9YpKpoJzcLGX3XBCJyo+Pw9ohbqWAgyBCYyBTQh\nmWV8+7BTWEZ6RCnGKcWfNRGg8mEMB6y+7YNdm+60YdCrbVasOstlDKoqTOa1gwD8\nfKpd1AzFldX7PwxwagGWYycYkSDXoS7nADEFzgn3cGlU9QnW4YtBBp30sOJjGgTj\nQm2JkTDk/UKsYKYDrHoZ4vk71XTFLAgsCfBE2/2VJpIkOutXtqz78E07C4y2+4O3\nFcCuzEOMSqDr2DwNtwLU1t+o7IUndlfTGRBD+LfXQBWxuEo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of South Bohemia"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Jiho\u010desk\u00e1 univerzita v \u010cesk\u00fdch Bud\u011bjovic\u00edch"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jcu.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of South Bohemia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib1.uwplatt.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sherer@uwplatt.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike Sherer"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@uwplatt.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UW-Platteville Help desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "perkinsm@uwplatt.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike Perkins"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "perkinsm@uwplatt.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike Perkins"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib1.uwplatt.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib1.uwplatt.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib1.uwplatt.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib1.uwplatt.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib1.uwplatt.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib1.uwplatt.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uwplatt.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uwplatt.edu/about"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Wisconsin - Platteville"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Wisconsin-Platteville Shibboleth IdP Server"
                  }
                ],
                "logo": [
                  {
                    "text": "https://shib1.uwplatt.edu/logo.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://kb.uwplatt.edu/page.php?id=36091"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAP8Xbwf1Tuc/Rp4EvdoU1gZkcvOrMA0GCSqGSIb3DQEB\nBQUAMBwxGjAYBgNVBAMTEXNoaWIxLnV3cGxhdHQuZWR1MB4XDTE0MDUwOTE1MDcw\nMloXDTM0MDUwOTE1MDcwMlowHDEaMBgGA1UEAxMRc2hpYjEudXdwbGF0dC5lZHUw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCYdo9R90GljPUE807is1EP\nM7R41IbOQtGq6FbNae/xcSfxFvVNg5ONVfCFXfNK0PiMWP8uLviE6hw4AJhHTwLX\npscbllJYXb8wQl4fIyNfakuHlmuU3gPLflzeXvnJ+4wCFFv+R2wGkbZ4O01ZrGF/\n99pPyHIL1nmDPFCYxjbePYq8f0zebH/Mq+BSXDcV6qx2mrN5vJBvQ5K8Na9wQdsB\nmIt2Mv93QwN9tjif9H1kg7W1WIRAzgNFbe0x99g734OA06QHOW6lx7Nm8RaH9/8W\nNAsJpzpk3gmWrllI0/Od8Q9sAjF8DwFbkYUURTow1wiUP6mlue+gEDK8L7xqL+xv\nAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEXNoaWIxLnV3cGxhdHQuZWR1hihodHRwczov\nL3NoaWIxLnV3cGxhdHQuZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBR83GAw\nMgixxu/yNpTRTW6+t5dg0jANBgkqhkiG9w0BAQUFAAOCAQEAApu/L+9PoY2VYteQ\n+ragjqINEpKn8BN52Agi6uJSb1+YJOSIi2MpTVk0VmASN6TEqojOuOjd52KCAl98\nIvxu8sozeR2oOwPU/A0i8y2KsYZvrhadWvrdT1wLau6yDY93VY57nDTQap7ZHCIy\n8cR3OtSUZ/27XN0+T9h+eqR+IOtL0FxQQ77A8YKAsNyiMaxV2VnT4ATM0aR31fee\no/7CBCSFgT8NxLha7tuxYka6zYh9CymL5hEEDDrE7+j/IqYdgNrnVQORMei3SsZR\nrJ5rLt9TKWB4CB+6csEOqQ0kMSk5t8Sqr2p+97SSv8Og+nXdrE9NabrSNFB3r0rG\nWmxXwg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Wisconsin - Platteville"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uwplatt.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Wisconsin - Platteville"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dev.play.sunet.se",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "saml_admin@kaltura.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dev.play.sunet.se",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SUNET (DEV)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://dev.play.sunet.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SUNET (DEV)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev.play.sunet.se/user/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.play.sunet.se/user/authenticate",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.esufa.edu.co/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Carlos Ramirez"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ingenieria@renata.edu.co"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.esufa.edu.co/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "es",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://colfire.co/?page_id=55"
              }
            ],
            "registration_instant": "2014-01-01T00:00:00Z",
            "registration_authority": "http://colfire.co",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.esufa.edu.co/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.esufa.edu.co/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.esufa.edu.co/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.esufa.edu.co/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.esufa.edu.co:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.esufa.edu.co:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "esufa.edu.co"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ESUFA - Escuela de Suboficiales de la Fuerza Aerea"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.esufa.edu.co/sites/all/themes/escudos/images/logo1.png",
                    "height": "116",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "104"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ESUFA - Escuela de Suboficiales de la Fuerza Aerea"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUR3iBFy9n6nA18hMLsJm30tEjr2IwDQYJKoZIhvcNAQEL\nBQAwGzEZMBcGA1UEAwwQaWRwLmVzdWZhLmVkdS5jbzAeFw0xNTEwMjcxNTE5MTda\nFw0zNTEwMjcxNTE5MTdaMBsxGTAXBgNVBAMMEGlkcC5lc3VmYS5lZHUuY28wggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDfGR5eateagj0PnAw+ysxMmMmQ\ntd6hMmG/hAHPUtIgGjriykJW62N9Pdnq96sQb6yGsErFcWwid0hPSNZUAqPjx32w\nakkVQnXmYwWnlldRXueFFyerHvD/vPBDrsClEQFDNoIAjtwcXW2myrdrY9Uvr7s0\n1HR+8ZANeddKnvn0BiZGvOR48MS8+JCAP2sCF0S0HcP49fCM8t/c3tl52HDgbeO6\nkfn4VH86JTyhghC2bNs9RM5UyzSiPYneSPuZDxi6mTxfyFIwAvYT+TcBTcP+/cYa\n4FXsF7TF+umPxRqnLMknFxOLsvblM5GDDuJzn3Yja+4GM5HyO4aprMlCqkL/AgMB\nAAGjZzBlMB0GA1UdDgQWBBQxt9Jk6AVo/EYsLzL+207UfLe7jDBEBgNVHREEPTA7\nghBpZHAuZXN1ZmEuZWR1LmNvhidodHRwczovL2lkcC5lc3VmYS5lZHUuY28vaWRw\nL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAIAeemyYbRf2nWT67tetcpVM\nGd2+Ws9nQhUEN/ZWTjCFu372m8o/nzNNNAh5+xSTFcrd6VMCbbm+XnVtPwt2WoRg\nNCCz8K45VIWmrgGwm8Nt6U+oAkumlswuAepJcfahsnKgv0U7qf2BVSL0jpy19c0p\n0H1p+mLIonGK1qOogKyfBZjyxawnTzZofLtfA8vUx7/IDuxTfgV6nnnc+Z/aDATB\n+fmWslC91CbfhCbMDmFA5qlNhCkvByn4ftNc4KVFXBa9yBZxCtv1ICIrMfNeGn6Z\nMRirrsA/Pf/HUBYniJVLRsfIJEZTI7zKqnKaS6EmM8qq40LW/Myj2MtEJ1rW1VA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUG1YyO7RicWuwZ/ERCAXtNnt0OUMwDQYJKoZIhvcNAQEL\nBQAwGzEZMBcGA1UEAwwQaWRwLmVzdWZhLmVkdS5jbzAeFw0xNTEwMjcxNTE5MTZa\nFw0zNTEwMjcxNTE5MTZaMBsxGTAXBgNVBAMMEGlkcC5lc3VmYS5lZHUuY28wggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCCr05q168l9MK8YfXb9yxrL4QV\na2gxg+CvJc3VlEiZ+upXbmnZCOr+5O8CccokRBV3WG9qfS5rLAZl/AmxF/Stcs0s\nan0eeMin9t44FZU12HM5VX1IS1oIVVOSp/EF7t5puIIMqPN6kIbKQOT3EqxOTEe/\nW+M0ofl+/DZg0qgDENMUaG9FU7qrA/4pehmytdv9JmhSTycg4nipr5iVAFvWy4vk\n5zNFzCvqtHxE1CegJUF72M5EITEUqihafnGoxAXVEyIWtD3q+XcxmI1PF6eUD7jH\nR+RBbdDKrfMsec3Dpd3/UsGcVKxztfUcSf/Yh2VRBkLLPixKdCE8ePzbIlHfAgMB\nAAGjZzBlMB0GA1UdDgQWBBRp8fBDzfSEIvqWJKHvQviqpLvUHzBEBgNVHREEPTA7\nghBpZHAuZXN1ZmEuZWR1LmNvhidodHRwczovL2lkcC5lc3VmYS5lZHUuY28vaWRw\nL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAGxgl6cHcqOCDahO5pJaSlDV\nmeFA/vg53pTunK4VVtbZwoagVUVOsYW38zU2ANKXetkx5yK38O7SPWL6GF7vVp9M\nVA3ILqEDEOYRgnjGA+sw5P3KU0zhzT6948EeD5qSdtfXxzlvh15I2nSeL9/8O3wQ\n1o8pKnIC0maLySulIP9BxFYBJExJi/7LrxNFPCsMAroHq7XEiEQyXi9f4ZWE+DJp\npBwyZmIKeUrMNRxpglFHiSIrrV44vzBTElJEUpB2cLnwGxu8LK2LYP/DkDDQl5Di\natE5Y2eHiCk2ku+gXCHtL6uQrGyxSIQHWcH49ohEKS/Jm2qnMNkG/YLE5PLefz0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUHzrD9JrVS3L07QCTwd1q9TdsaoMwDQYJKoZIhvcNAQEL\nBQAwGzEZMBcGA1UEAwwQaWRwLmVzdWZhLmVkdS5jbzAeFw0xNTEwMjcxNTE5MTda\nFw0zNTEwMjcxNTE5MTdaMBsxGTAXBgNVBAMMEGlkcC5lc3VmYS5lZHUuY28wggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDcSXgBUncSqkmxkIxtxSK8e4k3\n+XZ1qbxhkHiGT+tSzxWNdyNy7JmNtpKNTDSvFF9el+sICWkdMUYj+LeFXB6gcJDK\ntr6tp3fVaXRKYXaT1rrStRbIzcRe7XMRqtRZTVnBhAXY7e0TJgKyZcSGrWz0wnxl\nfk0EKwBIVK3CiguAjndelPJbp11ZOSHOgUWBExAwUAKecb02IhgWe5g79ZdGB2be\n0MC/e2xB9DfVbQ/Z+8Iz9hxx+njvTiHknaypJDV2KQHeUXLxhL86FCwCdaCFBYO9\nkBBG5sVimpoY2xBrngdJuAagYhcWwExcIEswJmx1W+pmgempFk0cNO6w4zdJAgMB\nAAGjZzBlMB0GA1UdDgQWBBSzwJJHyRiw4DQZnbs6x67gmzOzHTBEBgNVHREEPTA7\nghBpZHAuZXN1ZmEuZWR1LmNvhidodHRwczovL2lkcC5lc3VmYS5lZHUuY28vaWRw\nL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAIad6RjxaKwApgDD3iY13HnZ\n2tmfEov0VY9hBBHI6jUJIb4+qWw4BIlbYzx8Z4r1Hc8B7J/xFU4oOevsLzuKiQbY\n89x01GEXT3cFPTZEoz6DX6npNBgzQVAGnC74f/nxGIy3Sbi8gJCSousfOn1H5LFg\nCIDMjvtwdqw0t+EDARXO5vBJ4UCtPAW/9dsnzcCliUYWCJ04iN+UMejkazqAIqbz\n3HGnmU5jCG2qaLE0D6NaZkj7wptqkwRpGm+vDE8YsEIhhl+LbsvA1GY579P978Pt\n3iMRmTxHiqJ9Le8DuivZ/9PrQRFDlqzrgfbADCkJRsowwXq3pTJZYuxs+9ynVEw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ESUFA - Escuela de Suboficiales de la Fuerza Aerea"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.esufa.edu.co"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.esufa.edu.co"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ESUFA - Escuela de Suboficiales de la Fuerza Aerea"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibbo.emse.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dsi-admin@emse.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibbo.emse.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2011-02-24T19:45:08Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibbo.emse.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibbo.emse.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibbo.emse.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "emse.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.emse.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole des Mines de Saint-Etienne"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole des Mines de Saint-Etienne"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUWG4OdOHMXs/jWUMbrVKK/qGFpQgwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOc2hpYmJvLmVtc2UuZnIwHhcNMTEwMTI1MTUxOTAzWhcN\nMzEwMTI1MTUxOTAzWjAZMRcwFQYDVQQDEw5zaGliYm8uZW1zZS5mcjCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIcRRG3bC6uPGH2dcbNjJvqCvFfy3P3p\njoVSK2SVXe1rqJ/mV0PBzyAi0grECmHoCoM8p5wg6IxdOTVrtnXEf4Wfg70bMGQY\nB/3BA5mXlO5gn9sJD/xx89b+vEJdIjAo8XHLjeLXlM5Om9f69jIxgr8RvmDHFl3E\nDzeCiNLURAB10ZgwwMjukIyPoFg7Hp77NH85/hni4yG1/7e82i1eKir4IGujDk3y\nUCc3TIPxLFYEBccoupZ6NfYn7LHgeJOHZktkNjSISyU7ZWlk7xBKrYijTbZmfWBm\nQxKaaAm/vhj7JgxVUdlgickTgyUZ4wptyHENPK6CLstOEU7eZVksgE0CAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOc2hpYmJvLmVtc2UuZnKGJWh0dHBzOi8vc2hpYmJvLmVt\nc2UuZnIvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFIeWYn8hGuMdpEWP1VMxfDVP\nVoIhMA0GCSqGSIb3DQEBBQUAA4IBAQBhsFzDv5g8+KI9HPYtus470fLWG6QeoPJS\nokvD3oKa25+3hfen1fUgNEg4mLmcKG1+y/Ej9u6UiJrjZeo/iHIu3VSh9KClDAal\nBRbo30th1KQ122Nhkz1Hzt0MuVprMJbVzNo3jRfTw6iFtadaVPyC1koEvn5FucTD\nbpyOZ6qLHkuuEPoYgtyn0h/mFudb/XGDD8exhidz7CkuO6IWfT/HB9RC4nf7IAHW\n060v4YqkJ/y5F87gyOTwsLlNA1vWuJ4L90/fgzhJ15sp3l38Dr8XPnaegFYRVyAM\nmG4EGyP6qUE1uSrPxMk9GFtp+QkIXdDDGi5u9iIkLzHPYUMB4IfI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ecole des Mines de Saint-Etienne"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.emse.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ecole des Mines de Saint-Etienne"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:stevens.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "incommonadmin@stevens.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stevens InCommon Admin"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "incommonadmin@stevens.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stevens InCommon Admin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:stevens.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.stevens.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.stevens.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE0DCCA7igAwIBAgIJAKUJTVvF9jMzMA0GCSqGSIb3DQEBBQUAMIGgMQswCQYD\nVQQGEwJVUzETMBEGA1UECBMKTmV3IEplcnNleTEQMA4GA1UEBxMHSG9ib2tlbjEo\nMCYGA1UEChMfU3RldmVucyBJbnN0aXR1dGUgb2YgVGVjaG5vbG9neTEfMB0GA1UE\nCxMWSW5mb3JtYXRpb24gVGVjaG5vbG9neTEfMB0GA1UEAxMWc2hpYmJvbGV0aC5z\ndGV2ZW5zLmVkdTAeFw0xMzA0MjUyMTAxMDlaFw0zMzA0MjAyMTAxMDlaMIGgMQsw\nCQYDVQQGEwJVUzETMBEGA1UECBMKTmV3IEplcnNleTEQMA4GA1UEBxMHSG9ib2tl\nbjEoMCYGA1UEChMfU3RldmVucyBJbnN0aXR1dGUgb2YgVGVjaG5vbG9neTEfMB0G\nA1UECxMWSW5mb3JtYXRpb24gVGVjaG5vbG9neTEfMB0GA1UEAxMWc2hpYmJvbGV0\naC5zdGV2ZW5zLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAO2c\nJBTo094f/BcRDAAT0tIgiJL4gUz4zNspGsgxP32Q4/mEiihco8hPFgMQr1mAc7JF\nS6X0WUvs6WZiDvOVScS22R4ivr09B1ZRnpOqEJ0L/ets7OK3UScE2V5VW5Kbeot/\nIOo6Yahljo2DkxfkfCzSSTMMxVrZBTwxtoAi5Ri1bShU9Vw4BL/A0MfV+RlgjXrT\ncGcWoCTRNBtXEeADqydq3IG/5tJBZJXMalj37hnhM5zqMkF5yunEFSqtXMafVq4f\nqik1Hu9QP4nR5lWxONG24V2MuNuNkFhKLfJ/QMMJVqpfA96p8Of5njwk4qTj5Hw9\nhnXKPbqvasgj4kw6Uz0CAwEAAaOCAQkwggEFMB0GA1UdDgQWBBSLYDJRDVrnnP7z\ndVbceo1m8LOw4TCB1QYDVR0jBIHNMIHKgBSLYDJRDVrnnP7zdVbceo1m8LOw4aGB\npqSBozCBoDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCk5ldyBKZXJzZXkxEDAOBgNV\nBAcTB0hvYm9rZW4xKDAmBgNVBAoTH1N0ZXZlbnMgSW5zdGl0dXRlIG9mIFRlY2hu\nb2xvZ3kxHzAdBgNVBAsTFkluZm9ybWF0aW9uIFRlY2hub2xvZ3kxHzAdBgNVBAMT\nFnNoaWJib2xldGguc3RldmVucy5lZHWCCQClCU1bxfYzMzAMBgNVHRMEBTADAQH/\nMA0GCSqGSIb3DQEBBQUAA4IBAQBdt86UgJOoIvSSwvh1ySB2S/zqEfRQl4U4uVLs\nzVhlaZjhTLJkg65q39mH7RWLtkRjmL5Ow3DhF3jkwFurn37wYj1aDF0I/EuxZNIn\nScmbRlIqJFfRqzrg3BlgFh1MC/wKjNPa7zP2u3dHcEjbA+3j4AMUMEpQraIRDTeJ\nsP2lUMDInk7ed7EtMwAZ3yzzZeErQlCTzcp2FEDqELvFaWs+72fQLLUAhaOyvQX/\neFcCdQ1M6aBTDHy7CrsFeIr+U90g9lwRLVfenOpRH9Hwhp3ADlPIFQWZCggwzPty\nvNxpYC0Zha2JoUI0lWpc6TWmQprKU5HaC/LZj6UdCQ11HM04"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stevens.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.stevens.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.stevens.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.stevens.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.stevens.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.stevens.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.stevens.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stevens.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://www.stevens.edu/sit/sites/sit/themes/sit_default/logo.png",
                    "lang": "en",
                    "height": "213",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "500"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Stevens Institute of Technology"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE0DCCA7igAwIBAgIJAKUJTVvF9jMzMA0GCSqGSIb3DQEBBQUAMIGgMQswCQYD\nVQQGEwJVUzETMBEGA1UECBMKTmV3IEplcnNleTEQMA4GA1UEBxMHSG9ib2tlbjEo\nMCYGA1UEChMfU3RldmVucyBJbnN0aXR1dGUgb2YgVGVjaG5vbG9neTEfMB0GA1UE\nCxMWSW5mb3JtYXRpb24gVGVjaG5vbG9neTEfMB0GA1UEAxMWc2hpYmJvbGV0aC5z\ndGV2ZW5zLmVkdTAeFw0xMzA0MjUyMTAxMDlaFw0zMzA0MjAyMTAxMDlaMIGgMQsw\nCQYDVQQGEwJVUzETMBEGA1UECBMKTmV3IEplcnNleTEQMA4GA1UEBxMHSG9ib2tl\nbjEoMCYGA1UEChMfU3RldmVucyBJbnN0aXR1dGUgb2YgVGVjaG5vbG9neTEfMB0G\nA1UECxMWSW5mb3JtYXRpb24gVGVjaG5vbG9neTEfMB0GA1UEAxMWc2hpYmJvbGV0\naC5zdGV2ZW5zLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAO2c\nJBTo094f/BcRDAAT0tIgiJL4gUz4zNspGsgxP32Q4/mEiihco8hPFgMQr1mAc7JF\nS6X0WUvs6WZiDvOVScS22R4ivr09B1ZRnpOqEJ0L/ets7OK3UScE2V5VW5Kbeot/\nIOo6Yahljo2DkxfkfCzSSTMMxVrZBTwxtoAi5Ri1bShU9Vw4BL/A0MfV+RlgjXrT\ncGcWoCTRNBtXEeADqydq3IG/5tJBZJXMalj37hnhM5zqMkF5yunEFSqtXMafVq4f\nqik1Hu9QP4nR5lWxONG24V2MuNuNkFhKLfJ/QMMJVqpfA96p8Of5njwk4qTj5Hw9\nhnXKPbqvasgj4kw6Uz0CAwEAAaOCAQkwggEFMB0GA1UdDgQWBBSLYDJRDVrnnP7z\ndVbceo1m8LOw4TCB1QYDVR0jBIHNMIHKgBSLYDJRDVrnnP7zdVbceo1m8LOw4aGB\npqSBozCBoDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCk5ldyBKZXJzZXkxEDAOBgNV\nBAcTB0hvYm9rZW4xKDAmBgNVBAoTH1N0ZXZlbnMgSW5zdGl0dXRlIG9mIFRlY2hu\nb2xvZ3kxHzAdBgNVBAsTFkluZm9ybWF0aW9uIFRlY2hub2xvZ3kxHzAdBgNVBAMT\nFnNoaWJib2xldGguc3RldmVucy5lZHWCCQClCU1bxfYzMzAMBgNVHRMEBTADAQH/\nMA0GCSqGSIb3DQEBBQUAA4IBAQBdt86UgJOoIvSSwvh1ySB2S/zqEfRQl4U4uVLs\nzVhlaZjhTLJkg65q39mH7RWLtkRjmL5Ow3DhF3jkwFurn37wYj1aDF0I/EuxZNIn\nScmbRlIqJFfRqzrg3BlgFh1MC/wKjNPa7zP2u3dHcEjbA+3j4AMUMEpQraIRDTeJ\nsP2lUMDInk7ed7EtMwAZ3yzzZeErQlCTzcp2FEDqELvFaWs+72fQLLUAhaOyvQX/\neFcCdQ1M6aBTDHy7CrsFeIr+U90g9lwRLVfenOpRH9Hwhp3ADlPIFQWZCggwzPty\nvNxpYC0Zha2JoUI0lWpc6TWmQprKU5HaC/LZj6UdCQ11HM04"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Stevens Institute of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.stevens.edu/sit/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Stevens Institute of Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://cafe.mcti.gov.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Daniel Souza"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cgti@mcti.gov.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.mcti.gov.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID4DCCAsgCAQAwDQYJKoZIhvcNAQEFBQAwgbUxNTAzBgNVBAoULE1JTklTVMlS\nSU8gREEgQ0nKTkNJQSwgVEVDTk9MT0dJQSBFIElOT1ZBx8NPMQ0wCwYDVQQLEwRD\nR1RJMR8wHQYJKoZIhvcNAQkBFhBjZ3RpQG1jdGkuZ292LmJyMREwDwYDVQQHFAhC\ncmFz7WxpYTELMAkGA1UECBMCREYxCzAJBgNVBAYTAkJSMR8wHQYDVQQDExZzaGli\nYm9sZXRoLm1jdC5nb3YuYnIgMB4XDTE1MTAwMjE5MDM1MloXDTE4MTAwMTE5MDM1\nMlowgbUxNTAzBgNVBAoULE1JTklTVMlSSU8gREEgQ0nKTkNJQSwgVEVDTk9MT0dJ\nQSBFIElOT1ZBx8NPMQ0wCwYDVQQLEwRDR1RJMR8wHQYJKoZIhvcNAQkBFhBjZ3Rp\nQG1jdGkuZ292LmJyMREwDwYDVQQHFAhCcmFz7WxpYTELMAkGA1UECBMCREYxCzAJ\nBgNVBAYTAkJSMR8wHQYDVQQDExZzaGliYm9sZXRoLm1jdC5nb3YuYnIgMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxNWc4sXlHfFx8K5z3tFp1qxqrjb3\nwcUnkt+WUAWDU329b0PzpRnojFW6V/NGvifpgb0omA1iKbM9HBJnLgAhQeVaB1Fa\n1qxN0tfaaQQQu3uC4Ge6jxJWnrZtbmC9Qfw/+yEoP+iN4PQKw7bhTQJDBD+i3Hlh\n67UBZ/uMOs8rEZJDbzocsGISikZfuwDmtflTlpf/DXfqnrQhzMhpEfegC8afzcA8\nO3ZDBrXBov4MdTKfPjtrtbIpdpU6OV/G8vIC+eEImvTbkHmKA3I3qOChTK4pj4Ck\nB7RGzE6Clalm+R1FVnPFgvO16lcS/KlL12jB1/vXAomGHThOj7M1LRI34wIDAQAB\nMA0GCSqGSIb3DQEBBQUAA4IBAQA58CiJc5O6Hq8ITWADFxM+BV97OzaQSkXsOF7e\nNnHva3kG6XJsc8CS2oYxWcGI6NRGDjLBK9phqjWQXm33yMZZTwNbzp8FdOfIYZYN\nZi5M0a/qtF5hF1ku7iD8q9ZGdZvaxHe5OKKooqJiqdX2GyGpSLKLi4oEzw/BQwZY\n0rshZowIsAKJFEVyVloAjTgNEBN8DqGIqFrwgjOYu/7JL/+lWQF2wxXRTJcEq+q4\naWfQR54+AvG5WzOajAhQSGTGXkMumQrnFAgJSi4r7S7T5zF6ynGalfRuqDG5xGih\nH4iAdWwzMf9pmj/5YnWSqe28vEbeEyPeX/4e53os0oM9raJN"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mcti.gov.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.mcti.gov.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.mcti.gov.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.mcti.gov.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.mcti.gov.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.mcti.gov.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.mcti.gov.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.mcti.gov.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.mcti.gov.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mcti.gov.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mcti.gov.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mcti.gov.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "MCTI - Ministerio da Ciencia, Tecnologia e Inovacao"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "MCTI - Ministerio da Ciencia, Tecnologia e Inovacao"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "MCTI - Ministerio da Ciencia, Tecnologia e Inovacao"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "MCTI - Ministerio da Ciencia, Tecnologia e Inovacao"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID4DCCAsgCAQAwDQYJKoZIhvcNAQEFBQAwgbUxNTAzBgNVBAoULE1JTklTVMlS\nSU8gREEgQ0nKTkNJQSwgVEVDTk9MT0dJQSBFIElOT1ZBx8NPMQ0wCwYDVQQLEwRD\nR1RJMR8wHQYJKoZIhvcNAQkBFhBjZ3RpQG1jdGkuZ292LmJyMREwDwYDVQQHFAhC\ncmFz7WxpYTELMAkGA1UECBMCREYxCzAJBgNVBAYTAkJSMR8wHQYDVQQDExZzaGli\nYm9sZXRoLm1jdC5nb3YuYnIgMB4XDTE1MTAwMjE5MDM1MloXDTE4MTAwMTE5MDM1\nMlowgbUxNTAzBgNVBAoULE1JTklTVMlSSU8gREEgQ0nKTkNJQSwgVEVDTk9MT0dJ\nQSBFIElOT1ZBx8NPMQ0wCwYDVQQLEwRDR1RJMR8wHQYJKoZIhvcNAQkBFhBjZ3Rp\nQG1jdGkuZ292LmJyMREwDwYDVQQHFAhCcmFz7WxpYTELMAkGA1UECBMCREYxCzAJ\nBgNVBAYTAkJSMR8wHQYDVQQDExZzaGliYm9sZXRoLm1jdC5nb3YuYnIgMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxNWc4sXlHfFx8K5z3tFp1qxqrjb3\nwcUnkt+WUAWDU329b0PzpRnojFW6V/NGvifpgb0omA1iKbM9HBJnLgAhQeVaB1Fa\n1qxN0tfaaQQQu3uC4Ge6jxJWnrZtbmC9Qfw/+yEoP+iN4PQKw7bhTQJDBD+i3Hlh\n67UBZ/uMOs8rEZJDbzocsGISikZfuwDmtflTlpf/DXfqnrQhzMhpEfegC8afzcA8\nO3ZDBrXBov4MdTKfPjtrtbIpdpU6OV/G8vIC+eEImvTbkHmKA3I3qOChTK4pj4Ck\nB7RGzE6Clalm+R1FVnPFgvO16lcS/KlL12jB1/vXAomGHThOj7M1LRI34wIDAQAB\nMA0GCSqGSIb3DQEBBQUAA4IBAQA58CiJc5O6Hq8ITWADFxM+BV97OzaQSkXsOF7e\nNnHva3kG6XJsc8CS2oYxWcGI6NRGDjLBK9phqjWQXm33yMZZTwNbzp8FdOfIYZYN\nZi5M0a/qtF5hF1ku7iD8q9ZGdZvaxHe5OKKooqJiqdX2GyGpSLKLi4oEzw/BQwZY\n0rshZowIsAKJFEVyVloAjTgNEBN8DqGIqFrwgjOYu/7JL/+lWQF2wxXRTJcEq+q4\naWfQR54+AvG5WzOajAhQSGTGXkMumQrnFAgJSi4r7S7T5zF6ynGalfRuqDG5xGih\nH4iAdWwzMf9pmj/5YnWSqe28vEbeEyPeX/4e53os0oM9raJN"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MCTI - Ministerio da Ciencia, Tecnologia e Inovacao"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MCTI - Ministerio da Ciencia, Tecnologia e Inovacao"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mcti.gov.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mcti.gov.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "MCTI - Ministerio da Ciencia, Tecnologia e Inovacao"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "MCTI - Ministerio da Ciencia, Tecnologia e Inovacao"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://us.ready.kuali.co/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ready-help@kuali.co"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kuali Ready Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://us.ready.kuali.co/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Kuali, Inc."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.kuali.co/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Kuali, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.kuali.co"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Kuali Ready: Continuity Planning Tool"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.kuali.co/privacy-policy/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kuali Ready"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFWDCCBECgAwIBAgIQdSD51D2J/H68GiKuV9R+VzANBgkqhkiG9w0BAQsFADCB\nkDELMAkGA1UEBhMCR0IxGzAZBgNVBAgTEkdyZWF0ZXIgTWFuY2hlc3RlcjEQMA4G\nA1UEBxMHU2FsZm9yZDEaMBgGA1UEChMRQ09NT0RPIENBIExpbWl0ZWQxNjA0BgNV\nBAMTLUNPTU9ETyBSU0EgRG9tYWluIFZhbGlkYXRpb24gU2VjdXJlIFNlcnZlciBD\nQTAeFw0xNDEyMDMwMDAwMDBaFw0xNTEyMDMyMzU5NTlaMFYxITAfBgNVBAsTGERv\nbWFpbiBDb250cm9sIFZhbGlkYXRlZDEVMBMGA1UECxMMRXNzZW50aWFsU1NMMRow\nGAYDVQQDExF1cy5yZWFkeS5rdWFsaS5jbzCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAIaKNbx0XrJSRssWcfgt43SopI7oZyDgjVdebLGphIRiB0+5AWaa\nkfDMCgEOmYQsoSdbtpdtIXChiO6x1sGnbP83eCO7bfZXXcreoOtNBjwIqSwujwen\nHAHyUoPPPwzC3MK80Zd6DwSA8py/jzl3lo42zpM4qxx5ziZ+n91ygQEXZLCUQUi9\n+U32WAGHR3FvS0ziHgbu/tuR6mBbGAaO18Tr4D+61VUe3tfrgbW+hsnhnsjYfae8\ncfmO4NCzK46Ydli6UsdcNsx8bJv0vDKhBmTXaW2pPc0wtzcxGmOsWAG1urH6zW/t\nfEWc97e9ZgAYStfoYDjtbN7LJ13gKjdAv2cCAwEAAaOCAeUwggHhMB8GA1UdIwQY\nMBaAFJCvajqUWgvYkOoSVnPfQ7Q6KNrnMB0GA1UdDgQWBBRDRSu3AHQGJP/m3ZZ8\nGUwIDKGfGjAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAU\nBggrBgEFBQcDAQYIKwYBBQUHAwIwTwYDVR0gBEgwRjA6BgsrBgEEAbIxAQICBzAr\nMCkGCCsGAQUFBwIBFh1odHRwczovL3NlY3VyZS5jb21vZG8uY29tL0NQUzAIBgZn\ngQwBAgEwVAYDVR0fBE0wSzBJoEegRYZDaHR0cDovL2NybC5jb21vZG9jYS5jb20v\nQ09NT0RPUlNBRG9tYWluVmFsaWRhdGlvblNlY3VyZVNlcnZlckNBLmNybDCBhQYI\nKwYBBQUHAQEEeTB3ME8GCCsGAQUFBzAChkNodHRwOi8vY3J0LmNvbW9kb2NhLmNv\nbS9DT01PRE9SU0FEb21haW5WYWxpZGF0aW9uU2VjdXJlU2VydmVyQ0EuY3J0MCQG\nCCsGAQUFBzABhhhodHRwOi8vb2NzcC5jb21vZG9jYS5jb20wMwYDVR0RBCwwKoIR\ndXMucmVhZHkua3VhbGkuY2+CFXd3dy51cy5yZWFkeS5rdWFsaS5jbzANBgkqhkiG\n9w0BAQsFAAOCAQEAEJx24eL3ZD2XB+ozeu8kScil7yS5UpqHrAr9FjXIJoKtGetG\nFoTgZhOaBcEPAV/Ck8lEafyyaeATPBprnp52v2MaXXKpsdfK5Ns30hXfDcksWLOZ\nFFT8c8VHCppH2mXkBC66PyKoI9iI6oF7v0D6LZJkCvYjQ6nMuyQ7KJyoKc0uoxuq\nBjeBl4P1r17InaZSLCwRPJkpU26qFUctBqe+eRBkiHcP8yA5SQe1pxJzmuvSIQxF\ngPmXUWIVQJomabMJXajnaW+N9aUgq2pkUFOWc/cyrPu4hCZ+3t1mYI53TCHZuT9j\nigrISDU4NE+WRFXYNimd2m6klDtRE3PVtwaPcQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://us.ready.kuali.co/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://us.ready.kuali.co/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://us.ready.kuali.co/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://us.ready.kuali.co/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://us.ready.kuali.co/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://us.ready.kuali.co/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Kuali Ready"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Kuali Ready: Continuity Planning Tool"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.godalming.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ITSupport@godalming.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ITSupport@godalming.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.godalming.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-10-06T17:13:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjwCCQDYuaHlo6w4dTANBgkqhkiG9w0BAQUFADBsMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEPMA0GA1UECBMGU3VycmV5MRIwEAYDVQQHEwlHb2RhbG1pbmcxGjAYBgNVBAoT\n\t\t\t\t\t\tEUdvZGFsbWluZyBDb2xsZWdlMRwwGgYDVQQDExNpZHAuZ29kYWxtaW5nLmFjLnVr\n\t\t\t\t\t\tMB4XDTEzMTEwNTEzNTk1NloXDTMzMTAzMTEzNTk1NlowbDELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tDzANBgNVBAgTBlN1cnJleTESMBAGA1UEBxMJR29kYWxtaW5nMRowGAYDVQQKExFH\n\t\t\t\t\t\tb2RhbG1pbmcgQ29sbGVnZTEcMBoGA1UEAxMTaWRwLmdvZGFsbWluZy5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKXVhe3ogE/3heu0gX8lxWxf\n\t\t\t\t\t\t9BEKJuvE3iNKpopu8xob4BjkExlapGP3WWcZ7bdDqdrkF6StEvAZeWkFtgdeDguA\n\t\t\t\t\t\tJbe/GgnYfjufgeiTGSKWwM7AOV3rz5txBcyKOrC88qorYl6gUdc7p2GPZFDZgcu7\n\t\t\t\t\t\tcCGKIMTVqUcMIp3uIZv0M/u+Vn4CI+BeUTZENIAZfeUHNTUxkcH6Oqhb6hnCYwmi\n\t\t\t\t\t\tsa+zu/701srcXEJV2ioPU9u765ssWKk3vrbw5Yl8sEDm/jyirhesyjh01YA/YMov\n\t\t\t\t\t\t3XgSQabUIY7q1QHztqHXNwA/tDnxzShEHPpuIMsz7PSYsCP4EA63iWGDx0WqfS8C\n\t\t\t\t\t\tAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAojTGzBpaChl86wL81BcANWi+VhfXJTWu\n\t\t\t\t\t\tTbY897lnhDaYjZQVEimRZjY17+NLepjySmjC7CJylZQrRvnSS5DnZZXqi+Vj6vJE\n\t\t\t\t\t\tjvaouneVqCXJuj6aqtuqIhVYsyuLo2C2gUhb6wWJd0LNvNkTHEtSsWA7MR6oG3on\n\t\t\t\t\t\tMq/u7YNxv0+M0hBvbPF7UhFX5ZcpQx6+Oz/YDKUaJ2mkyeskMa45zM3KS89izU3a\n\t\t\t\t\t\tBfhIQnUh08BVlrphQmoeTxMvRQ4onNp4uy0UtoFfD6WGEIwfzckosJcEkukGNfUJ\n\t\t\t\t\t\t3PcXdcBw5DL6rHdWkpNGnyuWj4w/csNAa8/ie/hWF5FgVJduilLWXA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "godalming.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.godalming.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.godalming.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.godalming.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.godalming.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.godalming.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.godalming.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.godalming.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.godalming.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "godalming.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjwCCQDYuaHlo6w4dTANBgkqhkiG9w0BAQUFADBsMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEPMA0GA1UECBMGU3VycmV5MRIwEAYDVQQHEwlHb2RhbG1pbmcxGjAYBgNVBAoT\n\t\t\t\t\t\tEUdvZGFsbWluZyBDb2xsZWdlMRwwGgYDVQQDExNpZHAuZ29kYWxtaW5nLmFjLnVr\n\t\t\t\t\t\tMB4XDTEzMTEwNTEzNTk1NloXDTMzMTAzMTEzNTk1NlowbDELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tDzANBgNVBAgTBlN1cnJleTESMBAGA1UEBxMJR29kYWxtaW5nMRowGAYDVQQKExFH\n\t\t\t\t\t\tb2RhbG1pbmcgQ29sbGVnZTEcMBoGA1UEAxMTaWRwLmdvZGFsbWluZy5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKXVhe3ogE/3heu0gX8lxWxf\n\t\t\t\t\t\t9BEKJuvE3iNKpopu8xob4BjkExlapGP3WWcZ7bdDqdrkF6StEvAZeWkFtgdeDguA\n\t\t\t\t\t\tJbe/GgnYfjufgeiTGSKWwM7AOV3rz5txBcyKOrC88qorYl6gUdc7p2GPZFDZgcu7\n\t\t\t\t\t\tcCGKIMTVqUcMIp3uIZv0M/u+Vn4CI+BeUTZENIAZfeUHNTUxkcH6Oqhb6hnCYwmi\n\t\t\t\t\t\tsa+zu/701srcXEJV2ioPU9u765ssWKk3vrbw5Yl8sEDm/jyirhesyjh01YA/YMov\n\t\t\t\t\t\t3XgSQabUIY7q1QHztqHXNwA/tDnxzShEHPpuIMsz7PSYsCP4EA63iWGDx0WqfS8C\n\t\t\t\t\t\tAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAojTGzBpaChl86wL81BcANWi+VhfXJTWu\n\t\t\t\t\t\tTbY897lnhDaYjZQVEimRZjY17+NLepjySmjC7CJylZQrRvnSS5DnZZXqi+Vj6vJE\n\t\t\t\t\t\tjvaouneVqCXJuj6aqtuqIhVYsyuLo2C2gUhb6wWJd0LNvNkTHEtSsWA7MR6oG3on\n\t\t\t\t\t\tMq/u7YNxv0+M0hBvbPF7UhFX5ZcpQx6+Oz/YDKUaJ2mkyeskMa45zM3KS89izU3a\n\t\t\t\t\t\tBfhIQnUh08BVlrphQmoeTxMvRQ4onNp4uy0UtoFfD6WGEIwfzckosJcEkukGNfUJ\n\t\t\t\t\t\t3PcXdcBw5DL6rHdWkpNGnyuWj4w/csNAa8/ie/hWF5FgVJduilLWXA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Godalming College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.godalming.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Godalming College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.britishonlinearchives.co.uk/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sarsfield"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dsarsfield@microform.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gill"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:martin@serversure.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.britishonlinearchives.co.uk/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Microform Imaging Limited: British Online Archives"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.microform.co.uk/archival-publishing.php"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Microform Imaging Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYzCCAkugAwIBAgIJAIntgQVy9bMDMA0GCSqGSIb3DQEBBQUAMEgxIDAeBgNV\n\t\t\t\t\t\tBAoMF0JyaXRpc2ggT25saW5lIEFyY2hpdmVzMSQwIgYDVQQDDBticml0aXNob25s\n\t\t\t\t\t\taW5lYXJjaGl2ZXMuY28udWswHhcNMTQxMjIyMTczNTE1WhcNMjQxMjE5MTczNTE1\n\t\t\t\t\t\tWjBIMSAwHgYDVQQKDBdCcml0aXNoIE9ubGluZSBBcmNoaXZlczEkMCIGA1UEAwwb\n\t\t\t\t\t\tYnJpdGlzaG9ubGluZWFyY2hpdmVzLmNvLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEArBXm14IC8EPPKMLqv8Mxc6lnsDNeT4ZQqQpsF3Kz325jqZnZ\n\t\t\t\t\t\t+4qUFliWnopWDHOPvdVDnnZg5ymSzinO2jKZcweM4yvBthDG/Wp3JNci11jgZk9h\n\t\t\t\t\t\tC/zyoByJ5qrKrtrDjYFW5zwAcOGrSbYGeA+cKG28FoeuVowvXavMnI8ZG5SaRcfP\n\t\t\t\t\t\tgVe9tGGeZOToVJpE3TNE5fEQA1vKCOvgoT7ED7Oqu513FFeUgINZv6R+o0xwuBc1\n\t\t\t\t\t\ty78xfG90PUJYZZzDW4r1ZqK1yxjHVnZZetOmJIFukQ9roooN0Obar5/o8SSmGcsS\n\t\t\t\t\t\t2TuOvURvNP8qedUQEKNZf3eoHGRwXem4yfgYwwIDAQABo1AwTjAdBgNVHQ4EFgQU\n\t\t\t\t\t\tjiD0ReK+F12gvk35faGLaMANkigwHwYDVR0jBBgwFoAUjiD0ReK+F12gvk35faGL\n\t\t\t\t\t\taMANkigwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAHZPJrhAtjWu4\n\t\t\t\t\t\tdl0m80tGN28YEJ4JTudooDQbUggD3bmf32P1l3gRxUt6JYyfcmzN8xTHQZureVB9\n\t\t\t\t\t\tNqxJ5UrEyVuFc6criS233tITks8ujfERX8L602gRIdvnqcrb//uqq86KdWc53fyR\n\t\t\t\t\t\tnFSfnnMQlRfHHXdwe4kB8tI5Q5GoWB2oIYxW/iePE93unoB6f12ueqji+FaaSih2\n\t\t\t\t\t\ts2YzFjlH1ERAupJq1xeqnO6DJ8J9BN/+h/Pm0ykn/8SmhI6fXiLqfkEqG/fAK+Lj\n\t\t\t\t\t\tbYGNjeYztEjaKkYDheCy8PqJAk5WLJMmxPR+/6Vb7uhJDDOYEnnmaLFL5uQIbWdd\n\t\t\t\t\t\tuKhMiG0GAg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYzCCAkugAwIBAgIJAIntgQVy9bMDMA0GCSqGSIb3DQEBBQUAMEgxIDAeBgNV\n\t\t\t\t\t\tBAoMF0JyaXRpc2ggT25saW5lIEFyY2hpdmVzMSQwIgYDVQQDDBticml0aXNob25s\n\t\t\t\t\t\taW5lYXJjaGl2ZXMuY28udWswHhcNMTQxMjIyMTczNTE1WhcNMjQxMjE5MTczNTE1\n\t\t\t\t\t\tWjBIMSAwHgYDVQQKDBdCcml0aXNoIE9ubGluZSBBcmNoaXZlczEkMCIGA1UEAwwb\n\t\t\t\t\t\tYnJpdGlzaG9ubGluZWFyY2hpdmVzLmNvLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEArBXm14IC8EPPKMLqv8Mxc6lnsDNeT4ZQqQpsF3Kz325jqZnZ\n\t\t\t\t\t\t+4qUFliWnopWDHOPvdVDnnZg5ymSzinO2jKZcweM4yvBthDG/Wp3JNci11jgZk9h\n\t\t\t\t\t\tC/zyoByJ5qrKrtrDjYFW5zwAcOGrSbYGeA+cKG28FoeuVowvXavMnI8ZG5SaRcfP\n\t\t\t\t\t\tgVe9tGGeZOToVJpE3TNE5fEQA1vKCOvgoT7ED7Oqu513FFeUgINZv6R+o0xwuBc1\n\t\t\t\t\t\ty78xfG90PUJYZZzDW4r1ZqK1yxjHVnZZetOmJIFukQ9roooN0Obar5/o8SSmGcsS\n\t\t\t\t\t\t2TuOvURvNP8qedUQEKNZf3eoHGRwXem4yfgYwwIDAQABo1AwTjAdBgNVHQ4EFgQU\n\t\t\t\t\t\tjiD0ReK+F12gvk35faGLaMANkigwHwYDVR0jBBgwFoAUjiD0ReK+F12gvk35faGL\n\t\t\t\t\t\taMANkigwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAHZPJrhAtjWu4\n\t\t\t\t\t\tdl0m80tGN28YEJ4JTudooDQbUggD3bmf32P1l3gRxUt6JYyfcmzN8xTHQZureVB9\n\t\t\t\t\t\tNqxJ5UrEyVuFc6criS233tITks8ujfERX8L602gRIdvnqcrb//uqq86KdWc53fyR\n\t\t\t\t\t\tnFSfnnMQlRfHHXdwe4kB8tI5Q5GoWB2oIYxW/iePE93unoB6f12ueqji+FaaSih2\n\t\t\t\t\t\ts2YzFjlH1ERAupJq1xeqnO6DJ8J9BN/+h/Pm0ykn/8SmhI6fXiLqfkEqG/fAK+Lj\n\t\t\t\t\t\tbYGNjeYztEjaKkYDheCy8PqJAk5WLJMmxPR+/6Vb7uhJDDOYEnnmaLFL5uQIbWdd\n\t\t\t\t\t\tuKhMiG0GAg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "want_assertions_signed": "false",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://www.britishonlinearchives.co.uk/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.britishonlinearchives.co.uk/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.britishonlinearchives.co.uk/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.britishonlinearchives.co.uk/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://shibboleth.ifam.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Janderson Silva"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "janderson_silva@ifam.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.ifam.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID7jCCAtYCAQAwDQYJKoZIhvcNAQEFBQAwgbwxLTArBgNVBAoTJElGQU0gLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkbyBBbWF6b25hczENMAsGA1UECxMEREdUSTEqMCgG\nCSqGSIb3DQEJARYbamFuZGVyc29uX3NpbHZhQGlmYW0uZWR1LmJyMQ8wDQYDVQQH\nEwZNYW5hdXMxETAPBgNVBAgTCEFtYXpvbmFzMQswCQYDVQQGEwJCUjEfMB0GA1UE\nAxMWc2hpYmJvbGV0aC5pZmFtLmVkdS5icjAeFw0xNTA5MTExNDM4MjRaFw0xODA5\nMTAxNDM4MjRaMIG8MS0wKwYDVQQKEyRJRkFNIC0gSW5zdGl0dXRvIEZlZGVyYWwg\nZG8gQW1hem9uYXMxDTALBgNVBAsTBERHVEkxKjAoBgkqhkiG9w0BCQEWG2phbmRl\ncnNvbl9zaWx2YUBpZmFtLmVkdS5icjEPMA0GA1UEBxMGTWFuYXVzMREwDwYDVQQI\nEwhBbWF6b25hczELMAkGA1UEBhMCQlIxHzAdBgNVBAMTFnNoaWJib2xldGguaWZh\nbS5lZHUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCwe8oW4kt+\n10kAHIs5ktvLFB1Re/x4DAOxPMDrTVrM9rK8KRp9ITjlHgCgwsE/hLmyebRlTPCA\nPVGol2yAX6MUqTaF8CEqoUs3E2Cs2vpFWUjcx7oP89TsL1nLHF+Ye33gfYUtOi/V\nmK0jP4BW4/OI/5GaYj3WhYSJd9ygWLeScxokricn+yrQzOH0pdbRFxXsiwURQCdD\nYWD5DKSER/44M1HK430Tl+5UST/9hGhTn7L5cfxC+iJUkythj6ZYEWp3e1SHfqWF\n/QgGk2nKT3B2PgMnLfiXRsry4cVaukty4r/9cRJAgC241wGbWEWnXiPshWOJIqBi\nsFhiqWvT5E81AgMBAAEwDQYJKoZIhvcNAQEFBQADggEBADgvNKCE3XgLvEk3HUND\nJdrWzeK2XIw9c8z0Qr4im901tpPKaJrt13M+C+lou9K1uQm6Bvf8Cb0KL35P/jtM\nZmxquu1syvxmRW1utOTt4jJUYA3k8E+dXMic995IWEQPIQMpFD53gE3/LF6QqD8F\nFsMYsy832J83v55+TWqMNSwG9Y6usOm/UqHyxh1/PKldHTCpr9bMY5Pba0ko++0B\n8TUVA71uquwvJaSPbGWhf6IvWKiZZXyNyswF59UmOZJzzk3biEOdCALlRNy4UOn9\n3HzXQpIvueRNQ4uKUw6CxbyFZBv5oosN399A0zqYQGNSYRJIx66T7UcsW1MoNM5f\ngl0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.ifam.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.ifam.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.ifam.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.ifam.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.ifam.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.ifam.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.ifam.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.ifam.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifam.edu.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifam.edu.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFAM - Instituto Federal do Amazonas"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFAM - Instituto Federal do Amazonas"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFAM - Instituto Federal do Amazonas"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFAM - Instituto Federal do Amazonas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID7jCCAtYCAQAwDQYJKoZIhvcNAQEFBQAwgbwxLTArBgNVBAoTJElGQU0gLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkbyBBbWF6b25hczENMAsGA1UECxMEREdUSTEqMCgG\nCSqGSIb3DQEJARYbamFuZGVyc29uX3NpbHZhQGlmYW0uZWR1LmJyMQ8wDQYDVQQH\nEwZNYW5hdXMxETAPBgNVBAgTCEFtYXpvbmFzMQswCQYDVQQGEwJCUjEfMB0GA1UE\nAxMWc2hpYmJvbGV0aC5pZmFtLmVkdS5icjAeFw0xNTA5MTExNDM4MjRaFw0xODA5\nMTAxNDM4MjRaMIG8MS0wKwYDVQQKEyRJRkFNIC0gSW5zdGl0dXRvIEZlZGVyYWwg\nZG8gQW1hem9uYXMxDTALBgNVBAsTBERHVEkxKjAoBgkqhkiG9w0BCQEWG2phbmRl\ncnNvbl9zaWx2YUBpZmFtLmVkdS5icjEPMA0GA1UEBxMGTWFuYXVzMREwDwYDVQQI\nEwhBbWF6b25hczELMAkGA1UEBhMCQlIxHzAdBgNVBAMTFnNoaWJib2xldGguaWZh\nbS5lZHUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCwe8oW4kt+\n10kAHIs5ktvLFB1Re/x4DAOxPMDrTVrM9rK8KRp9ITjlHgCgwsE/hLmyebRlTPCA\nPVGol2yAX6MUqTaF8CEqoUs3E2Cs2vpFWUjcx7oP89TsL1nLHF+Ye33gfYUtOi/V\nmK0jP4BW4/OI/5GaYj3WhYSJd9ygWLeScxokricn+yrQzOH0pdbRFxXsiwURQCdD\nYWD5DKSER/44M1HK430Tl+5UST/9hGhTn7L5cfxC+iJUkythj6ZYEWp3e1SHfqWF\n/QgGk2nKT3B2PgMnLfiXRsry4cVaukty4r/9cRJAgC241wGbWEWnXiPshWOJIqBi\nsFhiqWvT5E81AgMBAAEwDQYJKoZIhvcNAQEFBQADggEBADgvNKCE3XgLvEk3HUND\nJdrWzeK2XIw9c8z0Qr4im901tpPKaJrt13M+C+lou9K1uQm6Bvf8Cb0KL35P/jtM\nZmxquu1syvxmRW1utOTt4jJUYA3k8E+dXMic995IWEQPIQMpFD53gE3/LF6QqD8F\nFsMYsy832J83v55+TWqMNSwG9Y6usOm/UqHyxh1/PKldHTCpr9bMY5Pba0ko++0B\n8TUVA71uquwvJaSPbGWhf6IvWKiZZXyNyswF59UmOZJzzk3biEOdCALlRNy4UOn9\n3HzXQpIvueRNQ4uKUw6CxbyFZBv5oosN399A0zqYQGNSYRJIx66T7UcsW1MoNM5f\ngl0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFAM - Instituto Federal do Amazonas"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFAM - Instituto Federal do Amazonas"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifam.edu.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifam.edu.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFAM - Instituto Federal do Amazonas"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFAM - Instituto Federal do Amazonas"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.brock.ac.uk/entity",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Shepherd"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pshepherd@brock.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Shepherd"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pshepherd@brock.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.brock.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-02-19T15:11:51Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVANN1qLwgEDjyuLo3Focb4T3EV2gCMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBoxGDAWBgNVBAMTD2lkcC5icm9jay5hYy51azAeFw0xMzAyMTgwOTA1NDla\n\t\t\t\t\t\tFw0zMzAyMTgwOTA1NDlaMBoxGDAWBgNVBAMTD2lkcC5icm9jay5hYy51azCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIrnJtQiC1X81M7+DWcfoRnbQG4W\n\t\t\t\t\t\t6npvaBkLrBFA8ax53ocICKOyJ6GM1lKOKG3D34U7r6KO+vdFk/xKqQ+SOmNc6flx\n\t\t\t\t\t\tVCv4hyY6hL2I43+XpPYyhVYLdHOBUmhwS1iI/MV2ZBEe2Lde39JwAlsDG1maL7Gm\n\t\t\t\t\t\tQffCCWkzECXQj4tTCB7A/IjTqchH15ONVQ5E/FLNBoJgMexsOttaF5mriUjeeE0Z\n\t\t\t\t\t\tNQRTdquqqfUsH1b5fupGBrJ8mAEEvy5Mq2kTCqwjTjLnbSNBCDUeiFNJc2VmH4Fa\n\t\t\t\t\t\tRHs556u+sB+2/UkV83dfMS90SEJeAVc8dpA5GUWSWOKpC9ucRyc2Zl192SsCAwEA\n\t\t\t\t\t\tAaNlMGMwQgYDVR0RBDswOYIPaWRwLmJyb2NrLmFjLnVrhiZodHRwczovL2lkcC5i\n\t\t\t\t\t\tcm9jay5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU87QGKLBQ6rJ9iKC9\n\t\t\t\t\t\ttMLCBSx1qXUwDQYJKoZIhvcNAQEFBQADggEBAEX8DbfcfkOH6Qx8L35niQuZQA6h\n\t\t\t\t\t\t6ysVBS9A1rfs2wmBktWJhBAtSx4vfZBervafqstZ75Tf0OOXtjWR2r5HzZKXF7/N\n\t\t\t\t\t\twYBpFm/ZeCGIXIWqRMsZTZpaZ1p3VuzXrr5R+LwI3pheNqI9gUMIkXyC4rsI+Dbb\n\t\t\t\t\t\tVNGTt+C4rwqOvpwY2yEtmYgUffYG6gYi5t/PznbObAUfXNGIrBYdj3qQvNxaTrV4\n\t\t\t\t\t\tp0qobtoz00+ETWsQ82JOccQ93FWqkzwEAvdD2oc8KDBQgeSLYT2fhppTtmlmSNDk\n\t\t\t\t\t\tokEJmm6PxABBZBrAZUlLPTzfIG9tQiZD8a/JIrUo8nH3xjQhgMtOuyTLH/c="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brock.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.brock.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.brock.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.brock.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.brock.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.brock.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.brock.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.brock.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.brock.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brock.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVANN1qLwgEDjyuLo3Focb4T3EV2gCMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBoxGDAWBgNVBAMTD2lkcC5icm9jay5hYy51azAeFw0xMzAyMTgwOTA1NDla\n\t\t\t\t\t\tFw0zMzAyMTgwOTA1NDlaMBoxGDAWBgNVBAMTD2lkcC5icm9jay5hYy51azCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIrnJtQiC1X81M7+DWcfoRnbQG4W\n\t\t\t\t\t\t6npvaBkLrBFA8ax53ocICKOyJ6GM1lKOKG3D34U7r6KO+vdFk/xKqQ+SOmNc6flx\n\t\t\t\t\t\tVCv4hyY6hL2I43+XpPYyhVYLdHOBUmhwS1iI/MV2ZBEe2Lde39JwAlsDG1maL7Gm\n\t\t\t\t\t\tQffCCWkzECXQj4tTCB7A/IjTqchH15ONVQ5E/FLNBoJgMexsOttaF5mriUjeeE0Z\n\t\t\t\t\t\tNQRTdquqqfUsH1b5fupGBrJ8mAEEvy5Mq2kTCqwjTjLnbSNBCDUeiFNJc2VmH4Fa\n\t\t\t\t\t\tRHs556u+sB+2/UkV83dfMS90SEJeAVc8dpA5GUWSWOKpC9ucRyc2Zl192SsCAwEA\n\t\t\t\t\t\tAaNlMGMwQgYDVR0RBDswOYIPaWRwLmJyb2NrLmFjLnVrhiZodHRwczovL2lkcC5i\n\t\t\t\t\t\tcm9jay5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU87QGKLBQ6rJ9iKC9\n\t\t\t\t\t\ttMLCBSx1qXUwDQYJKoZIhvcNAQEFBQADggEBAEX8DbfcfkOH6Qx8L35niQuZQA6h\n\t\t\t\t\t\t6ysVBS9A1rfs2wmBktWJhBAtSx4vfZBervafqstZ75Tf0OOXtjWR2r5HzZKXF7/N\n\t\t\t\t\t\twYBpFm/ZeCGIXIWqRMsZTZpaZ1p3VuzXrr5R+LwI3pheNqI9gUMIkXyC4rsI+Dbb\n\t\t\t\t\t\tVNGTt+C4rwqOvpwY2yEtmYgUffYG6gYi5t/PznbObAUfXNGIrBYdj3qQvNxaTrV4\n\t\t\t\t\t\tp0qobtoz00+ETWsQ82JOccQ93FWqkzwEAvdD2oc8KDBQgeSLYT2fhppTtmlmSNDk\n\t\t\t\t\t\tokEJmm6PxABBZBrAZUlLPTzfIG9tQiZD8a/JIrUo8nH3xjQhgMtOuyTLH/c="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Brockenhurst College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.brock.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Brockenhurst College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://secure.uva.nl/cas",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://secure.uva.nl/cas",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-03-30T12:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/1b2e4ba73d7b526eee14a91782c45435",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Universiteit van Amsterdam"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Universiteit van Amsterdam"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/uva.png",
                    "height": "48",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "48"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universiteit van Amsterdam"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Amsterdam"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universiteit van Amsterdam"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universiteit van Amsterdam"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uva.nl"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uva.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universiteit van Amsterdam"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universiteit van Amsterdam"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.parliament.uk/openaccess",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.parliament.uk/openaccess",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/parliament.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/parliament.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "parliament.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "House of Commons"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.parliament.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.cpp.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "henson@cpp.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul Henson"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cpp.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cpp.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cpp.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUcgDt3ZH+mG2Chj61P92XzVTNbBkwDQYJKoZIhvcNAQEF\nBQAwFjEUMBIGA1UEAwwLaWRwLmNwcC5lZHUwHhcNMTQxMjE5MDM1ODMxWhcNMzQx\nMjE5MDM1ODMxWjAWMRQwEgYDVQQDDAtpZHAuY3BwLmVkdTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAKhqSiN7v+1ENcPxskjwEgayl8fHt5AWL93BOyP6\nLKc427BDR+beOW+iAJAtx44Vz0Fi8n/UoEC/cNbOxCk/Br1ZR7DcL/NYY9EbCd4S\n3uiGOPCiDQO9UVT6HcuhtR9/UXP2MWA8X7RHJFKR5hNQREWGaoriccpdMbfdKDM1\n/otvxyfJjQWaKm16EN8JE26E7EhBgsJn/YklafuDZGnliYX8XQ5LoZZPTApOuaSa\n7c6Uzeb+16reCP/AknTut0F4s3+G60wrSvCb/N0Ha3tVB8RscJL14PG39sYa53HQ\nHeD5FbFh/nw3VVfP8xNi1RoNff+WYrm5WMPWcx6LesPe/5UCAwEAAaNdMFswHQYD\nVR0OBBYEFF8DROHsl63pHHskwsoyBNrVB4oNMDoGA1UdEQQzMDGCC2lkcC5jcHAu\nZWR1hiJodHRwczovL2lkcC5jcHAuZWR1L2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3\nDQEBBQUAA4IBAQBLM5KaygDxcrC2SMxx72gca7A5Jk4y8XT7QZoaLk7aFKFC3b03\nAjIuVlnt6Ki0gsGQvcK509D4Y5gtipwiQYNZ9l7Pyi8w/BPNun26LYTCrTc1zW/N\nHOXvSvSkBI1fjHUF9M9GPhgSpOWTHSO6S3ugS4EcOfwdzcM4w61few5VVscAaUlH\nw6C2piN3HPUa0+88hna1AN0dGGmpVKdR7Xkac6LIMCdEsAwlBpHzlWGNnilE4qEe\nwQmsBX7k7/eUcdm/yH1rGY7oJExcfp/868ns8xN9o8E1xXFnwTCni+3EmtrMCw6t\nB/i23als47eQ6V3GQjcS0HkMkF6kkuZhMEv0"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cpp.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "California State Polytechnic University, Pomona"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California State Polytechnic University, Pomona"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cpp.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California State Polytechnic University, Pomona"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sci-ware-customer.com/swldev/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Blue"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alexei.blue@sci-ware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alexei"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Blue"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alexei.blue@sci-ware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alexei"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sci-ware-customer.com/swldev/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-11-05T10:52:13Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Science Warehouse SwlDev"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sci-ware.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Science Warehouse Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://swldev.sci-ware-customer.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://swldev.sci-ware-customer.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://swldev.sci-ware-customer.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://swldev.sci-ware-customer.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://swldev.sci-ware-customer.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://swldev.sci-ware-customer.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://swldev.sci-ware-customer.com/Shibboleth.sso/LoginYSJ",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAPftzawoE6U+MA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEGlwLTEwLTk1LTE0Mi0xNDUwHhcNMTUxMTAzMTcyNzM1WhcNMjUxMDMxMTcy\n\t\t\t\t\t\tNzM1WjAbMRkwFwYDVQQDExBpcC0xMC05NS0xNDItMTQ1MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAt9QCuEdzCjpBx2LtXLKhEWsjsBrd/4Uxkeh1/o6d\n\t\t\t\t\t\tIPPJZHrPMhaSb3TXfWqZhNNQEomI5rPd7LTNVgcGxAG9DVU3RBZc2TqaZgvP18xh\n\t\t\t\t\t\tIxF8SZk7tuR+HarVUXZMZJgf/yprQS8db4LCliqh1RPce5KylslsXktyjpg5AEwA\n\t\t\t\t\t\tqCd+8dC3+qw54WAG/pj28qbXNqwUm9BHWI50JN/HmhcvJgLKofbhwoJoGUPbO21e\n\t\t\t\t\t\tyFpGe1nQ91wLR8uLkzMb+LhFXwBNTpQ0AIIcIZ7ce6WirYRWSUrdNbWZ/nvSjq8f\n\t\t\t\t\t\tNwAmUrfSXOzSjdQQa8M1nwBZ3uCATyE6S/eTU0TEFXgD4QIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghBpcC0xMC05NS0xNDItMTQ1MB0GA1UdDgQWBBSOvn0o+/xiKTdakpuz\n\t\t\t\t\t\tsxefHX8ufTANBgkqhkiG9w0BAQUFAAOCAQEAIj+36LqW5NZsoBDUVA7L0/U3XTS3\n\t\t\t\t\t\tN36rYaoT8ibqj7Ol43DYC+kREavEEYF8NAPiNp06MhcZ5+NLpT0Z+lrNeLYyFN38\n\t\t\t\t\t\tM9HxcgrQV6syB3l09nUJaTCl4G1izUVAA0dVKWjI6qIOqrpMp2PcE181Z25lSl9b\n\t\t\t\t\t\tWEz45qKTxs3bvMp+hgi9WVwQX8kWvzKA3CGqCwFgcZSi58kn5/lcmNpaYCK+cNZH\n\t\t\t\t\t\teAquk+r1oYNyazGO4kkBhsYJ33hi9+G5ZJJkBHK8mHvvJMsWmN5ISQSUE0H+5yxy\n\t\t\t\t\t\tYCzUShNiI4OLItnjtZBuovyi9S3CB0BebK30iaLYM/LXpVI124hiqCbvdQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://swldev.sci-ware-customer.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://swldev.sci-ware-customer.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://swldev.sci-ware-customer.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://swldev.sci-ware-customer.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://swldev.sci-ware-customer.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://swldev.sci-ware-customer.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://swldev.sci-ware-customer.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://swldev.sci-ware-customer.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://swldev.sci-ware-customer.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://swldev.sci-ware-customer.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://rcnp-test.literatumonline.com/action/samlACS/shibboleth/testshib/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://rcnp-test.literatumonline.com/action/samlACS/shibboleth/testshib/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-11-26T14:28:29Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Royal College of Nursing Publishing"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://rcnp-test.literatumonline.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://rcnp-test.literatumonline.com/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://rcnp-test.literatumonline.com/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://rcnp-test.literatumonline.com/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIJAMqMZUiIsl4nMA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\n\t\t\t\t\t\tBAMTEXJjbnB1Ymxpc2hpbmcuY29tMB4XDTEzMTAwMzIxMzU1OFoXDTIzMTAwMTIx\n\t\t\t\t\t\tMzU1OFowHDEaMBgGA1UEAxMRcmNucHVibGlzaGluZy5jb20wggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDBlUJDDRaIIieWxx02H8sbXKNbUE6X+ZQbDeEk\n\t\t\t\t\t\tifb/0TqrolBjWGbwIB55jf4qL5aHy1Xb9lWiuItveLETbDsb6LGVRXjoBLMD/hq/\n\t\t\t\t\t\tINQNKlId7sUyaDD1dKdWo8vZAORnLLJfiNfJBFSfwt8dnnQihsv8ip1sQonfdjWF\n\t\t\t\t\t\t2JaPRwKHX864wn6x8CvqOgRNheowlhj6Hq69zX9mL9bKww6MC9c++11rwOYHVdGZ\n\t\t\t\t\t\tvZqhU0CxzNTDJWDRYwu5//PpMDLMJGTpbuRnN0SRR0uOJ6H9hACTO4MLGzO/WF4X\n\t\t\t\t\t\tcU1+I48q2gCdsZ2LaHWmNJqIy5IU24r2gu75uYAdUfE/n6UxAgMBAAGjZTBjMEIG\n\t\t\t\t\t\tA1UdEQQ7MDmCEXJjbnB1Ymxpc2hpbmcuY29thiRodHRwczovL3JjbnB1Ymxpc2hp\n\t\t\t\t\t\tbmcuY29tL3NoaWJib2xldGgwHQYDVR0OBBYEFBME3+HToUv+o1RLhxpnUhzXeecR\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQAiMV6SbpPn4cSK/tteSnvlGDu0kx0WrKHcq70j\n\t\t\t\t\t\t/TQyKZYc/roD1Xsbusj6kNhtbyg2UDKZMtUDJUX49Gy6od4hMft/LaO0d+S0fBA5\n\t\t\t\t\t\tpMGEl3rQpubIUem/SBAfN+Au+7j6yqi0vukGCqSWNAaQXt/XqkKys69b/CIbqkrm\n\t\t\t\t\t\tggWl3cXSrJx7GPKL1S9O5Oxd/cJO+g32L9qMH7LuKHLlnkEH8O5ZKjZjn+F6rBy7\n\t\t\t\t\t\tBBfwdYT/FpEL/nu+CPZwOcochpjY1HNtmq8tYGHv85r3mZkaLLnd+t0HGTw8X/Rs\n\t\t\t\t\t\tUlakv64cRCvOJRV/8DpP8bRsMrlqMkCQ2N3nu3eWKuQsgp67"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://rcnp-test.literatumonline.com/page/about-us"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "RCNP Test SP"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RCNP Test SP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "http://stsfed.login.vu.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://stsfed.login.vu.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-05-26T16:10:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/f5fc4ac4149942d16a3ad9e1d2c82065",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Vrije Universiteit Amsterdam"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Vrije Universiteit Amsterdam"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/vu.png",
                    "height": "51",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "107"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Vrije Universiteit Amsterdam"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Vrije Universiteit Amsterdam"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Vrije Universiteit Amsterdam"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vu.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Vrije Universiteit Amsterdam"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayf.viauc.dk/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayf.viauc.dk/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2010-08-17T13:39:34Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayf.viauc.dk/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "viauc.dk"
              },
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "VIA University College"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "VIA University College"
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "VIA University College"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "VIA University College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "viauc.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+DCCAeACAQcwDQYJKoZIhvcNAQELBQAwQjFAMD4GA1UEAww3aHR0cHM6Ly93\nYXlmLnZpYXVjLmRrL3NpbXBsZXNhbWwvc2FtbDIvaWRwL21ldGFkYXRhLnBocDAe\nFw0xNTAxMDEwMDAwMDBaFw0yNTEyMzEyMzU5NTlaMEIxQDA+BgNVBAMMN2h0dHBz\nOi8vd2F5Zi52aWF1Yy5kay9zaW1wbGVzYW1sL3NhbWwyL2lkcC9tZXRhZGF0YS5w\naHAwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDHiAwKahBTuI4Z+IJ1\nrgOeEiCCy3bR9QIe3BpCsejFCU5rSzkWANqVuc1PDfp0JdIZhrPXsmDJQMmidPCG\nPIDQKo+bk+af3+EUFS/I/+35sSBX2vf+h1DHvZV9jsznmpSVjp7HZ/WoPWBykWBJ\nO0AOVmzB5zlaqkS36J76+wxerwdpuExVnYSNd73S+AyT/EZ+tXAO+6lQ8FL/YMlJ\nnUkSaSqLSHFy01D2qBNmYRwBpCS6/dUZyxi0t5j8ghKUD4BHOZVavn65J62cJdXi\nOcMRyUAIp57GXQrL63KtrjIcXddq+CZyZ5t37EdUOIz42joFcy73MFOntynlKEvO\nw1BJAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAJLyoBjPprgZw7+PJUziqtx/XKbN\nHWNBLTHyukbdJuZITmsMdTnBDB1ZFLjQRx0xa1hEAzz6qAm8rAAUPPYNnYX6de4y\n+eutukD4eOrYOJrWXBgSRNh7pROKop7pcfF1O2kPJVKe5N6P2EosufIjedmg5M37\n95UnIU27my6t267qx3ucDya0tJn7P2YphiAJX4NnTb7pmlcy0VYlgKfHxyqn/yaF\nWNNvyHTFl7PX2VmlhOHPWxVCaL2HOsPyD62JGQoeGXNR0Y+HfZTXb3YpR9H+2x02\np2YMU09Pb33T82fJfzyq0fwa2AhboACWsblekPEHoMxrzNQUuKzcoGbK+WI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "VIA University College"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "VIA University College"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.viauc.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.viauc.com"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "VIA University College"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "VIA University College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ndsandbox.onecampus.com",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cloud_ops_support@rsmart.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Cloud Ops Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ndsandbox.onecampus.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RSmart"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rsmart.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RSmart"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://inside-test.nd.edu/saml/SSO/alias/ndsandbox",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://inside-test.nd.edu/saml/SSO/alias/ndsandbox",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://inside-test.nd.edu/saml/SSO/alias/ndsandbox",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://inside-test.nd.edu/saml/SSO/alias/ndsandbox",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF4jCCBMqgAwIBAgIIGDXYkef9MTEwDQYJKoZIhvcNAQELBQAwgbQxCzAJBgNV\nBAYTAlVTMRAwDgYDVQQIEwdBcml6b25hMRMwEQYDVQQHEwpTY290dHNkYWxlMRow\nGAYDVQQKExFHb0RhZGR5LmNvbSwgSW5jLjEtMCsGA1UECxMkaHR0cDovL2NlcnRz\nLmdvZGFkZHkuY29tL3JlcG9zaXRvcnkvMTMwMQYDVQQDEypHbyBEYWRkeSBTZWN1\ncmUgQ2VydGlmaWNhdGUgQXV0aG9yaXR5IC0gRzIwHhcNMTYwMjE3MjE1MjQwWhcN\nMTYwODA0MDIxMzM4WjBDMSEwHwYDVQQLExhEb21haW4gQ29udHJvbCBWYWxpZGF0\nZWQxHjAcBgNVBAMTFW9wZXJhdGlvbnMucnNtYXJ0LmNvbTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAMdKDT4kOWMti2IunhJLbHYbUqKMy2cPNnNl/8Ga\n4hmN60AL3khVxIum8KPFrWwcR/l7hka5zmQHJZgyPS7pmfl7u7UfzNJ1VVn5J0iI\nOZsv0g9XPGAHyoKIzwEMubzrO+nok8N2ZLJTmqYNfsKY9cj/db/ito5kw5GTEEIh\n5RO6NhcjrDUT8kiVqbusaJca/odwxZptzQk34XIa1jWp0N1A+XuhYRLHAQxpdMK3\nzTMvsagMHZYy+v4dOL9zAvfj8omjD/88/FUEhwxjR3mKPiuqu5zsGeh8Ackht36K\nutHbsUR0gABn4v0L02Ir7uBhUAPtvHK4sx3jJk/qbhC5cr8CAwEAAaOCAmYwggJi\nMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMA4G\nA1UdDwEB/wQEAwIFoDA3BgNVHR8EMDAuMCygKqAohiZodHRwOi8vY3JsLmdvZGFk\nZHkuY29tL2dkaWcyczEtMTk2LmNybDBTBgNVHSAETDBKMEgGC2CGSAGG/W0BBxcB\nMDkwNwYIKwYBBQUHAgEWK2h0dHA6Ly9jZXJ0aWZpY2F0ZXMuZ29kYWRkeS5jb20v\ncmVwb3NpdG9yeS8wdgYIKwYBBQUHAQEEajBoMCQGCCsGAQUFBzABhhhodHRwOi8v\nb2NzcC5nb2RhZGR5LmNvbS8wQAYIKwYBBQUHMAKGNGh0dHA6Ly9jZXJ0aWZpY2F0\nZXMuZ29kYWRkeS5jb20vcmVwb3NpdG9yeS9nZGlnMi5jcnQwHwYDVR0jBBgwFoAU\nQMK9J47MNIMwojPX+2yz8LQsgM4wgdwGA1UdEQSB1DCB0YIVb3BlcmF0aW9ucy5y\nc21hcnQuY29tghl3d3cub3BlcmF0aW9ucy5yc21hcnQuY29tghFvbmVjYW1wdXMu\nb3J1LmVkdYIRc2Fjc21hcnQuY3N1cy5lZHWCF3Rlc3QudWZpdC5vbmVjYW1wdXMu\nY29tghNkYXNoYm9hcmQud3Nlc3UubmV0ghRzZXJ2aWNlcy5vaXQucGR4LmVkdYIN\naW5zaWRlLm5kLmVkdYIQaW5zaWRlLXFhLm5kLmVkdYISaW5zaWRlLXRlc3QubmQu\nZWR1MB0GA1UdDgQWBBQPjZYdibOQi3hsFPA7MC9kSugpEjANBgkqhkiG9w0BAQsF\nAAOCAQEATaaZfrkcjzTHwhx/JxbHdQ25a4wyjCQNQvSsishfyIQ1BvXm5+LAPzOT\n7CHDZd7JJYvxMpK1fSfhyD9VkTr79Dml+Cc4hk+xNrFTyeRoU0PW3t6RophM8BO9\ntSivy7qLxDZyF4wCO3VKdhIK4nds+Ii0onX1yMnrq3O9rr0ucAgIRYPuEWs45++5\nD6poAwUTzyTxJWFhLRIRRMwriI7jJv397rRbQCxl48a57Fnby61sVH5HAu/fxQYP\nb9lqIDeybtp3R8/9ESFMjEKs+PRHXFWqWMyqeVF2i10omeJ1g/oBc9yQQBdwaMLg\nt+jAm0TyfZSJbeqoNJrVOYxd/djzcg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.rsmart.com/"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.rsmart.com/privacy-policy/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ND OneCampus Sandbox"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://shibboleth.lib.uh.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rspragg@uh.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert Spragg"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rspragg@uh.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert Spragg"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rspragg@uh.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert Spragg"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.lib.uh.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.lib.uh.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.lib.uh.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIULlNaR/yPtpIHLsg043vHlyUUb9owDQYJKoZIhvcNAQEF\nBQAwIDEeMBwGA1UEAxMVc2hpYmJvbGV0aC5saWIudWguZWR1MB4XDTA5MTEwNjIx\nNTEwOVoXDTI5MTEwNjIxNTEwOVowIDEeMBwGA1UEAxMVc2hpYmJvbGV0aC5saWIu\ndWguZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAiLfH0IINKgkb\nrIOkA/VFCgs+O8Voj/ywl8krAdq2+F5VQQC1+pHoTtcMp7MRHJ/HsRmDjQVkWlNR\nQEnFhnJv38dEIZnfkKWoijqWXTvkQeSvw+9rhU44I1GoBAxYRLm8BuljkOUlt/Xe\npfusfkjNZaSoeXyS4Q8VGxOtY4FrRXK5SuVhU8tYiBHj+oN7EEHaaj6amADey8u/\nkmGdlJIaq71qwkm9xPeOCcAceLJF0pJBsGUx4sDR4E3y+wGEoPfMSMgJFDH1cmmj\nlFlbE81f6R+57NaX5gIX2oDQStj/D4B5BTSkV0EJiG6ZwcdzsX4nRv+qI1XtMfN3\nvYu8DcA4VwIDAQABo3EwbzBOBgNVHREERzBFghVzaGliYm9sZXRoLmxpYi51aC5l\nZHWGLGh0dHBzOi8vc2hpYmJvbGV0aC5saWIudWguZWR1L2lkcC9zaGliYm9sZXRo\nMB0GA1UdDgQWBBTWtN42GnjSk3RkyD9wChaumT6JeTANBgkqhkiG9w0BAQUFAAOC\nAQEAckRFXo/Ps3CGTexk0U6VhZ3nUihG8dQR6yECjxpnrZU19u8u8jETLvTdgccL\nLTUlW9oapCGLiDNe9pAz04OrXrWFPaAG64eeFudF9ADat26Fb93alIUlJYTvIH9C\n7cIVqjtE4w1YDiGxIkmlxPCFsjxqQjRNzWvNmJAZ/7BqunjcKu573Ilv4CcteD2P\nE9I51v3x2TJs8SbOPJN87OyKEAilTSERUgXLxPKpGdL/3D3fZTB2cg35/EbDsAHd\nYBqltouvVCvEIi4TGm2qwqj8+X+JwbZ+ZHyLsy6u0GTBDQtMAvij6n17rKlM7DOv\nasKcVxzFt1IOY7qRu811/rvH7A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lib.uh.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.lib.uh.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.lib.uh.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.lib.uh.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.lib.uh.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.lib.uh.edu/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.lib.uh.edu/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lib.uh.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Shibboleth identity provider for the University of Houston Libraries."
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth.lib.uh.edu/idp/images2/uhl.png",
                    "lang": "en",
                    "height": "150",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "379"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Houston Libraries"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIULlNaR/yPtpIHLsg043vHlyUUb9owDQYJKoZIhvcNAQEF\nBQAwIDEeMBwGA1UEAxMVc2hpYmJvbGV0aC5saWIudWguZWR1MB4XDTA5MTEwNjIx\nNTEwOVoXDTI5MTEwNjIxNTEwOVowIDEeMBwGA1UEAxMVc2hpYmJvbGV0aC5saWIu\ndWguZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAiLfH0IINKgkb\nrIOkA/VFCgs+O8Voj/ywl8krAdq2+F5VQQC1+pHoTtcMp7MRHJ/HsRmDjQVkWlNR\nQEnFhnJv38dEIZnfkKWoijqWXTvkQeSvw+9rhU44I1GoBAxYRLm8BuljkOUlt/Xe\npfusfkjNZaSoeXyS4Q8VGxOtY4FrRXK5SuVhU8tYiBHj+oN7EEHaaj6amADey8u/\nkmGdlJIaq71qwkm9xPeOCcAceLJF0pJBsGUx4sDR4E3y+wGEoPfMSMgJFDH1cmmj\nlFlbE81f6R+57NaX5gIX2oDQStj/D4B5BTSkV0EJiG6ZwcdzsX4nRv+qI1XtMfN3\nvYu8DcA4VwIDAQABo3EwbzBOBgNVHREERzBFghVzaGliYm9sZXRoLmxpYi51aC5l\nZHWGLGh0dHBzOi8vc2hpYmJvbGV0aC5saWIudWguZWR1L2lkcC9zaGliYm9sZXRo\nMB0GA1UdDgQWBBTWtN42GnjSk3RkyD9wChaumT6JeTANBgkqhkiG9w0BAQUFAAOC\nAQEAckRFXo/Ps3CGTexk0U6VhZ3nUihG8dQR6yECjxpnrZU19u8u8jETLvTdgccL\nLTUlW9oapCGLiDNe9pAz04OrXrWFPaAG64eeFudF9ADat26Fb93alIUlJYTvIH9C\n7cIVqjtE4w1YDiGxIkmlxPCFsjxqQjRNzWvNmJAZ/7BqunjcKu573Ilv4CcteD2P\nE9I51v3x2TJs8SbOPJN87OyKEAilTSERUgXLxPKpGdL/3D3fZTB2cg35/EbDsAHd\nYBqltouvVCvEIi4TGm2qwqj8+X+JwbZ+ZHyLsy6u0GTBDQtMAvij6n17rKlM7DOv\nasKcVxzFt1IOY7qRu811/rvH7A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Houston Libraries"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://info.lib.uh.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Houston Libraries"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://wayf.ordbogen.com",
    {
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2010-08-17T14:13:05Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute_value": [
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "kalmar"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "denmark"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "iceland"
              }
            ],
            "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
            "name": "tags",
            "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "http://wayf.ordbogen.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://wayf.ordbogen.com/saml2/sp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Form\u00e5let er at levere en online ordbog hvori du kan foretage et ubegr\u00e6nset antal opslag i de ordb\u00f8ger som din institution har k\u00f8bt adgang til."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The purpose is to provide an online dictionary in which you can look up an unlimited number of words in the dictionaries bought by your educational institution."
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ordbogen.com"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ordbogen.com"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wayf.ordbogen.com/saml2/sp/AssertionConsumerService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Form\u00e5let er at levere en online ordbog hvori du kan foretage et ubegr\u00e6nset antal opslag i de ordb\u00f8ger som din institution har k\u00f8bt adgang til."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The purpose is to provide an online dictionary in which you can look up an unlimited number of words in the dictionaries bought by your educational institution."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Ordbogen.com"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Ordbogen.com"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "organizationName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib.labarchives.com/sp/production",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@labarchives.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LabArchives Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kenney"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nkenney@labarchives.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Norman"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.labarchives.com/sp/production",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-06-18T17:36:26Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "LabArchives"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.labarchives.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LabArchives, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.labarchives.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.labarchives.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.labarchives.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.labarchives.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.labarchives.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib.labarchives.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Electronic Laboratory Notebook, including Professional and Classroom Editions."
                  }
                ],
                "logo": [
                  {
                    "text": "https://mynotebook.labarchives.com/images/la_beaker.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "LabArchives"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQjCCAiqgAwIBAgIJAN/P3HVfB4O6MA0GCSqGSIb3DQEBBQUAMDQxMjAwBgNV\n\t\t\t\t\t\tBAMTKWRvbVUtMTItMzEtMzktMDMtMzAtNTQuY29tcHV0ZS0xLmludGVybmFsMB4X\n\t\t\t\t\t\tDTEyMTIwNDIxMDM1NloXDTIyMTIwMjIxMDM1NlowNDEyMDAGA1UEAxMpZG9tVS0x\n\t\t\t\t\t\tMi0zMS0zOS0wMy0zMC01NC5jb21wdXRlLTEuaW50ZXJuYWwwggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDYEIq97L4YEh0lzxO1gU0c3ZlD4luAqhr2DQeo\n\t\t\t\t\t\t/14OAlhUDRqgDgEdpKaGec2guAXiyJSuA0bsTFOx+DaYZorr7MFfuMMm2P7rU45G\n\t\t\t\t\t\tmbrhBmMLiQalvlAyk/2tOVenPM4yCJ6FMvf9o5AS+c4JsZCprSKSjSegMt6+zy4E\n\t\t\t\t\t\tuaO/SjD4DJ6sz4Xa7RqWIxVygGrjPKD7zOQpfDVVOc78mdUnCtNAudTiiLGBsRrZ\n\t\t\t\t\t\tetlymJm7snHG2gGcHC9Zfa1uoBsBzrwPA4X/nu/B4ICnuyTgLJq4Fx+o54bqWSZZ\n\t\t\t\t\t\tA9CNXvSXjoAOw3+Jqgdm1WFOrYOwOPGP0Y84vKUbaj+lzL1FAgMBAAGjVzBVMDQG\n\t\t\t\t\t\tA1UdEQQtMCuCKWRvbVUtMTItMzEtMzktMDMtMzAtNTQuY29tcHV0ZS0xLmludGVy\n\t\t\t\t\t\tbmFsMB0GA1UdDgQWBBQXjWp50EyWG9BwpuZJai08QZoJRTANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAiczpR8WP641CI/wX0wuVnhtYWQvrLcqhbzsOSojlK04DC8MdDysK+tpv\n\t\t\t\t\t\tKROZ8F4D1Tngrr4l1MWa0+BVQhW03opIQ2iKDp7fRSlqyJqqXS4DMEw0G2zcde7P\n\t\t\t\t\t\tD7o/Q8YD/PsboOIvsveaV8g3uaRvv0Y6/i+B/TslX8Mcpc8kkYhpVR1QfFpHo18m\n\t\t\t\t\t\tOzV0TEys7QRbVskIW8+a0uomjapzkYd3A9GWE4liaWByDSNDw/dqz9TNHKxHg4Ii\n\t\t\t\t\t\tyIRaQldYvHwxl9A5OL7ZutupYQ4z+C3c7QNBvrRVvM+bcDqxNVGk4MuhcjBdlIlE\n\t\t\t\t\t\t/C6n87viaq/ZgIt4Vck1JCGjLbLlqg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.labarchives.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.labarchives.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.labarchives.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shib.labarchives.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shib.labarchives.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shib.labarchives.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp1.crous-toulouse.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "crous-reseau@crous-toulouse.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp1.crous-toulouse.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-02-22T14:37:55Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp1.crous-toulouse.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp1.crous-toulouse.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp1.crous-toulouse.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "etu.crous-toulouse.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.crous-toulouse.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Toulouse - Etudiants"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Toulouse - Etudiants"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVANP/syULUNCGiJ6jMUcqvbTYvZ74MA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEFNSVmlEUC5jcm91cy5sYW4wHhcNMTExMDI4MTQwMDAx\nWhcNMzExMDI4MTUwMDAxWjAbMRkwFwYDVQQDExBTUlZpRFAuY3JvdXMubGFuMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkYnPcZx0e0Ce2gh7d7wyIkME\novrrzv0vlruzvby4oU2L0ebZwMb9cxQQBYu7jEgnvITkoAqzzAjnNW0aiPbTDnX0\nMa1OC1H7yG2HjdjMUmu9Dn7o8nhluFzXk7my3v6Cblt4SrMmsjh8aDFbixEIVLhp\nNdS80dAvUzhxlYd6JzJSdwcqB4pt9Syb4ahJxRh6BuzIQzqM4j+7ChIKkMP8BVYU\nZl3R0hkTcgB24Ha6GlWBeW15/mKSKnbXmQOy74Jhkhyh/jJ/0u03STQUx9mKnC5R\nOPyQNhIA7eBBQ1soxAXe59UURfcvMHj1u4Zw1jj09sHNLMaQDtf9f13H5bwo8wID\nAQABo2cwZTBEBgNVHREEPTA7ghBTUlZpRFAuY3JvdXMubGFuhidodHRwczovL1NS\nVmlEUC5jcm91cy5sYW4vaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFAawx20ceqtg\nJga00U1mDWS7Y0uJMA0GCSqGSIb3DQEBBQUAA4IBAQByK4s5e6Mx/3Kfiph8sbOV\nJlnm3mL8MrnOchYVGZ+qF/9Od66OH7wDv45gZ53EcuLBIFyPO8d1UjXGaMmjx5Un\npqjvYXU/lWWx1wSa5NzVXHNk/JMbSjvG5eqB4/HNy8PIhK/eviNX31N+tK40iTAP\nAY5+hwohjB3vH2jNsQgnSLqNG23N0XP+gywXbe4DeQyQeOSXCWF1cmN2AyJcwlX4\n+9yrgYP8FwS+60ev2v26ZY7fERxUSDtlpwvuWqor0ANFpPg8HbTiTxw4UCyOyLdL\nFm2Z0wb+tZB2P+GVyIVeS5Kk7SBtWd6iOnuhPvXdTZxSMTCnBOPDqwuSKJNzYSQL"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEWzCCA0OgAwIBAgIBBDANBgkqhkiG9w0BAQUFADB+MQswCQYDVQQGEwJmcjEO\nMAwGA1UECBMFRmFuY2UxETAPBgNVBAcTCFRvdWxvdXNlMQ4wDAYDVQQKEwVDcm91\nczEmMCQGCSqGSIb3DQEJARYXY3JvdXMtc2lAYWMtdG91bG91c2UuZnIxFDASBgNV\nBAMTC2ludGVybmFsLWNhMB4XDTExMTAyNzE0MjQxOFoXDTIxMTAyNDE0MjQxOFow\ngYMxCzAJBgNVBAYTAmZyMQ4wDAYDVQQIEwVGYW5jZTERMA8GA1UEBxMIVG91bG91\nc2UxDjAMBgNVBAoTBUNyb3VzMSYwJAYJKoZIhvcNAQkBFhdjcm91cy1zaUBhYy10\nb3Vsb3VzZS5mcjEZMBcGA1UEAxMQU1JWaURQLmNyb3VzLmxhbjCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAMgpkRfNo/rn5xeuCDLvQPoaFrMwq3tjCcCM\nO00rQSCNy81KOtPQOqTtbw+0CiOgHr0oC2jhUqV+IIkXP5rzBcBQw9IkGrHCQLPm\nYg0Yik1eQPGf8UYZKb5ulvArG2t0HuEfD+npSbsPhJPBmNhr5OkP9aZx+ey3+wQ7\n3RLhR3aDzTyFqwFjkkJcUANLQLmz2CbxnZ3c84OA//SVdDPe/iSqkBwPNOyi/ZsA\nsPSMYGf1OngY2lJJSllKssPIOkYNZPP7EIZxMv9jd7deMtTjEcAnoVJUOb0yb2HE\n+TBXShU4dSE46PBu8K9+/W90woEM11kwkHETwLDHuxzmfde5mrkCAwEAAaOB3TCB\n2jAdBgNVHQ4EFgQU7/P8O36Gwrq+uyg6sDWqG8jN3d4wgaoGA1UdIwSBojCBn4AU\ntrBU7BEx8lPtHYx+4HWHX6l5gguhgYOkgYAwfjELMAkGA1UEBhMCZnIxDjAMBgNV\nBAgTBUZhbmNlMREwDwYDVQQHEwhUb3Vsb3VzZTEOMAwGA1UEChMFQ3JvdXMxJjAk\nBgkqhkiG9w0BCQEWF2Nyb3VzLXNpQGFjLXRvdWxvdXNlLmZyMRQwEgYDVQQDEwtp\nbnRlcm5hbC1jYYIBADAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAV\nUtC7q5CB5NpDeJLsh7Caq5yTBD0Aq6QBp9fgjirq4U6wHxlriGTFqhGtc90t0lxQ\n8x/Xd+sXKT/65+yHj8BlfjGgT/1jTuUuLZNO67eIh04aMv/VGqCifo+6+B41ot77\n/XYb8OCrLhZdTrMyo3k+/tlXC4cZqY8e3q4EhQZm4YCA4/HIwd+VyBN1pjaYT7j/\nJ8VDIxl4TLSZqOQQdl/kMZhp5FtvJW6hB5IvFXiPzUru/eSelrTiCErPWDooGVol\nxaAGmA2uF92HwcV8uKkqzq8HVzznIXjR35te/qaKm6SO31RiK6/PxM2hfPK1UeOT\nefZl8BTyGK4ETamE3ANP"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS Toulouse - Etudiants"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.crous-toulouse.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS Toulouse - Etudiants"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.manchester.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-support@manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chalabi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:r.chalabi@manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rachid"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.manchester.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2007-12-04T15:35:56.421696Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEdzCCA1+gAwIBAgIQaXCywgq+vX5DO7vX+v+c6TANBgkqhkiG9w0BAQUFADA2\n\t\t\t\t\t\tMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n\t\t\t\t\t\tU1NMIENBMB4XDTEzMDUzMDAwMDAwMFoXDTE2MDUyOTIzNTk1OVowQzEhMB8GA1UE\n\t\t\t\t\t\tCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMR4wHAYDVQQDExVzaGliLm1hbmNo\n\t\t\t\t\t\tZXN0ZXIuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQD7mNMx\n\t\t\t\t\t\tlCtJ3uEbR9KNxl4wxdpRof4DyoKCu/FfByvIDfr9zB5H2P8mGQfOD0o49xiEkFCd\n\t\t\t\t\t\tlozVa8f8a3yNjY3pHgibEIMXSJ1QalP+CrINr/a32O8WYV9ZA2w3rkSggtWxxmVD\n\t\t\t\t\t\tHHQ9ufTl2lmvkGg1Z0+3VCic5mEEDHDKXKm4CWo5CGnT8/FzTD2sJfGdSsfi1WDK\n\t\t\t\t\t\tk6Gff+hv9VZCjWzSJgXtuLgYP5Ze9ZcDgcKuqlwlpOzOO6NEMI8dzfHMp+yTL+4B\n\t\t\t\t\t\tJaahF0zPuOsfJFdi6/r5GsmVLtJXiQuPstRPVTwb9mQuhOmDC4zYcPfjA49yjqnC\n\t\t\t\t\t\treJTACJv6Z42rmtRAgMBAAGjggFyMIIBbjAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJ\n\t\t\t\t\t\tays3V0fqkOO57TAdBgNVHQ4EFgQUNwr+LyyfLnzNIYq172tNWGDX2tIwDgYDVR0P\n\t\t\t\t\t\tAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsG\n\t\t\t\t\t\tAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1Ud\n\t\t\t\t\t\tHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NM\n\t\t\t\t\t\tQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50\n\t\t\t\t\t\tY3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6\n\t\t\t\t\t\tLy9vY3NwLnRjcy50ZXJlbmEub3JnMCAGA1UdEQQZMBeCFXNoaWIubWFuY2hlc3Rl\n\t\t\t\t\t\tci5hYy51azANBgkqhkiG9w0BAQUFAAOCAQEAcL1bk4E3a2N2C+va00jBDRb4BF69\n\t\t\t\t\t\tPfSqKZkXeeUHOpGUU0l30p8iS2uR7F+t3CYHulqN3jqPbtpNHUbtUdBpbIY/KTGW\n\t\t\t\t\t\tnm2fF8hW84RwmGhR2w7B+f3He5gleC7t7Tj91L+z7ue8YvbYxiLjIZfiEmon0iUT\n\t\t\t\t\t\t7d2BkbiIL7TVA3W63EIHnQHT4xNLzv1pvWCXU275R2k54qFyoYdmhC9sljPQWZ1v\n\t\t\t\t\t\tG7+O+Vm74LsAsHXnCQ0qkxarXF8aCLkHqhhLLUm4EgzRTeYbh9E6WFaQlDbQvRp8\n\t\t\t\t\t\tVwcrfdTH7WKGAJFWbvlQd/HKb8NJOkQOh+bJoHAn71W3DUoZU+DZYjiuIA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "manchester.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.manchester.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.manchester.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.manchester.ac.uk/shibboleth-idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.manchester.ac.uk/shibboleth-idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.manchester.ac.uk/shibboleth-idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.manchester.ac.uk/shibboleth-idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.manchester.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.manchester.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "manchester.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://login.manchester.ac.uk/disco/logo-16x16-m.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://login.manchester.ac.uk/disco/logo-80x34-ltd.png",
                    "height": "34",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Manchester"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "manchester.ac.uk"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "man.ac.uk"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "mbs.ac.uk"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "mimas.ac.uk"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "mib.ac.uk"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "mbs-worldwide.ac.uk"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.465624,-2.233193"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.474881,-2.233593"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.236237,-2.306421"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.480372,-2.24893"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.572576,-1.315923"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.462436,-2.227711"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.429749,-2.230049"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.445089,-2.278115"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.490592,-2.28839"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.487545,-2.323424"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.427332,-2.247825"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:46.23145,6.050119"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.88.0.0/16"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEdzCCA1+gAwIBAgIQaXCywgq+vX5DO7vX+v+c6TANBgkqhkiG9w0BAQUFADA2\n\t\t\t\t\t\tMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n\t\t\t\t\t\tU1NMIENBMB4XDTEzMDUzMDAwMDAwMFoXDTE2MDUyOTIzNTk1OVowQzEhMB8GA1UE\n\t\t\t\t\t\tCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMR4wHAYDVQQDExVzaGliLm1hbmNo\n\t\t\t\t\t\tZXN0ZXIuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQD7mNMx\n\t\t\t\t\t\tlCtJ3uEbR9KNxl4wxdpRof4DyoKCu/FfByvIDfr9zB5H2P8mGQfOD0o49xiEkFCd\n\t\t\t\t\t\tlozVa8f8a3yNjY3pHgibEIMXSJ1QalP+CrINr/a32O8WYV9ZA2w3rkSggtWxxmVD\n\t\t\t\t\t\tHHQ9ufTl2lmvkGg1Z0+3VCic5mEEDHDKXKm4CWo5CGnT8/FzTD2sJfGdSsfi1WDK\n\t\t\t\t\t\tk6Gff+hv9VZCjWzSJgXtuLgYP5Ze9ZcDgcKuqlwlpOzOO6NEMI8dzfHMp+yTL+4B\n\t\t\t\t\t\tJaahF0zPuOsfJFdi6/r5GsmVLtJXiQuPstRPVTwb9mQuhOmDC4zYcPfjA49yjqnC\n\t\t\t\t\t\treJTACJv6Z42rmtRAgMBAAGjggFyMIIBbjAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJ\n\t\t\t\t\t\tays3V0fqkOO57TAdBgNVHQ4EFgQUNwr+LyyfLnzNIYq172tNWGDX2tIwDgYDVR0P\n\t\t\t\t\t\tAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsG\n\t\t\t\t\t\tAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1Ud\n\t\t\t\t\t\tHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NM\n\t\t\t\t\t\tQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50\n\t\t\t\t\t\tY3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6\n\t\t\t\t\t\tLy9vY3NwLnRjcy50ZXJlbmEub3JnMCAGA1UdEQQZMBeCFXNoaWIubWFuY2hlc3Rl\n\t\t\t\t\t\tci5hYy51azANBgkqhkiG9w0BAQUFAAOCAQEAcL1bk4E3a2N2C+va00jBDRb4BF69\n\t\t\t\t\t\tPfSqKZkXeeUHOpGUU0l30p8iS2uR7F+t3CYHulqN3jqPbtpNHUbtUdBpbIY/KTGW\n\t\t\t\t\t\tnm2fF8hW84RwmGhR2w7B+f3He5gleC7t7Tj91L+z7ue8YvbYxiLjIZfiEmon0iUT\n\t\t\t\t\t\t7d2BkbiIL7TVA3W63EIHnQHT4xNLzv1pvWCXU275R2k54qFyoYdmhC9sljPQWZ1v\n\t\t\t\t\t\tG7+O+Vm74LsAsHXnCQ0qkxarXF8aCLkHqhhLLUm4EgzRTeYbh9E6WFaQlDbQvRp8\n\t\t\t\t\t\tVwcrfdTH7WKGAJFWbvlQd/HKb8NJOkQOh+bJoHAn71W3DUoZU+DZYjiuIA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Manchester"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.manchester.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Manchester"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.meertens.knaw.nl/Shibboleth.sso/Metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@knaw.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "KNAW"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kemps-Snijders"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:marc.kemps.snijders@meertens.knaw.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marc"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kemps-Snijders"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:marc.kemps.snijders@meertens.knaw.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marc"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.meertens.knaw.nl/Shibboleth.sso/Metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-02-13T16:31:05Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://clarin.eu/category/clarin-member"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.meertens.knaw.nl/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.meertens.knaw.nl/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.meertens.knaw.nl/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.meertens.knaw.nl/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Meertens Institut"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Meertens Institute"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Dieser Service Provider regelt den Zugang zum Meertens Institut Archive und ausgew\u00e4hlten Dienstleistungen f\u00fcr geisteswissenschaftliche Forschungsaktivit\u00e4ten auf dem Gebiet der niederl\u00e4ndischen Sprachvariation und Kultur."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This Service Provider regulates access to the Meertens Institute Archive and selected services for humanities research activities in the domain of Dutch language variation and culture."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "uid",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.meertens.knaw.nl/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.meertens.knaw.nl/cms/en"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Meertens Institut"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Meertens Institute"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Dieser Service Provider regelt den Zugang zum Meertens Institut Archive und ausgew\u00e4hlten Dienstleistungen f\u00fcr geisteswissenschaftliche Forschungsaktivit\u00e4ten auf dem Gebiet der niederl\u00e4ndischen Sprachvariation und Kultur."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This Service Provider regulates access to the Meertens Institute Archive and selected services for humanities research activities in the domain of Dutch language variation and culture."
                  }
                ],
                "logo": [
                  {
                    "text": "http://www.meertens.knaw.nl/cms/templates/mi_hetgelaat/css/images/logo_meertens_full.png",
                    "height": "135",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "200"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.meertens.knaw.nl/cms/en/collections/data-protection"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.meertens.knaw.nl"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF8TCCA9mgAwIBAgIJAPS1Y07BXsRDMA0GCSqGSIb3DQEBBQUAMIGOMQswCQYD\nVQQGEwJOTDELMAkGA1UECAwCTkgxEjAQBgNVBAcMCUFtc3RlcmRhbTENMAsGA1UE\nCgwES05BVzEMMAoGA1UECwwDSSZBMR0wGwYDVQQDDBR3d3cubWVlcnRlbnMua25h\ndy5ubDEiMCAGCSqGSIb3DQEJARYTc2VydmljZWRlc2tAa25hdy5ubDAeFw0xNDA1\nMDYxMDQxMzJaFw0yNDA1MDMxMDQxMzJaMIGOMQswCQYDVQQGEwJOTDELMAkGA1UE\nCAwCTkgxEjAQBgNVBAcMCUFtc3RlcmRhbTENMAsGA1UECgwES05BVzEMMAoGA1UE\nCwwDSSZBMR0wGwYDVQQDDBR3d3cubWVlcnRlbnMua25hdy5ubDEiMCAGCSqGSIb3\nDQEJARYTc2VydmljZWRlc2tAa25hdy5ubDCCAiIwDQYJKoZIhvcNAQEBBQADggIP\nADCCAgoCggIBAN0PojgkCqamdv1KflImeJwSTai6yEQv1lVchZsKhtw/eNQrGgFz\n2iC2p/hpQXoa32W76jXYfG9gK59N2Y22HQcjbw4azfMRyrorDXI9ruAjq9KY0l+q\nPibNODH4lXUEcJtQ5tgckCZnHtHJHGMrqIUZmgMDWI91GhmKb9qI5OucuHi4dFw0\n9gvWy2MW/wVejBAuWimQhlDvIzLNF3nesS/mawyXAAIgnyzT5sMEcTDifKuuF/Dq\nDyrIrlbFcUR9063SGtsbi32Qzk43VXZobD1GiMaah/jtlkZvvHx7x9HRXkjsROsy\nT0fqPSGsuH1USF4Ll0ctfmjKZdSU1DXoYefnFGah2+vu5x8+aSHyeIAABoNLzaPj\nNMI+Dt99IuLfSiRKi51HBcgI+uNScJuir/1qxjqxiAzJmXNiKOhPf2ATgsYWeP40\nQ7Q0AFDIdvFMaRBy+apmHcoE6C8DEnf2ejHaeZBm8T50z/2x1yvGd2EvLKB4Vonq\nCH/tdiPDRTEgcNjUMD+ZKDsZS3RhqaXJwWyRms0hHEnLPKsLK0JU9pAVEd15nGyg\nziL7QpdNpD08UYCjhIoWR/byMPAvU794n/SAYorLs7DpKEinwm4lYeMo1JglhHLa\n9KFuOBMy5iyQyCijxqSjWfzTgmUf0V0SJMY4283ctufsccPiPbBymSQjAgMBAAGj\nUDBOMB0GA1UdDgQWBBTvJnIYoaUYRuUSgD1dejg/rypgajAfBgNVHSMEGDAWgBTv\nJnIYoaUYRuUSgD1dejg/rypgajAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUA\nA4ICAQC7ki6eHoRyFUVoPK+A9aDfarOnLqujQDk8s775ZcNeSZwza47MgX4HVtxB\nbfRO4HRTp0huXVbfldV60Fo/OjoQb4hS7bZjTq0m2zy1XoEmlM9rykMS8UnUsVzr\nBfC4Tq3mF3hBkiTSYkp5EekBr7PVkQK8G3XW8Jfbaf9AMbgOnEiSztHR8VKhgu2H\n6cxEj6K2il1ge/kbvYJWoxHLAhSkxOhnMs225COGoQt8Gb6pWXIIMo5QkVuZwlQE\nAKDXeuthjxa/DtxDN3SYw5MMw9qZN1RPbkwEkJpRzHceq7hQbmL0KlwPKXqqKT90\no/+9ZTdR/6xptba73E1YtG1Iq5pQBxK6SU3HPLpCBcei6XGdi7QdDFPFfrPLg7RK\nKpxjeDWUTpopH0JEVvSgX0Tn9pVFVq5F4cial+yOpwDxZvAOwjJlWotoqnyVsDOn\nuESSSj1tVqW+2zqLTdzOpWaP0kWlu7wrL5PzqWhaPVChL+KYs40TNd2XK1rlOtNe\nWWcZ8uJ+ftZDNEGNvaTnRZLhxGxE9OWThvwL0iyOw8vEcWHm2JNRy3VkSvguFDcM\nMXWm4sBAe8iEXXkAxrflHdBubei1FTexa+Kl9lQ/ICrpmT+V1Jyi4DrdvS0+2ijb\nSF7hTs3mZvR2FPh5VJ0vBUC7QOXB5RBcP6vy4H25WiovevzKOg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=servicedesk@knaw.nl,CN=www.meertens.knaw.nl,OU=I&A,O=KNAW,L=Amsterdam,ST=NH,C=NL"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.meertens.knaw.nl/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.meertens.knaw.nl/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.meertens.knaw.nl/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.meertens.knaw.nl/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.meertens.knaw.nl/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.meertens.knaw.nl/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.meertens.knaw.nl/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.meertens.knaw.nl/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.meertens.knaw.nl/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.meertens.knaw.nl/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ucl-research-test.worktribe.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@worktribe.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Southall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:matt.southall@worktribe.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matt"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ucl-research-test.worktribe.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-11-13T10:15:45Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UCL Worktribe Research Management (Test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.worktribe.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Worktribe Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ucl-research-test.worktribe.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ucl-research-test.worktribe.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ucl-research-test.worktribe.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ucl-research-test.worktribe.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ucl-research-test.worktribe.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ucl-research-test.worktribe.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIJALJ6YNn8QO6YMA0GCSqGSIb3DQEBBQUAMCoxKDAmBgNV\n\t\t\t\t\t\tBAMTH3VjbC1yZXNlYXJjaC10ZXN0Lndvcmt0cmliZS5jb20wHhcNMTUxMTA5MTU0\n\t\t\t\t\t\tNjEzWhcNMjUxMTA2MTU0NjEzWjAqMSgwJgYDVQQDEx91Y2wtcmVzZWFyY2gtdGVz\n\t\t\t\t\t\tdC53b3JrdHJpYmUuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tsMg3x4IK0YYNTCzZL5lq1vdm4YgGEKrnG6eGz0DVTxuqMBy6wvmRs/ibHBraD+c7\n\t\t\t\t\t\tCqz+89aKjQGpED+QkIajP8f7X/5b7UMV/Ee1gUcHsQiNH3pvNci9t5k5nhNSUlVI\n\t\t\t\t\t\tS2tbeKNdxFarNm5DfbuXSQZ0/6ix203W9GId4e535i/poqJK+tX58rJgRtyK9ctE\n\t\t\t\t\t\tIAHAmvelJ0r8dVv6L1p0vl+hwhFERF0DVHBcsW0Bjya9oq3FzUpPosGRRB8nISlF\n\t\t\t\t\t\tOQxPIcNaLB0x4hn6sixLGk8t5ieqH0+dH1JXZMfas92ezx0N/2kEIgMI8XUEjjPB\n\t\t\t\t\t\tbUqKKhv+K5k5vmc7+hnznwIDAQABo00wSzAqBgNVHREEIzAhgh91Y2wtcmVzZWFy\n\t\t\t\t\t\tY2gtdGVzdC53b3JrdHJpYmUuY29tMB0GA1UdDgQWBBT+0Yvz6W6N62PE+glPO64K\n\t\t\t\t\t\tolYhlDANBgkqhkiG9w0BAQUFAAOCAQEAn9CW+v5B4ZPYGB+5j/nDlXhhNMvb8Xqb\n\t\t\t\t\t\tr1C3q2FhnoOVxwZmQrNVOTL/tHQ98eEgm+G9PXTGpSD3zDgUsChxY9WHhvQsN7JU\n\t\t\t\t\t\tWuLfQVjnKSQRjoDwO/Fneg5rZstZJtQPM1JNK4ovEkJPwVuEtxGQc8/W0pnQDhWm\n\t\t\t\t\t\tNHaWS8dkuu3GULmMN6VHXIQ3JtrdrV9JViYxzuXIBlDHcJP9KSHYQLRT5E7VQsKB\n\t\t\t\t\t\tDqlP/Xl8qSeRDuZ2BGHaRY9L9tv83/wmgDw5M9aD6mnitldU42OaaRgOZfz9IJw8\n\t\t\t\t\t\twEizXjk+w4nXfsGJx17O8t3uXHElZVQeCtUfiAR7QL+9hmQGhhTvMA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ucl-research-test.worktribe.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ucl-research-test.worktribe.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ucl-research-test.worktribe.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ucl-research-test.worktribe.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ucl-research-test.worktribe.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ucl-research-test.worktribe.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://login.unlv.edu/FIM/sps/MyShib/saml20",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "don.diener@unlv.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Don Diener"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "bob.fournier@unlv.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bob Fournier"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ithelp@unlv.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT  Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "informationsecurityoffice@unlv.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Security Office"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://login.unlv.edu/FIM/sps/MyShib/saml20",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.unlv.edu/FIM/sps/MyShib/saml20/soap",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUjCCAjqgAwIBAgIEVD3EHjANBgkqhkiG9w0BAQUFADBrMQswCQYDVQQGEwJVUzELMAkGA1UE\nCBMCTlYxEjAQBgNVBAcTCUxhcyBWZWdhczENMAsGA1UEChMEVU5MVjEMMAoGA1UECxMDT0lUMR4w\nHAYDVQQDExVzc28tZmltLXNoaWIudW5sdi5lZHUwHhcNMTQxMDE1MDA0NzI2WhcNMjMwMTAxMDE0\nNzI2WjBrMQswCQYDVQQGEwJVUzELMAkGA1UECBMCTlYxEjAQBgNVBAcTCUxhcyBWZWdhczENMAsG\nA1UEChMEVU5MVjEMMAoGA1UECxMDT0lUMR4wHAYDVQQDExVzc28tZmltLXNoaWIudW5sdi5lZHUw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCbkmPqD2c1WXNNFPdSo8UPPJjb4n7HhKBn\ni8mvzzXMr/GQwsxaJM3pEek+aSQgwN59Oh3/odoQR2LAUMyhTZEWEtZXfksgNvEv5lpM3CbNdmnM\nxowDo+RZv7wxjr2HpswHJxGcCNAvKHeUJeFlW3BYq3stqY0Ix42DSgRXgXQpE9mAJzoRtdMXyhqL\nbN+rawZkV2/5+WU2batVV/u0TITD6RhdoylUqppmJSSsjXpoR7u16VRb6x9LZIU21eyPJjvdnPA6\nL33br9yQ0bCINUgjXugNrIs5YefKK2soBsU5AovnXRAnAiIaZhHuPlOxO1RELZn7UANA8DBRLhzH\n9j8NAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBADGw+IvIW0Pm8Bqvf3WTmpszhNDyP4jD+K5Vt+zO\nuEpSKrxb+HN2vO2hQ9SSFi6gxmkVWg1eK7c/JPh36vmX6dlGuhUBPnsr4wgpfC/ZFOGEAo1Vwpu7\n7+p8JbHn1Y21QcSGPOdxzMRJOUzN7IeQtYwVOLnrXXLHlFqf0RjcB22vfyPANc6yAIWFBTC5pc/2\nHVfcwNXQRj8KQswTahjDFSbPulp97SLNa5aMw3f1PRtnGGvb8HB7CSjGfzHouNqxTEPf3A0nqpdx\n9ec1L21OjIC/MXHxLYUfFJOldQNNCr5jHELdJU2xsuv3t7G8dNw/dwIjL3ItJgEYFeQNDUTIl78="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unlv.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.unlv.edu/FIM/sps/MyShib/saml20/slo",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.unlv.edu/FIM/sps/MyShib/saml20/soap",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.unlv.edu/FIM/sps/MyShib/saml20/login",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.unlv.edu/FIM/sps/MyShib/saml20/login",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unlv.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://oit.unlv.edu/incommon/information"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Nevada-Las Vegas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUjCCAjqgAwIBAgIEVD3EHjANBgkqhkiG9w0BAQUFADBrMQswCQYDVQQGEwJVUzELMAkGA1UE\nCBMCTlYxEjAQBgNVBAcTCUxhcyBWZWdhczENMAsGA1UEChMEVU5MVjEMMAoGA1UECxMDT0lUMR4w\nHAYDVQQDExVzc28tZmltLXNoaWIudW5sdi5lZHUwHhcNMTQxMDE1MDA0NzI2WhcNMjMwMTAxMDE0\nNzI2WjBrMQswCQYDVQQGEwJVUzELMAkGA1UECBMCTlYxEjAQBgNVBAcTCUxhcyBWZWdhczENMAsG\nA1UEChMEVU5MVjEMMAoGA1UECxMDT0lUMR4wHAYDVQQDExVzc28tZmltLXNoaWIudW5sdi5lZHUw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCbkmPqD2c1WXNNFPdSo8UPPJjb4n7HhKBn\ni8mvzzXMr/GQwsxaJM3pEek+aSQgwN59Oh3/odoQR2LAUMyhTZEWEtZXfksgNvEv5lpM3CbNdmnM\nxowDo+RZv7wxjr2HpswHJxGcCNAvKHeUJeFlW3BYq3stqY0Ix42DSgRXgXQpE9mAJzoRtdMXyhqL\nbN+rawZkV2/5+WU2batVV/u0TITD6RhdoylUqppmJSSsjXpoR7u16VRb6x9LZIU21eyPJjvdnPA6\nL33br9yQ0bCINUgjXugNrIs5YefKK2soBsU5AovnXRAnAiIaZhHuPlOxO1RELZn7UANA8DBRLhzH\n9j8NAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBADGw+IvIW0Pm8Bqvf3WTmpszhNDyP4jD+K5Vt+zO\nuEpSKrxb+HN2vO2hQ9SSFi6gxmkVWg1eK7c/JPh36vmX6dlGuhUBPnsr4wgpfC/ZFOGEAo1Vwpu7\n7+p8JbHn1Y21QcSGPOdxzMRJOUzN7IeQtYwVOLnrXXLHlFqf0RjcB22vfyPANc6yAIWFBTC5pc/2\nHVfcwNXQRj8KQswTahjDFSbPulp97SLNa5aMw3f1PRtnGGvb8HB7CSjGfzHouNqxTEPf3A0nqpdx\n9ec1L21OjIC/MXHxLYUfFJOldQNNCr5jHELdJU2xsuv3t7G8dNw/dwIjL3ItJgEYFeQNDUTIl78="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Nevada-Las Vegas"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unlv.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Nevada-Las Vegas"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.holycross.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wilson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:raw@holycross.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wilson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:raw@holycross.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.holycross.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-08-08T11:07:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjwCCQDPBZyVuDlkujANBgkqhkiG9w0BAQUFADBsMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjETMBEGA1UECBMKTGFuY2FzaGlyZTENMAsGA1UEBxMEQnVyeTEbMBkGA1UEChMS\n\t\t\t\t\t\tSG9seSBDcm9zcyBDb2xsZWdlMRwwGgYDVQQDExNpZHAuaG9seWNyb3NzLmFjLnVr\n\t\t\t\t\t\tMB4XDTE0MDYyMDEyMDgzOVoXDTM0MDYxNTEyMDgzOVowbDELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tEzARBgNVBAgTCkxhbmNhc2hpcmUxDTALBgNVBAcTBEJ1cnkxGzAZBgNVBAoTEkhv\n\t\t\t\t\t\tbHkgQ3Jvc3MgQ29sbGVnZTEcMBoGA1UEAxMTaWRwLmhvbHljcm9zcy5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALkf9BA2MoTWP1Et24UtZ4ZE\n\t\t\t\t\t\t6XsAQ+ykCv3jhfVULoxzTjgSEDepcS1uweBQo0Mua4uB2iAmTe4GCXh2xfdCVNK8\n\t\t\t\t\t\t3Sm1fusNjjZFyIEOV1Kf+pmqR5IJFtDfVZpfiYiohiBkGm5WX1Ir1BLKUWxZjT0e\n\t\t\t\t\t\tlW21AdK8vPl5Ag38vAZynNUmKIxCSED9MiZoh373dgtu5Wl01Yjj6NH46JGA7G7/\n\t\t\t\t\t\tFOId7Ip/jhPYTldVWpGDv/5SHjpP+nMnRmUEw0hSQ/fpNS5fpnnGcoUjFDUHhlZN\n\t\t\t\t\t\tc8wgfpL1SeG5rdVkMioLvRMCnyyrKQeKyZNhg97WDiKuHag41tf5MQ/LSznH0fsC\n\t\t\t\t\t\tAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAnPfzR48PVuYBh+xA5vAUU+habal3VAoD\n\t\t\t\t\t\tmEEOU4Zvn2KonwB8JTyNqaNdFHqwmuR8fctB6XV1ZWQeOTDqJp+sc/SZRAFVCG36\n\t\t\t\t\t\tZadN0NNByFp0jZblXYI3XQs2MYPzOsqKJgqFUPfDPSfJ2W3aIbD3vDG7UbOfDKkx\n\t\t\t\t\t\tLtaM9+LmqqBASGV8qwIJhdLG4znAeaeeDdes84gLFcSuxGq9EqvOIO4q+Q+m2JwX\n\t\t\t\t\t\tWWZqc/Tnz6A60KnEbChH/UnymSArytLz6Zfk47Xzxs+Mq9NzPZ9XPif+Dw04pm69\n\t\t\t\t\t\tqAp30iOD9pcAPq2kyLUGxrT4XraJjaw/JV+lVPY6QYCcJoj0kKteRA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "holycross.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.holycross.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.holycross.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.holycross.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.holycross.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.holycross.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.holycross.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.holycross.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.holycross.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "holycross.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjwCCQDPBZyVuDlkujANBgkqhkiG9w0BAQUFADBsMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjETMBEGA1UECBMKTGFuY2FzaGlyZTENMAsGA1UEBxMEQnVyeTEbMBkGA1UEChMS\n\t\t\t\t\t\tSG9seSBDcm9zcyBDb2xsZWdlMRwwGgYDVQQDExNpZHAuaG9seWNyb3NzLmFjLnVr\n\t\t\t\t\t\tMB4XDTE0MDYyMDEyMDgzOVoXDTM0MDYxNTEyMDgzOVowbDELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tEzARBgNVBAgTCkxhbmNhc2hpcmUxDTALBgNVBAcTBEJ1cnkxGzAZBgNVBAoTEkhv\n\t\t\t\t\t\tbHkgQ3Jvc3MgQ29sbGVnZTEcMBoGA1UEAxMTaWRwLmhvbHljcm9zcy5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALkf9BA2MoTWP1Et24UtZ4ZE\n\t\t\t\t\t\t6XsAQ+ykCv3jhfVULoxzTjgSEDepcS1uweBQo0Mua4uB2iAmTe4GCXh2xfdCVNK8\n\t\t\t\t\t\t3Sm1fusNjjZFyIEOV1Kf+pmqR5IJFtDfVZpfiYiohiBkGm5WX1Ir1BLKUWxZjT0e\n\t\t\t\t\t\tlW21AdK8vPl5Ag38vAZynNUmKIxCSED9MiZoh373dgtu5Wl01Yjj6NH46JGA7G7/\n\t\t\t\t\t\tFOId7Ip/jhPYTldVWpGDv/5SHjpP+nMnRmUEw0hSQ/fpNS5fpnnGcoUjFDUHhlZN\n\t\t\t\t\t\tc8wgfpL1SeG5rdVkMioLvRMCnyyrKQeKyZNhg97WDiKuHag41tf5MQ/LSznH0fsC\n\t\t\t\t\t\tAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAnPfzR48PVuYBh+xA5vAUU+habal3VAoD\n\t\t\t\t\t\tmEEOU4Zvn2KonwB8JTyNqaNdFHqwmuR8fctB6XV1ZWQeOTDqJp+sc/SZRAFVCG36\n\t\t\t\t\t\tZadN0NNByFp0jZblXYI3XQs2MYPzOsqKJgqFUPfDPSfJ2W3aIbD3vDG7UbOfDKkx\n\t\t\t\t\t\tLtaM9+LmqqBASGV8qwIJhdLG4znAeaeeDdes84gLFcSuxGq9EqvOIO4q+Q+m2JwX\n\t\t\t\t\t\tWWZqc/Tnz6A60KnEbChH/UnymSArytLz6Zfk47Xzxs+Mq9NzPZ9XPif+Dw04pm69\n\t\t\t\t\t\tqAp30iOD9pcAPq2kyLUGxrT4XraJjaw/JV+lVPY6QYCcJoj0kKteRA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Holy Cross College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.holycross.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Holy Cross College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibidp.cca.unipd.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:supporto.sso@unipd.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibidp.cca.unipd.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2009-12-31T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUTSdt0Dt8swpFu9qJLBfnEV09alwwDQYJKoZIhvcNAQEF\nBQAwHzEdMBsGA1UEAxMUc2hpYmlkcC5jY2EudW5pcGQuaXQwHhcNMTAxMjI5MTgz\nNjIyWhcNMzAxMjI5MTgzNjIyWjAfMR0wGwYDVQQDExRzaGliaWRwLmNjYS51bmlw\nZC5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJMiK2A2ZC6vp69H\nsIR2wqYEMMkDfhs91u1UhDibfc1kT3LZEPN42L6B95s1TZb6+f1M5YDCmDzmHrlA\nYkFbK/yW2jSHXuTR+dSP071d+Xa+00qrokGotUYyqstfqOjiAhVyC4vDVwDgAPj3\n1K9wCjrZcazt3NZC6mPD9XJBQ1YJ6sDvk6y+UVQfeHoKKrAC9MSoFMRwoLI9izIq\n7NbqOLV9pDjV4GvspxJs00krQiATzoYblatuR4xtSHcSpmYFqD6VCTosKwISLqKA\nerlsKlyfKSBF7xuan+lgzJLSLWvvhj+Bv0oRfOJnQEsP1vjG/s9J8RQPee/HdmjQ\nkKiHOF0CAwEAAaNvMG0wTAYDVR0RBEUwQ4IUc2hpYmlkcC5jY2EudW5pcGQuaXSG\nK2h0dHBzOi8vc2hpYmlkcC5jY2EudW5pcGQuaXQvaWRwL3NoaWJib2xldGgwHQYD\nVR0OBBYEFGYTCKzj5155S2lqpPV5/6I1jePjMA0GCSqGSIb3DQEBBQUAA4IBAQAM\nOKvcKfl2rMZS1ivnvOcDNNwgXEaa27Vre4D6PxMhR4dM3UvdS+qP2pL6M2guI95K\nHSR4VUoHXw4Hnq5Hk9yyCBp38xmPs7AefGcbYvgf3nx75CEtXE9jDG35tL9lgted\nd1Ksu3uT3jxKcPTVqdNWnTB7N2TYoWJhbGOmC1US4iMzp5UEGrvdZUvcZI+6/VsG\nd/CKd1tzg3Io4xevtARfgavjvQ5VDbyGdzMg9GD3h5zNsTDDqEjFyylYlay7cUCe\n48QsT4K0vJexMVAd/xf3jNCQmcFmgmE/pgq+4636NURxTV39x3TxwjQv6Wa57zml\nG+DXFhqRaj5xn2FulnFc"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unipd.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.cca.unipd.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.cca.unipd.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.cca.unipd.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.cca.unipd.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibidp.cca.unipd.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.cca.unipd.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.cca.unipd.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.cca.unipd.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unipd.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unipd.it/en/idem"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unipd.it/idem"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Padova"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 degli Studi di Padova"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for users affiliated to the University of Padova"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider per gli utenti dell'Universit\u00e0 degli Studi di Padova"
                  }
                ],
                "logo": [
                  {
                    "text": "https://bandi.didattica.unipd.it/logo-unipd16x16.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://bandi.didattica.unipd.it/logo-unipd16x16.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://bandi.didattica.unipd.it/logo-unipd80x60.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://bandi.didattica.unipd.it/logo-unipd80x60.png",
                    "lang": "it",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.unipd.it/en/idem"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.unipd.it/idem"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUTSdt0Dt8swpFu9qJLBfnEV09alwwDQYJKoZIhvcNAQEF\nBQAwHzEdMBsGA1UEAxMUc2hpYmlkcC5jY2EudW5pcGQuaXQwHhcNMTAxMjI5MTgz\nNjIyWhcNMzAxMjI5MTgzNjIyWjAfMR0wGwYDVQQDExRzaGliaWRwLmNjYS51bmlw\nZC5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJMiK2A2ZC6vp69H\nsIR2wqYEMMkDfhs91u1UhDibfc1kT3LZEPN42L6B95s1TZb6+f1M5YDCmDzmHrlA\nYkFbK/yW2jSHXuTR+dSP071d+Xa+00qrokGotUYyqstfqOjiAhVyC4vDVwDgAPj3\n1K9wCjrZcazt3NZC6mPD9XJBQ1YJ6sDvk6y+UVQfeHoKKrAC9MSoFMRwoLI9izIq\n7NbqOLV9pDjV4GvspxJs00krQiATzoYblatuR4xtSHcSpmYFqD6VCTosKwISLqKA\nerlsKlyfKSBF7xuan+lgzJLSLWvvhj+Bv0oRfOJnQEsP1vjG/s9J8RQPee/HdmjQ\nkKiHOF0CAwEAAaNvMG0wTAYDVR0RBEUwQ4IUc2hpYmlkcC5jY2EudW5pcGQuaXSG\nK2h0dHBzOi8vc2hpYmlkcC5jY2EudW5pcGQuaXQvaWRwL3NoaWJib2xldGgwHQYD\nVR0OBBYEFGYTCKzj5155S2lqpPV5/6I1jePjMA0GCSqGSIb3DQEBBQUAA4IBAQAM\nOKvcKfl2rMZS1ivnvOcDNNwgXEaa27Vre4D6PxMhR4dM3UvdS+qP2pL6M2guI95K\nHSR4VUoHXw4Hnq5Hk9yyCBp38xmPs7AefGcbYvgf3nx75CEtXE9jDG35tL9lgted\nd1Ksu3uT3jxKcPTVqdNWnTB7N2TYoWJhbGOmC1US4iMzp5UEGrvdZUvcZI+6/VsG\nd/CKd1tzg3Io4xevtARfgavjvQ5VDbyGdzMg9GD3h5zNsTDDqEjFyylYlay7cUCe\n48QsT4K0vJexMVAd/xf3jNCQmcFmgmE/pgq+4636NURxTV39x3TxwjQv6Wa57zml\nG+DXFhqRaj5xn2FulnFc"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Padova"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 di Padova"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unipd.it/en/"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unipd.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Padova"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli Studi di Padova"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://play.education.lu.se/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:saml_admin@kaltura.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://play.education.lu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lund University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://play.education.lu.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Lunds universitet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://play.education.lu.se/user/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Kaltura MediaSpace"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Kaltura MediaSpace"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kaltura MediaSpace"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kaltura MediaSpace"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.education.lu.se/user/authenticate",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib.uvu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "daniel.hutchison@uvu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Daniel Hutchison"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "roark.fisher@uvu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roark Fisher"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ray.walker@uvu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ray Walker"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "servicedesk@uvu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UVU Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.uvu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.uvu.edu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.uvu.edu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.uvu.edu:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.uvu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.uvu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.uvu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.uvu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.uvu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uvu.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Utah Valley University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAIWjwZnQgd29AuQOjNMS9y2+8FFwMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDHNoaWIudXZ1LmVkdTAeFw0xMzEyMTAxNzU3MDNaFw0z\nMzEyMTAxNzU3MDNaMBcxFTATBgNVBAMTDHNoaWIudXZ1LmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAN1YKRKz+60gwNpZEYxw51V3q9BblanyftbM\nyaHTAA/SN9H855TBFiss878JtQLCvbbodnaYVlDK72z6vTBEnw4cJ+q8OkYmnSmx\nPkVDAn3rPN1ZhQXtRxQRQgVWVZafOMn8VtPSNWhKuuWHDkeAJ0eurJXkgnAHVdlZ\nxl+GCEtYqcNTzDY6rjRei2SIoIW8iTxslLSIOB3bKot4MSw76r/pTRTM2sT1LguW\nIBmWyiEf0ZE1eN2tFUuJ0YXRdY+gv5cXE/4FJvmRZLUIpESbgVhKYqE1nZ/uOdDy\nxelKK/KyiNobPC+j0kOEK8kqBH52uDEHYAEfgOZVY6jF8+bSOSkCAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMc2hpYi51dnUuZWR1hiNodHRwczovL3NoaWIudXZ1LmVkdS9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU9ry+XKPGV4qG5d5pmeOxy8macHgwDQYJ\nKoZIhvcNAQEFBQADggEBAEI3J/h+DD38s5sQAZ9CGLEryR38OcI3YoOVomOcbWqh\n4OySvoopqnpkKyn3CU7+6YY7JHKIM3dOZJCrVdMkLdMaiM+qZU/KVPoWCYP82fx7\nQpvT/IJmfVDOQvo5g74G071up6qoJD0/F7u4Ay88EeCeWZj56FDUEoLPdA7nbIPs\nVMrMibM4Ev/bsVae0FBMJFhOvNc23AbdB4tGn28u7TKhh9GhVT6OQCFt3Mh9t7s9\n8ImEM2KbtYysjpDT7fIvlc7AOeeXSAmhdjSB+D3BKcJfwWqHEl9mZ0WQHgmPUj+L\nBrv9aaSeb9ZfeFo2Sw2coWZe3ONc4UsUWdwDiPjTElU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Utah Valley University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uvu.edu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Utah Valley University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://iam.atypon.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://iam.atypon.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-04-08T13:39:46Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Atypon SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.atypon.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://iam.atypon.com/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://iam.atypon.com/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://iam.atypon.com/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIJAO6CoIEi6CasMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\n\t\t\t\t\t\tBAMTDmlhbS5hdHlwb24uY29tMB4XDTE1MDMyMDE1NDE0OFoXDTE4MDMxOTE1NDE0\n\t\t\t\t\t\tOFowGTEXMBUGA1UEAxMOaWFtLmF0eXBvbi5jb20wggEiMA0GCSqGSIb3DQEBAQUA\n\t\t\t\t\t\tA4IBDwAwggEKAoIBAQC4u+54JO70zG5x0q61H8Mq3Pjf/gBEIrfs/E6+0QF27Qqc\n\t\t\t\t\t\tpxKly7r5OAnLJ+QOk3gAsK3LELmRRu6eBIE/wtKMpm9GfAtznr4Ts7eFUx6aBthc\n\t\t\t\t\t\tKUG2YWPOtbg3jFh92BHaB37GnVAoTSfT4nVuFSeWGgfoi6ny50IXpnhXFTvddNai\n\t\t\t\t\t\t0eNZEPgliIgZ8sVbssDGOzyJ4TLADFGd1XstW52zh17ceUn4DEOCpMc4yDtRZWTL\n\t\t\t\t\t\tjbfatEVvrKNbBhs1lvGa+UqLxD2Sb5PneRt7R/s4OICaM4D0y2S4y+5zkwLc65fO\n\t\t\t\t\t\t0m/FAnxPjBPXZFqoNX1FtGuMd7wbryYDlbFbah4FAgMBAAGjXzBdMDwGA1UdEQQ1\n\t\t\t\t\t\tMDOCDmlhbS5hdHlwb24uY29thiFodHRwczovL2lhbS5hdHlwb24uY29tL3NoaWJi\n\t\t\t\t\t\tb2xldGgwHQYDVR0OBBYEFOzD1qWEnKX/3+ulIieqI3ZSTumhMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQADIEJbWhPEFvYPsE63K3Y8pW7GYcxItU+0WJdNjoKixKfK2m7wuPjb\n\t\t\t\t\t\t9DT5JqOBqglFVygbKujATJKBmDM3AGaQSsv36V6rypd3vrzcxbCg1BuhvBsLnOt+\n\t\t\t\t\t\tmrnh/Qgnj/LHzxanzX2IMaM3zRTkDni2/nNlXY3YNlKfzV2pEOvIY13cautAzkbV\n\t\t\t\t\t\tRHyeLh1sv+GYbxEEpX61/0Wspsh98H01XqvziuqOs2ybCNRzYwqxgwb4K4Noi22U\n\t\t\t\t\t\tZFCNuvYP54V/cy2/QhB/1TvFTRqVlL0KzuoqChjuw3XJI+6PYfnjfMHkTKcnqQk+\n\t\t\t\t\t\tbqny/aV5srItkU3iMCsXEbaV5Rf0xBcr"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.atypon.com"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Atypon Service Provider"
                  }
                ],
                "logo": [
                  {
                    "text": "https://iam.atypon.com/sda/1004/atypon_logo.png",
                    "height": "75",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "241"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Atypon SP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://nd.onecampus.com",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cloud_ops_support@rsmart.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Cloud Ops Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://nd.onecampus.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RSmart"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rsmart.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RSmart"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://inside-qa.nd.edu/saml/SSO/alias/nd",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://inside-qa.nd.edu/saml/SSO/alias/nd",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://inside-qa.nd.edu/saml/SSO/alias/nd",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://inside-qa.nd.edu/saml/SSO/alias/nd",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF4jCCBMqgAwIBAgIIGDXYkef9MTEwDQYJKoZIhvcNAQELBQAwgbQxCzAJBgNV\nBAYTAlVTMRAwDgYDVQQIEwdBcml6b25hMRMwEQYDVQQHEwpTY290dHNkYWxlMRow\nGAYDVQQKExFHb0RhZGR5LmNvbSwgSW5jLjEtMCsGA1UECxMkaHR0cDovL2NlcnRz\nLmdvZGFkZHkuY29tL3JlcG9zaXRvcnkvMTMwMQYDVQQDEypHbyBEYWRkeSBTZWN1\ncmUgQ2VydGlmaWNhdGUgQXV0aG9yaXR5IC0gRzIwHhcNMTYwMjE3MjE1MjQwWhcN\nMTYwODA0MDIxMzM4WjBDMSEwHwYDVQQLExhEb21haW4gQ29udHJvbCBWYWxpZGF0\nZWQxHjAcBgNVBAMTFW9wZXJhdGlvbnMucnNtYXJ0LmNvbTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAMdKDT4kOWMti2IunhJLbHYbUqKMy2cPNnNl/8Ga\n4hmN60AL3khVxIum8KPFrWwcR/l7hka5zmQHJZgyPS7pmfl7u7UfzNJ1VVn5J0iI\nOZsv0g9XPGAHyoKIzwEMubzrO+nok8N2ZLJTmqYNfsKY9cj/db/ito5kw5GTEEIh\n5RO6NhcjrDUT8kiVqbusaJca/odwxZptzQk34XIa1jWp0N1A+XuhYRLHAQxpdMK3\nzTMvsagMHZYy+v4dOL9zAvfj8omjD/88/FUEhwxjR3mKPiuqu5zsGeh8Ackht36K\nutHbsUR0gABn4v0L02Ir7uBhUAPtvHK4sx3jJk/qbhC5cr8CAwEAAaOCAmYwggJi\nMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMA4G\nA1UdDwEB/wQEAwIFoDA3BgNVHR8EMDAuMCygKqAohiZodHRwOi8vY3JsLmdvZGFk\nZHkuY29tL2dkaWcyczEtMTk2LmNybDBTBgNVHSAETDBKMEgGC2CGSAGG/W0BBxcB\nMDkwNwYIKwYBBQUHAgEWK2h0dHA6Ly9jZXJ0aWZpY2F0ZXMuZ29kYWRkeS5jb20v\ncmVwb3NpdG9yeS8wdgYIKwYBBQUHAQEEajBoMCQGCCsGAQUFBzABhhhodHRwOi8v\nb2NzcC5nb2RhZGR5LmNvbS8wQAYIKwYBBQUHMAKGNGh0dHA6Ly9jZXJ0aWZpY2F0\nZXMuZ29kYWRkeS5jb20vcmVwb3NpdG9yeS9nZGlnMi5jcnQwHwYDVR0jBBgwFoAU\nQMK9J47MNIMwojPX+2yz8LQsgM4wgdwGA1UdEQSB1DCB0YIVb3BlcmF0aW9ucy5y\nc21hcnQuY29tghl3d3cub3BlcmF0aW9ucy5yc21hcnQuY29tghFvbmVjYW1wdXMu\nb3J1LmVkdYIRc2Fjc21hcnQuY3N1cy5lZHWCF3Rlc3QudWZpdC5vbmVjYW1wdXMu\nY29tghNkYXNoYm9hcmQud3Nlc3UubmV0ghRzZXJ2aWNlcy5vaXQucGR4LmVkdYIN\naW5zaWRlLm5kLmVkdYIQaW5zaWRlLXFhLm5kLmVkdYISaW5zaWRlLXRlc3QubmQu\nZWR1MB0GA1UdDgQWBBQPjZYdibOQi3hsFPA7MC9kSugpEjANBgkqhkiG9w0BAQsF\nAAOCAQEATaaZfrkcjzTHwhx/JxbHdQ25a4wyjCQNQvSsishfyIQ1BvXm5+LAPzOT\n7CHDZd7JJYvxMpK1fSfhyD9VkTr79Dml+Cc4hk+xNrFTyeRoU0PW3t6RophM8BO9\ntSivy7qLxDZyF4wCO3VKdhIK4nds+Ii0onX1yMnrq3O9rr0ucAgIRYPuEWs45++5\nD6poAwUTzyTxJWFhLRIRRMwriI7jJv397rRbQCxl48a57Fnby61sVH5HAu/fxQYP\nb9lqIDeybtp3R8/9ESFMjEKs+PRHXFWqWMyqeVF2i10omeJ1g/oBc9yQQBdwaMLg\nt+jAm0TyfZSJbeqoNJrVOYxd/djzcg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.rsmart.com/"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.rsmart.com/privacy-policy/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ND OneCampus"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://shibdev.ltscotland.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wilson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:graham.wilson@educationscotland.gov.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Graham"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wilson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:graham.wilson@educationscotland.gov.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Graham"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibdev.ltscotland.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2012-04-25T08:40:02Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Education Scotland: Development"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.educationscotland.gov.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Education Scotland"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibdev.educationscotland.gov.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibdev.educationscotland.gov.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibdev.educationscotland.gov.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibdev.educationscotland.gov.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibdev.educationscotland.gov.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibdev.educationscotland.gov.uk/Shibboleth.sso/WAYF/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibdev.educationscotland.gov.uk/Shibboleth.sso/Glow",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibdev.educationscotland.gov.uk/Shibboleth.sso/GlowApproval",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibdev.educationscotland.gov.uk/Shibboleth.sso/GlowDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEjCCAfqgAwIBAgIJALr0olzkd9TzMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\n\t\t\t\t\t\tBAMTGWx0c2UtZGV2MDEubHRzY290bGFuZC5jb20wHhcNMTAwMzAzMTIyMjEyWhcN\n\t\t\t\t\t\tMjAwMjI5MTIyMjEyWjAkMSIwIAYDVQQDExlsdHNlLWRldjAxLmx0c2NvdGxhbmQu\n\t\t\t\t\t\tY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA3MIiCvfKQ/w1RYJg\n\t\t\t\t\t\tbp1tfVWaaCH66IQO0yE2PG0Eotdg+GR/LVfQlY9QXJj7Kvj1UqsncmIia9hK9Td/\n\t\t\t\t\t\tonmydjcfxsheeLPDkS9H8EUTJSn1yNfq/4bMJ03Wn+/gT/UWVtyhRBvCMwA/gdUJ\n\t\t\t\t\t\tnyQTdKBOLOYCzSr1Q3X8NlBmezmsw1mAu1wa+nyWciUP4d7pH+5h4oHCXHzAyw2I\n\t\t\t\t\t\t5HHCTzN8bR2Q5y6W0yCXfcM/ChbO1ii3uHwnLruN1LKBqvmirLk7UlkCITpaYLmC\n\t\t\t\t\t\ta2eS2ZkA3bMEbixGL5osjpUah5GB9tB/IK5EKkXxSrlyE+TvBIoXx5HKWEyLb6PO\n\t\t\t\t\t\tHhY76wIDAQABo0cwRTAkBgNVHREEHTAbghlsdHNlLWRldjAxLmx0c2NvdGxhbmQu\n\t\t\t\t\t\tY29tMB0GA1UdDgQWBBQQVXRf9vWh6lfW092XrIDlT6WLejANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAyrRlJ79mn0tmcyiAX6HsYcnBvITOztgXcyHmnGMSAwqpWDidderSwgso\n\t\t\t\t\t\tP82PaffnZkYc62eOrMbDqOdPjhpUT7DepyRRjIxdmZq5DiC1u+XweoQhe0EO4qAG\n\t\t\t\t\t\txrp6528ksWgecUNgh28/Mw2MmsbVeuZY4hIUiTE+dUCaH+85e8i7MBnycNrJVDco\n\t\t\t\t\t\twRbczc6a1T+FCSy+cYF5TLdZXQneRVv9VxTmhgsXpES+gwKiFO2YrqySuVbE8P5A\n\t\t\t\t\t\tEWiBnZJb0MdjMCENixhuHes8WRqs5CZ3GRqswZ1WdQJI7YirJLzaSydiasXH/QqL\n\t\t\t\t\t\teoQwxslZb8rsMUyN8K/+4EGSsAa35g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibdev.educationscotland.gov.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibdev.educationscotland.gov.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibdev.educationscotland.gov.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibdev.educationscotland.gov.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibdev.educationscotland.gov.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibdev.educationscotland.gov.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibdev.educationscotland.gov.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibdev.educationscotland.gov.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibdev.educationscotland.gov.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibdev.educationscotland.gov.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.jisc.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Grigg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.grigg@jisc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Grigg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.grigg@jisc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.jisc.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-03-28T13:43:58Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLjCCAhYCCQCv1Jl+hrmSWjANBgkqhkiG9w0BAQUFADBZMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEQMA4GA1UECBMHQnJpc3RvbDEQMA4GA1UEBxMHQnJpc3RvbDENMAsGA1UEChME\n\t\t\t\t\t\tSklTQzEXMBUGA1UEAxMOaWRwLmppc2MuYWMudWswHhcNMTQwMzEzMTAzMzE0WhcN\n\t\t\t\t\t\tMzQwMzA4MTAzMzE0WjBZMQswCQYDVQQGEwJHQjEQMA4GA1UECBMHQnJpc3RvbDEQ\n\t\t\t\t\t\tMA4GA1UEBxMHQnJpc3RvbDENMAsGA1UEChMESklTQzEXMBUGA1UEAxMOaWRwLmpp\n\t\t\t\t\t\tc2MuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCds/3E0LCX\n\t\t\t\t\t\tCKEsKlPjxzFBrktliW7ldFZupqcIdVyXhPYP7u9dKcf5bU3h/1R2Q0AUP1EqCuX/\n\t\t\t\t\t\tPy8lpJKAO59+YQgM70FWUS0oVr9QxvJiSn5fmCa7vhAIDQtwMekl3523ByfRgynN\n\t\t\t\t\t\tQRS01OjHPE0oaJAb1dDgt1KK5WCHnW7udrWbdOyRWuvvgDgyqecK253BG8kungcz\n\t\t\t\t\t\tJvJ+zhI57sEM2+DTCuuzKgVnzqn7WvezswOmWAJvxGXW8iEkJYydrxItCF1aYrU2\n\t\t\t\t\t\tMgRQZHeyUogJaiLU7PZ0Rq9Pw1McPaZZ4qoo4j09w3AIu9+tUwdhpBmpE9PrVgwo\n\t\t\t\t\t\tUprGqV4ITCUtAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAA12gtk7woOH+ILs1Ynf\n\t\t\t\t\t\tL4BBT/skUhrKn8XHEynizu4qlcbHVIS5vH7zHp/Fmj2v9Yy9PKrynFCXQvVi0HsH\n\t\t\t\t\t\tySBQuNMT40gOFlkQp/CH1fiTZGykl3BsaQEsS5JLmIOfg/LO6rtnEqeHXtBOuDb+\n\t\t\t\t\t\taXdMpXwcO7nsHvTE1HWtrIxfBOKpKVa0O7A07iTs+OYaFBCxo3btFpZ/QoZgnyx3\n\t\t\t\t\t\tDuqj4fvKfPlVB+aysYQV9dQFwaOofRgxAtiivGncenCqmNaF44KacrINzfWY22om\n\t\t\t\t\t\t8H2um6dpNv1oaivSr1PS79zX6aO4G0jFH9MHotmgICOJx6V2ROMnu1ZdXx2yxRUP\n\t\t\t\t\t\tdnA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "jisc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "corp.jisc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.jisc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.jisc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.jisc.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.jisc.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.jisc.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.jisc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.jisc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.jisc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.jisc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.jisc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.jisc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "jisc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "corp.jisc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLjCCAhYCCQCv1Jl+hrmSWjANBgkqhkiG9w0BAQUFADBZMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEQMA4GA1UECBMHQnJpc3RvbDEQMA4GA1UEBxMHQnJpc3RvbDENMAsGA1UEChME\n\t\t\t\t\t\tSklTQzEXMBUGA1UEAxMOaWRwLmppc2MuYWMudWswHhcNMTQwMzEzMTAzMzE0WhcN\n\t\t\t\t\t\tMzQwMzA4MTAzMzE0WjBZMQswCQYDVQQGEwJHQjEQMA4GA1UECBMHQnJpc3RvbDEQ\n\t\t\t\t\t\tMA4GA1UEBxMHQnJpc3RvbDENMAsGA1UEChMESklTQzEXMBUGA1UEAxMOaWRwLmpp\n\t\t\t\t\t\tc2MuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCds/3E0LCX\n\t\t\t\t\t\tCKEsKlPjxzFBrktliW7ldFZupqcIdVyXhPYP7u9dKcf5bU3h/1R2Q0AUP1EqCuX/\n\t\t\t\t\t\tPy8lpJKAO59+YQgM70FWUS0oVr9QxvJiSn5fmCa7vhAIDQtwMekl3523ByfRgynN\n\t\t\t\t\t\tQRS01OjHPE0oaJAb1dDgt1KK5WCHnW7udrWbdOyRWuvvgDgyqecK253BG8kungcz\n\t\t\t\t\t\tJvJ+zhI57sEM2+DTCuuzKgVnzqn7WvezswOmWAJvxGXW8iEkJYydrxItCF1aYrU2\n\t\t\t\t\t\tMgRQZHeyUogJaiLU7PZ0Rq9Pw1McPaZZ4qoo4j09w3AIu9+tUwdhpBmpE9PrVgwo\n\t\t\t\t\t\tUprGqV4ITCUtAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAA12gtk7woOH+ILs1Ynf\n\t\t\t\t\t\tL4BBT/skUhrKn8XHEynizu4qlcbHVIS5vH7zHp/Fmj2v9Yy9PKrynFCXQvVi0HsH\n\t\t\t\t\t\tySBQuNMT40gOFlkQp/CH1fiTZGykl3BsaQEsS5JLmIOfg/LO6rtnEqeHXtBOuDb+\n\t\t\t\t\t\taXdMpXwcO7nsHvTE1HWtrIxfBOKpKVa0O7A07iTs+OYaFBCxo3btFpZ/QoZgnyx3\n\t\t\t\t\t\tDuqj4fvKfPlVB+aysYQV9dQFwaOofRgxAtiivGncenCqmNaF44KacrINzfWY22om\n\t\t\t\t\t\t8H2um6dpNv1oaivSr1PS79zX6aO4G0jFH9MHotmgICOJx6V2ROMnu1ZdXx2yxRUP\n\t\t\t\t\t\tdnA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Jisc"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jisc.ac.uk"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Jisc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.unioncloud.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@zendesk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Menon"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shoba.menon@arrkgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shoba"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kancherla"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sudheer.kancherla@arrkgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sudheer"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.unioncloud.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-07-05T13:45:10Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NUS Digital Unioncloud Service Provider"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unioncloud.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NUS Services Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.unioncloud.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.unioncloud.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.unioncloud.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.unioncloud.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.unioncloud.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.unioncloud.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVzCCAj+gAwIBAgIJANZRUr3l66IUMA0GCSqGSIb3DQEBBQUAMDsxOTA3BgNV\n\t\t\t\t\t\tBAMTMGVjMi00Ni0xMzctMy0xNjIuZXUtd2VzdC0xLmNvbXB1dGUuYW1hem9uYXdz\n\t\t\t\t\t\tLmNvbTAeFw0xMjA1MTQwOTExNThaFw0yMjA1MTIwOTExNThaMDsxOTA3BgNVBAMT\n\t\t\t\t\t\tMGVjMi00Ni0xMzctMy0xNjIuZXUtd2VzdC0xLmNvbXB1dGUuYW1hem9uYXdzLmNv\n\t\t\t\t\t\tbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMOKLRNP923gpEphaq9H\n\t\t\t\t\t\tlqaeg3wIr6k6CQEZTnVeXHaqBS1T/IeLChh0MGikmqzAGz4gL3Jp7xg+LjAb7fHW\n\t\t\t\t\t\ts84wG6ZkDFxy2plDsNoVPatzgKQYtiXsGqtlXdW8UzTpIpsvVAlJ+QGqhIibAZWK\n\t\t\t\t\t\taIsU6V38NGafvB4UWFlIpbECHgFz41x1cmK7gYFD7wzsA6hojAOWaY8UmQgW+nJn\n\t\t\t\t\t\t4WxKl+gDe8qUiwdMzrEUK1yOFjsDuqdHnejSrtyc8b7iccE7hzo1Y/kw40FVG7gW\n\t\t\t\t\t\toiKrzF49G14BiHwkt448mCiXGDMnFM0TYfs1nkS/FdTpyhHgICu1qHX8pqJnnNbn\n\t\t\t\t\t\tuNMCAwEAAaNeMFwwOwYDVR0RBDQwMoIwZWMyLTQ2LTEzNy0zLTE2Mi5ldS13ZXN0\n\t\t\t\t\t\tLTEuY29tcHV0ZS5hbWF6b25hd3MuY29tMB0GA1UdDgQWBBRAI6NKxAK3XKLGUqTb\n\t\t\t\t\t\tgJhCWI0FuzANBgkqhkiG9w0BAQUFAAOCAQEAf+1jf17uxp5uGeGJUFI/t2bhxnfD\n\t\t\t\t\t\tTbmnNBzQST5/+VK+qNAc6tCw+0gngBGREBkdVmcebIw8AmfhciDqe3xEl3Pp2oWT\n\t\t\t\t\t\tHSnbl7bZnoG90FlxEbHm8THMNFjTDTmrlX37ldH5mfiP0EOFpMaCmlkNr9D617tF\n\t\t\t\t\t\tgZ2xUEelwk+5dg5RpIHsgOnVr6zcUMdYHZPs64O/kySxnuN+PaOIOt9JERw1jHT6\n\t\t\t\t\t\tLbD66CIPaC/TtydoiCUfS7s9Hr3hSJUnJ0gi+fzXh/5/z/+NjMZXd4G4FPVMonXy\n\t\t\t\t\t\tXrRfr87YvwJm38sU/z+Gnka487212biN6XS36YGLSohRByTKTNZM+H1x8A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.unioncloud.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.unioncloud.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.unioncloud.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.unioncloud.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.unioncloud.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.unioncloud.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://manchesterstudentsunion.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://manchesterstudentsunion.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://manchesterstudentsunion.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://manchesterstudentsunion.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://manchesterstudentsunion.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://manchesterstudentsunion.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.kusu.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.kusu.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.kusu.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.kusu.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.kusu.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.kusu.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "18"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.sunderlandsu.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "19"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.sunderlandsu.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "20"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.sunderlandsu.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "21"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.sunderlandsu.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "22"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.sunderlandsu.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "23"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.sunderlandsu.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "24"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.trentstudents.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "31"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.trentstudents.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "32"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.trentstudents.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "33"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.trentstudents.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "34"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.trentstudents.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "35"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.trentstudents.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "36"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.suarts.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "37"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.suarts.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "38"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.suarts.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "39"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.suarts.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "40"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.suarts.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "41"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.suarts.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "42"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.subu.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "43"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.subu.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "44"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.subu.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "45"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.subu.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "46"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.subu.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "47"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.subu.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "48"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.edgehillsu.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "49"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.edgehillsu.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "50"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.edgehillsu.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "51"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.edgehillsu.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "52"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.edgehillsu.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "53"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.edgehillsu.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "54"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.uadsa.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "55"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.uadsa.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "56"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.uadsa.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "57"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.uadsa.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "58"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.uadsa.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "59"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.uadsa.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "60"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.liverpoolsu.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "67"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.liverpoolsu.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "68"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.liverpoolsu.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "69"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.liverpoolsu.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "70"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.liverpoolsu.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "71"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.liverpoolsu.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "72"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.bedssu.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "79"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.bedssu.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "80"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.bedssu.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "81"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.bedssu.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "82"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.bedssu.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "83"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.bedssu.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "84"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.durhamsu.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "85"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.durhamsu.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "86"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.durhamsu.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "87"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.durhamsu.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "88"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.durhamsu.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "89"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.durhamsu.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "90"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.mdxsu.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "91"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.mdxsu.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "92"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.mdxsu.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "93"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.mdxsu.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "94"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.mdxsu.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "95"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.mdxsu.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "96"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.uclansu.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "97"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.uclansu.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "98"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.uclansu.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "99"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.uclansu.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "100"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.uclansu.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "101"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.uclansu.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "102"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ucsu.me/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "103"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.ucsu.me/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "104"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ucsu.me/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "105"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.ucsu.me/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "106"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.ucsu.me/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "107"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.ucsu.me/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "108"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://su.sheffield.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "109"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://su.sheffield.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "110"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://su.sheffield.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "111"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://su.sheffield.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "112"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://su.sheffield.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "113"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://su.sheffield.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "114"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.lsu.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "115"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.lsu.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "116"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.lsu.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "117"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.lsu.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "118"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.lsu.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "119"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.lsu.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "120"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.liverpoolguild.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "121"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.liverpoolguild.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "122"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.liverpoolguild.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "123"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.liverpoolguild.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "124"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.liverpoolguild.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "125"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.liverpoolguild.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "126"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ueastudent.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "127"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.ueastudent.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "128"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ueastudent.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "129"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.ueastudent.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "130"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.ueastudent.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "131"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.ueastudent.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "132"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ssu.unioncloud.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "133"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ssu.unioncloud.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "134"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ssu.unioncloud.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "135"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ssu.unioncloud.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "136"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ssu.unioncloud.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "137"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ssu.unioncloud.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "138"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.uwlsu.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "139"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.uwlsu.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "140"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.uwlsu.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "141"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.uwlsu.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "142"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.uwlsu.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "143"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.uwlsu.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "144"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.gcustudents.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "145"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.gcustudents.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "146"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.gcustudents.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "147"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.gcustudents.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "148"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.gcustudents.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "149"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.gcustudents.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "150"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.mostactivestudents.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "151"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.mostactivestudents.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "152"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.mostactivestudents.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "153"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.mostactivestudents.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "154"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.mostactivestudents.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "156"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.mostactivestudents.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "157"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.salfordstudents.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "159"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.salfordstudents.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "160"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.salfordstudents.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "161"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.salfordstudents.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "162"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.salfordstudents.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "163"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.salfordstudents.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "164"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.uswsu.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "165"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.uswsu.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "166"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.uswsu.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "167"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.uswsu.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "168"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.uswsu.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "169"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.uswsu.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "170"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.abertaysa.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "171"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.abertaysa.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "172"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.abertaysa.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "173"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.abertaysa.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "174"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.abertaysa.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "175"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.abertaysa.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "176"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ucsunion.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "177"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.ucsunion.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "178"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ucsunion.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "179"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.ucsunion.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "180"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.ucsunion.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "181"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.ucsunion.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "182"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.stmaryssu.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "183"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.stmaryssu.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "184"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.stmaryssu.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "185"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.stmaryssu.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "186"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.stmaryssu.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "187"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.stmaryssu.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "188"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.leedsbeckettsu.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "189"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.leedsbeckettsu.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "190"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.leedsbeckettsu.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "191"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.leedsbeckettsu.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "192"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.leedsbeckettsu.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "193"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.leedsbeckettsu.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "194"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cds-dev-liam.ligo.org/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "warren.anderson@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Warren Anderson"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "michael.manske@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael Manske"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rt-auth@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LIGO Identity Management Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lsc-seccomm@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LIGO Security Committee"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://cds-dev-liam.ligo.org/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "LIGO Scientific Collaboration"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ligo.caltech.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LIGO Scientific Collaboration"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://cds-dev-liam.ligo.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://cds-dev-liam.ligo.org/SpInfo"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "A place to develop essential discovery service solution for LIGO."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://cds-dev-liam.ligo.org/SpPrivacy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "LIGO CDS Development Machine"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID3zCCAsegAwIBAgIJAIVoW4Nz7yHpMA0GCSqGSIb3DQEBBQUAMIGFMQswCQYD\nVQQGEwJVUzELMAkGA1UECAwCQ0ExITAfBgNVBAoMGEludGVybmV0IFdpZGdpdHMg\nUHR5IEx0ZDEeMBwGA1UEAwwVY2RzLWRldi1saWFtLmxpZ28ub3JnMSYwJAYJKoZI\nhvcNAQkBFhdtaWNoYWVsLm1hbnNrZUBsaWdvLm9yZzAeFw0xNjAzMDQyMjMzMTJa\nFw0yNTEyMDIyMjMzMTJaMIGFMQswCQYDVQQGEwJVUzELMAkGA1UECAwCQ0ExITAf\nBgNVBAoMGEludGVybmV0IFdpZGdpdHMgUHR5IEx0ZDEeMBwGA1UEAwwVY2RzLWRl\ndi1saWFtLmxpZ28ub3JnMSYwJAYJKoZIhvcNAQkBFhdtaWNoYWVsLm1hbnNrZUBs\naWdvLm9yZzCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALNFPHIX+Xu9\n6xh6gs5063wtR6AVz+aamF7wAP+I9XR5bZqlV5HccbKKJlLI7a80BVjA2na6bHLY\ngfZoPPkdhJ9NbAUCYjZoxvSjo26RAAiGNBKBGqtHuzLiERU+O8k4sk93GovwqljG\nVngGnXO/iSz5KJ3SnGJvDqOyt+z9k6WAVCCytKIsf2MI2XACq5cTJM3sIqqUs4mh\nLyC1qg1ZJW57iud5DTr5OKM+Upk6HmETE2sRlS4i7ih9fLctuwfHTjvayG9hm6o0\nG/TtwVoJBIvwAUh/VWn3oYmVZC8jRGCPYjJJJOvMbmcdhriWFOVwVqNf2piK2z/F\nf4L/c7pYkAUCAwEAAaNQME4wHQYDVR0OBBYEFKfKfAE9V3ljRMvacGOvHMPz9bns\nMB8GA1UdIwQYMBaAFKfKfAE9V3ljRMvacGOvHMPz9bnsMAwGA1UdEwQFMAMBAf8w\nDQYJKoZIhvcNAQEFBQADggEBADYX7VtD3pf0NBVbrpI8hKUTkxYV7Bsx6I+HzkbP\nRuYWcUd5kMHWZTz4TEkoLPoBWL7DrLbmoV9pTK1PA4aqsEqOVGF6ANyu3THPca66\nD7aGFdaIDyvkL5NXgJtCDgMLPZ/aHjwDT2DAjYO1HxCwEmKbZ+2v6j2Ap/vdOzHO\nwvxKIBiaXhHvIXf4UV2UipagNum/PwuwkvrEJY0uEKzM9HJJ83zcjBIuk4TX9FQm\n6qe0YlQMqogioTm+XVxEfPyUSkBHHqH2jbw1fJZOgWu/h686ShzXg8GnfdR1/Yx2\nLksBNoL+uUBAvqYXb1XjbYCK/UPvQgK37ZGY0GRXougte8Y="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cds-dev-liam.ligo.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cds-dev-liam.ligo.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cds-dev-liam.ligo.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://cds-dev-liam.ligo.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "LIGO CDS Development Machine"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "A place to develop essential discovery service solution for LIGO."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.hackney.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.hackney.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/hackney.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/hackney.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hackney.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hackney Community College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hackney.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.etrs.terre.defense.gouv.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fabrice Pollet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "fabrice.pollet@etrs.terre.defense.gouv.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.etrs.terre.defense.gouv.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-06-16T13:41:03Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.etrs.terre.defense.gouv.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.etrs.terre.defense.gouv.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.etrs.terre.defense.gouv.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "etrs.terre.defense.gouv.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.etrs.terre.defense.gouv.fr/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Staff and students of Ecole des Transmissions"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnels et stagiaires de l'Ecole des Transmissions"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/vnd.microsoft.icon;base64,AAABAAEAEBACAAEAAQCwAAAAFgAAACgAAAAQAAAAIAAAAAEAAQAAAAAAAAgAAAAAAAAAAAAAAgAAAAAAAACEIxoAfuP8APAPAAD4HwAA+B8AAPw/AAD8PwAA/D8AAPw/AAD8PwAA/D8AAPw/AAB8PgAAHDgAAAAAAAAAAAAAAAAAAH/+AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ETRS - Ecole des Transmissions"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ETRS - Ecole des Transmissions"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZTCCAk2gAwIBAgIUJ8+wj9VvvaWkYWc7Lv9ZrozEz5wwDQYJKoZIhvcNAQEF\nBQAwKTEnMCUGA1UEAwweaWRwLmV0cnMudGVycmUuZGVmZW5zZS5nb3V2LmZyMB4X\nDTE1MDYwNDEyNDMzM1oXDTM1MDYwNDEyNDMzM1owKTEnMCUGA1UEAwweaWRwLmV0\ncnMudGVycmUuZGVmZW5zZS5nb3V2LmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEAncSOI7ZLCUW1YAQxsXx9sGUhIETkAQD0rW31036RsUcxJKHvSfvH\nLz9t95F0OmCw4K+gVFFobxoOzwWrfNkQKNLmWJjfqVWe7euL5S6a5CLdzvosDCIa\nP63/9JAlAlAPvVQ3JYH08FcLQL2zcbxshZJBvsAQrSOOnkytXndkmpjlvPZNn3Hb\nofiSA2CDDfNjIgFq1AS0nGJyuHSDD+Foi2TsU8ejirYVZPxn8wacxpt9GtIuY/tl\neYTjdH41kskaXqRGoN0X7aC2Xea357hf950lEbacTOxztYITIJFZVkQjjea+YdGU\n9fsjrAkxuAyXX5yHD9SU8t9Px1Y/jwVWxwIDAQABo4GEMIGBMB0GA1UdDgQWBBRV\n5pi3YXYkaI4CLWcEtD2SiRteWTBgBgNVHREEWTBXgh5pZHAuZXRycy50ZXJyZS5k\nZWZlbnNlLmdvdXYuZnKGNWh0dHBzOi8vaWRwLmV0cnMudGVycmUuZGVmZW5zZS5n\nb3V2LmZyL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBBQUAA4IBAQB7c5PZS50w\nlcNUHGNv0QbHmFIEl2qSVW5p+y4lZX3QBEy+dyKw9qaTFGDD+qLfa9QKo6s31uLo\ncW7aGmG2ok6U0XjT7fCKIR8YljugdZfetCw5BiHRIaDzVhj8ozZPmb0OxlTecpJ/\ngQ3wik7Qo9ZPU/wLObyVcxGBeIiQxXhCTu0Gqvl2UUV1Jwo4OEt5Vb6oBjN7HMDj\nCSaG+Q/uQK0g4lfhJr2ZvpDrAy+f5ZJcccgz4uPJk0hqdydB6gHGIbSYVt1X89vW\nWYYigdavCrEx/mzNsCIdNuvFCFWQxDTr62aRd9Ib9VdrTc4GL7w+Gi7Ne++PRgzX\nlaUPwIb+uQ6Z"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ETRS - Ecole des Transmissions"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.etrs.terre.defense.gouv.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ETRS - Ecole des Transmissions"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.vsb.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Orkac"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "radomir.orkac@vsb.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Radomir"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lason"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "martin.lason@vsb.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.vsb.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2010-09-22T11:42:11Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/university"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.vsb.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.vsb.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.vsb.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.vsb.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.vsb.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.vsb.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vsb.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.vsb.cz/en/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.vsb.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for employees and students of the V\u0160B-Technical University of Ostrava"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance a studenty V\u0160B-TUO"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www2.eduid.cz/idp-loga/vsb.jpeg",
                    "height": "244",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "207"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "V\u0160B-Technical University of Ostrava"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Vysok\u00e1 \u0161kola b\u00e1\u0148sk\u00e1 - Technick\u00e1 univerzita Ostrava"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAKuWvd4iPNRnRXukyKOp+sqpReNLMA0GCSqGSIb3DQEB\nCwUAMBUxEzARBgNVBAMMCmlkcC52c2IuY3owHhcNMTYwMjEyMTAxOTE5WhcNMzYw\nMjEyMTAxOTE5WjAVMRMwEQYDVQQDDAppZHAudnNiLmN6MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAyJIW3WNHkYH7Hi6y/oSjjsyTFSMoMwGeQfpAjhp1\n+iXSTxI/X+Se3zqgQn5EJ2SeqZKxlsmx+qbl1Wf+0SSeLQ6JrxDMC4HQQ0mDor5x\nUrqerSHEcXyvoh2Sspzd/ZMaN7VCRv/Ax6uPVv16WeML/I2euB3IboPZo6FndVT+\nLEukL8U+2g0CXp3wuJW+ORv6HwaeJSgN9JgLagr69FJ2NY+Yw8GwmeHEeq/m9jww\nDcmSwzdibOVnsqXMZOXQ/X5WDNVe78b9OsC/5m0MtJSdnkX2FgKS5M3QXtMSpXLP\n9lHoBkYmAFb3p1EnRXEafhwsZrk4Z6vvHvQaLvKsCvlNGQIDAQABo1swWTAdBgNV\nHQ4EFgQUhDzLExAhPepv1Symwbvj3E2q65QwOAYDVR0RBDEwL4IKaWRwLnZzYi5j\neoYhaHR0cHM6Ly9pZHAudnNiLmN6L2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\nCwUAA4IBAQAeAvQXibD29dK99tJj0QtYMOcNyih7Ru/LXl+XkbXhCs0HuP2qhDMk\nTXGOpukRw5xi1VqznvnIFOusnwKU5gG/7DSsE/hU/KBWhVfb3uQrjX6jMUwP9/Is\nvsJAm9UDf0/iyGA2pjGOpWlYB5N1dJau6iAMjDP5xaBtnwbPZCQJl6q0vI1jroPs\nqENqBYkiuUrkE2sQtYTbqvJi/0aSjgQwD6qVZtRNalavRIInGqPOpG3663t9vSCK\nZY58F6tPf6hRCqY0YM246W9jj6IZ0QH/gDbMDQxQYiuLhQ03uDHlTwB32/G27Tkb\nCSX2Yqgu+nMLaqtZ5IZORr9jyxd0h0hM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAMu0ePB4xgh9EIK+qEugr/6czSz9MA0GCSqGSIb3DQEB\nCwUAMBUxEzARBgNVBAMMCmlkcC52c2IuY3owHhcNMTYwMjEyMTAxOTE5WhcNMzYw\nMjEyMTAxOTE5WjAVMRMwEQYDVQQDDAppZHAudnNiLmN6MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAp9ddBjiE6E+aXfEUOc6oKurTK1dsoqZ+ACLUQgVF\noGaBc3yToQMgnD6tQ4xGS4zgUPn02fe/0hh9Tz2hD+aNHvf7j24I1RUYBd5p/geG\nwMvReGp9H5lDmSrABic6kLB121GoMMIBqZO+2VadiSIMziItI2V6KuGs90t/UDOO\nncnjjPmzpJIdACk1JOWDGZtE4AIQhz9q5tAiev6ETJG77WAwLbH1eAv2DsYCSVdk\n1NXbgaMV0SNBhgD9oqga1SQNyK+R/Q2boc22pXQMdbdgB95zrMGoFuSBK/yMXIGH\nfNLYRWemKT8N6fF+y6X3glL5VHwe9e4vxdUOeprUurqn3QIDAQABo1swWTAdBgNV\nHQ4EFgQUrx36LTaKgVLjioqCfZdQOA5wLL4wOAYDVR0RBDEwL4IKaWRwLnZzYi5j\neoYhaHR0cHM6Ly9pZHAudnNiLmN6L2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\nCwUAA4IBAQA7OHbMVdAJTFfeM2yUXG5Sb6LMrZzMBgJvE2kM6X2+ONggB8c5relu\nTD6+BoA4q/ZiTYabXZUVtglz/ksMWPwFcW+EdZnLQeCAS9DSJRjR1/ZOFU73awfE\nUbDUopTknDLZ06+LW045Qgg7Q7LNqVs5SUDYy/EAmEYNgHJVL4T6Lrk/f2ToLpXb\ne+84As5I60v+3ywJlBKOZsjZ17Nw+y6fcbpeEIuWXd/YvuyT/qN6fzNqLkjU+F1I\nwBFnh3xvCTPaFTFgT++wDCqDvtq9GMD1w6SEiZiq7xSh1SVoJYxIu6Zq5C3YyOVS\n8aQKeBPJ3f6ZH0CSSD1nGI+/joVQegLg"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAMmUzXW7GcBvS+GdXawthrAEM9CfMA0GCSqGSIb3DQEB\nCwUAMBUxEzARBgNVBAMMCmlkcC52c2IuY3owHhcNMTYwMjEyMTAxOTE5WhcNMzYw\nMjEyMTAxOTE5WjAVMRMwEQYDVQQDDAppZHAudnNiLmN6MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEApzklpC0+jz80eDzf+wfHgDYTS5xTFLCzoXVfZt5m\nl2T9de/TQW2eVYyJ0vqvkhL+dfSkzH2GCdb+f0F5GxFfhT4rR4AAk4kXw7hJEh/L\n6CrNy/JaOYNe1TilEDJAliHsoZf57JlAoIx7jyKCq5+sOFxvnQuh72Kt19GDTD3w\nN/o314GrDweeQOvRu4e8mpuLYDLuG98DqzmnTvb7xc1aDRtk5ofYUA9A2+EKYyyo\n/1BhgTO/jajWVuM65sVDa9Rl84ilmUbLMOVKUlwoT4gwQG/8owgNXu895AkALAm0\nExeCPEjg67cCktIWXlp4p1wH0zfbEYE9VIiM4lcgcD6OGwIDAQABo1swWTAdBgNV\nHQ4EFgQUs/PYqEYGUoKa+2UEe9GoUXKmw6swOAYDVR0RBDEwL4IKaWRwLnZzYi5j\neoYhaHR0cHM6Ly9pZHAudnNiLmN6L2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\nCwUAA4IBAQCTjBqHy13Fd9m9yMBkh0ATYWdFUwjtm9O+QnLFBM00Gwm8evy14ytv\nAIVK+ljiLdEiFrtF7Szx17An2wFHC/7fZZ/lGfy3d+qwKUF8P/AY6zL8zZfwYpJr\nOQy/9x15/f50pyF7eDEm3XRuwUV+HQLqqZz4NUtJI88A7/wy60bhNxGFYzxLO5dJ\nfc8cOb2/uYOBc2W08BOf2Q6nBywhojlq1TBVigHFb5jdakQ6JJ1WbaKBtMbsXzGW\n7d23IK/AF0SEWknFsrqnhapeDFc2Jh7XZkz8Zf0LMg3d/fCQtTVdi6iS4u1pfzRv\nJYH5NKeeBBdGOunN7KfPzfd86tveJ6kn"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEhDCCA2ygAwIBAgIQMsrmzp+34gaErwPAEEHDaTANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDEwNzAwMDAwMFoXDTE2MDEwNzIzNTk1OVowZTELMAkGA1UE\nBhMCQ1oxQTA/BgNVBAoMOFZ5c29rw6EgxaFrb2xhIGLDocWIc2vDoSAtIFRlY2hu\naWNrw6EgdW5pdmVyeml0YSBPc3RyYXZhMRMwEQYDVQQDEwppZHAudnNiLmN6MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAyn69Pwg4S/psf0nUhaz0lst9\nXC677alnuLNJBXFn/nNb+zZK/EVQBA4S6puSWBA9VVKrXmDWiUVuqAizzWNgaEKq\n/ssklSA5/gAsxULsvO3MB6lCBU9fpT9mVnJe7NZ6NOd9H4F+ImIGB/jQrqzeI5HZ\n39ceuuSx/rSkknu31BiE1fsHswtFqjUDa70IGHrvY+5LT0X0Q6CyOnO5VEZm3YWQ\nbYifE0xk0ntJAwyDVAV9bVPQxtisai/uvhNmMTsiDCnjK1PIM5nFnLpGEZij8iBJ\nQU5QFStykiFV/58M0xsprC/J23TOodP8mv7D4EYlTCfJ4EQ5uXwl3d1ATA0hBwID\nAQABo4IBXTCCAVkwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH6pDjue0wHQYD\nVR0OBBYEFD8TNImBkVfIIWRwMN6X08cgCD+SMA4GA1UdDwEB/wQEAwIFoDAMBgNV\nHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAYBgNVHSAE\nETAPMA0GCysGAQQBsjEBAgIdMDoGA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwu\ndGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1\nBggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xD\nQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9vY3NwLnRjcy50ZXJlbmEub3JnMBUG\nA1UdEQQOMAyCCmlkcC52c2IuY3owDQYJKoZIhvcNAQEFBQADggEBAHSOi94CDBd4\nKEw9Xv/DYSTNLin25EBU3BB752KG+JWBkeSSK+4/BaxaUFG44zUqcRheebYkovVE\nopyKs7cTdEC6E+/1R6PSlKmkMTRqAllVUxnnXOa1k84jaG3bPWPjYWWIk9iRX0sG\nnFXjhATWbi7bRx15x36jP2vR/yxigWhN73cxZNhhAC76zcH/Fj8/qUhTITiV5hyq\n8ARxGHOMVSrlwkwBECg71sdijCPAg76WjNrTuFN6c3L2NQcLYszy4N/MFBpEl0ws\nuGEHDQJdr6KAGF8iO78FoR66sQNIvHTSpJCUyS5tRkHn59BfUlapw4Y6eQ6bxJDN\nh15jC+yc8m8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "VSB - Technical University of Ostrava"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "V\u0160B - Technick\u00e1 univerzita Ostrava"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vsb.cz/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://en.vsb.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "VSB - Technical University of Ostrava"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Vysok\u00e1 \u0161kola b\u00e1\u0148sk\u00e1 - Technick\u00e1 univerzita Ostrava"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.u-bordeaux.fr/idp_ubx/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@univ-bordeaux.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.u-bordeaux.fr/idp_ubx/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-12-10T11:43:22Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.u-bordeaux.fr/idp_ubx/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.u-bordeaux.fr/idp_ubx/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.u-bordeaux.fr/idp_ubx/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "u-bordeaux.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.u-bordeaux.fr/"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Bordeaux"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Bordeaux"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIJAPEVvQl9sqJ0MA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\nBAMTGXYtaWRwMDEuc3J2LnUtYm9yZGVhdXguZnIwHhcNMTQwNDE0MDc1NjE5WhcN\nMjQwNDExMDc1NjE5WjAkMSIwIAYDVQQDExl2LWlkcDAxLnNydi51LWJvcmRlYXV4\nLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1AStm5TtjTJEnbVB\nKxe+Qjkh9z7V1Td2uUiWbswYVIfFlw2mDhj9Gq3clTRiyPhebB4qTeRzJKNnxVBw\nlzk+JmRnJd+JPwIyX3ctN+XZRaeFjbspP1Xl9sjsa5LBFVZ43LrXPlQH2o8Z3jZJ\ng9WaTj++SbUa4xKnqJ6bJm4voykhCG4cAyQ9jpV3Qivofwa9VHC5KauXR9JeHMr4\ngjOZBxfh8e9iTRSt1fUHDrHpgx00zvVIXBi5d9DRENPjyCNzSHR/32UUxnJOomEY\neyf1Ux8yr3xiucqY8ht90n/LtvxBGl33uGZZPu2oBuJGj8F48VqJwKyKdZi72Lqo\nsauYUQIDAQABo30wezBaBgNVHREEUzBRghl2LWlkcDAxLnNydi51LWJvcmRlYXV4\nLmZyhjRodHRwczovL3YtaWRwMDEuc3J2LnUtYm9yZGVhdXguZnIvaWRwX3VieC9z\naGliYm9sZXRoMB0GA1UdDgQWBBS2KmA2aaKd0lRemau76adcI936lzANBgkqhkiG\n9w0BAQUFAAOCAQEAXoRdSclj17K5pHqZC+MYjFQgRpZ9Gq7Sdk/kEXyH10SJuc5r\neApBAWYFIJvWAXKBhtvPxnkgoDkQ84Rrho/jR4RzkqCEEiUHjLzObVuHtcHE1dAV\nX5iaAObzXlNr5aDAPPPjaZXQpZOvNDwrhVQrZWoeupQogoP1VYEJtCag2tgLD7ZW\nwuQY8NfjOSmMrG1NsCIia2C4gWqEqKwFwuknaueT95GubIrz4ayqz5WYEe2KTNSy\n1KI84uKzIgymoedQ2eibLzfcTg3aEs24aWfjpKhLYERBgUGeoymuqTT2WPnH21IT\nRl74R0YddDzKj3NOCjggOxW2tAPCCd5pPprTRQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTzCCAjegAwIBAgIUE1/WgEZpWyPYXsF/fURZlGXutGUwDQYJKoZIhvcNAQEF\nBQAwJDEiMCAGA1UEAxMZdi1pZHAwMS5zcnYudS1ib3JkZWF1eC5mcjAeFw0xMzEy\nMTAwODA5NDFaFw0xNjEyMTAwODA5NDFaMCQxIjAgBgNVBAMTGXYtaWRwMDEuc3J2\nLnUtYm9yZGVhdXguZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCd\nWezh53yFD4rbJyj74HT7VOJpNorPhQGoqEAMZOQWuT182+2XRq373xcOZ6suy0NS\nYbOoxKdFQn+o/bIQwpvnN708YVU7rcVUcxzpYwyPdIwMgm9xqC5hBE902mErUHNP\nVOqkgmnIf5YDm92fSzIEoE/klpQwCSsG88qlfTxwmB+sWh/2UcG8RZXyjowP4zHh\nhjhC3weBXQltSktL92Xg92F3nnBiTY6YKZ+8UQx34WGzTC+DjAXbE7d84LTufMkA\npckM01O9LY3S6QHxsZ8AdZmWIe8/yxF7mDTstEZR44IXCAff3p4r7BeI8t6G5pDj\n8TxLlKEdRzF8jtPJ1rm5AgMBAAGjeTB3MFYGA1UdEQRPME2CGXYtaWRwMDEuc3J2\nLnUtYm9yZGVhdXguZnKGMGh0dHBzOi8vdi1pZHAwMS5zcnYudS1ib3JkZWF1eC5m\nci9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUKnhNaI/fipTjD6bWLF0lcbs6rMsw\nDQYJKoZIhvcNAQEFBQADggEBAF0Dd1Fvi1mSzozQ1zF+ynVD+Vno7QyhIIQG+yKe\n0W5/ZLrF8ddiAvHku+lXJakRi+7zI45+O85YN1ZmrL8LHtkmoz39YSGBXtQL92PR\n6jLOaQ4AAXG/Co3ONAmT7Qtr8wUBdCdLI1PiHKUoWg5U6CFTROE/1x5TwoALbO1H\ne3NB3eRNWIn9CMUNYgz3BEHSM36bb+I4pZ3iG2yLIFZ9FpnAHbuBkbE2hdPgppYw\nxq57ToMq1Btju+x6evFlV0uqCSszQMxTU/Tleid5iZfL4ae9IgM6xqEvYZ4xr6fr\nVkBzyAKX8s3JZo9lM7GdA2PXiIodtHSyeNvrRmVpGN63REs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Bordeaux"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.u-bordeaux.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Bordeaux"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp2-1.slu.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 90 786 81 22"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bengt Norman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "saml-admins@slu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Swedish University of Agricultural Science"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 70 2413737"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ivan Clegg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "saml-admins@slu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Swedish University of Agricultural Science"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 18 67 66 00"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT-st\u00f6d"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:IT-stod@slu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Swedish University of Agricultural Science"
          }
        }
      ],
      "entity_id": "https://idp2-1.slu.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oasis:names:tc:SAML:attribute:assurance-certification",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIUIDSi2H8dePffTFkVUjtBaLv6ctUwDQYJKoZIhvcNAQEF\nBQAwETEPMA0GA1UEAxMGaWRwMi0xMB4XDTEzMDMxNDA3NTU0OVoXDTMzMDMxNDA3\nNTU0OVowETEPMA0GA1UEAxMGaWRwMi0xMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEA1L9PRiIOUnTbMQoU0LwTtlSeQLwvXbu87PfFMTTpQgdUBrMCPDWL\nmrT6Wko9WmGoAGkYft7bMjFDEkA03Cj5qTbFtemN6Jp/ZqieDnh09wxBdfzOAkSv\njSdHQK08ITpH91PYtubd9Id6sEI5M6oZ2gSqim/BitjEOh2X1pd5wlLRCtX+YKPE\nUhOdHOuxFfiZALpWoQDWSID0g+yOc9qPj9BvO4gE+YsHbVw+T4f+7IdMEQj+WX1e\nx6EDWSJ8yjRc8RyCXw3AtGWEaCU6NkL5ksTV7DfkozWDjfF6srFck6ksDKN+EEZ4\nwBC+ZCRevaqO/BRfQmsn3JxWRUU9ddTP8QIDAQABo1MwUTAwBgNVHREEKTAnggZp\nZHAyLTGGHWh0dHBzOi8vaWRwMi0xL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTs\nFaVVn2xyoTYbOGdkDDdtFV8ErzANBgkqhkiG9w0BAQUFAAOCAQEAVETKawYhusol\nwIP2n2bnvKoTD8wJPZNUpxvxBeY72Ux9tzILAdnaDY3lPAwaslqGN7Q3MEVIPbA7\nebTyR6KPprv3/ijN78HA2FpuIumCiMwgcKTntA1ti8TkCknc/p25yuSJm8kk1YYT\nEI/cBEjV7AeP1NQXVkxyj9zwY0dYzax/h6Wg+t7qvs8ORxOJdEhr1zdsxY1f+7Aa\nGH/yHRavwkRh3ICgDSty9dO7c8k5MXjnX/W+zZR1/IngJMmUKZXIoLmqwdaHPb+S\nlb1DOdXnNxi+WNQXbBjzonEZa0hFPT/ml32QpjCzh11edlGltCnQVzyLJGw/W5KT\no04ltBnMhQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "slu.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2-1.slu.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2-1.slu.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp2-1.slu.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2-1.slu.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp2-1.slu.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2-1.slu.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2-1.slu.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2-1.slu.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "slu.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.slu.se/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.slu.se/en/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r Sveriges Lantbruksuniversitet."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Swedish University of Agricultural Science"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp2-1.slu.se/info/images/slu_logotyp_web_100.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  },
                  {
                    "text": "https://idp2-1.slu.se/info/images/slu_logotyp_web_16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sveriges Lantbruksuniversitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Swedish University of Agricultural Science"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "slu.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIUIDSi2H8dePffTFkVUjtBaLv6ctUwDQYJKoZIhvcNAQEF\nBQAwETEPMA0GA1UEAxMGaWRwMi0xMB4XDTEzMDMxNDA3NTU0OVoXDTMzMDMxNDA3\nNTU0OVowETEPMA0GA1UEAxMGaWRwMi0xMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEA1L9PRiIOUnTbMQoU0LwTtlSeQLwvXbu87PfFMTTpQgdUBrMCPDWL\nmrT6Wko9WmGoAGkYft7bMjFDEkA03Cj5qTbFtemN6Jp/ZqieDnh09wxBdfzOAkSv\njSdHQK08ITpH91PYtubd9Id6sEI5M6oZ2gSqim/BitjEOh2X1pd5wlLRCtX+YKPE\nUhOdHOuxFfiZALpWoQDWSID0g+yOc9qPj9BvO4gE+YsHbVw+T4f+7IdMEQj+WX1e\nx6EDWSJ8yjRc8RyCXw3AtGWEaCU6NkL5ksTV7DfkozWDjfF6srFck6ksDKN+EEZ4\nwBC+ZCRevaqO/BRfQmsn3JxWRUU9ddTP8QIDAQABo1MwUTAwBgNVHREEKTAnggZp\nZHAyLTGGHWh0dHBzOi8vaWRwMi0xL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTs\nFaVVn2xyoTYbOGdkDDdtFV8ErzANBgkqhkiG9w0BAQUFAAOCAQEAVETKawYhusol\nwIP2n2bnvKoTD8wJPZNUpxvxBeY72Ux9tzILAdnaDY3lPAwaslqGN7Q3MEVIPbA7\nebTyR6KPprv3/ijN78HA2FpuIumCiMwgcKTntA1ti8TkCknc/p25yuSJm8kk1YYT\nEI/cBEjV7AeP1NQXVkxyj9zwY0dYzax/h6Wg+t7qvs8ORxOJdEhr1zdsxY1f+7Aa\nGH/yHRavwkRh3ICgDSty9dO7c8k5MXjnX/W+zZR1/IngJMmUKZXIoLmqwdaHPb+S\nlb1DOdXnNxi+WNQXbBjzonEZa0hFPT/ml32QpjCzh11edlGltCnQVzyLJGw/W5KT\no04ltBnMhQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Sveriges Lantbruksuniversitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish University of Agricultural Science"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.slu.se/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Swedish University of Agricultural Science"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://beta.lawtel.com/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bukka"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:prashanthi.bukka@thomsonreuters.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Prashanthi"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Patara"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jagvir.patara@thomsonreuters.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jag"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bukka"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:prashanthi.bukka@thomsonreuters.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Prashanthi"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Patara"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jagvir.patara@thomsonreuters.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jag"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://beta.lawtel.com/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-03-13T15:40:44Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lawtel"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lawtel.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Thomson Reuters (Professional) UK Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZzCCAk+gAwIBAgIJAI1Uwq7I6bpMMA0GCSqGSIb3DQEBBQUAMCsxDzANBgNV\n\t\t\t\t\t\tBAoTBkxhd3RlbDEYMBYGA1UEAxMPYmV0YS5sYXd0ZWwuY29tMB4XDTEyMDMwMjA4\n\t\t\t\t\t\tNTEzOVoXDTIyMDIyODA4NTEzOVowKzEPMA0GA1UEChMGTGF3dGVsMRgwFgYDVQQD\n\t\t\t\t\t\tEw9iZXRhLmxhd3RlbC5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCxEgaufApwXsEAPskvBtI41FSV/q4gDprwIlB6BZYABV2ZSVa3slVq0x/kvnH7\n\t\t\t\t\t\tWkV8rgpkSMVW6cDUQruNRvI0aoMl+1UaIrVEEN+CIxdWvnPlCiOrzapwGJ52cKMe\n\t\t\t\t\t\t0xcUVnZiPaBoaR+JQO9M07Q7decSF910M4w0AaWaj/ELyU5qIPjdRJIpMlpG0DVq\n\t\t\t\t\t\tjKljU+mfaxyZ9DG3r5nk8G8ajaFhg4pQAJMp/pis7s2CreP1T4+dxIpOVpjysCmL\n\t\t\t\t\t\tglb3WYt0tsslJkVya3q2SMR1qi8F2RtKu973mgS+EEXF5afl5xA4SW6N8u2/EnQT\n\t\t\t\t\t\tr8U/r5QaJDVixBYSMFWrnWB1AgMBAAGjgY0wgYowHQYDVR0OBBYEFLsFufpV+fZJ\n\t\t\t\t\t\tk/h+DX4S+LxiDHCkMFsGA1UdIwRUMFKAFLsFufpV+fZJk/h+DX4S+LxiDHCkoS+k\n\t\t\t\t\t\tLTArMQ8wDQYDVQQKEwZMYXd0ZWwxGDAWBgNVBAMTD2JldGEubGF3dGVsLmNvbYIJ\n\t\t\t\t\t\tAI1Uwq7I6bpMMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAGXQukuo\n\t\t\t\t\t\td33p2sDND2tkiWr4un7NXMe6oB5vS3AQEKvc6TEq5qRheZfpKzjbshcRqCDy1lHh\n\t\t\t\t\t\tAKz779DDPPmh/0nhQMdi1NvbIGYshKgeus7JskhIZWLhuohKncsmuOq77Ojb4/T6\n\t\t\t\t\t\tJqOWqSOzKdhguviaJiibb6GgBmTBLH5AHpbD5GEtyFdaH42HCK5DM3x1H15JM+5M\n\t\t\t\t\t\tGPzgwXMbtYQ8AFsxGZvbVfK/YwHx36Z3Tn/cPZM93U2bQY/mjiAjhgoqiuyJJ1bB\n\t\t\t\t\t\twJZC0VQskEP1pPdAWJpI4EbOwUxSEHENXdKb1dXvMcYY+dK1O9vHLfXJXkbBGE2E\n\t\t\t\t\t\tl2hv92HcUJJF5Ug="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZzCCAk+gAwIBAgIJAI1Uwq7I6bpMMA0GCSqGSIb3DQEBBQUAMCsxDzANBgNV\n\t\t\t\t\t\tBAoTBkxhd3RlbDEYMBYGA1UEAxMPYmV0YS5sYXd0ZWwuY29tMB4XDTEyMDMwMjA4\n\t\t\t\t\t\tNTEzOVoXDTIyMDIyODA4NTEzOVowKzEPMA0GA1UEChMGTGF3dGVsMRgwFgYDVQQD\n\t\t\t\t\t\tEw9iZXRhLmxhd3RlbC5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCxEgaufApwXsEAPskvBtI41FSV/q4gDprwIlB6BZYABV2ZSVa3slVq0x/kvnH7\n\t\t\t\t\t\tWkV8rgpkSMVW6cDUQruNRvI0aoMl+1UaIrVEEN+CIxdWvnPlCiOrzapwGJ52cKMe\n\t\t\t\t\t\t0xcUVnZiPaBoaR+JQO9M07Q7decSF910M4w0AaWaj/ELyU5qIPjdRJIpMlpG0DVq\n\t\t\t\t\t\tjKljU+mfaxyZ9DG3r5nk8G8ajaFhg4pQAJMp/pis7s2CreP1T4+dxIpOVpjysCmL\n\t\t\t\t\t\tglb3WYt0tsslJkVya3q2SMR1qi8F2RtKu973mgS+EEXF5afl5xA4SW6N8u2/EnQT\n\t\t\t\t\t\tr8U/r5QaJDVixBYSMFWrnWB1AgMBAAGjgY0wgYowHQYDVR0OBBYEFLsFufpV+fZJ\n\t\t\t\t\t\tk/h+DX4S+LxiDHCkMFsGA1UdIwRUMFKAFLsFufpV+fZJk/h+DX4S+LxiDHCkoS+k\n\t\t\t\t\t\tLTArMQ8wDQYDVQQKEwZMYXd0ZWwxGDAWBgNVBAMTD2JldGEubGF3dGVsLmNvbYIJ\n\t\t\t\t\t\tAI1Uwq7I6bpMMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAGXQukuo\n\t\t\t\t\t\td33p2sDND2tkiWr4un7NXMe6oB5vS3AQEKvc6TEq5qRheZfpKzjbshcRqCDy1lHh\n\t\t\t\t\t\tAKz779DDPPmh/0nhQMdi1NvbIGYshKgeus7JskhIZWLhuohKncsmuOq77Ojb4/T6\n\t\t\t\t\t\tJqOWqSOzKdhguviaJiibb6GgBmTBLH5AHpbD5GEtyFdaH42HCK5DM3x1H15JM+5M\n\t\t\t\t\t\tGPzgwXMbtYQ8AFsxGZvbVfK/YwHx36Z3Tn/cPZM93U2bQY/mjiAjhgoqiuyJJ1bB\n\t\t\t\t\t\twJZC0VQskEP1pPdAWJpI4EbOwUxSEHENXdKb1dXvMcYY+dK1O9vHLfXJXkbBGE2E\n\t\t\t\t\t\tl2hv92HcUJJF5Ug="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "want_assertions_signed": "false",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://www.beta.lawtel.com/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.beta.lawtel.com/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.beta.lawtel.com/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.beta.lawtel.com/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://idp-cafe.ifrr.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Francisco Cavalcante Filho"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "francisco.filho@ifrr.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-cafe.ifrr.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC0DCCAbgCAQAwDQYJKoZIhvcNAQEFBQAwLjEMMAoGA1UECxMDRFRJMQswCQYD\nVQQGEwJCUjERMA8GA1UEAxMIaWRwLWNhZmUwHhcNMTQwNDA5MTYyNzU1WhcNMTkw\nNDA4MTYyNzU1WjAuMQwwCgYDVQQLEwNEVEkxCzAJBgNVBAYTAkJSMREwDwYDVQQD\nEwhpZHAtY2FmZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM2QLiQp\nv/NepaRdzlGTeoyC//4t4vPsByuVLTF9BJ9zXfpgb70bFt5Ka4FXaYEafGC76n8H\nuCzk/nWrzEKuNMZMPgQbteCpvhrGm8RziPF7zelZl2Q4FDAORAOQwfw/GIyadsmY\n38BYCGQmuppiCAL5SUvGBHvEPyGwJnLBqnE/f1e66ZXfLvniYqRjKvU1VSsUUF5Y\nBrVE/LqUB6OA7uJEKTtp6uCx8XNUNYGML6hHR9joDZrQuK4wYOocjdWuWn0/1/uw\nhvb8sOYiTgAPap4UtTxTqVZ6XBRWmWVP9fTEjpSNEgeaWBvNpmJx+Ci9Hi5+F0zq\nGZMyVBZZAXsBBj0CAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAl6toGY7toL1HPVtj\npjGi7ed76phnITf4cHJi6Ny99tsCK29pdkWKGQ4p1F8usGy8QoWCBBLTAo/LhZye\n/AzLnW+zUV9qioGw+guncG8/GCg8SM2FR2nwUt2BXsXUodHg2kl8S8I7NbXcw9p1\noI8OT1fkM3RcJ5F4XBErp9PI9KK5zaLGYjDgCOm4m09GmIuPbzlIBlx77B8+WZXA\nCX6Zy+sNmrpOzcg/UDotLp5yCOWlJQkcNH4U4gqCMiwbpys3zMLPjKcH+N2th9MB\nDqEeFHCPJJZZTT+MFcUMt4fMrYZ2EKfNZnLbO0cvTEmLXDTxEVU/m9n41DGtxSF0\nNMSiiw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-cafe.ifrr.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-cafe.ifrr.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-cafe.ifrr.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-cafe.ifrr.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-cafe.ifrr.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-cafe.ifrr.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-cafe.ifrr.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-cafe.ifrr.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifrr.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifrr.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFRR - Instituto Federal de Roraima"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFRR - Instituto Federal de Roraima"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFRR - Instituto Federal de Roraima"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFRR - Instituto Federal de Roraima"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC0DCCAbgCAQAwDQYJKoZIhvcNAQEFBQAwLjEMMAoGA1UECxMDRFRJMQswCQYD\nVQQGEwJCUjERMA8GA1UEAxMIaWRwLWNhZmUwHhcNMTQwNDA5MTYyNzU1WhcNMTkw\nNDA4MTYyNzU1WjAuMQwwCgYDVQQLEwNEVEkxCzAJBgNVBAYTAkJSMREwDwYDVQQD\nEwhpZHAtY2FmZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM2QLiQp\nv/NepaRdzlGTeoyC//4t4vPsByuVLTF9BJ9zXfpgb70bFt5Ka4FXaYEafGC76n8H\nuCzk/nWrzEKuNMZMPgQbteCpvhrGm8RziPF7zelZl2Q4FDAORAOQwfw/GIyadsmY\n38BYCGQmuppiCAL5SUvGBHvEPyGwJnLBqnE/f1e66ZXfLvniYqRjKvU1VSsUUF5Y\nBrVE/LqUB6OA7uJEKTtp6uCx8XNUNYGML6hHR9joDZrQuK4wYOocjdWuWn0/1/uw\nhvb8sOYiTgAPap4UtTxTqVZ6XBRWmWVP9fTEjpSNEgeaWBvNpmJx+Ci9Hi5+F0zq\nGZMyVBZZAXsBBj0CAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAl6toGY7toL1HPVtj\npjGi7ed76phnITf4cHJi6Ny99tsCK29pdkWKGQ4p1F8usGy8QoWCBBLTAo/LhZye\n/AzLnW+zUV9qioGw+guncG8/GCg8SM2FR2nwUt2BXsXUodHg2kl8S8I7NbXcw9p1\noI8OT1fkM3RcJ5F4XBErp9PI9KK5zaLGYjDgCOm4m09GmIuPbzlIBlx77B8+WZXA\nCX6Zy+sNmrpOzcg/UDotLp5yCOWlJQkcNH4U4gqCMiwbpys3zMLPjKcH+N2th9MB\nDqEeFHCPJJZZTT+MFcUMt4fMrYZ2EKfNZnLbO0cvTEmLXDTxEVU/m9n41DGtxSF0\nNMSiiw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFRR - Instituto Federal de Roraima"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFRR - Instituto Federal de Roraima"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifrr.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifrr.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFRR - Instituto Federal de Roraima"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFRR - Instituto Federal de Roraima"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://training.nicurriculum.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Doran"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sdoran@ccea.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stephanie"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McAfee"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:amcafee@ccea.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Doran"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sdoran@ccea.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stephanie"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McAfee"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:amcafee@ccea.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://training.nicurriculum.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-07-16T15:33:11Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Northern Ireland Council for the Curriculum Examinations and Assessment: CCEA VLE"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rewardinglearning.org.uk/about/index.asp"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Northern Ireland Council for the Curriculum Examinations and Assessment"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://training.ccea.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://training.ccea.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://training.ccea.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://training.ccea.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://training.ccea.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://training.ccea.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://training.ccea.org.uk/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://training.ccea.org.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://training.ccea.org.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://training.ccea.org.uk/Shibboleth.sso/Login1",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAM1uIbHlDY9TMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\n\t\t\t\t\t\tBAMTFHRyYWluaW5nLmNjZWEub3JnLnVrMB4XDTEyMTEwNzExMTgxM1oXDTIyMTEw\n\t\t\t\t\t\tNTExMTgxM1owHzEdMBsGA1UEAxMUdHJhaW5pbmcuY2NlYS5vcmcudWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDlpY86D7QHaObXoklR20+kjJzdQYfi\n\t\t\t\t\t\t94QcGWeku6T24AvaJ33sHEilrvnRDfgm4aJpMaA5XxSyOzsWTRCu18T/jiBKFYvh\n\t\t\t\t\t\tTQVYp8hdAog9GMjICrXqPARXwJQBOkQSJwQxozIxgABLzuxZetvv/Bhdbq0rbpk7\n\t\t\t\t\t\t1Bgcx7iX1FYj/eOzYLpx+l9cpSJqtb3vveDQLMGESE0epefMdDhCf5oPJCkntr4A\n\t\t\t\t\t\t5+pvyZyqgCCpJGxmFXil1zfpO2Hz3R9GSvkgwMX3ZxHI/9Zui7vF1bSLNTt50TKB\n\t\t\t\t\t\tTfGsbVyWz06y/Y0e17HEP7J9AxNfO/8vowDUv0QLyaAFHnEkcYMGiIS9AgMBAAGj\n\t\t\t\t\t\tQjBAMB8GA1UdEQQYMBaCFHRyYWluaW5nLmNjZWEub3JnLnVrMB0GA1UdDgQWBBTy\n\t\t\t\t\t\tKmW+2gMYROrJikMsR2nPRYvbtjANBgkqhkiG9w0BAQUFAAOCAQEARKJcpoJ/AZbu\n\t\t\t\t\t\tPAhqAR7v25TlONn/XQj5c6lES7TI1qPpCQ/5VsraIwKJDkbLO6Zv4DS0nVkepvaM\n\t\t\t\t\t\tfAK6gPv9p5zT0VDJZQCFgB3CYxRMxlnrD885lMdETSPyiZnoyWjjBTB22fFJDeFy\n\t\t\t\t\t\t1928iTJpB3Svjx81XAhbf71yAfcuTweb07W8cPgML47+4/NyaDdvWqClT8tebq/W\n\t\t\t\t\t\t3ifzVDlGcQqf9eN6FyLVYWaj6Md/kiF0lae0FjLYgqYX0OD65HDgcWNGVEgHD/3y\n\t\t\t\t\t\tJHaQ6tFjNL4fGdsNXQftF1JkcqTLZts4USDG8yFKxyN2VODC1DcjSAbm33sJpo9J\n\t\t\t\t\t\tceK3gd6V5Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://training.ccea.org.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://training.ccea.org.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://training.ccea.org.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://training.ccea.org.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://training.ccea.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://training.ccea.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://training.ccea.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://training.ccea.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://training.ccea.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://training.ccea.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-21.ladok.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-21.ladok.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;21"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;21"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-21.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-21.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAJSSrVoFJ4N4MA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0yMS5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTQ0NDA3WhcNMjQx\nMDA0MTQ0NDA3WjAhMR8wHQYDVQQDExZsYWRvazMtMjEubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApgkSEfWPTzFHUHpcyu8r26CG\n8BU6OCy+8PRhWZJ/xXnuljWLa0VvWdkjMItHDR9VCjtLIK5t5oGbTiqPEsb93anr\nVqcgIPz6AYeo0SXJcpBdFuF3zGyW3yfUfoi6t3g4ikyAsQFKbX7wDg7vyUTKo15S\nVBbREkdmrYFb3JEByjQZjKbZUjsU9U78HjrzE7WCvDK4DDnzgWQg+aN6LHKHvn2H\njZlerYpF30aZKAXGvQh+HHNwBvfd0wE8DgixeMdRpId4/b+BMs2A4Q5dcn1fGcb7\n+JzTXxhHqtL/hiH055IYT3HHo/mTseJqoE3R1uT0FASsl21MYcOpqpnBNAKUZwID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMjEubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0yMS5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUea/KnYVe/DceUeFfUCEnrpCOoukwDQYJKoZIhvcNAQEFBQADggEB\nAJPsk6/BRaaiREtL6YzWQxkC7I8h1yhZpGSFZ2FPemesuLOFREva62qBYTP0IbZV\ntHvM/R/IsLo1yw8C5Mk+GTo3XPzgeTgNvNNUiK8KsKc+nVP0D5HUzodFxuRnu/HU\nFOGMknPKeZHfHe3UZJaXDbTogIp+KUWt4W7xJyVnuLMywXTSy2h52s5H6iFJQBaf\ney5yjTkPrBrnTI/Z7hx9fsYDR8oZb+U5cwz+l8s9bkaPXX9043nzgpgm9A/lma7j\nLSXPvEPTHzAkNoiAXAn5jW9xE3fsWdJs40SdhR1tcZ4LaaaGRvFCk6j+QIXLdjuE\n4KRUNahlmikpWye1rQPSZuo="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-21.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://napier-shib.hosted.exlibrisgroup.com/shib",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://napier-shib.hosted.exlibrisgroup.com/shib",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-06-25T10:14:28Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Edinburgh Napier University - Primo"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://exlibrisgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ex Libris (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://napier-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://napier-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://napier-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://napier-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://napier-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://napier-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is an Ex Libris Primo Hosted SP on behalf of the Edinburgh Napier University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Edinburgh Napier University - Primo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJALjiKNTZ3VmHMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB2FpbzAwMDIwHhcNMTQwNjI0MTcxNjM0WhcNMjQwNjIxMTcxNjM0WjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdhaW8wMDAyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\t0NHNpqzxRZEUmqRAPecaMNEk3LHrAoN6YR/8d+4JrHvkwY3PQYhFZUHjqcP02fwy\n\t\t\t\t\t\t9UEoelEWltX0QAnLlKFu2uiHVcm+5lhJ4vZqUmoYhtuqfaYcCmYi59ejY72uUP9c\n\t\t\t\t\t\taqd8duyC5kh8vKio4zHfuGPtlvc/Uoyw8tcBoDq/u+3NBCrSjZKh8+nW7HWhdJ2l\n\t\t\t\t\t\tg59HWZwLUo2iZUqicyQo57Ahut6YYl8guO3EBLg7pwtq/hdHydq5QGaAd0tbOOYt\n\t\t\t\t\t\tV4Y32/BLWUuChN4n/BDLCEYaeJUQ1dyKuMu4uOKJtQ2C3cWgDBk6sA316QvHhfTY\n\t\t\t\t\t\tvCrmCekrNXTVoRGy09icywIDAQABozUwMzASBgNVHREECzAJggdhaW8wMDAyMB0G\n\t\t\t\t\t\tA1UdDgQWBBRzYEI+CDBGccK525266LYvcGwuljANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\ta/j2gPQbZ7lzb8OthFIBt4ktulrb1rwBHpvv4BvtJ6VtM1uJMwGilVVba6mczihR\n\t\t\t\t\t\tk3sLeicALw06cqkgzGjSv8gLHBD1c06sRiTPh4YHdJKGpKRrS4quCnv7/9Eu7Use\n\t\t\t\t\t\tDT5R2cNjNfBIavipSX0HeP6I8ZUDvfZc2IeC1r/J6I29YD23siyMXkCE+cahWaj8\n\t\t\t\t\t\tdhTPVvq/avtplWKyECD0Mnf3r/NmLbjyc1e3nXCsYE+kMCWWe4Q+g4yWxXmrOS3Q\n\t\t\t\t\t\trPegVeBmWMHONjT6JVorvLFa37FCt7QvpZFLX5D2uv46b118DT1WCVayN1MBBqb2\n\t\t\t\t\t\tcIIz4hKEyHd/FjV5wSc0dw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://napier-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://napier-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://napier-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://napier-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://napier-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://napier-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://adfs.hvhl.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs.hvhl.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2016-01-15T12:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/1a3b0a58200dbe2973bb21eaa1adf33e",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hogeschool Van Hall Larenstein"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Van Hall Larenstein, University of Applied Sciences"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/media/idp/hogeschoolvhl.png",
                    "height": "232",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "500"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hogeschool Van Hall Larenstein"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Van Hall Larenstein, University of Applied Sciences"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hogeschool Van Hall Larenstein"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Van Hall Larenstein, University of Applied Sciences"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vhl.nl/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vhl.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hogeschool Van Hall Larenstein"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Van Hall Larenstein, University of Applied Sciences"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://appraisal.qmul.ac.uk",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Latham"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:adrian.latham@simitive.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adrian"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Latham"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:adrian.latham@simitive.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adrian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://appraisal.qmul.ac.uk",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-08-18T14:36:12Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "QMUL Appraisal Simitive"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.simitive.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Simitive Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://appraisal.qmul.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://appraisal.qmul.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://appraisal.qmul.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://appraisal.qmul.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://appraisal.qmul.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "authn_requests_signed": "1",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://appraisal.qmul.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://appraisal.qmul.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTjCCAjagAwIBAgIJALX9bGZHGFQXMA0GCSqGSIb3DQEBBQUAMC4xLDAqBgNV\n\t\t\t\t\t\tBAMTI2hvc3QtOTUtMTU0LTI1NC0xMjcucnNjbGllbnRkbnMuY29tMB4XDTE0MDcz\n\t\t\t\t\t\tMTA5NDIzNVoXDTI0MDcyODA5NDIzNVowLjEsMCoGA1UEAxMjaG9zdC05NS0xNTQt\n\t\t\t\t\t\tMjU0LTEyNy5yc2NsaWVudGRucy5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQCt/HdEunDhkbUtvNlMhBKoLN3JTSfu7CsglaNYyTM05F9kRUsq/LOf\n\t\t\t\t\t\tE4Hh1JRx9bb7TLazS6YvD8ZU+sc2WF3xCVPYDp4oY8ANDJYfB53dhtT4lLpqFB/0\n\t\t\t\t\t\taTjMj1PNvGqYJOElZhkp0m4nrHjNATuA7eQB3iff6v/0xdJ7AcTSfmTQTOXYyma+\n\t\t\t\t\t\tvQadTmxs9990Xml3HosGy1IXCbbO2ht4sg7/MxmbJblrha31wGURTWkE+WmVRwV6\n\t\t\t\t\t\tnMaituJhyk2d1UYEAjzpiAgwlOBVdUVNrdhTiTW5rWKNnPsIaam/XOhAeQeRj2IF\n\t\t\t\t\t\t9I10RB3OSTshOZuDEw4zseUrBcEtWejpAgMBAAGjbzBtMEwGA1UdEQRFMEOCI2hv\n\t\t\t\t\t\tc3QtOTUtMTU0LTI1NC0xMjcucnNjbGllbnRkbnMuY29thhxodHRwczovL2FwcHJh\n\t\t\t\t\t\taXNhbC5xbXVsLmFjLnVrMB0GA1UdDgQWBBTH7kFVLALHzYDH4QoBrsLhOiiDGjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAnkihlzTiIbxprbKw818zRBsRexB9pqUFYuRBSmAB\n\t\t\t\t\t\tjTRFLn+VouYicmETvhyVI4BU69mFz3nLsHG5HtmCeDS45ZoZhY/hBY3HqXJ/jOGB\n\t\t\t\t\t\tRsYQQdkC5vHCrRJrimsZMKOUY7HR8OZWsDbcmAXXoYSk3yMaBHI4BcZAXZa4KRX7\n\t\t\t\t\t\t69wlCV41DWzh3yKaHEQ0+eLnbVj2/ECVHaz1JzA0l/eRtH4vlSJpQQy/PymODDCc\n\t\t\t\t\t\tlrIU37xyczOKjgW1LpMwbl2aSND2BxalCKHxXiOIeLudwu9VPws/eN3UxeD1Nc2q\n\t\t\t\t\t\td4bJN7QJIBsfqLD3Dr3yXiTkMO9vJbZvRHKJRmR8eaYZCQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://appraisal.qmul.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://appraisal.qmul.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://appraisal.qmul.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://appraisal.qmul.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://appraisal.qmul.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://appraisal.qmul.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol"
        }
      ]
    }
  ],
  [
    "https://bibliometri.swepub.kb.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://bibliometri.swepub.kb.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bibliometri.swepub.kb.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://bibliometri.swepub.kb.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bibliometri.swepub.kb.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bibliometri.swepub.kb.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bibliometri.swepub.kb.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.kb.se/libris/swepub"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.example.se/info/about.html"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SwePub f\u00f6r analys och bibliometri samlar vetenskapliga publikationer fr\u00e5n svenska l\u00e4ros\u00e4ten och myndigheter."
                  }
                ],
                "logo": [
                  {
                    "text": "https://bibliometri.swepub.kb.se/2.0/vendor/kungbib-styles/dist/assets/kb_logo_white.svg",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SwePub"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SwePub"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://bibliometri.swepub.kb.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://bibliometri.swepub.kb.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "bibliometri.swepub.kb.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKTCCAhGgAwIBAgIJALSn+ImlArPBMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\nBAMTGGJpYmxpb21ldHJpLnN3ZXB1Yi5rYi5zZTAeFw0xNjAyMTYwOTIwMzdaFw0x\nOTAyMTUwOTIwMzdaMCMxITAfBgNVBAMTGGJpYmxpb21ldHJpLnN3ZXB1Yi5rYi5z\nZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM/BQW766TQFw738AlFw\n8gED1ZJfnS+uygE8NzK/S/1FH3FBKfU8anbZlVqXfNwf1HaS5r86ZIi1OP4BbDAv\nc9FZLpsnupc3QYhgyVZGi+jYWEJc3kPlajEj5hhdOtez/8/ZlJr+MIYcEm4vM3Y9\nwgvE6JOkSSXemAp/XotvXAMcz/BMcYfn9/Jr8nkZZCGWL145K73B2P/6VkeS1xrG\n5tKskeXBvsxw4pSTkzvLYc3iHFm8r2YBLc6h6ZllCxgzAUQCk+Lyu1Wu9ImPdhN/\nMINWAPYS0t5U/IUtfOW2n7eEd8gaoyuRdlY3im60buNKy6miKCDYtOCt4OAmerbP\nYLECAwEAAaNgMF4wPQYDVR0RBDYwNIIYYmlibGlvbWV0cmkuc3dlcHViLmtiLnNl\nhhhiaWJsaW9tZXRyaS5zd2VwdWIua2Iuc2UwHQYDVR0OBBYEFJagivm6oxVmwHg6\nrvhpLgSG1XX1MA0GCSqGSIb3DQEBBQUAA4IBAQAJcReLbtoOglBXv1t612ed6o3V\nYKoPLWijdlewJp0rzVJL021RZmeefar7z2pm0YKfGNdjE14Cax/p846+bZTw/k49\nVrrbTseCOOUA/fXQcnN7TRlo/N3YoMzCYckm3V0T53ff47R9KbOs0tTMvCx7SrEh\nOD+ICf8YLTkPnEr8mj/sbEyyQ+i1ZLFtMqt+V779BE0oaskv+R8tIQnKuj1XPE9d\nV+TucAkeuALHBUaMIVOg81ybHdDJTGmN5uLrmppQGSltVywFpznyyHfVMo8cBs4F\nhAZa0sY7HtDFgG7fhRkJjpHcIIidqb10OwtQqerkUmXDOXjzv6oOPV968L6N"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=bibliometri.swepub.kb.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bibliometri.swepub.kb.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://bibliometri.swepub.kb.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bibliometri.swepub.kb.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bibliometri.swepub.kb.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bibliometri.swepub.kb.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bibliometri.swepub.kb.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://bibliometri.swepub.kb.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://bibliometri.swepub.kb.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://bibliometri.swepub.kb.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:ibistic:prod:services.ibistic.net",
    {
      "entity_id": "urn:ibistic:prod:services.ibistic.net",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://services.ibistic.net/redirector/saml/post/ac",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Ibistic Services"
                },
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Ibistic Services"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "to handle and approve supplier invoices in a web-based solution"
                },
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "at h\u00e5ndtere og godkende leverand\u00f8rfakturarer i en webbaseret l\u00f8sning"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.cat-portal.epigenesys.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@epigenesys.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "epiGenesys Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gregory"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.gregory@epigenesys.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.cat-portal.epigenesys.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-07-15T11:40:14Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Clinical Academic Training Portal"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.epigenesys.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Epi Genesys Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://leeds.cat-portal.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://leeds.cat-portal.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://leeds.cat-portal.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://leeds.cat-portal.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://leeds-cat-portal.qa2.epigenesys.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://leeds-cat-portal.qa2.epigenesys.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://leeds-cat-portal.qa2.epigenesys.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://leeds-cat-portal.qa2.epigenesys.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://leeds.cat-portal.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://leeds-cat-portal.qa2.epigenesys.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://leeds-cat-portal.qa2.epigenesys.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Clinical Academic Training Portal provides management and monitoring of the training undertaken by postgraduate medical professionals."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Clinical Academic Training Portal"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIJALwqYDQ+/VO6MA0GCSqGSIb3DQEBBQUAMCoxKDAmBgNV\n\t\t\t\t\t\tBAMMH3NwLmNhdC1wb3J0YWwuZXBpZ2VuZXN5cy5vcmcudWswHhcNMTUwNzE1MDkz\n\t\t\t\t\t\tMjQ1WhcNMjUwNzEyMDkzMjQ1WjAqMSgwJgYDVQQDDB9zcC5jYXQtcG9ydGFsLmVw\n\t\t\t\t\t\taWdlbmVzeXMub3JnLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\to1494sYXTSFT31LkzQREFZjq6HNTZJznd0Q73T1SPZqt8G2e3UjoAA7cIq9qPpoi\n\t\t\t\t\t\tJCiXj1gtc+gqyJz++lz0xi2xj7TBYfeqRsicX6Xu2uVNJUWDBL3v2qs3Cavzk7ZM\n\t\t\t\t\t\tamnNg7fntbuq8ienG20rbPPFbD3yHbwIWb5e5UjMv2fXg+Bn5ky0Cr4c+aXw+8ci\n\t\t\t\t\t\tJCK6kA2ygZbrnoui59rTJcE6Luc8T8hYLaeMT5WuE2btaPC1MlXaUNigFnau7L/4\n\t\t\t\t\t\tlUQxsX3horXsslNAzq0J3gRp8I3yxLUv0z0eCZ2/Yi3GZX20a8MNuRNKXMjf4HC+\n\t\t\t\t\t\t80sdZtwGy2VlmFlgebgv6QIDAQABo1AwTjAdBgNVHQ4EFgQU93bNqheTncDjUW8+\n\t\t\t\t\t\taCAhUmvKpnswHwYDVR0jBBgwFoAU93bNqheTncDjUW8+aCAhUmvKpnswDAYDVR0T\n\t\t\t\t\t\tBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAGi43Omihdohtgy/LSXkgVf7+YW1i\n\t\t\t\t\t\tjx/c8OtBqvAxnzTOowlZQtG52VDSke91MABEPIEMqfrqXgFPcknWKxJGUXpMDr+F\n\t\t\t\t\t\tiXeMakpSMJ2eu7g6vcUriSx5g2CnjfMTUXNBHm3SjwsTjxoQtM0IyS0kSw+VWxYf\n\t\t\t\t\t\tTTCVYM4UikSGW/6DR/BXOFIa2BiQhkT+nvGaOBjiK0072RnxGJM205NzpGcxbUlC\n\t\t\t\t\t\toQVG2tSDNdiE6UN+D3jXlgmZSYSs80SvPVo3WFGdmj3y0lC89i7+dsRAaJNeakZH\n\t\t\t\t\t\tbuM7D9A982RDuZMPE7hmviLtmENGtpw8zJBjOxkKTxmMPxNTXMotCBLdzA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://leeds.cat-portal.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://leeds.cat-portal.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://leeds.cat-portal.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://leeds.cat-portal.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://leeds.cat-portal.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://leeds.cat-portal.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://leeds-cat-portal.qa2.epigenesys.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://leeds-cat-portal.qa2.epigenesys.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://leeds-cat-portal.qa2.epigenesys.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://leeds-cat-portal.qa2.epigenesys.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://leeds-cat-portal.qa2.epigenesys.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://leeds-cat-portal.qa2.epigenesys.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://journals.rcni.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso-support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "sso-support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso-tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "sso-tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://journals.rcni.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-03-06T13:47:37Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Royal College of Nursing Publishing"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://journals.rcni.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://journals.rcni.com/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://journals.rcni.com/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://journals.rcni.com/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIJAMqMZUiIsl4nMA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\n\t\t\t\t\t\tBAMTEXJjbnB1Ymxpc2hpbmcuY29tMB4XDTEzMTAwMzIxMzU1OFoXDTIzMTAwMTIx\n\t\t\t\t\t\tMzU1OFowHDEaMBgGA1UEAxMRcmNucHVibGlzaGluZy5jb20wggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDBlUJDDRaIIieWxx02H8sbXKNbUE6X+ZQbDeEk\n\t\t\t\t\t\tifb/0TqrolBjWGbwIB55jf4qL5aHy1Xb9lWiuItveLETbDsb6LGVRXjoBLMD/hq/\n\t\t\t\t\t\tINQNKlId7sUyaDD1dKdWo8vZAORnLLJfiNfJBFSfwt8dnnQihsv8ip1sQonfdjWF\n\t\t\t\t\t\t2JaPRwKHX864wn6x8CvqOgRNheowlhj6Hq69zX9mL9bKww6MC9c++11rwOYHVdGZ\n\t\t\t\t\t\tvZqhU0CxzNTDJWDRYwu5//PpMDLMJGTpbuRnN0SRR0uOJ6H9hACTO4MLGzO/WF4X\n\t\t\t\t\t\tcU1+I48q2gCdsZ2LaHWmNJqIy5IU24r2gu75uYAdUfE/n6UxAgMBAAGjZTBjMEIG\n\t\t\t\t\t\tA1UdEQQ7MDmCEXJjbnB1Ymxpc2hpbmcuY29thiRodHRwczovL3JjbnB1Ymxpc2hp\n\t\t\t\t\t\tbmcuY29tL3NoaWJib2xldGgwHQYDVR0OBBYEFBME3+HToUv+o1RLhxpnUhzXeecR\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQAiMV6SbpPn4cSK/tteSnvlGDu0kx0WrKHcq70j\n\t\t\t\t\t\t/TQyKZYc/roD1Xsbusj6kNhtbyg2UDKZMtUDJUX49Gy6od4hMft/LaO0d+S0fBA5\n\t\t\t\t\t\tpMGEl3rQpubIUem/SBAfN+Au+7j6yqi0vukGCqSWNAaQXt/XqkKys69b/CIbqkrm\n\t\t\t\t\t\tggWl3cXSrJx7GPKL1S9O5Oxd/cJO+g32L9qMH7LuKHLlnkEH8O5ZKjZjn+F6rBy7\n\t\t\t\t\t\tBBfwdYT/FpEL/nu+CPZwOcochpjY1HNtmq8tYGHv85r3mZkaLLnd+t0HGTw8X/Rs\n\t\t\t\t\t\tUlakv64cRCvOJRV/8DpP8bRsMrlqMkCQ2N3nu3eWKuQsgp67"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://journals.rcni.com/page/about-us"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "RCNi is the premier provider of innovative and creative information solutions \n\t\t\t\t\tfor the whole nursing team and allied health professionals."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RCNi"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://www.communistpartyarchive.org.uk/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sarsfield"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dsarsfield@microform.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gill"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:martin@serversure.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.communistpartyarchive.org.uk/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-09-05T13:54:55Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Communist Party of Great Britain archive"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.microform.co.uk/archival-publishing.php"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Microform Imaging Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDzTCCArWgAwIBAgIJANL2QbULh4NnMA0GCSqGSIb3DQEBBQUAME0xIDAeBgNV\n\t\t\t\t\t\tBAoTF0NvbW11bmlzdCBQYXJ0eSBBcmNoaXZlMSkwJwYDVQQDEyB3d3cuY29tbXVu\n\t\t\t\t\t\taXN0cGFydHlhcmNoaXZlLm9yZy51azAeFw0xMjA4MDcwOTU2MzFaFw0yMjA4MDUw\n\t\t\t\t\t\tOTU2MzFaME0xIDAeBgNVBAoTF0NvbW11bmlzdCBQYXJ0eSBBcmNoaXZlMSkwJwYD\n\t\t\t\t\t\tVQQDEyB3d3cuY29tbXVuaXN0cGFydHlhcmNoaXZlLm9yZy51azCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBALBBdaQ3L6V12/DE7TBeX3F0Rv/YwdXOqY2l\n\t\t\t\t\t\tLmBKNpjlrUH5NgWV7SFNZ/M6FMujjpBxgJ6duJRYIqgUs8471krbW3ARi3GpX60G\n\t\t\t\t\t\twJWjfio4ZwDXv82o+Tafh6F936LwdU9AtswDcmA6MBiueV4s3cnoyY+pHBpzrxH4\n\t\t\t\t\t\tLeSAUeCgTVHps1oaPMBc3/dIJMpPRGGkBI+e7P3k1529lVnX7qTKzr3QK+tcWCM4\n\t\t\t\t\t\tb3WeievcKInQJZUJ96t2zoDfcISnorx/1bZ68dG7N49QYfPdz8HUM7Q26j6eoYg1\n\t\t\t\t\t\tFaF2tYRk3YDLSmgxQ+MvWIouExSycBBmBvT7mlvQNpHdAhNEKZECAwEAAaOBrzCB\n\t\t\t\t\t\trDAdBgNVHQ4EFgQUEH2vsDmRr7SvveavUuqSeAT574gwfQYDVR0jBHYwdIAUEH2v\n\t\t\t\t\t\tsDmRr7SvveavUuqSeAT574ihUaRPME0xIDAeBgNVBAoTF0NvbW11bmlzdCBQYXJ0\n\t\t\t\t\t\teSBBcmNoaXZlMSkwJwYDVQQDEyB3d3cuY29tbXVuaXN0cGFydHlhcmNoaXZlLm9y\n\t\t\t\t\t\tZy51a4IJANL2QbULh4NnMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEB\n\t\t\t\t\t\tADvVdVP4IMEvIyT3VW7715A78q2eaXGr8HaXy2UP3fyJtauR7P7A4t2lBKpsTNwK\n\t\t\t\t\t\tdP0JYNIF/iavfD4KElg4z0egQb3tAK5AG2m4AE3Iei9wQKhO38kU/nCYS1MnrD/Y\n\t\t\t\t\t\toQikQE0EXee0I4hj9jZUeHtJphigNEtiIRZ/cKXpvRxDZudiklCf+Y/uKXbB4B5R\n\t\t\t\t\t\twgs2lGyckw7YMMheECpuSI7zVyls4pQP3iczc3dO8hQvVHIT10CeKgSeVyr2KvME\n\t\t\t\t\t\tvLO0bK9UD3LPNN39N/wJzqKjhW7vC98egpagUfnEna+aK+QxCZLJDHelYlqdL0/0\n\t\t\t\t\t\t8OPzZPdB5minjy+sO+WAQy4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDzTCCArWgAwIBAgIJANL2QbULh4NnMA0GCSqGSIb3DQEBBQUAME0xIDAeBgNV\n\t\t\t\t\t\tBAoTF0NvbW11bmlzdCBQYXJ0eSBBcmNoaXZlMSkwJwYDVQQDEyB3d3cuY29tbXVu\n\t\t\t\t\t\taXN0cGFydHlhcmNoaXZlLm9yZy51azAeFw0xMjA4MDcwOTU2MzFaFw0yMjA4MDUw\n\t\t\t\t\t\tOTU2MzFaME0xIDAeBgNVBAoTF0NvbW11bmlzdCBQYXJ0eSBBcmNoaXZlMSkwJwYD\n\t\t\t\t\t\tVQQDEyB3d3cuY29tbXVuaXN0cGFydHlhcmNoaXZlLm9yZy51azCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBALBBdaQ3L6V12/DE7TBeX3F0Rv/YwdXOqY2l\n\t\t\t\t\t\tLmBKNpjlrUH5NgWV7SFNZ/M6FMujjpBxgJ6duJRYIqgUs8471krbW3ARi3GpX60G\n\t\t\t\t\t\twJWjfio4ZwDXv82o+Tafh6F936LwdU9AtswDcmA6MBiueV4s3cnoyY+pHBpzrxH4\n\t\t\t\t\t\tLeSAUeCgTVHps1oaPMBc3/dIJMpPRGGkBI+e7P3k1529lVnX7qTKzr3QK+tcWCM4\n\t\t\t\t\t\tb3WeievcKInQJZUJ96t2zoDfcISnorx/1bZ68dG7N49QYfPdz8HUM7Q26j6eoYg1\n\t\t\t\t\t\tFaF2tYRk3YDLSmgxQ+MvWIouExSycBBmBvT7mlvQNpHdAhNEKZECAwEAAaOBrzCB\n\t\t\t\t\t\trDAdBgNVHQ4EFgQUEH2vsDmRr7SvveavUuqSeAT574gwfQYDVR0jBHYwdIAUEH2v\n\t\t\t\t\t\tsDmRr7SvveavUuqSeAT574ihUaRPME0xIDAeBgNVBAoTF0NvbW11bmlzdCBQYXJ0\n\t\t\t\t\t\teSBBcmNoaXZlMSkwJwYDVQQDEyB3d3cuY29tbXVuaXN0cGFydHlhcmNoaXZlLm9y\n\t\t\t\t\t\tZy51a4IJANL2QbULh4NnMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEB\n\t\t\t\t\t\tADvVdVP4IMEvIyT3VW7715A78q2eaXGr8HaXy2UP3fyJtauR7P7A4t2lBKpsTNwK\n\t\t\t\t\t\tdP0JYNIF/iavfD4KElg4z0egQb3tAK5AG2m4AE3Iei9wQKhO38kU/nCYS1MnrD/Y\n\t\t\t\t\t\toQikQE0EXee0I4hj9jZUeHtJphigNEtiIRZ/cKXpvRxDZudiklCf+Y/uKXbB4B5R\n\t\t\t\t\t\twgs2lGyckw7YMMheECpuSI7zVyls4pQP3iczc3dO8hQvVHIT10CeKgSeVyr2KvME\n\t\t\t\t\t\tvLO0bK9UD3LPNN39N/wJzqKjhW7vC98egpagUfnEna+aK+QxCZLJDHelYlqdL0/0\n\t\t\t\t\t\t8OPzZPdB5minjy+sO+WAQy4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "want_assertions_signed": "false",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://www.communistpartyarchive.org.uk/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.communistpartyarchive.org.uk/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.communistpartyarchive.org.uk/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.communistpartyarchive.org.uk/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://www.bathspasu.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.bathspasu.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-08-16T11:04:20Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bath Spa University Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bathspasu.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.bathspasu.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.bathspasu.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.bathspasu.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.bathspasu.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.bathspasu.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.bathspasu.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.bathspasu.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.bathspasu.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.bathspasu.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.bathspasu.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.bathspasu.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.bathspasu.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.bathspasu.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://webauth.cmc.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jwhaley@cmc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeremy Whaley"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jwhaley@cmc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeremy Whaley"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jwhaley@cmc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeremy Whaley"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jwhaley@cmc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeremy Whaley"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://webauth.cmc.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webauth.cmc.edu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://webauth.cmc.edu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webauth.cmc.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://webauth.cmc.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cmc.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider service for Claremont McKenna College."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Claremont McKenna College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWzCCAkOgAwIBAgIUdpkFxVnLjHw29WkEImbR9wGOCcUwDQYJKoZIhvcNAQEF\nBQAwJzElMCMGA1UEAxMcd2ViYXV0aC5jbGFyZW1vbnRtY2tlbm5hLmVkdTAeFw0x\nMzA5MjUyMTQ0NDdaFw0zMzA5MjUyMTQ0NDdaMCcxJTAjBgNVBAMTHHdlYmF1dGgu\nY2xhcmVtb250bWNrZW5uYS5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQCg8aHl2KXv3AHO4rxVzY5hAR79SqEvM1attEq0zf3MRg+xoKk/KMXw99vn\nE3PMYZN1+M/0PMVg4GLUOrDVAtfASUV8+7QnxEoAHtuTxlJghfIUaAhw5lgysYjd\nwGPkqVHR5rg0USaz/3j77Z4w3evrjXf00JMInysrkB88D4bMNQW4qeALq4yhztzU\nGcFs0KCFF4evf7TArdI5w+R8bRKfAyt6c/1MbtRpneWpsawXn7zP5+co3whaf6tC\nf10ExWMipDo39+MyqLzPgGEMklyU5HaAP6iZKMedrDWiMgYaP7wYF7MmTORvohBL\nSVtvif424JRSdg4ab8ZxLdtibeV7AgMBAAGjfzB9MFwGA1UdEQRVMFOCHHdlYmF1\ndGguY2xhcmVtb250bWNrZW5uYS5lZHWGM2h0dHBzOi8vd2ViYXV0aC5jbGFyZW1v\nbnRtY2tlbm5hLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUS22lwbhLnUmm\n/CVrh6n8h4svE/AwDQYJKoZIhvcNAQEFBQADggEBAB0dxZnUD29xM+awE6QelYnE\nC/jXxn7p4nSDYih6Yu/XObBiNOyWBeLi+Z5QuA+ROMGbom/w9kr5uhMRB2W9RwBf\nN+Zvg7/lYE1+Qm4tP358miPbeRvUjofTMCuVamzgzymBrEPU/Xl5xXxQ1vXxfHzK\nTXsJyRTIBjXcneMWAbGFmXIHfSgKuTaVYEMEU/qojdAgn3oLeMiuOK2e2mg37r4G\nE3QIN8c2JvIbeEfy2vWy2KUf91EsPWGaL35jHbZQj0CFj5CCxjEBOmDciPVq3+D+\nBiV98zaRzZEkS+1uWpkqkJjsjpGu6OoulUkarBQY6aMfvJ5QDgWDyQURKaJEeIg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "error_url": "https://webauth.cmc.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Claremont McKenna College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cmc.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Claremont McKenna College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://cafernp.insa.gov.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pedro Pacheco"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ppacheco@insa.gov.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafernp.insa.gov.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDpjCCAo4CAQAwDQYJKoZIhvcNAQEFBQAwgZgxDTALBgNVBAoTBElOU0ExDDAK\nBgNVBAsTA0NQRDEjMCEGCSqGSIb3DQEJARYUcHBhY2hlY29AaW5zYS5nb3YuYnIx\nFzAVBgNVBAcTDkNhbXBpbmEgR3JhbmRlMRAwDgYDVQQIEwdQYXJhaWJhMQswCQYD\nVQQGEwJCUjEcMBoGA1UEAxMTY2FmZXJucC5pbnNhLmdvdi5icjAeFw0xMzA5MDUx\nMTQ3MDRaFw0xNjA5MDQxMTQ3MDRaMIGYMQ0wCwYDVQQKEwRJTlNBMQwwCgYDVQQL\nEwNDUEQxIzAhBgkqhkiG9w0BCQEWFHBwYWNoZWNvQGluc2EuZ292LmJyMRcwFQYD\nVQQHEw5DYW1waW5hIEdyYW5kZTEQMA4GA1UECBMHUGFyYWliYTELMAkGA1UEBhMC\nQlIxHDAaBgNVBAMTE2NhZmVybnAuaW5zYS5nb3YuYnIwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQC6e7hlynC3DhhZh4vMpmlAGM9jGjQIRJNXmDIBU+YN\nTVhwfM8+HzMGuUhqPdoFL2aGJmJVn5TRsOjAIlK6TuHYPVJjZFrV5CGaimuXDkqH\n6nFgKoFLI6Zg0+vNUOGIQvfT1TpZaonPRqIu4MpKEDEtEk8bFkfsqxq55ivcLLYp\nGwGTZMGGBcaAztR0GRBooh3WDLIQR9gkzhxeTHEPiwF5jXGLIFZNR+kxo1ddmg4j\nsvohDefVHSkTQZt6QptsGVa408tn2pokQ4K8Enmi9zMdR6LuKvdhoC8Rs1Cc8rlJ\n7Kj5KOMmOjniR03aokncdqNoBIUBijfV0gI58L1Uca53AgMBAAEwDQYJKoZIhvcN\nAQEFBQADggEBAGVgBV46eVFwW+kASWxOC3FprDP5q/1GDcaD3rKu471uU+nd/L5n\np5xIKFBVIhx42FbAW7wpLRvhjPDCRDlXVKBgthbWGFawAyjtfPwJvR0aAowP0xHX\nQFFg7t0AXj88u89109tEaxLXpm7tzPHUiuk/D/ZtFy1JtJxZfLPHII5q53ioxF7A\nGgD+wSudqXEc3gKs2bynFcvlWgiali2b3dxNWZ5qRP652Mebtdl4H67/bSsKnhEX\nCcE/6M9wD9oWIdgaoL49rKZnU3ubSz0A5AwNhZiqGk70SbcAYrVWfZH1ApyBnt+8\njMogdK5eP4afg8zXeCSXaDF45MMQP7+gRsY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "insa.gov.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafernp.insa.gov.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafernp.insa.gov.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafernp.insa.gov.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafernp.insa.gov.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafernp.insa.gov.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafernp.insa.gov.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafernp.insa.gov.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafernp.insa.gov.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "insa.gov.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.insa.gov.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.insa.gov.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "INSA - Instituto Nacional do Semiarido"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "INSA - Instituto Nacional do Semiarido"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INSA - Instituto Nacional do Semiarido"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INSA - Instituto Nacional do Semiarido"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDpjCCAo4CAQAwDQYJKoZIhvcNAQEFBQAwgZgxDTALBgNVBAoTBElOU0ExDDAK\nBgNVBAsTA0NQRDEjMCEGCSqGSIb3DQEJARYUcHBhY2hlY29AaW5zYS5nb3YuYnIx\nFzAVBgNVBAcTDkNhbXBpbmEgR3JhbmRlMRAwDgYDVQQIEwdQYXJhaWJhMQswCQYD\nVQQGEwJCUjEcMBoGA1UEAxMTY2FmZXJucC5pbnNhLmdvdi5icjAeFw0xMzA5MDUx\nMTQ3MDRaFw0xNjA5MDQxMTQ3MDRaMIGYMQ0wCwYDVQQKEwRJTlNBMQwwCgYDVQQL\nEwNDUEQxIzAhBgkqhkiG9w0BCQEWFHBwYWNoZWNvQGluc2EuZ292LmJyMRcwFQYD\nVQQHEw5DYW1waW5hIEdyYW5kZTEQMA4GA1UECBMHUGFyYWliYTELMAkGA1UEBhMC\nQlIxHDAaBgNVBAMTE2NhZmVybnAuaW5zYS5nb3YuYnIwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQC6e7hlynC3DhhZh4vMpmlAGM9jGjQIRJNXmDIBU+YN\nTVhwfM8+HzMGuUhqPdoFL2aGJmJVn5TRsOjAIlK6TuHYPVJjZFrV5CGaimuXDkqH\n6nFgKoFLI6Zg0+vNUOGIQvfT1TpZaonPRqIu4MpKEDEtEk8bFkfsqxq55ivcLLYp\nGwGTZMGGBcaAztR0GRBooh3WDLIQR9gkzhxeTHEPiwF5jXGLIFZNR+kxo1ddmg4j\nsvohDefVHSkTQZt6QptsGVa408tn2pokQ4K8Enmi9zMdR6LuKvdhoC8Rs1Cc8rlJ\n7Kj5KOMmOjniR03aokncdqNoBIUBijfV0gI58L1Uca53AgMBAAEwDQYJKoZIhvcN\nAQEFBQADggEBAGVgBV46eVFwW+kASWxOC3FprDP5q/1GDcaD3rKu471uU+nd/L5n\np5xIKFBVIhx42FbAW7wpLRvhjPDCRDlXVKBgthbWGFawAyjtfPwJvR0aAowP0xHX\nQFFg7t0AXj88u89109tEaxLXpm7tzPHUiuk/D/ZtFy1JtJxZfLPHII5q53ioxF7A\nGgD+wSudqXEc3gKs2bynFcvlWgiali2b3dxNWZ5qRP652Mebtdl4H67/bSsKnhEX\nCcE/6M9wD9oWIdgaoL49rKZnU3ubSz0A5AwNhZiqGk70SbcAYrVWfZH1ApyBnt+8\njMogdK5eP4afg8zXeCSXaDF45MMQP7+gRsY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INSA - Instituto Nacional do Semiarido"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INSA - Instituto Nacional do Semiarido"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.insa.gov.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.insa.gov.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INSA - Instituto Nacional do Semiarido"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INSA - Instituto Nacional do Semiarido"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.lit.ie/saml2",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "O'Gorman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:joe.ogorman@lit.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Joe"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tuohy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mickt@lit.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Corcoran"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Niall.Corcoran@lit.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Niall"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.lit.ie/saml2",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.heanet.ie/services/identity-access/edugate#join"
              }
            ],
            "registration_instant": "2010-11-05T00:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.lit.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.lit.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.lit.ie/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lit.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://lit.ie"
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/lit.png",
                    "height": "68",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "224"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Limerick Institute of Technology"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:52.67518513199228,-8.64822506904602"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAK59k/q1uMH3/ug2R0Sas9bw35KeMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC5saXQuaWUwHhcNMTAwMjA0MTEyOTQxWhcNMzAw\nMjA0MTEyOTQxWjAVMRMwEQYDVQQDEwppZHAubGl0LmllMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA495mH78CGgvQeZvKrOJ4woldl2dp7Ci4QbHLGgTp\nKKfjO76MZHmgHkModQoSBefWldbJlVfWACYl9VbY068M7G1lzK6Zm53YYjOd8Ofx\nZvQGJKdNwovc3mJj3JIUbKgFYGJB5RelSBiit8THDuIUVbiOjNdEKY5j88FRE7bq\neOs38te8Mb4M7CmodPNY49L17bKdj9HTDMMy+Eb7K8cXm0tI13u662dv6Eo25gHh\nyOfW+D7yN6M9QpxYiwdGsdyEI1L+3RC2wyeXyD+BPehGFIIS6E98FPrm8aEb5VYF\nLSv6HM7Svh/OYD5SUg0vVaWRq3Zk0Qnh4h3/CjN8IA/BxQIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAubGl0LmllhiFodHRwczovL2lkcC5saXQuaWUvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFHxvq0yuTJFQfC4suTA1dPy6/UlwMA0GCSqGSIb3DQEB\nBQUAA4IBAQASBDPS14vXHejZhfmJEXVmnV23Zxm0Log8KQz23JKlTETQenL2kmPJ\nFRT2sqYb96vJO+p1oK3NuVHIrqb3/c9GsvieODItogGjMSbZxIE+NEzw6unBUkmu\nytleOJgoRQpzmV1RYSRUEFC9fqM+a6g/2OEj44k48xyxgsrf2inNGm5h8J3xg92z\nzJ1pOvbz5lQUhwFoXj6hK+Mbf2eMkRPBB2GWyHa+SQ7Od9OiGOXO3yq458Z56Epu\n4bU1gxeWc19hELfEjHGb2GcLShYI6WQMUbW8VYxJHHEko1zuS/Ubblk0L6r7pX01\nJoJbFT2leW55hVI25oEHL5f7LtG353O6"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Limerick Institute of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://lit.ie"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Limerick Institute of Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.barton.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.barton.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/barton.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/barton.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "barton.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Barton Peveril College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.barton.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.colby.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@colby.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Colby College ITS PCSS"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@colby.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Colby College ITS Shibboleth"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.colby.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.colby.edu:9443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.colby.edu:9443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDojCCAooCCQD+HsLeuS+i6TANBgkqhkiG9w0BAQUFADCBkjELMAkGA1UEBhMC\nVVMxCzAJBgNVBAgMAk1FMRMwEQYDVQQHDApXYXRlcnZpbGxlMRYwFAYDVQQKDA1D\nb2xieSBDb2xsZWdlMQwwCgYDVQQLDANJVFMxFjAUBgNVBAMMDWlkcC5jb2xieS5l\nZHUxIzAhBgkqhkiG9w0BCQEWFGluY29tbW9uY2FAY29sYnkuZWR1MB4XDTEzMTIw\nMjIyMDkwNFoXDTIzMTIwMjIyMDkwNFowgZIxCzAJBgNVBAYTAlVTMQswCQYDVQQI\nDAJNRTETMBEGA1UEBwwKV2F0ZXJ2aWxsZTEWMBQGA1UECgwNQ29sYnkgQ29sbGVn\nZTEMMAoGA1UECwwDSVRTMRYwFAYDVQQDDA1pZHAuY29sYnkuZWR1MSMwIQYJKoZI\nhvcNAQkBFhRpbmNvbW1vbmNhQGNvbGJ5LmVkdTCCASIwDQYJKoZIhvcNAQEBBQAD\nggEPADCCAQoCggEBAMPz3tu+BESQZNcAXXWLf+WVD4JozBF4bKvQnYYiPMrKc/ay\nsqwWRasGtfazdPb+npbeHrGmd8EXOfi2jIxyq2LPWvX9pS4mHxmCWyNs63mYgs2U\nuE0dpC6kBJea0dQEJ+9o3PXlG9VlVZQ4JnuVsOMlz0WNCyYGp9tJ+HhJHn9If2Rt\nXNgioCpNVdmyJ1n8GXzcuv7hb4MDbxzzRy4VAAXI062OURs4w6ZRgQ2Q7KRSeVB6\nIdK5hoTOsoLEgn8qvYgNoQCaBGW84F6njc0jZx/a9TV24Zci+sC0ivRKgEjSDp3r\ndAYUeenUxJ1x8uOdJoQgUtIC7kmOtpQ/JKEk/hECAwEAATANBgkqhkiG9w0BAQUF\nAAOCAQEAqFxpW7m89Hh7DOIfmhrJk5nH/2JSsWjaKI0FP2H7uaWZgqtsF8L0xWMU\npf8DrAsEn7tMGp8f19vcxW/d4lTFU7t28DZiUEV0m4+ClILwZdkneT6zE/VUeEhz\n2mNFlSzJrUJUiieRRCtrAHe/gSJ5voxrzs90zFNe1JNO9TuO5Itb5kp+kJAtOHkY\nHpab4IvZysoebT5U//OQ3Ct5e0tyj8jZkEeBDGvyHQ15+uszE7N+fteM2ezplDU/\n1GuxzsqRMQG9RlzDIWJPv8kek9V7eBcMjg5q+28ahgx/lY1Fs4SbVqk3WbaPbdF0\nPK29MmCAAwy8UHLt802YOYiAxSCvTw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOjCCAiICCQDPAjl6rCMrhTANBgkqhkiG9w0BAQUFADBfMRYwFAYDVQQDDA1p\nZHAuY29sYnkuZWR1MRYwFAYDVQQKDA1Db2xieSBDb2xsZWdlMQswCQYDVQQGEwJV\nUzELMAkGA1UECAwCTUUxEzARBgNVBAcMCldhdGVydmlsbGUwHhcNMTIxMjE0MjAx\nNzAzWhcNMTMxMjE0MjAxNzAzWjBfMRYwFAYDVQQDDA1pZHAuY29sYnkuZWR1MRYw\nFAYDVQQKDA1Db2xieSBDb2xsZWdlMQswCQYDVQQGEwJVUzELMAkGA1UECAwCTUUx\nEzARBgNVBAcMCldhdGVydmlsbGUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQDUYAdbuO3YMDJtqpOtAByF7PSU7gc+iSBf9z24Kl92NBCHTx1owcCgYhJn\nL/hvceInZsFRaPo7Wx5P4nkIE8FlLg4zecGLgzdDbZcrt7UY1FJ7VW2GPQ/j4Vqy\nSe90cXfcxFEI47fgkZPGRB4nfS6Vo4aJ3rJnSKVqiD2zWGqGtquIrWQnQJ0Yns5L\nzsLcypq6Wc8CNYWugTyxdZZ+8YXG5ZVz4p5m75uBtbst2U1caFR4ZOEjNd5yUBbv\n393OcLk5wtGtngqcgmFndbd+Oum2KzKMPxBRZQsrjOqb7QFUduMrDGNEn2wBzFku\n2ANj8InQG1AFSUuW1C2bCkE0v+mjAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAH3o\nSd0G1hZ0wA71HJOf5ki6xKLH+QNDvQPS9XZJqMi1VZ//GiIzPK1lsOLH+VD2sAV2\nRx67OvmjPpR9Y0iUpVDVBltVB2LxX/e+s5nrM2oCLXRIenbInX5iFjPJQOLhH/jp\nNQlwC1CiYgKXmrc2mXBW89BLpEzDrgjeDGBZ9y5b3/mEdNV+Sf5thXTSAU7l+9He\nrTzqxMMsR9dpLWvTd5DVSXK204Hk6gL8ZWRAEZc/dMXfq+kOKAcsDHM4UHMklise\npLPbEgpvIgAyy2liUsYhCCcvuR6b2IiDdtmyQwnfVqnZEXipGKvN4ZmN+Wk1wCw+\nkcpHik3So/cLW9CwMZ4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "colby.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.colby.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.colby.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.colby.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.colby.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.colby.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.colby.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "colby.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.colby.edu/administration_cs/its/policies/index.cfm"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Colby College Shibboleth Identity Provider Service"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.colby.edu/images/ColbyLogo_280_1.png",
                    "lang": "en",
                    "height": "75",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "149"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Colby College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDojCCAooCCQD+HsLeuS+i6TANBgkqhkiG9w0BAQUFADCBkjELMAkGA1UEBhMC\nVVMxCzAJBgNVBAgMAk1FMRMwEQYDVQQHDApXYXRlcnZpbGxlMRYwFAYDVQQKDA1D\nb2xieSBDb2xsZWdlMQwwCgYDVQQLDANJVFMxFjAUBgNVBAMMDWlkcC5jb2xieS5l\nZHUxIzAhBgkqhkiG9w0BCQEWFGluY29tbW9uY2FAY29sYnkuZWR1MB4XDTEzMTIw\nMjIyMDkwNFoXDTIzMTIwMjIyMDkwNFowgZIxCzAJBgNVBAYTAlVTMQswCQYDVQQI\nDAJNRTETMBEGA1UEBwwKV2F0ZXJ2aWxsZTEWMBQGA1UECgwNQ29sYnkgQ29sbGVn\nZTEMMAoGA1UECwwDSVRTMRYwFAYDVQQDDA1pZHAuY29sYnkuZWR1MSMwIQYJKoZI\nhvcNAQkBFhRpbmNvbW1vbmNhQGNvbGJ5LmVkdTCCASIwDQYJKoZIhvcNAQEBBQAD\nggEPADCCAQoCggEBAMPz3tu+BESQZNcAXXWLf+WVD4JozBF4bKvQnYYiPMrKc/ay\nsqwWRasGtfazdPb+npbeHrGmd8EXOfi2jIxyq2LPWvX9pS4mHxmCWyNs63mYgs2U\nuE0dpC6kBJea0dQEJ+9o3PXlG9VlVZQ4JnuVsOMlz0WNCyYGp9tJ+HhJHn9If2Rt\nXNgioCpNVdmyJ1n8GXzcuv7hb4MDbxzzRy4VAAXI062OURs4w6ZRgQ2Q7KRSeVB6\nIdK5hoTOsoLEgn8qvYgNoQCaBGW84F6njc0jZx/a9TV24Zci+sC0ivRKgEjSDp3r\ndAYUeenUxJ1x8uOdJoQgUtIC7kmOtpQ/JKEk/hECAwEAATANBgkqhkiG9w0BAQUF\nAAOCAQEAqFxpW7m89Hh7DOIfmhrJk5nH/2JSsWjaKI0FP2H7uaWZgqtsF8L0xWMU\npf8DrAsEn7tMGp8f19vcxW/d4lTFU7t28DZiUEV0m4+ClILwZdkneT6zE/VUeEhz\n2mNFlSzJrUJUiieRRCtrAHe/gSJ5voxrzs90zFNe1JNO9TuO5Itb5kp+kJAtOHkY\nHpab4IvZysoebT5U//OQ3Ct5e0tyj8jZkEeBDGvyHQ15+uszE7N+fteM2ezplDU/\n1GuxzsqRMQG9RlzDIWJPv8kek9V7eBcMjg5q+28ahgx/lY1Fs4SbVqk3WbaPbdF0\nPK29MmCAAwy8UHLt802YOYiAxSCvTw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOjCCAiICCQDPAjl6rCMrhTANBgkqhkiG9w0BAQUFADBfMRYwFAYDVQQDDA1p\nZHAuY29sYnkuZWR1MRYwFAYDVQQKDA1Db2xieSBDb2xsZWdlMQswCQYDVQQGEwJV\nUzELMAkGA1UECAwCTUUxEzARBgNVBAcMCldhdGVydmlsbGUwHhcNMTIxMjE0MjAx\nNzAzWhcNMTMxMjE0MjAxNzAzWjBfMRYwFAYDVQQDDA1pZHAuY29sYnkuZWR1MRYw\nFAYDVQQKDA1Db2xieSBDb2xsZWdlMQswCQYDVQQGEwJVUzELMAkGA1UECAwCTUUx\nEzARBgNVBAcMCldhdGVydmlsbGUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQDUYAdbuO3YMDJtqpOtAByF7PSU7gc+iSBf9z24Kl92NBCHTx1owcCgYhJn\nL/hvceInZsFRaPo7Wx5P4nkIE8FlLg4zecGLgzdDbZcrt7UY1FJ7VW2GPQ/j4Vqy\nSe90cXfcxFEI47fgkZPGRB4nfS6Vo4aJ3rJnSKVqiD2zWGqGtquIrWQnQJ0Yns5L\nzsLcypq6Wc8CNYWugTyxdZZ+8YXG5ZVz4p5m75uBtbst2U1caFR4ZOEjNd5yUBbv\n393OcLk5wtGtngqcgmFndbd+Oum2KzKMPxBRZQsrjOqb7QFUduMrDGNEn2wBzFku\n2ANj8InQG1AFSUuW1C2bCkE0v+mjAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAH3o\nSd0G1hZ0wA71HJOf5ki6xKLH+QNDvQPS9XZJqMi1VZ//GiIzPK1lsOLH+VD2sAV2\nRx67OvmjPpR9Y0iUpVDVBltVB2LxX/e+s5nrM2oCLXRIenbInX5iFjPJQOLhH/jp\nNQlwC1CiYgKXmrc2mXBW89BLpEzDrgjeDGBZ9y5b3/mEdNV+Sf5thXTSAU7l+9He\nrTzqxMMsR9dpLWvTd5DVSXK204Hk6gL8ZWRAEZc/dMXfq+kOKAcsDHM4UHMklise\npLPbEgpvIgAyy2liUsYhCCcvuR6b2IiDdtmyQwnfVqnZEXipGKvN4ZmN+Wk1wCw+\nkcpHik3So/cLW9CwMZ4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://www.colby.edu/search_cs/search.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Colby College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.colby.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Colby College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ldp.esc.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@esc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@esc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ldp.esc.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjACCQCbDs0NVoukPTANBgkqhkiG9w0BAQUFADBmMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEPMA0GA1UECBMGU3VycmV5MRAwDgYDVQQHEwdSZWRoaWxsMRwwGgYDVQQKExNF\n\t\t\t\t\t\tYXN0IFN1cnJleSBDb2xsZWdlMRYwFAYDVQQDEw1sZHAuZXNjLmFjLnVrMB4XDTEz\n\t\t\t\t\t\tMDIxNTE1MDgyNloXDTMzMDIxMDE1MDgyNlowZjELMAkGA1UEBhMCR0IxDzANBgNV\n\t\t\t\t\t\tBAgTBlN1cnJleTEQMA4GA1UEBxMHUmVkaGlsbDEcMBoGA1UEChMTRWFzdCBTdXJy\n\t\t\t\t\t\tZXkgQ29sbGVnZTEWMBQGA1UEAxMNbGRwLmVzYy5hYy51azCCASIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEBBQADggEPADCCAQoCggEBAN4077Zl1Y8VXd7nsyZ2Y1yP+5iYqzjbBfy35BSI\n\t\t\t\t\t\tbTdcPSuiPuYdlIij+ThG2KGSjxSJ+ErmKSqHzjF+IXfwoe4sjcESY1VGtn0Gu/ym\n\t\t\t\t\t\twyynWCnq5+ClJ+6SAT6EUzF9m5E6kT4nj2XZn7tLrW9PvT3IJpqNfzhruzzUwhqa\n\t\t\t\t\t\ttahM/bg27nPtXzhdjVKiYcwDEtDggSlT2gxbI2ZCtwtCjlAavHE8uBWHJPwVSCBT\n\t\t\t\t\t\tiLb20qdLR/hWGnBR9Dg20y8M3Yxl/rrTsllQTPqp1V+A1K7xRSauFsed3tkth0KQ\n\t\t\t\t\t\twPzI04I6Cdp3R33h/0y/OG2yJGBgX0NuvfSuc8L/nJ1d7+8CAwEAATANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAEYSEGne2kBrM0Nq2GbquH/XbjwFpMS6dLHChZyRmNNL18XVb\n\t\t\t\t\t\tvrjkBvHxMYTtHJhXdM9odkb08pxFIToG/V0nd3zy7MUZFnZQ6RAyaVTXll9DCMFc\n\t\t\t\t\t\tPp4ufilnrQMlW3OqR/MsKHZx0xAMWMDyMbPp9OrDxVj0V62p7XvlNfk1fDDNnoQN\n\t\t\t\t\t\tRgd0Lv896JOa398XcorCNltyF5C47lvpS1iJPiMCq58ZOV9/wpYzf2yA3EctFgPz\n\t\t\t\t\t\tfuxb+x4Agg1mqJiR5txLQfJjXDqnd6mbPRipuilvglK0cApdAl5rIPXJ5AzrguTq\n\t\t\t\t\t\tEOa26/uzKHmeNsbTWjKpMo3U/1Nz0fW6hltQtQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "esc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://ldp.esc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ldp.esc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://ldp.esc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ldp.esc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ldp.esc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ldp.esc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://ldp.esc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ldp.esc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "esc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjACCQCbDs0NVoukPTANBgkqhkiG9w0BAQUFADBmMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEPMA0GA1UECBMGU3VycmV5MRAwDgYDVQQHEwdSZWRoaWxsMRwwGgYDVQQKExNF\n\t\t\t\t\t\tYXN0IFN1cnJleSBDb2xsZWdlMRYwFAYDVQQDEw1sZHAuZXNjLmFjLnVrMB4XDTEz\n\t\t\t\t\t\tMDIxNTE1MDgyNloXDTMzMDIxMDE1MDgyNlowZjELMAkGA1UEBhMCR0IxDzANBgNV\n\t\t\t\t\t\tBAgTBlN1cnJleTEQMA4GA1UEBxMHUmVkaGlsbDEcMBoGA1UEChMTRWFzdCBTdXJy\n\t\t\t\t\t\tZXkgQ29sbGVnZTEWMBQGA1UEAxMNbGRwLmVzYy5hYy51azCCASIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEBBQADggEPADCCAQoCggEBAN4077Zl1Y8VXd7nsyZ2Y1yP+5iYqzjbBfy35BSI\n\t\t\t\t\t\tbTdcPSuiPuYdlIij+ThG2KGSjxSJ+ErmKSqHzjF+IXfwoe4sjcESY1VGtn0Gu/ym\n\t\t\t\t\t\twyynWCnq5+ClJ+6SAT6EUzF9m5E6kT4nj2XZn7tLrW9PvT3IJpqNfzhruzzUwhqa\n\t\t\t\t\t\ttahM/bg27nPtXzhdjVKiYcwDEtDggSlT2gxbI2ZCtwtCjlAavHE8uBWHJPwVSCBT\n\t\t\t\t\t\tiLb20qdLR/hWGnBR9Dg20y8M3Yxl/rrTsllQTPqp1V+A1K7xRSauFsed3tkth0KQ\n\t\t\t\t\t\twPzI04I6Cdp3R33h/0y/OG2yJGBgX0NuvfSuc8L/nJ1d7+8CAwEAATANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAEYSEGne2kBrM0Nq2GbquH/XbjwFpMS6dLHChZyRmNNL18XVb\n\t\t\t\t\t\tvrjkBvHxMYTtHJhXdM9odkb08pxFIToG/V0nd3zy7MUZFnZQ6RAyaVTXll9DCMFc\n\t\t\t\t\t\tPp4ufilnrQMlW3OqR/MsKHZx0xAMWMDyMbPp9OrDxVj0V62p7XvlNfk1fDDNnoQN\n\t\t\t\t\t\tRgd0Lv896JOa398XcorCNltyF5C47lvpS1iJPiMCq58ZOV9/wpYzf2yA3EctFgPz\n\t\t\t\t\t\tfuxb+x4Agg1mqJiR5txLQfJjXDqnd6mbPRipuilvglK0cApdAl5rIPXJ5AzrguTq\n\t\t\t\t\t\tEOa26/uzKHmeNsbTWjKpMo3U/1Nz0fW6hltQtQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "East Surrey College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.esc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "East Surrey College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.westherts.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@westherts.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cleaver"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Lawrence.cleaver@westherts.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lawrence"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.westherts.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-08-12T16:24:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAJ9cooaHnMILJdvfcwbpOMFGaY3KMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB8xHTAbBgNVBAMTFGlkcDIud2VzdGhlcnRzLmFjLnVrMB4XDTE0MDUwNjE0\n\t\t\t\t\t\tNTc0MVoXDTM0MDUwNjE0NTc0MVowHzEdMBsGA1UEAxMUaWRwMi53ZXN0aGVydHMu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCw1GVlx3OHs9vz\n\t\t\t\t\t\tPNI4XgpqaTckETUbvNuYzSHHO8Cd42rWqbW38ukmWmZn6a0emWQ/AcoQvISc8SK4\n\t\t\t\t\t\tW+U6XM43w+FsCioKesE+JFmUZEs4vbiQw/F5MiAOwaDwjDtGuXy36aCR2MlUleAC\n\t\t\t\t\t\ta1nFUolcsJmd3J1FsRMcs07naGZYwPVGnwNMABTjQWMHgkoWhKgaCO/YuJR1/dkC\n\t\t\t\t\t\trFt5tTw+a2NBjaL26Yo/+3Aw3SoE+7CmIAmh1vP48m8rCdCbahPWmhbzESBdb52c\n\t\t\t\t\t\t7Aui1S4Z4QuagudLGFt7QwR7sEUQ2+qvrpb+oluMnDUq5UiYyh2hCzH6a6ssg4rM\n\t\t\t\t\t\t1fXp6SN/AgMBAAGjbzBtMEwGA1UdEQRFMEOCFGlkcDIud2VzdGhlcnRzLmFjLnVr\n\t\t\t\t\t\thitodHRwczovL2lkcDIud2VzdGhlcnRzLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0G\n\t\t\t\t\t\tA1UdDgQWBBQWp8mzB9AC+Od9M1CfhkXVEbhP9DANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tGvX+Jixu4yzpXQysV3BrHkLaU6QiwYgoDnVh1269NfiGpCp2J3dz5+1uU4WGwwXY\n\t\t\t\t\t\taqr1679DjW9w8EujJHQRibwODnXM8kAJNd7GlJvrVXz1ZM4CXHpR/gAiI58MG4Vr\n\t\t\t\t\t\ttQ7sB0fyZzWlwcjNxbRqrX00v8Xz467YtYtJb4eDpZq2WHP/1lL1U9gm3FyqYxzn\n\t\t\t\t\t\tmrBVgIjdvI7Z/Y8DR/vRAwWS/qAiTzu+3tTbn8FalwF0ybn7Do9yVPP7DTm+B2rJ\n\t\t\t\t\t\tlYoHgVIrTV4juJFqx+tJsPceOgQyIqU86/CFyH6rymiSCOoUa4x3uUtI6fBdffuR\n\t\t\t\t\t\tQvZDzAP5C4j6b/8pYlItCA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "westherts.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.westherts.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.westherts.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp2.westherts.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.westherts.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp2.westherts.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2.westherts.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.westherts.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.westherts.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "westherts.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAJ9cooaHnMILJdvfcwbpOMFGaY3KMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB8xHTAbBgNVBAMTFGlkcDIud2VzdGhlcnRzLmFjLnVrMB4XDTE0MDUwNjE0\n\t\t\t\t\t\tNTc0MVoXDTM0MDUwNjE0NTc0MVowHzEdMBsGA1UEAxMUaWRwMi53ZXN0aGVydHMu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCw1GVlx3OHs9vz\n\t\t\t\t\t\tPNI4XgpqaTckETUbvNuYzSHHO8Cd42rWqbW38ukmWmZn6a0emWQ/AcoQvISc8SK4\n\t\t\t\t\t\tW+U6XM43w+FsCioKesE+JFmUZEs4vbiQw/F5MiAOwaDwjDtGuXy36aCR2MlUleAC\n\t\t\t\t\t\ta1nFUolcsJmd3J1FsRMcs07naGZYwPVGnwNMABTjQWMHgkoWhKgaCO/YuJR1/dkC\n\t\t\t\t\t\trFt5tTw+a2NBjaL26Yo/+3Aw3SoE+7CmIAmh1vP48m8rCdCbahPWmhbzESBdb52c\n\t\t\t\t\t\t7Aui1S4Z4QuagudLGFt7QwR7sEUQ2+qvrpb+oluMnDUq5UiYyh2hCzH6a6ssg4rM\n\t\t\t\t\t\t1fXp6SN/AgMBAAGjbzBtMEwGA1UdEQRFMEOCFGlkcDIud2VzdGhlcnRzLmFjLnVr\n\t\t\t\t\t\thitodHRwczovL2lkcDIud2VzdGhlcnRzLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0G\n\t\t\t\t\t\tA1UdDgQWBBQWp8mzB9AC+Od9M1CfhkXVEbhP9DANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tGvX+Jixu4yzpXQysV3BrHkLaU6QiwYgoDnVh1269NfiGpCp2J3dz5+1uU4WGwwXY\n\t\t\t\t\t\taqr1679DjW9w8EujJHQRibwODnXM8kAJNd7GlJvrVXz1ZM4CXHpR/gAiI58MG4Vr\n\t\t\t\t\t\ttQ7sB0fyZzWlwcjNxbRqrX00v8Xz467YtYtJb4eDpZq2WHP/1lL1U9gm3FyqYxzn\n\t\t\t\t\t\tmrBVgIjdvI7Z/Y8DR/vRAwWS/qAiTzu+3tTbn8FalwF0ybn7Do9yVPP7DTm+B2rJ\n\t\t\t\t\t\tlYoHgVIrTV4juJFqx+tJsPceOgQyIqU86/CFyH6rymiSCOoUa4x3uUtI6fBdffuR\n\t\t\t\t\t\tQvZDzAP5C4j6b/8pYlItCA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "West Herts College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.westherts.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "West Herts College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://oar.sci-gaia.eu/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fargetta"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:admin@sci-gaia.eu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marco"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barbera"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:admin@sci-gaia.eu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roberto"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://oar.sci-gaia.eu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2015-09-23T10:56:28Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Open Access Repository del progetto Sci-GaIA erogato dall'Universit\u00e0 degli Studi di Catania"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "R\u00e9pertoire d'Acc\u00e8s Ouvert par le projet Sci-GaIA d\u00e9livr\u00e9 par l'Universit\u00e0 degli Studi di Catania"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Sci-GaIA Open Access Repository provided by the University of Catania"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unict.it/"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unict.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unict.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli Studi Catania"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli Studi Catania"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Catania"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://oar.sci-gaia.eu/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://oar.sci-gaia.eu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://oar.sci-gaia.eu/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://oar.sci-gaia.eu/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://oar.sci-gaia.eu/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://oar.sci-gaia.eu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://oar.sci-gaia.eu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://oar.sci-gaia.eu/?ln=en"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://oar.sci-gaia.eu/ln=fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Sci-GaIA project Open Access Repository"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Sci-GaIA project Open Access Repository"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "R\u00e9pertoire d'Acc\u00e8s Ouvert par le projet Sci-GaIA"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://oar.sci-gaia.eu/help/privacy-policy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sci-GaIA project Open Access Repository"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sci-GaIA project Open Access Repository"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "R\u00e9pertoire d'Acc\u00e8s Ouvert par le projet Sci-GaIA"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFnjCCBIagAwIBAgIRAM3ckvEIEzZuZULXK4R98qkwDQYJKoZIhvcNAQELBQAw\ngZYxCzAJBgNVBAYTAkdCMRswGQYDVQQIExJHcmVhdGVyIE1hbmNoZXN0ZXIxEDAO\nBgNVBAcTB1NhbGZvcmQxGjAYBgNVBAoTEUNPTU9ETyBDQSBMaW1pdGVkMTwwOgYD\nVQQDEzNDT01PRE8gUlNBIE9yZ2FuaXphdGlvbiBWYWxpZGF0aW9uIFNlY3VyZSBT\nZXJ2ZXIgQ0EwHhcNMTUwOTE3MDAwMDAwWhcNMTgwOTE2MjM1OTU5WjCBoDELMAkG\nA1UEBhMCSVQxDjAMBgNVBBETBTk1MTIzMRAwDgYDVQQIEwdDYXRhbmlhMRAwDgYD\nVQQHEwdDYXRhbmlhMRkwFwYDVQQJExBWaWEgUy4gU29maWEsIDY0MRIwEAYDVQQK\nEwlVTklDVC1EUEExFDASBgNVBAsTC1BsYXRpbnVtU1NMMRgwFgYDVQQDEw9vYXIu\nc2NpLWdhaWEuZXUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDmdNsc\n6ZOGij3jDmsiaQ01gKUT3F7QCxUn/LLsMZJO5Q+wr913AxwcIrN90KUdtFwcpofU\nKK6c3/kVjBPcqizubV3KyGP2GhgO9srj6sJv07lKPOSM3zujuQM0L00uI2Q0t4wd\nv126+qd1pt3z7yjt5fIIjST2vk6tZd/o0G4ouuXlTi/qNaOBMhYDmfmysZojtuZp\n2pxwBNNAJYJg0ubt/hpQt0eBgoPITbp8WrGDw9TAz2pc8stcOK+ibvDANsQBuOI8\nE/Hlm+GAAk86T13IUSo8HWdcFAy+Ou2xaQZCdpUg58hdUb58ffl2UAUhseINH+Eq\n7YoBGH2AzTc2+kZRAgMBAAGjggHZMIIB1TAfBgNVHSMEGDAWgBSa8yvaz61Pti+7\nKkhIKhK3G0LBJDAdBgNVHQ4EFgQUZrSR5oipbEqnS0ssSvdbpzExFOswDgYDVR0P\nAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsG\nAQUFBwMCMFAGA1UdIARJMEcwOwYMKwYBBAGyMQECAQMEMCswKQYIKwYBBQUHAgEW\nHWh0dHBzOi8vc2VjdXJlLmNvbW9kby5jb20vQ1BTMAgGBmeBDAECAjBaBgNVHR8E\nUzBRME+gTaBLhklodHRwOi8vY3JsLmNvbW9kb2NhLmNvbS9DT01PRE9SU0FPcmdh\nbml6YXRpb25WYWxpZGF0aW9uU2VjdXJlU2VydmVyQ0EuY3JsMIGLBggrBgEFBQcB\nAQR/MH0wVQYIKwYBBQUHMAKGSWh0dHA6Ly9jcnQuY29tb2RvY2EuY29tL0NPTU9E\nT1JTQU9yZ2FuaXphdGlvblZhbGlkYXRpb25TZWN1cmVTZXJ2ZXJDQS5jcnQwJAYI\nKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmNvbW9kb2NhLmNvbTAaBgNVHREEEzARgg9v\nYXIuc2NpLWdhaWEuZXUwDQYJKoZIhvcNAQELBQADggEBAFvYiOoqoFdN43X4PPUj\nZs1dKveKKj2nUr9L8LgLl9ff2FkR9B6gF7kgTC8x1dq5JbG8s0bC3dgh8gh9kUXB\n1+PWZ9+WKoq2W/RfCBEoUSMrcQVGW0lkoHJjuEyh5lty43g5HhgTKLypwD1a/glL\n9l/sH/XOu1VEoAU0ocbrkwMB9t7LkNBEegEyx3d2TcarCywhJ43WFoCeORHKHKPk\nsKwrSiI3l4S1BlRq1GQJElZl9/oKpBYQ8UzjOXuTgDN6U6lwyj/uSj75BQ3jwbCF\nVDSqlLDi9y84jexFwiY+/ulPUc7WQPtD8QxeemcFbLvP/gnosW9YxY3/TZvQQ68y\nInI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://oar.sci-gaia.eu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://oar.sci-gaia.eu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://oar.sci-gaia.eu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://oar.sci-gaia.eu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://oar.sci-gaia.eu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://oar.sci-gaia.eu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Sci-GaIA project Open Access Repository"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Sci-GaIA project Open Access Repository"
                },
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "R\u00e9pertoire d'Acc\u00e8s Ouvert par le projet Sci-GaIA"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Sci-GaIA project Open Access Repository"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Sci-GaIA project Open Access Repository"
                },
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "R\u00e9pertoire d'Acc\u00e8s Ouvert par le projet Sci-GaIA"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://missouri.nupark.com/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "stephen.lambert@nupark.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stephen Lambert"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ron.frick@nupark.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ron Frick"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "stephen.lambert@nupark.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stephen Lambert"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "stephen.lambert@nupark.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stephen Lambert"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://missouri.nupark.com/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NuPark LLC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nupark.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NuPark LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NuPark Inc"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFqTCCBJGgAwIBAgIRANyV4qxFIn2HIWhpS2CN6I4wDQYJKoZIhvcNAQELBQAwgZYxCzAJBgNV\nBAYTAkdCMRswGQYDVQQIExJHcmVhdGVyIE1hbmNoZXN0ZXIxEDAOBgNVBAcTB1NhbGZvcmQxGjAY\nBgNVBAoTEUNPTU9ETyBDQSBMaW1pdGVkMTwwOgYDVQQDEzNDT01PRE8gUlNBIE9yZ2FuaXphdGlv\nbiBWYWxpZGF0aW9uIFNlY3VyZSBTZXJ2ZXIgQ0EwHhcNMTUxMDEwMDAwMDAwWhcNMTgxMTA5MjM1\nOTU5WjCBojELMAkGA1UEBhMCVVMxDjAMBgNVBBETBTc5NDI0MQswCQYDVQQIEwJUWDEQMA4GA1UE\nBxMHTFVCQk9DSzEZMBcGA1UECRMQMTEwMDMgUVVBS0VSIEFWRTEUMBIGA1UEChMLTlVQQVJLLCBM\nTEMxHDAaBgNVBAsTE1ByZW1pdW1TU0wgV2lsZGNhcmQxFTATBgNVBAMMDCoubnVwYXJrLmNvbTCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALl0/H0Ff+YUTStdeNNHlH9ha5BMF/pikEYV\n25nWCKLQMWcOqU4Zz2LValap82t7up6Qiv0gR055HA5cJA/lkYP80qD/XdBDLAJoUILShBZj0pNk\nFMeMNutZopE6H8sae9WVU1jaroioGRka7WbtURH/ysHv7x925DsnL4VenM0DMOVGQPKGf8FAgGI/\ntSXYz1riHqTWH5ZgJwHCWJyjMKtE3SOu6UsAngViYSjH6nAko5tetmGUUW/67n3JbFZk4SwbZCEN\nzmZg9fF03zzwojHSanqwvHDLvqoihO6+y2q0DReOC3zqqc4wu9XOK5/K+4sb4AOcD7gR3fURzqyX\nt8sCAwEAAaOCAeIwggHeMB8GA1UdIwQYMBaAFJrzK9rPrU+2L7sqSEgqErcbQsEkMB0GA1UdDgQW\nBBSNq+MnzV1IIKU6UCAHcTZRA40dgjAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNV\nHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwUAYDVR0gBEkwRzA7BgwrBgEEAbIxAQIBAwQwKzAp\nBggrBgEFBQcCARYdaHR0cHM6Ly9zZWN1cmUuY29tb2RvLmNvbS9DUFMwCAYGZ4EMAQICMFoGA1Ud\nHwRTMFEwT6BNoEuGSWh0dHA6Ly9jcmwuY29tb2RvY2EuY29tL0NPTU9ET1JTQU9yZ2FuaXphdGlv\nblZhbGlkYXRpb25TZWN1cmVTZXJ2ZXJDQS5jcmwwgYsGCCsGAQUFBwEBBH8wfTBVBggrBgEFBQcw\nAoZJaHR0cDovL2NydC5jb21vZG9jYS5jb20vQ09NT0RPUlNBT3JnYW5pemF0aW9uVmFsaWRhdGlv\nblNlY3VyZVNlcnZlckNBLmNydDAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AuY29tb2RvY2EuY29t\nMCMGA1UdEQQcMBqCDCoubnVwYXJrLmNvbYIKbnVwYXJrLmNvbTANBgkqhkiG9w0BAQsFAAOCAQEA\nc8O1FR4h3KzRATUGH/AR73ZEyWzUxpV9WYi3Hg5CdbX4X97OeYD+GWcIUiN5HzmwpO/Nfu2A8i/s\ntQLTtnHsObba27af6XF6l4dASmJc97csHrXCdx4xiqedPnLuAemgnQqOfMzieXt0Zmxyxl2GTU95\n6DcfXBQl1kK1HNsvl3Pzc5kKrYaac5GVudq+TCiETa2v6bsDRm7bUOiBzHvmJ8ZekUmvNEA3L/ns\nl0IIEvGH8twjVy00jBgrTJZiz8LiTN958X/dWQDubmFhr27S66R3/9wyGqGnEIvY+6gsWvitoX2L\nQzkVTGIslCDUoFF35o+DrDRHpQNl3C2PSLgXrQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://missouri.nupark.com/portal/authservices/acs",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://missouri.nupark.com/portal/authservices/acs",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://missouri.nupark.com/portal/authservices/acs",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://missouri.nupark.com/portal/authservices/acs",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "NuPark Inc"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "cn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ids-mannheim.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Schonefeld"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:schonefeld@ids-mannheim.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Oliver"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Witt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:witt@ids-mannheim.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andreas"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@ids-mannheim.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAI"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ids-mannheim.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2009-12-22T10:22:36Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.ids-mannheim.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGIzCCBQugAwIBAgIHGHGxHEF17jANBgkqhkiG9w0BAQsFADCBoDELMAkGA1UE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\nwF9hg13FcbfC9M9Vw8yzlIpbNxbbxyj5DlQ6umERQ+wWQcvGmPIK"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=aai@ids-mannheim.de,CN=idp.ids-mannheim.de,O=Institut fuer Deutsche Sprache,L=Mannheim,ST=Baden-Wuerttemberg,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ids-mannheim.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ids-mannheim.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ids-mannheim.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ids-mannheim.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ids-mannheim.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ids-mannheim.de/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ids-mannheim.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ids-mannheim.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ids-mannheim.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ids-mannheim.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ids-mannheim.de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ids-mannheim.de"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity-Provider des Institut f\u00fcr Deutsche Sprache"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity-Provider of the Institut f\u00fcr Deutsche Sprache"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.ids-mannheim.de/logos/ids-logo-small.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.ids-mannheim.de/logos/ids-logo-large.png",
                    "height": "63",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "318"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institut f\u00fcr Deutsche Sprache (IDS)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institut f\u00fcr Deutsche Sprache (IDS)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.ids-mannheim.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGIzCCBQugAwIBAgIHGHGxHEF17jANBgkqhkiG9w0BAQsFADCBoDELMAkGA1UE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\nwF9hg13FcbfC9M9Vw8yzlIpbNxbbxyj5DlQ6umERQ+wWQcvGmPIK"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=aai@ids-mannheim.de,CN=idp.ids-mannheim.de,O=Institut fuer Deutsche Sprache,L=Mannheim,ST=Baden-Wuerttemberg,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institut f\u00fcr Deutsche Sprache (IDS)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institut f\u00fcr Deutsche Sprache (IDS)"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ids-mannheim.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ids-mannheim.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e217"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e217"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.northland.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.northland.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/northland.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/northland.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "northland.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Northumberland College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.northland.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.fhv.at/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "System Management"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sysadmins@fhv.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "FHV"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "System Management"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sysadmins@fhv.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "FHV"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.fhv.at/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://eduid.at/policy/mdrps-20140606"
              }
            ],
            "registration_instant": "2011-07-26T12:52:10Z",
            "registration_authority": "http://eduid.at",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.fhv.at/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.fhv.at/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.fhv.at/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.fhv.at/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fhv.at"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uclv.net"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "students.fhv.at"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "schlosshofen.at"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "students.schlosshofen.at"
              },
              {
                "logo": [
                  {
                    "text": "https://login.fhv.at/fhv-logo.png",
                    "height": "57",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "113"
                  },
                  {
                    "text": "https://login.fhv.at/favicon.ico",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Fachhochschule Vorarlberg"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Vorarlberg University of Applied Sciences"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVANvjM2hsZMTPMmIUd7JVjV9bZ4d1MA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDGxvZ2luLmZodi5hdDAeFw0xMTA3MjYwOTQ1MTRaFw0z\nMTA3MjYwOTQ1MTRaMBcxFTATBgNVBAMTDGxvZ2luLmZodi5hdDCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAKxwsD9+OJckD5tkuEmbHOuzwYAtkRyXfVuV\n/Y4up4H8I+eUgqr44g+o4IiIjW/MQHqiottVUUeimuFzbiVwsr/VRzMQBJqNiE/h\neT2TOnUzHh+nPuZDtVzwy2S5lMxpGI7a5v6IwGhLjf6jV9jJjB1VtQys6ofH7uqv\njF75Jkz7X5cuPMRCXGaXEecWKeOLX0PaMsptIOUR+a6YXX2dOJbPJojH/E0OOlg2\nXxoizHzZceZF7K3Tr1SZX7mT7TjcFjCOIcbiL0hkrto5oSBkY1G77d3fdkyZvO8u\n65iPN5rVoJSuYe7aYjVqlDECQSHH46vNJXanepMmZ+iPU5K0tkECAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMbG9naW4uZmh2LmF0hiNodHRwczovL2xvZ2luLmZodi5hdC9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU1hyr7QdkMxYmdbqg/wxKiwGh9nUwDQYJ\nKoZIhvcNAQEFBQADggEBAHZCy5j4cx8jyYL6m6sY0oIzX9F5kVGPdKSXhjE85RrY\nGzGlRpXjBTA8CPlxnu99Wt4jZ2jjudwrw/bHLPwxOkZNALxj4HUa7T0cdWXCj3lR\n1b8iI5tXTYHmgjCbl+UTl/WA8YVQvA4v+2RaBMduspAFsvjwZDDOXvskLB4Aflbu\newmlLixdIpZYWbQTkSovm0InLzBuoF77CFul8Nt2oIlbLg9Qfd4f94RsaNx/2MrZ\n/YXD0gncEwV9ijUqIUGJuGicMrTGeLhxlr6bltA8K9RyTgAU3dCImRUX0tbK0jRa\nApOxw/gcmrRQwbhGEghVXhv3KlZ/xEkpVndXwiF651w="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Fachhochschule Vorarlberg"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Vorarlberg University of Applied Sciences"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fhv.at/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fhv.at/en-fhv-portal?set_language=en"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Fachhochschule Vorarlberg GmbH"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Vorarlberg University of Applied Sciences"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://falmouthtechbookings.sisoshibboleth.co.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Info"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Oates"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://falmouthtechbookings.sisoshibboleth.co.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-10-07T08:51:26Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SiSo Falmouth University Online Resource Booking"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.siso.uk.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "TechEthika Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://falmouthtechbookings.siso.co/sso/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://falmouthtechbookings.siso.co/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://falmouthtechbookings.siso.co/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SiSo Falmouth University Online Resource Booking"
                  }
                ],
                "logo": [
                  {
                    "text": "https://falmouthtechbookings.siso.co/images/layout/siso-logo.jpg",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SiSo Falmouth University Online Resource Booking"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAOSUhyDXVj7AMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB3Npc28uY28wHhcNMTMwMTA3MTYzMTIxWhcNMjMwMTA1MTYzMTIxWjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdzaXNvLmNvMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\txDnj9YFJVXclawo/8rs1aWYAgk6rKi8A/Cyycq0mW5yOKLLh8MUIgDeOGL7bLl7p\n\t\t\t\t\t\tMBeZM4ILlNaeJhICWm1tuLB6SYzREnXwpO7+lvx13xsRHW2TjCPGV3yUgz55vRYj\n\t\t\t\t\t\tbseFrwFHJ8IrL24UTLcpX/R//9cMkZpSqM+77Hn22dxbYvGUOQCHOQzL78AO91qz\n\t\t\t\t\t\tdUaxKzYWyWM7w2U4APP41Zvd0flyUtRZXp8W+WwlUDffFoNndsjR4L/9wuXvOcrH\n\t\t\t\t\t\t+VZtMLy60+cB9bpvVlaQVlt+1stEABdMVvuGNkJ9wIjRjP2b9OLUI76QmgwIDtdE\n\t\t\t\t\t\t5BS0Bv0Puz66L96r2MunRQIDAQABozUwMzASBgNVHREECzAJggdzaXNvLmNvMB0G\n\t\t\t\t\t\tA1UdDgQWBBRRosxNbUQXXwtWDl/kYMScRImh5TANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tgrfjza9Btcz+9WvzcjDTZ+KSrWWvrthA3zc6Q+C/MIBG8CCuxMO+uwFBnXIopGlX\n\t\t\t\t\t\tbLa/QtVLjOugsnizFxjaEFTG4jGndtPJ8+9V8Eja5RlOazuM2LT738+Um8/1Frhr\n\t\t\t\t\t\tGXa0Hdv9ZWEbIhil65fFqZNOmOteja6xxAQ9NgGG/XUnTVTbr7msihEAYTTcS40/\n\t\t\t\t\t\tGSYpT9nQwiryfSWDNJ17Zyl44389kSw+FCUsu8Ns9VSDEDWr/R+97ZMcjN6hAfJL\n\t\t\t\t\t\tdji3X1aaAC/JbnJl/v+yR1TH/sdHyObVaM7FToUGKiyjX9VpfOe64d0hjogzEr0x\n\t\t\t\t\t\tfirJubLNu96jbGctasqcpQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://falmouthtechbookings.siso.co/sso/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://falmouthtechbookings.siso.co/sso/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://falmouthtechbookings.siso.co/sso/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://falmouthtechbookings.siso.co/sso/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://falmouthtechbookings.siso.co/sso/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://falmouthtechbookings.siso.co/sso/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:incommon:mcnc.org",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "thorpe@mcnc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve Thorpe"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kventers@mcnc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Keith Venters"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@mcnc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MCNC Help Desk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:mcnc.org",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.mcnc.org:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.mcnc.org:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAKPDo3j6X66pMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDXNoaWIubWNuYy5vcmcwHhcNMTMxMjEzMTU0ODE4WhcNMzMxMjEzMTU0ODE4\nWjAYMRYwFAYDVQQDEw1zaGliLm1jbmMub3JnMIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAtrw9IAY4PuLTkfH9uRH92E0J+Ij+4DEfo6hxI50NdWsioMJ3\nP05GyEdIIB7TPEI0EOtWNJT6wLBxAVlM38GFfh/OSN4IEgiBywbPLQrmOuEMnTEs\nhpfDdI1aPFJpMVEx+2i5bwMD5EOSPKFNxD8B9Gqm7TZmTr3VbCb+n4xu5orpSka8\nlPBLilksOnZwOKjCHFLJlIlvyAVzB1JpNk+AC171bjdNUWIgRzpjTyD5JKzBKOGO\nVSuZfMsbpwaj8Mhm4IY49f69o9L4IleEeoAI5bWfwYFNQ/ptilcblDK/SASIXpDf\nOklntjt5DL4shertVGRAAZAkzkF6SvvX8zZ1dQIDAQABo3kwdzAdBgNVHQ4EFgQU\nW44lUTMIMW34L32RSSBpxHcbpRMwSAYDVR0jBEEwP4AUW44lUTMIMW34L32RSSBp\nxHcbpROhHKQaMBgxFjAUBgNVBAMTDXNoaWIubWNuYy5vcmeCCQCjw6N4+l+uqTAM\nBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQB/Fwb1O8NDBsrkDd/KPdaF\n5E+cJXbyu5RA/kPcyBcXRmqxdatc9olix3Tm9utN0EbuP3aiImr/6P07YHGQk+Go\nd77lFj2laehVqeVUvTrPwTUc0j3375on8E96NaXdfbeJ87nlXT84onEXWp3Ahnx/\nKJsQKCUT/4ZZoYJVFCBDShlu4igbXjNuBdL1gCsnlL8VWEbWbNJVMqzknZs4QWNw\nEUWUdnmWZjKjlk0102QEkIUvLU7en3kNqsmuPjw92IY2YhQPIH3J2RTas/FQjIL8\nnN1kNG2Jp9SMNpbgU3AYpY0oEFwoZ5QaEk0kYGPfE06xkiSOH0axJzPUWQ0yg1K+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAPKCnaTdOvUTMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDXNoaWIubWNuYy5vcmcwHhcNMTAxMjIyMTgzMzMwWhcNMTMxMjIxMTgzMzMw\nWjAYMRYwFAYDVQQDEw1zaGliLm1jbmMub3JnMIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAtrw9IAY4PuLTkfH9uRH92E0J+Ij+4DEfo6hxI50NdWsioMJ3\nP05GyEdIIB7TPEI0EOtWNJT6wLBxAVlM38GFfh/OSN4IEgiBywbPLQrmOuEMnTEs\nhpfDdI1aPFJpMVEx+2i5bwMD5EOSPKFNxD8B9Gqm7TZmTr3VbCb+n4xu5orpSka8\nlPBLilksOnZwOKjCHFLJlIlvyAVzB1JpNk+AC171bjdNUWIgRzpjTyD5JKzBKOGO\nVSuZfMsbpwaj8Mhm4IY49f69o9L4IleEeoAI5bWfwYFNQ/ptilcblDK/SASIXpDf\nOklntjt5DL4shertVGRAAZAkzkF6SvvX8zZ1dQIDAQABo3kwdzAdBgNVHQ4EFgQU\nW44lUTMIMW34L32RSSBpxHcbpRMwSAYDVR0jBEEwP4AUW44lUTMIMW34L32RSSBp\nxHcbpROhHKQaMBgxFjAUBgNVBAMTDXNoaWIubWNuYy5vcmeCCQDygp2k3Tr1EzAM\nBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCb73PacEF/52k+5WrtiO+T\nFeW4gR22sHcqJE383mz2WaWA3u0xsgYNbyA7erqIxriY1DOpdQCr4VkY3B4MNSRe\niHCeDJ67GRKDK1KiH6gR84rugPiOgBRMRkiZEY/sr5PCojg44w/NpFjF0669ZsLk\niNSnodKcEBwA2xzg/5JBoN8+c2lfA3RErnNE6H1krRSdFUIf6qqvjAsAC4tiaNoX\nqpDN0kQQPXRDoNTOQwq3dsk8Ln3Xath+S+qGl7S4hvAx4uSwRBvq9NC8nbpPOePy\nyON7kOgCmBkorVBXljwXBx36Q7X8jMYI/CQtHFcH2M05Ld8oOU31/m8xiOGruasK"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mcnc.org"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.mcnc.org/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.mcnc.org/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.mcnc.org/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.mcnc.org/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.mcnc.org:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.mcnc.org:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mcnc.org"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "MCNC"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAKPDo3j6X66pMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDXNoaWIubWNuYy5vcmcwHhcNMTMxMjEzMTU0ODE4WhcNMzMxMjEzMTU0ODE4\nWjAYMRYwFAYDVQQDEw1zaGliLm1jbmMub3JnMIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAtrw9IAY4PuLTkfH9uRH92E0J+Ij+4DEfo6hxI50NdWsioMJ3\nP05GyEdIIB7TPEI0EOtWNJT6wLBxAVlM38GFfh/OSN4IEgiBywbPLQrmOuEMnTEs\nhpfDdI1aPFJpMVEx+2i5bwMD5EOSPKFNxD8B9Gqm7TZmTr3VbCb+n4xu5orpSka8\nlPBLilksOnZwOKjCHFLJlIlvyAVzB1JpNk+AC171bjdNUWIgRzpjTyD5JKzBKOGO\nVSuZfMsbpwaj8Mhm4IY49f69o9L4IleEeoAI5bWfwYFNQ/ptilcblDK/SASIXpDf\nOklntjt5DL4shertVGRAAZAkzkF6SvvX8zZ1dQIDAQABo3kwdzAdBgNVHQ4EFgQU\nW44lUTMIMW34L32RSSBpxHcbpRMwSAYDVR0jBEEwP4AUW44lUTMIMW34L32RSSBp\nxHcbpROhHKQaMBgxFjAUBgNVBAMTDXNoaWIubWNuYy5vcmeCCQCjw6N4+l+uqTAM\nBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQB/Fwb1O8NDBsrkDd/KPdaF\n5E+cJXbyu5RA/kPcyBcXRmqxdatc9olix3Tm9utN0EbuP3aiImr/6P07YHGQk+Go\nd77lFj2laehVqeVUvTrPwTUc0j3375on8E96NaXdfbeJ87nlXT84onEXWp3Ahnx/\nKJsQKCUT/4ZZoYJVFCBDShlu4igbXjNuBdL1gCsnlL8VWEbWbNJVMqzknZs4QWNw\nEUWUdnmWZjKjlk0102QEkIUvLU7en3kNqsmuPjw92IY2YhQPIH3J2RTas/FQjIL8\nnN1kNG2Jp9SMNpbgU3AYpY0oEFwoZ5QaEk0kYGPfE06xkiSOH0axJzPUWQ0yg1K+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAPKCnaTdOvUTMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDXNoaWIubWNuYy5vcmcwHhcNMTAxMjIyMTgzMzMwWhcNMTMxMjIxMTgzMzMw\nWjAYMRYwFAYDVQQDEw1zaGliLm1jbmMub3JnMIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAtrw9IAY4PuLTkfH9uRH92E0J+Ij+4DEfo6hxI50NdWsioMJ3\nP05GyEdIIB7TPEI0EOtWNJT6wLBxAVlM38GFfh/OSN4IEgiBywbPLQrmOuEMnTEs\nhpfDdI1aPFJpMVEx+2i5bwMD5EOSPKFNxD8B9Gqm7TZmTr3VbCb+n4xu5orpSka8\nlPBLilksOnZwOKjCHFLJlIlvyAVzB1JpNk+AC171bjdNUWIgRzpjTyD5JKzBKOGO\nVSuZfMsbpwaj8Mhm4IY49f69o9L4IleEeoAI5bWfwYFNQ/ptilcblDK/SASIXpDf\nOklntjt5DL4shertVGRAAZAkzkF6SvvX8zZ1dQIDAQABo3kwdzAdBgNVHQ4EFgQU\nW44lUTMIMW34L32RSSBpxHcbpRMwSAYDVR0jBEEwP4AUW44lUTMIMW34L32RSSBp\nxHcbpROhHKQaMBgxFjAUBgNVBAMTDXNoaWIubWNuYy5vcmeCCQDygp2k3Tr1EzAM\nBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCb73PacEF/52k+5WrtiO+T\nFeW4gR22sHcqJE383mz2WaWA3u0xsgYNbyA7erqIxriY1DOpdQCr4VkY3B4MNSRe\niHCeDJ67GRKDK1KiH6gR84rugPiOgBRMRkiZEY/sr5PCojg44w/NpFjF0669ZsLk\niNSnodKcEBwA2xzg/5JBoN8+c2lfA3RErnNE6H1krRSdFUIf6qqvjAsAC4tiaNoX\nqpDN0kQQPXRDoNTOQwq3dsk8Ln3Xath+S+qGl7S4hvAx4uSwRBvq9NC8nbpPOePy\nyON7kOgCmBkorVBXljwXBx36Q7X8jMYI/CQtHFcH2M05Ld8oOU31/m8xiOGruasK"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MCNC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mcnc.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "MCNC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.iwcollege.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Violaris"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Steve.Violaris@iwcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Annetts"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:simon@ateb.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.iwcollege.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-02-12T12:31:19Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUU3AARW5EezCLsq9ZxfkceNTJVYEwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJTEjMCEGA1UEAxMac2hpYmJvbGV0aC5pd2NvbGxlZ2UuYWMudWswHhcNMTQw\n\t\t\t\t\t\tMjEwMTQ0MDEzWhcNMzQwMjEwMTQ0MDEzWjAlMSMwIQYDVQQDExpzaGliYm9sZXRo\n\t\t\t\t\t\tLml3Y29sbGVnZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAKzUxmDIS29Sejm1J9fiY/ld8mkk6sskW5Pghzam6gGCa/YcH0VYdJvqCMC2juZO\n\t\t\t\t\t\trGHHePIr4X4pygytSKgyXf6MOuavQ8xdhpglM73DDiPeGZsGsdvAET994q2gbIpR\n\t\t\t\t\t\tUaR0kzFW4LDSsY1GFbujIl59hu0vbxbddlgR9byKamsEmiXETKf+1oDkWLPHQQ9H\n\t\t\t\t\t\tSc6xFZihQT5562RBlhswMquk2ZKY9WsUhzG+PaVrXxQoFCPsus8QhX9cALKNFH2g\n\t\t\t\t\t\t99VkRqlS+3fE5v3AQnEBCUXJSAK/Y8lNuLWQnSmLuYRxXbXVzQy3JB1fHCZKCxYm\n\t\t\t\t\t\tDTlMiNEMJoziUQ3Oa+9cqxECAwEAAaN7MHkwWAYDVR0RBFEwT4Iac2hpYmJvbGV0\n\t\t\t\t\t\taC5pd2NvbGxlZ2UuYWMudWuGMWh0dHBzOi8vc2hpYmJvbGV0aC5pd2NvbGxlZ2Uu\n\t\t\t\t\t\tYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFFoss0RidHbwaeYmqjP1zYLn\n\t\t\t\t\t\t4ptTMA0GCSqGSIb3DQEBBQUAA4IBAQCj2RH3sEFLevVNOV7Tg30KcYw0IYYLGVD9\n\t\t\t\t\t\tg2WjGCAm/7ukH4jP9Tbdo8aUMx7ouCdTFcfHO0j5l5iezPf65fo/Zt8sCf8vd75f\n\t\t\t\t\t\tCfUeB0p5d174teNMpQiMrF753TWUjdtde36+d97WHpAhDwaKEfRc1wR1N0rjXrBy\n\t\t\t\t\t\tnZ3+lS4aUxJqdbzU2/zHJxfsMasqJTybKUk2CEkFp+54nbE88LmFe0be3S+1iTKY\n\t\t\t\t\t\trMTyTBDwBP+18XGlbE3LMu/ZjoIUcpuVfoDsFUG6yZSsE8gVTh1IutH33K0Y7ikx\n\t\t\t\t\t\tZBo49q3f1kRNl5PRuqWPA3U/tG5LsoStLJ+SxD2xbc4q3D9A6YBZ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iwcollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.iwcollege.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.iwcollege.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.iwcollege.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.iwcollege.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.iwcollege.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.iwcollege.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.iwcollege.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.iwcollege.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iwcollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUU3AARW5EezCLsq9ZxfkceNTJVYEwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJTEjMCEGA1UEAxMac2hpYmJvbGV0aC5pd2NvbGxlZ2UuYWMudWswHhcNMTQw\n\t\t\t\t\t\tMjEwMTQ0MDEzWhcNMzQwMjEwMTQ0MDEzWjAlMSMwIQYDVQQDExpzaGliYm9sZXRo\n\t\t\t\t\t\tLml3Y29sbGVnZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAKzUxmDIS29Sejm1J9fiY/ld8mkk6sskW5Pghzam6gGCa/YcH0VYdJvqCMC2juZO\n\t\t\t\t\t\trGHHePIr4X4pygytSKgyXf6MOuavQ8xdhpglM73DDiPeGZsGsdvAET994q2gbIpR\n\t\t\t\t\t\tUaR0kzFW4LDSsY1GFbujIl59hu0vbxbddlgR9byKamsEmiXETKf+1oDkWLPHQQ9H\n\t\t\t\t\t\tSc6xFZihQT5562RBlhswMquk2ZKY9WsUhzG+PaVrXxQoFCPsus8QhX9cALKNFH2g\n\t\t\t\t\t\t99VkRqlS+3fE5v3AQnEBCUXJSAK/Y8lNuLWQnSmLuYRxXbXVzQy3JB1fHCZKCxYm\n\t\t\t\t\t\tDTlMiNEMJoziUQ3Oa+9cqxECAwEAAaN7MHkwWAYDVR0RBFEwT4Iac2hpYmJvbGV0\n\t\t\t\t\t\taC5pd2NvbGxlZ2UuYWMudWuGMWh0dHBzOi8vc2hpYmJvbGV0aC5pd2NvbGxlZ2Uu\n\t\t\t\t\t\tYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFFoss0RidHbwaeYmqjP1zYLn\n\t\t\t\t\t\t4ptTMA0GCSqGSIb3DQEBBQUAA4IBAQCj2RH3sEFLevVNOV7Tg30KcYw0IYYLGVD9\n\t\t\t\t\t\tg2WjGCAm/7ukH4jP9Tbdo8aUMx7ouCdTFcfHO0j5l5iezPf65fo/Zt8sCf8vd75f\n\t\t\t\t\t\tCfUeB0p5d174teNMpQiMrF753TWUjdtde36+d97WHpAhDwaKEfRc1wR1N0rjXrBy\n\t\t\t\t\t\tnZ3+lS4aUxJqdbzU2/zHJxfsMasqJTybKUk2CEkFp+54nbE88LmFe0be3S+1iTKY\n\t\t\t\t\t\trMTyTBDwBP+18XGlbE3LMu/ZjoIUcpuVfoDsFUG6yZSsE8gVTh1IutH33K0Y7ikx\n\t\t\t\t\t\tZBo49q3f1kRNl5PRuqWPA3U/tG5LsoStLJ+SxD2xbc4q3D9A6YBZ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Isle of Wight College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://iwcollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Isle of Wight College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://jenkins.ukfederation.org.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:service@ukfederation.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UK federation helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ukfed.infrastructure@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UK federation infrastructure"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://jenkins.ukfederation.org.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-07-12T10:52:56Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UK federation Jenkins CI server"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://ukfederation.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jenkins.ukfederation.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This continuous integration server is part of the UK federation infrastructure and is only\n\t\t\t\t\tavailable to UK federation team members."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UK federation Jenkins CI server"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://jenkins.ukfederation.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://jenkins.ukfederation.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://jenkins.ukfederation.org.uk/Shibboleth.sso/EDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://jenkins.ukfederation.org.uk/Shibboleth.sso/EDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEPjCCAyagAwIBAgIJAOVnQ3eBaoIXMA0GCSqGSIb3DQEBBQUAMIGfMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjERMA8GA1UECBMIU2NvdGxhbmQxEjAQBgNVBAcTCUVkaW5idXJnaDFD\n\t\t\t\t\t\tMEEGA1UEChM6VUsgQWNjZXNzIE1hbmFnZW1lbnQgRmVkZXJhdGlvbiBmb3IgRWR1\n\t\t\t\t\t\tY2F0aW9uIGFuZCBSZXNlYXJjaDEkMCIGA1UEAxMbamVua2lucy51a2ZlZGVyYXRp\n\t\t\t\t\t\tb24ub3JnLnVrMB4XDTEzMDcxMjEwMDQxOFoXDTIzMDcxMDEwMDQxOFowgZ8xCzAJ\n\t\t\t\t\t\tBgNVBAYTAkdCMREwDwYDVQQIEwhTY290bGFuZDESMBAGA1UEBxMJRWRpbmJ1cmdo\n\t\t\t\t\t\tMUMwQQYDVQQKEzpVSyBBY2Nlc3MgTWFuYWdlbWVudCBGZWRlcmF0aW9uIGZvciBF\n\t\t\t\t\t\tZHVjYXRpb24gYW5kIFJlc2VhcmNoMSQwIgYDVQQDExtqZW5raW5zLnVrZmVkZXJh\n\t\t\t\t\t\tdGlvbi5vcmcudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCU/xHG\n\t\t\t\t\t\tDw0FRJUVC8evIBKqH77osYeVSYqeaHhjnCMDGURYfua8by5lYVWufRS6gVv/MaJU\n\t\t\t\t\t\tFKbZY9XKPH6uDBJ/l5Lypx6H7V1tZn7BroXg9fNyLrC0WpUrBYw5S+MYFQgEuB+C\n\t\t\t\t\t\tB2wvuvoKKa0GSPHvgfV/K8ymh08ARsgT83MMfW9rA0+gy2x1AvJt0VYO96rGjI1q\n\t\t\t\t\t\t0SeDGMWwk58OFXA/4UbIsTg56hl9NfW2QLkSsi4cz/uJD2q1F44Ai/pOUHiT8lVH\n\t\t\t\t\t\tXAl77Nefma9w5Djng2yVoMd9tQ9Sx5bWOZ6VxnbA0ARJBq/8QzRvkiiQ3Ceacu0G\n\t\t\t\t\t\tV961M6U1X4ZcqSpRAgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8W\n\t\t\t\t\t\tHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBSeM+/WeAoJ\n\t\t\t\t\t\tDPll4Dh3TUT+dI3oPzAfBgNVHSMEGDAWgBSeM+/WeAoJDPll4Dh3TUT+dI3oPzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAHUHH0JodQuv4B984Z8aESW04OJSDFIpYL30luVQr\n\t\t\t\t\t\tAwFPZ3wopM5qfkO6CpJIa+IK9oQxppOi+Fs+dYEBUYHjXQbx/xbSuqzjr7GE/xS6\n\t\t\t\t\t\tKumhmn3Y1RP9/2l0Ema7DMryN7nxIsF+fxDr0LgaXboAMnITKvhf0k5cVDdAO/JT\n\t\t\t\t\t\ty+lx0ZxwizlzdmjyfmmCIJkUXvPwnh8Le+9AqU2qjh14OPw4cHabf2mtEKAXFkJ/\n\t\t\t\t\t\tHrX1GuA4GsXXdKYi1Deaj2JIATS/7YTYt4S2vyx+gEN/0+Rg70YC5P9xFWsibAIr\n\t\t\t\t\t\tWXY859KC7gEzlErCQS2KPKYA4abXdTiut4yaeh+HZN1Ctw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jenkins.ukfederation.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://jenkins.ukfederation.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://jenkins.ukfederation.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://jenkins.ukfederation.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://jenkins.ukfederation.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://jenkins.ukfederation.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "UK federation Jenkins CI server"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This continuous integration server is part of the UK federation infrastructure and is only\n\t\t\t\tavailable to UK federation team members."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://lcm.idm.oclc.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Support Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Support Desk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://lcm.idm.oclc.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-01-03T17:14:03Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Leeds College of Music Hosted EZproxy"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oclc.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "OCLC (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID+DCCAuCgAwIBAgIBAzANBgkqhkiG9w0BAQUFADBgMRswGQYDVQQDFBIqLmxj\n\t\t\t\t\t\tbS5pZG0ub2NsYy5vcmcxCzAJBgNVBAYTAlVLMQ0wCwYDVQQKEwRPQ0xDMSUwIwYJ\n\t\t\t\t\t\tKoZIhvcNAQkBFhZqdWxpYW4ubWNmYWxsQG9jbGMub3JnMB4XDTEzMTAxODE2MDMw\n\t\t\t\t\t\tOFoXDTIzMTAxODE2MDMwOFowYDEbMBkGA1UEAxQSKi5sY20uaWRtLm9jbGMub3Jn\n\t\t\t\t\t\tMQswCQYDVQQGEwJVSzENMAsGA1UEChMET0NMQzElMCMGCSqGSIb3DQEJARYWanVs\n\t\t\t\t\t\taWFuLm1jZmFsbEBvY2xjLm9yZzCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBALXw8P+ELg/oOkOBKaQEW84oW+Kp043lngkY/hZledNtKgLP37IYa3Ml/K5T\n\t\t\t\t\t\t+sehBTRFrXeR/MzYM1dbsvzl92ty0f5yF1q97QAEK9BbKF2vCIItuteFw/Fe6/7Q\n\t\t\t\t\t\tApGDrC842s/EexAQPFuOn5o5G/F6kRghWiOk0U/tkdO0muilulCNA3O/5A1HYWnb\n\t\t\t\t\t\tQwwDdrS/EOHM8y1DM1bn+66WZgdQaXuAn5RSQFm0KLj+v/fq6MlU34Zueg3YUAwV\n\t\t\t\t\t\to0U22FvtARo2Mc4kbfekM9dZQF22chbVSRh2DMrE8ySF96IMeW2gcwsK150D9uNR\n\t\t\t\t\t\tCiIhxdaEXus73yNKjGgtAr8ww9ECAwEAAaOBvDCBuTAdBgNVHQ4EFgQUDoMxYApE\n\t\t\t\t\t\tqa3KQU0dQ8E0V4c0C14wgYkGA1UdIwSBgTB/gBQOgzFgCkSprcpBTR1DwTRXhzQL\n\t\t\t\t\t\tXqFkpGIwYDEbMBkGA1UEAxQSKi5sY20uaWRtLm9jbGMub3JnMQswCQYDVQQGEwJV\n\t\t\t\t\t\tSzENMAsGA1UEChMET0NMQzElMCMGCSqGSIb3DQEJARYWanVsaWFuLm1jZmFsbEBv\n\t\t\t\t\t\tY2xjLm9yZ4IBAzAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCaSvOu\n\t\t\t\t\t\tZiZdvyHNxoVgF9k34mfDKLanrgxcr2jf2Y4B4i/6hrL7jHDZyfh8RoZW4G0pX3Zo\n\t\t\t\t\t\tCKJob6cqxEIzws+yRcVdjpseSrmZ4iRMdBxFuFLlrvV7f1OTpkOZGNg7vW+vWKsp\n\t\t\t\t\t\tJ7LF3OeilOJJkWrvYEHhJw0gHzLB69Td6A2JmlDm0x8M1OrJ16u942azdVIfiH8U\n\t\t\t\t\t\ttu7Gx1GoWXiIjQU5JRhcXnxLhaWk8RCK8DnS+uxTD9Gi2auCgUwe/M1GPF5XQ2Co\n\t\t\t\t\t\tm8VxEpX1XIKFFn3LbFNLFmAJqmz0w09hVS7XVQfViRbYnWHNf44l7xD75gTQ+qPS\n\t\t\t\t\t\tRRihYOyFbxq/SI85"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://login.lcm.idm.oclc.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.lcm.idm.oclc.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.lcm.idm.oclc.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.lcm.idm.oclc.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://nidev-consumer.nordu.net/saml2/metadata/",
    {
      "entity_id": "https://nidev-consumer.nordu.net/saml2/metadata/",
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lundberg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lundberg@nordu.net"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "NORDUnet A/S"
          },
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Johan"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nidev-consumer.nordu.net/saml2/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEsDCCA5igAwIBAgIJAJu8g6oQf0k0MA0GCSqGSIb3DQEBBQUAMIGWMQswCQYD\nVQQGEwJTRTESMBAGA1UECBMJU3RvY2tob2xtMRIwEAYDVQQHEwlTdG9ja2hvbG0x\nFTATBgNVBAoTDE5PUkRVbmV0IEEvUzEMMAoGA1UECxMDRGV2MRcwFQYDVQQDEw5K\nb2hhbiBMdW5kYmVyZzEhMB8GCSqGSIb3DQEJARYSbHVuZGJlcmdAbm9yZHUubmV0\nMB4XDTEyMDgyNDA4NTA1NVoXDTE3MDgyMzA4NTA1NVowgZYxCzAJBgNVBAYTAlNF\nMRIwEAYDVQQIEwlTdG9ja2hvbG0xEjAQBgNVBAcTCVN0b2NraG9sbTEVMBMGA1UE\nChMMTk9SRFVuZXQgQS9TMQwwCgYDVQQLEwNEZXYxFzAVBgNVBAMTDkpvaGFuIEx1\nbmRiZXJnMSEwHwYJKoZIhvcNAQkBFhJsdW5kYmVyZ0Bub3JkdS5uZXQwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCfBoRr9+zzx9fWoTrP0ML1ZpFVaUj9\nJRJCPOjE9SNjnqnjIE2bB91W3nCQRbHy+AdyUOk5p/SgtVlqgAMYRNTvEmm3/6Tj\nuDAT1ft+AsOSZoBp14s0LqlYTXJWgNlDA5Lti5Z1HL+6YMCmWJSRC5IsgDy2BOqf\n52EW+cTkgOoIqWt0vtLyIYTAM1S5cLeC/+TrN6tTwTsQ043YSePqR/Ixhhwb0viF\nN+1F5XKHYni8jncw71//VKF2xKFAld5zS7cH7WAHg4FHdlEh5O4Ot0OxtN5md7eb\nskkEkbY6/hSWf6wlXndlmO1lf5x6bo4ZiT/9YgjPAukaQN8vruFi49RnAgMBAAGj\ngf4wgfswHQYDVR0OBBYEFFfCbcMGldF2YVDr6mdPYkKfDyoOMIHLBgNVHSMEgcMw\ngcCAFFfCbcMGldF2YVDr6mdPYkKfDyoOoYGcpIGZMIGWMQswCQYDVQQGEwJTRTES\nMBAGA1UECBMJU3RvY2tob2xtMRIwEAYDVQQHEwlTdG9ja2hvbG0xFTATBgNVBAoT\nDE5PUkRVbmV0IEEvUzEMMAoGA1UECxMDRGV2MRcwFQYDVQQDEw5Kb2hhbiBMdW5k\nYmVyZzEhMB8GCSqGSIb3DQEJARYSbHVuZGJlcmdAbm9yZHUubmV0ggkAm7yDqhB/\nSTQwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAQVt/TcsaSBk3Ntss\ng1uNCrXJ5JM0GnFxjQwCovKOT05BLagctbNoVkPCkAOtn9mXk4W17wC4Bvl/dWIY\neahQiF4pAxOiI2Yk9Gyr0Sn39yR/SAp46XwEH1k1tLblCb40yADOZzaJa2r54YhF\nn+YuzxirlYLnAmU+5u8BF9qcMH8tXbM3ss1PRtEPbe4ntqzhU9GF5ZIt+SE/f7Dl\nRk0oUvUGJpTOgmmLI5bsg3F0oiKFFDs1jlR3Xx4DlGo1VnI0VWHkeR63mB57bKkp\nk/Nin4OuWJ9R1vU0OpdW4SjcfXkEElXfMslpqAst4IribB3Koa51CtWWdPPxJK8R\nZ+RKbg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nidev-consumer.nordu.net/saml2/acs/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "NOCLook Development"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://secure.nature.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ollier"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:j.ollier@nature.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ollier"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:j.ollier@nature.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://secure.nature.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Nature Publishing Group"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nature.com/npg_/company_info/index.html"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Macmillan Publishers Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://secure.nature.com/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://secure.nature.com/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://secure.nature.com/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://secure.nature.com/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVzCCAj+gAwIBAgIESsDsijANBgkqhkiG9w0BAQsFADBcMQswCQYDVQQGEwJVSzEPMA0GA1UE\n\t\t\t\t\t\tBxMGTG9uZG9uMRIwEAYDVQQKEwlNYWNtaWxsYW4xDDAKBgNVBAsTA05QRzEaMBgGA1UEAxMRc2Vj\n\t\t\t\t\t\tdXJlLm5hdHVyZS5jb20wHhcNMTUwNjIzMDgxODQ3WhcNMjUwNjIwMDgxODQ3WjBcMQswCQYDVQQG\n\t\t\t\t\t\tEwJVSzEPMA0GA1UEBxMGTG9uZG9uMRIwEAYDVQQKEwlNYWNtaWxsYW4xDDAKBgNVBAsTA05QRzEa\n\t\t\t\t\t\tMBgGA1UEAxMRc2VjdXJlLm5hdHVyZS5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQC0tKViXqJ6zxZ0W6kBxCk/6Jd8dqcfeODSonisCrGqAOO6uP2G81LICj/WQCSGu7J8gY2o1ZbV\n\t\t\t\t\t\tKWxyXWzYUgs8ZR0zoPUVOCpo8JPjXqZFlo2mCy5Ex9H7VrUu2KqM0eGZ8c80r7rUj0a7Yp8HvZex\n\t\t\t\t\t\tkt1HMcnvUYPER8XGGFqRaut7Ny/D1HlSZdQhkXVmHhySEkaObGDLR9ZG0EJFqjuRwk7RZu9fDuFw\n\t\t\t\t\t\tuo2+GVOQsR0A/dUzo49F/RDyRmjGpSpajirCm5paLCfb2K2mNSboNQ8VQqH5nYpxL9xuwAyt5ect\n\t\t\t\t\t\tvKlsun+gRJiRmw3Nbm4D+jrVMzz/OLqCVIWVK6PRAgMBAAGjITAfMB0GA1UdDgQWBBRAYRF+J0Fz\n\t\t\t\t\t\tkBZcXfNNK2IXcL66ijANBgkqhkiG9w0BAQsFAAOCAQEAlQszJFL/eicmXBGXIBtz0xWpLRc4hjvt\n\t\t\t\t\t\tLAD16bPmMqOXk8RYlFy3BFC9ZLs/imkOK4ixfgMNfCyddbT+//ABNTuM4a6qeL/5oNNPJZJmqInm\n\t\t\t\t\t\t8QqN0fxNfSnFtyVCfX68mYBD7Onl9TcnRKKqJ4dm6C4qXQqVAUbC7gYTTljCHXoqbLjwnY5pPFqF\n\t\t\t\t\t\t3CuGxi7rhyP39Dax4UKiQm3V9AZkcxq8fDs+GsTLUceGOYa0g4LoDsUMcPo26IP8N4gcz7VHslwv\n\t\t\t\t\t\tmxxchptFQSwuunaMQuJhSrR18v8AFekwNd6YEDzxQSqKOo/9eLoymeztcHBVP9f+l39z/rvGsWlZ\n\t\t\t\t\t\t5C+nbg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Online access to Nature Publishing Group journals"
                  }
                ],
                "logo": [
                  {
                    "text": "https://secure.nature.com/images/naturegroup_logo2png.PNG",
                    "height": "165",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "250"
                  },
                  {
                    "text": "https://secure.nature.com/images/naturegroup_logopng.PNG",
                    "height": "70",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "220"
                  },
                  {
                    "text": "https://secure.nature.com/images/naturegroup_logo2.GIF",
                    "height": "165",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "250"
                  },
                  {
                    "text": "https://secure.nature.com/images/naturegroup_logo.GIF",
                    "height": "70",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "220"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Nature Publishing Group journals"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://keystone.cloud.ipnett.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://keystone.cloud.ipnett.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://keystone.cloud.ipnett.se/Shibboleth.sso/Logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IPnett Cloud Services OpenStack"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IPnett Cloud Services OpenStack"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.cloud.ipnett.se/ipnett.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "77"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IPnett Cloud Services"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IPnett Cloud Services"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDmzCCAoOgAwIBAgIJALMD2UXE6X0+MA0GCSqGSIb3DQEBCwUAMGQxCzAJBgNV\n            BAYTAlNFMRIwEAYDVQQKDAlJUG5ldHQgQUIxHjAcBgNVBAsMFUlQbmV0dCBDbG91\n            ZCBTZXJ2aWNlczEhMB8GA1UEAwwYa2V5c3RvbmUuY2xvdWQuaXBuZXR0LnNlMB4X\n            DTE1MDkwODExMjIyOFoXDTI2MDgyMTExMjIyOFowZDELMAkGA1UEBhMCU0UxEjAQ\n            BgNVBAoMCUlQbmV0dCBBQjEeMBwGA1UECwwVSVBuZXR0IENsb3VkIFNlcnZpY2Vz\n            MSEwHwYDVQQDDBhrZXlzdG9uZS5jbG91ZC5pcG5ldHQuc2UwggEiMA0GCSqGSIb3\n            DQEBAQUAA4IBDwAwggEKAoIBAQDGnD+EKpJL8J0QoU726uut/Q/BNlsof72ivhqq\n            kdZDAw8j9C3ILzECplWYjxXR/gO5p1J5plcFqv4/M3q3P3zuiWCETvUA7Ha1cTwI\n            XU+33LqnnYp2SzICl1RfdHYuLSx2kYLhdvaPiOpZJvb6v2WEmcAx0gbEpgHjz3fh\n            Qm572sEksRGZ05Cr+STSicbqWgjEljGonlQWgpyYeLf6MWGg54Z4xWlJXbFk8kG/\n            fuoib7GajfM3qPBa/rv81GBZTPl/6n8NTwHXSRF2ma5+204oZJy2CjW0YJnZW8qB\n            kMGD0bwFBcB8Oh2wjwPF0+bIuVBO4vszUYGsEZB113tAooAhAgMBAAGjUDBOMB0G\n            A1UdDgQWBBTHAWptkTT/t84Tjn28cbnZb/7ZyTAfBgNVHSMEGDAWgBTHAWptkTT/\n            t84Tjn28cbnZb/7ZyTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQA6\n            SRQk0fw4o2f5u0vy3YAu1Zmr1bFCOlG1b4wnWXd6J1j1duHDIE7aWgTdT6bMCU7X\n            AAByaVmYOgzps+38kw27j1EE9CpIvQed6RWD5kDUU5rdpYNfKRvA1+sy62h3qMK4\n            e0Yfo1t7WRG1pz7FWz324PR3mAmXDbhrs47zan0m+Ds7VpI+n4SMKNHzqnMrKDe3\n            HVifjPaoea6SwMrPfuVQPxlwJh1XmtYybkqozmo6RB8Mkt/feN+YUXt9G2Rd5xfr\n            N86EdmlYTjlxDf9XzhXt2xyKO5YsNIv6sgPnGTxZC6/rzx8NYUbfXfFh4HUDEtbY\n            TA50ga7htHv63FhyREun"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDmzCCAoOgAwIBAgIJALMD2UXE6X0+MA0GCSqGSIb3DQEBCwUAMGQxCzAJBgNV\n            BAYTAlNFMRIwEAYDVQQKDAlJUG5ldHQgQUIxHjAcBgNVBAsMFUlQbmV0dCBDbG91\n            ZCBTZXJ2aWNlczEhMB8GA1UEAwwYa2V5c3RvbmUuY2xvdWQuaXBuZXR0LnNlMB4X\n            DTE1MDkwODExMjIyOFoXDTI2MDgyMTExMjIyOFowZDELMAkGA1UEBhMCU0UxEjAQ\n            BgNVBAoMCUlQbmV0dCBBQjEeMBwGA1UECwwVSVBuZXR0IENsb3VkIFNlcnZpY2Vz\n            MSEwHwYDVQQDDBhrZXlzdG9uZS5jbG91ZC5pcG5ldHQuc2UwggEiMA0GCSqGSIb3\n            DQEBAQUAA4IBDwAwggEKAoIBAQDGnD+EKpJL8J0QoU726uut/Q/BNlsof72ivhqq\n            kdZDAw8j9C3ILzECplWYjxXR/gO5p1J5plcFqv4/M3q3P3zuiWCETvUA7Ha1cTwI\n            XU+33LqnnYp2SzICl1RfdHYuLSx2kYLhdvaPiOpZJvb6v2WEmcAx0gbEpgHjz3fh\n            Qm572sEksRGZ05Cr+STSicbqWgjEljGonlQWgpyYeLf6MWGg54Z4xWlJXbFk8kG/\n            fuoib7GajfM3qPBa/rv81GBZTPl/6n8NTwHXSRF2ma5+204oZJy2CjW0YJnZW8qB\n            kMGD0bwFBcB8Oh2wjwPF0+bIuVBO4vszUYGsEZB113tAooAhAgMBAAGjUDBOMB0G\n            A1UdDgQWBBTHAWptkTT/t84Tjn28cbnZb/7ZyTAfBgNVHSMEGDAWgBTHAWptkTT/\n            t84Tjn28cbnZb/7ZyTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQA6\n            SRQk0fw4o2f5u0vy3YAu1Zmr1bFCOlG1b4wnWXd6J1j1duHDIE7aWgTdT6bMCU7X\n            AAByaVmYOgzps+38kw27j1EE9CpIvQed6RWD5kDUU5rdpYNfKRvA1+sy62h3qMK4\n            e0Yfo1t7WRG1pz7FWz324PR3mAmXDbhrs47zan0m+Ds7VpI+n4SMKNHzqnMrKDe3\n            HVifjPaoea6SwMrPfuVQPxlwJh1XmtYybkqozmo6RB8Mkt/feN+YUXt9G2Rd5xfr\n            N86EdmlYTjlxDf9XzhXt2xyKO5YsNIv6sgPnGTxZC6/rzx8NYUbfXfFh4HUDEtbY\n            TA50ga7htHv63FhyREun"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://keystone.cloud.ipnett.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "IPnett Cloud Services OpenStack"
                },
                {
                  "lang": "sv",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "IPnett Cloud Services OpenStack"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cafe.ufpa.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hugo Pereira Kuribayashi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "hugok@ufpa.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.ufpa.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDcDCCAlgCAQAwDQYJKoZIhvcNAQEFBQAwfjENMAsGA1UEChMEVUZQQTENMAsG\nA1UECxMEQ1RJQzEbMBkGCSqGSIb3DQEJARYMY3RpY0B1ZnBhLmJyMQ4wDAYDVQQH\nEwVCRUxFTTENMAsGA1UECBMEUEFSQTELMAkGA1UEBhMCQlIxFTATBgNVBAMTDGNh\nZmUudWZwYS5icjAeFw0xNDExMDYxNDEzMzZaFw0xOTExMDUxNDEzMzZaMH4xDTAL\nBgNVBAoTBFVGUEExDTALBgNVBAsTBENUSUMxGzAZBgkqhkiG9w0BCQEWDGN0aWNA\ndWZwYS5icjEOMAwGA1UEBxMFQkVMRU0xDTALBgNVBAgTBFBBUkExCzAJBgNVBAYT\nAkJSMRUwEwYDVQQDEwxjYWZlLnVmcGEuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQC9YBhCGCvghJfWlbqNqPAes/VvzKs2G7FQMPeeI0rvzgn6Dzyd\nwsexq07Cj1adg4lR80t/0lcQl2gfahCJMOlTcYMNvmeNhsxsq2VwsOI73mRmedlk\njIPHPu8fpE69FV4nldafKWRSLfcVkWzMSB48BeM7NQQjC0MYwbaAfRSi49fq/cPo\n25kOXGI8a78fpTkCINthiC6fbicq9ztjNq8ni6WnNvde+zM+VKxgefk3OD+i8du9\ndAR2GzwPz7Qy547kUjen/6TrN1dYJt/sQ6+3MnEabD9YsMrlrg5zUoGuhYzaZRp9\nPtjmo3OSUGCd6EIIAL89MJV9N2y1EFls2it5AgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBADjRSj+Wn2mBFAy4zYySVRu4C/hoSsO0954xKdrC6MUpWpz1E2R5CVps3dla\nCLZfsN8lAQuXsesz6tIWg3s/S/gxPcfDmyqpk/3QfQyRwFoBI0+vaolLJKuNRfUg\nTxuvnSG9eNxT+gVi4jVGq/VFMCqhNPXJPtIwLi+fFD3hDpf5kbGd0RxE55qgAvVk\nDyX8GBnEN1DrO9/fx9eVMtL4XZqhmi8+N7xzrR/ENvinmOcoBP+/MJBJbKXVogrk\nq+cyRSqYY5v1CHb8m6yXbvjEK/8d7eBqOk3DsqQDQqbAVvUwucunh1X4KE6c7/HR\nJgmG8SX7B3mxxMyusl3faqQlYgk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufpa.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.ufpa.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.ufpa.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.ufpa.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.ufpa.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.ufpa.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.ufpa.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.ufpa.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.ufpa.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufpa.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufpa.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufpa.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFPA - Universidade Federal do Para"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFPA - Universidade Federal do Para"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFPA - Universidade Federal do Para"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFPA - Universidade Federal do Para"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDcDCCAlgCAQAwDQYJKoZIhvcNAQEFBQAwfjENMAsGA1UEChMEVUZQQTENMAsG\nA1UECxMEQ1RJQzEbMBkGCSqGSIb3DQEJARYMY3RpY0B1ZnBhLmJyMQ4wDAYDVQQH\nEwVCRUxFTTENMAsGA1UECBMEUEFSQTELMAkGA1UEBhMCQlIxFTATBgNVBAMTDGNh\nZmUudWZwYS5icjAeFw0xNDExMDYxNDEzMzZaFw0xOTExMDUxNDEzMzZaMH4xDTAL\nBgNVBAoTBFVGUEExDTALBgNVBAsTBENUSUMxGzAZBgkqhkiG9w0BCQEWDGN0aWNA\ndWZwYS5icjEOMAwGA1UEBxMFQkVMRU0xDTALBgNVBAgTBFBBUkExCzAJBgNVBAYT\nAkJSMRUwEwYDVQQDEwxjYWZlLnVmcGEuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQC9YBhCGCvghJfWlbqNqPAes/VvzKs2G7FQMPeeI0rvzgn6Dzyd\nwsexq07Cj1adg4lR80t/0lcQl2gfahCJMOlTcYMNvmeNhsxsq2VwsOI73mRmedlk\njIPHPu8fpE69FV4nldafKWRSLfcVkWzMSB48BeM7NQQjC0MYwbaAfRSi49fq/cPo\n25kOXGI8a78fpTkCINthiC6fbicq9ztjNq8ni6WnNvde+zM+VKxgefk3OD+i8du9\ndAR2GzwPz7Qy547kUjen/6TrN1dYJt/sQ6+3MnEabD9YsMrlrg5zUoGuhYzaZRp9\nPtjmo3OSUGCd6EIIAL89MJV9N2y1EFls2it5AgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBADjRSj+Wn2mBFAy4zYySVRu4C/hoSsO0954xKdrC6MUpWpz1E2R5CVps3dla\nCLZfsN8lAQuXsesz6tIWg3s/S/gxPcfDmyqpk/3QfQyRwFoBI0+vaolLJKuNRfUg\nTxuvnSG9eNxT+gVi4jVGq/VFMCqhNPXJPtIwLi+fFD3hDpf5kbGd0RxE55qgAvVk\nDyX8GBnEN1DrO9/fx9eVMtL4XZqhmi8+N7xzrR/ENvinmOcoBP+/MJBJbKXVogrk\nq+cyRSqYY5v1CHb8m6yXbvjEK/8d7eBqOk3DsqQDQqbAVvUwucunh1X4KE6c7/HR\nJgmG8SX7B3mxxMyusl3faqQlYgk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFPA - Universidade Federal do Para"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFPA - Universidade Federal do Para"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufpa.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufpa.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFPA - Universidade Federal do Para"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFPA - Universidade Federal do Para"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://hbidp.hb.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 33 435 4690"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT-avdelningen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it-avdelningen@hb.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University of Bor\u00e5s"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 33 435 4697"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Per-Olof Axelsson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Per-Olof.Axelsson@hb.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University of Bor\u00e5s"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 33 435 4690"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT-avdelningen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it-avdelningen@hb.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University of Bor\u00e5s"
          }
        }
      ],
      "entity_id": "https://hbidp.hb.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfjCCA2agAwIBAgIQQh0tAUo8tbGvjLhvMULUFjANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTA5MTAwMTAwMDAwMFoXDTEyMDkzMDIzNTk1OVowTjELMAkGA1UE\nBhMCU0UxHDAaBgNVBAoME0jDtmdza29sYW4gaSBCb3LDpXMxCzAJBgNVBAsTAklU\nMRQwEgYDVQQDEwtoYmlkcC5oYi5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBANmhPsWXpER8PlBGqHtoR1hsTeLWqTRGhaFm9Vuc57qf7xd328jkwZ3C\ntyBL65rNHYI/EVrsiA5nNAm/NLuPl5Wh8IOztI26XcHgNhYgqe6Tlpw5kN4pn0ME\n+KAMAGKh1PAaKP2E3sHN2k3QdqHU0hesmaFHRAm+9JqcP++Frkdr1WVIcxYniOBa\ndorbeA+Mui3WaMsUm/tkYTOOQ3QCHi2VT9U6JOIVyuyIjX6slHhS2LkCSAKn4sKD\nDUVaeSyTxWrH12Dx/mMd8BfXV8XkjBbDNzfFizxTzHsdrj8K8y9ggGiv5+g1Mmsf\n2ehMfEhN0TNtVLaiw9Br2N7XSLLGuaMCAwEAAaOCAW4wggFqMB8GA1UdIwQYMBaA\nFAy9k2gM896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBRNDaiYtvTh/NO79ufN3n7k\nZx6CjjAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggr\nBgEFBQcDAQYIKwYBBQUHAwIwGAYDVR0gBBEwDzANBgsrBgEEAbIxAQICHTA6BgNV\nHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNT\nTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQu\ndGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRw\nOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAmBgNVHREEHzAdggtoYmlkcC5oYi5zZYIO\ndm0taGJpZHAuaGIuc2UwDQYJKoZIhvcNAQEFBQADggEBACUT4mjeYXLYfWz4oKhH\nou/S52jlhiVtskXArO7Ntxk0Oy6tpSkRYgyBN4NDuaFfS//69Et4kQWfxpe7tS8X\nt2cEEtTRhYhwBpBHCMnixRxcoYyeH60fnHoeCn+w7HmD+ffyRojbtcE86O+7bRTP\nJ2xZfZxoRzyEYBVfLBEcBSOYTQrlIBtZmZS/w4whSQs5ruf5X9Wj7BrFLjo8nnli\nrA6Msf8vaeuR1RNKQFHIx/vX3Aj+s2E4rq+L9O3BDAyfc1vKiNy8LLhlvYUFl9If\nNtlzTU8oxWfErMa+Y2BMXWIALruQgeQrFxbO/k4RoPBHRvCul0uUsxak1IFtfT0x\n9Ks="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hb.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://hbidp.hb.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hbidp.hb.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://hbidp.hb.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hbidp.hb.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://hbidp.hb.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://hbidp.hb.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://hbidp.hb.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hbidp.hb.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hb.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.hb.se/Om-hogskolan/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.hb.se/en/About-UB/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r anst\u00e4llda och studenter vid H\u00f6gskolan i Bor\u00e5s."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for employees and students at Bor\u00e5s University."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.hb.se//PageFiles/41206/HBloggaSwamid.gif",
                    "height": "90",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  },
                  {
                    "text": "https://www.hb.se//PageFiles/41206/HBloggaSwamid.gif",
                    "lang": "sv",
                    "height": "90",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "H\u00f6gskolan i Bor\u00e5s"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Bor\u00e5s"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "hb.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:57.724368,12.939918"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.168.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.169.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.170.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.171.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.172.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.173.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.174.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.175.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.245.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.246.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.247.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.11.64.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.11.65.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.11.66.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.11.67.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.11.68.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.11.69.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.11.70.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.11.71.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.11.72.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.11.73.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfjCCA2agAwIBAgIQQh0tAUo8tbGvjLhvMULUFjANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTA5MTAwMTAwMDAwMFoXDTEyMDkzMDIzNTk1OVowTjELMAkGA1UE\nBhMCU0UxHDAaBgNVBAoME0jDtmdza29sYW4gaSBCb3LDpXMxCzAJBgNVBAsTAklU\nMRQwEgYDVQQDEwtoYmlkcC5oYi5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBANmhPsWXpER8PlBGqHtoR1hsTeLWqTRGhaFm9Vuc57qf7xd328jkwZ3C\ntyBL65rNHYI/EVrsiA5nNAm/NLuPl5Wh8IOztI26XcHgNhYgqe6Tlpw5kN4pn0ME\n+KAMAGKh1PAaKP2E3sHN2k3QdqHU0hesmaFHRAm+9JqcP++Frkdr1WVIcxYniOBa\ndorbeA+Mui3WaMsUm/tkYTOOQ3QCHi2VT9U6JOIVyuyIjX6slHhS2LkCSAKn4sKD\nDUVaeSyTxWrH12Dx/mMd8BfXV8XkjBbDNzfFizxTzHsdrj8K8y9ggGiv5+g1Mmsf\n2ehMfEhN0TNtVLaiw9Br2N7XSLLGuaMCAwEAAaOCAW4wggFqMB8GA1UdIwQYMBaA\nFAy9k2gM896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBRNDaiYtvTh/NO79ufN3n7k\nZx6CjjAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggr\nBgEFBQcDAQYIKwYBBQUHAwIwGAYDVR0gBBEwDzANBgsrBgEEAbIxAQICHTA6BgNV\nHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNT\nTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQu\ndGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRw\nOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAmBgNVHREEHzAdggtoYmlkcC5oYi5zZYIO\ndm0taGJpZHAuaGIuc2UwDQYJKoZIhvcNAQEFBQADggEBACUT4mjeYXLYfWz4oKhH\nou/S52jlhiVtskXArO7Ntxk0Oy6tpSkRYgyBN4NDuaFfS//69Et4kQWfxpe7tS8X\nt2cEEtTRhYhwBpBHCMnixRxcoYyeH60fnHoeCn+w7HmD+ffyRojbtcE86O+7bRTP\nJ2xZfZxoRzyEYBVfLBEcBSOYTQrlIBtZmZS/w4whSQs5ruf5X9Wj7BrFLjo8nnli\nrA6Msf8vaeuR1RNKQFHIx/vX3Aj+s2E4rq+L9O3BDAyfc1vKiNy8LLhlvYUFl9If\nNtlzTU8oxWfErMa+Y2BMXWIALruQgeQrFxbO/k4RoPBHRvCul0uUsxak1IFtfT0x\n9Ks="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "H\u00f6gskolan i Bor\u00e5s"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Bor\u00e5s"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hb.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HB"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.turnitin.com/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://shibboleth.turnitin.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.turnitin.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.turnitin.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.turnitin.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.turnitin.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.turnitin.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "authn_requests_signed": "1",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.turnitin.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth.turnitin.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.turnitin.com/Shibboleth.sso/WAYF/HAKA",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth.turnitin.com/Shibboleth.sso/WAYF/HAKA",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.turnitin.com/Shibboleth.sso/WAYF/HAKATEST",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth.turnitin.com/Shibboleth.sso/WAYF/HAKATEST",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.turnitin.com/Shibboleth.sso/WAYF/DFNAAI",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth.turnitin.com/Shibboleth.sso/WAYF/DFNAAI",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "4"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.turnitin.com/Shibboleth.sso/WAYF/DFNAAITEST",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth.turnitin.com/Shibboleth.sso/WAYF/DFNAAITEST",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "5"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.turnitin.com/Shibboleth.sso/WAYF/SWAMID",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth.turnitin.com/Shibboleth.sso/WAYF/SWAMID",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "6"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Verktyg f\u00f6r att hj\u00e4lpa examinatorer att uppt\u00e4cka plagiat och st\u00f6dja studenter i deras uppsatsarbete"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Tools to allow instructors to identify unoriginal content, ensure proper attribution and provide feedback on written assignments"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Turnitin"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Turnitin"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shibboleth.turnitin.com"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID1DCCArwCCQC+3npDDe+fTjANBgkqhkiG9w0BAQUFADCBqzELMAkGA1UEBhMC\nVVMxEzARBgNVBAgMCkNhbGlmb3JuaWExEDAOBgNVBAcMB09ha2xhbmQxGDAWBgNV\nBAoMD2lQYXJhZGlnbXMsIExMQzERMA8GA1UECwwIVHVybml0aW4xIDAeBgNVBAMM\nF3NoaWJib2xldGgudHVybml0aW4uY29tMSYwJAYJKoZIhvcNAQkBFhdzaGliLWFk\nbWluQHR1cm5pdGluLmNvbTAeFw0xMzA1MzAxODI4MjNaFw0xODA1MzAxODI4MjNa\nMIGrMQswCQYDVQQGEwJVUzETMBEGA1UECAwKQ2FsaWZvcm5pYTEQMA4GA1UEBwwH\nT2FrbGFuZDEYMBYGA1UECgwPaVBhcmFkaWdtcywgTExDMREwDwYDVQQLDAhUdXJu\naXRpbjEgMB4GA1UEAwwXc2hpYmJvbGV0aC50dXJuaXRpbi5jb20xJjAkBgkqhkiG\n9w0BCQEWF3NoaWItYWRtaW5AdHVybml0aW4uY29tMIIBIjANBgkqhkiG9w0BAQEF\nAAOCAQ8AMIIBCgKCAQEAo1MWMXiaOvXPRs1N+yjpPsVb++YldXkD5EbwPwA9hZO1\nnI2uyuCG+qqDkZ2Oj0v+9n9FSiYR+Y25Y1VPECqGhkLzpC/5qSKrMZBzsh8ne/U3\nc2UJM/fS73zaX6eIyFlJ5lnort2yz63xYiTZr0nXmGaRsKml4MFofapGwwA+bwPt\nYZ3Ho13R7xM7/qrORHKcumb+xrLHO7a5JKuPPzzPh/iCtZ4DsQ8sgy+lMo22nGwo\nNnp1ITDXCci+XGumZeBhUA2ZRq97eqEAlJDeWsizGCFUfsRjZTtC2pU5LS9l1pPL\n0JAJ1zNm5kc7wAQVus+cbjXL2XGjPlVK8tqAKz6I8QIDAQABMA0GCSqGSIb3DQEB\nBQUAA4IBAQBcPSoo0yib9CQb/A0KIjqlHzDggMYm8xBBT/VHUB9KTUUuKIYWcEy8\nwTvIHbA43qGM/AWQ8ZDLZNJNSZlkylg8ItO+JH0YA9DGwo6LJ7mF+yS88bxQvDqd\nynqfNUUqSG0t9WHNzAdAKsZwkuPCaqur6irEds/70OhMOJgC/cGGU+9ZnybkIEdS\nHxOByoTCtRF0Lo/Ub77kUZcJwALWsGmuuXknptLjlQeIANpv4v47KzhO/X/Er03r\nalLzLitEoGPhcGTB2IefAy4BD3gsF/OXLWwz1p3lx0NWfd69JG+i7esvgEN7eZ7b\nFfnY7V5wsSpLdk49lCnffBRVtwzF0tzt"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=shib-admin@turnitin.com,CN=shibboleth.turnitin.com,OU=Turnitin,O=iParadigms\\, LLC,L=Oakland,ST=California,C=US"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.turnitin.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.turnitin.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.turnitin.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth.turnitin.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.turnitin.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.turnitin.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol"
        }
      ]
    }
  ],
  [
    "https://sp.silverchair.com/acp/staging/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ShibbolethAdmin@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Laseter"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jlaseter@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Josh"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.silverchair.com/acp/staging/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-04-12T09:28:44Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Silverchair Staging: Annals of Internal Medicine"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://annals.acprc.silverchair.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Silverchair Science + Communications, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://annals.acprc.silverchair.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://annals.acprc.silverchair.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://annals.acprc.silverchair.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://annals.acprc.silverchair.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://annals.acprc.silverchair.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://annals.acprc.silverchair.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTjCCAjagAwIBAgIJAJZHv95563KvMA0GCSqGSIb3DQEBBQUAMCcxJTAjBgNV\n\t\t\t\t\t\tBAMTHGFubmFscy5hY3ByYy5zaWx2ZXJjaGFpci5jb20wHhcNMTUwNzE0MjEwNDA0\n\t\t\t\t\t\tWhcNMjAwNzEyMjEwNDA0WjAnMSUwIwYDVQQDExxhbm5hbHMuYWNwcmMuc2lsdmVy\n\t\t\t\t\t\tY2hhaXIuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAx3gcRS/n\n\t\t\t\t\t\tKEJ7E1rnbpEr5bFNSLH05dYeJw8gO5qvgZWS8kEK742uRAy/BDEytNNGru6Kgn2T\n\t\t\t\t\t\tOKAUXFjqYhpUMZD0dvdrkuIBRLsluyWqHNFKNV2kfxdn2P0Ku5DWrhDERcVjsBCV\n\t\t\t\t\t\tDV2ZFuLSXUjO//Tf4U3hddnQAmDY+DHzn5JVQc2qxAcm3SauHllpdf2D3ml5jt0C\n\t\t\t\t\t\tJJ2HjzLe7RjWsB2ZcdfTx53YoBjHs8fQ//a9XueczEEnGLee6KWoOafmJtNUaNJw\n\t\t\t\t\t\tLUJKMqQ0cwkDGO9+GHXIUv0UZaQqJzOEpassE6pnDWF+lU0QLiKEhLWb4t/raYb5\n\t\t\t\t\t\tFNw5MX7Dh1KflQIDAQABo30wezBaBgNVHREEUzBRghxhbm5hbHMuYWNwcmMuc2ls\n\t\t\t\t\t\tdmVyY2hhaXIuY29thjFodHRwczovL3NwLnNpbHZlcmNoYWlyLmNvbS9hY3Avc3Rh\n\t\t\t\t\t\tZ2luZy9zaGliYm9sZXRoMB0GA1UdDgQWBBTR5Oq0DmD770Dj6nz8AVhHW7M+1DAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEANTzhu7oiv6sPVeLQJIurSMlWUlVdslHfKtHITuUq\n\t\t\t\t\t\trJr2V7ENZqiP96ZExF6rd6gfnrQJW0j0Qlpa3BBmoY1mXKf9ptnU3CeEFF772AL6\n\t\t\t\t\t\tXqUH7G/qwYzxoybsQSMvcmvnwJtDXJ7/7UElzdnnIOEemewIvWr/JP9uKT4I7QpM\n\t\t\t\t\t\tH9FxsfFwkiIaC1tljcEjmtmNBqep8/5k9bTY78/FhI2VBWViA9G9SjW/wsTHg2n7\n\t\t\t\t\t\tyd73sCRREx9PLTR9xwaFTXd3sUKa9twF2Mcelv+YMQ54jDLMYMXYE7sQQAmCJntA\n\t\t\t\t\t\tXHPzjiDW9qkSn90k3YhY8pW1gd59mGKAZUiC+cQFhlnRFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://annals.acprc.silverchair.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://annals.acprc.silverchair.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://annals.acprc.silverchair.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://annals.acprc.silverchair.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://annals.acprc.silverchair.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://annals.acprc.silverchair.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://federation2.univ-brest.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "federation@univ-brest.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federation2.univ-brest.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-06-26T15:36:06Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation2.univ-brest.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federation2.univ-brest.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://federation2.univ-brest.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-brest.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-brest.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Bretagne Occidentale"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Bretagne Occidentale"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTzCCAjegAwIBAgIUbLNw35nuqDWZoyy6h3P4LlkzPIAwDQYJKoZIhvcNAQEF\nBQAwJDEiMCAGA1UEAxMZZmVkZXJhdGlvbjIudW5pdi1icmVzdC5mcjAeFw0xMzAz\nMTIyMTE1MDVaFw0zMzAzMTIyMTE1MDVaMCQxIjAgBgNVBAMTGWZlZGVyYXRpb24y\nLnVuaXYtYnJlc3QuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCe\nkMm2n9YaUsOi8wAXfTnfE7/jehc3Mnc5UP4iR2A9mTF6fZc025FTK/O5O3lEowUh\nFCT8cD2sYjRm+hX+G8qqKDM6zPkvq2IOB5T9WxOMi/M7oaXrhnDUieoc0Bf72R9W\nQ/yBigsLVTCCxFP/qf6lsqpgtaZgQXm9Js4AuHKvcrxoZgJvmwH7r8ON0uJrP2rJ\nfUEgNYsCYx/R3yogLteMYKS01YUSmL0Q6rVUyZRC3VmU8bWJENBNkKhdUfP4dW0w\neXR6heUDqvoP3xJzpsH0o6bGXYa684T3rbWWt0Kpc1mQVsmTWsxwZMaSrMiPH9OW\nW0J8sZuQjLzex1XcuAjVAgMBAAGjeTB3MFYGA1UdEQRPME2CGWZlZGVyYXRpb24y\nLnVuaXYtYnJlc3QuZnKGMGh0dHBzOi8vZmVkZXJhdGlvbjIudW5pdi1icmVzdC5m\nci9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUOemOV1cIWomxjeTIq5jtpWN1HEow\nDQYJKoZIhvcNAQEFBQADggEBAD/ZBa+xOskPywe5pYfAusdeil2y0z7Nhse5HcnJ\nOdjkk3n1qeYUE7agiStMzh2i2I4VY2WM5/vmhodmdIn4hYcDpWz8PSj+uLcVBcQO\nczrADiucBs72+PSEYiaOjrEQZOkLuyszWEWLkwID6n8e4nbJoK2NNf5ujIqm9C2s\n2RHyJVXxVHUczOR/0hnZtc2fyrRY5281u6Caenoxgoed88E4ua7FSnzjZnnBb0+T\nYvneR/KwwVHLp54Fg5QDQlLHbcDX3O+H59/Jmi2dRUgl7+SdCyug2APyBTWvNI6K\nV6haQaNennUWPfKNVUx9kRADhvU84XK1fH8ynIIBY7o3zIg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTzCCAjegAwIBAgIUcGVhc58lBOziviLuEFA04RVPhjAwDQYJKoZIhvcNAQEF\nBQAwJDEiMCAGA1UEAxMZZmVkZXJhdGlvbjIudW5pdi1icmVzdC5mcjAeFw0wOTAy\nMDUxMTUxNDFaFw0yOTAyMDUxMTUxNDFaMCQxIjAgBgNVBAMTGWZlZGVyYXRpb24y\nLnVuaXYtYnJlc3QuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCW\nRzPe3Vq2lpziOaEyUzKIEfjZXr23PfYVy/rwvT64y+Zk+eKNvgjWHMpSqbuX7nqx\n/2q5G/mox/pk1xaG0iZlsVu97qoUlSJ+POQCp8dAIJNKYpP/vFGUW1RTdE9vzACT\nU8NRNgZz1Df1e/SwwDUyFOfU58xEgsSUhgxc1skKCvJSpkTH8aDavnVvbKGv08Dr\ncjvKakemcoPeil5fV40/REHDGHHLtFgE/k8wHIvtRxw+UZ3qF/Pwss1Yvszph5aU\nb2f/nP9KL6cCIwomwrJYZcQ/llP+ksuwjum6m0V/H0wQYL+EkebIFh1M055RdpAP\nilBFaCiL5geQo0RSBrqhAgMBAAGjeTB3MFYGA1UdEQRPME2CGWZlZGVyYXRpb24y\nLnVuaXYtYnJlc3QuZnKGMGh0dHBzOi8vZmVkZXJhdGlvbjIudW5pdi1icmVzdC5m\nci9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUbnsYQCi+qnK7dB3sTYe7ArIKwlQw\nDQYJKoZIhvcNAQEFBQADggEBAIHQBrg0VjCQ1ApOWOBpOVDujQHG7/+oazQ/kJWA\nYxWZCLCzg5yW74ut1rxxwYlSN/c3ZYU5paZRUeok61SiCNs0ggzqEy6pYt4yJqCu\ngdmhUHokWFzxzReL34u+XCXzZjd/g52B3DDvHU8OLKzOqc7EXppiuFLh2hRjffjX\nXIZgjVVgHmtDcih29YmV+LcRlQrHpze8o976ovyXcM/katGaUei8OHAy8LJh7cvu\n9Xvuti2J+axxQXdzeUa4KIQ8Gi7EUEEwQ5PVGE/T0AP/fSWlCHuQWk+y9wESI1NL\ndZkkc0h92MuezOhzNpM1FfXU/7Zb8eYTeQZbOUQhqiLTogg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Bretagne Occidentale"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-brest.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Bretagne Occidentale"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.dijon.iufm.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bourdin Jean-Michel"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jean-michel.bourdin@dijon.iufm.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.dijon.iufm.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-01-28T12:03:39Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.dijon.iufm.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.dijon.iufm.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.dijon.iufm.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dijon.iufm.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.dijon.iufm.fr"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ESPE de Bourgogne - Dpt MEEF"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ESPE de Bourgogne - Dpt MEEF"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAPJxU6vXRtyZ2B8/iZhhakdOe/SBMA0GCSqGSIb3DQEB\nBQUAMBwxGjAYBgNVBAMTEWRpcC5kaWpvbi5pdWZtLmZyMB4XDTEyMTAzMTA5MDYz\nOVoXDTMyMTAzMTA5MDYzOVowHDEaMBgGA1UEAxMRZGlwLmRpam9uLml1Zm0uZnIw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDQ2TDr3Xoz5TBEKdyL3ZSS\noWgPsLaId+qegB3aYnBcLK9/Oge/K8WThAVVAUSX7A/FyFrZdeQBR9HpUqaOb2p3\nUE0MHs0w3h80vQ3btvM4ag6ZxakEZh066VxgSb6bRAD4G1kmwDUbXl/Hm+pypx7O\nkndJYVDWke+M8Y9Hqvjl9F0ZLH58HPwtCwN3Gg9IGfbiSMtvLLZoHfifSc6O2m0R\nkHDGg4LMqbhNoFo2Z9VTwqV/7dd2qy+4+11C0Sd9v9vzdRCB5MawK40ARyhhwwFE\nWoqxXKmndbh+rnvCDZadM0jT3A9QuUm6/PVVhaXnMXGAlm97EWtP+CL8/AdFCm3f\nAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEWRpcC5kaWpvbi5pdWZtLmZyhihodHRwczov\nL2RpcC5kaWpvbi5pdWZtLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBT1MxRC\nyvoAAjqWbajuVCCe5OQ2OjANBgkqhkiG9w0BAQUFAAOCAQEAiewYRJ5OUQoPEThR\n5JKesIDaeCUz9QoGBsRPUVGudb2FiuKp+iKVLPXZ9CuRidg6ZDk0ejXQjThk/Xaz\nscNJ39+zbOBNqE+v7XhYsCLSG/3DhrfTWz4XosuqKojH9ZwXsBhQqB1Rk/Vebr50\nIUHP0I8OQKilNbv7IYx3eduXIVAicsVOW5DaWYZBQJ2zFa+9we5ZBMeZ/Lq6DkGC\nYpPfDGEAblTPzFEiMw7TlhPvLehjCzmBggW8fG061FZ8J2rBeOzBlTNBRMqekUaf\nV5IHw211pa1xInH+EzE4//vuvfemALnv0wPbbvUbroFeb/qqwNMZP22D9p2r+s9J\n27C2qA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ESPE de Bourgogne - Dpt MEEF"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dijon.iufm.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ESPE de Bourgogne - Dpt MEEF"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.uxbridge.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Abdulaziz"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:MAbdulaz@uxbridgecollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mohammed"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uxbridge.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-02-15T15:33:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUZwOkMlPz3cSvnZG/flZHZc+acwkwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHTEbMBkGA1UEAwwSaWRwLnV4YnJpZGdlLmFjLnVrMB4XDTE1MDEyNjA5MTYw\n\t\t\t\t\t\tOVoXDTM1MDEyNjA5MTYwOVowHTEbMBkGA1UEAwwSaWRwLnV4YnJpZGdlLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnsE3nHinfWPqK7JfCUdq\n\t\t\t\t\t\tq4o5aiqFt6lXkXVsFQLbSHfIz3Cf2kgndwqULQnSyBlyELbUVktdFQuHfve+qKJb\n\t\t\t\t\t\thnYGFMbOpIqAHnlvc2LfhsZ1+H/C/B9gnzhjRVdgSEsG71R6GtidFmuRQeFvqTkg\n\t\t\t\t\t\tx+rtlgva2Iz2ZFE2n3dN9Fw+gNaqHfL3GEFewIECHuTdhbn/dJTXnogBZR+RQ/u1\n\t\t\t\t\t\txTyuOM2IYyULmwiDb5X6koX0O/5yC/Pgj/vQ+7A4ZSKmpFYtF1d3PXLJ5x5pPlm1\n\t\t\t\t\t\ttw6MNivuAe8V+6IZeEOdZsM3NosiBLFiA0YsFdqXzPNFqVt7hFURH3KbqciMur5T\n\t\t\t\t\t\t+QIDAQABo2swaTAdBgNVHQ4EFgQUiUoY92tgFoq4JqVfu9gSJmdlXS4wSAYDVR0R\n\t\t\t\t\t\tBEEwP4ISaWRwLnV4YnJpZGdlLmFjLnVrhilodHRwczovL2lkcC51eGJyaWRnZS5h\n\t\t\t\t\t\tYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAA7+wTS76kWJq\n\t\t\t\t\t\tXgjsoyeCqrxQrSIwx6eL4QKQvgAVv8QuvXbAf4LeX+70pMY5iZ67ZEN8U/Hukq/J\n\t\t\t\t\t\tgya6DSiAFPViTJnACZMXFRogS1EkC+kLG1dcPPmqY2tweg6SDsMTwHOB9WbaAt+Q\n\t\t\t\t\t\tiNwQfBjlaEFHfPE6lo+C3rWEScABiHn0V6FWODuUxTqPaFwPIvM2insjUAWGM62U\n\t\t\t\t\t\tAa488QsFI+qKCnntrvZcoEAyWmG/d5i/jK8MohytrC1khQ56VlYVFlXG2/05m3Bq\n\t\t\t\t\t\taZniFfgK4PHqWDyOTMlF9wG5JNuzVb4CP04ptQZXiKBtMgnfpmlTyfimiGM/Jn2E\n\t\t\t\t\t\tldckhs6TCQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uxbridge.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uxbridge.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uxbridge.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.uxbridge.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uxbridge.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.uxbridge.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uxbridge.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uxbridge.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uxbridge.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uxbridge.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUZwOkMlPz3cSvnZG/flZHZc+acwkwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHTEbMBkGA1UEAwwSaWRwLnV4YnJpZGdlLmFjLnVrMB4XDTE1MDEyNjA5MTYw\n\t\t\t\t\t\tOVoXDTM1MDEyNjA5MTYwOVowHTEbMBkGA1UEAwwSaWRwLnV4YnJpZGdlLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnsE3nHinfWPqK7JfCUdq\n\t\t\t\t\t\tq4o5aiqFt6lXkXVsFQLbSHfIz3Cf2kgndwqULQnSyBlyELbUVktdFQuHfve+qKJb\n\t\t\t\t\t\thnYGFMbOpIqAHnlvc2LfhsZ1+H/C/B9gnzhjRVdgSEsG71R6GtidFmuRQeFvqTkg\n\t\t\t\t\t\tx+rtlgva2Iz2ZFE2n3dN9Fw+gNaqHfL3GEFewIECHuTdhbn/dJTXnogBZR+RQ/u1\n\t\t\t\t\t\txTyuOM2IYyULmwiDb5X6koX0O/5yC/Pgj/vQ+7A4ZSKmpFYtF1d3PXLJ5x5pPlm1\n\t\t\t\t\t\ttw6MNivuAe8V+6IZeEOdZsM3NosiBLFiA0YsFdqXzPNFqVt7hFURH3KbqciMur5T\n\t\t\t\t\t\t+QIDAQABo2swaTAdBgNVHQ4EFgQUiUoY92tgFoq4JqVfu9gSJmdlXS4wSAYDVR0R\n\t\t\t\t\t\tBEEwP4ISaWRwLnV4YnJpZGdlLmFjLnVrhilodHRwczovL2lkcC51eGJyaWRnZS5h\n\t\t\t\t\t\tYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAA7+wTS76kWJq\n\t\t\t\t\t\tXgjsoyeCqrxQrSIwx6eL4QKQvgAVv8QuvXbAf4LeX+70pMY5iZ67ZEN8U/Hukq/J\n\t\t\t\t\t\tgya6DSiAFPViTJnACZMXFRogS1EkC+kLG1dcPPmqY2tweg6SDsMTwHOB9WbaAt+Q\n\t\t\t\t\t\tiNwQfBjlaEFHfPE6lo+C3rWEScABiHn0V6FWODuUxTqPaFwPIvM2insjUAWGM62U\n\t\t\t\t\t\tAa488QsFI+qKCnntrvZcoEAyWmG/d5i/jK8MohytrC1khQ56VlYVFlXG2/05m3Bq\n\t\t\t\t\t\taZniFfgK4PHqWDyOTMlF9wG5JNuzVb4CP04ptQZXiKBtMgnfpmlTyfimiGM/Jn2E\n\t\t\t\t\t\tldckhs6TCQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Uxbridge College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uxbridge.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Uxbridge College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.hesam.eu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "fed-admin@univ-paris1.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.hesam.eu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-04-22T13:40:54Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.hesam.eu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.hesam.eu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.hesam.eu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hesam.eu"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-paris1.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PRES HESAM - Hautes Etudes-Sorbonne-Arts et M\u00e9tiers"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PRES HESAM - Hautes Etudes-Sorbonne-Arts et M\u00e9tiers"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUcOyBUfV1JWYkzdfbAaltfBkAukQwDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMaWRwLmhlc2FtLmV1MB4XDTEzMDQwNTE2MDMzNloXDTMz\nMDQwNTE2MDMzNlowFzEVMBMGA1UEAxMMaWRwLmhlc2FtLmV1MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAhQP48nRAAh9b78ybhUcTpuXHSXmC2m1hHwqF\nB2jJjgVlHTZTjLa2s95aIgeAt4lwJhlJ7RxZDxj+udG9840FkRAwbvuiufgRmR05\nq+VX2+eejxe1fyP+5XsNA7dUcvCp3wMurRK3f0Z/x3sMEIlh/Nh0pB9fVqwi6TtD\ngyRayTuCFu6wnH1oGhhu6Edrihn4OTJBvUR0vqrg98SY3S1FsYB9OhV03U7vbwfV\nJ9sVPu8vbYkbofXuDPpaKdIMYzFWMNIZnnkZvSBY1C6fa/f4pCmwcVBpOjlEW2fA\n1Zj9cxnu8MIhYY6CVV3d0IVrmvXeK9IprM7ixfME59XVnsy4jQIDAQABo18wXTA8\nBgNVHREENTAzggxpZHAuaGVzYW0uZXWGI2h0dHBzOi8vaWRwLmhlc2FtLmV1L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBRLm+HxjRffot5ojMgT+q8252oBfDANBgkq\nhkiG9w0BAQUFAAOCAQEAg9CezjS15qvJOTpkIEzGHkk2LfKKqbExgWshU8yYPHlo\nWefs+Gdj4NEtJy28RYM59KgPG+KvC6xog3l0ZL1CVIx8Xch1rZDSeNUvgUAvbrPu\nUWNzsjEbT22QkvcbyW1vi3/ZgSJg909nvH2GBqASWokEIT7VC30Un+mrEsffqFuZ\nfJe5PTSZ3SGmR0yPPTVQpLqbYLVdWBhE46JP84qFZlsZomBnoVRlCSURARHgJIcF\nq4+smXBAWAFRltJUEQ7hjQKaNCKApYnAdWReOTEhkMkVZZNqbkFYSSeQ1cxlabLV\n3usSDArcclPgsgS25qfJ4XUmUJadJhyAZIJ9zluU0Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PRES HESAM - Hautes Etudes-Sorbonne-Arts et M\u00e9tiers"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-paris1.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "PRES HESAM - Hautes Etudes-Sorbonne-Arts et M\u00e9tiers"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.sru.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "henry.magusiak@sru.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Henry Magusiak"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.sru.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sru.edu:9443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sru.edu:9443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUjCCAjoCCQC4QuY3Kem21zANBgkqhkiG9w0BAQUFADBrMRQwEgYDVQQDDAtp\nZHAuc3J1LmVkdTEhMB8GA1UECgwYU2xpcHBlcnkgUm9jayBVbml2ZXJzaXR5MQsw\nCQYDVQQGEwJVUzELMAkGA1UECAwCUEExFjAUBgNVBAcMDVNsaXBwZXJ5IFJvY2sw\nHhcNMTMwNTExMTYyMjI2WhcNMTQwNTExMTYyMjI2WjBrMRQwEgYDVQQDDAtpZHAu\nc3J1LmVkdTEhMB8GA1UECgwYU2xpcHBlcnkgUm9jayBVbml2ZXJzaXR5MQswCQYD\nVQQGEwJVUzELMAkGA1UECAwCUEExFjAUBgNVBAcMDVNsaXBwZXJ5IFJvY2swggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQD3fFM/uu4LyqEZLgqHRAtVSfxK\nMdzmk5oQymQ+3wDlfZhZ4U37eJKxrUIQpJrYMpPaGavLqllWfT+YpAqai1L28W32\nWdhb3t4soeMZ0SqpDdwOjwhpi5BumTgxxehR0wTbnM1mce7Dcm97chv7S+6g00G+\nJracU4eavR5HYAe1VBCyL4pikCUAumgMTXClY/uUoIRQ8i53Apx3gAm1Yt5K+eiu\ngY78ImJS67uprvTsBn7jb3pUFhjMRVxhMhmZuYjapGraZn1TRtmDOjM6gJd5B7IS\nO/5e8sK6Pl1E2+z+R0ti7I/hsR0eZ4He4yMoCdFqqybaHHvANEfl6NFb97fZAgMB\nAAEwDQYJKoZIhvcNAQEFBQADggEBALgr/gAqImcBgGUln30vP7I7uCU9iyw/wZBr\nw4Kr5hszYbfoKk/UCpc84eyF2HOk4yfv5GJX7rcKbsz0frWSMt21LDLAytWrLktN\nlgJNjFcB0Sq5hCpIZ/nDbEveFJGw820KK4T1429H1WAzahf/Nu52kZOZC2nVahe4\n5lstrvfFwyPEE49TSKPh3wipsW0UTL262Smps/9tbPImBgVNEYfNHuwujNLuefAY\nFNTCh5GCTEEwP+oWWYizGWNo/1pJmSZZlvj/3d/JoNWbc+q2b3ig6FSTXkonXgdA\n+FrbfgLPw5cs4D4ECPBvlgj6hTbyG7HWRgT9XH6S67PDWvpvpWM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sru.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.sru.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sru.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sru.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.sru.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sru.edu:9443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sru.edu:9443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sru.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Slippery Rock University of Pennsylvania"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Slippery Rock University of Pennsylvania"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUjCCAjoCCQC4QuY3Kem21zANBgkqhkiG9w0BAQUFADBrMRQwEgYDVQQDDAtp\nZHAuc3J1LmVkdTEhMB8GA1UECgwYU2xpcHBlcnkgUm9jayBVbml2ZXJzaXR5MQsw\nCQYDVQQGEwJVUzELMAkGA1UECAwCUEExFjAUBgNVBAcMDVNsaXBwZXJ5IFJvY2sw\nHhcNMTMwNTExMTYyMjI2WhcNMTQwNTExMTYyMjI2WjBrMRQwEgYDVQQDDAtpZHAu\nc3J1LmVkdTEhMB8GA1UECgwYU2xpcHBlcnkgUm9jayBVbml2ZXJzaXR5MQswCQYD\nVQQGEwJVUzELMAkGA1UECAwCUEExFjAUBgNVBAcMDVNsaXBwZXJ5IFJvY2swggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQD3fFM/uu4LyqEZLgqHRAtVSfxK\nMdzmk5oQymQ+3wDlfZhZ4U37eJKxrUIQpJrYMpPaGavLqllWfT+YpAqai1L28W32\nWdhb3t4soeMZ0SqpDdwOjwhpi5BumTgxxehR0wTbnM1mce7Dcm97chv7S+6g00G+\nJracU4eavR5HYAe1VBCyL4pikCUAumgMTXClY/uUoIRQ8i53Apx3gAm1Yt5K+eiu\ngY78ImJS67uprvTsBn7jb3pUFhjMRVxhMhmZuYjapGraZn1TRtmDOjM6gJd5B7IS\nO/5e8sK6Pl1E2+z+R0ti7I/hsR0eZ4He4yMoCdFqqybaHHvANEfl6NFb97fZAgMB\nAAEwDQYJKoZIhvcNAQEFBQADggEBALgr/gAqImcBgGUln30vP7I7uCU9iyw/wZBr\nw4Kr5hszYbfoKk/UCpc84eyF2HOk4yfv5GJX7rcKbsz0frWSMt21LDLAytWrLktN\nlgJNjFcB0Sq5hCpIZ/nDbEveFJGw820KK4T1429H1WAzahf/Nu52kZOZC2nVahe4\n5lstrvfFwyPEE49TSKPh3wipsW0UTL262Smps/9tbPImBgVNEYfNHuwujNLuefAY\nFNTCh5GCTEEwP+oWWYizGWNo/1pJmSZZlvj/3d/JoNWbc+q2b3ig6FSTXkonXgdA\n+FrbfgLPw5cs4D4ECPBvlgj6hTbyG7HWRgT9XH6S67PDWvpvpWM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idp.sru.edu/identity/feedback.htm"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Slippery Rock University of Pennsylvania"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sru.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Slippery Rock University of Pennsylvania"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://openathens.adults.ccinform.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:CCInformHelpdesk@rbi.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CCInform Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Radjendirane"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:surya.radjendirane@rbi.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Surya"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Stobbs"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Tracey.Stobbs@rbi.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tracey"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hodgkiss"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:katie.hodgkiss@rbi.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Katie"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chauhan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Sonya.Chauhan@rbi.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sonya"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://openathens.adults.ccinform.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-02-10T13:27:17Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CCInform Adults (Shib Test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://adults.ccinform.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Reed Business Information Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Vital information for professionals working with disabled and older people."
                  }
                ],
                "logo": [
                  {
                    "text": "https://s3-eu-west-1.amazonaws.com/rbi-cci/wp-content/uploads/sites/3/2014/07/Adults-logo300.jpg",
                    "height": "82",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "300"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CCInform Adults (Shib Test)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEFTCCAv2gAwIBAgIJAMneSf8qSaB3MA0GCSqGSIb3DQEBBQUAMGQxKDAmBgNV\n\t\t\t\t\t\tBAoTH1JlZWQgQnVzaW5lc3MgSW5mbyAtIFZpcGVyIEJldGExODA2BgNVBAMTL3d3\n\t\t\t\t\t\tdy5vYXNlcnZlci1zc28tYmV0YS5hd3N2aXBlci5yZWVkYnVzaW5lc3MubmV0MB4X\n\t\t\t\t\t\tDTE1MTEyMzE0NTU0MloXDTI1MTEyMDE0NTU0MlowZDEoMCYGA1UEChMfUmVlZCBC\n\t\t\t\t\t\tdXNpbmVzcyBJbmZvIC0gVmlwZXIgQmV0YTE4MDYGA1UEAxMvd3d3Lm9hc2VydmVy\n\t\t\t\t\t\tLXNzby1iZXRhLmF3c3ZpcGVyLnJlZWRidXNpbmVzcy5uZXQwggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDGroeDl0uM+jhIVrqKJFn5okiOAbJw6julPlKK\n\t\t\t\t\t\tpFeGLNyT70aOcsCG0+4utfzsriKAO9fGITmLwt+8ERJe3TPbbWBz6jo678+Avn92\n\t\t\t\t\t\tTzvqvj9KDUk2UHRkR/gzb1Y66smO/k1lxXMVlkW5e6KFn1Zs1NUnSbyGYANPmSjR\n\t\t\t\t\t\t2XcLgxtmQxedpKFj2urFCdi+EpFaszs2cuuBsvZqx4DwcDBsayjePDu2GnKtVF24\n\t\t\t\t\t\trsWxHZMfBtr1KIDQuQDm8MWMzjIB4PHZ3K0dsqCNHg8zjGvu1/N2C3Es5SS5OTip\n\t\t\t\t\t\tweXS7ejveKU2LZTGOelhDho2MTtx8mOMyVslq/PZ1hzplwltAgMBAAGjgckwgcYw\n\t\t\t\t\t\tHQYDVR0OBBYEFMj6G2UwHf8kGxz74rhomi/C1cT4MIGWBgNVHSMEgY4wgYuAFMj6\n\t\t\t\t\t\tG2UwHf8kGxz74rhomi/C1cT4oWikZjBkMSgwJgYDVQQKEx9SZWVkIEJ1c2luZXNz\n\t\t\t\t\t\tIEluZm8gLSBWaXBlciBCZXRhMTgwNgYDVQQDEy93d3cub2FzZXJ2ZXItc3NvLWJl\n\t\t\t\t\t\tdGEuYXdzdmlwZXIucmVlZGJ1c2luZXNzLm5ldIIJAMneSf8qSaB3MAwGA1UdEwQF\n\t\t\t\t\t\tMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAEGnnYllzfUQ483OyFbjm1PUyWCPlEX+\n\t\t\t\t\t\tz82+hODcpmvt9mRuwBierbGgsByUUswK7wc4X50VSH/TCBbaGgav/FAWQZqMUsdG\n\t\t\t\t\t\tiLtDT7xdbnnMVKCBJhBrmo//rfJ4QXscGkQ+gViY+wHJmCjaNAAxxvO25oAEhkFX\n\t\t\t\t\t\tzGoPN2QAM7ue1XuAoG6uDXCJYMh507OXLh1IoF5+ubQOhyhr+yaiXkHp2cfYhxSg\n\t\t\t\t\t\tHs8TX8jAiK1K2BczXNKTKgevn6hpRZbX8AiJuoS49h7j2DgzY3KdW0l6FK8jbZ5G\n\t\t\t\t\t\tPBrPCD2rrGz3T8vnZL3JjkQr2hrxD62QB00hozoykT0RXdAY1S5CbUI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEFTCCAv2gAwIBAgIJAMneSf8qSaB3MA0GCSqGSIb3DQEBBQUAMGQxKDAmBgNV\n\t\t\t\t\t\tBAoTH1JlZWQgQnVzaW5lc3MgSW5mbyAtIFZpcGVyIEJldGExODA2BgNVBAMTL3d3\n\t\t\t\t\t\tdy5vYXNlcnZlci1zc28tYmV0YS5hd3N2aXBlci5yZWVkYnVzaW5lc3MubmV0MB4X\n\t\t\t\t\t\tDTE1MTEyMzE0NTU0MloXDTI1MTEyMDE0NTU0MlowZDEoMCYGA1UEChMfUmVlZCBC\n\t\t\t\t\t\tdXNpbmVzcyBJbmZvIC0gVmlwZXIgQmV0YTE4MDYGA1UEAxMvd3d3Lm9hc2VydmVy\n\t\t\t\t\t\tLXNzby1iZXRhLmF3c3ZpcGVyLnJlZWRidXNpbmVzcy5uZXQwggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDGroeDl0uM+jhIVrqKJFn5okiOAbJw6julPlKK\n\t\t\t\t\t\tpFeGLNyT70aOcsCG0+4utfzsriKAO9fGITmLwt+8ERJe3TPbbWBz6jo678+Avn92\n\t\t\t\t\t\tTzvqvj9KDUk2UHRkR/gzb1Y66smO/k1lxXMVlkW5e6KFn1Zs1NUnSbyGYANPmSjR\n\t\t\t\t\t\t2XcLgxtmQxedpKFj2urFCdi+EpFaszs2cuuBsvZqx4DwcDBsayjePDu2GnKtVF24\n\t\t\t\t\t\trsWxHZMfBtr1KIDQuQDm8MWMzjIB4PHZ3K0dsqCNHg8zjGvu1/N2C3Es5SS5OTip\n\t\t\t\t\t\tweXS7ejveKU2LZTGOelhDho2MTtx8mOMyVslq/PZ1hzplwltAgMBAAGjgckwgcYw\n\t\t\t\t\t\tHQYDVR0OBBYEFMj6G2UwHf8kGxz74rhomi/C1cT4MIGWBgNVHSMEgY4wgYuAFMj6\n\t\t\t\t\t\tG2UwHf8kGxz74rhomi/C1cT4oWikZjBkMSgwJgYDVQQKEx9SZWVkIEJ1c2luZXNz\n\t\t\t\t\t\tIEluZm8gLSBWaXBlciBCZXRhMTgwNgYDVQQDEy93d3cub2FzZXJ2ZXItc3NvLWJl\n\t\t\t\t\t\tdGEuYXdzdmlwZXIucmVlZGJ1c2luZXNzLm5ldIIJAMneSf8qSaB3MAwGA1UdEwQF\n\t\t\t\t\t\tMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAEGnnYllzfUQ483OyFbjm1PUyWCPlEX+\n\t\t\t\t\t\tz82+hODcpmvt9mRuwBierbGgsByUUswK7wc4X50VSH/TCBbaGgav/FAWQZqMUsdG\n\t\t\t\t\t\tiLtDT7xdbnnMVKCBJhBrmo//rfJ4QXscGkQ+gViY+wHJmCjaNAAxxvO25oAEhkFX\n\t\t\t\t\t\tzGoPN2QAM7ue1XuAoG6uDXCJYMh507OXLh1IoF5+ubQOhyhr+yaiXkHp2cfYhxSg\n\t\t\t\t\t\tHs8TX8jAiK1K2BczXNKTKgevn6hpRZbX8AiJuoS49h7j2DgzY3KdW0l6FK8jbZ5G\n\t\t\t\t\t\tPBrPCD2rrGz3T8vnZL3JjkQr2hrxD62QB00hozoykT0RXdAY1S5CbUI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://ccinformadults.sso2-beta.awsviper.reedbusiness.net/sites/ccinformadults/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ccinformadults.sso2-beta.awsviper.reedbusiness.net/sites/ccinformadults/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ccinformadults.sso2-beta.awsviper.reedbusiness.net/sites/ccinformadults/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ccinformadults.sso2-beta.awsviper.reedbusiness.net/sites/ccinformadults/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CCInform Adults (Shib Test)"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Vital information for professionals working with disabled and older people."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonTargetedID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonEntitlement",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-21.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-21.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;21"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;21"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-21.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-21.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAJSSrVoFJ4N4MA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0yMS5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTQ0NDA3WhcNMjQx\nMDA0MTQ0NDA3WjAhMR8wHQYDVQQDExZsYWRvazMtMjEubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApgkSEfWPTzFHUHpcyu8r26CG\n8BU6OCy+8PRhWZJ/xXnuljWLa0VvWdkjMItHDR9VCjtLIK5t5oGbTiqPEsb93anr\nVqcgIPz6AYeo0SXJcpBdFuF3zGyW3yfUfoi6t3g4ikyAsQFKbX7wDg7vyUTKo15S\nVBbREkdmrYFb3JEByjQZjKbZUjsU9U78HjrzE7WCvDK4DDnzgWQg+aN6LHKHvn2H\njZlerYpF30aZKAXGvQh+HHNwBvfd0wE8DgixeMdRpId4/b+BMs2A4Q5dcn1fGcb7\n+JzTXxhHqtL/hiH055IYT3HHo/mTseJqoE3R1uT0FASsl21MYcOpqpnBNAKUZwID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMjEubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0yMS5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUea/KnYVe/DceUeFfUCEnrpCOoukwDQYJKoZIhvcNAQEFBQADggEB\nAJPsk6/BRaaiREtL6YzWQxkC7I8h1yhZpGSFZ2FPemesuLOFREva62qBYTP0IbZV\ntHvM/R/IsLo1yw8C5Mk+GTo3XPzgeTgNvNNUiK8KsKc+nVP0D5HUzodFxuRnu/HU\nFOGMknPKeZHfHe3UZJaXDbTogIp+KUWt4W7xJyVnuLMywXTSy2h52s5H6iFJQBaf\ney5yjTkPrBrnTI/Z7hx9fsYDR8oZb+U5cwz+l8s9bkaPXX9043nzgpgm9A/lma7j\nLSXPvEPTHzAkNoiAXAn5jW9xE3fsWdJs40SdhR1tcZ4LaaaGRvFCk6j+QIXLdjuE\n4KRUNahlmikpWye1rQPSZuo="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-21.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-21.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.mynsu.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.mynsu.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-08-04T08:23:54Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Northumbria Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mynsu.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.mynsu.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.mynsu.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.mynsu.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.mynsu.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.mynsu.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.mynsu.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.mynsu.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.mynsu.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.mynsu.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.mynsu.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.mynsu.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.mynsu.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://srvcafe.uniso.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "William A Oliveira"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "william.oliveira@uniso.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://srvcafe.uniso.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID1jCCAr4CAQAwDQYJKoZIhvcNAQEFBQAwgbAxKTAnBgNVBAoTIFVOSVNPIC0g\nVW5pdmVyc2lkYWRlIGRlIFNvcm9jYWJhMQwwCgYDVQQLEwNTUEQxKDAmBgkqhkiG\n9w0BCQEWGXdpbGxpYW0ub2xpdmVpcmFAdW5pc28uYnIxETAPBgNVBAcTCFNvcm9j\nYWJhMRMwEQYDVQQIFApTw6NvIFBhdWxvMQswCQYDVQQGEwJCUjEWMBQGA1UEAxMN\nY2FmZS51bmlzby5icjAeFw0xNDA1MTYxNzAzNTBaFw0xNzA1MTUxNzAzNTBaMIGw\nMSkwJwYDVQQKEyBVTklTTyAtIFVuaXZlcnNpZGFkZSBkZSBTb3JvY2FiYTEMMAoG\nA1UECxMDU1BEMSgwJgYJKoZIhvcNAQkBFhl3aWxsaWFtLm9saXZlaXJhQHVuaXNv\nLmJyMREwDwYDVQQHEwhTb3JvY2FiYTETMBEGA1UECBQKU8OjbyBQYXVsbzELMAkG\nA1UEBhMCQlIxFjAUBgNVBAMTDWNhZmUudW5pc28uYnIwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQDDGWne13N4Edo+DRkrx+sQwJPnh3Xzv00KomAfcn4l\nsH8RDMHvQEEv0oV82SCvrAEqf5HatLNZyxr2gioq73CGN8ijZjDayQ5rxgLKWeVM\n+mlyuOXGGs/HQt9uFHglylC0uzM1Ns0bI2hpupKXmZvF+Mv6czX1sGlNMgLSMUvk\nwfCD4ak25YClASWwEzTzro9+kAtZV/lLWdrpENOgTU/H12QYIH7Gyjb20Mrksqu2\n5Wd5HFbyr/IwQF4FXfc6zS5soDCI2jqHJ4J/CE+JhCmJyUmbgzdGRg1smeKHpLPA\nc+q4dxHXlgG6O/Tk1tip455UbF7gevtNjxgcIOhTITftAgMBAAEwDQYJKoZIhvcN\nAQEFBQADggEBABuT+O4ZBPQXWOaifgeuaA3o7pSegZExaqy4cTjOUH8UCZfyROd8\ngU6RmIWEKGdg/8FbY+L8UjqPYXzkzGNxxbQqWBu+ytrvAeSv24alfpEmI5M9sTzj\nOBGr+lwvbMLFKrSmDGfrWAGnEcj8l7zr5+WjiFgC8TT9RRkZmI2YL4LCa+xuaAHz\nu7FcVvwdnkRaJBMW8+99YtZd1DkhGac5z3rfeJagr4h/Dn7sDglWobnX/IjblwQo\nIBDwiWpQtZ1HNQbMCNddAJHe/+AvjDz797AZB/JmPS8n2C6zX2VEbaLc58borXVA\ntM+CLQt/lQ18Q/48d2qPMVKQS2mGIhHI6wU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uniso.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://srvcafe.uniso.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://srvcafe.uniso.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://srvcafe.uniso.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://srvcafe.uniso.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://srvcafe.uniso.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://srvcafe.uniso.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://srvcafe.uniso.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://srvcafe.uniso.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uniso.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uniso.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uniso.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNISO - Universidade de Sorocaba"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNISO - Universidade de Sorocaba"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNISO - Universidade de Sorocaba"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNISO - Universidade de Sorocaba"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID1jCCAr4CAQAwDQYJKoZIhvcNAQEFBQAwgbAxKTAnBgNVBAoTIFVOSVNPIC0g\nVW5pdmVyc2lkYWRlIGRlIFNvcm9jYWJhMQwwCgYDVQQLEwNTUEQxKDAmBgkqhkiG\n9w0BCQEWGXdpbGxpYW0ub2xpdmVpcmFAdW5pc28uYnIxETAPBgNVBAcTCFNvcm9j\nYWJhMRMwEQYDVQQIFApTw6NvIFBhdWxvMQswCQYDVQQGEwJCUjEWMBQGA1UEAxMN\nY2FmZS51bmlzby5icjAeFw0xNDA1MTYxNzAzNTBaFw0xNzA1MTUxNzAzNTBaMIGw\nMSkwJwYDVQQKEyBVTklTTyAtIFVuaXZlcnNpZGFkZSBkZSBTb3JvY2FiYTEMMAoG\nA1UECxMDU1BEMSgwJgYJKoZIhvcNAQkBFhl3aWxsaWFtLm9saXZlaXJhQHVuaXNv\nLmJyMREwDwYDVQQHEwhTb3JvY2FiYTETMBEGA1UECBQKU8OjbyBQYXVsbzELMAkG\nA1UEBhMCQlIxFjAUBgNVBAMTDWNhZmUudW5pc28uYnIwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQDDGWne13N4Edo+DRkrx+sQwJPnh3Xzv00KomAfcn4l\nsH8RDMHvQEEv0oV82SCvrAEqf5HatLNZyxr2gioq73CGN8ijZjDayQ5rxgLKWeVM\n+mlyuOXGGs/HQt9uFHglylC0uzM1Ns0bI2hpupKXmZvF+Mv6czX1sGlNMgLSMUvk\nwfCD4ak25YClASWwEzTzro9+kAtZV/lLWdrpENOgTU/H12QYIH7Gyjb20Mrksqu2\n5Wd5HFbyr/IwQF4FXfc6zS5soDCI2jqHJ4J/CE+JhCmJyUmbgzdGRg1smeKHpLPA\nc+q4dxHXlgG6O/Tk1tip455UbF7gevtNjxgcIOhTITftAgMBAAEwDQYJKoZIhvcN\nAQEFBQADggEBABuT+O4ZBPQXWOaifgeuaA3o7pSegZExaqy4cTjOUH8UCZfyROd8\ngU6RmIWEKGdg/8FbY+L8UjqPYXzkzGNxxbQqWBu+ytrvAeSv24alfpEmI5M9sTzj\nOBGr+lwvbMLFKrSmDGfrWAGnEcj8l7zr5+WjiFgC8TT9RRkZmI2YL4LCa+xuaAHz\nu7FcVvwdnkRaJBMW8+99YtZd1DkhGac5z3rfeJagr4h/Dn7sDglWobnX/IjblwQo\nIBDwiWpQtZ1HNQbMCNddAJHe/+AvjDz797AZB/JmPS8n2C6zX2VEbaLc58borXVA\ntM+CLQt/lQ18Q/48d2qPMVKQS2mGIhHI6wU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNISO - Universidade de Sorocaba"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNISO - Universidade de Sorocaba"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uniso.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uniso.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universidade de Sorocaba"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universidade de Sorocaba"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ufit.onecampus.com",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cloud_ops_support@rsmart.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Cloud Ops Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ufit.onecampus.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RSmart"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rsmart.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RSmart"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ufit.onecampus.com/saml/SSO/alias/ufit",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ufit.onecampus.com/saml/SSO/alias/ufit",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ufit.onecampus.com/saml/SSO/alias/ufit",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ufit.onecampus.com/saml/SSO/alias/ufit",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFKTCCBBGgAwIBAgIJAP2Ays74REYyMA0GCSqGSIb3DQEBCwUAMIG0MQswCQYD\nVQQGEwJVUzEQMA4GA1UECBMHQXJpem9uYTETMBEGA1UEBxMKU2NvdHRzZGFsZTEa\nMBgGA1UEChMRR29EYWRkeS5jb20sIEluYy4xLTArBgNVBAsTJGh0dHA6Ly9jZXJ0\ncy5nb2RhZGR5LmNvbS9yZXBvc2l0b3J5LzEzMDEGA1UEAxMqR28gRGFkZHkgU2Vj\ndXJlIENlcnRpZmljYXRlIEF1dGhvcml0eSAtIEcyMB4XDTE1MDgyNjEzMTI0MloX\nDTE2MDkyNDE5MjAwNFowPTEhMB8GA1UECxMYRG9tYWluIENvbnRyb2wgVmFsaWRh\ndGVkMRgwFgYDVQQDDA8qLm9uZWNhbXB1cy5jb20wggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDHSg0+JDljLYtiLp4SS2x2G1KijMtnDzZzZf/BmuIZjetA\nC95IVcSLpvCjxa1sHEf5e4ZGuc5kByWYMj0u6Zn5e7u1H8zSdVVZ+SdIiDmbL9IP\nVzxgB8qCiM8BDLm86zvp6JPDdmSyU5qmDX7CmPXI/3W/4raOZMORkxBCIeUTujYX\nI6w1E/JIlam7rGiXGv6HcMWabc0JN+FyGtY1qdDdQPl7oWESxwEMaXTCt80zL7Go\nDB2WMvr+HTi/cwL34/KJow//PPxVBIcMY0d5ij4rqruc7BnofAHJIbd+irrR27FE\ndIAAZ+L9C9NiK+7gYVAD7bxyuLMd4yZP6m4QuXK/AgMBAAGjggGyMIIBrjAMBgNV\nHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAOBgNVHQ8B\nAf8EBAMCBaAwNwYDVR0fBDAwLjAsoCqgKIYmaHR0cDovL2NybC5nb2RhZGR5LmNv\nbS9nZGlnMnMxLTExMy5jcmwwUwYDVR0gBEwwSjBIBgtghkgBhv1tAQcXATA5MDcG\nCCsGAQUFBwIBFitodHRwOi8vY2VydGlmaWNhdGVzLmdvZGFkZHkuY29tL3JlcG9z\naXRvcnkvMHYGCCsGAQUFBwEBBGowaDAkBggrBgEFBQcwAYYYaHR0cDovL29jc3Au\nZ29kYWRkeS5jb20vMEAGCCsGAQUFBzAChjRodHRwOi8vY2VydGlmaWNhdGVzLmdv\nZGFkZHkuY29tL3JlcG9zaXRvcnkvZ2RpZzIuY3J0MB8GA1UdIwQYMBaAFEDCvSeO\nzDSDMKIz1/tss/C0LIDOMCkGA1UdEQQiMCCCDyoub25lY2FtcHVzLmNvbYINb25l\nY2FtcHVzLmNvbTAdBgNVHQ4EFgQUD42WHYmzkIt4bBTwOzAvZEroKRIwDQYJKoZI\nhvcNAQELBQADggEBAHmpPl8xZ7bMe7oBKwEV62VDuQZ1ToTZRvNfI36vjlYpdypI\n0yWf0ckHy0OIyEEW4Gx3PCmZZq3lptKmbnvsj+zBmFgM4Z+bYtMR60s4wlpQGoDU\nrhuszTLtIwWLLvQx+fbI9/K1rHS6pI3QV8g4OdMOznM82oEwpR+kPOUVsnw+gMmw\nbT/p8eVAUr3oWuhDp+qQo1LP9A0LaDNkH9UThAOQx1L0CP45RHlG7Ewd+LGS9S0X\ntTDiJ0v3T1w1Y4kZPLU7Z/fdeHHU1Yh4KeEfU43rF5kWQMSp1q0W6b49YrX9OvHJ\n/bKQ4YxUAr7Q4ohFqImnAEy2n4ZjivQ6z8kOPrY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.rsmart.com/"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.rsmart.com/privacy-policy/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Florida - IT"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://his.hr.evry.se/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "primulasupport@evry.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Primula"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://his.hr.evry.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Evry HR Solutions AB"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.evry.se/it-tjanster/applikationstjanster-och-losningar/personal-och-lonesystem/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Evry HR Solutions AB"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Webgr\u00e4nssnittet till HR-systemet Primula fr\u00e5n EVRY HR Solutions AB f\u00f6r anst\u00e4llda vid H\u00f6gskolan i Sk\u00f6vde"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The web interface to the HR software system Primula from EVRY HR Solutions AB for employees at University of Sk\u00f6vde"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Primula"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Primula"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDuDCCAqACBQCo2ygOMA0GCSqGSIb3DQEBBAUAMIGfMQswCQYDVQQGEwJTRTEQ\nMA4GA1UECBMHVXBwc2FsYTEdMBsGA1UEChMURXZyeSBIUiBTb2x1dGlvbnMgQUIx\nEDAOBgNVBAcTB1VwcHNhbGExEzARBgNVBAMTCmhyLmV2cnkuc2UxEDAOBgNVBAsT\nB1ByaW11bGExJjAkBgkqhkiG9w0BCQEWF3ByaW11bGFzdXBwb3J0QGV2cnkuY29t\nMB4XDTE1MDEyNzEzMTQ0M1oXDTI1MDEyNDEzMTQ0M1owgZ8xCzAJBgNVBAYTAlNF\nMRAwDgYDVQQIEwdVcHBzYWxhMR0wGwYDVQQKExRFdnJ5IEhSIFNvbHV0aW9ucyBB\nQjEQMA4GA1UEBxMHVXBwc2FsYTETMBEGA1UEAxMKaHIuZXZyeS5zZTEQMA4GA1UE\nCxMHUHJpbXVsYTEmMCQGCSqGSIb3DQEJARYXcHJpbXVsYXN1cHBvcnRAZXZyeS5j\nb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCvJstEPNIMU6Q+1Fie\nekZiInII7woqYNQ9cg30gvwYluNA9aKs9Rx1OXufcvxZEhcQ1R5zCe2gWa7I9bCi\ngyluonu51qmk++c7aMLIXU1pXhM/6sIXIHy36WZbabg7HYp4Ju+diUmV+LxWAe3c\nzjvoFWC3pr4mwJBeUkQtKk+UBLd4L6rOAM2htN6lyXduMcSJMSckS4aZqYMj02Dd\nhz3lMiSVErkA351af+oVC+6HghlnfNyiJbjGh+hslPcvnrBaOCX84/QI36X0NZjo\n7/o5vfmbfEM3K4YZklqhjkXOm+0KuRWj3DLyxqDyMURu4WNpMlap+kPhm1J64agx\nuo6rAgMBAAEwDQYJKoZIhvcNAQEEBQADggEBAEl9NSzAegcuz+J2ktf63LNRge/e\nGxWW8KIM2t5HyWYudHBTsVqlSNQEe1V/vmW/lwntct7gGHXwnPp8Ulb3JrGjJq6I\nNukeIMKSMJVHsCYTwbAqeCT6POaX6C8Uzs4CFV8VUv3x61Rbr7BKrYgxf2Q+CyG7\n2fWaucSmjZ56flYFTUmJ1sFzYuFKn9Ty5xPMV/eGmlT8kJ8HBH5E3cVQ+vVSoRYf\nfP/0el9T10aI13RD/03wXWCku1Ewx8Qqw+ANcN9HhZwdH23kpP+jYiBfOmhtCDh1\nDTGN04FIC5s+8yFP1O/+RrQ8DQRmS/dfyc8iOXxm5vsWIVAnwD5nX5WrSp4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://his.hr.evry.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://his.hr.evry.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://his.hr.evry.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:artifact-01",
              "location": "https://his.hr.evry.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:browser-post",
              "location": "https://his.hr.evry.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Primula Web"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eppn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "norEduPersonNIN",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.2428.90.1.5",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-12.ladok.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-12.ladok.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-12.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-12.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-12.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-12.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-12.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-12.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-12.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;12"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;12"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-12.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-12.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAJMhCC29P8hlMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0xMi5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTQ0MzM4WhcNMjQx\nMDA0MTQ0MzM4WjAhMR8wHQYDVQQDExZsYWRvazMtMTIubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAt27FF0C4jnnFkS9WAH9evibT\n2mQurh1Z19WYXGFQbHRx23hU5IX1CrR/EltoIz3cAzhpKYD24mkSXlYwoYgMlChP\n6Ic+HyWJsxUxcn/jCviD5QZtn73XFyZB5Yihbp//sQtQFxlQcJG1bPgjRUUHXrCs\nqMtdo72BtaYUE47O48RNX5nHWMCDUFCJRinWjO7Y1+AJcMCKHoITWjxCuE8wM90y\ns3qnAAnGqcraMxCE/iVghscvdTzIY2CFNpZWhn9xs0CtyLfElpj98qYCraLfhMOe\n+Pr78tpOJv5c4868f7rhkXfPNC8xE15tjnRRVMmvs1bNvaWsTriOQ24ZEBeMvwID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMTIubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0xMi5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUn1H3qvGaobqFNYNZH33prnm7XUswDQYJKoZIhvcNAQEFBQADggEB\nAH3f6k6w7pNY14cNRRHZMKyXfkBrKevNE8buSBAs5b1yzyVNDThETmT/fEkGCBf+\nzQaEtFdOc7TKMFWwRJaaBu5jSyoitWYFEXZqvNz9spT2mUCKg3PXR+rLk3J1+An3\n+yUk65nAqCtz2YUXYDYZfJyGRUiZGHj7Yixtkj9aH/68byz2fzIPwdFyn8BXDG05\n7LfglwhbBGytnPodGldvHR7dE77Hdt3pJnR8utrVinydoJbogzYCpN+AK6Nkd9r9\nsxle+ramSfhrt8V456dPBSRd16T/db9U3lv+dceE51AC5YA4D31yqKzNRmHJaNSQ\nn1fPE1wPBVcs1yMWkY5e3NM="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-12.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-12.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-12.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-12.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-12.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-12.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-12.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-12.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-12.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-12.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sso.han.nl/ssp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.han.nl/ssp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-04-30T15:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/2bcc4b974a6b5107c3cd0f0aba1d73ef",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "han.nl"
              },
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hogeschool van Arnhem en Nijmegen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hogeschool van Arnhem en Nijmegen"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/han.png",
                    "height": "21",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hogeschool van Arnhem en Nijmegen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "HAN University of Applied Sciences"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hogeschool van Arnhem en Nijmegen"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.han.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hogeschool van Arnhem en Nijmegen"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://keystone.lab.cloud.ipnett.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@kirei.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Information Kirei"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jakob@kirei.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jakob Schlyter"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://keystone.lab.cloud.ipnett.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://keystone.lab.cloud.ipnett.se/Shibboleth.sso/Logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IPnett Cloud Services OpenStack LAB"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IPnett Cloud Services OpenStack LAB"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.cloud.ipnett.se/ipnett.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "77"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IPnett Cloud Services LAB"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IPnett Cloud Services LAB"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDtzCCAp+gAwIBAgIJAL+7sP+g3LH7MA0GCSqGSIb3DQEBCwUAMHIxCzAJBgNV\n            BAYTAlNFMRwwGgYDVQQKDBNEZWZhdWx0IENvbXBhbnkgTHRkMR4wHAYDVQQLDBVJ\n            UG5ldHQgQ2xvdWQgU2VydmljZXMxJTAjBgNVBAMMHGtleXN0b25lLmxhYi5jbG91\n            ZC5pcG5ldHQuc2UwHhcNMTYwMTE5MTA1NzA2WhcNMTYwMjE4MTA1NzA2WjByMQsw\n            CQYDVQQGEwJTRTEcMBoGA1UECgwTRGVmYXVsdCBDb21wYW55IEx0ZDEeMBwGA1UE\n            CwwVSVBuZXR0IENsb3VkIFNlcnZpY2VzMSUwIwYDVQQDDBxrZXlzdG9uZS5sYWIu\n            Y2xvdWQuaXBuZXR0LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n            28LvLrq5A617+Uq0Z5eK8LKpYrk9Z9r9lLpMcQRIt+RB1V8DzNK3HY5uN/yL4Gv1\n            EhVSaDp8Msv+QmAfjc0Z/k0SeXbIU3hom6b3Ae2Ab6fu1OrJSyoee3vvXRDXHcz2\n            rt6Wh7/ligCOmZ+ciQYFMvRGqPPxq3xYtrDcZy1W+5JXrDKwZqPyGPvSsSe50xIv\n            xOE79ZQ/YawSbqzAL4ZMimDQSw7on7aPpG5b2zFukbHrJDDBFz7u9SWG8FGPLNfk\n            tVAWgTvfAu3drHFn+9dbbkkTBT9Pk8ETO3xkrwHJ+R6mmq8LhcGUv480D0/2NgIg\n            aHd4uuibtnwNOuZmgebfFwIDAQABo1AwTjAdBgNVHQ4EFgQUitpivDx/clvkbWJF\n            M2qGHp6epWgwHwYDVR0jBBgwFoAUitpivDx/clvkbWJFM2qGHp6epWgwDAYDVR0T\n            BAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAQEAh5WSbGmyKjj4iEeHwnRr3hSNJInU\n            h6JprxjttiPXjv4LBDuOP2sKnaqL9GAIk018nCvNm8jZvYVUEy1g3eeWBHWlrsyW\n            C5sUZa1BscqItsKbiaeldW42bYmT3R68zrAVEljp85CL49oDRLN3Cp+HT/GS/4e5\n            CNq57xHIao8v7qNgmgwA9rH3AbL0nUHwKCgIiTttDYbxFkjXNqBzj8Bx6m9spGN5\n            /qkqkB5j12S0qQYVOQv7YyvWyKiKFFim6YyTdAxjVmw2aus822+bm/O0LQPXuyXb\n            kJRlRT3IA0S0L7chd/PSMbzxFplFepMlhP6rbrKXd7PCmrENo+HOVi3PRQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDtzCCAp+gAwIBAgIJAL+7sP+g3LH7MA0GCSqGSIb3DQEBCwUAMHIxCzAJBgNV\n            BAYTAlNFMRwwGgYDVQQKDBNEZWZhdWx0IENvbXBhbnkgTHRkMR4wHAYDVQQLDBVJ\n            UG5ldHQgQ2xvdWQgU2VydmljZXMxJTAjBgNVBAMMHGtleXN0b25lLmxhYi5jbG91\n            ZC5pcG5ldHQuc2UwHhcNMTYwMTE5MTA1NzA2WhcNMTYwMjE4MTA1NzA2WjByMQsw\n            CQYDVQQGEwJTRTEcMBoGA1UECgwTRGVmYXVsdCBDb21wYW55IEx0ZDEeMBwGA1UE\n            CwwVSVBuZXR0IENsb3VkIFNlcnZpY2VzMSUwIwYDVQQDDBxrZXlzdG9uZS5sYWIu\n            Y2xvdWQuaXBuZXR0LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n            28LvLrq5A617+Uq0Z5eK8LKpYrk9Z9r9lLpMcQRIt+RB1V8DzNK3HY5uN/yL4Gv1\n            EhVSaDp8Msv+QmAfjc0Z/k0SeXbIU3hom6b3Ae2Ab6fu1OrJSyoee3vvXRDXHcz2\n            rt6Wh7/ligCOmZ+ciQYFMvRGqPPxq3xYtrDcZy1W+5JXrDKwZqPyGPvSsSe50xIv\n            xOE79ZQ/YawSbqzAL4ZMimDQSw7on7aPpG5b2zFukbHrJDDBFz7u9SWG8FGPLNfk\n            tVAWgTvfAu3drHFn+9dbbkkTBT9Pk8ETO3xkrwHJ+R6mmq8LhcGUv480D0/2NgIg\n            aHd4uuibtnwNOuZmgebfFwIDAQABo1AwTjAdBgNVHQ4EFgQUitpivDx/clvkbWJF\n            M2qGHp6epWgwHwYDVR0jBBgwFoAUitpivDx/clvkbWJFM2qGHp6epWgwDAYDVR0T\n            BAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAQEAh5WSbGmyKjj4iEeHwnRr3hSNJInU\n            h6JprxjttiPXjv4LBDuOP2sKnaqL9GAIk018nCvNm8jZvYVUEy1g3eeWBHWlrsyW\n            C5sUZa1BscqItsKbiaeldW42bYmT3R68zrAVEljp85CL49oDRLN3Cp+HT/GS/4e5\n            CNq57xHIao8v7qNgmgwA9rH3AbL0nUHwKCgIiTttDYbxFkjXNqBzj8Bx6m9spGN5\n            /qkqkB5j12S0qQYVOQv7YyvWyKiKFFim6YyTdAxjVmw2aus822+bm/O0LQPXuyXb\n            kJRlRT3IA0S0L7chd/PSMbzxFplFepMlhP6rbrKXd7PCmrENo+HOVi3PRQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://keystone.lab.cloud.ipnett.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "IPnett Cloud Services OpenStack LAB"
                },
                {
                  "lang": "sv",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "IPnett Cloud Services OpenStack LAB"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idpStaging.miamioh.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dkidd@miamioh.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Don Kidd"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "beckmd@miamioh.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike Beck"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idpStaging.miamioh.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idptest.miamioh.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idptest.miamioh.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idptest.miamioh.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idptest.miamioh.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idptest.miamioh.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "miamioh.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "zTEST_MUOhioIdP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPjCCAiagAwIBAgIJAPI7S0Hg1hxlMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE2lkcHRlc3QubWlhbWlvaC5lZHUwHhcNMTQwMjE3MTY0NzMzWhcNMjQwMjE1\nMTY0NzMzWjAeMRwwGgYDVQQDExNpZHB0ZXN0Lm1pYW1pb2guZWR1MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAurUC6sPE/TX0G3nQlkcgd/ibtwJMyi6u\nSMMFUeUYUmjl4Q4d+5QKQhaUJyqcTWpXX+htpp4F1OCtfhlwxGTz2F/LWZq8JkPX\nFD4uxvzn9lmzT6BI4+B6TN2Ww7ILaZ1wR1HcMu6M8wJ7/AreoNy9MGUaxc8uhKGy\n+KhoB+19VObZCjCBRqBV11vTL2h+Y8nQnJcplhdKPkNlGwIWn90SzJbHc/F95QFC\nna2Wbl5l3v4cYcReY4W5iE2TftlTDTDBdSBqwf+iHLNGjhkL8EsktYC3/p/dHBK3\nev8EaXqfPod3HVC+l87fPkNuA3W3XGoHGtDPHrCHR8VMMNZlUklpOwIDAQABo38w\nfTAdBgNVHQ4EFgQUfrLFYCDW7K1ZnO1QkHQYp0YawxswTgYDVR0jBEcwRYAUfrLF\nYCDW7K1ZnO1QkHQYp0YawxuhIqQgMB4xHDAaBgNVBAMTE2lkcHRlc3QubWlhbWlv\naC5lZHWCCQDyO0tB4NYcZTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IB\nAQA5k3SlFffFRq81u1uy3sjkpgp19S9L7KCoc63IVXN1aREJ9kQHRGbQbjcnzT05\nr/7vBO87OQMH0+Ojbn1xPSfIsUR91TgkGOAQc2yM/dkdFODgi+83guR1jilHRuFD\nDgA7rRiuqkPnVcrnatRdlSAYfNL8YtMkf9eQ63B1D6YfnQ23Giwytw3ZTaplD7He\neoKLu82UwkCAPtbKR5oqAyr+0FUDuLv8pwIrfeA/TaGGm9KwG2ddk/QnxTf5Io3R\nnD4EJJtThpP8l6iMoV9RRnOlrqfK+xuogzBC1lzJDDIM0KTSCMlN8G2qqAsswnrw\n5Cj8SlfNPom7OhnCL7HOCbzC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idptest.miamioh.edu/shibboleth/error.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "zTEST_MUOhioIdP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.muohio.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Miami University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://lc-idp.lincolncollege.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ithelpdesk@lincolncollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT help desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ithelpdesk@lincolncollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT help desk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://lc-idp.lincolncollege.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDaDCCAlACCQD46bmBVwfiXDANBgkqhkiG9w0BAQUFADB2MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEVMBMGA1UECBMMTGluY29sbnNoaXJlMRAwDgYDVQQHEwdMaW5jb2xuMRgwFgYD\n\t\t\t\t\t\tVQQKEw9MaW5jb2xuIENvbGxlZ2UxJDAiBgNVBAMTG2xjLWlkcC5saW5jb2xuY29s\n\t\t\t\t\t\tbGVnZS5hYy51azAeFw0xMjA3MjMwOTE3NTVaFw0zMjA3MTgwOTE3NTVaMHYxCzAJ\n\t\t\t\t\t\tBgNVBAYTAkdCMRUwEwYDVQQIEwxMaW5jb2xuc2hpcmUxEDAOBgNVBAcTB0xpbmNv\n\t\t\t\t\t\tbG4xGDAWBgNVBAoTD0xpbmNvbG4gQ29sbGVnZTEkMCIGA1UEAxMbbGMtaWRwLmxp\n\t\t\t\t\t\tbmNvbG5jb2xsZWdlLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\n\t\t\t\t\t\tAQEAuHXeFxNwSynRVryyHfnvoz3yjpFR7OWEGJxkoJLeIHtFx1TLEyU5sW472CSw\n\t\t\t\t\t\tntzE7L2JdkblesYNlq7Wb7JoCs3og71B7wYJywd2yCxiDST7Pnxyjy9A1cwo7yeN\n\t\t\t\t\t\tBxPP21b5UcNvd1KtFGe3CGOWhgWa0ai4Z3DA/pkOwmy42GmSrC3Z/U5pviUAaBOp\n\t\t\t\t\t\tkidvrj6VnaV58qBcVgnqCRauWqr3M0jqSqwDzGQ5iCjfG4Bm/19dHsyQgQ8cXPJs\n\t\t\t\t\t\tE+lviBx6UHpAMZqcu0RXl/Y5tvY3+MDpC9vLQKjoGkZH0PToO2mYakLDDgboK64C\n\t\t\t\t\t\tvaQtg+qydns+za80qF4hLDEwrwIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQBTnrK6\n\t\t\t\t\t\t5J0QLLwWgAre26KAspklobXnnNcKR1VySi6N5SgvHVmLBSRtvODgdrf0gr/vilvG\n\t\t\t\t\t\tKXF3TBYnRMMfm61zPVFf1qfzmS7JTseVeO0jEH/vEgK46snDSinmyJSeTiWyNDsi\n\t\t\t\t\t\tGwNh2Z+HS5CtvtBiGucmHx17liMvdyICIGTeTvfF4tSK0yb0lJYJdYOTSPHy3tp6\n\t\t\t\t\t\tRQFsfuy0eglvAwYrJ1wHg3wQFXVkiYunGf1Mp3LOpY+lBmMlHEaRbomidxLXk1qv\n\t\t\t\t\t\tWcqedLVOpjYFQ3I6Z4vQ/io3czPPfBmxlAKaGgItuNLFT97z66QJUM7yMLwjlP0j\n\t\t\t\t\t\tgOEDoZmzZH+n3JY1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lincolncollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://lc-idp.lincolncollege.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lc-idp.lincolncollege.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://lc-idp.lincolncollege.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lc-idp.lincolncollege.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://lc-idp.lincolncollege.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lc-idp.lincolncollege.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://lc-idp.lincolncollege.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lc-idp.lincolncollege.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lincolncollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDaDCCAlACCQD46bmBVwfiXDANBgkqhkiG9w0BAQUFADB2MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEVMBMGA1UECBMMTGluY29sbnNoaXJlMRAwDgYDVQQHEwdMaW5jb2xuMRgwFgYD\n\t\t\t\t\t\tVQQKEw9MaW5jb2xuIENvbGxlZ2UxJDAiBgNVBAMTG2xjLWlkcC5saW5jb2xuY29s\n\t\t\t\t\t\tbGVnZS5hYy51azAeFw0xMjA3MjMwOTE3NTVaFw0zMjA3MTgwOTE3NTVaMHYxCzAJ\n\t\t\t\t\t\tBgNVBAYTAkdCMRUwEwYDVQQIEwxMaW5jb2xuc2hpcmUxEDAOBgNVBAcTB0xpbmNv\n\t\t\t\t\t\tbG4xGDAWBgNVBAoTD0xpbmNvbG4gQ29sbGVnZTEkMCIGA1UEAxMbbGMtaWRwLmxp\n\t\t\t\t\t\tbmNvbG5jb2xsZWdlLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\n\t\t\t\t\t\tAQEAuHXeFxNwSynRVryyHfnvoz3yjpFR7OWEGJxkoJLeIHtFx1TLEyU5sW472CSw\n\t\t\t\t\t\tntzE7L2JdkblesYNlq7Wb7JoCs3og71B7wYJywd2yCxiDST7Pnxyjy9A1cwo7yeN\n\t\t\t\t\t\tBxPP21b5UcNvd1KtFGe3CGOWhgWa0ai4Z3DA/pkOwmy42GmSrC3Z/U5pviUAaBOp\n\t\t\t\t\t\tkidvrj6VnaV58qBcVgnqCRauWqr3M0jqSqwDzGQ5iCjfG4Bm/19dHsyQgQ8cXPJs\n\t\t\t\t\t\tE+lviBx6UHpAMZqcu0RXl/Y5tvY3+MDpC9vLQKjoGkZH0PToO2mYakLDDgboK64C\n\t\t\t\t\t\tvaQtg+qydns+za80qF4hLDEwrwIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQBTnrK6\n\t\t\t\t\t\t5J0QLLwWgAre26KAspklobXnnNcKR1VySi6N5SgvHVmLBSRtvODgdrf0gr/vilvG\n\t\t\t\t\t\tKXF3TBYnRMMfm61zPVFf1qfzmS7JTseVeO0jEH/vEgK46snDSinmyJSeTiWyNDsi\n\t\t\t\t\t\tGwNh2Z+HS5CtvtBiGucmHx17liMvdyICIGTeTvfF4tSK0yb0lJYJdYOTSPHy3tp6\n\t\t\t\t\t\tRQFsfuy0eglvAwYrJ1wHg3wQFXVkiYunGf1Mp3LOpY+lBmMlHEaRbomidxLXk1qv\n\t\t\t\t\t\tWcqedLVOpjYFQ3I6Z4vQ/io3czPPfBmxlAKaGgItuNLFT97z66QJUM7yMLwjlP0j\n\t\t\t\t\t\tgOEDoZmzZH+n3JY1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lincoln College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lincolncollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Lincoln College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.crous-bordeaux.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "houelbec"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mickael.houelbec@crous-bordeaux.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.crous-bordeaux.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-11-03T12:40:25Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.crous-bordeaux.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.crous-bordeaux.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.crous-bordeaux.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "crous-bordeaux.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "crous-bordeaux.local"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-test.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.crous-bordeaux.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnels Crous"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnels Crous"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Bordeaux"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Bordeaux"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUDt3bxzRJ9VeaaPgY1fFNSuTy8qMwDQYJKoZIhvcNAQEL\nBQAwHTEbMBkGA1UEAwwSaWRwLXRlc3QubnVvbmV0LmZyMB4XDTE2MDEyNjE0MTYw\nMVoXDTM2MDEyNjE0MTYwMVowHTEbMBkGA1UEAwwSaWRwLXRlc3QubnVvbmV0LmZy\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAq77pfqDV9GwKrvOzYXpm\nFrlSuF8s6gKeSkJoY94AU5rAUGkE2khbkiC4dKoAVHyrKw61p/Y+rZeiddhx9pYx\n87TthJQWuO17ZajQtj3k2uQO2+oaTqyNidcLVDP9CJwwHRqPhKLaQJuhjl9aqRad\nTOfBi/dqkUaxU5pjD5ff0+SYxkhzanYWbI4DIgioq+Y271N30d3mmzTXjgVnJUVH\nF4oIVDar7CnLRHDe6xLsrf5CWuAmcfHA20mcwTRtMR002ufF4SYe56751klxc+m3\nX0PSo6sKFcWzD1hcbbQs6Nsbro9kxHSI/mRmSbLqMDMpKqqkbJ3BGOzM5uBLTfZc\nyQIDAQABo2swaTAdBgNVHQ4EFgQUjdjCwHoV17y6lftmc2H1o2S13TkwSAYDVR0R\nBEEwP4ISaWRwLXRlc3QubnVvbmV0LmZyhilodHRwczovL2lkcC10ZXN0Lm51b25l\ndC5mci9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAA00YGaErU3M5\nhGLrLayanAYTfx9zN+zL+Wo8ZvVeiiGyy+1YKJzwpP+aoW8vpj82bGBolc2I+VFA\n8sYA4HFlTnf0j9VWMSeTOh69HcdF5Wb2SwRuTgRvdagxn/FzijR3PcXNAVfDd8QL\nQolGDgqZAFRHJ617yepJmMaTvkWt2jxzsuvFbnIJy7Ph/+qpacsns9Jrds/IPXpF\nZTL9ow+uyZ7IvCo64fHDQV0xUNfTupztoj9a3F55y5ylzqYj+7lw1LRz9NR3mu3U\nvYGX0ypFWEQsGNF+7e+WMYj/mdlnmlbVyHMLGoViZtMF778QRWmG2eUA6e6f5XO3\nV1qshASPfg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVAOQhRzkgfr4mUbjdybfye+CwFu0OMA0GCSqGSIb3DQEB\nBQUAMCAxHjAcBgNVBAMMFWlkcC5jcm91cy1ib3JkZWF1eC5mcjAeFw0xNTA5MDMx\nMjA3MzJaFw0zNTA5MDMxMjA3MzJaMCAxHjAcBgNVBAMMFWlkcC5jcm91cy1ib3Jk\nZWF1eC5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALrGCAtWigBo\n7UzBARBnrmjNgDPX1PrOgE+xY1auT6AkRHl7cmYgM2y1M5fdFIP2iwqgQcQ/smTN\nYfusM/ge2uUVXWdmck004yrpotU4b6tNOhangckaJ4i2Wp1LESwm6JKcEQqmmoF9\ne7PQwTu1G++Pfua8tzZZsGZ9Rs5+0WOVMDDgSKwuQYifsvnLGqRw3AtGSiXIJIkj\nvzf08nRDIx3/PyUXxjRsBYfuj4rbRlP9YYKi2oUzmQcvBX+idsKUJsH5BejvQeAC\ncUz6onAtLlGaLccHzOxEctpVrAaY2Z9e/kwjvDx9hE1SK8tmv8An0AscbRtQg56D\nXaAU2CHgn28CAwEAAaNxMG8wHQYDVR0OBBYEFO+LDZnMw+Zff/6ylX3/GV1XoajC\nME4GA1UdEQRHMEWCFWlkcC5jcm91cy1ib3JkZWF1eC5mcoYsaHR0cHM6Ly9pZHAu\nY3JvdXMtYm9yZGVhdXguZnIvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEFBQAD\nggEBAF9PNvcC6FN8wEQzolY0xtRlyjH+rTHA8NIYayS5CvsWMR5PwO8lmWxaXDNU\n2OeL8LhcAhCGfSCfY1fPZIfmFPJyqDuVFbgXzCLnxlFQF8EZwqwsBupluD4pNoMa\nNKNoumupr4NyT1sdeVR9rhGLzydFplNZIgDKxIv+owQ13dVpJI6WOfwopMefNXAi\nokLOG5FUO0VXkVyW5vk3P73e+/PXV+zDtx7AUaq3LrREyo02BKELEtQU4PLyXgVy\n1Rx7DL8vvMzvSEHyKJxaz7DvYO2Bpift/oivYI4iKParKuXxeEBui1H4vFSOYOvU\njFe1mGLYUbAC+0MvhTbC1QZSxgw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS Bordeaux"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.crous-bordeaux.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS Bordeaux"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibidp.bates.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "netadmin@bates.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bates NetAdmin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "netadmin@bates.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bates NetAdmin"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "netadmin@bates.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bates NetAdmin"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@bates.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Help Desk Services"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibidp.bates.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.bates.edu/idp/profile/Logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.bates.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.bates.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.bates.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.bates.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.bates.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bates.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.bates.edu/ils/login-service"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Bates College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Bates College Identity Provider"
                  }
                ],
                "logo": [
                  {
                    "text": "https://abacus.bates.edu/1855/wordmarks/bates-wordmark-201-515x150.jpg",
                    "lang": "en",
                    "height": "150",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "515"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.bates.edu/ils/policies"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUL/x4yeKXw8Qo1fj6nOo++CaAWnEwDQYJKoZIhvcNAQEF\nBQAwHDEaMBgGA1UEAxMRc2hpYmlkcC5iYXRlcy5lZHUwHhcNMTMwODMwMTQwOTMx\nWhcNMzMwODMwMTQwOTMxWjAcMRowGAYDVQQDExFzaGliaWRwLmJhdGVzLmVkdTCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL8gHC7Wjjzyp5xNqVGvh+YZ\n/Yc0j4Srp/vh6iNoDKgyxm8ttcUoBWmtauchw0EXs6uCihZpTlms+kVp+C8sVZC+\n6CBrfnwXb3cL251AIhsOex3eA94+1ugxs0ot8g9jSjFXpLu3FUcAyiIxYlODaVcy\n3wdfsMPVr0tx9eGN9jwuvJHE3wFn2IfmJb6cb7m4QlpDO+9jpjYJyya3a8NKrQwQ\n75EBq07muPbHPIJWDF+STOnQWdyxj5ly4XIg+S11P77saEz9vQbVB/Z5FX/lD7/J\nihxbKld7OurrXF/NjBwLXWkOnC3Np0lzAvYtU4JUqgxLpOpLyCwmbuMJRJNlzaMC\nAwEAAaNpMGcwRgYDVR0RBD8wPYIRc2hpYmlkcC5iYXRlcy5lZHWGKGh0dHBzOi8v\nc2hpYmlkcC5iYXRlcy5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFF6udEhN\nMEepB0wrvrtfT8Nkm4ytMA0GCSqGSIb3DQEBBQUAA4IBAQA2KfxSHhsyuzK62mna\nqnG7ctE70OZRBQiia9QE2aadgolB+CEr43dZb2YC4+EpbfBCODW5QNixLod3dYlx\nsG3R9y7ilVz+0dKFje+O31JHP+HKTbVhurvb/A+ksuUTyngczT/TxkwEz3WLXUK6\nwNtnuj7nHea0zQFF4RWcJ2UrN0I+RT6czQwSoTnrDlpGUPhYbd7fDUgj4XTC85Tk\nNMGcNLnWPXMs/8cJh+BhVcMR+ATeUYIT6ZZR5XVsjxtSVj/dYlugatENLwu4Zxye\nP9qcR8MfjVr4G5DgNUhpRXkHN5Oj8WhYwa2rgzTR+QqGnIKHZNVyna7BTHVIDsgV\nIq67"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "http://www.bates.edu/ils/login-service"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bates College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bates.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Bates College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idpcafe.ufjf.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jose Luiz Ribeiro de Souza Filho"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "engenharia.redes@ufjf.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idpcafe.ufjf.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID/DCCAuQCAQAwDQYJKoZIhvcNAQEFBQAwgcMxNDAyBgNVBAoTK1VGSkYgLSBV\nbml2ZXJzaWRhZGUgRmVkZXJhbCBkZSBKdWl6IGRlIEZvcmExDTALBgNVBAsTBENH\nQ08xJzAlBgkqhkiG9w0BCQEWGGVuZ2VuaGFyaWEucmVkZXNAdWZqZi5icjEVMBMG\nA1UEBxMMSnVpeiBkZSBGb3JhMRUwEwYDVQQIEwxNaW5hcyBHZXJhaXMxCzAJBgNV\nBAYTAkJSMRgwFgYDVQQDEw9pZHBjYWZlLnVmamYuYnIwHhcNMTQwNTE1MTI1NDA4\nWhcNMTcwNTE0MTI1NDA4WjCBwzE0MDIGA1UEChMrVUZKRiAtIFVuaXZlcnNpZGFk\nZSBGZWRlcmFsIGRlIEp1aXogZGUgRm9yYTENMAsGA1UECxMEQ0dDTzEnMCUGCSqG\nSIb3DQEJARYYZW5nZW5oYXJpYS5yZWRlc0B1ZmpmLmJyMRUwEwYDVQQHEwxKdWl6\nIGRlIEZvcmExFTATBgNVBAgTDE1pbmFzIEdlcmFpczELMAkGA1UEBhMCQlIxGDAW\nBgNVBAMTD2lkcGNhZmUudWZqZi5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBALchDbtE8aCMl4QLHxwYXSd6XUKkGLr8MUTeRqanArp6GjbPdmRCVXXD\n1jQxYKOreu3FAe6HA5N+miqKs6/lYFspfiYv3hhv7kYjvch8HDde2Y4dBb6R/tDv\nRronbnX/7yHnlYvVgJsgG8vAvvk8G2i8DkFxXm2voBgd1oZKFCxZ91u5VspOZBll\n9IpRo92eV4s2r4gA29Y5PTt+9QhKcYbwqbY0H/qOsrDUUw3N6eHkbMCmTbTwF9QQ\n9kdGNE9kqsCpVe2pvdDRufAGM2lhW9FRQ7TtQVM2W05gAKqM/gtqmFTHcXOW61s9\n1UNQHy950x3+6XV5uPSJ5goWVH/IBq8CAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\nZvdlVROsCPu31t4NMLcJffMJ3UczKuQz/hnpqFopzHx/ZzAvA2qh7EyyDSKZYcVb\nu1Ot25INLgEMywDAE54zD5kzPiWqe7L1ozoXoO5KB3wLPn6E61JVq4T4OJDdKyJy\n+laNFVPumFJ1OoOJimQW5s8LhuW7cwIojE5r0Mi5M8lxuazQIxMUMsOy+cjvEJ1l\n4xAqcBQPPzN8BS9nh21wZ0yrpxDTk7WhASv+OmjFhod5fyYdWrATt/7ayoP3lNv9\nIgvH8wv82qKhKozHFDyFhPwNwBMLIskMni1P/NJSlXbMYt3/I6mvRKLGBVZWOdeG\nVHUsC0A0Nd9rEkuwkV0GdA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufjf.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idpcafe.ufjf.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idpcafe.ufjf.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idpcafe.ufjf.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idpcafe.ufjf.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idpcafe.ufjf.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idpcafe.ufjf.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idpcafe.ufjf.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idpcafe.ufjf.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufjf.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufjf.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufjf.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFJF - Universidade Federal de Juiz de Fora"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFJF - Universidade Federal de Juiz de Fora"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFJF - Universidade Federal de Juiz de Fora"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFJF - Universidade Federal de Juiz de Fora"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID/DCCAuQCAQAwDQYJKoZIhvcNAQEFBQAwgcMxNDAyBgNVBAoTK1VGSkYgLSBV\nbml2ZXJzaWRhZGUgRmVkZXJhbCBkZSBKdWl6IGRlIEZvcmExDTALBgNVBAsTBENH\nQ08xJzAlBgkqhkiG9w0BCQEWGGVuZ2VuaGFyaWEucmVkZXNAdWZqZi5icjEVMBMG\nA1UEBxMMSnVpeiBkZSBGb3JhMRUwEwYDVQQIEwxNaW5hcyBHZXJhaXMxCzAJBgNV\nBAYTAkJSMRgwFgYDVQQDEw9pZHBjYWZlLnVmamYuYnIwHhcNMTQwNTE1MTI1NDA4\nWhcNMTcwNTE0MTI1NDA4WjCBwzE0MDIGA1UEChMrVUZKRiAtIFVuaXZlcnNpZGFk\nZSBGZWRlcmFsIGRlIEp1aXogZGUgRm9yYTENMAsGA1UECxMEQ0dDTzEnMCUGCSqG\nSIb3DQEJARYYZW5nZW5oYXJpYS5yZWRlc0B1ZmpmLmJyMRUwEwYDVQQHEwxKdWl6\nIGRlIEZvcmExFTATBgNVBAgTDE1pbmFzIEdlcmFpczELMAkGA1UEBhMCQlIxGDAW\nBgNVBAMTD2lkcGNhZmUudWZqZi5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBALchDbtE8aCMl4QLHxwYXSd6XUKkGLr8MUTeRqanArp6GjbPdmRCVXXD\n1jQxYKOreu3FAe6HA5N+miqKs6/lYFspfiYv3hhv7kYjvch8HDde2Y4dBb6R/tDv\nRronbnX/7yHnlYvVgJsgG8vAvvk8G2i8DkFxXm2voBgd1oZKFCxZ91u5VspOZBll\n9IpRo92eV4s2r4gA29Y5PTt+9QhKcYbwqbY0H/qOsrDUUw3N6eHkbMCmTbTwF9QQ\n9kdGNE9kqsCpVe2pvdDRufAGM2lhW9FRQ7TtQVM2W05gAKqM/gtqmFTHcXOW61s9\n1UNQHy950x3+6XV5uPSJ5goWVH/IBq8CAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\nZvdlVROsCPu31t4NMLcJffMJ3UczKuQz/hnpqFopzHx/ZzAvA2qh7EyyDSKZYcVb\nu1Ot25INLgEMywDAE54zD5kzPiWqe7L1ozoXoO5KB3wLPn6E61JVq4T4OJDdKyJy\n+laNFVPumFJ1OoOJimQW5s8LhuW7cwIojE5r0Mi5M8lxuazQIxMUMsOy+cjvEJ1l\n4xAqcBQPPzN8BS9nh21wZ0yrpxDTk7WhASv+OmjFhod5fyYdWrATt/7ayoP3lNv9\nIgvH8wv82qKhKozHFDyFhPwNwBMLIskMni1P/NJSlXbMYt3/I6mvRKLGBVZWOdeG\nVHUsC0A0Nd9rEkuwkV0GdA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFJF - Universidade Federal de Juiz de Fora"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFJF - Universidade Federal de Juiz de Fora"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufjf.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufjf.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFJF - Universidade Federal de Juiz de Fora"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFJF - Universidade Federal de Juiz de Fora"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://aai.helmholtz-muenchen.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hu\u00df"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:huss@helmholtz-muenchen.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Walter"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ahrens"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:marcus.ahrens@helmholtz-muenchen.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marcus"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://aai.helmholtz-muenchen.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2013-07-11T11:39:55Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "aai.helmholtz-muenchen.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIG2jCCBcKgAwIBAgIHFStsxRFcQDANBgkqhkiG9w0BAQUFADCB2TELMAkGA1UE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\nMB5OOnMF/hsOUVseiza2g8mKOTsARybpYAwFeDgJ"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=aai.helmholtz-muenchen.de,OU=ASC,O=Helmholtz Zentrum Muenchen,L=Oberschleissheim-Neuherberg,ST=Bayern,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "aai.helmholtz-muenchen.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIG2jCCBcKgAwIBAgIHFStsxRFcQDANBgkqhkiG9w0BAQUFADCB2TELMAkGA1UE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\nMB5OOnMF/hsOUVseiza2g8mKOTsARybpYAwFeDgJ"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=aai.helmholtz-muenchen.de,OU=ASC,O=Helmholtz Zentrum Muenchen,L=Oberschleissheim-Neuherberg,ST=Bayern,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "helmholtz-muenchen.de"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "scidom.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai.helmholtz-muenchen.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai.helmholtz-muenchen.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aai.helmholtz-muenchen.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai.helmholtz-muenchen.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aai.helmholtz-muenchen.de/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai.helmholtz-muenchen.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai.helmholtz-muenchen.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai.helmholtz-muenchen.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "helmholtz-muenchen.de"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "scidom.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.helmholtz-muenchen.de/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.helmholtz-muenchen.de/"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Instanz des internen IdP des Helmholtz Zentrums M\u00fcnchen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IdP of Helmholtz Zentrums Muenchen"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Helmholtz Zentrum M\u00fcnchen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Helmholtz Zentrum Muenchen"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "aai.helmholtz-muenchen.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIG2jCCBcKgAwIBAgIHFStsxRFcQDANBgkqhkiG9w0BAQUFADCB2TELMAkGA1UE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\nMB5OOnMF/hsOUVseiza2g8mKOTsARybpYAwFeDgJ"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=aai.helmholtz-muenchen.de,OU=ASC,O=Helmholtz Zentrum Muenchen,L=Oberschleissheim-Neuherberg,ST=Bayern,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "aai.helmholtz-muenchen.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIG2jCCBcKgAwIBAgIHFStsxRFcQDANBgkqhkiG9w0BAQUFADCB2TELMAkGA1UE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\nMB5OOnMF/hsOUVseiza2g8mKOTsARybpYAwFeDgJ"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=aai.helmholtz-muenchen.de,OU=ASC,O=Helmholtz Zentrum Muenchen,L=Oberschleissheim-Neuherberg,ST=Bayern,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Helmholtz Zentrum M\u00fcnchen Deutsches Forschungzentrum f\u00fcr Gesundheit und Umwelt"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Helmholtz Zentrum M\u00fcnchen German Research Center for Environmental Health"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.helmholtz-muenchen.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.helmholtz-muenchen.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e310"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e310"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://libauth.com/saml/module.php/saml/sp/metadata.php/springy-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Xiao"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jing@springshare.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jing"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Xiao"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jing@springshare.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jing"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://libauth.com/saml/module.php/saml/sp/metadata.php/springy-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-12-23T09:43:22Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Springshare LibApps"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://springshare.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Springshare LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://libauth.com/saml/module.php/saml/sp/saml2-logout.php/springy-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Springshare's LibApps helps libraries share knowledge, analyze services, and connect with users."
                  }
                ],
                "logo": [
                  {
                    "text": "https://libauth.com/static/springshare-incommon.png",
                    "lang": "en",
                    "height": "150",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "183"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Springshare LibApps"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE4TCCA8mgAwIBAgIQW9IQE6lOfxilMVYUD3eYQTANBgkqhkiG9w0BAQsFADBE\n\t\t\t\t\t\tMQswCQYDVQQGEwJVUzEWMBQGA1UEChMNR2VvVHJ1c3QgSW5jLjEdMBsGA1UEAxMU\n\t\t\t\t\t\tR2VvVHJ1c3QgU1NMIENBIC0gRzMwHhcNMTQwOTMwMDAwMDAwWhcNMTYwOTI5MjM1\n\t\t\t\t\t\tOTU5WjBfMQswCQYDVQQGEwJVUzEQMA4GA1UECBQHRmxvcmlkYTEOMAwGA1UEBxQF\n\t\t\t\t\t\tTWlhbWkxFDASBgNVBAoUC1NwcmluZ3NoYXJlMRgwFgYDVQQDFA93d3cubGliYXV0\n\t\t\t\t\t\taC5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDeaK+45OlvZMCW\n\t\t\t\t\t\tnhBlRi2vNUFNSdhppfyoLNGyQrDxDr5JSwSLwuWdSkJPkFkJsnScSxfXBki/BMz0\n\t\t\t\t\t\tV3yY2CqkPYSMBYtG5OhD+4Bb8pcEcqtXrHzkj88Eo0eJP7iLOxWQsMIl1XZG6BW3\n\t\t\t\t\t\tOWm2xxAJIqGdTGAyFWiE4Zq7sD+umMRacJWioY9Wu6X9AXZzJMT8qq5AnvK5qt6r\n\t\t\t\t\t\tb4wJxBqwFp3ObUlRYG1TMHKaEd7VVgKcr4mEWQh7H44KcDDsI60322Rp0tzomPz9\n\t\t\t\t\t\tFJ7htSSJ4K1imeWqOcImM1VmXHem3eruZlg+csslLGzsqVzsI8//Drf2RMWilu/U\n\t\t\t\t\t\tPV5dtHwTAgMBAAGjggGyMIIBrjAnBgNVHREEIDAegg93d3cubGliYXV0aC5jb22C\n\t\t\t\t\t\tC2xpYmF1dGguY29tMAkGA1UdEwQCMAAwDgYDVR0PAQH/BAQDAgWgMCsGA1UdHwQk\n\t\t\t\t\t\tMCIwIKAeoByGGmh0dHA6Ly9nbi5zeW1jYi5jb20vZ24uY3JsMIGhBgNVHSAEgZkw\n\t\t\t\t\t\tgZYwgZMGCmCGSAGG+EUBBzYwgYQwPwYIKwYBBQUHAgEWM2h0dHBzOi8vd3d3Lmdl\n\t\t\t\t\t\tb3RydXN0LmNvbS9yZXNvdXJjZXMvcmVwb3NpdG9yeS9sZWdhbDBBBggrBgEFBQcC\n\t\t\t\t\t\tAjA1DDNodHRwczovL3d3dy5nZW90cnVzdC5jb20vcmVzb3VyY2VzL3JlcG9zaXRv\n\t\t\t\t\t\tcnkvbGVnYWwwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMB8GA1UdIwQY\n\t\t\t\t\t\tMBaAFNJv95b0hT9yPDB9I9qFeJujfFp8MFcGCCsGAQUFBwEBBEswSTAfBggrBgEF\n\t\t\t\t\t\tBQcwAYYTaHR0cDovL2duLnN5bWNkLmNvbTAmBggrBgEFBQcwAoYaaHR0cDovL2du\n\t\t\t\t\t\tLnN5bWNiLmNvbS9nbi5jcnQwDQYJKoZIhvcNAQELBQADggEBAAE9UJj2EnSkAgJe\n\t\t\t\t\t\tbexMA4e9x4YCrVDfBLF6nLLwBCT1ZWb7ganm2HeFwciO1ofcgBfvnUvIyKRtcNnM\n\t\t\t\t\t\t7/XjJPfkdZWS9oja0IKCUPkFH85qHxkHzsquMqm/pNO3XTHnA11VpTQQekNeOTH8\n\t\t\t\t\t\tH9mX1U06mPcQ5gb7FQ1pjFkGJf1KjPVcErbmcUPIi+0nyMYvHzO9s+4YkMNNKsk1\n\t\t\t\t\t\tLTp+baR6oEsfyn58NIXjB1QVcwJKc9b+ImKE5MySsZi5ikqFq0DBAfGV6cacZY+K\n\t\t\t\t\t\tAJv0x5aloVA/YBekndNFXDC+mtxo+pKrWyGsTcA33n+twUZ7Agz8Fzsh+3VIJooQ\n\t\t\t\t\t\tqqVHvtY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE4TCCA8mgAwIBAgIQW9IQE6lOfxilMVYUD3eYQTANBgkqhkiG9w0BAQsFADBE\n\t\t\t\t\t\tMQswCQYDVQQGEwJVUzEWMBQGA1UEChMNR2VvVHJ1c3QgSW5jLjEdMBsGA1UEAxMU\n\t\t\t\t\t\tR2VvVHJ1c3QgU1NMIENBIC0gRzMwHhcNMTQwOTMwMDAwMDAwWhcNMTYwOTI5MjM1\n\t\t\t\t\t\tOTU5WjBfMQswCQYDVQQGEwJVUzEQMA4GA1UECBQHRmxvcmlkYTEOMAwGA1UEBxQF\n\t\t\t\t\t\tTWlhbWkxFDASBgNVBAoUC1NwcmluZ3NoYXJlMRgwFgYDVQQDFA93d3cubGliYXV0\n\t\t\t\t\t\taC5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDeaK+45OlvZMCW\n\t\t\t\t\t\tnhBlRi2vNUFNSdhppfyoLNGyQrDxDr5JSwSLwuWdSkJPkFkJsnScSxfXBki/BMz0\n\t\t\t\t\t\tV3yY2CqkPYSMBYtG5OhD+4Bb8pcEcqtXrHzkj88Eo0eJP7iLOxWQsMIl1XZG6BW3\n\t\t\t\t\t\tOWm2xxAJIqGdTGAyFWiE4Zq7sD+umMRacJWioY9Wu6X9AXZzJMT8qq5AnvK5qt6r\n\t\t\t\t\t\tb4wJxBqwFp3ObUlRYG1TMHKaEd7VVgKcr4mEWQh7H44KcDDsI60322Rp0tzomPz9\n\t\t\t\t\t\tFJ7htSSJ4K1imeWqOcImM1VmXHem3eruZlg+csslLGzsqVzsI8//Drf2RMWilu/U\n\t\t\t\t\t\tPV5dtHwTAgMBAAGjggGyMIIBrjAnBgNVHREEIDAegg93d3cubGliYXV0aC5jb22C\n\t\t\t\t\t\tC2xpYmF1dGguY29tMAkGA1UdEwQCMAAwDgYDVR0PAQH/BAQDAgWgMCsGA1UdHwQk\n\t\t\t\t\t\tMCIwIKAeoByGGmh0dHA6Ly9nbi5zeW1jYi5jb20vZ24uY3JsMIGhBgNVHSAEgZkw\n\t\t\t\t\t\tgZYwgZMGCmCGSAGG+EUBBzYwgYQwPwYIKwYBBQUHAgEWM2h0dHBzOi8vd3d3Lmdl\n\t\t\t\t\t\tb3RydXN0LmNvbS9yZXNvdXJjZXMvcmVwb3NpdG9yeS9sZWdhbDBBBggrBgEFBQcC\n\t\t\t\t\t\tAjA1DDNodHRwczovL3d3dy5nZW90cnVzdC5jb20vcmVzb3VyY2VzL3JlcG9zaXRv\n\t\t\t\t\t\tcnkvbGVnYWwwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMB8GA1UdIwQY\n\t\t\t\t\t\tMBaAFNJv95b0hT9yPDB9I9qFeJujfFp8MFcGCCsGAQUFBwEBBEswSTAfBggrBgEF\n\t\t\t\t\t\tBQcwAYYTaHR0cDovL2duLnN5bWNkLmNvbTAmBggrBgEFBQcwAoYaaHR0cDovL2du\n\t\t\t\t\t\tLnN5bWNiLmNvbS9nbi5jcnQwDQYJKoZIhvcNAQELBQADggEBAAE9UJj2EnSkAgJe\n\t\t\t\t\t\tbexMA4e9x4YCrVDfBLF6nLLwBCT1ZWb7ganm2HeFwciO1ofcgBfvnUvIyKRtcNnM\n\t\t\t\t\t\t7/XjJPfkdZWS9oja0IKCUPkFH85qHxkHzsquMqm/pNO3XTHnA11VpTQQekNeOTH8\n\t\t\t\t\t\tH9mX1U06mPcQ5gb7FQ1pjFkGJf1KjPVcErbmcUPIi+0nyMYvHzO9s+4YkMNNKsk1\n\t\t\t\t\t\tLTp+baR6oEsfyn58NIXjB1QVcwJKc9b+ImKE5MySsZi5ikqFq0DBAfGV6cacZY+K\n\t\t\t\t\t\tAJv0x5aloVA/YBekndNFXDC+mtxo+pKrWyGsTcA33n+twUZ7Agz8Fzsh+3VIJooQ\n\t\t\t\t\t\tqqVHvtY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://libauth.com/saml/module.php/saml/sp/saml2-acs.php/springy-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://libauth.com/saml/module.php/saml/sp/saml1-acs.php/springy-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://libauth.com/saml/module.php/saml/sp/saml2-acs.php/springy-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://libauth.com/saml/module.php/saml/sp/saml1-acs.php/springy-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Springshare LibApps"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Springshare's LibApps helps libraries share knowledge, analyze services, and connect with users."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.mendelu.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Banzet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "michael.banzet@mendelu.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.mendelu.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2010-09-15T15:19:47Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/university"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDlzCCAn+gAwIBAgIJAJDI3wy+XpHDMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDmlkcC5tZW5kZWx1LmN6MB4XDTE2MDMyOTEwNDE0MFoXDTM2MDMyNDEwNDE0\nMFowGTEXMBUGA1UEAxMOaWRwLm1lbmRlbHUuY3owggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDZVvr0rRSzqYtQwJFLlnemOD8otdNMGZvQg3wMF+iiasJH\nzRvjQSK/faikBr4bg4srewOUW0dPAmB5tQWxRAs/Nm2v9vwalHktD97ccZ8J9oHo\nVMsm7JKiGFozkVRHXD//EHzD+UwtuwNZvrwTysGSnIFMg7GVFSpi0ByvLu+To5gl\n5mjNppiMqRXDnKiNtbUncwD2U+0/h5/GN0flI4mNZocR2DY2qyYGXF41MMxbsUjI\ncIghx2H2vWdF5G1YTY6qye6E8m9xVClQc/KNm00YqrjIElFwxeP0zi5GV6mO8PEP\nEx99Q1yyos8lyQpmM37MvLnX2B8g/fD1cYdowDEDAgMBAAGjgeEwgd4wgbwGA1Ud\nEQSBtDCBsYIOaWRwLm1lbmRlbHUuY3qGJWh0dHBzOi8vaWRwLm1lbmRlbHUuY3ov\naWRwL3NoaWJib2xldGiCEmFsaWJhYmEubWVuZGVsdS5jeoYpaHR0cHM6Ly9hbGli\nYWJhLm1lbmRlbHUuY3ovaWRwL3NoaWJib2xldGiCEG1iZGV2Lm1lbmRlbHUuY3qG\nJ2h0dHBzOi8vbWJkZXYubWVuZGVsdS5jei9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4E\nFgQU1I2Hy25eKS9D3EIf+kjHt+7tbwgwDQYJKoZIhvcNAQEFBQADggEBANgEHcEi\nl6c+DVsixfpPKloIAaGTnd6rk3VrEoW22zhPmEYh8TZiZl1Ie2Ldbpbql/b7C8iK\nT/QyVEayGDuyLgehZTfLshC+EWtxsWT82QONdmhVutLYc5HEMBEvuiHYuQwqX3FS\njJNONzPvn6QsiC5LevJmX9I3vgIeEF3wbOgwdqnfzIl5k4DuGhDNdpv9iy3zwM+H\nly0Ky8TPxWhwkcZo83muhNJk5LuZG8VblckmvsGR27bt9wty60PqE1Wb4zlguTzY\neBFJcQNHXyofYwsQlK2LyCnlOlpQUtbXe5/BcXKA9pp+RnjZAB9dVpY/KJ6hy6BQ\n/9z9n5iDjFjm8dk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mendelu.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.mendelu.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.mendelu.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.mendelu.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.mendelu.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.mendelu.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.mendelu.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.mendelu.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.mendelu.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mendelu.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mendelu.cz/en/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mendelu.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Mendel Univerzity in Brno"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Poskytovatel identity Mendelovy univerzity v Brn\u011b"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.mendelu.cz/mendelu-logo.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "150"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mendel Univerzity in Brno"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mendelova univerzita v Brn\u011b"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDlzCCAn+gAwIBAgIJAJDI3wy+XpHDMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDmlkcC5tZW5kZWx1LmN6MB4XDTE2MDMyOTEwNDE0MFoXDTM2MDMyNDEwNDE0\nMFowGTEXMBUGA1UEAxMOaWRwLm1lbmRlbHUuY3owggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDZVvr0rRSzqYtQwJFLlnemOD8otdNMGZvQg3wMF+iiasJH\nzRvjQSK/faikBr4bg4srewOUW0dPAmB5tQWxRAs/Nm2v9vwalHktD97ccZ8J9oHo\nVMsm7JKiGFozkVRHXD//EHzD+UwtuwNZvrwTysGSnIFMg7GVFSpi0ByvLu+To5gl\n5mjNppiMqRXDnKiNtbUncwD2U+0/h5/GN0flI4mNZocR2DY2qyYGXF41MMxbsUjI\ncIghx2H2vWdF5G1YTY6qye6E8m9xVClQc/KNm00YqrjIElFwxeP0zi5GV6mO8PEP\nEx99Q1yyos8lyQpmM37MvLnX2B8g/fD1cYdowDEDAgMBAAGjgeEwgd4wgbwGA1Ud\nEQSBtDCBsYIOaWRwLm1lbmRlbHUuY3qGJWh0dHBzOi8vaWRwLm1lbmRlbHUuY3ov\naWRwL3NoaWJib2xldGiCEmFsaWJhYmEubWVuZGVsdS5jeoYpaHR0cHM6Ly9hbGli\nYWJhLm1lbmRlbHUuY3ovaWRwL3NoaWJib2xldGiCEG1iZGV2Lm1lbmRlbHUuY3qG\nJ2h0dHBzOi8vbWJkZXYubWVuZGVsdS5jei9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4E\nFgQU1I2Hy25eKS9D3EIf+kjHt+7tbwgwDQYJKoZIhvcNAQEFBQADggEBANgEHcEi\nl6c+DVsixfpPKloIAaGTnd6rk3VrEoW22zhPmEYh8TZiZl1Ie2Ldbpbql/b7C8iK\nT/QyVEayGDuyLgehZTfLshC+EWtxsWT82QONdmhVutLYc5HEMBEvuiHYuQwqX3FS\njJNONzPvn6QsiC5LevJmX9I3vgIeEF3wbOgwdqnfzIl5k4DuGhDNdpv9iy3zwM+H\nly0Ky8TPxWhwkcZo83muhNJk5LuZG8VblckmvsGR27bt9wty60PqE1Wb4zlguTzY\neBFJcQNHXyofYwsQlK2LyCnlOlpQUtbXe5/BcXKA9pp+RnjZAB9dVpY/KJ6hy6BQ\n/9z9n5iDjFjm8dk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mendel Univerzity in Brno"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mendelova univerzita v Brn\u011b"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mendelu.cz/en/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mendelu.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Mendel Univerzity in Brno"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Mendelova univerzita v Brn\u011b"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://rja-idp.lanet.lv",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ITserviss"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itserviss@lu.lv"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://rja-idp.lanet.lv",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://laife.lanet.lv/wiki/Latvian-Academic-Identity-Federation-Policy.pdf"
              }
            ],
            "registration_instant": "2013-10-10T10:10:10Z",
            "registration_authority": "http://laife.lanet.lv/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://rja-idp.lanet.lv/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://rja-idp.lanet.lv/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:56.950974,24.116292"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Riga Graduate School of Law"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Riga Graduate School of Law - RJA IDP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://laife.lanet.lv/"
          },
          {
            "lang": "lv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rgsl.edu.lv/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LAIFE - RJA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ucreative.idm.oclc.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Akkineni"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:akkinenv@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Vasu"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Akkineni"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:akkinenv@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Vasu"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ucreative.idm.oclc.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-04-12T10:14:54Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Creative Arts Hosted Ezproxy"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oclc.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "OCLC (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID/DCCAuSgAwIBAgIBAjANBgkqhkiG9w0BAQUFADBhMSEwHwYDVQQDFBgqLnVj\n\t\t\t\t\t\tcmVhdGl2ZS5pZG0ub2NsYy5vcmcxCzAJBgNVBAYTAlVLMQ0wCwYDVQQKEwRPQ0xD\n\t\t\t\t\t\tMSAwHgYJKoZIhvcNAQkBFhFha2tpbmVudkBvY2xjLm9yZzAeFw0xMzAzMDYyMzU0\n\t\t\t\t\t\tNTdaFw0yMzAzMDYyMzU0NTdaMGExITAfBgNVBAMUGCoudWNyZWF0aXZlLmlkbS5v\n\t\t\t\t\t\tY2xjLm9yZzELMAkGA1UEBhMCVUsxDTALBgNVBAoTBE9DTEMxIDAeBgkqhkiG9w0B\n\t\t\t\t\t\tCQEWEWFra2luZW52QG9jbGMub3JnMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAtQnizhQPQp2HjZLdRFGV1w20U0XsDrrHSzDiU0kxevGeroRLU3k9TDfO\n\t\t\t\t\t\tH3X+4FZlamSAEyg7ocmV6vKOi3PWo2hGeINtwhPBEo5JLFAl2waySFsvIlsCS+hr\n\t\t\t\t\t\txI+ZMrUU87S0kDeiheUTw6okMi2hBTCkPEDp3E/B7q0KMZACvL/sxm37x4Q+W4A3\n\t\t\t\t\t\tfP0pFLpbZqdZ2oxHY3KS8m/ZtWbakS2ghKq2+FayIt9/rB4V2FjnxpbqAajaT0h5\n\t\t\t\t\t\tsiljQFizMd49JzvzOOBuNvXcSJKUHOhH/wiOi5RN2Mx0HJX/0UiTJjpKCuv/+aIp\n\t\t\t\t\t\tR/elpqrOpEcOfY3QVdOQ+pepxM5spQIDAQABo4G+MIG7MB0GA1UdDgQWBBSEJ4FL\n\t\t\t\t\t\t+vjP0U4FQXK3tgP8CVC77zCBiwYDVR0jBIGDMIGAgBSEJ4FL+vjP0U4FQXK3tgP8\n\t\t\t\t\t\tCVC776FlpGMwYTEhMB8GA1UEAxQYKi51Y3JlYXRpdmUuaWRtLm9jbGMub3JnMQsw\n\t\t\t\t\t\tCQYDVQQGEwJVSzENMAsGA1UEChMET0NMQzEgMB4GCSqGSIb3DQEJARYRYWtraW5l\n\t\t\t\t\t\tbnZAb2NsYy5vcmeCAQIwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tieePqbyx1ZdzWKUXCgD1geGlmym1MWpFK7UueQWLHUTIi8oGBFb+kJsBkLCQaaVY\n\t\t\t\t\t\tags/ViUndWoBpiKP8efTMzjM3MpBOiji8u4KO/3O2tX0VkpPmQoO3ngOPtVSvm0y\n\t\t\t\t\t\tFdG/sr9ZdhLw4kYok8Gpb6vi08I/75OlSIbd+W/gL1nBe8wzcmORHV5aOZ7006WJ\n\t\t\t\t\t\tIlhSzLTtewnsmcTIJ/hVmgL07gByHLaJxR/40btxhdJrWENaSUnE2Vc8PHr46XSK\n\t\t\t\t\t\tWBSxxYRpDgUJ+Pz5QCZuAMkQGbPdhWSGfcURBUxYhiBK4fnOghJTXMXumg7GycfW\n\t\t\t\t\t\tvVK8cWTrEwbTlG9q6mlD0Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://login.ucreative.idm.oclc.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.ucreative.idm.oclc.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.ucreative.idm.oclc.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.ucreative.idm.oclc.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://kentsso.simitive.com",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dolby"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chris.dolby@simitive.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dolby"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chris.dolby@simitive.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://kentsso.simitive.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-10-22T15:17:04Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Simitive"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.simitive.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Simitive Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://kentsso.simitive.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://kentsso.simitive.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://kentsso.simitive.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://kentsso.simitive.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://kentsso.simitive.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "authn_requests_signed": "1",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://kentsso.simitive.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://kentsso.simitive.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLTCCAhWgAwIBAgIJAPuc4ZrD2thhMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGGxpdmUtbm9kZS0xLnNpbWl0aXZlLmNvbTAeFw0xNTEwMDIxNDI3MDVaFw0y\n\t\t\t\t\t\tNTA5MjkxNDI3MDVaMCMxITAfBgNVBAMTGGxpdmUtbm9kZS0xLnNpbWl0aXZlLmNv\n\t\t\t\t\t\tbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOUpc8HAMCrL4BiGieJh\n\t\t\t\t\t\tY0kTPCmKa2dWuIZy0GjBtb3PIqRX9L90452/sjW9P5RaQYyEMfdSEdXZBw/DEYAm\n\t\t\t\t\t\ta3WrZNkNj4vNEts/5g/mW16Y3ISY8V7Gk127liMANTcbFoLJMRvcNo5skyVz2nxp\n\t\t\t\t\t\tJ4kppKp5c9ocH+zV7cm5aWUYGwdrfDnGCy/zCX4P0IvmZzffBG57ygHG1MAbTZQG\n\t\t\t\t\t\tcn46v65F8XAWa5xwu+ZfiYCGb5IjJTUYTNgO5+BMx4Mx1Ssd20iohgJ/hnhIlvbd\n\t\t\t\t\t\tqtuAXjgLDULEma+6XhsNxIN7Khy3YEORw5ch8NqnllnbBhKPhTIFspbcIx247Wnu\n\t\t\t\t\t\tIHECAwEAAaNkMGIwQQYDVR0RBDowOIIYbGl2ZS1ub2RlLTEuc2ltaXRpdmUuY29t\n\t\t\t\t\t\thhxodHRwczovL2tlbnRzc28uc2ltaXRpdmUuY29tMB0GA1UdDgQWBBQIVpk9cai3\n\t\t\t\t\t\tQu4eE+cdf+T67ttSKzANBgkqhkiG9w0BAQUFAAOCAQEAoZv+PznzhifNi0Ez9YPk\n\t\t\t\t\t\tYNOBp9zEOIlDtQOE8bsmFdUYEnbJ1GkMcJsJwmU0bIjEV9/g56ygW4D7ZsycLHYu\n\t\t\t\t\t\tMd/v4fyqAQM3xCmZQs92H96nm6Pkv99mRN0oMPIT3Oy2FTy5qWgX1qFBZ+C0TlNn\n\t\t\t\t\t\tgSBq5F5D0I3BkB6oZMgXvUuWDLoU42SM1Ks8/1zL6xxy0QF+qapp6g27MenTgRYU\n\t\t\t\t\t\tg9OevEy4MLX592kL7TWCJ3K/nbnrYF7lqPzHHkvtBFFVfTNleQzKLGdSlIifm/g2\n\t\t\t\t\t\tNFIvl9x747DAi2Vm92ULH9Qgy4/k21c0P8sSJZD+P6nHAB5G2XecceewxYkH4s+z\n\t\t\t\t\t\tcA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://kentsso.simitive.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://kentsso.simitive.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://kentsso.simitive.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://kentsso.simitive.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://kentsso.simitive.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://kentsso.simitive.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol"
        }
      ]
    }
  ],
  [
    "https://iss-openathensla-runtime.swan.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Whitcombe"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:N.Whitcombe@swansea.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nina"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Brown"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:A.T.Brown@swansea.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://iss-openathensla-runtime.swan.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-06-16T13:09:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://iss-openathensla-runtime.swan.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://iss-openathensla-runtime.swan.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "swan.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://iss-openathensla-runtime.swan.ac.uk/oala/images/uk-federation-branding.png",
                    "height": "25",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://iss-openathensla-runtime.swan.ac.uk/oala/images/swansea-university-icon.gif",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Swansea University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDxzCCAq+gAwIBAgIJAKaRp6YdpxbFMA0GCSqGSIb3DQEBBQUAMEsxGzAZBgNV\n\t\t\t\t\t\tBAoTElN3YW5zZWEgVW5pdmVyc2l0eTEsMCoGA1UEAxMjaXNzLW9wZW5hdGhlbnNs\n\t\t\t\t\t\tYS1ydW50aW1lLnN3YW4uYWMudWswHhcNMTQwMzIxMTAzMzI5WhcNMjQwMzE4MTAz\n\t\t\t\t\t\tMzI5WjBLMRswGQYDVQQKExJTd2Fuc2VhIFVuaXZlcnNpdHkxLDAqBgNVBAMTI2lz\n\t\t\t\t\t\tcy1vcGVuYXRoZW5zbGEtcnVudGltZS5zd2FuLmFjLnVrMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAxSGK+XQQj0yhGBm/ig/1JYcAKjOblBds1+DH85ub\n\t\t\t\t\t\t1MasaxAq+Wxo8PkneHtsBZVagc+7mpUjH6LrQBVY2ltWNz8w1Lw3bEIFvkvHrYYb\n\t\t\t\t\t\t+DzMI6vBpyRlGgwZUTQpSFsHUrkEJmS7Y2lGPRCOZGFduvQwa85BmTciympInFcL\n\t\t\t\t\t\t467abYfL7YCjjvjrAL0A7T5v91UvfLkqkV0ZwLWCzs/vZH2z7zd24t4FqsX3DLnA\n\t\t\t\t\t\tEWFaLSmgdP/EEaSL1XHRV7rBEpyNe9aPjYIeL8Y0X0Wm2KHUu/L4er7Rwd6BcVLg\n\t\t\t\t\t\t74CDPps4QC3cfRALzllx/4UiBFpftJ7OTEU/h8A47kl/awIDAQABo4GtMIGqMB0G\n\t\t\t\t\t\tA1UdDgQWBBRta2Fv0weameEGf4FV4KhhXCwFXzB7BgNVHSMEdDBygBRta2Fv0wea\n\t\t\t\t\t\tmeEGf4FV4KhhXCwFX6FPpE0wSzEbMBkGA1UEChMSU3dhbnNlYSBVbml2ZXJzaXR5\n\t\t\t\t\t\tMSwwKgYDVQQDEyNpc3Mtb3BlbmF0aGVuc2xhLXJ1bnRpbWUuc3dhbi5hYy51a4IJ\n\t\t\t\t\t\tAKaRp6YdpxbFMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAIr4duye\n\t\t\t\t\t\t2F9oXAkfotF0kQdAKR9a2xgbsx/qQiKPyuk2QGucPeY1Aw8XfkLcgfw7GzFU8EVf\n\t\t\t\t\t\t3h8Bwu53/UinLh3xOjZxbzPA+Pj76PfkPV9aZNTpE8AZeHM+BTBj94/cNN3CYzWc\n\t\t\t\t\t\tw6Yiz84MqktGMLyScDPi0bKaoLRd5hrzbbu2Uu9ohmVhP9MDMKAFOYuVel8xiat9\n\t\t\t\t\t\t51jvG6uRFNoAE6W4So601BjZMsvOAzUjnTpkdwVBtCRhf8TOlO2JMZN1GaqbzQjC\n\t\t\t\t\t\thbOM1aMGtZOY6ba1luEWp7tuBHQGIdBHJaZyLUjiYpSDquuiYm9oZai2NIksjDq9\n\t\t\t\t\t\tYjbfp1B8p/YQJQw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swansea University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.swan.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Swansea University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idptest.arts.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shib-support@arts.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UAL Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Birt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:j.birt@arts.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Justin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idptest.arts.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-06-24T11:56:04Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEQzCCAyugAwIBAgIJAPSUoUxlNXOCMA0GCSqGSIb3DQEBBQUAMIG3MQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEXMBUGA1UECAwOR3JlYXRlciBMb25kb24xDzANBgNVBAcMBkxvbmRv\n\t\t\t\t\t\tbjEnMCUGA1UECgweVW5pdmVyc2l0eSBvZiB0aGUgQXJ0cywgTG9uZG9uMRQwEgYD\n\t\t\t\t\t\tVQQLDAtJVCBTZXJ2aWNlczEbMBkGA1UEAwwSaWRwdGVzdC5hcnRzLmFjLnVrMSIw\n\t\t\t\t\t\tIAYJKoZIhvcNAQkBFhNzc2xhZG1pbkBhcnRzLmFjLnVrMB4XDTE0MDUyMzEzNTAx\n\t\t\t\t\t\tNFoXDTM0MDYwNzEzNTAxNFowgbcxCzAJBgNVBAYTAkdCMRcwFQYDVQQIDA5HcmVh\n\t\t\t\t\t\tdGVyIExvbmRvbjEPMA0GA1UEBwwGTG9uZG9uMScwJQYDVQQKDB5Vbml2ZXJzaXR5\n\t\t\t\t\t\tIG9mIHRoZSBBcnRzLCBMb25kb24xFDASBgNVBAsMC0lUIFNlcnZpY2VzMRswGQYD\n\t\t\t\t\t\tVQQDDBJpZHB0ZXN0LmFydHMuYWMudWsxIjAgBgkqhkiG9w0BCQEWE3NzbGFkbWlu\n\t\t\t\t\t\tQGFydHMuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCTpA1p\n\t\t\t\t\t\tywFyL2PyQc3aBiEha1Ie3hBkNUwOmmptUPLT0+g/MrJXlkx0QXgLtbaEp97YGzO6\n\t\t\t\t\t\twEbY27djJwzGaq0VDocqt6yZ1aRzg2xN3haSUHQDI3cNhGtjd/K/g9+ZUcI6nXfs\n\t\t\t\t\t\tg+sE43dBal5lRiziNDjKV8SaEjKwe39+alnbFRdR6GD3ROMP+SiY4CNCq42ivNOJ\n\t\t\t\t\t\tyaW2x83qdhNo0Bn8JTm6wU9l7ann1/76LtKO8Z3l5cKcxpVr7b0vdAf81IetQM8S\n\t\t\t\t\t\tsDZ0kTWpYRF3sOpxXiO43D10GdYA7gywPhBlpEWZy67qowQatD6M4Za0/WK7r6sk\n\t\t\t\t\t\tCB//HU/HqpuQRgp5AgMBAAGjUDBOMB0GA1UdDgQWBBRU0koaCOcSqDZ5OK9mbTVe\n\t\t\t\t\t\ty0nIHDAfBgNVHSMEGDAWgBRU0koaCOcSqDZ5OK9mbTVey0nIHDAMBgNVHRMEBTAD\n\t\t\t\t\t\tAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCDAZRXEf7m2IFQfeKiDvjDnW39uCuTRbVS\n\t\t\t\t\t\tV9gb+sww+fKJMY0p9uVXgtt5xEJG3MKlW6ytxSRMtS5eM6pD0/R0/knDRoWdQYwi\n\t\t\t\t\t\tOfFvToZUcu9LEmdFnYV99WxquCVjCD0rnl9nVOPRJ7HW3IwZqDO3fleawh2xHrc+\n\t\t\t\t\t\tNbeWEv2yfDRDehYtTsI/fMBX8tp9u/80mYt8JRvVpmgMs5AaE88/MYZihnFEe31o\n\t\t\t\t\t\tcSv7+YOHKs3p5aBYeuvvTsv1hZMwtD7ehNNzSGwv9S+nfIGQ16B1JRcmXSN14V1+\n\t\t\t\t\t\tBKVZVakKzX6WCxengZ2A8lbx/oQPp5rbxtWkiv9dYMUY2nyQsjGF"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "arts.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idptest.arts.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idptest.arts.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idptest.arts.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idptest.arts.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idptest.arts.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idptest.arts.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idptest.arts.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idptest.arts.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idptest.arts.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idptest.arts.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idptest.arts.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "arts.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEQzCCAyugAwIBAgIJAPSUoUxlNXOCMA0GCSqGSIb3DQEBBQUAMIG3MQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEXMBUGA1UECAwOR3JlYXRlciBMb25kb24xDzANBgNVBAcMBkxvbmRv\n\t\t\t\t\t\tbjEnMCUGA1UECgweVW5pdmVyc2l0eSBvZiB0aGUgQXJ0cywgTG9uZG9uMRQwEgYD\n\t\t\t\t\t\tVQQLDAtJVCBTZXJ2aWNlczEbMBkGA1UEAwwSaWRwdGVzdC5hcnRzLmFjLnVrMSIw\n\t\t\t\t\t\tIAYJKoZIhvcNAQkBFhNzc2xhZG1pbkBhcnRzLmFjLnVrMB4XDTE0MDUyMzEzNTAx\n\t\t\t\t\t\tNFoXDTM0MDYwNzEzNTAxNFowgbcxCzAJBgNVBAYTAkdCMRcwFQYDVQQIDA5HcmVh\n\t\t\t\t\t\tdGVyIExvbmRvbjEPMA0GA1UEBwwGTG9uZG9uMScwJQYDVQQKDB5Vbml2ZXJzaXR5\n\t\t\t\t\t\tIG9mIHRoZSBBcnRzLCBMb25kb24xFDASBgNVBAsMC0lUIFNlcnZpY2VzMRswGQYD\n\t\t\t\t\t\tVQQDDBJpZHB0ZXN0LmFydHMuYWMudWsxIjAgBgkqhkiG9w0BCQEWE3NzbGFkbWlu\n\t\t\t\t\t\tQGFydHMuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCTpA1p\n\t\t\t\t\t\tywFyL2PyQc3aBiEha1Ie3hBkNUwOmmptUPLT0+g/MrJXlkx0QXgLtbaEp97YGzO6\n\t\t\t\t\t\twEbY27djJwzGaq0VDocqt6yZ1aRzg2xN3haSUHQDI3cNhGtjd/K/g9+ZUcI6nXfs\n\t\t\t\t\t\tg+sE43dBal5lRiziNDjKV8SaEjKwe39+alnbFRdR6GD3ROMP+SiY4CNCq42ivNOJ\n\t\t\t\t\t\tyaW2x83qdhNo0Bn8JTm6wU9l7ann1/76LtKO8Z3l5cKcxpVr7b0vdAf81IetQM8S\n\t\t\t\t\t\tsDZ0kTWpYRF3sOpxXiO43D10GdYA7gywPhBlpEWZy67qowQatD6M4Za0/WK7r6sk\n\t\t\t\t\t\tCB//HU/HqpuQRgp5AgMBAAGjUDBOMB0GA1UdDgQWBBRU0koaCOcSqDZ5OK9mbTVe\n\t\t\t\t\t\ty0nIHDAfBgNVHSMEGDAWgBRU0koaCOcSqDZ5OK9mbTVey0nIHDAMBgNVHRMEBTAD\n\t\t\t\t\t\tAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCDAZRXEf7m2IFQfeKiDvjDnW39uCuTRbVS\n\t\t\t\t\t\tV9gb+sww+fKJMY0p9uVXgtt5xEJG3MKlW6ytxSRMtS5eM6pD0/R0/knDRoWdQYwi\n\t\t\t\t\t\tOfFvToZUcu9LEmdFnYV99WxquCVjCD0rnl9nVOPRJ7HW3IwZqDO3fleawh2xHrc+\n\t\t\t\t\t\tNbeWEv2yfDRDehYtTsI/fMBX8tp9u/80mYt8JRvVpmgMs5AaE88/MYZihnFEe31o\n\t\t\t\t\t\tcSv7+YOHKs3p5aBYeuvvTsv1hZMwtD7ehNNzSGwv9S+nfIGQ16B1JRcmXSN14V1+\n\t\t\t\t\t\tBKVZVakKzX6WCxengZ2A8lbx/oQPp5rbxtWkiv9dYMUY2nyQsjGF"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of the Arts London Test"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.arts.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of the Arts London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.carshalton.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpline@carshalton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpline@carshalton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpline"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.carshalton.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-03-11T09:15:13Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkCgAwIBAgIVAK9zq/AGPCsO/yVh6eCXxG1GorxSMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCYxJDAiBgNVBAMMG3NoaWJib2xldGguY2Fyc2hhbHRvbi5hYy51azAeFw0x\n\t\t\t\t\t\tNTAzMjAyMTE0MjlaFw0zNTAzMjAyMTE0MjlaMCYxJDAiBgNVBAMMG3NoaWJib2xl\n\t\t\t\t\t\tdGguY2Fyc2hhbHRvbi5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAMhqQcCsuNuhtnmSRMeocTutCXZkgaYK93fHH6k6jyS3GWlfhpIJisUt4oWH\n\t\t\t\t\t\tQBOFIDjWEFiLh78QatyTEzsJ3sCn/K65j69jEY4AlXFhYLw7Kva+3WOXNGvrxC3X\n\t\t\t\t\t\thW1BbBmowXIs3J5b12huosQH6NR1/7jrZzPxAqtCexmdkmsnkAZdR1BoahuVH5AU\n\t\t\t\t\t\tUcLt70qKKFtP4sNLipZFfij9/voYTefD4+f7qejxjAOGPspDKBy71SJGIn1lAMKa\n\t\t\t\t\t\tEPzBBjUUpXIa4f+LK38ccUtJFbA6+sBzrBEgw4YVTIG919bdtdC6fVsL65gAlZes\n\t\t\t\t\t\tm/EeCZiPAVVzkyrA6MDB3EkM5tcCAwEAAaN9MHswHQYDVR0OBBYEFE69ioHDWu+y\n\t\t\t\t\t\tCvMQGnbrcXvrL4GtMFoGA1UdEQRTMFGCG3NoaWJib2xldGguY2Fyc2hhbHRvbi5h\n\t\t\t\t\t\tYy51a4YyaHR0cHM6Ly9zaGliYm9sZXRoLmNhcnNoYWx0b24uYWMudWsvaWRwL3No\n\t\t\t\t\t\taWJib2xldGgwDQYJKoZIhvcNAQEFBQADggEBACsQILUEknK3w+OYS+nsR8bwaQ1t\n\t\t\t\t\t\t1cFIn13TU4uL0wk+ZqycRZb9FQHgmDwZC550m7XEuT8QJLuS5kA2XulJ+HzD3G5Z\n\t\t\t\t\t\tRLLZ7lHtsLcMI6+w8B414dR2oNCA4C1whGVOC9MVHE3JYRcXqR2c1gAEA1UdFCyH\n\t\t\t\t\t\tX77FHhdWlqqEsZOP+RfYy6pCd7w6KEh1/zMr+rAQhOcr8JzKPHpu3ejGQn0cPZ5C\n\t\t\t\t\t\tTvmDIyDspkoPMxW1M2dUl+g+nIZSqY1gUKdE+4wgvWZ64giL4VqmqsCpf1WmQuok\n\t\t\t\t\t\taZ/E2PZAbR5KW3lPYXM3YF/ym2KBQM0F95HSTqAYWjiMbSVoBVhvRDtt+u0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "carshalton.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.carshalton.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.carshalton.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.carshalton.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.carshalton.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.carshalton.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.carshalton.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.carshalton.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.carshalton.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.carshalton.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.carshalton.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.carshalton.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Carshalton College UK"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "carshalton.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkCgAwIBAgIVAK9zq/AGPCsO/yVh6eCXxG1GorxSMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCYxJDAiBgNVBAMMG3NoaWJib2xldGguY2Fyc2hhbHRvbi5hYy51azAeFw0x\n\t\t\t\t\t\tNTAzMjAyMTE0MjlaFw0zNTAzMjAyMTE0MjlaMCYxJDAiBgNVBAMMG3NoaWJib2xl\n\t\t\t\t\t\tdGguY2Fyc2hhbHRvbi5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAMhqQcCsuNuhtnmSRMeocTutCXZkgaYK93fHH6k6jyS3GWlfhpIJisUt4oWH\n\t\t\t\t\t\tQBOFIDjWEFiLh78QatyTEzsJ3sCn/K65j69jEY4AlXFhYLw7Kva+3WOXNGvrxC3X\n\t\t\t\t\t\thW1BbBmowXIs3J5b12huosQH6NR1/7jrZzPxAqtCexmdkmsnkAZdR1BoahuVH5AU\n\t\t\t\t\t\tUcLt70qKKFtP4sNLipZFfij9/voYTefD4+f7qejxjAOGPspDKBy71SJGIn1lAMKa\n\t\t\t\t\t\tEPzBBjUUpXIa4f+LK38ccUtJFbA6+sBzrBEgw4YVTIG919bdtdC6fVsL65gAlZes\n\t\t\t\t\t\tm/EeCZiPAVVzkyrA6MDB3EkM5tcCAwEAAaN9MHswHQYDVR0OBBYEFE69ioHDWu+y\n\t\t\t\t\t\tCvMQGnbrcXvrL4GtMFoGA1UdEQRTMFGCG3NoaWJib2xldGguY2Fyc2hhbHRvbi5h\n\t\t\t\t\t\tYy51a4YyaHR0cHM6Ly9zaGliYm9sZXRoLmNhcnNoYWx0b24uYWMudWsvaWRwL3No\n\t\t\t\t\t\taWJib2xldGgwDQYJKoZIhvcNAQEFBQADggEBACsQILUEknK3w+OYS+nsR8bwaQ1t\n\t\t\t\t\t\t1cFIn13TU4uL0wk+ZqycRZb9FQHgmDwZC550m7XEuT8QJLuS5kA2XulJ+HzD3G5Z\n\t\t\t\t\t\tRLLZ7lHtsLcMI6+w8B414dR2oNCA4C1whGVOC9MVHE3JYRcXqR2c1gAEA1UdFCyH\n\t\t\t\t\t\tX77FHhdWlqqEsZOP+RfYy6pCd7w6KEh1/zMr+rAQhOcr8JzKPHpu3ejGQn0cPZ5C\n\t\t\t\t\t\tTvmDIyDspkoPMxW1M2dUl+g+nIZSqY1gUKdE+4wgvWZ64giL4VqmqsCpf1WmQuok\n\t\t\t\t\t\taZ/E2PZAbR5KW3lPYXM3YF/ym2KBQM0F95HSTqAYWjiMbSVoBVhvRDtt+u0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Carshalton College UK"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.carshalton.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Carshalton College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://aai-login.hsr.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support Contact"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@hsr.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Servicedesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fr\u00fcchtenicht"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cedric.fruechtenicht@hsr.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Cedric"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Oberli"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:poberli@hsr.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Patrick"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://aai-login.hsr.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2015-09-28T14:02:53Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIJALbnMqADD20yMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGFhaS1sb2dpbi5oc3IuY2gwHhcNMTUwNTE4MDgwMDI4WhcNMTgwNTE3MDgw\nMDI4WjAbMRkwFwYDVQQDExBhYWktbG9naW4uaHNyLmNoMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAtu/T1cjcxHjIj87PNh0gwDTN4R71W53IFXMqjxoq\n+qr2K9NTez+7w45G5/klw/7k8jXhdQA4zoo+bQbvtLaR/8IJAKmZqXOOfw0DveIQ\ngVzCuKkfljcz+Vukemz4k9uGnY3B1yu1pmPzNws9oB60NA1vz0dk4+H/h4QEnf+o\nHi3NfX+nXbywFOG1L4ZqiKdil7oThV9SO3/pmmH+kQs9Qf2jNi49x6ApE5HZ+J6F\nSZr+fkfLBnPLFMwvZzZK4z26QdEkjb1B9O/rxrad91YaE7Uhu5FO76nhKEG2/nCZ\nMB+66WlDYBEM5OYA/aYH9bnRCBVPWLQs6SdA+TXnf90HAQIDAQABo2cwZTBEBgNV\nHREEPTA7ghBhYWktbG9naW4uaHNyLmNohidodHRwczovL2FhaS1sb2dpbi5oc3Iu\nY2gvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFFn0kuDp5MlHsnqDUWsvTCTGM6UA\nMA0GCSqGSIb3DQEBBQUAA4IBAQCj8Hen4EbMbS/ykxE4PV+PPOOR0Hc1H+JsLt+Q\njSXBdZ6RYt1NQ9/WK0KmNap8dsNQ4KhGv1Kb3feR3wgeFeSVJTAEf2IFXhFgNQAe\nl/rDigoS4F7Mv1//1fsUggM5C3VM/8Q3ZhPyU4QbMBXkkLdV1mZwKcvJXwT93SPK\nny+nOXDdmC68IYvONQ+JSTXNOhKbuxQhYLlc5ETq+K/kb6p734trD6NesCOaaNYl\ngeOSWVdj8kw8A9qt+p4/9XxYGGvrcxW49BovsjD5RlaD++RIyap3TDUFIYHkpo48\nVlqG9d3H6ougFWjTlcGEmbCKHbuP6pmxM9POV16FGrrLUPHB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hsr.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-login.hsr.ch:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-login.hsr.ch:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aai-login.hsr.ch/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai-login.hsr.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai-login.hsr.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aai-login.hsr.ch/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-login.hsr.ch:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-login.hsr.ch:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hsr.ch"
              },
              {
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hochschule f\u00fcr Technik Rapperswil"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Applied Sciences Rapperswil"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "HSR - Hochschule f\u00fcr Technik Rapperswil"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "HSR - Hochschule f\u00fcr Technik Rapperswil"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "hsr.ch"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.22336,8.81745"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "152.96.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:620:130::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIJALbnMqADD20yMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGFhaS1sb2dpbi5oc3IuY2gwHhcNMTUwNTE4MDgwMDI4WhcNMTgwNTE3MDgw\nMDI4WjAbMRkwFwYDVQQDExBhYWktbG9naW4uaHNyLmNoMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAtu/T1cjcxHjIj87PNh0gwDTN4R71W53IFXMqjxoq\n+qr2K9NTez+7w45G5/klw/7k8jXhdQA4zoo+bQbvtLaR/8IJAKmZqXOOfw0DveIQ\ngVzCuKkfljcz+Vukemz4k9uGnY3B1yu1pmPzNws9oB60NA1vz0dk4+H/h4QEnf+o\nHi3NfX+nXbywFOG1L4ZqiKdil7oThV9SO3/pmmH+kQs9Qf2jNi49x6ApE5HZ+J6F\nSZr+fkfLBnPLFMwvZzZK4z26QdEkjb1B9O/rxrad91YaE7Uhu5FO76nhKEG2/nCZ\nMB+66WlDYBEM5OYA/aYH9bnRCBVPWLQs6SdA+TXnf90HAQIDAQABo2cwZTBEBgNV\nHREEPTA7ghBhYWktbG9naW4uaHNyLmNohidodHRwczovL2FhaS1sb2dpbi5oc3Iu\nY2gvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFFn0kuDp5MlHsnqDUWsvTCTGM6UA\nMA0GCSqGSIb3DQEBBQUAA4IBAQCj8Hen4EbMbS/ykxE4PV+PPOOR0Hc1H+JsLt+Q\njSXBdZ6RYt1NQ9/WK0KmNap8dsNQ4KhGv1Kb3feR3wgeFeSVJTAEf2IFXhFgNQAe\nl/rDigoS4F7Mv1//1fsUggM5C3VM/8Q3ZhPyU4QbMBXkkLdV1mZwKcvJXwT93SPK\nny+nOXDdmC68IYvONQ+JSTXNOhKbuxQhYLlc5ETq+K/kb6p734trD6NesCOaaNYl\ngeOSWVdj8kw8A9qt+p4/9XxYGGvrcxW49BovsjD5RlaD++RIyap3TDUFIYHkpo48\nVlqG9d3H6ougFWjTlcGEmbCKHbuP6pmxM9POV16FGrrLUPHB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "HSR - Hochschule f\u00fcr Technik Rapperswil"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "HSR - Hochschule f\u00fcr Technik Rapperswil"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hsr.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hsr.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "hsr.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.stokecoll.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@stokecoll.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hodson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:guy.hodson@stokecoll.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Guy"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.stokecoll.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAOCqTm8BSRjHD01zcVqQKEU41GmFMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB4xHDAaBgNVBAMME2lkcC5zdG9rZWNvbGwuYWMudWswHhcNMTUxMTAyMTQz\n\t\t\t\t\t\tMzQxWhcNMzUxMTAyMTQzMzQxWjAeMRwwGgYDVQQDDBNpZHAuc3Rva2Vjb2xsLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoDVAaU0SopZtZfOk\n\t\t\t\t\t\tezqhgxVvoNXc8/sHwoXudaFpMuqDks8JwmeUIdYmEJMTDVe5dblO4bAl0w5XeIOB\n\t\t\t\t\t\t9mMpBeFBNuSICGQIzODFjl0iFua0tZ/Tj5rqhcnhixHze1imu6QR1msdqobnq9e5\n\t\t\t\t\t\tm43/nGDrjTZ0XXt9LHo8AJKlgZwbzWC08UNTFoqezdKwo1LqD0hW8RP7V3FoZ7XU\n\t\t\t\t\t\ty2bToftaFPlPiwYK0B91WidS1lLvo1ll21bMqqJOvkU78oCoachHt0U6colmje2t\n\t\t\t\t\t\t81Coi5E/1mVEKCHFYWwlD029Dx2PCGzXaDvD1lpY/yrny4VkACZIEz9ZnJdWRdzW\n\t\t\t\t\t\tBibIYQIDAQABo20wazAdBgNVHQ4EFgQUcIQ4XgCf+qz/ulow1O31zDs9Mv4wSgYD\n\t\t\t\t\t\tVR0RBEMwQYITaWRwLnN0b2tlY29sbC5hYy51a4YqaHR0cHM6Ly9pZHAuc3Rva2Vj\n\t\t\t\t\t\tb2xsLmFjLnVrL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBBQUAA4IBAQAyAEw9\n\t\t\t\t\t\tukmynMc4xXxu44hcVBF6qgNxC14XKLBbou9Tn64ll47OJh+uKyluSgLfR7Q1WD1J\n\t\t\t\t\t\to1A6GltLT2FJoCZMKUhKogJ2m+Lntc5WH0hkTwAfNRxzCEtXuNR1q0DjH90MIn7G\n\t\t\t\t\t\tX40/IaxIoqB9ykjRkzK0HAIuO1+Fwx5xDorY6OsHPWQHevIFNN7LMLwkFaQDGecE\n\t\t\t\t\t\tJXPWN2dGcIHx9en8OVPkDYdx99gt1+6n+s7ghk8qSlazZCCFYoJryMAApnPj3FbY\n\t\t\t\t\t\tKJyA0eEShvBL36YxCvQD5YPmoDI7hlQ4Erj+Ge8AR1ImHFCHh8h4hif1E7dXG0rS\n\t\t\t\t\t\tcodng9Xuyk8xt0/m"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stokecoll.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.stokecoll.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.stokecoll.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.stokecoll.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.stokecoll.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.stokecoll.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.stokecoll.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.stokecoll.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.stokecoll.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stokecoll.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAOCqTm8BSRjHD01zcVqQKEU41GmFMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB4xHDAaBgNVBAMME2lkcC5zdG9rZWNvbGwuYWMudWswHhcNMTUxMTAyMTQz\n\t\t\t\t\t\tMzQxWhcNMzUxMTAyMTQzMzQxWjAeMRwwGgYDVQQDDBNpZHAuc3Rva2Vjb2xsLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoDVAaU0SopZtZfOk\n\t\t\t\t\t\tezqhgxVvoNXc8/sHwoXudaFpMuqDks8JwmeUIdYmEJMTDVe5dblO4bAl0w5XeIOB\n\t\t\t\t\t\t9mMpBeFBNuSICGQIzODFjl0iFua0tZ/Tj5rqhcnhixHze1imu6QR1msdqobnq9e5\n\t\t\t\t\t\tm43/nGDrjTZ0XXt9LHo8AJKlgZwbzWC08UNTFoqezdKwo1LqD0hW8RP7V3FoZ7XU\n\t\t\t\t\t\ty2bToftaFPlPiwYK0B91WidS1lLvo1ll21bMqqJOvkU78oCoachHt0U6colmje2t\n\t\t\t\t\t\t81Coi5E/1mVEKCHFYWwlD029Dx2PCGzXaDvD1lpY/yrny4VkACZIEz9ZnJdWRdzW\n\t\t\t\t\t\tBibIYQIDAQABo20wazAdBgNVHQ4EFgQUcIQ4XgCf+qz/ulow1O31zDs9Mv4wSgYD\n\t\t\t\t\t\tVR0RBEMwQYITaWRwLnN0b2tlY29sbC5hYy51a4YqaHR0cHM6Ly9pZHAuc3Rva2Vj\n\t\t\t\t\t\tb2xsLmFjLnVrL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBBQUAA4IBAQAyAEw9\n\t\t\t\t\t\tukmynMc4xXxu44hcVBF6qgNxC14XKLBbou9Tn64ll47OJh+uKyluSgLfR7Q1WD1J\n\t\t\t\t\t\to1A6GltLT2FJoCZMKUhKogJ2m+Lntc5WH0hkTwAfNRxzCEtXuNR1q0DjH90MIn7G\n\t\t\t\t\t\tX40/IaxIoqB9ykjRkzK0HAIuO1+Fwx5xDorY6OsHPWQHevIFNN7LMLwkFaQDGecE\n\t\t\t\t\t\tJXPWN2dGcIHx9en8OVPkDYdx99gt1+6n+s7ghk8qSlazZCCFYoJryMAApnPj3FbY\n\t\t\t\t\t\tKJyA0eEShvBL36YxCvQD5YPmoDI7hlQ4Erj+Ge8AR1ImHFCHh8h4hif1E7dXG0rS\n\t\t\t\t\t\tcodng9Xuyk8xt0/m"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Stoke-on-Trent College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.stokecoll.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Stoke-on-Trent College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-04.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-04.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-04.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-04.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-04.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-04.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-04.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-04.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-04.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;04"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;04"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-04.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-04.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJANPtBqZBdS0tMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wNC5sYWRvay51bXUuc2UwHhcNMTIwNjI5MTIwODA5WhcNMjIw\nNjI3MTIwODA5WjAhMR8wHQYDVQQDExZsYWRvazMtMDQubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA5xFv5om6PNpOo9l6kxcd0+KK\nBC/qKPFtgmDrgU5ab/0QUBGwyr5NRQcXBFtuXtLTr1wVlggmJg8ScdC/6WGFaj/6\nsC9OUIxAN18DjXUySvTtLWTPo9QGVNGeTKkanLmuE+ZbkKzMkWqs92BdqcrybB6I\nqP/34M83u0Dl11aQUanBEzp7dddEXvpwjGNUjGhg+7Yp2KIx4BLECXPKH6e7jq+F\njoT7kduaSI/uGqgrWhuOX9fjzQmFn1/nC7ofd6NTRLvX2NmxiACIp+yJ1M7lPfjp\ndF4YRwRRXkkWFcX1b2ZiP/ByQ9imytgi3T+A9e/MX74u1ag4/MI03GbCwt7ANQID\nAQABo2swaTBIBgNVHREEQTA/ghZsYWRvazMtMDQubGFkb2sudW11LnNlhiVodHRw\nczovL2xhZG9rMy0wNC5sYWRvay51bXUuc2UvZ3VpLXNwMB0GA1UdDgQWBBTAG+rA\nGMVRIVIHzxQ9UdKzBjEujjANBgkqhkiG9w0BAQUFAAOCAQEACfVBkZuIyVuDCdV3\nHCmZ2eWfp/htS3tuCig2SABtx7KNR1TAVNRofyM7uBKOxCwI5XLRkoyKUWYfQbSY\nTn3Rl/T5lPkRnJDAHBQJXFtkqB9NLYQc7EtSjxoyYVaxqIwZIkUvZmt1Bk2vTy0H\niSjjrebMwzKsUeJvZvD2OaSO1Q0itMJjwlKydSNCefLVGZ1kGutzoz+jgJr8dw7w\nm5TVPtJ9JYyx7rxk0bE1Q/Z9r1VfWJYRMeEur8OttyxzlJj0gkI6zLgPwyXaDE7p\npsn62LqB/yCbuQgQ9UDHa3SvDgg9HGAEvk+xvT9upqmmvXTP1Afr0gB0EW6PvcVP\nAMLCoA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-04.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-04.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-04.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-04.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-04.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-04.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-04.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-04.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-04.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-04.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.silverchair.com/bates/staging/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:technicaloperations@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:technicaloperations@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Operations"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.silverchair.com/bates/staging/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-02-13T10:07:43Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Silverchair Staging: Bates Visual Guide to Physical Examination"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://batesvisualguide.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Silverchair Science + Communications, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://batesrc.silverchair.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://batesrc.silverchair.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://batesrc.silverchair.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://batesrc.silverchair.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://batesrc.silverchair.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://batesrc.silverchair.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAJ2KkG77HkGAMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\n\t\t\t\t\t\tBAMTF2JhdGVzcmMuc2lsdmVyY2hhaXIuY29tMB4XDTE1MDYwOTE4Mjk0M1oXDTI1\n\t\t\t\t\t\tMDYwNjE4Mjk0M1owIjEgMB4GA1UEAxMXYmF0ZXNyYy5zaWx2ZXJjaGFpci5jb20w\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDmkrPfcl6WOqq9VTTl3W0I\n\t\t\t\t\t\tkY92nqD3bUMEJl2xUZvbfQS5opwkCZX92nDdU8VlWLanmWjCN9pn7v0oNKsznYoU\n\t\t\t\t\t\tnQ3FYoS6AFCuwBxMcM7BPfefOuzQiGb9e29hFPxOrabnuCtU7Qp4lEIxovcPUJWN\n\t\t\t\t\t\tJvnJhkvO6ozN85RYmWK+HAX5k61XqYqWVpOBdLWYygDGT8m9JBmJUr60vHI31VbJ\n\t\t\t\t\t\t1gjlus9jyOB3ZOfDJ+doK+jQQg3Gxux8lcEuS4Peouhb93cWg561XM7VV6Zj8CoC\n\t\t\t\t\t\t0RmRFbPy3Qhmp1bguva9jumIHiJjyRsZ0uwkOp+ztFChLA7WwzTxcKOuO+rC07X7\n\t\t\t\t\t\tAgMBAAGjRTBDMCIGA1UdEQQbMBmCF2JhdGVzcmMuc2lsdmVyY2hhaXIuY29tMB0G\n\t\t\t\t\t\tA1UdDgQWBBSsGjJ8Yd4xoiuTaj9OWTXGLCi2VjANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tDkWLJVnH0A5zbVrVLkzAM1mpmU9DwXpQekNNePid0M1GjXOJj0HRl2gfbHm9qDy5\n\t\t\t\t\t\tWfoZOsJJjeLw/YxiKlb6vY98OY0+hydm65wNt3IoyM5NrcscUk9tHMBVPSntjeI9\n\t\t\t\t\t\tJpY5O/sz+GJ8/LB2jvN5bs6bKBYJbK2akFT5nRsqXmFq/BQSjeO1iiWaJ0DUyx+1\n\t\t\t\t\t\tIng6yhcR+ZP0Y1IMcyg7JpQJez19YSrMvYuoSA3sAwn8qa8oJs8GB4ZYT1m1U0+J\n\t\t\t\t\t\tTmtN8MS1QK7dip9Z28UfFVXYZOAXzKGWbH6hVO1dqYfydZB43D1KBEOgvZSlmCQi\n\t\t\t\t\t\tm1PTokszlb2QuY/86Yar3g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://batesrc.silverchair.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://batesrc.silverchair.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://batesrc.silverchair.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://batesrc.silverchair.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://batesrc.silverchair.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://batesrc.silverchair.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://webauth.njit.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "uis-systems@njit.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "University Information Systems"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "uis-systems@njit.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "University Information Systems"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "uis-systems@njit.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "University Information Systems"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://webauth.njit.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://webauth.njit.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webauth.njit.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://webauth.njit.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://webauth.njit.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://webauth.njit.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "njit.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "New Jersey Institute of Technology"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIG/DCCBeSgAwIBAgIQB/fmHShEQYuz/UoWXr96MzANBgkqhkiG9w0BAQUFADBm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\nMFSqMAoE31SDA9ZeOi1yqg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://webauth.njit.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "New Jersey Institute of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.njit.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "New Jersey Institute of Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://csueastbay.infoready4.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jtesta@inforeadycorp.om"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Testa"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://csueastbay.infoready4.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "InfoReady Corp"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.infoready4.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "InfoReady Corp"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://csueastbay.infoready4.com/Shibboleth.sso/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://csueastbay.infoready4.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://csueastbay.infoready4.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://csueastbay.infoready4.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "InfoReady Review - CSU East Bay"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6zCCAdOgAwIBAgIJAOO9wmxE2PCSMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDGluZm9yZHl3aW4wMjAeFw0xMzEwMjkwNjE0NDlaFw0yMzEwMjcwNjE0NDla\nMBcxFTATBgNVBAMTDGluZm9yZHl3aW4wMjCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAMpdE35LzF2eEaAhLfxtotv6XhMXfkOMbugHq8xk5rhyx7RKS+Ku\nt9wW8Mv2rG7NAJw+8167dP6N2RQKpRBn17FIOhm/cuSNtiTBJtA9QiTEkyN5D1ma\nykJjlD95ymo0XdRDWwz/6IP5v+d95BlfbnlkswWOGOMLxCtaWCSZQ00RJFDKudL5\nIrK+2A1KwF4O+DxqivhdLsd/yA+IjX1efYnT7MPsd7Yyh5wKXKkGbKEg9yAW65Dt\nx2xbBCjDT2PCBhJ4ZuRfUv8whBCT2qgH6+pQ5JBN9ZDz1iGDFp8XfQ27UtzlFdBc\ncjvWmtOh/V35fBXl5LIbJdU/ypJMBwehxbcCAwEAAaM6MDgwFwYDVR0RBBAwDoIM\naW5mb3JkeXdpbjAyMB0GA1UdDgQWBBQTyklRhSLuL0VcI0Nv4tQhZYqHITANBgkq\nhkiG9w0BAQUFAAOCAQEAJyNYKdKAFdp7xvqnjszw+AF3dYl3HQKe5bC0M+gu7G+2\nhJL2D70cFCXXi2bNcdyLsFVPiecMo69QinOP3kqCPNL7S5pSjm48T9bTiRr4WNy1\nhkxJ7nCV++z696YqbE7WYec9LEpcNDnDnmDfQOxvxzdtpIyM3Egw+koKEZu13ebw\nzAs2xgBj3V5YWmzS7nk1wPPJBKpr+9W5xixEGfaKfrrQXayP/LVyN+u/3BjZCZfE\nbfqmalH+rjpJ7ZCck4CQFxCvnLhwl+L5DEuEFXmgTzk7EDb65no+rXaZQd3/IEre\nsazovBHNw8FPYGiOCi2757flvBsb6gW+FbN0SPmtSQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://csueastbay.infoready4.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://csueastbay.infoready4.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://csueastbay.infoready4.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://csueastbay.infoready4.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "InfoReady Review - CSU East Bay"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:incommon:nih.gov",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "CITIAMNIHLoginTeam@mail.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIH Login Team"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "NIHLoginSupport@mail.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIH Login Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "NIHFederationRequest@mail.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIH Federation Request"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:nih.gov",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://itrusteauth.nih.gov/affwebservices/public/saml2sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://citdecadssoweb.cit.nih.gov/affwebservices/public/saml2sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFyTCCBLGgAwIBAgIEUS3McTANBgkqhkiG9w0BAQsFADB/MQswCQYDVQQGEwJV\nUzEYMBYGA1UEChMPVS5TLiBHb3Zlcm5tZW50MQwwCgYDVQQLEwNISFMxIjAgBgNV\nBAsTGUNlcnRpZmljYXRpb24gQXV0aG9yaXRpZXMxJDAiBgNVBAMTG0hIUy1GUEtJ\nLUludGVybWVkaWF0ZS1DQS1FMTAeFw0xNDAzMjExNjA5MjVaFw0xNzAzMjExNjM5\nMjVaMIGAMQswCQYDVQQGEwJVUzEYMBYGA1UEChMPVS5TLiBHb3Zlcm5tZW50MQww\nCgYDVQQLEwNISFMxDDAKBgNVBAsTA05JSDEQMA4GA1UECxMHRGV2aWNlczEpMCcG\nA1UEAxMgc2lnbmluZy1pdHJ1c3RmZWRlcmF0aW9uLm5paC5nb3YwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC+Hv8UwJAvEYleCBBmeC4pNv1y2X9FCk/v\nTRt8xi5X7ynk3iXcCUVMjcYzEWIt4AGKoyAMxJnEIbLI1xVxy/gVfNi9KTvO6PgN\nO0ayiamnxiAi44f/L/SMm4Ikplpdhcb2RQmGMlAuUJHgMtzBRo+g5blk5OVyHzok\njij6rUZp4sY0A16+4A644hST9mxok63H52btrmgB7FwSRV19gxc/+8I6Rzomud41\ntG41TXG6Cyq/PrvssqBB4mp0y5KDi67eyE+oSLOZxOJSd8Bck/XaokENFYxgQnSn\nw2hhFTmzG2FNmGeQZ9h1gzCoOBOdP32dvQ/i0LT78/Sd4Mr54D0/AgMBAAGjggJJ\nMIICRTAOBgNVHQ8BAf8EBAMCBaAwFwYDVR0gBBAwDjAMBgpghkgBZQMCAQMIMIHL\nBggrBgEFBQcBAQSBvjCBuzBSBggrBgEFBQcwAoZGaHR0cDovL2hoc3BraWNybC5t\nYW5hZ2VkLmVudHJ1c3QuY29tL0FJQS9DZXJ0c0lzc3VlZFRvSEhTRW50cnVzdENB\nLnA3YzAgBggrBgEFBQcwAYYUaHR0cDovL29jc3AuZGhocy5nb3YwQwYIKwYBBQUH\nMAGGN2h0dHA6Ly9oaHNwa2lvY3NwLm1hbmFnZWQuZW50cnVzdC5jb20vT0NTUC9I\nSFNFbnRydXN0Q0EwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMIHsBgNV\nHR8EgeQwgeEwQKA+oDyGOmh0dHA6Ly9oaHNwa2ljcmwubWFuYWdlZC5lbnRydXN0\nLmNvbS9DUkxzL0hIU0VudHJ1c3RDQS5jcmwwgZyggZmggZakgZMwgZAxCzAJBgNV\nBAYTAlVTMRgwFgYDVQQKEw9VLlMuIEdvdmVybm1lbnQxDDAKBgNVBAsTA0hIUzEi\nMCAGA1UECxMZQ2VydGlmaWNhdGlvbiBBdXRob3JpdGllczEkMCIGA1UEAxMbSEhT\nLUZQS0ktSW50ZXJtZWRpYXRlLUNBLUUxMQ8wDQYDVQQDEwZDUkwzNjMwHwYDVR0j\nBBgwFoAUTdWqJp4OSL7lRiz44QB0CPr2Q0QwHQYDVR0OBBYEFBQjpWaGyUF2KGRQ\nIkSNJbGGOBHYMA0GCSqGSIb3DQEBCwUAA4IBAQAhxNDlqiv8VoWtkhZlF5ydjFV9\nyUNzalhc9mRnp3Sov3vu8BcGcJvSDqicHRbIlLGoDZYIjyUvFkvsIJ5xfztyMBHS\ne+Rc9L/SeNOVik42h23vfypGL0QfvlnpyHCUzseYZfFo0bIe8RLqFZKiC2FcdAcM\nkE2fjMauvXZQTI266pqnYFlwkFD48llB6wrbjKO9SDBSyeq2gAnxp3BIny7gBU/R\nWGRgzl5q5RbOcAjE63Jx7upsjb2L3QFpKrftvc4c9PApGKXKf7DYj1P4OPgOfDlC\npy4JyFjQZIDX97DqBhQa41A9M/NKJ+UtBAbHXNhyYWgCbMvH8jMRLbhOGPhO"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nih.gov"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "National Institutes of Health"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "National Institutes of Health"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nih.gov/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National Institutes of Health"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp1.turkuamk.fi/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Vina"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:miina.vina@turkuamk.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Miina"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Desk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@turkuamk.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Help"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp1.turkuamk.fi/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.csc.fi/english/institutions/haka/instructions/join/eduGAINRegistrationStatement/"
              }
            ],
            "registration_authority": "http://www.csc.fi/haka",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp1.turkuamk.fi/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "turkuamk.fi"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.tuas.fi/en/about-us/tuas/"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.turkuamk.fi/fi/turun-amk/esittely/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u00c5bo yrkesh\u00f6gskola"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Turku University of Applied Sciences"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Turun ammattikorkeakoulu"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEmzCCA4OgAwIBAgIRANZqNXD6/wnELqTUo3xZV5kwDQYJKoZIhvcNAQELBQAw\nZDELMAkGA1UEBhMCTkwxFjAUBgNVBAgTDU5vb3JkLUhvbGxhbmQxEjAQBgNVBAcT\nCUFtc3RlcmRhbTEPMA0GA1UEChMGVEVSRU5BMRgwFgYDVQQDEw9URVJFTkEgU1NM\nIENBIDIwHhcNMTQxMTA2MDAwMDAwWhcNMTcxMTIxMjM1OTU5WjA+MSEwHwYDVQQL\nExhEb21haW4gQ29udHJvbCBWYWxpZGF0ZWQxGTAXBgNVBAMTEGlkcDEudHVya3Vh\nbWsuZmkwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCtHVA4t7YZJsPU\nsSQf0eRQ8S4HTSZ+UpwQVdHRHzfU5CncoP2LKft4/LmZXXasfzLZJLTr4NPWDuyY\naEdTr6fJe/36FuboIKfbwRhb8LAQ0hC29rqCWPoJKDGsaoCICJKm8ORou5n5UM5G\n7x+YBiMPo8a+PF884Nr8hST465JeEkxD9naGjYkAzjd1tJF1FOfZY4de4OAHrK5w\nRC6hRbXEtZRJSigtJyl2Ql6uHWdQuyZjd8Lnz1mTnNLcPENs0fwOsF5TCRAW+h07\nOE785+2plIc7TUo9azFtS1e4T+VFhbBZ1Jq79r8b6XR/mgMmtYknb3nJJHgianYO\nvMClrOCLAgMBAAGjggFsMIIBaDAfBgNVHSMEGDAWgBRb0IocmjJb4LXdllQb4YYo\nsP22vTAdBgNVHQ4EFgQU9CSDbdlhk4vBYwWYtzQUY1PuEVUwDgYDVR0PAQH/BAQD\nAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMC\nMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1UdHwQzMDEw\nL6AtoCuGKWh0dHA6Ly9jcmwudXNlcnRydXN0LmNvbS9URVJFTkFTU0xDQTIuY3Js\nMGwGCCsGAQUFBwEBBGAwXjA1BggrBgEFBQcwAoYpaHR0cDovL2NydC51c2VydHJ1\nc3QuY29tL1RFUkVOQVNTTENBMi5jcnQwJQYIKwYBBQUHMAGGGWh0dHA6Ly9vY3Nw\nLnVzZXJ0cnVzdC5jb20wGwYDVR0RBBQwEoIQaWRwMS50dXJrdWFtay5maTANBgkq\nhkiG9w0BAQsFAAOCAQEAfuOGiRjCC9BUPBYMn1xZQnFwv+C0KuIhdCQJ2hXCXT/3\nhLN5n7SoFKenPUIQ3jyuzF0SgXZlZyPoOPUtvW+TtK4ztIIK246IWUb5BQUvzUj3\nRt/QNZAJyFYDl+CrTnYxBxF/y6IkNHQvIZGb82wuKLSZdiXq1qzqLMAq499UUBwk\nF7Mg1CgcZSQqvGWAdluOtJ+9XoLVotsK/5euhvQcsYo1AO6CWI+d+eexVIRrYkKv\nRk0r8pW68ywkt5FlYtZ3l5FKymPri7dpJYO0Wq2gcE8IbOl4W/XENLvgS0EPuxpa\naIV/r1hKpwPEjw86BQw8hLueNYlwlJ5GAmA+Xb8zOg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Turun ammattikorkeakoulu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Turku University of Applied Sciences"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u00c5bo yrkesh\u00f6gskola"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.turkuamk.fi"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.turkuamk.fi"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.turkuamk.fi"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Turun ammattikorkeakoulu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Turku University of Applied Sciences"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u00c5bo yrkesh\u00f6gskola"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://atlases.muni.cz/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2011-09-13T08:42:02Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute_value": [
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "kalmar"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "denmark"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "iceland"
              }
            ],
            "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
            "name": "tags",
            "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://atlases.muni.cz/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://atlases.muni.cz/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Form\u00e5let er give adgang til tre atlasser: (1) Dermato-patologi, (2) Foster- og neonatal patologi, (3) Patologi for medicinstuderende. Atlasserne kan bruges som undervisningsmateriale for patologistuderende."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The purpose is to provide access to the three atlases: (1) Dermatopathology, (2) Fetal and Neonatal Pathology, (3) Pathology for Pre-graduate Students of Medicine. The atlases may serve as sources of teaching material for pre-graduate as well as postgraduate students of pathology."
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Patologi-atlasser"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Pathology Images"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://atlases.muni.cz/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Form\u00e5let er give adgang til tre atlasser: (1) Dermato-patologi, (2) Foster- og neonatal patologi, (3) Patologi for medicinstuderende. Atlasserne kan bruges som undervisningsmateriale for patologistuderende."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The purpose is to provide access to the three atlases: (1) Dermatopathology, (2) Fetal and Neonatal Pathology, (3) Pathology for Pre-graduate Students of Medicine. The atlases may serve as sources of teaching material for pre-graduate as well as postgraduate students of pathology."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Patologi-atlasser"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Pathology Images"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://mondo.su.se/Shibboleth.sso",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://mondo.su.se/Shibboleth.sso",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mondo.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mondo.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mondo.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mondo.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mondo.su.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://mondo.su.se/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://mondo.su.se/Shibboleth.sso/WAYF/wavelan",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Mondo \u00e4r en webbaserad l\u00e4r-och samarbetsplattform vid Stockholms universitet."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Mondo is a web based system for learning and collaboration at Stockholm University."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mondo Stockholms universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mondo Stockholm University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "mondo-prod-sp01"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAM4UJR2qKYERMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD21vbmRvLXByb2Qtc3AwMTAeFw0xMDEyMDcwOTUyMjhaFw0yMDEyMDQwOTUy\nMjhaMBoxGDAWBgNVBAMTD21vbmRvLXByb2Qtc3AwMTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBANHDpW8ngm6S+O6mOrOLGoxikroSOp4ClimdSi1Pb4f1\nwH++06xGrPuokxkS/nmSdv2xm4mJHVwr7JeZp3p0ZHX/yxZMCw7s52w0PrN7/e9+\nEy8VVBfDUh86jhMrKfBu+fKq63fW+qnvuFKEL84kkOeED4XvzuhwZf5+qZBhmrH1\n0GJUYTizTjPJQdltNbYVvXu9qzs6LX2P4RIg2H+Tk9bZ8a8fGgjtfvSafkp5i9t+\nJ+ibw7nF/MRPamL59OGBU8djeWboRM/Oieo0Mt4aaO3W2hwbwoq38TaPKiy+VkhO\nAa6RLmbPDTzh41l9gW2Je0lk7ioW+J/c5ozAfEbkeVcCAwEAAaM9MDswGgYDVR0R\nBBMwEYIPbW9uZG8tcHJvZC1zcDAxMB0GA1UdDgQWBBSL7nCk9l9a+y+ESFJPaEWc\nR/E+KjANBgkqhkiG9w0BAQUFAAOCAQEArzbPoh14ZeOaO7KtyQ5b9itZL6XoGgxg\nqDfLT9pSpxeEceZ3RuZZKSO00PhSZnPmku5sERzUsmRusO51lBZa1O5chwSdQ9Wu\nqgf4nRO0eLV1DxrVNJa9YEf1C9EF1/gvroH3tVmxjGx+5MxjNe3ZVeUQU3pwqDmv\nQRqWkgrelnHcniL1hgNABqyvxnP4Gn/vMvkVMNi5pzdG+MHnmZnH7Kv8g0Cd9uNf\n3a0hM0uphP4e9/KSBhFYfswjH0mOvHjXW3/6bbimc+zxs4mNxNWP2sPtIvkCkXHM\nz/E5dFvlHgjgE2ON6BQ/LtWQP5FMV/ZXjsRSINnc12T9AQV6Q4P51Q=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=mondo-prod-sp01"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "mondo-prod-sp01"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAM4UJR2qKYERMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD21vbmRvLXByb2Qtc3AwMTAeFw0xMDEyMDcwOTUyMjhaFw0yMDEyMDQwOTUy\nMjhaMBoxGDAWBgNVBAMTD21vbmRvLXByb2Qtc3AwMTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBANHDpW8ngm6S+O6mOrOLGoxikroSOp4ClimdSi1Pb4f1\nwH++06xGrPuokxkS/nmSdv2xm4mJHVwr7JeZp3p0ZHX/yxZMCw7s52w0PrN7/e9+\nEy8VVBfDUh86jhMrKfBu+fKq63fW+qnvuFKEL84kkOeED4XvzuhwZf5+qZBhmrH1\n0GJUYTizTjPJQdltNbYVvXu9qzs6LX2P4RIg2H+Tk9bZ8a8fGgjtfvSafkp5i9t+\nJ+ibw7nF/MRPamL59OGBU8djeWboRM/Oieo0Mt4aaO3W2hwbwoq38TaPKiy+VkhO\nAa6RLmbPDTzh41l9gW2Je0lk7ioW+J/c5ozAfEbkeVcCAwEAAaM9MDswGgYDVR0R\nBBMwEYIPbW9uZG8tcHJvZC1zcDAxMB0GA1UdDgQWBBSL7nCk9l9a+y+ESFJPaEWc\nR/E+KjANBgkqhkiG9w0BAQUFAAOCAQEArzbPoh14ZeOaO7KtyQ5b9itZL6XoGgxg\nqDfLT9pSpxeEceZ3RuZZKSO00PhSZnPmku5sERzUsmRusO51lBZa1O5chwSdQ9Wu\nqgf4nRO0eLV1DxrVNJa9YEf1C9EF1/gvroH3tVmxjGx+5MxjNe3ZVeUQU3pwqDmv\nQRqWkgrelnHcniL1hgNABqyvxnP4Gn/vMvkVMNi5pzdG+MHnmZnH7Kv8g0Cd9uNf\n3a0hM0uphP4e9/KSBhFYfswjH0mOvHjXW3/6bbimc+zxs4mNxNWP2sPtIvkCkXHM\nz/E5dFvlHgjgE2ON6BQ/LtWQP5FMV/ZXjsRSINnc12T9AQV6Q4P51Q=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=mondo-prod-sp01"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mondo.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mondo.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mondo.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mondo.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://mondo.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://mondo.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mondo.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://mondo.su.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mondo.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://mondo.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ecsg.dch-rp.eu/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fargetta"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:marco.fargetta@ct.infn.it"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:credentials-admin@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marco"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barbera"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:roberto.barbera@ct.infn.it"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:credentials-admin@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roberto"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ecsg.dch-rp.eu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2013-06-10T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INFN Catania"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ct.infn.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INFN Catania"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ecsg.dch-rp.eu/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ecsg.dch-rp.eu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ecsg.dch-rp.eu/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ecsg.dch-rp.eu/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ecsg.dch-rp.eu/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service allows to use on a Grid infrastructure the applications of the DCH-RP Project which provides tools to store and preserve digital cultural heritage."
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Questo servizio permette l'accesso e l'uso delle applicazioni/servizi sviluppati per il progetto europeo DCH-RP che ha come obiettivo quello di fornire strumenti per la memo\n                        rizzazione ed il mantenimento del patrimonio culturale"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "e-Culture Science Gateway"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "e-Culture Science Gateway"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ecsg.dch-rp.eu/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ecsg.dch-rp.eu/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDmjCCAoICCQDgPftvWW8OQDANBgkqhkiG9w0BAQsFADCBjjELMAkGA1UEBhMC\nSVQxDzANBgNVBAgMBlNpY2lseTEQMA4GA1UEBwwHQ2F0YW5pYTEZMBcGA1UECgwQ\nQ29uc29yemlvIENPTUVUQTEXMBUGA1UEAwwOZWNzZy5kY2gtcnAuZXUxKDAmBgkq\nhkiG9w0BCQEWGW1hcmNvLmZhcmdldHRhQGN0LmluZm4uaXQwHhcNMTYwMjEwMTE1\nOTIzWhcNNDYwMjAyMTE1OTIzWjCBjjELMAkGA1UEBhMCSVQxDzANBgNVBAgMBlNp\nY2lseTEQMA4GA1UEBwwHQ2F0YW5pYTEZMBcGA1UECgwQQ29uc29yemlvIENPTUVU\nQTEXMBUGA1UEAwwOZWNzZy5kY2gtcnAuZXUxKDAmBgkqhkiG9w0BCQEWGW1hcmNv\nLmZhcmdldHRhQGN0LmluZm4uaXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQDIGc2CbPsWWTRO10ocj80kmGgG6LyB1hRwtw9qnw1aAD9S47WlwsYK4mZk\n25YGuUCZB05eRpc0xqhGcpzW7BKp6UDZtautsb9CrQENtPn9EUA1boferS5xO3KV\nfVZB9/dgV1NpQfn4rGrpQKTRzhHTSBimD+IiFxPYd2G2tNjUXuPVsAQ1r69cDfat\nHq9gA1/Nfyy4I+ONRUfagncsobp3tR1sKWuExAy66ifeIDMb5SP4Z2Jxd6/NIMUb\nYptcHI3xopV13zJluiFJA41xLWgyH6f0WeZDmcI1paoLzrgXa3KOdPrICPnOxnZ+\nIJBV5K+RAIOgxRm5PT6Ip610kJH5AgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFTI\nCSfKBVmhn3jFM2oI/i31AoBqIQ3Sj0x8aiW69Bd4gLKliS70ldN/mAxKJiamAa8/\nx4FrNcqM6IkFepZFOhc9xwGdwPLvpuY7JsJFAiMgqz21XLkoQPS3MOU+biIUiv1t\nzD4nUF3bC79ZoJUyoUXXs5/KlJoiahILzEpH2Czyk9Teo6seWiJ5ylneG6TGW4OE\nmek7II2Phij/cAQ2qJp3IvEbz4PDhDulL8p9AIs/MbyqZpqTtkni/k/stPvx+Rgx\nZYCBmD9Uk/DCb6YiLrHtA/5RaWibviwBVWYiw6qEClbb6fTo65nNyaXuPy4Urys/\n9gDYtmUJyWOvX6N76rU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ecsg.dch-rp.eu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ecsg.dch-rp.eu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ecsg.dch-rp.eu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ecsg.dch-rp.eu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ecsg.dch-rp.eu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ecsg.dch-rp.eu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "e-Culture Science Gateway"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This service allows to use on a Grid infrastructure the applications of the DCH-RP Project which provides tools to store and preserve digital cultural heritage."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:incommon:usc.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "asbed@usc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Asbed Bedrossian"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shib-admin-l@usc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "security@usc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ITS Security"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "urn:mace:incommon:usc.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.usc.edu:8444/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.usc.edu:8444/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJAIO8BJMy8v25MA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEnNoaWJib2xldGgudXNjLmVkdTAeFw0xMzA3MTUxODM0MTVaFw0yMzA3MTMx\nODM0MTVaMB0xGzAZBgNVBAMTEnNoaWJib2xldGgudXNjLmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALsR/GQRzogc63vGoWk94bSkvK5TYVtQvH9A\nyj7a8XXuQGr0+v/n6ElnjC7ir0TsrgsMizrWZuHNEdFi3ICV7ZATmuomH2IQbU/8\niQ+Bk2y6tS3yaLhXlf8jOgoccGUAQwP/0+OoRNQmx6PzdkWBXjsiMDSIbRJj58L4\nIhTd5MYUYYbVY2JLZtgFXX7ACLkLrzTJhgCr/CkepP6PfTn+Nom+t+x04SQuUF8H\n5W2jwRRvlA1DOL0kZI7LWBarG4W99YHCCC4b5To9tvY+eNZoHCqbHXyYgBUlz4AT\nDJ9SRbU5MizWYWMDvVEklA/M4EQ+F7c8gpAVYt9hquBd3oYNi+MCAwEAAaNbMFkw\nOAYDVR0RBDEwL4ISc2hpYmJvbGV0aC51c2MuZWR1hhl1cm46bWFjZTppbmNvbW1v\nbjp1c2MuZWR1MB0GA1UdDgQWBBSFKUf2/Ha65sgbO2VkfrBkQFzIjTANBgkqhkiG\n9w0BAQUFAAOCAQEAlssx6u6/cU5ucI1TEUfw9sNhVpYyRX6kzAnzNIkyuq1vNv7y\nDFBKbvKlMjuXbxEqLU9pGUgZaRW0yHLTa2Lj001ohk2A/AhhAEoNYJOIeN2w3bFl\nCOY0jAtSyCs9CEK7t6i1+w1jH3CBE1QO8BLHK5jMLkBEuL6KCpshxypyqVxA99cf\nz5Bx1PefOz4/mE6zQrYUwbn1wSlbPnG8VvFHCkPWFYq0fUtt2GFa9/Va4MfzMJO8\nzh419vf+P3WE28wIM1uzuNJnnN1ugTINM0tdncgJnoXGwXPXpDvIDUWBHqHhqiqf\n8bMYQw/J8MvmwVw++cbBCgAi6bEcrOpcge9r1g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "usc.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.usc.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.usc.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.usc.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.usc.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.usc.edu:8444/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.usc.edu:8444/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "usc.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Southern California"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJAIO8BJMy8v25MA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEnNoaWJib2xldGgudXNjLmVkdTAeFw0xMzA3MTUxODM0MTVaFw0yMzA3MTMx\nODM0MTVaMB0xGzAZBgNVBAMTEnNoaWJib2xldGgudXNjLmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALsR/GQRzogc63vGoWk94bSkvK5TYVtQvH9A\nyj7a8XXuQGr0+v/n6ElnjC7ir0TsrgsMizrWZuHNEdFi3ICV7ZATmuomH2IQbU/8\niQ+Bk2y6tS3yaLhXlf8jOgoccGUAQwP/0+OoRNQmx6PzdkWBXjsiMDSIbRJj58L4\nIhTd5MYUYYbVY2JLZtgFXX7ACLkLrzTJhgCr/CkepP6PfTn+Nom+t+x04SQuUF8H\n5W2jwRRvlA1DOL0kZI7LWBarG4W99YHCCC4b5To9tvY+eNZoHCqbHXyYgBUlz4AT\nDJ9SRbU5MizWYWMDvVEklA/M4EQ+F7c8gpAVYt9hquBd3oYNi+MCAwEAAaNbMFkw\nOAYDVR0RBDEwL4ISc2hpYmJvbGV0aC51c2MuZWR1hhl1cm46bWFjZTppbmNvbW1v\nbjp1c2MuZWR1MB0GA1UdDgQWBBSFKUf2/Ha65sgbO2VkfrBkQFzIjTANBgkqhkiG\n9w0BAQUFAAOCAQEAlssx6u6/cU5ucI1TEUfw9sNhVpYyRX6kzAnzNIkyuq1vNv7y\nDFBKbvKlMjuXbxEqLU9pGUgZaRW0yHLTa2Lj001ohk2A/AhhAEoNYJOIeN2w3bFl\nCOY0jAtSyCs9CEK7t6i1+w1jH3CBE1QO8BLHK5jMLkBEuL6KCpshxypyqVxA99cf\nz5Bx1PefOz4/mE6zQrYUwbn1wSlbPnG8VvFHCkPWFYq0fUtt2GFa9/Va4MfzMJO8\nzh419vf+P3WE28wIM1uzuNJnnN1ugTINM0tdncgJnoXGwXPXpDvIDUWBHqHhqiqf\n8bMYQw/J8MvmwVw++cbBCgAi6bEcrOpcge9r1g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Southern California"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.usc.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Southern California"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://smidp.uwstout.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tnst@uwstout.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Darren Hoyland"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://smidp.uwstout.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://smidp.uwstout.edu/SAML/SSOService.aspx?binding=redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://smidp.uwstout.edu/SAML/ArtifactResolutionService.aspx",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uwstout.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Wisconsin - Stout"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGQzCCBSugAwIBAgIQdYe679tqRUWxqWGBWyB7jjANBgkqhkiG9w0BAQUFADBE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\n6zchnxeWCYfmFi6iASRnTMQBMipNMsc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Wisconsin - Stout"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uwstout.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Wisconsin - Stout"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://fsso-qa1.springer.com",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:onlineservice@springer.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Springer Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:caspersupport@springer.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Casper Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://fsso-qa1.springer.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-09-24T12:58:12Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SpringerLink and Springer for R&D (qa1)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://link.springer.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Springer-Verlag London Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "response_location": "https://fsso-qa1.springer.com/federation/SPSloRedirect/metaAlias/SpringerServiceProvider",
              "location": "https://fsso-qa1.springer.com/federation/SPSloRedirect/metaAlias/SpringerServiceProvider",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "response_location": "https://fsso-qa1.springer.com/federation/SPSloPOST/metaAlias/SpringerServiceProvider",
              "location": "https://fsso-qa1.springer.com/federation/SPSloPOST/metaAlias/SpringerServiceProvider",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://fsso-qa1.springer.com/federation/SPSloSoap/metaAlias/SpringerServiceProvider",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "key_size": {
                    "__class__": "http://www.w3.org/2001/04/xmlenc#&KeySize",
                    "text": "128"
                  },
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDpjCCAo4CCQDEC3NoQurXpjANBgkqhkiG9w0BAQUFADCBlDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxDzANBgNVBAgTBkxvbmRvbjEPMA0GA1UEBxMGTG9uZG9uMRgwFgYDVQQKEw9T\n\t\t\t\t\t\tcHJpbmdlciBOYXR1cmUxHjAcBgNVBAMTFWZzc28tcWExLnNwcmluZ2VyLmNvbTEp\n\t\t\t\t\t\tMCcGCSqGSIb3DQEJARYaY2FzcGVyc3VwcG9ydEBzcHJpbmdlci5jb20wHhcNMTUw\n\t\t\t\t\t\tODExMTMwNDA5WhcNMzAwODA3MTMwNDA5WjCBlDELMAkGA1UEBhMCR0IxDzANBgNV\n\t\t\t\t\t\tBAgTBkxvbmRvbjEPMA0GA1UEBxMGTG9uZG9uMRgwFgYDVQQKEw9TcHJpbmdlciBO\n\t\t\t\t\t\tYXR1cmUxHjAcBgNVBAMTFWZzc28tcWExLnNwcmluZ2VyLmNvbTEpMCcGCSqGSIb3\n\t\t\t\t\t\tDQEJARYaY2FzcGVyc3VwcG9ydEBzcHJpbmdlci5jb20wggEiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tAQUAA4IBDwAwggEKAoIBAQDSBZBY3JNf6ymg6Sa7MwlfFZ0sKuhFSZEaR2Nuhzme\n\t\t\t\t\t\t1Rgh7Jerthr9i97fXq2MBLvS5hI14rqFubJhET0QuAaolPlC1NEt4xM4wsjNLzni\n\t\t\t\t\t\tfY/LjY2Jm8WCc4IIjdWPDLoUPiT7Y96XQd3K9hTjRbRXjdluGrIB+NiJcpBq3YSi\n\t\t\t\t\t\tj6FEZC1rhyUcNVNGYUQe612PLVQ/goamlfyCXpSCKL6S1HxHTDgt8EMxKIHrgrUi\n\t\t\t\t\t\tqW6riSYUBW7TqqeOvnYhCBSZA/S/D+7U8xmIBn1i/v+BGudcIAiqlg3opyNFVY37\n\t\t\t\t\t\tVSqcSHq8GMijpjgJeKcOwxBL09/D2xSuTm6MJC4JbM4jAgMBAAEwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBALLDEftdIFmRKY2g9r7vAz2kWu59dePgY549TzvIkjdABjF+HufZ\n\t\t\t\t\t\t2eyPddoN2jM6LGycZ9SS//0/BHC/ClPon0A69+1kygYAWhWI0y7+7DhR34Uu0N3G\n\t\t\t\t\t\tAMeq+VC1zizApD9WWxLw2MVaz2R67AAOIO9C1niOV056FePDV8qA6aut6xhN9fCg\n\t\t\t\t\t\tEp3iXISmuAkyLUVMyTURYGQfm6YtUFeV+OwIN7KZoSqVKR8Ip7R9YL8DVLnoj0wj\n\t\t\t\t\t\tpFbrFKC2mGsR1jg+BCJKDAK/7snX+2UMkI3CjlAiNO13XQF3FsyoVP2+CIKdNV/h\n\t\t\t\t\t\tGf4Gupnkh8oSSqO3d3brgXvHIeU5mlKOGVw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "response_location": "https://fsso-qa1.springer.com/federation/SPMniRedirect/metaAlias/SpringerServiceProvider",
              "location": "https://fsso-qa1.springer.com/federation/SPMniRedirect/metaAlias/SpringerServiceProvider",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "response_location": "https://fsso-qa1.springer.com/federation/SPMniPOST/metaAlias/SpringerServiceProvider",
              "location": "https://fsso-qa1.springer.com/federation/SPMniPOST/metaAlias/SpringerServiceProvider",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "response_location": "https://fsso-qa1.springer.com/federation/SPMniSoap/metaAlias/SpringerServiceProvider",
              "location": "https://fsso-qa1.springer.com/federation/SPMniSoap/metaAlias/SpringerServiceProvider",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://fsso-qa1.springer.com/federation/Consumer/metaAlias/SpringerServiceProvider",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://fsso-qa1.springer.com/federation/Consumer/metaAlias/SpringerServiceProvider",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://fsso-qa1.springer.com/federation/Consumer/ECP/metaAlias/SpringerServiceProvider",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib.lythamsixth.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@blackpool.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shib-tech@blackpool.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.lythamsixth.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-10-19T12:06:12Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEdjCCA16gAwIBAgIJAOeox3UBOO8vMA0GCSqGSIb3DQEBCwUAMIG7MQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjETMBEGA1UECBMKTGFuY2FzaGlyZTEPMA0GA1UEBxMGTHl0aGFtMSIw\n\t\t\t\t\t\tIAYDVQQKExlMeXRoYW0gU2l4dGggRm9ybSBDb2xsZWdlMRQwEgYDVQQLEwtJVCBT\n\t\t\t\t\t\tZXJ2aWNlczEfMB0GA1UEAxMWc2hpYi5seXRoYW1zaXh0aC5hYy51azErMCkGCSqG\n\t\t\t\t\t\tSIb3DQEJARYccG9zdG1hc3RlckBseXRoYW1zaXh0aC5hYy51azAeFw0xNTEwMTYx\n\t\t\t\t\t\tNDIwNDZaFw0yNTEwMTMxNDIwNDZaMIG7MQswCQYDVQQGEwJHQjETMBEGA1UECBMK\n\t\t\t\t\t\tTGFuY2FzaGlyZTEPMA0GA1UEBxMGTHl0aGFtMSIwIAYDVQQKExlMeXRoYW0gU2l4\n\t\t\t\t\t\tdGggRm9ybSBDb2xsZWdlMRQwEgYDVQQLEwtJVCBTZXJ2aWNlczEfMB0GA1UEAxMW\n\t\t\t\t\t\tc2hpYi5seXRoYW1zaXh0aC5hYy51azErMCkGCSqGSIb3DQEJARYccG9zdG1hc3Rl\n\t\t\t\t\t\tckBseXRoYW1zaXh0aC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAL3bcKHTe4mNGr9hCMPc8PwvjYPspPS5MlHOSPLtxMMCFxs7a2mPjrJsoXHG\n\t\t\t\t\t\tq3xE7I/QHAninXZG9FgAjvhpr5poYHg8ZWgPfH/jGV4qScb5kCjPR4AAGMHxb7hD\n\t\t\t\t\t\tUXd4n05M854yKjUz1luIUKe65121L9E08/qvrQ8mUVhtRFIsY+vYZXWDql1IrtQQ\n\t\t\t\t\t\t6fl4Kn+cr829WM4Z/ZKgj7J+EsmR3ejyTFMn9VmQihXkPgeSGTzs+Etv7k1Bn9OF\n\t\t\t\t\t\tVmMeyaUxAVhbYvR+qHbH1iEdNfHJ7ku1XlG5HJ3tvusF7ar5QycTqsoIaCCDJJ5/\n\t\t\t\t\t\t3rvcTpLDqr35aDDdmiH6jogZglsCAwEAAaN7MHkwCQYDVR0TBAIwADAsBglghkgB\n\t\t\t\t\t\thvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYE\n\t\t\t\t\t\tFIUZC6IwXrhL2dZpcBtcSudbPv4cMB8GA1UdIwQYMBaAFIUZC6IwXrhL2dZpcBtc\n\t\t\t\t\t\tSudbPv4cMA0GCSqGSIb3DQEBCwUAA4IBAQAKffu+lOxW1bPF1j18RaGgjB5x58ME\n\t\t\t\t\t\tpM9ocOpqkPLdPkOW4/OehNVNFdLE4jw1p7iPr9Q+dRIRxVl/ewsXnDi7HaIySrja\n\t\t\t\t\t\trriIhi4/j5WBczTN6cjg8gWo4/31PXfS2OwKJ4BTaiVscSCvlIedBM5uIFaX4CwF\n\t\t\t\t\t\tT0ioAwWKcYc3dpEz97w2b5s3JeHyjjrqZjlLkxRuI9U0jxu/j2M+mLl6pdmDIGXL\n\t\t\t\t\t\tXuCbJtyKrqjmkL9TD9qXKQBBDxHCqOmGdJRp5EhUyVoC3u3wFDhaUufSXd6K863r\n\t\t\t\t\t\tjxKoHRU8H+vWtT+cjFopBvaAVyQjqNRoN7zXX5xjecEFsnNkhSgjeZTR"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lythamsixth.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.lythamsixth.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.lythamsixth.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.lythamsixth.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.lythamsixth.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.lythamsixth.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.lythamsixth.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.lythamsixth.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.lythamsixth.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lythamsixth.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://shib.lythamsixth.ac.uk/gif/LSF-Logo-350x64.png",
                    "height": "146",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lytham Sixth Form College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "lythamsixth.ac.uk"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.63.160.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.63.161.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.63.162.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.63.163.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.63.164.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.63.165.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.63.166.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.63.167.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEdjCCA16gAwIBAgIJAOeox3UBOO8vMA0GCSqGSIb3DQEBCwUAMIG7MQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjETMBEGA1UECBMKTGFuY2FzaGlyZTEPMA0GA1UEBxMGTHl0aGFtMSIw\n\t\t\t\t\t\tIAYDVQQKExlMeXRoYW0gU2l4dGggRm9ybSBDb2xsZWdlMRQwEgYDVQQLEwtJVCBT\n\t\t\t\t\t\tZXJ2aWNlczEfMB0GA1UEAxMWc2hpYi5seXRoYW1zaXh0aC5hYy51azErMCkGCSqG\n\t\t\t\t\t\tSIb3DQEJARYccG9zdG1hc3RlckBseXRoYW1zaXh0aC5hYy51azAeFw0xNTEwMTYx\n\t\t\t\t\t\tNDIwNDZaFw0yNTEwMTMxNDIwNDZaMIG7MQswCQYDVQQGEwJHQjETMBEGA1UECBMK\n\t\t\t\t\t\tTGFuY2FzaGlyZTEPMA0GA1UEBxMGTHl0aGFtMSIwIAYDVQQKExlMeXRoYW0gU2l4\n\t\t\t\t\t\tdGggRm9ybSBDb2xsZWdlMRQwEgYDVQQLEwtJVCBTZXJ2aWNlczEfMB0GA1UEAxMW\n\t\t\t\t\t\tc2hpYi5seXRoYW1zaXh0aC5hYy51azErMCkGCSqGSIb3DQEJARYccG9zdG1hc3Rl\n\t\t\t\t\t\tckBseXRoYW1zaXh0aC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAL3bcKHTe4mNGr9hCMPc8PwvjYPspPS5MlHOSPLtxMMCFxs7a2mPjrJsoXHG\n\t\t\t\t\t\tq3xE7I/QHAninXZG9FgAjvhpr5poYHg8ZWgPfH/jGV4qScb5kCjPR4AAGMHxb7hD\n\t\t\t\t\t\tUXd4n05M854yKjUz1luIUKe65121L9E08/qvrQ8mUVhtRFIsY+vYZXWDql1IrtQQ\n\t\t\t\t\t\t6fl4Kn+cr829WM4Z/ZKgj7J+EsmR3ejyTFMn9VmQihXkPgeSGTzs+Etv7k1Bn9OF\n\t\t\t\t\t\tVmMeyaUxAVhbYvR+qHbH1iEdNfHJ7ku1XlG5HJ3tvusF7ar5QycTqsoIaCCDJJ5/\n\t\t\t\t\t\t3rvcTpLDqr35aDDdmiH6jogZglsCAwEAAaN7MHkwCQYDVR0TBAIwADAsBglghkgB\n\t\t\t\t\t\thvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYE\n\t\t\t\t\t\tFIUZC6IwXrhL2dZpcBtcSudbPv4cMB8GA1UdIwQYMBaAFIUZC6IwXrhL2dZpcBtc\n\t\t\t\t\t\tSudbPv4cMA0GCSqGSIb3DQEBCwUAA4IBAQAKffu+lOxW1bPF1j18RaGgjB5x58ME\n\t\t\t\t\t\tpM9ocOpqkPLdPkOW4/OehNVNFdLE4jw1p7iPr9Q+dRIRxVl/ewsXnDi7HaIySrja\n\t\t\t\t\t\trriIhi4/j5WBczTN6cjg8gWo4/31PXfS2OwKJ4BTaiVscSCvlIedBM5uIFaX4CwF\n\t\t\t\t\t\tT0ioAwWKcYc3dpEz97w2b5s3JeHyjjrqZjlLkxRuI9U0jxu/j2M+mLl6pdmDIGXL\n\t\t\t\t\t\tXuCbJtyKrqjmkL9TD9qXKQBBDxHCqOmGdJRp5EhUyVoC3u3wFDhaUufSXd6K863r\n\t\t\t\t\t\tjxKoHRU8H+vWtT+cjFopBvaAVyQjqNRoN7zXX5xjecEFsnNkhSgjeZTR"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lytham Sixth Form College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lythamsixth.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Blackpool and The Fylde College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://grouper.idem.garr.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Help"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem-help@garr.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IDEM"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://grouper.idem.garr.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2015-04-21T14:30:22Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUYTvnXW3b3991IXgqQUMkP+nhKqkwDQYJKoZIhvcNAQEF\nBQAwHzEdMBsGA1UEAwwUZ3JvdXBlci5pZGVtLmdhcnIuaXQwHhcNMTUwMzMwMjIx\nMzAwWhcNMzUwMzMwMjIxMzAwWjAfMR0wGwYDVQQDDBRncm91cGVyLmlkZW0uZ2Fy\nci5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM7913BgHLAXXvsj\n37Sg8o8tjoXNo/C13zueCqiIJKsu2qhpwiy7KpgLADpCzLFArgT0r/aup0saMFfx\ntUa8et39E0TfPwNBLeI77TUt7QE/NHtVwDph8d0ocizAxqJC1yhUMSuwDzRU/U5H\nY1qGJ6NrmzYqG4dKNr5CC+FUhDfdSn/UJ8o95PLV7xkqpDCcXf2WVSSmGAlR1jDP\nrdE9PcfNSvNzA71EaYTdlUXr/MadlNFf7H7rgEyZwqHrIQGjizpcWsPrZW1k0ZlB\npgLjZFK5w0lzcS5Qt0gjdYJvdmTlyt2AZ4XurrKGMaAFNc/004DMnQYG1EYxr0kr\nLoCQV3kCAwEAAaNvMG0wHQYDVR0OBBYEFPnHU6MSgDLEwrBmW9dmMwBp/YStMEwG\nA1UdEQRFMEOCFGdyb3VwZXIuaWRlbS5nYXJyLml0hitodHRwczovL2dyb3VwZXIu\naWRlbS5nYXJyLml0L2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBBQUAA4IBAQB6\nX8cCYmz+iKywoiMIlXxMGRXtACODRIWh8jdUqyJwUdHqvmSPnaHSjW41By4wZcFx\nGRwURHaJfFqpG6JMFbIIlBmmdroQ02vWWalA9bhShgBhbGiHbKw4Clma9n7jDFtT\nUTEYR6Riveae/n9/PYBQrFnrMTsoV/0ig20VI70bTyY4wBkTTJgwYNon+MpMGp34\nN34CsdueAafyNMLr+BdNqmDpbLUncKxGU0z56M5r1xD/oYpWzm3asUHqPuojtFlb\nKwS+Xn3HU5Hd928ljFR+l+62LhqN8zb5SaNCJkfDkGlZU0RZEAYAWq7v5mk3A5oh\nKYJMKvnMhrAnlcxegh90"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "garr.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://grouper.idem.garr.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://grouper.idem.garr.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Attribute Authority per IDEM by Consortium GARR"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Attribute Authority for IDEM by Consortium GARR"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.garr.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.garr.it/b/eng"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consortium GARR"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consortium GARR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://captivelan-test.it.su.se/Shibboleth.sso",
    {
      "entity_id": "https://captivelan-test.it.su.se/Shibboleth.sso",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://captivelan-test.it.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://captivelan-test.it.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://captivelan-test.it.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://captivelan-test.it.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://captivelan-test.it.su.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://captivelan-test.it.su.se/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://captivelan-test.it.su.se/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://captivelan-test.it.su.se/Shibboleth.sso/WAYF/wavelan",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://captivelan-test.it.su.se/Shibboleth.sso/WAYF/wavelan",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://captivelan-test.it.su.se/Shibboleth.sso/WAYF/idp.secure.su.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://captivelan-test.it.su.se/Shibboleth.sso/WAYF/idp.it.su.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://captivelan-test.it.su.se/Shibboleth.sso/SWAMID",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://captivelan-test.it.su.se/Shibboleth.sso/WAYF/wavelan-test",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://captivelan-test.it.su.se/Shibboleth.sso/WAYF/wavelan-test",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "cpgw-lab01.it.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJALBncbJG3wsYMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE2NwZ3ctbGFiMDEuaXQuc3Uuc2UwHhcNMTIwMzEzMTQxOTI1WhcNMjIwMzEx\nMTQxOTI1WjAeMRwwGgYDVQQDExNjcGd3LWxhYjAxLml0LnN1LnNlMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA56U5HB9fy3fqVfLdreUVdk/E5XMTZcLb\nRNxXOQM/Wmbg+daAIAPar49jDUZ+gJ3rS6Vn1KbNwaKerbGtutojdrtKPkHBWT7O\n/oLuBePY26+coYzHrjjVoRoIsCvpFpEq/e66HPP/Fb77Po2fI7lJgZ1daqLw2wWE\nHE/wj8sq+H6KQJzcS5ts4v7UxqSMy9pwG4sIc4BoGDJGq38ZFWhRFiyLFf6oshVW\nNRBXoH9DMCWcs8No6MROC/fTyRHl9zVBzcKvPl28hNkOdQLfMC/c9i2gLj+IC9yw\nmWQc7wOSV/clDbYwjl8+GPjLR1fFGA4DYzTo+tq+CI/gy26qXopeYQIDAQABo0Ew\nPzAeBgNVHREEFzAVghNjcGd3LWxhYjAxLml0LnN1LnNlMB0GA1UdDgQWBBTLWYM+\nqGSaqwwGeBogeJUkShYBlTANBgkqhkiG9w0BAQUFAAOCAQEATepYFMmK30pDq4I8\nbde/SrGXNIKqr3TB6wLXVMBrta1bwGmJmnxJBu4Cf17ShbEBRyjnKML7/oGs/p2r\nMsBu74xlWAett9sUkwOg0A2C2EzJB8OrO0pUaFgFYZbaW8OQVZvSqmkvTQcIh2ZC\npFBtfAzUJ9y40T++z6D0P948oN3/4kbtkQvcllNVjxVfAG8eafGcrXJx60/aN7As\np63AVSlYluX3+fdIHqVDx/AlXll4KlcPLiVRIXZd9C0WYi4I0hbw0GiWngU/GLaC\n+OAkMXA0RUsY5c2IBzCrkktrakl1fh3RnJZcvG8QDi6kz5WRbWD1z6HsFSNURiUf\n68eknw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=cpgw-lab01.it.su.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://captivelan-test.it.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://captivelan-test.it.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://captivelan-test.it.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://captivelan-test.it.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://captivelan-test.it.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://captivelan-test.it.su.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://captivelan-test.it.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://captivelan-test.it.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://captivelan-test.it.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://captivelan-test.it.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib-idp.siu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shib-support@siu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SIUC Shibboleth Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shib-support@siu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SIUC Shibboleth Admin"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shib-support@siu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SIUC Shibboleth Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib-idp.siu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib-idp.siu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-idp.siu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-idp.siu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib-idp.siu.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-idp.siu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.siu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "siu.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Southern Illinois University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAIJcn4M3RZTxxXP7hVa6qv+n806fMA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEHNoaWItaWRwLnNpdS5lZHUwHhcNMTMwMjIxMTk0ODMw\nWhcNMzMwMjIxMTk0ODMwWjAbMRkwFwYDVQQDExBzaGliLWlkcC5zaXUuZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAi6kE0NfGNu9kkPAXlJSHJhFU\nFSYuqnXRdpf6I56tXJYeDJ+vr/a4C9V/nOIJqpqf0E5XZxOkHshL+rG7NPOe002/\n3mmzwLtKCc4IhgEX54Yrz2WQ3x7eAAtkKHF2n85PV0oJh7/co9oMq+2V45hSrAEq\n06j4zEE4mdEbFu8XlJdsmRo7GKj5UX7Uxh7ayp8irzsBkSFSvj8UpvWuQgHgqAhR\nDUXo2zgqys8WniWX3FtoUJ9evol230GAi4otycfPAEqzAckLlSIE48le5hq9+pgm\nTJ9qHZlvZqMEpY4mCzyYD1eznjZooJ9oMjbfql5BpJGP0KmgQS8TJ7JotDslnQID\nAQABo2cwZTBEBgNVHREEPTA7ghBzaGliLWlkcC5zaXUuZWR1hidodHRwczovL3No\naWItaWRwLnNpdS5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFGaJCIGrvLic\ncpyzSKZZZYGSHuqlMA0GCSqGSIb3DQEBBQUAA4IBAQBbAUGIyzryzCV4WlTVCpwE\nlKzam10cB0FEuIlJZBuhV7RAF4dlB98utwB/oLo6yDU6SGjBmZBc2rjji00HPCLF\nNNscde+Nh2GJ2Th3JO7TzEXGIeyZ2779daPRNUldWn0e/PSuljXlOv9Fxdde5FZN\nxSVY5pXQEXc1rjR6hSYZJNSkwMpipp/l7uIbvTrUicPHIXBlOgHCfxjnZD7KCZNU\nTHhkLPoiTD6LKEMsf5E4vm24y70NfsQDbLRt8xO4JXec8wK05K/D2dFkvqZgrF0s\nJcNjbx+tHm0hFfpjX8J2OY+FfSw71mQ7vmgKpoVv+QesTzYaFqfZIv1ZG25t5Ga9"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Southern Illinois University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.siu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Southern Illinois University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.silverchair.com/spie/production/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ShibbolethAdmin@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Laseter"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jlaseter@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Josh"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.silverchair.com/spie/production/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-07-20T07:40:58Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Silverchair Production: International Society for Optics and Photonics (SPIE)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://spiedigitallibrary.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Silverchair Science + Communications, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://spiedigitallibrary.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://spiedigitallibrary.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://spiedigitallibrary.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://spiedigitallibrary.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://spiedigitallibrary.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://spiedigitallibrary.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJALDmz160GZUgMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHNjbTYtZDVwdm0td2ViMS5zY3NsLmludDAeFw0xMjA3MTkxNzIyMjRaFw0y\n\t\t\t\t\t\tMjA3MTcxNzIyMjRaMCMxITAfBgNVBAMTGHNjbTYtZDVwdm0td2ViMS5zY3NsLmlu\n\t\t\t\t\t\tdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKy1suWo6bSOBOft6isd\n\t\t\t\t\t\tNMjOmCiY/er3+zb7H4DEC71X76DUTN+BNYbPCvYzcgncAoFIMftH3OL1+2ku1zpX\n\t\t\t\t\t\t+eHXPAmPX85cMIsnQG0mRFF67+Aieg/dSXPUg7H/4gV/qanlUX238A96pS/zf/aT\n\t\t\t\t\t\tDKq/HB6wvb4UDB6874ZHkhlzsBmF6giQh3DsiyvQaMbw41oAIR/GReDZnu1yx7+u\n\t\t\t\t\t\tUPzAwpLnqY/lrAnl1vyGmoxjNbwNnxCo6WjusiEtoQcd7Ted+oHjvi910FQI+7kI\n\t\t\t\t\t\tb4Cj8Iqb5uZ0iQ60mzOuBTzMJgb+OYuQINPO8719Q/8Nf7YTgm5jCw0y4EZe4Otu\n\t\t\t\t\t\twmUCAwEAAaNGMEQwIwYDVR0RBBwwGoIYc2NtNi1kNXB2bS13ZWIxLnNjc2wuaW50\n\t\t\t\t\t\tMB0GA1UdDgQWBBRDU2Ew8E7Xwa6XxKtPysNZNS59vDANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAc91ruViikIw39jO3H0vYGk87IHE7x1F0ymeRlHJ/NsJ3oVIFrNFbwEy5CaIg\n\t\t\t\t\t\tsS/0L+UwyBT/bW9r7XsYNHGaip3ONHH3bd05L4mxoBplKHJK9yhrw0Y0RHwPqfTr\n\t\t\t\t\t\tVUJmsexW3CSDAShJ6SWydIqF2GfUGYz5WH6FH7Nsa9GwctxRGIn8/kDz0CpbsD8F\n\t\t\t\t\t\tKRlv5RUWyPVOZr2sFhHsooERzhY6eRrj5wttWe/RKOiHYyC9zWDLrNktYF1MC/vz\n\t\t\t\t\t\tMMW8uxvLMg0NdQGLtSclrrUCUf5qcoRvdAxkdoCxbJgrqNSI9xOnOmdQgwfDwQbu\n\t\t\t\t\t\t4lzH+AGLbg18D+2I28Y7IdPrUg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://spiedigitallibrary.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://spiedigitallibrary.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://spiedigitallibrary.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://spiedigitallibrary.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://spiedigitallibrary.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://spiedigitallibrary.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://beta.shib.manchester.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-support@manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chalabi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:r.chalabi@manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rachid"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://beta.shib.manchester.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-05-06T16:24:24Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEgjCCA2qgAwIBAgIRAO3e2IFUJk3Dd0HJQF3ZKBUwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xNDA0MjQwMDAwMDBaFw0xNzA0MjMyMzU5NTlaMEgxITAfBgNV\n\t\t\t\t\t\tBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEjMCEGA1UEAxMaYmV0YS5zaGli\n\t\t\t\t\t\tLm1hbmNoZXN0ZXIuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQC7j0ZmPbM3J6dknUGo1FQF1QZP10Bitu67DJPczwy8WYSqXBhTQ3F7HIVNLAVH\n\t\t\t\t\t\tgeMs/ZfGi7ct3d5HBPyg84rcPRHXjfgWOFnokwUxcI7ZEIooUc7wtNk1LZ/89mzR\n\t\t\t\t\t\tA4icZm+w7XCatdkYTSFQR6SN6n9mWDGMY//H7KDBwLxbqA0UfFIrmGwhW1kjnoaL\n\t\t\t\t\t\tJ3PTl2I8dXYNKXnvsZxtJM1n9XwGSlU7YipLhyjlyQ35JAXs1qeAtXYRNFTjV2Gx\n\t\t\t\t\t\tEXjhejs9XrXNb0w8Gvv3iKwxzK8WWVFXh0udsKoeb/r84o98jDiDoSap9Lo5qDsJ\n\t\t\t\t\t\tkIJd5dYCaP40h3qQHpFJiL7FAgMBAAGjggF3MIIBczAfBgNVHSMEGDAWgBQMvZNo\n\t\t\t\t\t\tDPPeq6NJays3V0fqkOO57TAdBgNVHQ4EFgQUZIEkV81JvNOr4jmDXZhTgfg+MFQw\n\t\t\t\t\t\tDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUH\n\t\t\t\t\t\tAwEGCCsGAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIB\n\t\t\t\t\t\tMDoGA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVS\n\t\t\t\t\t\tRU5BU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDov\n\t\t\t\t\t\tL2NydC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGG\n\t\t\t\t\t\tGmh0dHA6Ly9vY3NwLnRjcy50ZXJlbmEub3JnMCUGA1UdEQQeMByCGmJldGEuc2hp\n\t\t\t\t\t\tYi5tYW5jaGVzdGVyLmFjLnVrMA0GCSqGSIb3DQEBBQUAA4IBAQC7+XD/MdO9ubLu\n\t\t\t\t\t\tVRzKDAiKfSGwMwAxOEyijhv2UzOxD3ISxji1UsCHPWXs30woYDgdKBC5WIVD8qYV\n\t\t\t\t\t\tDszYqyLcRu2mwUtL/He30t8XqFZj4Y9R9faP+0321G1vn61SiUXe+c81reveIy5y\n\t\t\t\t\t\tp8sry9f/ENJJpXNEEllrmi15TW32kSNAjoyV7OFiI1QAdfypeX2oAkyeL504UvZe\n\t\t\t\t\t\tCYUUMyN2JAp7PTGI7WkP72AZFSMxzUZCj9UteUkKYMEXfOiKvqp6MEPSTNLVrXHn\n\t\t\t\t\t\tHETktGDZoR6CEfyI6TGfxD6muKXhDZvFEm1t3z/Lc3mtZT0MSRwzcmQf/I27UnlD\n\t\t\t\t\t\trjZU5UPE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "manchester.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://beta.shib.manchester.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://beta.shib.manchester.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://beta.shib.manchester.ac.uk/shibboleth-idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://beta.shib.manchester.ac.uk/shibboleth-idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://beta.shib.manchester.ac.uk/shibboleth-idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://beta.shib.manchester.ac.uk/shibboleth-idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://beta.shib.manchester.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://beta.shib.manchester.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "manchester.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://login.manchester.ac.uk/disco/logo-16x16-m.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://login.manchester.ac.uk/disco/logo-80x34-ltd.png",
                    "height": "34",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The University of Manchester (Beta)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "manchester.ac.uk"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "man.ac.uk"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "mbs.ac.uk"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "mimas.ac.uk"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "mib.ac.uk"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "mbs-worldwide.ac.uk"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.465624,-2.233193"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.474881,-2.233593"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.236237,-2.306421"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.480372,-2.24893"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.572576,-1.315923"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.462436,-2.227711"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.429749,-2.230049"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.445089,-2.278115"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.490592,-2.28839"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.487545,-2.323424"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.427332,-2.247825"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:46.23145,6.050119"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.88.0.0/16"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEgjCCA2qgAwIBAgIRAO3e2IFUJk3Dd0HJQF3ZKBUwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xNDA0MjQwMDAwMDBaFw0xNzA0MjMyMzU5NTlaMEgxITAfBgNV\n\t\t\t\t\t\tBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEjMCEGA1UEAxMaYmV0YS5zaGli\n\t\t\t\t\t\tLm1hbmNoZXN0ZXIuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQC7j0ZmPbM3J6dknUGo1FQF1QZP10Bitu67DJPczwy8WYSqXBhTQ3F7HIVNLAVH\n\t\t\t\t\t\tgeMs/ZfGi7ct3d5HBPyg84rcPRHXjfgWOFnokwUxcI7ZEIooUc7wtNk1LZ/89mzR\n\t\t\t\t\t\tA4icZm+w7XCatdkYTSFQR6SN6n9mWDGMY//H7KDBwLxbqA0UfFIrmGwhW1kjnoaL\n\t\t\t\t\t\tJ3PTl2I8dXYNKXnvsZxtJM1n9XwGSlU7YipLhyjlyQ35JAXs1qeAtXYRNFTjV2Gx\n\t\t\t\t\t\tEXjhejs9XrXNb0w8Gvv3iKwxzK8WWVFXh0udsKoeb/r84o98jDiDoSap9Lo5qDsJ\n\t\t\t\t\t\tkIJd5dYCaP40h3qQHpFJiL7FAgMBAAGjggF3MIIBczAfBgNVHSMEGDAWgBQMvZNo\n\t\t\t\t\t\tDPPeq6NJays3V0fqkOO57TAdBgNVHQ4EFgQUZIEkV81JvNOr4jmDXZhTgfg+MFQw\n\t\t\t\t\t\tDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUH\n\t\t\t\t\t\tAwEGCCsGAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIB\n\t\t\t\t\t\tMDoGA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVS\n\t\t\t\t\t\tRU5BU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDov\n\t\t\t\t\t\tL2NydC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGG\n\t\t\t\t\t\tGmh0dHA6Ly9vY3NwLnRjcy50ZXJlbmEub3JnMCUGA1UdEQQeMByCGmJldGEuc2hp\n\t\t\t\t\t\tYi5tYW5jaGVzdGVyLmFjLnVrMA0GCSqGSIb3DQEBBQUAA4IBAQC7+XD/MdO9ubLu\n\t\t\t\t\t\tVRzKDAiKfSGwMwAxOEyijhv2UzOxD3ISxji1UsCHPWXs30woYDgdKBC5WIVD8qYV\n\t\t\t\t\t\tDszYqyLcRu2mwUtL/He30t8XqFZj4Y9R9faP+0321G1vn61SiUXe+c81reveIy5y\n\t\t\t\t\t\tp8sry9f/ENJJpXNEEllrmi15TW32kSNAjoyV7OFiI1QAdfypeX2oAkyeL504UvZe\n\t\t\t\t\t\tCYUUMyN2JAp7PTGI7WkP72AZFSMxzUZCj9UteUkKYMEXfOiKvqp6MEPSTNLVrXHn\n\t\t\t\t\t\tHETktGDZoR6CEfyI6TGfxD6muKXhDZvFEm1t3z/Lc3mtZT0MSRwzcmQf/I27UnlD\n\t\t\t\t\t\trjZU5UPE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The University of Manchester (Beta)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.manchester.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Manchester"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.unipi.gr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mavropodi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rosa@unipi.gr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rosa"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@unipi.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University of Piraeus NOC"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.unipi.gr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEZjCCA06gAwIBAgIRAIo9PfLIpcxScL7s/HwtDqYwDQYJKoZIhvcNAQEFBQAw\n                            NjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n                            IFNTTCBDQTAeFw0xMzA2MTcwMDAwMDBaFw0xNjA2MTYyMzU5NTlaMDoxITAfBgNV\n                            BAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEVMBMGA1UEAxMMaWRwLnVuaXBp\n                            LmdyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2RRKBgMguSIc82gv\n                            GEtnoiJDzwvk48Xc8QAEN1GWe8kUCR16aFHkCEH1CD5Zs23qzdq7O7x6Dh0Bgfqp\n                            XDL+12Qj/OzV6h9AjvDXZOJ93kW0OAKf3nX2ew8e1Vn17pe7jonlOYHasR3LRdBx\n                            UClIqfWXtVfYuNV0ULtx5OL8o9gVvsIRHXg99eVdRlzISp5l+yvVFllE8aZOoRaX\n                            fGEHR9S0l4n9tLNEDpGa1sHbeH+cI+GUpbMavc0OoNtXaLVR1V+edMHsszchF/2Q\n                            ZIHtVXj0gR//mIPl8sfzaT9HPJKhgBOTgkcCR1LvNeRXw3p/AyIEPiCsXliUvIpH\n                            sC6v1QIDAQABo4IBaTCCAWUwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH6pDj\n                            ue0wHQYDVR0OBBYEFLIWRJWXCeyP6IwGeGcES/Har0hZMA4GA1UdDwEB/wQEAwIF\n                            oDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAi\n                            BgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAxMC+g\n                            LaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNybDBt\n                            BggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVu\n                            YS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8vb2NzcC50\n                            Y3MudGVyZW5hLm9yZzAXBgNVHREEEDAOggxpZHAudW5pcGkuZ3IwDQYJKoZIhvcN\n                            AQEFBQADggEBAD4DeOCwaQ5/a/woSH8UlW/dlSmkbcCYKScjzx8Xq6EG8Sc5X0zd\n                            FlkN847W4zwrJ2N6WZq4PYFcO6JoR0mVfUwE9A/B8Hi1IvEQGkKtR62CSBDmZIMC\n                            qS1+8+CTEK8+Y6Mw0JC8nNzIfyyVA4lhnSaxitGmrw9LQYQ/ZdunDZFv17KidpB0\n                            2lOu89ACMkFnbZX8HupjgSGKptozrw+cNtpYJIOosJ0OLb6x5bB1IAUvdz7NCDLf\n                            8gxesMwGkGUu1rajPOV0Q77M09CGb94+/N9KndnCEHPnqi6L2DSi0Al/4zXgrv+Q\n                            PbUa3MIF7HIzuiNXpv6/9O0asdXCOmyaUkY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unipi.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unipi.gr:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unipi.gr:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.unipi.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unipi.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.unipi.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unipi.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unipi.gr:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unipi.gr:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unipi.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEZjCCA06gAwIBAgIRAIo9PfLIpcxScL7s/HwtDqYwDQYJKoZIhvcNAQEFBQAw\n                            NjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n                            IFNTTCBDQTAeFw0xMzA2MTcwMDAwMDBaFw0xNjA2MTYyMzU5NTlaMDoxITAfBgNV\n                            BAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEVMBMGA1UEAxMMaWRwLnVuaXBp\n                            LmdyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2RRKBgMguSIc82gv\n                            GEtnoiJDzwvk48Xc8QAEN1GWe8kUCR16aFHkCEH1CD5Zs23qzdq7O7x6Dh0Bgfqp\n                            XDL+12Qj/OzV6h9AjvDXZOJ93kW0OAKf3nX2ew8e1Vn17pe7jonlOYHasR3LRdBx\n                            UClIqfWXtVfYuNV0ULtx5OL8o9gVvsIRHXg99eVdRlzISp5l+yvVFllE8aZOoRaX\n                            fGEHR9S0l4n9tLNEDpGa1sHbeH+cI+GUpbMavc0OoNtXaLVR1V+edMHsszchF/2Q\n                            ZIHtVXj0gR//mIPl8sfzaT9HPJKhgBOTgkcCR1LvNeRXw3p/AyIEPiCsXliUvIpH\n                            sC6v1QIDAQABo4IBaTCCAWUwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH6pDj\n                            ue0wHQYDVR0OBBYEFLIWRJWXCeyP6IwGeGcES/Har0hZMA4GA1UdDwEB/wQEAwIF\n                            oDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAi\n                            BgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAxMC+g\n                            LaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNybDBt\n                            BggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVu\n                            YS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8vb2NzcC50\n                            Y3MudGVyZW5hLm9yZzAXBgNVHREEEDAOggxpZHAudW5pcGkuZ3IwDQYJKoZIhvcN\n                            AQEFBQADggEBAD4DeOCwaQ5/a/woSH8UlW/dlSmkbcCYKScjzx8Xq6EG8Sc5X0zd\n                            FlkN847W4zwrJ2N6WZq4PYFcO6JoR0mVfUwE9A/B8Hi1IvEQGkKtR62CSBDmZIMC\n                            qS1+8+CTEK8+Y6Mw0JC8nNzIfyyVA4lhnSaxitGmrw9LQYQ/ZdunDZFv17KidpB0\n                            2lOu89ACMkFnbZX8HupjgSGKptozrw+cNtpYJIOosJ0OLb6x5bB1IAUvdz7NCDLf\n                            8gxesMwGkGUu1rajPOV0Q77M09CGb94+/N9KndnCEHPnqi6L2DSi0Al/4zXgrv+Q\n                            PbUa3MIF7HIzuiNXpv6/9O0asdXCOmyaUkY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Piraeus"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u03a0\u03b1\u03bd\u03b5\u03c0\u03b9\u03c3\u03c4\u03ae\u03bc\u03b9\u03bf \u03a0\u03b5\u03b9\u03c1\u03b1\u03b9\u03ac"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unipi.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unipi.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Piraeus"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u03a0\u03b1\u03bd\u03b5\u03c0\u03b9\u03c3\u03c4\u03ae\u03bc\u03b9\u03bf \u03a0\u03b5\u03b9\u03c1\u03b1\u03b9\u03ac"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.mba.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lear"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dble@mba.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lear"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dble@mba.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.mba.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-07-16T15:47:41Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDeDCCAmACCQC//ypb/YRuTTANBgkqhkiG9w0BAQUFADB+MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEOMAwGA1UECAwFRGV2b24xETAPBgNVBAcMCFBseW1vdXRoMTQwMgYDVQQKDCtU\n\t\t\t\t\t\taGUgTWFyaW5lIEJpb2xvZ2ljYWwgQXNzb2NpYXRpb24gb2YgdGhlIFVLMRYwFAYD\n\t\t\t\t\t\tVQQDDA1pZHAubWJhLmFjLnVrMB4XDTE0MDcxNDEwNTg1MloXDTM0MDcwOTEwNTg1\n\t\t\t\t\t\tMlowfjELMAkGA1UEBhMCR0IxDjAMBgNVBAgMBURldm9uMREwDwYDVQQHDAhQbHlt\n\t\t\t\t\t\tb3V0aDE0MDIGA1UECgwrVGhlIE1hcmluZSBCaW9sb2dpY2FsIEFzc29jaWF0aW9u\n\t\t\t\t\t\tIG9mIHRoZSBVSzEWMBQGA1UEAwwNaWRwLm1iYS5hYy51azCCASIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEBBQADggEPADCCAQoCggEBAMrLs4qNhaeMVehDUdMdHKNkzu6FdEIv7+I+fK1N\n\t\t\t\t\t\txQEY7/xH4ei0+3szIy9AYFnFq6jQD/gvWg2tQmrzksuUcZPluWv+p1Oa8uAXf/8v\n\t\t\t\t\t\to4Nl1kbrw8lPf+QfFdtkRbgNwWQGPb9B46l8WctyyE7gIZMG/3kL13FKMkx2B51c\n\t\t\t\t\t\t1t1VTdiOEP6+v/TuhQuzk+uczWtQb9JvpSplo25BtLiIobm/aKUtr48vD+yNhEm8\n\t\t\t\t\t\tKFw9/HENeeCMqrs7+UNSbwyxQA289rVLo0X2mQYKllOt9GSB7TA9QqbogI6aFQg9\n\t\t\t\t\t\tYcGgLu1r+VUV4tSJDTyWObs/o0FRWj+OAszT7UnhAU2I/D0CAwEAATANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEANkSL3XK8hSm3z0HVikjTUXTKtv3VLPJqhhMddR9iyxVDoHff\n\t\t\t\t\t\tnbiO1UlJV2QXxlVbRODZ3cwgjj4SHQFRpX3/2K5dK4WONGhxE37SNNtFrpdW37uv\n\t\t\t\t\t\tMsaxlRzd8U7RgHyQQW1SlYgjDJt10S8Wh4Ztx3tlpMm/aXZyoRKryuUXK16VbEA6\n\t\t\t\t\t\tUBYyypbXGq9dHlR/Hln5yEchjXlQe62dG/19UdqC5nC60eFtnSgmMWiLnJO3DjwD\n\t\t\t\t\t\tcnhP7ImWStAG8MeUbq7PpoEfB29LFlAyelI4VkG6ms51DGE3ApJ5M1My6aAkhKXi\n\t\t\t\t\t\t+x2qLGn4QG1NifGc7iGgas5AQdopZwumKy8d6A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mba.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.mba.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.mba.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.mba.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.mba.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.mba.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.mba.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.mba.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.mba.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.mba.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.mba.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.mba.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mba.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://idp.mba.ac.uk/idp/images/logo.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idp.mba.ac.uk/idp/images/logo-icon.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The Marine Biological Association of the UK"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDeDCCAmACCQC//ypb/YRuTTANBgkqhkiG9w0BAQUFADB+MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEOMAwGA1UECAwFRGV2b24xETAPBgNVBAcMCFBseW1vdXRoMTQwMgYDVQQKDCtU\n\t\t\t\t\t\taGUgTWFyaW5lIEJpb2xvZ2ljYWwgQXNzb2NpYXRpb24gb2YgdGhlIFVLMRYwFAYD\n\t\t\t\t\t\tVQQDDA1pZHAubWJhLmFjLnVrMB4XDTE0MDcxNDEwNTg1MloXDTM0MDcwOTEwNTg1\n\t\t\t\t\t\tMlowfjELMAkGA1UEBhMCR0IxDjAMBgNVBAgMBURldm9uMREwDwYDVQQHDAhQbHlt\n\t\t\t\t\t\tb3V0aDE0MDIGA1UECgwrVGhlIE1hcmluZSBCaW9sb2dpY2FsIEFzc29jaWF0aW9u\n\t\t\t\t\t\tIG9mIHRoZSBVSzEWMBQGA1UEAwwNaWRwLm1iYS5hYy51azCCASIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEBBQADggEPADCCAQoCggEBAMrLs4qNhaeMVehDUdMdHKNkzu6FdEIv7+I+fK1N\n\t\t\t\t\t\txQEY7/xH4ei0+3szIy9AYFnFq6jQD/gvWg2tQmrzksuUcZPluWv+p1Oa8uAXf/8v\n\t\t\t\t\t\to4Nl1kbrw8lPf+QfFdtkRbgNwWQGPb9B46l8WctyyE7gIZMG/3kL13FKMkx2B51c\n\t\t\t\t\t\t1t1VTdiOEP6+v/TuhQuzk+uczWtQb9JvpSplo25BtLiIobm/aKUtr48vD+yNhEm8\n\t\t\t\t\t\tKFw9/HENeeCMqrs7+UNSbwyxQA289rVLo0X2mQYKllOt9GSB7TA9QqbogI6aFQg9\n\t\t\t\t\t\tYcGgLu1r+VUV4tSJDTyWObs/o0FRWj+OAszT7UnhAU2I/D0CAwEAATANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEANkSL3XK8hSm3z0HVikjTUXTKtv3VLPJqhhMddR9iyxVDoHff\n\t\t\t\t\t\tnbiO1UlJV2QXxlVbRODZ3cwgjj4SHQFRpX3/2K5dK4WONGhxE37SNNtFrpdW37uv\n\t\t\t\t\t\tMsaxlRzd8U7RgHyQQW1SlYgjDJt10S8Wh4Ztx3tlpMm/aXZyoRKryuUXK16VbEA6\n\t\t\t\t\t\tUBYyypbXGq9dHlR/Hln5yEchjXlQe62dG/19UdqC5nC60eFtnSgmMWiLnJO3DjwD\n\t\t\t\t\t\tcnhP7ImWStAG8MeUbq7PpoEfB29LFlAyelI4VkG6ms51DGE3ApJ5M1My6aAkhKXi\n\t\t\t\t\t\t+x2qLGn4QG1NifGc7iGgas5AQdopZwumKy8d6A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Marine Biological Association of the UK"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mba.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Marine Biological Association of the United Kingdom"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ibt.cas.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Van\u00ed\u010dek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vanicekp@utia.cas.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ibt.cas.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2016-03-22T16:52:02Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/avcr"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUMPAWv713tZR1Gu1dYDN+R/Ff2aswDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOaWRwLmlidC5jYXMuY3owHhcNMTYwMzE4MDczMjQ2WhcN\nMzYwMzE4MDczMjQ2WjAZMRcwFQYDVQQDEw5pZHAuaWJ0LmNhcy5jejCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIZTEMLujf7WZuKhRO3O/ZSjXa9CE/Hg\nOiqfPWv8l/K+hbpfd4pO3mP1Y5BUx5PxmOYosN/XGjFQyEBTNePalBVAPrq98Alr\n9uQIwQuzDda/Ypk0KDS9y+R+5j85k6QE5jFdzlb6bpQmoQNBmqvSHfJjYDFhz2fy\njqML1GfunwdfkiFxwYtX1jQtBaxzp5f5ptEPo4LI7KUkqoNqHtZDIG7oLZYy7yTR\nNTgcPOm7wkUTcfo8U4968FDk2x9/z6TudUMEgl8ToVGYz4D6880B9gLPaAH/XuyL\nqliSQeVTOD6Or1Xt1Utu0bF4RnqroqRHCLV1DLFWSZMKQrRtjJKwJtkCAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOaWRwLmlidC5jYXMuY3qGJWh0dHBzOi8vaWRwLmlidC5j\nYXMuY3ovaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFIUiOnNKx9kW0PEFpI0WvFAA\negsvMA0GCSqGSIb3DQEBBQUAA4IBAQAsSfb08Y4xlav74IcDid7OZbM2pDW4lZeM\ncdUgixAMQdMCmRkb2rmwz2QhuGLeKCgID6/EIlJBOMozAZP/2PG+TZh/22CcN9fj\nCWCc+akxGbMW1FCgE5VZ8OMqFLVUzvh5fkhCDLc8BmKmafeRCS9b2wnu8rnDNaPv\nmI8BViNwcRds9xmIN0lPkW9eI0QeCz9HEiywiig2MDA2OEQ1uxB56lrCfs5+sU07\na2eDWPSwOGAqw0PDUVJcxcxL0XpG6YEdnbFWwo9g4WbjlGJNRVPtECyIymTIpEia\nRz/AYiVVKMJBhTjfy5Qt2syX09PrzoS6djp4aeuSoc+NZPnM8v+8"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ibt.cas.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ibt.cas.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ibt.cas.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ibt.cas.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ibt.cas.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ibt.cas.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ibt.cas.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ibt.cas.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ibt.cas.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ibt.cas.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ibt.cas.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ibt.cas.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ibt.cas.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ibt.cas.cz/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ibt.cas.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider IBT AV CR employees."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance BT\u00da AV \u010cR"
                  }
                ],
                "logo": [
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-btu-44.png",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  },
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-btu-366.png",
                    "height": "366",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "524"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Biotechnology CAS, v.v.i."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Biotechnologick\u00fd \u00fastav AV \u010cR, v.v.i."
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUMPAWv713tZR1Gu1dYDN+R/Ff2aswDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOaWRwLmlidC5jYXMuY3owHhcNMTYwMzE4MDczMjQ2WhcN\nMzYwMzE4MDczMjQ2WjAZMRcwFQYDVQQDEw5pZHAuaWJ0LmNhcy5jejCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIZTEMLujf7WZuKhRO3O/ZSjXa9CE/Hg\nOiqfPWv8l/K+hbpfd4pO3mP1Y5BUx5PxmOYosN/XGjFQyEBTNePalBVAPrq98Alr\n9uQIwQuzDda/Ypk0KDS9y+R+5j85k6QE5jFdzlb6bpQmoQNBmqvSHfJjYDFhz2fy\njqML1GfunwdfkiFxwYtX1jQtBaxzp5f5ptEPo4LI7KUkqoNqHtZDIG7oLZYy7yTR\nNTgcPOm7wkUTcfo8U4968FDk2x9/z6TudUMEgl8ToVGYz4D6880B9gLPaAH/XuyL\nqliSQeVTOD6Or1Xt1Utu0bF4RnqroqRHCLV1DLFWSZMKQrRtjJKwJtkCAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOaWRwLmlidC5jYXMuY3qGJWh0dHBzOi8vaWRwLmlidC5j\nYXMuY3ovaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFIUiOnNKx9kW0PEFpI0WvFAA\negsvMA0GCSqGSIb3DQEBBQUAA4IBAQAsSfb08Y4xlav74IcDid7OZbM2pDW4lZeM\ncdUgixAMQdMCmRkb2rmwz2QhuGLeKCgID6/EIlJBOMozAZP/2PG+TZh/22CcN9fj\nCWCc+akxGbMW1FCgE5VZ8OMqFLVUzvh5fkhCDLc8BmKmafeRCS9b2wnu8rnDNaPv\nmI8BViNwcRds9xmIN0lPkW9eI0QeCz9HEiywiig2MDA2OEQ1uxB56lrCfs5+sU07\na2eDWPSwOGAqw0PDUVJcxcxL0XpG6YEdnbFWwo9g4WbjlGJNRVPtECyIymTIpEia\nRz/AYiVVKMJBhTjfy5Qt2syX09PrzoS6djp4aeuSoc+NZPnM8v+8"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Biotechnology CAS, v.v.i."
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Biotechnologick\u00fd \u00fastav AV \u010cR, v.v.i."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ibt.cas.cz/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ibt.cas.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Biotechnology CAS"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Biotechnologick\u00fd \u00fastav AV \u010cR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.infn.it/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai-support@lists.infn.it"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fasanelli"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Enrico.M.V.Fasanelli@le.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Enrico Maria Vincenzo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Maselli"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Dael.Maselli@lnf.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Grandi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Claudio.Grandi@bo.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Claudio"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.infn.it/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2011-11-28T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.infn.it/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.infn.it/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.infn.it/saml2/idp/ArtifactResolutionService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://web.infn.it/CCR/index.php/i-progetti/aai/federazione-idem"
                  }
                ],
                "description": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti dell'INFN"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for INFN users"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.infn.it/utils/infnLogo80x80.png",
                    "lang": "it",
                    "height": "79",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idp.infn.it/utils/infnLogo80x80.png",
                    "lang": "en",
                    "height": "79",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idp.infn.it/utils/infnLogo16x16.png",
                    "lang": "it",
                    "height": "15",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.infn.it/utils/infnLogo16x16.png",
                    "lang": "en",
                    "height": "15",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INFN - Istituto Nazionale di Fisica Nucleare"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INFN - National Institute for Nuclear Physics"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "infn.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDtTCCAp2gAwIBAgIJAOU29OWoolW3MA0GCSqGSIb3DQEBBQUAMEUxFDASBgNV\nBAMTC2lkcC5pbmZuLml0MREwDwYDVQQLEwhJTkZOLUFBSTENMAsGA1UEChMESU5G\nTjELMAkGA1UEBhMCSVQwHhcNMTQwNDE0MTQ1NzI2WhcNNDEwODI5MTQ1NzI2WjBF\nMRQwEgYDVQQDEwtpZHAuaW5mbi5pdDERMA8GA1UECxMISU5GTi1BQUkxDTALBgNV\nBAoTBElORk4xCzAJBgNVBAYTAklUMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\nCgKCAQEAxTXQ7OFlyqDxcDkdUgPXtKrHw2vUkKuGkEMpQrrK/PU/emzT13Jualti\n38jV4NTSBSIXc7P3PTTUsfnk3o+IAej1JKNlQ2klqFDvPiwl9sKFh4Pd66K0g6eb\nGunsRZtR5LJLMJrrqOhRiLZdAcJzB4RxZsqSYxz0EDw6S5r6w6Sgm4xiupviC9gI\nNAzpTkjFR78dbJ7fDzvvVUXxPz1T4awL01RCt0s/05fHeWM1I4cPjoVSB0t6wzv0\nCfaWWlid3I6yyFWiFYeVGvn7eeqhvRckthumYOayL18Ri+S2vxYkDqDcY6b6y2OW\nYhFZ1VTosUoUBPhwXyCYYJ2wAmi2VwIDAQABo4GnMIGkMB0GA1UdDgQWBBROEkiq\nrjIVFsHZKsnYbh+xPNmilDB1BgNVHSMEbjBsgBROEkiqrjIVFsHZKsnYbh+xPNmi\nlKFJpEcwRTEUMBIGA1UEAxMLaWRwLmluZm4uaXQxETAPBgNVBAsTCElORk4tQUFJ\nMQ0wCwYDVQQKEwRJTkZOMQswCQYDVQQGEwJJVIIJAOU29OWoolW3MAwGA1UdEwQF\nMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBALVVWVWP9nrWlmU37KbTE3kuqJWptGma\nDS2uuOg5RN5lGevQvVu4cac23qaZZ+TN+b6WDXuhEfmVJzBYczxByVeGEvew0fHg\nRRMZLqST6j2gyb89qzNNFyTcyRZ/5Z7jXWjrnDp3pOLNvrr9BhVojoC2F7EYjSdd\ndwq2pb++9FiHglwSTl5WV+V4ZuNUMemY8jzhqayOK6UuwdL61UE4dPGKnlCgMaiY\nVST86HkiqFh9oOJ8D6jtlk695pRaz1h3ajxwB9zOa2VAWEsi40P2tZIzY3ek25wT\nM2vuvHO4YsOmkAOxj2Wk/itj5MnK1tT0u840b61Q/j4SJGuKLe4Tzzg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDtTCCAp2gAwIBAgIJAOU29OWoolW3MA0GCSqGSIb3DQEBBQUAMEUxFDASBgNV\nBAMTC2lkcC5pbmZuLml0MREwDwYDVQQLEwhJTkZOLUFBSTENMAsGA1UEChMESU5G\nTjELMAkGA1UEBhMCSVQwHhcNMTQwNDE0MTQ1NzI2WhcNNDEwODI5MTQ1NzI2WjBF\nMRQwEgYDVQQDEwtpZHAuaW5mbi5pdDERMA8GA1UECxMISU5GTi1BQUkxDTALBgNV\nBAoTBElORk4xCzAJBgNVBAYTAklUMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\nCgKCAQEAxTXQ7OFlyqDxcDkdUgPXtKrHw2vUkKuGkEMpQrrK/PU/emzT13Jualti\n38jV4NTSBSIXc7P3PTTUsfnk3o+IAej1JKNlQ2klqFDvPiwl9sKFh4Pd66K0g6eb\nGunsRZtR5LJLMJrrqOhRiLZdAcJzB4RxZsqSYxz0EDw6S5r6w6Sgm4xiupviC9gI\nNAzpTkjFR78dbJ7fDzvvVUXxPz1T4awL01RCt0s/05fHeWM1I4cPjoVSB0t6wzv0\nCfaWWlid3I6yyFWiFYeVGvn7eeqhvRckthumYOayL18Ri+S2vxYkDqDcY6b6y2OW\nYhFZ1VTosUoUBPhwXyCYYJ2wAmi2VwIDAQABo4GnMIGkMB0GA1UdDgQWBBROEkiq\nrjIVFsHZKsnYbh+xPNmilDB1BgNVHSMEbjBsgBROEkiqrjIVFsHZKsnYbh+xPNmi\nlKFJpEcwRTEUMBIGA1UEAxMLaWRwLmluZm4uaXQxETAPBgNVBAsTCElORk4tQUFJ\nMQ0wCwYDVQQKEwRJTkZOMQswCQYDVQQGEwJJVIIJAOU29OWoolW3MAwGA1UdEwQF\nMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBALVVWVWP9nrWlmU37KbTE3kuqJWptGma\nDS2uuOg5RN5lGevQvVu4cac23qaZZ+TN+b6WDXuhEfmVJzBYczxByVeGEvew0fHg\nRRMZLqST6j2gyb89qzNNFyTcyRZ/5Z7jXWjrnDp3pOLNvrr9BhVojoC2F7EYjSdd\ndwq2pb++9FiHglwSTl5WV+V4ZuNUMemY8jzhqayOK6UuwdL61UE4dPGKnlCgMaiY\nVST86HkiqFh9oOJ8D6jtlk695pRaz1h3ajxwB9zOa2VAWEsi40P2tZIzY3ek25wT\nM2vuvHO4YsOmkAOxj2Wk/itj5MnK1tT0u840b61Q/j4SJGuKLe4Tzzg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEZDCCA0ygAwIBAgIRAJtYpZkrXh+6+4/H9lRGN+gwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xMzExMDcwMDAwMDBaFw0xNjEyMDMyMzU5NTlaMDkxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEUMBIGA1UEAxMLaWRwLmluZm4u\naXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDEhXjZzNhibw+wWO18\na1xsZv+SwEKvfLeDcS+wmkkjt537rJmVJH3NMGRQHxlADQ4VIJHXi5rC7R3tQjHi\ngcxoitPryb02DsrpTz8wNbqF6cY5I02xV2gDjvVZIjBUFEzH2Qq2AvZDlSv2pINk\nAW8NALfk5M8j6yukd35Wxm+EugwlAEaYnGyE7dHpM3AyFJlK+yp0guh1YwGVz4LT\nxI23eHNsdxiJmDSq2ac57D6tmQgUuzj/s5PJOP9n8wDK3YXc48RW8UwQXDxP/o8U\nWo+ZkcAeNYVpeaSyme2Do/us36Vtk44mL13Sh5MjAplSC2rJdSD2V62eomgTZxsr\nX62BAgMBAAGjggFoMIIBZDAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3V0fqkOO5\n7TAdBgNVHQ4EFgQUvAzDM5m+wp/rK4ScoCezlzF27i8wDgYDVR0PAQH/BAQDAgWg\nMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMCIG\nA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1UdHwQzMDEwL6At\noCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3JsMG0G\nCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3MudGVyZW5h\nLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9vY3NwLnRj\ncy50ZXJlbmEub3JnMBYGA1UdEQQPMA2CC2lkcC5pbmZuLml0MA0GCSqGSIb3DQEB\nBQUAA4IBAQBclu01pFdY9/QUnNh89d5BuYj/4Rd9JG8cjTnzjU1+Zb+QHSmUNlk0\n15vebyx30FjbnnCH8NBpiPMG63osofR3Bp098yqV1+W9MGekflromp9mF5w098xL\n313ysJX+29u9uDIWYiQhEYASOxbsubAwX0EZaPL1mwFJVsXzYVTKbrFBHpRthU1c\n6njn9Aks4jqeE30Md3nA720jkc3gjcYU4t0eI/m2dVsTwfnwTJh7SjXS2GrzsNU1\ncDhA29FRWYWUwT0z3fA1EDvmYpfP926yoYcrrwguDJzz7BVjMKsHLD/jn8zb3W0v\njp7JtavGgA6UwGLX5KnnpPeICQozxORx"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        },
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.infn.it/shib13/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDtTCCAp2gAwIBAgIJAOU29OWoolW3MA0GCSqGSIb3DQEBBQUAMEUxFDASBgNV\nBAMTC2lkcC5pbmZuLml0MREwDwYDVQQLEwhJTkZOLUFBSTENMAsGA1UEChMESU5G\nTjELMAkGA1UEBhMCSVQwHhcNMTQwNDE0MTQ1NzI2WhcNNDEwODI5MTQ1NzI2WjBF\nMRQwEgYDVQQDEwtpZHAuaW5mbi5pdDERMA8GA1UECxMISU5GTi1BQUkxDTALBgNV\nBAoTBElORk4xCzAJBgNVBAYTAklUMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\nCgKCAQEAxTXQ7OFlyqDxcDkdUgPXtKrHw2vUkKuGkEMpQrrK/PU/emzT13Jualti\n38jV4NTSBSIXc7P3PTTUsfnk3o+IAej1JKNlQ2klqFDvPiwl9sKFh4Pd66K0g6eb\nGunsRZtR5LJLMJrrqOhRiLZdAcJzB4RxZsqSYxz0EDw6S5r6w6Sgm4xiupviC9gI\nNAzpTkjFR78dbJ7fDzvvVUXxPz1T4awL01RCt0s/05fHeWM1I4cPjoVSB0t6wzv0\nCfaWWlid3I6yyFWiFYeVGvn7eeqhvRckthumYOayL18Ri+S2vxYkDqDcY6b6y2OW\nYhFZ1VTosUoUBPhwXyCYYJ2wAmi2VwIDAQABo4GnMIGkMB0GA1UdDgQWBBROEkiq\nrjIVFsHZKsnYbh+xPNmilDB1BgNVHSMEbjBsgBROEkiqrjIVFsHZKsnYbh+xPNmi\nlKFJpEcwRTEUMBIGA1UEAxMLaWRwLmluZm4uaXQxETAPBgNVBAsTCElORk4tQUFJ\nMQ0wCwYDVQQKEwRJTkZOMQswCQYDVQQGEwJJVIIJAOU29OWoolW3MAwGA1UdEwQF\nMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBALVVWVWP9nrWlmU37KbTE3kuqJWptGma\nDS2uuOg5RN5lGevQvVu4cac23qaZZ+TN+b6WDXuhEfmVJzBYczxByVeGEvew0fHg\nRRMZLqST6j2gyb89qzNNFyTcyRZ/5Z7jXWjrnDp3pOLNvrr9BhVojoC2F7EYjSdd\ndwq2pb++9FiHglwSTl5WV+V4ZuNUMemY8jzhqayOK6UuwdL61UE4dPGKnlCgMaiY\nVST86HkiqFh9oOJ8D6jtlk695pRaz1h3ajxwB9zOa2VAWEsi40P2tZIzY3ek25wT\nM2vuvHO4YsOmkAOxj2Wk/itj5MnK1tT0u840b61Q/j4SJGuKLe4Tzzg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:1.1:protocol urn:mace:shibboleth:1.0",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INFN - Istituto Nazionale di Fisica Nucleare"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INFN - National Institute for Nuclear Physics"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.infn.it/index.php?lang=it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.infn.it/index.php?lang=en"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INFN - Istituto Nazionale di Fisica Nucleare"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INFN - National Institute for Nuclear Physics"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://va-idp.lanet.lv",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ITserviss"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itserviss@lu.lv"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://va-idp.lanet.lv",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://laife.lanet.lv/wiki/Latvian-Academic-Identity-Federation-Policy.pdf"
              }
            ],
            "registration_instant": "2013-10-10T10:10:10Z",
            "registration_authority": "http://laife.lanet.lv/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://va-idp.lanet.lv/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://va-idp.lanet.lv/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:56.950974,24.116292"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Vidzeme University of Applied Sciences"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Vidzeme University of Applied Sciences - VA IDP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://laife.lanet.lv/"
          },
          {
            "lang": "lv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.va.lv/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LAIFE - VA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.fandm.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "alan.sutter@fandm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alan Sutter"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "thiggins@fandm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Todd Higgins"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jbaron1@fandm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Josh Baron"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.fandm.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.fandm.edu:9443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.fandm.edu:9443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkACCQCgR54qxO43SDANBgkqhkiG9w0BAQUFADBuMRgwFgYDVQQDDA9s\nb2dpbi5mYW5kbS5lZHUxJDAiBgNVBAoMG0ZyYW5rbGluICYgTWFyc2hhbGwgQ29s\nbGVnZTELMAkGA1UEBhMCVVMxCzAJBgNVBAgMAlBBMRIwEAYDVQQHDAlMYW5jYXN0\nZXIwHhcNMTIwMjAzMjAzMDExWhcNMTMwMjAyMjAzMDExWjBuMRgwFgYDVQQDDA9s\nb2dpbi5mYW5kbS5lZHUxJDAiBgNVBAoMG0ZyYW5rbGluICYgTWFyc2hhbGwgQ29s\nbGVnZTELMAkGA1UEBhMCVVMxCzAJBgNVBAgMAlBBMRIwEAYDVQQHDAlMYW5jYXN0\nZXIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDeIVrJ8OaD1iYdxU9a\nMfRmN6bKvRiv+oV4yHr9CXBb8sZL7uIWasZj45jmPPq3zhCLtEifDyl9oq8KzMtW\nHNGFqTPM6e5YrxmJClU4JofxE1MkIPpEpYM3CeIK39+BvkPlsqr8OWD+sCmZJcF+\nfm3seCY99LMCTZeQnFZ3WiJwdr2WBtHHiIEB9NXv/++eYX9JwWmD9mSftuLJGx4o\n2hIkC67Nr2RyFTofof9qTSLfcUefsvk2ftVrIWRLxp9FOjGqjhts5ETFjWIOxcMg\nSazmG5MqAgYrVMvLUYttK8rzN6nzjS4siYyXapnSbS+w9p6APCiNbISJggPRkLfY\nzXrPAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAMxccWoHFHDZYhlS04qc2AeT8kK7\nrQnsQ0jMt8kplrdxf3kG+xdyJisZJ6AcpQ+ALZAOIIOYIfuqtmlO29Ygz68/MZQp\n1WPkDGlEmkbZky440kSB9Sk/yGx3hV8kMPICOij3NwD50AeJeEte8gBajMi4FQri\nPKzE57kTpjjW07EiRyJoX5ZJgEAahuqnHr6oiPte03+wTNsggU/GPXtdHoLbuMb9\nZu6vJeprCmXU9SY6J15CXDaG0QVXnwBgmYJSE6DJyjDRm/DQx8f2d2zA0AUueVRL\nTst5Vgudzgfdi5v2XmFJxVABbku9IJRRBBIDfChUtC2b8LJl7PA34qknhMg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvDCCAqQCCQDnGiNHgho1rjANBgkqhkiG9w0BAQUFADCBnzELMAkGA1UEBhMC\nVVMxCzAJBgNVBAgMAlBBMRIwEAYDVQQHDAlMYW5jYXN0ZXIxJDAiBgNVBAoMG0Zy\nYW5rbGluICYgTWFyc2hhbGwgQ29sbGVnZTEMMAoGA1UECwwDSVRTMRgwFgYDVQQD\nDA9sb2dpbi5mYW5kbS5lZHUxITAfBgkqhkiG9w0BCQEWEnNzbGFkbWluQGZhbmRt\nLmVkdTAeFw0xMzAxMTQxNDAwMjJaFw0yMzAxMTIxNDAwMjJaMIGfMQswCQYDVQQG\nEwJVUzELMAkGA1UECAwCUEExEjAQBgNVBAcMCUxhbmNhc3RlcjEkMCIGA1UECgwb\nRnJhbmtsaW4gJiBNYXJzaGFsbCBDb2xsZWdlMQwwCgYDVQQLDANJVFMxGDAWBgNV\nBAMMD2xvZ2luLmZhbmRtLmVkdTEhMB8GCSqGSIb3DQEJARYSc3NsYWRtaW5AZmFu\nZG0uZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAwb099yvp3PyV\nX/eK1+Ga7FQijJIEXmCjWKGELCK218mRFaxfLC95UQGxF8WFrTJsLXEOV84vXufy\n1ZGzBRHx9+WSsiOcA6mCUgUkLLNMBQzj6XlTNxtZAypDPqBTwRqwQeSBMHzp+1L9\n9OnZ2cLYsi6YwrEEb8S7WLkSAQDsWpFEU9WbUHHkWarvHGs40Dz1a78cEId/4KZR\nYUV84cbOlfaz3/cob+BuN9c6HM64gmA36cDHbBWaMDussVvaHxa2JnzuCt0r7KQK\naKfTxLTXX6gA0GvNgXuXLx/X2E/QM0QDOgzkY2a9d4ar1tXbl/HoMCN79uyAcAb8\nmb3nY/ot7wIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQBdjOu5c+kqe612POaok3a4\nhauXGAsvfu3uKb/KvyjupltdfjScaE570/6qEMR/xIJuSK4E0CLizSBFor9z0rwx\nqqmvk+iLSHTrgLSqFdxdY70Kpo2RytrBhJDKDMitnAZA9lzwmhTgqoMYhRVvJ7Iu\nOkLkJ88iMFpMBUxj4EuKNLP5XPj20ofG0H2yIiVUvOpAjU4lAqekKY16vnl7hJe4\niwfMfHgdJvFXhnlv6keguRFmm3Kmdo9zVoHYI4QeMk7hhk2OYyoZMR1IFcMN16P9\n6y60fPr2Yyp6e9uyGPEZv4Qfum6VSa56tN9MXL3PQO0CHADwmM/PrucSPtYd6LR6"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fandm.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.fandm.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.fandm.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.fandm.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.fandm.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.fandm.edu:9443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.fandm.edu:9443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fandm.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.fandm.edu/its/policies"
                  }
                ],
                "logo": [
                  {
                    "text": "https://secure.fandm.edu/images/fandmft.gif",
                    "lang": "en",
                    "height": "77",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "265"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.fandm.edu/its/policies"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Franklin & Marshall College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkACCQCgR54qxO43SDANBgkqhkiG9w0BAQUFADBuMRgwFgYDVQQDDA9s\nb2dpbi5mYW5kbS5lZHUxJDAiBgNVBAoMG0ZyYW5rbGluICYgTWFyc2hhbGwgQ29s\nbGVnZTELMAkGA1UEBhMCVVMxCzAJBgNVBAgMAlBBMRIwEAYDVQQHDAlMYW5jYXN0\nZXIwHhcNMTIwMjAzMjAzMDExWhcNMTMwMjAyMjAzMDExWjBuMRgwFgYDVQQDDA9s\nb2dpbi5mYW5kbS5lZHUxJDAiBgNVBAoMG0ZyYW5rbGluICYgTWFyc2hhbGwgQ29s\nbGVnZTELMAkGA1UEBhMCVVMxCzAJBgNVBAgMAlBBMRIwEAYDVQQHDAlMYW5jYXN0\nZXIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDeIVrJ8OaD1iYdxU9a\nMfRmN6bKvRiv+oV4yHr9CXBb8sZL7uIWasZj45jmPPq3zhCLtEifDyl9oq8KzMtW\nHNGFqTPM6e5YrxmJClU4JofxE1MkIPpEpYM3CeIK39+BvkPlsqr8OWD+sCmZJcF+\nfm3seCY99LMCTZeQnFZ3WiJwdr2WBtHHiIEB9NXv/++eYX9JwWmD9mSftuLJGx4o\n2hIkC67Nr2RyFTofof9qTSLfcUefsvk2ftVrIWRLxp9FOjGqjhts5ETFjWIOxcMg\nSazmG5MqAgYrVMvLUYttK8rzN6nzjS4siYyXapnSbS+w9p6APCiNbISJggPRkLfY\nzXrPAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAMxccWoHFHDZYhlS04qc2AeT8kK7\nrQnsQ0jMt8kplrdxf3kG+xdyJisZJ6AcpQ+ALZAOIIOYIfuqtmlO29Ygz68/MZQp\n1WPkDGlEmkbZky440kSB9Sk/yGx3hV8kMPICOij3NwD50AeJeEte8gBajMi4FQri\nPKzE57kTpjjW07EiRyJoX5ZJgEAahuqnHr6oiPte03+wTNsggU/GPXtdHoLbuMb9\nZu6vJeprCmXU9SY6J15CXDaG0QVXnwBgmYJSE6DJyjDRm/DQx8f2d2zA0AUueVRL\nTst5Vgudzgfdi5v2XmFJxVABbku9IJRRBBIDfChUtC2b8LJl7PA34qknhMg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvDCCAqQCCQDnGiNHgho1rjANBgkqhkiG9w0BAQUFADCBnzELMAkGA1UEBhMC\nVVMxCzAJBgNVBAgMAlBBMRIwEAYDVQQHDAlMYW5jYXN0ZXIxJDAiBgNVBAoMG0Zy\nYW5rbGluICYgTWFyc2hhbGwgQ29sbGVnZTEMMAoGA1UECwwDSVRTMRgwFgYDVQQD\nDA9sb2dpbi5mYW5kbS5lZHUxITAfBgkqhkiG9w0BCQEWEnNzbGFkbWluQGZhbmRt\nLmVkdTAeFw0xMzAxMTQxNDAwMjJaFw0yMzAxMTIxNDAwMjJaMIGfMQswCQYDVQQG\nEwJVUzELMAkGA1UECAwCUEExEjAQBgNVBAcMCUxhbmNhc3RlcjEkMCIGA1UECgwb\nRnJhbmtsaW4gJiBNYXJzaGFsbCBDb2xsZWdlMQwwCgYDVQQLDANJVFMxGDAWBgNV\nBAMMD2xvZ2luLmZhbmRtLmVkdTEhMB8GCSqGSIb3DQEJARYSc3NsYWRtaW5AZmFu\nZG0uZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAwb099yvp3PyV\nX/eK1+Ga7FQijJIEXmCjWKGELCK218mRFaxfLC95UQGxF8WFrTJsLXEOV84vXufy\n1ZGzBRHx9+WSsiOcA6mCUgUkLLNMBQzj6XlTNxtZAypDPqBTwRqwQeSBMHzp+1L9\n9OnZ2cLYsi6YwrEEb8S7WLkSAQDsWpFEU9WbUHHkWarvHGs40Dz1a78cEId/4KZR\nYUV84cbOlfaz3/cob+BuN9c6HM64gmA36cDHbBWaMDussVvaHxa2JnzuCt0r7KQK\naKfTxLTXX6gA0GvNgXuXLx/X2E/QM0QDOgzkY2a9d4ar1tXbl/HoMCN79uyAcAb8\nmb3nY/ot7wIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQBdjOu5c+kqe612POaok3a4\nhauXGAsvfu3uKb/KvyjupltdfjScaE570/6qEMR/xIJuSK4E0CLizSBFor9z0rwx\nqqmvk+iLSHTrgLSqFdxdY70Kpo2RytrBhJDKDMitnAZA9lzwmhTgqoMYhRVvJ7Iu\nOkLkJ88iMFpMBUxj4EuKNLP5XPj20ofG0H2yIiVUvOpAjU4lAqekKY16vnl7hJe4\niwfMfHgdJvFXhnlv6keguRFmm3Kmdo9zVoHYI4QeMk7hhk2OYyoZMR1IFcMN16P9\n6y60fPr2Yyp6e9uyGPEZv4Qfum6VSa56tN9MXL3PQO0CHADwmM/PrucSPtYd6LR6"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Franklin & Marshall College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fandm.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Franklin & Marshall College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://federation.ined.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Marc Lamouche"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "marc.lamouche@ined.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rainer Kugel"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rainer.kugel@ined.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federation.ined.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-09-26T17:01:56Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.ined.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federation.ined.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://federation.ined.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ined.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ined.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INED - Institut National d'Etudes D\u00e9mographiques"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INED - Institut National d'Etudes D\u00e9mographiques"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVALSDfGTkP7KOu8osupywHMFeyFANMA0GCSqGSIb3DQEB\nBQUAMB0xGzAZBgNVBAMTEmZlZGVyYXRpb24uaW5lZC5mcjAeFw0xMzA3MjMxNzE3\nMzJaFw0zMzA3MjMxNzE3MzJaMB0xGzAZBgNVBAMTEmZlZGVyYXRpb24uaW5lZC5m\ncjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMJG3Cg6FzR6km9GqLst\ngxKkkLLSsfnfncy+/ulDiS5tu3ueqr2c/dwz6o0kn97WrBLLlrFIiYaQPIZp1Lp3\ngA7utUMZeEs3ABn631suaI4ra+sMdrhIKgPBRmXchfPrWEk0QgqIkZhK7vP+yH4Z\nh4Tx+s5aLIDDmsh3tESGaWvP4OEE4oE6lTXS5coGrD1P3LqRLRBmmD/VBur3YDQG\nMfXKthCrBXfSsawSITjqN/HIRZO+75ZcO8L29BGu3jpDZQJOocvzsXEGcf1Yfzro\nBSf3w9wCRkuTpYqgvSqaIjG0BVxlq5S8V9NpVjgmQSiBBTBjDfXEhQnbvARg9o3i\n/2cCAwEAAaNrMGkwSAYDVR0RBEEwP4ISZmVkZXJhdGlvbi5pbmVkLmZyhilodHRw\nczovL2ZlZGVyYXRpb24uaW5lZC5mci9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\nH5JcyQ9+maCLgPuzsi40nhRq8hgwDQYJKoZIhvcNAQEFBQADggEBAGtHb3XbAcb0\nbOuPVgifcFmXV7/AnUciKnhZBaMPSt8Q4brCg7+BPzNsGH0k9FGRfH8EHrHLa2qm\n0xqrBf1dEM3v1vq981fLnuks3rmqTrWApPYvxehrAlmtYRexYMv7QXVH06zECBee\nxgHHvFcGJ/JEHRYO8ZFeytl4dQej4tIKxfeW2WUR8zrrfBZNPKvPeN8Y/sHwO8EL\nNbDmdeOfpc1PjxHHbPkJQDLMdAZuMPTYYRdv7+v4s2saF8T3e7kazMNQOW8tQdwL\ni3VOe/mxnZMuPaIV1sWncTmcvo1hUtT89R4DQIimZCyCorKfPM4DNSPp/4KWB8SE\nSCHrArErnq8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INED - Institut National d'Etudes D\u00e9mographiques"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ined.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INED - Institut National d'Etudes D\u00e9mographiques"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.utulsa.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cloud-services@utulsa.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "University of Tulsa Web Services"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.utulsa.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.utulsa.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.utulsa.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.utulsa.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.utulsa.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.utulsa.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utulsa.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Tulsa"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAPETSHdVBddiUfH4XU1QHq66RnYFMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC51dHVsc2EuZWR1MB4XDTA4MDQyNTE5NDczMFoX\nDTI4MDQyNTE5NDczMFowGTEXMBUGA1UEAxMOaWRwLnV0dWxzYS5lZHUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDUKjm3UOGqb/XN68VPJAgmkFWnWf9h\npnzoPXXySxCz35RMglLM75CVW1ywVZ3jXSP8bWJZszs98U5Bux/a2qGvT3ed/8BC\n863nqHBqLNwiheQypWv0x5R4J+PCdyrkFtsRn2KZgoQDlKn5m2YfYyTXM6X/HlIK\nRUW+MITzcI5BcyUhzP35A6Qn1aDzJlkG/V9Pt+5XQD1dY2H8Yk7OR4W62yOzZM8j\nnBWmXJI9kgtRgL2QAt8TY67JdFU7BkA7YIJyeqUK7fHZiiBIZhIUUZD6XMK8T4og\n3L7DCscJ+u6gHf3OHToDNVV6T/TBqRMvKp8fz3vEyB9D++VyIXJWABZRAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC51dHVsc2EuZWR1hiVodHRwczovL2lkcC51dHVs\nc2EuZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQrgw0aUl7dUN/9uPPa2VTR\nKRkgyjANBgkqhkiG9w0BAQUFAAOCAQEABmI+tK+7rjabbHX6t/YKKnLA8+foVBZ+\nlxBuA6zVOEncm++U+uSp8eBV9DtYD6ijOS/Z57hF4BVzSKOepUr8oQumfIgYdrYf\nRlEwY+arGnZwHyJRijXw7SfHHPxOVpWW97erlfWiHCqbzVmKFMcGZuojsiJLM/pf\nu1Bbjw70nFF2AT5X6TBSNgfKNPUkI9qoNeSKin8YdAfcVIGLaj2MXHcyUub3nwJh\nUPH7vTDTXUCgoSAnXDXgEw/2ty4gN/l29qwVl4XqZ9idbFdcH4i70LJQjdekC3CY\nhiXKVILgWJYPDUw4K1gedb5r17APna++AIb37J+mtSJ1KesPn3K45g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "http://errror.utulsa.edu/shiberror.php"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Tulsa"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utulsa.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Tulsa"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://grouper.idem.garr.it/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Help"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem-help@garr.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IDEM"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://grouper.idem.garr.it/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2015-04-21T11:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Grouper erogato da Consortium GARR"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Grouper provided by Consortium GARR"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.garr.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.garr.it/b/eng"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consortium GARR"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consortium GARR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://grouper.idem.garr.it/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://grouper.idem.garr.it/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://grouper.idem.garr.it/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://grouper.idem.garr.it/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://grouper.idem.garr.it/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://grouper.idem.garr.it/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://grouper.idem.garr.it/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://grouper.idem.garr.it/grouper-sp/en/info.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://grouper.idem.garr.it/grouper-sp/it/info.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IDEM Grouper SP"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IDEM Grouper SP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Grouper SP for IDEM provided by GARR"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Grouper SP per IDEM fornito da GARR"
                  }
                ],
                "logo": [
                  {
                    "text": "https://grouper.idem.garr.it/grouper-sp/grouper_logo_180x120.png",
                    "height": "120",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "180"
                  },
                  {
                    "text": "https://grouper.idem.garr.it/grouper-sp/grouper_logo_32x32.png",
                    "height": "32",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "32"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://grouper.idem.garr.it/grouper-sp/en/privacy.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://grouper.idem.garr.it/grouper-sp/it/privacy.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAIJNTw7flL9uMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFGdyb3VwZXIuaWRlbS5nYXJyLml0MB4XDTE1MDMxODE0NDg0OVoXDTI1MDMx\nNTE0NDg0OVowHzEdMBsGA1UEAxMUZ3JvdXBlci5pZGVtLmdhcnIuaXQwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCzwqbkYCC3F5+SSkaqTUQwaN/dwyYH\nj1k6Z7+30/hTSSerJF33Lofmq69EaSx2R+NpeZF6FjdoAIZouwrFsgnxfo1ToJCl\nAqFfq0at395CTrk1r0RHyAIN3o3H/mN9gu2asYGfAs7cPFDmIpy2Cm3wOObtu3YV\nccqlcf8h3DS0iNtPyqoVzShfKE54E1QQLgl+QFFbxomMD2RJCTdexNG2oeOVLoDR\nAJeX6iRThsbMjcz0W+G94YixmHeJ3E1STgT71irMEtumbS4D/ow7HdVF0RKLIKob\ndfQ8ALPV1R1C1hM5xwy4JjzlurTl28ir9AL/pv14TOWxePs6ZuKcVkipAgMBAAGj\nQjBAMB8GA1UdEQQYMBaCFGdyb3VwZXIuaWRlbS5nYXJyLml0MB0GA1UdDgQWBBQ+\n1mQ9Sz4LMwDdtI2Fwcpc3NEuoTANBgkqhkiG9w0BAQUFAAOCAQEAOqe6gZCcoNW2\n8Z7hU0icrKnCx3llcCyWgX3yn1ef7zWeLy7wZGpKgOHQDbmdOaMa3vk4t0PeL7IP\n5dnmhxu15A5t+csMvTNTi5G4L3pl5vKg6Jv6V5n94UlS5sam+TtO4WPsJ8gyhIGu\n/CY+Sq/BPVs8Sy8quoTIfCtDJLYuK+rF1sHDtGlQ4dGnTWLYw4auGess8b3vxNkq\nEMA/9OGny/lSYy2Ihh97+m2w8lZPskio9dnC9BbWbiyGY5hjd1W50c6HVmR+b0fe\nujg8dxgduViYDlu51BFyleoAxHhnauOlpFNzJuHMakCKv0riztIH3gAun7RPnFYF\n0Man4StZKw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://grouper.idem.garr.it/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://grouper.idem.garr.it/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://grouper.idem.garr.it/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://grouper.idem.garr.it/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://grouper.idem.garr.it/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://grouper.idem.garr.it/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "IDEM Grouper SP"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "IDEM Grouper SP"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Grouper SP for IDEM provided by GARR"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Grouper SP per IDEM erogato da GARR"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "commonName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.hillcroft.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Overt Software Solutions"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Frary"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pfrary@hillcroft.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.hillcroft.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-07-09T10:50:01Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUY+dzAdJP4F29WhYMkIYWVz7OXIkwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJTEjMCEGA1UEAwwac2hpYmJvbGV0aC5oaWxsY3JvZnQuYWMudWswHhcNMTUw\n\t\t\t\t\t\tNjMwMTQ0OTE2WhcNMzUwNjMwMTQ0OTE2WjAlMSMwIQYDVQQDDBpzaGliYm9sZXRo\n\t\t\t\t\t\tLmhpbGxjcm9mdC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAKZsE6hMiiscNndGGJrMv0d77p+JYtgJcyChH/YklmL4W4YbJFubYposfFjRUOHL\n\t\t\t\t\t\tq9h/ZoKE1uNRMI0wCZ/43FX5uTeBoOWfldsDU5z0GPh6J/D/KM6d+ahoYHSQVkJT\n\t\t\t\t\t\tH3lQNTCizjEXs6LsMgQYiWeaNhsAvmBEz/2IotGzfQkS4wa8C+saWpog2p1Z+iqr\n\t\t\t\t\t\t4IZVcoKdIAZdrUBxAdBxITdoOsC3GPyIksqvLhfwa9CmYI6iI0NgDwUfsPJlKBJy\n\t\t\t\t\t\turdHHsJonEn5iJnkgCVX8Qg3XFcdtn15Q7LDUUNDp9nwQ/2SUJMmMpjf7r+bIYx3\n\t\t\t\t\t\tgqQCIh53qERD8qCmE+LXrsMCAwEAAaN7MHkwHQYDVR0OBBYEFNYN0h/Zy2tW0tfR\n\t\t\t\t\t\tSp7LfNDOOhckMFgGA1UdEQRRME+CGnNoaWJib2xldGguaGlsbGNyb2Z0LmFjLnVr\n\t\t\t\t\t\thjFodHRwczovL3NoaWJib2xldGguaGlsbGNyb2Z0LmFjLnVrL2lkcC9zaGliYm9s\n\t\t\t\t\t\tZXRoMA0GCSqGSIb3DQEBBQUAA4IBAQButipjXmmT9bD6lP6yYyqqE3kCC87p6ub8\n\t\t\t\t\t\tQuwSjnHpAxSJlhdyS/o3rS5SauwqDs12gYgrx4zoJWNZfAfV0QzSR/mmX5+k0Vt6\n\t\t\t\t\t\toSyhY0flaCi0np13AAJKQCVyiIfqBATXaGOV4fSoTIpC2ajEQA0QBMbW9tb10/uA\n\t\t\t\t\t\t4hTmxJ/AT5GADtMpe9iUknnsBQCXmojKtnILV9bGSgPi0bmHK68GIHe72TPfgXae\n\t\t\t\t\t\tEninOSrPVYCTYu2Ye0uNMjUJLcaWG/4Bg4KHjCcw0ElUB6gAAozzBGg4YWuYIX69\n\t\t\t\t\t\tkhh8QXuVbtNdLDflq8uEmlwtw92SweSEsLZpZrF/dTPMjmy9XzP7"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hillcroft.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.hillcroft.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.hillcroft.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.hillcroft.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.hillcroft.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.hillcroft.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.hillcroft.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.hillcroft.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.hillcroft.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.hillcroft.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.hillcroft.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.hillcroft.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hillcroft.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://shibboleth.hillcroft.ac.uk/logo.jpg",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://shibboleth.hillcroft.ac.uk/icon.jpg",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hillcroft College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUY+dzAdJP4F29WhYMkIYWVz7OXIkwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJTEjMCEGA1UEAwwac2hpYmJvbGV0aC5oaWxsY3JvZnQuYWMudWswHhcNMTUw\n\t\t\t\t\t\tNjMwMTQ0OTE2WhcNMzUwNjMwMTQ0OTE2WjAlMSMwIQYDVQQDDBpzaGliYm9sZXRo\n\t\t\t\t\t\tLmhpbGxjcm9mdC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAKZsE6hMiiscNndGGJrMv0d77p+JYtgJcyChH/YklmL4W4YbJFubYposfFjRUOHL\n\t\t\t\t\t\tq9h/ZoKE1uNRMI0wCZ/43FX5uTeBoOWfldsDU5z0GPh6J/D/KM6d+ahoYHSQVkJT\n\t\t\t\t\t\tH3lQNTCizjEXs6LsMgQYiWeaNhsAvmBEz/2IotGzfQkS4wa8C+saWpog2p1Z+iqr\n\t\t\t\t\t\t4IZVcoKdIAZdrUBxAdBxITdoOsC3GPyIksqvLhfwa9CmYI6iI0NgDwUfsPJlKBJy\n\t\t\t\t\t\turdHHsJonEn5iJnkgCVX8Qg3XFcdtn15Q7LDUUNDp9nwQ/2SUJMmMpjf7r+bIYx3\n\t\t\t\t\t\tgqQCIh53qERD8qCmE+LXrsMCAwEAAaN7MHkwHQYDVR0OBBYEFNYN0h/Zy2tW0tfR\n\t\t\t\t\t\tSp7LfNDOOhckMFgGA1UdEQRRME+CGnNoaWJib2xldGguaGlsbGNyb2Z0LmFjLnVr\n\t\t\t\t\t\thjFodHRwczovL3NoaWJib2xldGguaGlsbGNyb2Z0LmFjLnVrL2lkcC9zaGliYm9s\n\t\t\t\t\t\tZXRoMA0GCSqGSIb3DQEBBQUAA4IBAQButipjXmmT9bD6lP6yYyqqE3kCC87p6ub8\n\t\t\t\t\t\tQuwSjnHpAxSJlhdyS/o3rS5SauwqDs12gYgrx4zoJWNZfAfV0QzSR/mmX5+k0Vt6\n\t\t\t\t\t\toSyhY0flaCi0np13AAJKQCVyiIfqBATXaGOV4fSoTIpC2ajEQA0QBMbW9tb10/uA\n\t\t\t\t\t\t4hTmxJ/AT5GADtMpe9iUknnsBQCXmojKtnILV9bGSgPi0bmHK68GIHe72TPfgXae\n\t\t\t\t\t\tEninOSrPVYCTYu2Ye0uNMjUJLcaWG/4Bg4KHjCcw0ElUB6gAAozzBGg4YWuYIX69\n\t\t\t\t\t\tkhh8QXuVbtNdLDflq8uEmlwtw92SweSEsLZpZrF/dTPMjmy9XzP7"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hillcroft College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hillcroft.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hillcroft College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.unicaen.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Nicolas HEURTEL"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "nicolas.heurtel@unicaen.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "David SURVILLE"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "david.surville@unicaen.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.unicaen.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-11-20T14:38:11Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unicaen.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unicaen.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.unicaen.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unicaen.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unicaen.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAAAAAA6mKC9AAAACXBIWXMAAABIAAAASABGyWs+AAAACXZwQWcAAAAQAAAAEABcxq3DAAAAV0lEQVQY03XPMQrAMAxD0d7/WOFPxkvAS8YsGUIW36BTS2WoxgcW8tVKrh9g7OwfsLPD4AX2RE7ioB1zlFKjwIwKq3R4ugCM7CBLI89ymY6H6XO0pvDkBhHbxZqnkacaAAAAJXRFWHRkYXRlOmNyZWF0ZQAyMDE1LTA3LTIwVDEwOjUwOjAyKzAyOjAwfjwnFQAAACV0RVh0ZGF0ZTptb2RpZnkAMjAxNS0wNy0yMFQxMDo1MDowMiswMjowMA9hn6kAAAAASUVORK5CYII=",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Caen Normandie"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Caen Normandie"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVALLJNRifsaDgq9SZsGgf6vqdEpntMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC51bmljYWVuLmZyMB4XDTA5MDcyNzEzNDMxMFoX\nDTI5MDcyNzEzNDMxMFowGTEXMBUGA1UEAxMOaWRwLnVuaWNhZW4uZnIwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCE/YcYohNvzICcNO78kljWYODlicgW\nxGoXBtCNtVN3z2E0S58zQdfGDelCvCgmRECKjeHEUJPCj0Ruarg9q9eqcOz44/9D\nCBZo2uLuNPURnaUeEPt502EPhSXPercAJVjmks7CeqbrA9192EnGWYe8hv5ZqY7d\noanvW63YYzwIUtyYShUND7TgZFL6GD08o9prPZrBltL+fuodwXI+aFT5XIX25Su1\nFC67/8WU9jbWb4WiIZZnHD6cQDpkhfMTUAmVtZ7sj+qqueCixP0yMTbLpQCisAIP\np2mqjC3j5i4ZHm++lrjhtfKOE8emD8V41e7z++Hb/ho95hNl5qOD7MP1AgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC51bmljYWVuLmZyhiVodHRwczovL2lkcC51bmlj\nYWVuLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTBGIdWisheOftwSUFEzpIO\nSm4I9jANBgkqhkiG9w0BAQUFAAOCAQEADIDOox8I0gRyY3uetAbe1n2Kfy/pxsQZ\nNr4Tn90NUMG8i2mp7KVoMuBhmJS5/BHJPdHNMprB6PjzlTDiriNxdl3NPSASUq7D\nE5oMcyemphYHMxcKvXDXif/uRX/dOmRZy77Wt3yjkQjy/Md/fmOYrxd8yKptnhpp\nsjYkdQpopHxBW3npgmOSS1/5X7qy1di8ckgLfEs7u3qfOZfw6i+nn1/98CjMKlv7\nTRVhM943X1kgV4l/lvaMWsPxvgTT8RRvaoAYClmyg6XLbdFC5QQUCjVCPldcbeIY\nIsKc8ui7+rEvhoAKrdmvAPrxTSfN8KMFQ3tbQDz2E3YzAELQD+4zWg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Caen Normandie"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unicaen.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Caen Normandie"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://2014.qmplus.qmul.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:its-aa@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Academic Applications"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:moodle-support@ulcc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Moodle Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:its-aa@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Academic Applications"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://2014.qmplus.qmul.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-06-11T12:33:19Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Queen Mary and Westfield College : 2014 Archive service QMPlus"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qmul.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Queen Mary and Westfield College, University of London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://2014.qmplus.qmul.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://2014.qmplus.qmul.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJAIIweJrqmrIEMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\n\t\t\t\t\t\tBAMTFjIwMTQucW1wbHVzLnFtdWwuYWMudWswHhcNMTUwNjAzMTE1MTU1WhcNMjUw\n\t\t\t\t\t\tNTMxMTE1MTU1WjAhMR8wHQYDVQQDExYyMDE0LnFtcGx1cy5xbXVsLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA6wqhw1O4q0vYMXU94rcHQ44P\n\t\t\t\t\t\tRxd9Zx6PTEWaZP7839SzVFstPegyYcLHcUnqVW4EM1kX7+MnDHk48/VrAaXa7Pbj\n\t\t\t\t\t\tTBaIg10O9V4uGAlMkdHD0GyNEeMWNKhfO4cpDs2WaRSBlHLcTIDXKmjoEZDDqaa8\n\t\t\t\t\t\tfuxEmEVc1Bm8Ao4qKCv4y5bBDL9aMvo9rw1OTJgXWgX/FyhznUUqpUYaZPWWMS+t\n\t\t\t\t\t\tHyTejxQCNCLi+UEIgpnGQngS/tj765jkbt2z9DB+SqHmYRPOtHhmtqdjWVfzdBaI\n\t\t\t\t\t\t5HyeS1TGob3qHVvVX8JgRA2dOzWx+eokpxjMV30+oHZFkClhWg43stCtkH9ZrQID\n\t\t\t\t\t\tAQABo0QwQjAhBgNVHREEGjAYghYyMDE0LnFtcGx1cy5xbXVsLmFjLnVrMB0GA1Ud\n\t\t\t\t\t\tDgQWBBQJlVc050moorXGSGplCA/WkCNCijANBgkqhkiG9w0BAQUFAAOCAQEAsXcc\n\t\t\t\t\t\t62YIy3TqdHgIbgUbS9mEnQtH3gXyOMswYfHLnDILQM1QXQSGRC4ccTbd5Jb1EUt0\n\t\t\t\t\t\tuE06Hfoo9Q0veZx/hfSQXHTCyhBmTEbcM6+FhN4I57egx2BQbxOut+628IqRSis9\n\t\t\t\t\t\tDLBzrI9SODauIBuk4zyGkERTFR8vTaG7d1sDGidmwmoHqPY0OJkZ4yMJmvEi75rY\n\t\t\t\t\t\t3L5yl3KWi9tgzzRPEO3FXS1eyXhsdcpBhRunJFCrS6smzYDpI+J2+New+HxV90ZO\n\t\t\t\t\t\tZvbjbDXchMopj9OKggJg7+Kazs+zPkL61kXjirvEJAfiM+34yCwtH3D3ZgDs0ZnS\n\t\t\t\t\t\tutfRdwVfCY936z7DOA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://2014.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://2014.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://2014.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://2014.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://2014.qmplus.qmul.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://2014.qmplus.qmul.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://hefce-shib.hefce.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Edwards"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:g.edwards@hefce.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gareth"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Edwards"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:g.edwards@hefce.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gareth"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://hefce-shib.hefce.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUezj/faBM5uouEQmqmYzIjOz/6JEwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwITEfMB0GA1UEAxMWaGVmY2Utc2hpYi5oZWZjZS5hYy51azAeFw0wOTA3MTYx\n\t\t\t\t\t\tMjA3MzZaFw0yOTA3MTYxMjA3MzZaMCExHzAdBgNVBAMTFmhlZmNlLXNoaWIuaGVm\n\t\t\t\t\t\tY2UuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCEaksTLYnl\n\t\t\t\t\t\tGL5voE3VgwtWMCMv3geB6Py4KTrP31bm1+lh0uOmLnvA/hWynXSVZlNneaxRKFMG\n\t\t\t\t\t\tVWeqPzA7Pgr18kNGsN3dL5Uqgsa5wHRssRERQLi7gGsOgDLeDHAVPeHdfq4Xf7xa\n\t\t\t\t\t\ttxX+0OEQ8o/8rBrVCrXvbb5+bYSdmrN9EljMpb9Thos3LN4kSentD6Ynmatsh/yc\n\t\t\t\t\t\t+aAc7T6OrIG1tIsahaIMAdS2bWufCKhKZTLvkQy5RypcfTUiRqdfGm+YUt5mI29J\n\t\t\t\t\t\tNVx0zVTfiv6EZNwrWdk23E0JyRn2qEQlnShyJD6TmVJfrX4XpPGx54DbZebMNpVK\n\t\t\t\t\t\t81xTMIgY9/69AgMBAAGjczBxMFAGA1UdEQRJMEeCFmhlZmNlLXNoaWIuaGVmY2Uu\n\t\t\t\t\t\tYWMudWuGLWh0dHBzOi8vaGVmY2Utc2hpYi5oZWZjZS5hYy51ay9pZHAvc2hpYmJv\n\t\t\t\t\t\tbGV0aDAdBgNVHQ4EFgQUGy/6MNFxhre5bjKaqpv+vZ9gETEwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQADggEBAGMdM/fMvuLzyNWsEiFZ9/8j0w3J24GP3vVHW5Qo78cgJFefvRCIiRyc\n\t\t\t\t\t\tVgd9xbOwa73jQmJfJVdVU2wQxE/zDlblpuVJRF2C5ZeNb02utv6k4z//aitqeJWs\n\t\t\t\t\t\t+iUj1PrebWVVQowkSjAs2q94qaQcwjYRajsp5WZak+nwknPJghRqwr3zhW4RlxV6\n\t\t\t\t\t\tZdwS2D2Ckz3bxI+EQDS4PNpxQA/rczG4H2FgvsLGXV9+s3LmVMtkrfGNdLhTd9yi\n\t\t\t\t\t\twXj9oLBF9cMb98YjywMT6pVbuGtbJVxnFqb0RAAkUrCkNdNLAUUGD8S3tRVLi7Cv\n\t\t\t\t\t\tBNj9t+EYKF8K7y4unRFf9gVHwyWBLq0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hefce.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://hefce-shib.hefce.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hefce-shib.hefce.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://hefce-shib.hefce.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hefce-shib.hefce.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://hefce-shib.hefce.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://hefce-shib.hefce.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://hefce-shib.hefce.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hefce-shib.hefce.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hefce.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUezj/faBM5uouEQmqmYzIjOz/6JEwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwITEfMB0GA1UEAxMWaGVmY2Utc2hpYi5oZWZjZS5hYy51azAeFw0wOTA3MTYx\n\t\t\t\t\t\tMjA3MzZaFw0yOTA3MTYxMjA3MzZaMCExHzAdBgNVBAMTFmhlZmNlLXNoaWIuaGVm\n\t\t\t\t\t\tY2UuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCEaksTLYnl\n\t\t\t\t\t\tGL5voE3VgwtWMCMv3geB6Py4KTrP31bm1+lh0uOmLnvA/hWynXSVZlNneaxRKFMG\n\t\t\t\t\t\tVWeqPzA7Pgr18kNGsN3dL5Uqgsa5wHRssRERQLi7gGsOgDLeDHAVPeHdfq4Xf7xa\n\t\t\t\t\t\ttxX+0OEQ8o/8rBrVCrXvbb5+bYSdmrN9EljMpb9Thos3LN4kSentD6Ynmatsh/yc\n\t\t\t\t\t\t+aAc7T6OrIG1tIsahaIMAdS2bWufCKhKZTLvkQy5RypcfTUiRqdfGm+YUt5mI29J\n\t\t\t\t\t\tNVx0zVTfiv6EZNwrWdk23E0JyRn2qEQlnShyJD6TmVJfrX4XpPGx54DbZebMNpVK\n\t\t\t\t\t\t81xTMIgY9/69AgMBAAGjczBxMFAGA1UdEQRJMEeCFmhlZmNlLXNoaWIuaGVmY2Uu\n\t\t\t\t\t\tYWMudWuGLWh0dHBzOi8vaGVmY2Utc2hpYi5oZWZjZS5hYy51ay9pZHAvc2hpYmJv\n\t\t\t\t\t\tbGV0aDAdBgNVHQ4EFgQUGy/6MNFxhre5bjKaqpv+vZ9gETEwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQADggEBAGMdM/fMvuLzyNWsEiFZ9/8j0w3J24GP3vVHW5Qo78cgJFefvRCIiRyc\n\t\t\t\t\t\tVgd9xbOwa73jQmJfJVdVU2wQxE/zDlblpuVJRF2C5ZeNb02utv6k4z//aitqeJWs\n\t\t\t\t\t\t+iUj1PrebWVVQowkSjAs2q94qaQcwjYRajsp5WZak+nwknPJghRqwr3zhW4RlxV6\n\t\t\t\t\t\tZdwS2D2Ckz3bxI+EQDS4PNpxQA/rczG4H2FgvsLGXV9+s3LmVMtkrfGNdLhTd9yi\n\t\t\t\t\t\twXj9oLBF9cMb98YjywMT6pVbuGtbJVxnFqb0RAAkUrCkNdNLAUUGD8S3tRVLi7Cv\n\t\t\t\t\t\tBNj9t+EYKF8K7y4unRFf9gVHwyWBLq0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Higher Education Funding Council for England"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hefce.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Higher Education Funding Council for England"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.longleypark.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.longleypark.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/longleypark.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/longleypark.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "longleypark.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Longley Park Sixth Form College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.longleypark.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://esodev.insrv.cf.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:esowebmaster@cardiff.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ESO Webmaster"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smart"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:smartp@cardiff.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Philip"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://esodev.insrv.cf.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-05-23T13:43:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cardiff University: European Sources Online Development Server"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.europeansources.info/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cardiff University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://esodev.insrv.cf.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://esodev.insrv.cf.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://esodev.insrv.cf.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://esodev.insrv.cf.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://esodev.insrv.cf.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://esodev.insrv.cf.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJAOTb7E3AJLSnMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\n\t\t\t\t\t\tBAMTFWVzb2Rldi5pbnNydi5jZi5hYy51azAeFw0xMjAzMDcxMDU5MzJaFw0yMjAz\n\t\t\t\t\t\tMDUxMDU5MzJaMCAxHjAcBgNVBAMTFWVzb2Rldi5pbnNydi5jZi5hYy51azCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAO6F55cSihSA/x76lMyqjJrD5Jg5\n\t\t\t\t\t\tMsTC+z8XzlBFDozBygx855+CwIVJbZPIUG1OeU4NKolb3ajhunSLRvXMieV8ggKZ\n\t\t\t\t\t\tkKmUrlze9Es5+4VjgIP7TN6DqPBoyvgAn/wdhwXYRebARb9gmQaXQngDMErJ9RzE\n\t\t\t\t\t\ty0Q8jvsxH4V/Dg7XhvoqZmiC1fTX4/Pu0a35gSG91hQGlq7YEevXR6fM0mndANiM\n\t\t\t\t\t\tW1m/bVQLFYdnqpWluda+4NQL1vQLY9s4/vNjZWuyOGG2wapxoYYZ1FVBicM85AWG\n\t\t\t\t\t\teHsSM3GflEKXKP+wMAyXLWeY42a9XhVKhLUO83UorFR77gL/lp38zlBE+8ECAwEA\n\t\t\t\t\t\tAaNDMEEwIAYDVR0RBBkwF4IVZXNvZGV2Lmluc3J2LmNmLmFjLnVrMB0GA1UdDgQW\n\t\t\t\t\t\tBBStsckECWrhJTx3JjU4j6MfCiUceTANBgkqhkiG9w0BAQUFAAOCAQEAf6oKwWJH\n\t\t\t\t\t\tits+N8IRS3V3853Q9JSfsACBaWo+InbckPmW2+D1PYhngdHRga/GGxJvF2drepBi\n\t\t\t\t\t\tp5L3rTqhS6+1dDQeXB5239MGQQyZZIuaUWqzgwkHhlbtwDZlcUDlsGyW7s3Wkbvf\n\t\t\t\t\t\tGC5FNlx3+gj5WpFo6l/iMpWwBK/kxEN+SRW8TJjAOqg8dLxcMUBnZw1Kydgc4tWm\n\t\t\t\t\t\tGeIoKDPY2grHcp4hT9Me12tj2DYcDjyw5rGiv0BL6YghzapXGFTcFI6BZoMnRji3\n\t\t\t\t\t\tldYUb4/0ivef8X0aOal+/U5alUlfmBCL8pMXh1ckpzJa55KMb+CkkMhGoQY95VuL\n\t\t\t\t\t\tPukhmwd1O96IqQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://esodev.insrv.cf.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://esodev.insrv.cf.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://esodev.insrv.cf.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://esodev.insrv.cf.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://esodev.insrv.cf.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://esodev.insrv.cf.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.port.ac.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@port.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "University IT Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Burland"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:phil.burland@port.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Phil"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.port.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEIjCCAwqgAwIBAgIJALf8bLjT1bnmMA0GCSqGSIb3DQEBBQUAMIGRMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjESMBAGA1UECBMJSGFtcHNoaXJlMRMwEQYDVQQHEwpQb3J0c21vdXRo\n\t\t\t\t\t\tMSEwHwYDVQQKExhVbml2ZXJzaXR5IG9mIFBvcnRzbW91dGgxHTAbBgNVBAsTFElu\n\t\t\t\t\t\tZm9ybWF0aW9uIFNlcnZpY2VzMRcwFQYDVQQDEw5pZHAucG9ydC5hYy51azAeFw0x\n\t\t\t\t\t\tMjA0MDQxMzIyMTZaFw0yMjA0MDIxMzIyMTZaMIGRMQswCQYDVQQGEwJHQjESMBAG\n\t\t\t\t\t\tA1UECBMJSGFtcHNoaXJlMRMwEQYDVQQHEwpQb3J0c21vdXRoMSEwHwYDVQQKExhV\n\t\t\t\t\t\tbml2ZXJzaXR5IG9mIFBvcnRzbW91dGgxHTAbBgNVBAsTFEluZm9ybWF0aW9uIFNl\n\t\t\t\t\t\tcnZpY2VzMRcwFQYDVQQDEw5pZHAucG9ydC5hYy51azCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBAOVFjymX7M8xWKzGhKlZ5/3aDsDeWjQ2oeooO1MSaFbT\n\t\t\t\t\t\tj/pMtOC3Qrsa7P3Hhwshh5m0nAYTqpdl4NvFFOiMv0WMmKiNDKR3DvrF8p5HP21Z\n\t\t\t\t\t\tNFFE1EI2K+ciRUpFgFg/+Aiy/J8hiiFvNgY/K1Bu7YzmJHakrrnQRn/1J+vDq7GJ\n\t\t\t\t\t\tE/9GUz5rqVBjh1Ny+346Pls5SYUf5aj0H5KmD83TRZsjfAQecl4hxsbZTmZQmn/1\n\t\t\t\t\t\tOTtqBp0yDy3DZYTWoeJ9ab2Smm+KRhP67rNG568S6hRvAPwdOxxQOnLZtZVbZJvl\n\t\t\t\t\t\t0zjT4no3JBBoJ+25Xdb5LiQKBLh4Q1e0Y0cDW4gPd+ECAwEAAaN7MHkwCQYDVR0T\n\t\t\t\t\t\tBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNh\n\t\t\t\t\t\tdGUwHQYDVR0OBBYEFGfthAjlQZ/cBPBgNARSaZC1cAfVMB8GA1UdIwQYMBaAFGft\n\t\t\t\t\t\thAjlQZ/cBPBgNARSaZC1cAfVMA0GCSqGSIb3DQEBBQUAA4IBAQCqBvYpE7bPdaOa\n\t\t\t\t\t\tOLoDnDySj0FdExCJCQpRGE1nFQ1eT4GrDjlPO2QE1jE2tStS6Wv4ZuW1qJyuEJDe\n\t\t\t\t\t\tfMJn7xtilLSDpzvocxhDGoF/SgDdDA5wpHt5iz/4e1wfDHHbUwxDiCXSYSPTn55u\n\t\t\t\t\t\t2ElvtdyQiiagoPkaIMoco3XKIyIG6LGoZPeFp0FS6GV541T6yJOzE71nCwJZ+RWA\n\t\t\t\t\t\tiAdkoJsFOs+PgXPPlN9hdEmspKrAKnp9G7JeIjc6at+YijvkSoCmRCdqNFj3jwDR\n\t\t\t\t\t\tKnGXAg5ikRPxi2wV6VGgyXCqoFhMFVQE/3zlNd8sPy6uEqHUo0gwE6amJJeafsN5\n\t\t\t\t\t\ttetph4SV"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "port.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.port.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.port.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib-login.port.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-login.port.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib-login.port.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-login.port.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.port.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.port.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "port.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEIjCCAwqgAwIBAgIJALf8bLjT1bnmMA0GCSqGSIb3DQEBBQUAMIGRMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjESMBAGA1UECBMJSGFtcHNoaXJlMRMwEQYDVQQHEwpQb3J0c21vdXRo\n\t\t\t\t\t\tMSEwHwYDVQQKExhVbml2ZXJzaXR5IG9mIFBvcnRzbW91dGgxHTAbBgNVBAsTFElu\n\t\t\t\t\t\tZm9ybWF0aW9uIFNlcnZpY2VzMRcwFQYDVQQDEw5pZHAucG9ydC5hYy51azAeFw0x\n\t\t\t\t\t\tMjA0MDQxMzIyMTZaFw0yMjA0MDIxMzIyMTZaMIGRMQswCQYDVQQGEwJHQjESMBAG\n\t\t\t\t\t\tA1UECBMJSGFtcHNoaXJlMRMwEQYDVQQHEwpQb3J0c21vdXRoMSEwHwYDVQQKExhV\n\t\t\t\t\t\tbml2ZXJzaXR5IG9mIFBvcnRzbW91dGgxHTAbBgNVBAsTFEluZm9ybWF0aW9uIFNl\n\t\t\t\t\t\tcnZpY2VzMRcwFQYDVQQDEw5pZHAucG9ydC5hYy51azCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBAOVFjymX7M8xWKzGhKlZ5/3aDsDeWjQ2oeooO1MSaFbT\n\t\t\t\t\t\tj/pMtOC3Qrsa7P3Hhwshh5m0nAYTqpdl4NvFFOiMv0WMmKiNDKR3DvrF8p5HP21Z\n\t\t\t\t\t\tNFFE1EI2K+ciRUpFgFg/+Aiy/J8hiiFvNgY/K1Bu7YzmJHakrrnQRn/1J+vDq7GJ\n\t\t\t\t\t\tE/9GUz5rqVBjh1Ny+346Pls5SYUf5aj0H5KmD83TRZsjfAQecl4hxsbZTmZQmn/1\n\t\t\t\t\t\tOTtqBp0yDy3DZYTWoeJ9ab2Smm+KRhP67rNG568S6hRvAPwdOxxQOnLZtZVbZJvl\n\t\t\t\t\t\t0zjT4no3JBBoJ+25Xdb5LiQKBLh4Q1e0Y0cDW4gPd+ECAwEAAaN7MHkwCQYDVR0T\n\t\t\t\t\t\tBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNh\n\t\t\t\t\t\tdGUwHQYDVR0OBBYEFGfthAjlQZ/cBPBgNARSaZC1cAfVMB8GA1UdIwQYMBaAFGft\n\t\t\t\t\t\thAjlQZ/cBPBgNARSaZC1cAfVMA0GCSqGSIb3DQEBBQUAA4IBAQCqBvYpE7bPdaOa\n\t\t\t\t\t\tOLoDnDySj0FdExCJCQpRGE1nFQ1eT4GrDjlPO2QE1jE2tStS6Wv4ZuW1qJyuEJDe\n\t\t\t\t\t\tfMJn7xtilLSDpzvocxhDGoF/SgDdDA5wpHt5iz/4e1wfDHHbUwxDiCXSYSPTn55u\n\t\t\t\t\t\t2ElvtdyQiiagoPkaIMoco3XKIyIG6LGoZPeFp0FS6GV541T6yJOzE71nCwJZ+RWA\n\t\t\t\t\t\tiAdkoJsFOs+PgXPPlN9hdEmspKrAKnp9G7JeIjc6at+YijvkSoCmRCdqNFj3jwDR\n\t\t\t\t\t\tKnGXAg5ikRPxi2wV6VGgyXCqoFhMFVQE/3zlNd8sPy6uEqHUo0gwE6amJJeafsN5\n\t\t\t\t\t\ttetph4SV"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Portsmouth - Legacy"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.port.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Portsmouth"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://betafoo.nordu.net/saml2/metadata/",
    {
      "entity_id": "https://betafoo.nordu.net/saml2/metadata/",
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lundberg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lundberg@nordu.net"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "NORDUnet A/S"
          },
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Johan"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://betafoo.nordu.net/saml2/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAMvFLpEMEvybMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\nBAMTB2JldGFmb28wHhcNMTIwMTIzMTMwNzAwWhcNMjIwMTIwMTMwNzAwWjASMRAw\nDgYDVQQDEwdiZXRhZm9vMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\nn96BBnx0AbGpOlFnSJB2OM5eq/7nzzUx/lwfXIUxolYmz3m7QD16V6+wSRaVvK9R\n+83uUFjiFlKs9OEFRfcDJYgYhlV7r/SXyy41AlPrsqTCuYwEMErtVXePOc88it+V\nnX2wamumJxszGFxon9NXqwnTaza/yM0DFXPi5GJLwI0nhKugiXmlFQHICq2xcNBA\nEGjHQrL2FM//Fg3f8OJsJzqu2GjplWLNrphbdDH3++RJQQ+cNWq4XOzxTnM4BYoj\nn0Avwn35xA7dYdb7cu1qTzss/KCjjDxrJBE7mxJ9b1TK0gxSANfkiKxveJrAJque\nYjLmt2F268BRyMncF91SNwIDAQABozUwMzASBgNVHREECzAJggdiZXRhZm9vMB0G\nA1UdDgQWBBQCWrIP+6UbPqDmZu4046xkI8hUwjANBgkqhkiG9w0BAQUFAAOCAQEA\nEDFP2mVE6wKa2qQdfJUPGLnPp8a5UZKkwrvGpRYcgPp2JRUPRY0sBJlOPM8JeGKi\nrdb+7oWy5pHdpXWEY3gD+Vod7aHJ2g8fQ70l+nqHmh5pFTzqb3dnh8Dbn9M8cG0F\n2bATYYQt7fLEmGIFQ81Ix5Qnm+owPw7QxemE7DaGL4CCyNB5xiX0Kx38eCeEFps8\nFqI3Il3tF2U+FgOT+nizupQelaoagRNerw3p2FHEYeBaTCYiW3IF7lUMIjoX2MYI\n9P5iyOC2nGSq2vAzarevECtjw7KtKuX4K37LIEB5r07NXCPlfgTzHq1KomrY5Lhm\n91krk/l5w5Ayt90FuWQbAA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://betafoo.nordu.net/saml2/acs/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Federated Django sample SP"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "uid",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "0.9.2342.19200300.100.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://kaltura.saas-idp-test.swamid.se/Saml2/proxy_saml2_backend.xml",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@sunet.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@sunet.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://kaltura.saas-idp-test.swamid.se/Saml2/proxy_saml2_backend.xml",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#md5",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#ripemd160",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http,//www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-md5",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-ripemd160",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SUNET Play"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://sunet.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SUNET Play"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://saas-idp-test.swamid.se/Saml2/disco",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIJAJ2oYIcVdeCnMA0GCSqGSIb3DQEBCwUAMCIxIDAeBgNV\nBAMMF3NhYXMtaWRwLXRlc3Quc3dhbWlkLnNlMB4XDTE2MDQyMjEwMDIxNVoXDTE2\nMDUyMjEwMDIxNVowIjEgMB4GA1UEAwwXc2Fhcy1pZHAtdGVzdC5zd2FtaWQuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCYm+GFzsTZbyzhGJ/bnc9C\nkBBZbZTpzSrVNhvvL6oa4c/vyhYh7Ba67JB35oQ7tjcf4YfLMs2N9YI1OVDX+FO+\nRebZedVNDcUVzqEkLN2rtwRwtniesEMxiRxwEh4CAo8GFy1LeZAc5QtZiJdFNWs5\ntfYTa2WmD++inPf3SymtDjbcB1pAAjLO5lxJoEVXTIZnAiqbvKfQvZpUSmidqoxO\nGj3cIz211FATr0NvoSZxx9g9Frr7neXYCEfFg7bJXYKZB1CigXqtk1Q3/WBDL9Lz\nHdxAeaJ0cHUtgQXUnWQ93pkgRzvYxBEzn3utnwAmtbx41d2Cty0TfR3KE0CJq1dp\nAgMBAAGjUDBOMB0GA1UdDgQWBBSktczsx8ebU+NG/XG4xqo2AUxr8jAfBgNVHSME\nGDAWgBSktczsx8ebU+NG/XG4xqo2AUxr8jAMBgNVHRMEBTADAQH/MA0GCSqGSIb3\nDQEBCwUAA4IBAQCAHoDP50F95ULtK9MRe9HBzj+4zK9XO8wTot6uY4G3gaeFDXUr\nzae5FbUFKnDbTACK/yUFjzPfSRWc5i8S9AdSIPJzQPffDTqOzKLKhhfAtRsHysxe\nMEkvSXepP1XiITRa/fIpPX9/HA3DI51WeAaNI0tu4r9bl2MWnI5oAqLLmAIetTNX\nOOmQimcvHRMfkStDwNXhlsjjvfwkibB2jRag4BJfMuSCn/1BxiQ1lMcpJDPeNPdB\n2cEO5CwnF2RKHNsWaWKN/peL53nk8smz4Yn+QhT2u6RAjslL8YSR7mcqfJCkAWHr\nvwUCgOYar5qF3huByMQmNfVFXoU6UDElCkeX"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIJAJ2oYIcVdeCnMA0GCSqGSIb3DQEBCwUAMCIxIDAeBgNV\nBAMMF3NhYXMtaWRwLXRlc3Quc3dhbWlkLnNlMB4XDTE2MDQyMjEwMDIxNVoXDTE2\nMDUyMjEwMDIxNVowIjEgMB4GA1UEAwwXc2Fhcy1pZHAtdGVzdC5zd2FtaWQuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCYm+GFzsTZbyzhGJ/bnc9C\nkBBZbZTpzSrVNhvvL6oa4c/vyhYh7Ba67JB35oQ7tjcf4YfLMs2N9YI1OVDX+FO+\nRebZedVNDcUVzqEkLN2rtwRwtniesEMxiRxwEh4CAo8GFy1LeZAc5QtZiJdFNWs5\ntfYTa2WmD++inPf3SymtDjbcB1pAAjLO5lxJoEVXTIZnAiqbvKfQvZpUSmidqoxO\nGj3cIz211FATr0NvoSZxx9g9Frr7neXYCEfFg7bJXYKZB1CigXqtk1Q3/WBDL9Lz\nHdxAeaJ0cHUtgQXUnWQ93pkgRzvYxBEzn3utnwAmtbx41d2Cty0TfR3KE0CJq1dp\nAgMBAAGjUDBOMB0GA1UdDgQWBBSktczsx8ebU+NG/XG4xqo2AUxr8jAfBgNVHSME\nGDAWgBSktczsx8ebU+NG/XG4xqo2AUxr8jAMBgNVHRMEBTADAQH/MA0GCSqGSIb3\nDQEBCwUAA4IBAQCAHoDP50F95ULtK9MRe9HBzj+4zK9XO8wTot6uY4G3gaeFDXUr\nzae5FbUFKnDbTACK/yUFjzPfSRWc5i8S9AdSIPJzQPffDTqOzKLKhhfAtRsHysxe\nMEkvSXepP1XiITRa/fIpPX9/HA3DI51WeAaNI0tu4r9bl2MWnI5oAqLLmAIetTNX\nOOmQimcvHRMfkStDwNXhlsjjvfwkibB2jRag4BJfMuSCn/1BxiQ1lMcpJDPeNPdB\n2cEO5CwnF2RKHNsWaWKN/peL53nk8smz4Yn+QhT2u6RAjslL8YSR7mcqfJCkAWHr\nvwUCgOYar5qF3huByMQmNfVFXoU6UDElCkeX"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://saas-idp-test.swamid.se/Saml2/acs/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://saas-idp-test.swamid.se/Saml2/acs/redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://sp.lat.csc.fi",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lind\u00e9n"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:fin-clarin@helsinki.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Krister"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Matthiesen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kielipankki@csc.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Aalto"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kielipankki@csc.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tero"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://sp.lat.csc.fi",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.csc.fi/english/institutions/haka/instructions/join/eduGAINRegistrationStatement/"
              }
            ],
            "registration_authority": "http://www.csc.fi/haka",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CSC - Tieteen tietotekniikan keskus Oy"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CSC - IT Center for Science Ltd."
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CSC - Tieteen tietotekniikan keskus Oy"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csc.fi"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csc.fi"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csc.fi"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CSC - Tieteen tietotekniikan keskus Oy"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CSC - IT Center for Science Ltd."
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CSC - Tieteen tietotekniikan keskus Oy"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://lat.csc.fi/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://tla.mpi.nl/a4-guides/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://tla.mpi.nl/a4-guides/"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://tla.mpi.nl/a4-guides/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "LAT \u2013 Language Archive Tools"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "LAT \u2013 Language Archive Tools"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "LAT is a user interface for language researchers to deposit and process audiovisual material."
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "LAT-palvelussa tutkijat voivat tallentaa ja k\u00e4sitell\u00e4 video- ja \u00e4\u00e4nimateriaalia."
                  }
                ],
                "logo": [
                  {
                    "text": "https://lat.csc.fi/gif/LA.png",
                    "height": "41",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://lat.csc.fi/corpora/Info/Lat_Privacy_Policy.html"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://lat.csc.fi/corpora/Info/Lat_Privacy_Policy.html"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://lat.csc.fi/corpora/Info/Lat_Privacy_Policy.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEYTCCA0mgAwIBAgIQIp6gFDuZ6VnJilIzPrnFvzANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDQxOTAwMDAwMFoXDTE2MDUxNjIzNTk1OVowODEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRMwEQYDVQQDEwpsYXQuY3NjLmZp\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxeInti6ywHVTSkzMdVwR\n4kTkapx06RcPwTRkFNtnIgKpe5XTfWewGh/h+EwYe9Fl/MNicdxo5SxPUyisNxSi\nw4cq8WEmLL9QfPxiDCbJbNEBJUc4XMgqeoNWnp0qYHIDqIAo9rVUqvI/hbkEexvN\nveMX8OXfpFBFrj6ZveDPhwi9/gJI4TZnw92h3Oo8GLtJvcXW/f7HgBuRnrCsUbJG\nWBEaiYWkcQeoWOPny5I+xCyleRP4vTfVrIkGrhaptaC1nrY0+rO98vBM0HC/LI8o\nM860aqpaWXZofJ5VweLHaGTXsr/yQdS3eB5KxcNKSY5uHWen4JzQwkgzk9gNidmA\n6QIDAQABo4IBZzCCAWMwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH6pDjue0w\nHQYDVR0OBBYEFDk6rvjXR1evlWyclQU4Qe/sUPF+MA4GA1UdDwEB/wQEAwIFoDAM\nBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNV\nHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAxMC+gLaAr\nhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNybDBtBggr\nBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5v\ncmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8vb2NzcC50Y3Mu\ndGVyZW5hLm9yZzAVBgNVHREEDjAMggpsYXQuY3NjLmZpMA0GCSqGSIb3DQEBBQUA\nA4IBAQCNbkTiCfr3bX3DWgymcCJ6bRNKxGVoGg8bq9aZrokE9GNTuBYnJuSe5XNl\n11+4pNQszc+JItNy612M55agdQrArrtzDp5MGWH0SoVCcoYv3DGkiKhaQhJeUBqV\njC+pHnekS6zfoVTN66KDHzU/JtJK3v8Bp3tudeAUlwXs7sSuiFSiD/Ua3qfZ21/v\nrkz1YmSz4bPS+bO477WiuDDTRHo5FSifBlWe46QQfM1beNCAiiBJZh0uyB6PPrD8\nCiBkuiUynwqLsQKjfkcSZa5W9a8spV7y8LmCAEtDk8l03p45TKRvWIgMAexg/60h\nTE5WJb+s+lUOs3IoVL33fpbG+Aor"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGKDCCBRCgAwIBAgIQCDaLAFllh/G6tbAenGqfPjANBgkqhkiG9w0BAQsFADBk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\nu6rNJlWkYCvlInc3MkWPxtgF8OqCZwcqjcAlmUD9/I3ReN2J2nkBis1zTVA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://lat.csc.fi/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "LAT-palvelussa tutkijat voivat tallentaa ja kasitella video- ja aanimateriaalia."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "LAT is a user interface for language researchers to deposit and process audiovisual material."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "LAT \u2013 Language Archive Tools"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "LAT \u2013 Language Archive Tools"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cas.educagri.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "khalid.farrahe@educagri.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cas.educagri.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-11-09T00:11:17Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cas.educagri.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cas.educagri.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cas.educagri.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "educagri.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.educagri.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Agricultural education, they are training for all levels, a great place for student life and individualized support for learners excellent employability. It is provided within public and private institutions."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "L\u2019enseignement agricole, ce sont des formations pour tout niveau, une grande place \u00e0 la vie \u00e9tudiante et un accompagnement individualis\u00e9 des apprenants pour une excellente insertion professionnelle. Il est dispens\u00e9 au sein d\u2019\u00e9tablissements publics et priv\u00e9s."
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Educagri"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Educagri - Enseignement Agricole"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEezCCA2OgAwIBAgIQHUcS+wnPV7LSIqe5j3rVeTANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDEwOTAwMDAwMFoXDTE2MDExMTIzNTk1OVowVzELMAkGA1UE\nBhMCRlIxFjAUBgNVBAoTDUFncm9zdXAgRGlqb24xFjAUBgNVBAsTDUVkdXRlci1D\nTkVSVEExGDAWBgNVBAMTD2Nhcy5lZHVjYWdyaS5mcjCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBALl111vi6dSX6qzz49BucGGumOP7B0OL7Rjjvctkyl65\nd6ECbrm8EloAQMfz1Ne43VzDoxiiWI9Unu+W4Reu0miOFIQDPDjZI0zRzYd2+bHs\nf/YWQygnCuiUHIAhFsMdnIW3yDC64xumVjZgGzTVby4hHEAY4CTYtm+FN8QXz1tm\n9uKDqkRbciLz0UBBgx0AGMfUmB4VhvjCJ6zIcQ1ePLTBZt4omT3h6HHYM3iVx4u2\nXBuOJhlnSl2BtcFz/Rwebyi6DWv/QprL0oJD5Fd8g9J1COfS5MKobZ24lKhFH2D6\n4ie40FVEFqf8ZK7gGaUV7l6WtN31AUULuk2a1unlAJkCAwEAAaOCAWIwggFeMB8G\nA1UdIwQYMBaAFAy9k2gM896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBSv1jHfEt61\nxKbsudGwlFVU2Mh/TDAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNV\nHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwGAYDVR0gBBEwDzANBgsrBgEEAbIx\nAQICHTA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3Jn\nL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0\ndHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUF\nBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAaBgNVHREEEzARgg9jYXMu\nZWR1Y2FncmkuZnIwDQYJKoZIhvcNAQEFBQADggEBABCKlz2uACI8H84L4XplIWXJ\nTpIHfFtWPiP2WtdmEdLoTcEOYffqULFaKPuJyNZjTOo8K4iB/bZIQxFhKXdosRiY\nvJp5LNr3XZcFwoIvYB8BmLLE4eNpdSpYtaPx5cnZDafuRwM/uWnjQRxoXQLhVuX9\naEvmYbWSSh7ZEJutIyLgZMsXRUQR1lbnsvYit1u+BlBkOhsbDDzl5kw+F9TbR8uN\nGG2aPW9m3f9ndjoLUdCVg4D54KSiUTPDihaPSk2Ye2zo5BU4f8VLWCoDR7bFSs39\nlFt/OsRU7CWuaoEe+asPiuldDQ+7HxNUbXAXIWXZrc3svUj75V3wSRbPlSDmYUg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Educagri - Enseignement Agricole"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.educagri.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Educagri - Enseignement Agricole"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.asmscience.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:service@asmusa.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Service"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Arbuthnott"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:openathens@publishingtechnology.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Peter"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.asmscience.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-07-31T15:36:54Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ASM Science"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.asmscience.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Publishing Technology plc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDnDCCAoSgAwIBAgIEUe5jgTANBgkqhkiG9w0BAQUFADCBjzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFDASBgNVBAgTC094Zm9yZHNoaXJlMQ8wDQYDVQQHEwZPeGZvcmQxHjAcBgNV\n\t\t\t\t\t\tBAoTFVB1Ymxpc2hpbmcgVGVjaG5vbG9neTEZMBcGA1UECxMQU2Nob2xhcmx5IE9u\n\t\t\t\t\t\tbGluZTEeMBwGA1UEAxMVUHVibGlzaGluZyBUZWNobm9sb2d5MB4XDTEzMDcyMzEx\n\t\t\t\t\t\tMDUzN1oXDTE2MDcyMjExMDUzN1owgY8xCzAJBgNVBAYTAkdCMRQwEgYDVQQIEwtP\n\t\t\t\t\t\teGZvcmRzaGlyZTEPMA0GA1UEBxMGT3hmb3JkMR4wHAYDVQQKExVQdWJsaXNoaW5n\n\t\t\t\t\t\tIFRlY2hub2xvZ3kxGTAXBgNVBAsTEFNjaG9sYXJseSBPbmxpbmUxHjAcBgNVBAMT\n\t\t\t\t\t\tFVB1Ymxpc2hpbmcgVGVjaG5vbG9neTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\n\t\t\t\t\t\tAQoCggEBAKz4tWwjcP2+Ld9vIqdI9ssmUF7yJVnDUoJqAPhejPOFSvrEZrjvofnY\n\t\t\t\t\t\t6VIcPcL3tyUADrD/vTRCb3T1FuQKsRnXgYzYI9o84hK6IZyTVzzD1G3Kil5ivsNq\n\t\t\t\t\t\tndv5hcMNfbH5kjGLfKvgHixrkR5HkLfITBghQydtCur4Yze0+u3mFu4OTabmqILH\n\t\t\t\t\t\thcnWlLPohznyRtx5F3fTtFFC/cUHAonymmH8OG3xQOhLFR1dSK5i2oGoRdqme6mR\n\t\t\t\t\t\tFiFHS8832tGjqsb072rFdpxKSmPLxz0vBxoa/YVw0RP6OYgt5Gze6mPOv1rFE5jq\n\t\t\t\t\t\tnMegHU7gLilsR6AS9GQoE+KUNiBeYhsCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tOlI/iGvczpy+BZErTXPBvizoKvFJzoi5Ri+zRRu+49qR67uMrnpKAQ51Weae6kj8\n\t\t\t\t\t\ttz0+iQIcKbyOO/9A+7Iu55PWruI4w0Qe4c8cCmFg5crORj2Orel3IMrT5s4XXOZ2\n\t\t\t\t\t\tMHweTl9+ZGFpshUYbSdPvj2vN8RhpC1c644lHVK0xceVxd3pFZA6VdtKfrnjyfXH\n\t\t\t\t\t\tt2m6Pzr00zEvxcvZch5rXdtH/tdSp8fRQzAoAWB1MBXTLBL1xztRSTacPMJYdiNP\n\t\t\t\t\t\tetGuGMwdTlZcDiknmfJT4zwcf6U1kXLon29n9b+6/Yq9wo+XYXd+HjGNmaJAhZm3\n\t\t\t\t\t\tmWuKjo4lfM11tPcrL+QV0g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDnDCCAoSgAwIBAgIEUe5jgTANBgkqhkiG9w0BAQUFADCBjzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFDASBgNVBAgTC094Zm9yZHNoaXJlMQ8wDQYDVQQHEwZPeGZvcmQxHjAcBgNV\n\t\t\t\t\t\tBAoTFVB1Ymxpc2hpbmcgVGVjaG5vbG9neTEZMBcGA1UECxMQU2Nob2xhcmx5IE9u\n\t\t\t\t\t\tbGluZTEeMBwGA1UEAxMVUHVibGlzaGluZyBUZWNobm9sb2d5MB4XDTEzMDcyMzEx\n\t\t\t\t\t\tMDUzN1oXDTE2MDcyMjExMDUzN1owgY8xCzAJBgNVBAYTAkdCMRQwEgYDVQQIEwtP\n\t\t\t\t\t\teGZvcmRzaGlyZTEPMA0GA1UEBxMGT3hmb3JkMR4wHAYDVQQKExVQdWJsaXNoaW5n\n\t\t\t\t\t\tIFRlY2hub2xvZ3kxGTAXBgNVBAsTEFNjaG9sYXJseSBPbmxpbmUxHjAcBgNVBAMT\n\t\t\t\t\t\tFVB1Ymxpc2hpbmcgVGVjaG5vbG9neTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\n\t\t\t\t\t\tAQoCggEBAKz4tWwjcP2+Ld9vIqdI9ssmUF7yJVnDUoJqAPhejPOFSvrEZrjvofnY\n\t\t\t\t\t\t6VIcPcL3tyUADrD/vTRCb3T1FuQKsRnXgYzYI9o84hK6IZyTVzzD1G3Kil5ivsNq\n\t\t\t\t\t\tndv5hcMNfbH5kjGLfKvgHixrkR5HkLfITBghQydtCur4Yze0+u3mFu4OTabmqILH\n\t\t\t\t\t\thcnWlLPohznyRtx5F3fTtFFC/cUHAonymmH8OG3xQOhLFR1dSK5i2oGoRdqme6mR\n\t\t\t\t\t\tFiFHS8832tGjqsb072rFdpxKSmPLxz0vBxoa/YVw0RP6OYgt5Gze6mPOv1rFE5jq\n\t\t\t\t\t\tnMegHU7gLilsR6AS9GQoE+KUNiBeYhsCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tOlI/iGvczpy+BZErTXPBvizoKvFJzoi5Ri+zRRu+49qR67uMrnpKAQ51Weae6kj8\n\t\t\t\t\t\ttz0+iQIcKbyOO/9A+7Iu55PWruI4w0Qe4c8cCmFg5crORj2Orel3IMrT5s4XXOZ2\n\t\t\t\t\t\tMHweTl9+ZGFpshUYbSdPvj2vN8RhpC1c644lHVK0xceVxd3pFZA6VdtKfrnjyfXH\n\t\t\t\t\t\tt2m6Pzr00zEvxcvZch5rXdtH/tdSp8fRQzAoAWB1MBXTLBL1xztRSTacPMJYdiNP\n\t\t\t\t\t\tetGuGMwdTlZcDiknmfJT4zwcf6U1kXLon29n9b+6/Yq9wo+XYXd+HjGNmaJAhZm3\n\t\t\t\t\t\tmWuKjo4lfM11tPcrL+QV0g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://www.asmscience.org/session/shib",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.asmscience.org/session/shib",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cafe-gateway.ifce.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jessyca"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ijessyca@ifce.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe-gateway.ifce.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDzjCCArYCAQAwDQYJKoZIhvcNAQEFBQAwgawxIzAhBgNVBAoTGklOU1RJVFVU\nTyBGRURFUkFMIERPIENFQVJBMQ0wCwYDVQQLEwRJRkNFMSIwIAYJKoZIhvcNAQkB\nFhNzdXBvcnRlQGlmY2UuZWR1LmJyMRIwEAYDVQQHEwlGb3J0YWxlemExDjAMBgNV\nBAgTBUNlYXJhMQswCQYDVQQGEwJCUjEhMB8GA1UEAxMYY2FmZS1nYXRld2F5Lmlm\nY2UuZWR1LmJyMB4XDTE1MDcyNzE4MDA1N1oXDTE4MDcyNjE4MDA1N1owgawxIzAh\nBgNVBAoTGklOU1RJVFVUTyBGRURFUkFMIERPIENFQVJBMQ0wCwYDVQQLEwRJRkNF\nMSIwIAYJKoZIhvcNAQkBFhNzdXBvcnRlQGlmY2UuZWR1LmJyMRIwEAYDVQQHEwlG\nb3J0YWxlemExDjAMBgNVBAgTBUNlYXJhMQswCQYDVQQGEwJCUjEhMB8GA1UEAxMY\nY2FmZS1nYXRld2F5LmlmY2UuZWR1LmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEAwbQCV74T4dzotdQhgUDJ7HKk4ax7RkCIe/wDWbZKiJWk/8C7FmMd\n5ny2BgHaD3ARXuwFW1HNxY+l8OcwSfBXTJxkurW53zlqdFRYcJeCqOAE4k8LlI1+\n6v1v5z7Prxyyi03ruX/gqFOFWVfVsNIqyBv2wHOUd3GWaM+o+3ic9Abd/d6D4D7N\nVWhNtyINH4wzRpqjDDSgWymwHGxI7ObBM7zLlJaHRm0M3nT8oh5mp2YtH9s2DRUg\neJ7IqCC7R1/vnzemh/CGr+SHDzmRrJFY5lGUrYM+oziWRZgVr2HCLtKNWIa17iIU\nGblDJT1E7G2vUGtGu5WHWC9GJDbUkSpiHQIDAQABMA0GCSqGSIb3DQEBBQUAA4IB\nAQCr74KCtDeIeMqWHLlky2SJOsFWp5GYsv2MTN985m+6C9drVN0MKh7vmJE0WXOE\nofIVJhiKOnA6cJ2nnMRtkYllHnfD5HdMpe3ImZ6kL7Phw9I6jcVjY/dIiL2txG7S\nNwbZWVpqu/bTQIkxiFB3qAujuPfeT6NaXQ6mNv0PmnC/76raZkr9MxpPi24z1i7Q\nGDbGrk0297/Kq6u+JoYV+Sy8OYi9P23ibg/jV+ACkfy7K4xDQZ76gg0bWvTK4sFj\ns9aiqLOUHREjOXpsvEa/B6CxUvNCSZcQO5p+tkwnSHPvcmxEDjZV1rmaKCJsC/aA\nvcq7vVYrtEXcJLkmBCQuQvhm"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ifce.edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe-gateway.ifce.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe-gateway.ifce.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe-gateway.ifce.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe-gateway.ifce.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe-gateway.ifce.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe-gateway.ifce.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe-gateway.ifce.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe-gateway.ifce.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ifce.edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifce.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifce.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFCE - Instituto Federal de Educacao do Ceara"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFCE - Instituto Federal de Educacao do Ceara"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFCE - Instituto Federal de Educacao do Ceara"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFCE - Instituto Federal de Educacao do Ceara"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDzjCCArYCAQAwDQYJKoZIhvcNAQEFBQAwgawxIzAhBgNVBAoTGklOU1RJVFVU\nTyBGRURFUkFMIERPIENFQVJBMQ0wCwYDVQQLEwRJRkNFMSIwIAYJKoZIhvcNAQkB\nFhNzdXBvcnRlQGlmY2UuZWR1LmJyMRIwEAYDVQQHEwlGb3J0YWxlemExDjAMBgNV\nBAgTBUNlYXJhMQswCQYDVQQGEwJCUjEhMB8GA1UEAxMYY2FmZS1nYXRld2F5Lmlm\nY2UuZWR1LmJyMB4XDTE1MDcyNzE4MDA1N1oXDTE4MDcyNjE4MDA1N1owgawxIzAh\nBgNVBAoTGklOU1RJVFVUTyBGRURFUkFMIERPIENFQVJBMQ0wCwYDVQQLEwRJRkNF\nMSIwIAYJKoZIhvcNAQkBFhNzdXBvcnRlQGlmY2UuZWR1LmJyMRIwEAYDVQQHEwlG\nb3J0YWxlemExDjAMBgNVBAgTBUNlYXJhMQswCQYDVQQGEwJCUjEhMB8GA1UEAxMY\nY2FmZS1nYXRld2F5LmlmY2UuZWR1LmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEAwbQCV74T4dzotdQhgUDJ7HKk4ax7RkCIe/wDWbZKiJWk/8C7FmMd\n5ny2BgHaD3ARXuwFW1HNxY+l8OcwSfBXTJxkurW53zlqdFRYcJeCqOAE4k8LlI1+\n6v1v5z7Prxyyi03ruX/gqFOFWVfVsNIqyBv2wHOUd3GWaM+o+3ic9Abd/d6D4D7N\nVWhNtyINH4wzRpqjDDSgWymwHGxI7ObBM7zLlJaHRm0M3nT8oh5mp2YtH9s2DRUg\neJ7IqCC7R1/vnzemh/CGr+SHDzmRrJFY5lGUrYM+oziWRZgVr2HCLtKNWIa17iIU\nGblDJT1E7G2vUGtGu5WHWC9GJDbUkSpiHQIDAQABMA0GCSqGSIb3DQEBBQUAA4IB\nAQCr74KCtDeIeMqWHLlky2SJOsFWp5GYsv2MTN985m+6C9drVN0MKh7vmJE0WXOE\nofIVJhiKOnA6cJ2nnMRtkYllHnfD5HdMpe3ImZ6kL7Phw9I6jcVjY/dIiL2txG7S\nNwbZWVpqu/bTQIkxiFB3qAujuPfeT6NaXQ6mNv0PmnC/76raZkr9MxpPi24z1i7Q\nGDbGrk0297/Kq6u+JoYV+Sy8OYi9P23ibg/jV+ACkfy7K4xDQZ76gg0bWvTK4sFj\ns9aiqLOUHREjOXpsvEa/B6CxUvNCSZcQO5p+tkwnSHPvcmxEDjZV1rmaKCJsC/aA\nvcq7vVYrtEXcJLkmBCQuQvhm"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFCE - Instituto Federal de Educacao do Ceara"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFCE - Instituto Federal de Educacao do Ceara"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifce.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifce.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFCE - Instituto Federal de Educacao do Ceara"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFCE - Instituto Federal de Educacao do Ceara"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://apps.csustan.edu/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "CBoucher@csustan.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Craig Boucher"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ccardoza@csustan.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Corey Cardoza"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://apps.csustan.edu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California State University, Stanislaus"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csustan.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California State University, Stanislaus"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth.csustan.edu/idp/Authn/UserPassword",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CSU Stanislaus App SP"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CSUStan Apps"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCDCCAfSgAwIBAgIQ5gj90g5xF75DsDsK752nNjAJBgUrDgMCHQUAMBsxGTAX\nBgNVBAMTEGFwcHMuY3N1c3Rhbi5lZHUwHhcNMTYwMzEwMjMyMTU3WhcNMzkxMjMx\nMjM1OTU5WjAbMRkwFwYDVQQDExBhcHBzLmNzdXN0YW4uZWR1MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqjDah5p4yx9wcqFhM1sWIsrqre0ss7hk+tbB\nMLhTQISkDexyjhXcvmF2j4AMR+DBRL59wfUWlPUxdcr2Z2Uj1FOhy9M/pE/O/wwt\nKphWIyt7wcrMr0mjlrEfz/ZZViJsVpcGt8tP/qF3yApdAsL/ysP1mxUajeBhAkIt\nU8xVbp4nW40yyaKuD2q94DESBCDtyqFjqZRQxPPK6tJW/DT4f3RlY4sAOS9TLHXl\nYf9PwlCiVV6W8qpqW1e9QOYsTqqi/NgX3jm32H4uhGbgNjOZLTy4De8lSS1EbQEQ\ndYNe+xrwiIhB4W/xfnjIxaM2IDaUuDNXhdXBVB5eDN73DhYxIQIDAQABo1AwTjBM\nBgNVHQEERTBDgBDYm1T930KHxBrGfo73ShSvoR0wGzEZMBcGA1UEAxMQYXBwcy5j\nc3VzdGFuLmVkdYIQ5gj90g5xF75DsDsK752nNjAJBgUrDgMCHQUAA4IBAQCObgiC\nE9qQkcqrpdt8Wm7hA2u7zLAxY3ITTsq/MA6a+zVBWI8CHLOic1wpENuVbMqj9tnx\ns2rOJomaT+TW7HQ0+f1pvf1/qsuX/Vi+Uh7gnfjJOdJW/9CgoLh+/1hyUyT5zQ+3\nyswNNfR06uJ+jBY7kV6y5TK+MZVXTOJP63quI3mO57QQ6kN2vcq7KTmjUYMnXIQG\nLOhaWrLcKD9/4YmEitNKxHu4abGj7Ll71Kf3RW3d5oyVpLZ5JrxgbF3DnW4M8iaL\n8z+Qa105gCm3fm7sIlrHJx2dp7RgbIl8paEzaBeeZAUilz1VbttXivTFV/DWC0/c\nxFxzcdITxtRaIIG4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://apps.csustan.edu/skillsoftimport/assertionservice.aspx",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://apps.csustan.edu/test/skillsoftimport/assertionservice.aspx",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CSUStan Apps"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "CSU Stanislaus App SP"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://acount-utv.hh.se/Shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gabrielsson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "bjorn.gabrielsson@hh.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "H\u00f6gskolan i Halmstad"
          },
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bj\u00f6rn"
          }
        }
      ],
      "entity_id": "https://acount-utv.hh.se/Shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "H\u00f6gskolan i Halmstad"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hh.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "H\u00f6gskolan i Halmstad"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://account-utv.hh.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://account-utv.hh.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://account-utv.hh.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://account-utv.hh.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://account-utv.hh.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://account-utv.hh.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://account-utv.hh.se"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://account-utv.se"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service is only used for testing"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Denna t\u00e4nst anv\u00e4nds endast f\u00f6r test och utveckling"
                  }
                ],
                "logo": [
                  {
                    "text": "https://signon.hh.se/hh-logo-en-350x116.png",
                    "height": "116",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  },
                  {
                    "text": "https://signon.hh.se/hh-logo-sv-350x116.png",
                    "lang": "sv",
                    "height": "116",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  },
                  {
                    "text": "https://signon.hh.se/hh-logo-en-350x116.png",
                    "lang": "en",
                    "height": "116",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "H\u00f6gskolan i Halmstad developer site for user account activation and password reset"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "H\u00f6gskolan i Halmstad utvecklingsmilj\u00f6 f\u00f6r kontoaktivering och l\u00f6senords\u00e5terst\u00e4llning"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "account-utv.hh.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+jCCAeKgAwIBAgIJANQBgWyxjcu1MA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\nBAMTEWFjY291bnQtdXR2LmhoLnNlMB4XDTE1MDIwNDExNTQzM1oXDTI1MDIwMTEx\nNTQzM1owHDEaMBgGA1UEAxMRYWNjb3VudC11dHYuaGguc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDAzLvnPNl20YzyKq1w0+ItQ2dUuaB403f1CCm1\nrxWP2mti32s8si+FxOI1r+KTgAbOETbSK5rnZIrjPWMWjOttvb7KD19xlcQoZb4t\nRPlJeUaI6uWMHVefkqdw6ic0vuc2BroTA8odXTQ23F+BM+O5n5KcaRWg0ohYC+E/\nuz+xbbrMwtI+LWRG9U3rGVkITvvHYfG1N1GhbwnUQXXl7G49IjDb7IfR38ao2fxO\nAMs8sCJhb75vpv62GD0bItlxuR6B467WKnRXYoOJH0w959nXTRll+gn9KO5x+tjB\ntr0KSzwsMYHxzmdz5vZ1PeFDoA6Hrf2Is+/HKZvb2aqn4YEhAgMBAAGjPzA9MBwG\nA1UdEQQVMBOCEWFjY291bnQtdXR2LmhoLnNlMB0GA1UdDgQWBBSsGXubXOkJhZfJ\n5W7GnickMPVnxjANBgkqhkiG9w0BAQUFAAOCAQEAYIEOH99rtKHb8Wmu3dmdjqmF\nTLd8+le3aK18fopuqcrBJNfCaAYONr1kqvxdl+tytesLX+/b/hDYGdRmMwNEdms2\nlyLlZ8WaOstWONbgCZa0npf9+9ldj2mG3f1jcwapmFLpkNfiJEKLxnDIXLPh318b\n26zJHgE6CYNMKS1VqubMNMOiwwqYS/mfmnIAmKxzv7Q5xxvDLUvVehXBZa9BDBFK\nM0k/gTbCKW5u2pm5OBnt3jdxAmuPcgMk3nsTbSABUCvqwR9w8fqHSAaHFwivUDLb\n4l1Yvcq+V6EZhqviCcHxfsRdDmUm7iXfxdWn/G/9vX2VKuba5JQ2ieZoxYVI2Q=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=account-utv.hh.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://account-utv.hh.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://account-utv.hh.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://account-utv.hh.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://account-utv.hh.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://account-utv.hh.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://account-utv.hh.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://account-utv.hh.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://account-utv.hh.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://account-utv.hh.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib-sp-dev.cf.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idman@cardiff.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Identity Management"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smart"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:smartp@cardiff.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Philip"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib-sp-dev.cf.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-10-23T14:26:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cardiff University Test SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cardiff.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cardiff University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-sp-dev.cf.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-sp-dev.cf.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-sp-dev.cf.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib-sp-dev.cf.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDETCCAfmgAwIBAgIJAPGWoIhDomdwMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\n\t\t\t\t\t\tBAMTC3NoaWItc3AtZGV2MB4XDTEwMTEwNTA0MTY1MVoXDTMwMTAzMTA0MTY1MVow\n\t\t\t\t\t\tFjEUMBIGA1UEAxMLc2hpYi1zcC1kZXYwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQDPvKQqQDjZxRKqICIU8CfnT+wU1zRJIHgP9fbiebqVEpklkUwXnlQK\n\t\t\t\t\t\t+Bif5oNaHAKq3etAp/QzP9/HffBCTHrRubdXPjzzhsqDCLvLMZ4xFk/omgjl36/N\n\t\t\t\t\t\t1ruDUapMB2T0xUGS2Gev1olYbfL0MjRnhQqasJOvdqswI/U9eU8xYXLnz1dqeOPs\n\t\t\t\t\t\tUry21Zop4fVL9KY6sAvFDg6TrdgY7h5f8RJbIkjA3R3E0M+TR/dZiOvIw4CIjKFU\n\t\t\t\t\t\tqUcIX4F+c0BGvSJU4RaunAG9RyNTGZvm9LBptiVcLGNXMyb0+KxIpwFQdd9juOpp\n\t\t\t\t\t\tOXHjzkqxwQ87BZ+lCPMH5I4UhqBfNNJDAgMBAAGjYjBgMD8GA1UdEQQ4MDaCC3No\n\t\t\t\t\t\taWItc3AtZGV2hidodHRwczovL3NoaWItc3AtZGV2LmNmLmFjLnVrL3NoaWJib2xl\n\t\t\t\t\t\tdGgwHQYDVR0OBBYEFAiqFmapO7egaR+j3lXoc8yFYs6oMA0GCSqGSIb3DQEBBQUA\n\t\t\t\t\t\tA4IBAQATLXYR4ia9D/oDtOBHmfxwRHLcrDZqUdYD2NmJc3R7VQoV+SiGeHCxqZ65\n\t\t\t\t\t\twF5wWEDWByWjk/LQmOM/vov8UzlLD6GlyVlyo/yLfvNrsDbh83Ohc4TSLKXGar1x\n\t\t\t\t\t\t2IzA6DP5OwA0FdJ5mZt6F+Mx9f/bo/yQf4yh219Gkuy/2MBtlTDelkSALTuoiaiq\n\t\t\t\t\t\t9VuAp1o2yJr3ttEa3oyZUQyMi0TbnfVd8rfEkGefvGvjmWdDSRT1ZoojRIfZh+tV\n\t\t\t\t\t\tw4NpiARsEdi/nWgud1MV7GTScg9YtZcaCahDoVeXVSTao4+NxBKXjlalGieMLlzC\n\t\t\t\t\t\tZgojzE1jEQkVmYzQirlmP/kiz1k5"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDETCCAfmgAwIBAgIJAPGWoIhDomdwMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\n\t\t\t\t\t\tBAMTC3NoaWItc3AtZGV2MB4XDTEwMTEwNTA0MTY1MVoXDTMwMTAzMTA0MTY1MVow\n\t\t\t\t\t\tFjEUMBIGA1UEAxMLc2hpYi1zcC1kZXYwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQDPvKQqQDjZxRKqICIU8CfnT+wU1zRJIHgP9fbiebqVEpklkUwXnlQK\n\t\t\t\t\t\t+Bif5oNaHAKq3etAp/QzP9/HffBCTHrRubdXPjzzhsqDCLvLMZ4xFk/omgjl36/N\n\t\t\t\t\t\t1ruDUapMB2T0xUGS2Gev1olYbfL0MjRnhQqasJOvdqswI/U9eU8xYXLnz1dqeOPs\n\t\t\t\t\t\tUry21Zop4fVL9KY6sAvFDg6TrdgY7h5f8RJbIkjA3R3E0M+TR/dZiOvIw4CIjKFU\n\t\t\t\t\t\tqUcIX4F+c0BGvSJU4RaunAG9RyNTGZvm9LBptiVcLGNXMyb0+KxIpwFQdd9juOpp\n\t\t\t\t\t\tOXHjzkqxwQ87BZ+lCPMH5I4UhqBfNNJDAgMBAAGjYjBgMD8GA1UdEQQ4MDaCC3No\n\t\t\t\t\t\taWItc3AtZGV2hidodHRwczovL3NoaWItc3AtZGV2LmNmLmFjLnVrL3NoaWJib2xl\n\t\t\t\t\t\tdGgwHQYDVR0OBBYEFAiqFmapO7egaR+j3lXoc8yFYs6oMA0GCSqGSIb3DQEBBQUA\n\t\t\t\t\t\tA4IBAQATLXYR4ia9D/oDtOBHmfxwRHLcrDZqUdYD2NmJc3R7VQoV+SiGeHCxqZ65\n\t\t\t\t\t\twF5wWEDWByWjk/LQmOM/vov8UzlLD6GlyVlyo/yLfvNrsDbh83Ohc4TSLKXGar1x\n\t\t\t\t\t\t2IzA6DP5OwA0FdJ5mZt6F+Mx9f/bo/yQf4yh219Gkuy/2MBtlTDelkSALTuoiaiq\n\t\t\t\t\t\t9VuAp1o2yJr3ttEa3oyZUQyMi0TbnfVd8rfEkGefvGvjmWdDSRT1ZoojRIfZh+tV\n\t\t\t\t\t\tw4NpiARsEdi/nWgud1MV7GTScg9YtZcaCahDoVeXVSTao4+NxBKXjlalGieMLlzC\n\t\t\t\t\t\tZgojzE1jEQkVmYzQirlmP/kiz1k5"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-sp-dev.cf.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-sp-dev.cf.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-sp-dev.cf.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib-sp-dev.cf.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-sp-dev.cf.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib-sp-dev.cf.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib-sp-dev.cf.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shib-sp-dev.cf.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shib-sp-dev.cf.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shib-sp-dev.cf.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://screeningshorts.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ciarrocca"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:web@scottishfilm.scot"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paolo"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ciarrocca"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:web@scottishfilm.scot"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paolo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://screeningshorts.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-15T15:56:55Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Screening Shorts"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://screeningshorts.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Scottish Film Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://screeningshorts.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://screeningshorts.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://screeningshorts.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://screeningshorts.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://screeningshorts.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://screeningshorts.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://screeningshorts.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Screening Shorts is a range of in-depth tutorials exploring moving image literacy in the classroom."
                  }
                ],
                "logo": [
                  {
                    "text": "https://screeningshorts.org.uk/sites/default/files/UK-Fed-SS.png",
                    "height": "116",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Screening Shorts"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4jCCAcqgAwIBAgIJAJfnVMY+1ZfdMA0GCSqGSIb3DQEBBQUAMBQxEjAQBgNV\n\t\t\t\t\t\tBAMTCWxvY2FsaG9zdDAeFw0xNjA0MTQxNTQ3NDlaFw0yNjA0MTIxNTQ3NDlaMBQx\n\t\t\t\t\t\tEjAQBgNVBAMTCWxvY2FsaG9zdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBALF3nJ2IbavPJMVsljjuLgJDJnSJtb06cWWTfQCPA55oAe9XZkIpwuA/gGjS\n\t\t\t\t\t\ta4/vschPSjH/H+WHPCEfIwFG2I2qK62ss+/NXcnPAj3S8MhXludG4XF2/XkSK0k7\n\t\t\t\t\t\tMDbDGGEMJDTtQIWkQum/PMfQsNDPRu6F36cPXn7EZi/ltkbEirdjslCxtVlbo6R8\n\t\t\t\t\t\tmAf+P2WTpRX3bye2BpSQLbTSAla+cievq9mJBP0WeQGYyTk2PKjKrbt8MF8uM+Wi\n\t\t\t\t\t\tbwHuL0wU3qEOGE5aXbvibnwxA6Bsto0uGknqvWCLpzazjpL1BAGZ4UNYasRJCnE4\n\t\t\t\t\t\t0m3Q+7AxhK8bSdtF8vaX6GZ79F0CAwEAAaM3MDUwFAYDVR0RBA0wC4IJbG9jYWxo\n\t\t\t\t\t\tb3N0MB0GA1UdDgQWBBQdF2eZYsKvX8f92jhRD4mWcLhaGTANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAj8Pi2cG34jKsSFLH8/iBBgzBEouymgZDgTWFkY72SCReAhF6qSOHPMq3\n\t\t\t\t\t\tGAxQCPW/sl1CtVxiTkyDkjxMrRWMKmplC/NnRnMN7vG6/KIEGmJpUmkYkXPPW1wW\n\t\t\t\t\t\tsvQnCpCjTuawK8LIMGENw9WfDGChXbDPvJD3PW2M8paqeB4H8BG5EOAees7ntuzF\n\t\t\t\t\t\tiRa87V5U2yiQozxI+mOnev9r8mOssmY3qOU1UXXxRDMwXcy3PImvA8nNqBM3ePVj\n\t\t\t\t\t\tRJbkUxN29dAC8j1+1KT9CTYnh9rRW321jJ24Gj/V5fp4QBaZuqZA/Y8J9cAz3Fn6\n\t\t\t\t\t\txUXPQ//vxoNpkf4LAWgCpsNZ8iRGbQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://screeningshorts.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://screeningshorts.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://screeningshorts.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://screeningshorts.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://screeningshorts.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://screeningshorts.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://bureau.idp.knaw.nl/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bureau.idp.knaw.nl/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-05-12T13:20:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/67a684e304b6bfffde2a662f795689cd",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "knaw.nl"
              },
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Bureau (KNAW)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Bureau (KNAW)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/knaw.png",
                    "height": "48",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "48"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Bureau (KNAW)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Bureau (KNAW)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Koninklijke Nederlandse Akademie van Wetenschappen (KNAW)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.knaw.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Koninklijke Nederlandse Akademie van Wetenschappen (KNAW)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://singlesignon.gwu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dhina@gwu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dhinakaran Thamanan Ramaian (Dhina)"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dhina@gwu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dhinakaran Thamanan Ramaian (Dhina)"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://singlesignon.gwu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/assurance/bronze"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oasis:names:tc:SAML:attribute:assurance-certification",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://singlesignon.gwu.edu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://singlesignon.gwu.edu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://singlesignon.gwu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://singlesignon.gwu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://singlesignon.gwu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://singlesignon.gwu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://singlesignon.gwu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gwu.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://singlesignon.gwu.edu/idp/images/gwlogo.png",
                    "lang": "en",
                    "height": "90",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "199"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The George Washington University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUCCBIyMPxHCBVy4X6syXgB3qY64gwDQYJKoZIhvcNAQEF\nBQAwHzEdMBsGA1UEAxMUc2luZ2xlc2lnbm9uLmd3dS5lZHUwHhcNMTMwNTE1MTMx\nNDU3WhcNMzMwNTE1MTMxNDU3WjAfMR0wGwYDVQQDExRzaW5nbGVzaWdub24uZ3d1\nLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKWgSYvEgHdsFFAv\nww8Z7ePb4hwpsrYdbauSArofVI3tE6USHvhH5PgDqhvYzk4HkKZSs1WUmggI0keY\nHvChJAnlDmMjaDAjfPymFMmMYfjhOMaVJmV+GLEcoKpWd64LcmyYkfSbNE7TPJn0\nafWKXfJZ8DCIKDeDPzMVa2xIabNE4IvKt6gA73bR40wym72S4RfKxzzI1vw0UHNz\nri3uW1g5X5AiTsM9tOatIp4Hd40suXl59FUU1ipZzCKnP2qOSkOW47DNQEHoEWVN\nFW5BiJC8iR5D0LYph9eZt+7izq8GT38CeSpaZkA/uq6fDDNG96drZo2FZhzGoEo8\nH8u6PwsCAwEAAaNvMG0wTAYDVR0RBEUwQ4IUc2luZ2xlc2lnbm9uLmd3dS5lZHWG\nK2h0dHBzOi8vc2luZ2xlc2lnbm9uLmd3dS5lZHUvaWRwL3NoaWJib2xldGgwHQYD\nVR0OBBYEFHtesMCjBqphZFg+PXku5pUNc5uJMA0GCSqGSIb3DQEBBQUAA4IBAQAc\nQ7edavN+AswtQiwulho1K3MZ33339SlEMvzbhl2CPDCDqVLbH0ClRVYMZaS6Prdi\niV6GLHrp00gRXrojbOSDmqRZ29dTdauvIbIC07JTqgM4aV5PUOjxI+spLcCqI7GE\nMRvNiq47Lb/amkzUEkSjlaeMRMD2Ay8xzSTQ+8lweS5zoypJf9NzbH9jqP89VtW7\nbvAGbxdEwTssKwpaD1d2KWHdaX+SImsJ58jOna4mJ6eCAYPfjgrtLPht9aiRHtvx\nWz3Q2BXEs5f75bfIUKL/LKI8/LMmP650thtM6YlRjLIDNoa+ymaV48i1+Lb7dPRZ\n2/bMRZ3Y0d/jjfFfYyhu"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The George Washington University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gwu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The George Washington University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.leeds-art.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.leeds-art.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/leeds-art.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/leeds-art.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "leeds-art.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Leeds College of Art"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.leeds-art.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.utp.edu.pl/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "admin@utp.edu.pl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "DMASK"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.utp.edu.pl/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.pionier.net.pl/en/index.php?page=rps"
              }
            ],
            "registration_instant": "2015-06-23T00:00:00Z",
            "registration_authority": "https://aai.pionier.net.pl",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.utp.edu.pl/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.utp.edu.pl/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.utp.edu.pl/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.utp.edu.pl/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.utp.edu.pl:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.utp.edu.pl:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utp.edu.pl"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Science and Technology in Bydgoszcz"
                  },
                  {
                    "lang": "pl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Uniwersytet Technologiczno-Przyrodniczy w Bydgoszczy"
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.utp.edu.pl/idp/images/logo_org.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "411"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Science and Technology in Bydgoszcz"
                  },
                  {
                    "lang": "pl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Uniwersytet Technologiczno-Przyrodniczy w Bydgoszczy"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVANTZhzBBbVG3A5ID/bB5iH95qTPMMA0GCSqGSIb3DQEB\nCwUAMBsxGTAXBgNVBAMMEGxvZ2luLnV0cC5lZHUucGwwHhcNMTUwNDE2MTA1OTI0\nWhcNMzUwNDE2MTA1OTI0WjAbMRkwFwYDVQQDDBBsb2dpbi51dHAuZWR1LnBsMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAllSGUwYP6GLhIubTO5S2jMWa\nS8CQNbYQYVI2m0LLnenwF7WY+171KBELuGHECSZ0Ccao2fnTViuJOpZi0dQXz9xa\nq132AqkRAJkwqoUrlfagSu2eoJytFLHTj3C4JmRSHME+93gDywIEdBqGf5wjNEI7\nNleZMlGMjyhWpfmpqjBX9XKDPsuWef85r/Y/son/RIfOZgO5SMhxzLZVZN39Ts1W\nPeaa2E9Mh3oj3ktCiHXjY4Eo7ghLrLLN3EpJl2QO8bEyhflR1A/bV47zlJbPlR7w\nhDlnY2k9X3PKdIERJPKlBhnOSuLCzkWBuvX0HxCV/UYhRxfWCzH5RgQA7wtWqQID\nAQABo2cwZTAdBgNVHQ4EFgQUsx7kER7PTMhmv74cnrOeZQTGl6wwRAYDVR0RBD0w\nO4IQbG9naW4udXRwLmVkdS5wbIYnaHR0cHM6Ly9sb2dpbi51dHAuZWR1LnBsL2lk\ncC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQAyklTyfwRxWpkgryyseVBW\nxsRB6Cp8jcsdwv4mTjnSwopn9hlGzaIWOW/kzNte6ad4KNRt0h4z6HHtvKGZhNhu\ndE+csEjmINxTbWVQyyxKYA5JUMnNQKAH8pLKxFf/fwwdkVfZDrQlBmPEwFw/ItGr\nQST+t+jRw2fQIn/Dg54oXjZ1GcWc5/erSPO0CgtWgm20iJmeoDbinaosNg01pzLb\n/2Zkwu9baimGvvwuRioCWrv8eZwyeNDZTJht/KXlOdP3o46c6qqqO74unu4KjFmo\nM3XxZC+dPpFfVbMXN5To7yCoUzwi5rpQt6yjQJ17oa6ZsVMco6fNSBiAxum02hV8"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUfpqpOEPSJsl5JtwBlfItUOO3fCUwDQYJKoZIhvcNAQEL\nBQAwGzEZMBcGA1UEAwwQbG9naW4udXRwLmVkdS5wbDAeFw0xNTA0MTYxMDU5MjNa\nFw0zNTA0MTYxMDU5MjNaMBsxGTAXBgNVBAMMEGxvZ2luLnV0cC5lZHUucGwwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCe4jSHC7TIWPWaG3AN6q2qCb49\ntI3YzJoTMfFbsjMN5RBsYeYdzrBKyMRaG+Kx95hP5Bt7CqmoGAlsd0EpOa8SEI/Y\n6ObGfj8c5OhvTiilq82UIx/L5B/gEZGMJqS43KahUyCdew5AUk4PutObb3v246yL\nCbdv3JjL5V0raOAtn4GCTeHFI+Qz2/FKHaoJe5AiXGLFa7jO/rC7s7ZvdFwMzReO\ni1FxLK3yWLYe15p2AjKkdAgZwH3WesXq5cD9C7qnG9u6RutAmNvZY70Nv0NKXyxf\nKqt6LcKE6w5FIguvWxBuf24FDSdU+wnqGmbs3OyDKrfZluz7rfMnL3CTNih5AgMB\nAAGjZzBlMB0GA1UdDgQWBBT+xoMGWGXWuhpsXyKP/kMJkX1NmDBEBgNVHREEPTA7\nghBsb2dpbi51dHAuZWR1LnBshidodHRwczovL2xvZ2luLnV0cC5lZHUucGwvaWRw\nL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBACsimFVv+lJaE8o+9hI/Tm/m\nxdFkJE+nnSXHB+kFTzsbwLy6+S7opofS61dIAxdh3vwja0a8fnQre/yHVTD3j7Pe\n+mFPUZAlP3CSKMWMbBB9QyAxzCae4X/2ycp+ZOqEHMGN2Z3W+Z68YJ5kiLehB5QW\n7ZozBo46U8/jqWJUaMxvL2VdJswxrHlvBIq5geOr9W6mySh+jTn1vyLwiVb6HYVY\nr5pBrBBCUKf4CkNizS2sz5W0ikv9W0f8fehSVr33mABcJewP4lUkcM5Zxs2Ktost\niOsudRJYzu9b82Hc5lqvq6cG2xODy3YxKEAqMOQfUYZzpiyJsI6gj4iGEr+yI7o="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUbBTB/3SY7nD+jXiZK9grzmv42cswDQYJKoZIhvcNAQEL\nBQAwGzEZMBcGA1UEAwwQbG9naW4udXRwLmVkdS5wbDAeFw0xNTA0MTYxMDU5MjRa\nFw0zNTA0MTYxMDU5MjRaMBsxGTAXBgNVBAMMEGxvZ2luLnV0cC5lZHUucGwwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCAKyF1wxVIbrOsBldj73g+lRHz\nvs8aKX8J65jLV1TJ9MfKP3PQqRSiheI41/JkNdCYU6f4iQfiDZXThPPoRqVPOzX7\nXqI7eBq5s1/xoaCzE/Y4c6FnMrEewIvlcwN/+0Xik4QfFg7JR39DZ//rbKozutpI\nvfDrWr8Hs5e1xJbRuJ8gdqzTLWxLUPn3AlBPjIMfZxABDPpwywWkZ3c6yUlNgeue\ngC0GW60oHgcqCQqo1FTAUmr3/G1nru2DGB8seex6cSidC3xkncq0BCqbd7O4ungt\nSTx8OjHSbI/es9Ogil0FhMR83sTzKrmHGJE+wr/MFIdK2RI3ipWHxYBN4PPhAgMB\nAAGjZzBlMB0GA1UdDgQWBBQatgrUHOXId+l8/6VMtBBEsFQ8GzBEBgNVHREEPTA7\nghBsb2dpbi51dHAuZWR1LnBshidodHRwczovL2xvZ2luLnV0cC5lZHUucGwvaWRw\nL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBACUMR8r1YA36eNJ4MKR72MNt\ndszTKj0aKVyvNPu6qhseg04F0bzDoCNhBcQkHaWL1XFxmMjkQdrTSduOIARzJQ6t\nhLrWkTnzwwZucQdfECUlEwgZY2vaIGiCoWI1dGwdQR584zsTzLbjBna7VcTWtEid\nGT2KjwWOBkOKov1SWYU9Dio5ixbwqEj6Yk01avNO3H+ccIptZ1MNVX04uLnV0+J/\nMo5hv2+kVOVeoXhmkJNo7867iIY9vU87JL5T1YS2l/LxlhsDU5gHQWNesfwgxHsY\nl8pnSfcxhoDEKU6WG6KnFdf+SfFtdg2ktYT8adwxpf31LacR/ZoNfem086a6kN0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Science and Technology in Bydgoszcz"
          },
          {
            "lang": "pl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Uniwersytet Technologiczno-Przyrodniczy w Bydgoszczy"
          }
        ],
        "organization_url": [
          {
            "lang": "pl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utp.edu.pl"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utp.edu.pl/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "pl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Uniwersytet Technologiczno-Przyrodniczy w Bydgoszczy"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Science and Technology in Bydgoszcz"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://sts.uidaho.edu/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "systems@uidaho.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Systems Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "its-security@uidaho.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Security Office"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@uidaho.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "its-security@uidaho.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Security Office"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "http://sts.uidaho.edu/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sts.uidaho.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sts.uidaho.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sts.uidaho.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sts.uidaho.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sts.uidaho.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uidaho.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Idaho"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC2DCCAcCgAwIBAgIQanGKteQbqaJAlcgB3suvTDANBgkqhkiG9w0BAQsFADAo\nMSYwJAYDVQQDEx1BREZTIFNpZ25pbmcgLSBzdHMudWlkYWhvLmVkdTAeFw0xMzEx\nMjEwMjAzNDBaFw0yMzExMTkwMjAzNDBaMCgxJjAkBgNVBAMTHUFERlMgU2lnbmlu\nZyAtIHN0cy51aWRhaG8uZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAvxqCeaB16O2SwKSirv/0Td7CezzlEY8xC343HZwj15PZpaByb9XgIMHgnH18\n7440sKK6s+XJDnYcM2qIpYMpfxeDWR/6TaPswOEncF4BBHrT/ksaBHG38JWYs+OQ\nMLLbBUO+kNmZBu4SM1+lPmwgk4v+3m/W/rLZO0QzD/uUM1uocPAdb/HiAOFH+2gB\nemPOO12FDnfeWzTcF1051SY9/WBDhoaLVfTJ/uBX9WYcuuMMM4z+9C09f7H2x9pu\nvZ1IwFjoS9Az3jsGaDJ9XgOjrPzxv25NrtH6Dw77vruddYMOYfgADtZHhXi6co0n\nTULj5VIuMy38vlv5Ku6UGDpg2QIDAQABMA0GCSqGSIb3DQEBCwUAA4IBAQAcSBso\ns7Tqr0JHLR2waVJoaXn8hELPBSNMzk6GocSVCtkKeMQyxmw2LWxfEIob2ho+EdyY\nhn1gm+l0vxXL3tOwJDEDNs6eZAzUOyNUOjSNOxAZEgIitX+QzswpTttZ1WGhma2O\nF2dXuQFEv79aRuRI4Bz2LeH4hu0OBVJR3NgILkPZvMK/QxcTN03SEOFTyCc5Ck2a\nQXa2fVyd3xEe7FAoaisTPVMi6e8MQ4Jcu/bgBG52rAg+Y/Sgz+D2EIbgTDc0+xGY\nMGhvxW12UxkimmJ8rN9492Znq/GewfKGTTZHhIFvPfRsrSEcUphmwD+V2boyAs2b\n3kFlhhPzSTF6fK6w"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Idaho"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uidaho.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Idaho"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.kpi.ua/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "TechSupport"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@kpi.ua"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.kpi.ua/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://peano.uran.ua/~eng/policy.htm"
              }
            ],
            "registration_instant": "2015-05-12T11:00:51Z",
            "registration_authority": "https://peano.uran.ua",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.kpi.ua/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.kpi.ua/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idp.kpi.ua"
                  },
                  {
                    "lang": "ru",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idp.kpi.ua"
                  },
                  {
                    "lang": "uk",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idp.kpi.ua"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NTUU KPI IdP"
                  },
                  {
                    "lang": "ru",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u041d\u0422\u0423\u0423 \u041a\u041f\u0418 IdP"
                  },
                  {
                    "lang": "uk",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u041d\u0422\u0423\u0423 \u041a\u041f\u0406 IdP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for NTUU \"KPI\""
                  },
                  {
                    "lang": "ru",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider \u0434\u043b\u044f \u041d\u0422\u0423\u0423 \"\u041a\u041f\u0418\""
                  },
                  {
                    "lang": "uk",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider \u0434\u043b\u044f \u041d\u0422\u0423\u0423 \"\u041a\u041f\u0406\""
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.kpi.ua/kpi-logo.jpg",
                    "height": "219",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "181"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://peano.uran.ua/~eng/policy.htm"
                  },
                  {
                    "lang": "ru",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://peano.uran.ua/~rus/policy.htm"
                  },
                  {
                    "lang": "uk",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://peano.uran.ua/~ukr/policy.htm"
                  }
                ]
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "kpi.ua"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "ntu-kpi.kiev.ua"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:50.450233,30.461022"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "77.47.128.0/17"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2a02:db0::/32"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFkDCCBHigAwIBAgIRAPRpb7ML9+xEG/ROUJsB3TYwDQYJKoZIhvcNAQELBQAw\ngZAxCzAJBgNVBAYTAkdCMRswGQYDVQQIExJHcmVhdGVyIE1hbmNoZXN0ZXIxEDAO\nBgNVBAcTB1NhbGZvcmQxGjAYBgNVBAoTEUNPTU9ETyBDQSBMaW1pdGVkMTYwNAYD\nVQQDEy1DT01PRE8gUlNBIERvbWFpbiBWYWxpZGF0aW9uIFNlY3VyZSBTZXJ2ZXIg\nQ0EwHhcNMTUxMjA3MDAwMDAwWhcNMTcwMzA2MjM1OTU5WjCBmjEhMB8GA1UECxMY\nRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMUIwQAYDVQQLEzlQcm92aWRlZCBieSBD\nZW50ZXIgb2YgVWtyYWluaWFuIEludGVybmV0IE5hbWVzIChVS1JOQU1FUykxHDAa\nBgNVBAsTE1Vrcm5hbWVzIERvbWFpbiBTU0wxEzARBgNVBAMTCmlkcC5rcGkudWEw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDb2JYyoJKx3Z7kp7V3U5m3\nP8yO+KYxZZZSsxqhcvfJ0RCnPFjhdnHiFn1zkuYmUfx5y1MM3hp12MAQ1QQqK9c8\nSX5+zyJCJ+dUGCY6PBzHEEBYcoN9jKChsicJeHIJ++rkvedt9x4WXcfy9pWIF7Qt\n+nX1shksdB5OxwbIQeVyi+aWIsJudOFCTpaaKTJT5yUBs3yg4FUNgRRliOhefp3T\n8c070I31VZta3ljIvgkAN3WrqKfE9TTsY/UgSuHZrpa+x279ALjIIwcDa9iBf8C8\nyz15gURdiEb8NkF91LeIOXDrIp9cTFSD1jNVQEip32adwJ9wg3QNItEQN151aTib\nAgMBAAGjggHXMIIB0zAfBgNVHSMEGDAWgBSQr2o6lFoL2JDqElZz30O0Oija5zAd\nBgNVHQ4EFgQUxbZ3DShR1AHNzya9dgKB8z5+egAwDgYDVR0PAQH/BAQDAgWgMAwG\nA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCME8GA1Ud\nIARIMEYwOgYLKwYBBAGyMQECAgcwKzApBggrBgEFBQcCARYdaHR0cHM6Ly9zZWN1\ncmUuY29tb2RvLmNvbS9DUFMwCAYGZ4EMAQIBMFQGA1UdHwRNMEswSaBHoEWGQ2h0\ndHA6Ly9jcmwuY29tb2RvY2EuY29tL0NPTU9ET1JTQURvbWFpblZhbGlkYXRpb25T\nZWN1cmVTZXJ2ZXJDQS5jcmwwgYUGCCsGAQUFBwEBBHkwdzBPBggrBgEFBQcwAoZD\naHR0cDovL2NydC5jb21vZG9jYS5jb20vQ09NT0RPUlNBRG9tYWluVmFsaWRhdGlv\nblNlY3VyZVNlcnZlckNBLmNydDAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AuY29t\nb2RvY2EuY29tMCUGA1UdEQQeMByCCmlkcC5rcGkudWGCDnd3dy5pZHAua3BpLnVh\nMA0GCSqGSIb3DQEBCwUAA4IBAQAsl4xNgSpfkVyTpTjDy8jGYR5XlNYEk6QSHGwc\nyVNfHLg1IpcXjLvE7skPjUyNIynQOYjLS3Bpakjy6yTkNQU5Cib4ygk5V3dFnddT\nPOG+2dCXXuk432RvfumrJRDWO+HF9sAR6ByWCg3Hy+tZ9ZMPWKEbpRPFkQ5wPYPs\nfQW4RquXlpR/6PoDPP6Cf13Rwp7uUf8ztARG7ayFJezjBMfMN5hejC4tPwWG6UJY\nv5XnzHrd9qUFqh0E1Q5gpnAHvQRcpeZ2kvajhOn2pNc+iVdNuWHt04X6NvCHY5dz\nSG0FZDkYw5/MQEKbISmfTiDg+gCz4ZW+BnZRjt/x319pMgsv"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "ru",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u041d\u0422\u0423\u0423 \"\u041a\u041f\u0418\""
          },
          {
            "lang": "uk",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u041d\u0422\u0423\u0423 \"\u041a\u041f\u0406\""
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NTUU \"KPI\""
          }
        ],
        "organization_url": [
          {
            "lang": "ru",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://kpi.ua/ru"
          },
          {
            "lang": "uk",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://kpi.ua"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://kpi.ua/en"
          }
        ],
        "organization_name": [
          {
            "lang": "ru",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u041d\u0430\u0446\u0438\u043e\u043d\u0430\u043b\u044c\u043d\u044b\u0439 \u0422\u0435\u0445\u043d\u0438\u0447\u0435\u0441\u043a\u0438\u0439 \u0423\u043d\u0438\u0432\u0435\u0440\u0441\u0438\u0442\u0435\u0442 \u0423\u043a\u0440\u0430\u0438\u043d\u044b \"\u041a\u0438\u0435\u0432\u0441\u043a\u0438\u0439 \u043f\u043e\u043b\u0438\u0442\u0435\u0445\u043d\u0438\u0447\u0435\u0441\u043a\u0438\u0439 \u0438\u043d\u0441\u0442\u0438\u0442\u0443\u0442\""
          },
          {
            "lang": "uk",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u041d\u0430\u0446\u0456\u043e\u043d\u0430\u043b\u044c\u043d\u0438\u0439 \u0422\u0435\u0445\u043d\u0456\u0447\u043d\u0438\u0439 \u0423\u043d\u0456\u0432\u0435\u0440\u0441\u0438\u0442\u0435\u0442 \u0423\u043a\u0440\u0430\u0457\u043d\u0438 \"\u041a\u0438\u0457\u0432\u0441\u044c\u043a\u0438\u0439 \u043f\u043e\u043b\u0456\u0442\u0435\u0445\u043d\u0456\u0447\u043d\u0438\u0439 \u0456\u043d\u0441\u0442\u0438\u0442\u0443\u0442\""
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National Technical University of Ukraine \"Kyiv Polytechnic Institute\""
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.calu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "utechrequests@calu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Donna Wright"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.calu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.calu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.calu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.calu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.calu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.calu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "calu.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.calu.edu"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.calu.edu/_files/images/logo_72red.jpg",
                    "lang": "en",
                    "height": "72",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "72"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.calu.edu/faculty-staff/it-services/policies-guides/index.htm"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "California University of Pennsylvania"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUNTBoyq7vKsfRV+tm+aeq+fVualkwDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNc2hpYi5jYWx1LmVkdTAeFw0xMzAzMjcyMDMwMzlaFw0z\nMzAzMjcyMDMwMzlaMBgxFjAUBgNVBAMTDXNoaWIuY2FsdS5lZHUwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCl5TuZ5k1KKCJ6vBK5BCej7zKP0NvbLBvX\nevabOdTtm6D0WprBXOR2qotdykV0I0PBontu/bQabTPzdDgwK1vObx+VXmZClno2\nxZph3zLkd38l5D1L3G+r06QiFyaWCknvqDUFJ0N9ALOCPiuhcDmJTEnk8uz4zyw9\nkGjr0srfuLRAbPoaDW6T+0NAE0OSeWsRMPYJ+1/E3+/bMtmkNtMntvoHjCUqNgeY\n6w18TnRT+1OkVJl9HSmTszRg424an6MFoas5yljtUp2TAoO22ynXCnHyZZJxfmZ9\nEJFJstW8m7z2fnnqTL8ykseTLuhhbjnSGlzJev7zW/ZWqyWt411lAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDXNoaWIuY2FsdS5lZHWGJGh0dHBzOi8vc2hpYi5jYWx1LmVk\ndS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUg4dHB8uyMBk3FIB4pRG0DYFmbj8w\nDQYJKoZIhvcNAQEFBQADggEBAHYqP1brpyvprXEg8+XatQ1rKH2iwKbUvlGvdciV\nuWjgWRlcOsms7Kk9Y9/MeJd/6Nrb+1ifj3IVHbZzZ3i7FAjQY6UeHgY08FcRIebm\nVfr3pD31o/35fYNiJKmHAX3qrykm05e2f6kfB1DX08J4iBNK0r3sLcvDAocEDaRl\nXVQ1sD4SrD1zvkgHGNmJdwcAADWt1HV80FZK2ruiaum0vskTIJxQ6BBQKnWPl0xD\ng1Yiin78qAMDA92LfN/ctvj8sFivFbL4FJeH035tl/y7k/rJJVpsDjQIHJDPROCG\n3Jz8+VUS/n8RsCWiCcjLEM+SzCbGXM1Rp9ndtD2CSwKn2dc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://shib.calu.edu/idp/profile/SAML2/POST/SSO"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California University of Pennsylvania"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.calu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California University of Pennsylvania"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.highwire.org/entity/secure-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.highwire.org/entity/secure-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-09-26T17:52:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "HighWire Press Online"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://highwire.stanford.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HighWire Press, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.highwire.org/applications/secure-sp/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.highwire.org/applications/secure-sp/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIJAMTRVlqTJ11lMA0GCSqGSIb3DQEBBQUAMIG+MQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBD\n\t\t\t\t\t\taXR5MRcwFQYDVQQKEw5IaWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUx\n\t\t\t\t\t\tIDAeBgNVBAMTF3NoaWJib2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkB\n\t\t\t\t\t\tFiZzaGliYm9sZXRoLWFkbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTAeFw0xNDA0\n\t\t\t\t\t\tMTUxOTQzMDNaFw0yNDA0MTIxOTQzMDNaMIG+MQswCQYDVQQGEwJVUzETMBEGA1UE\n\t\t\t\t\t\tCBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBDaXR5MRcwFQYDVQQKEw5I\n\t\t\t\t\t\taWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUxIDAeBgNVBAMTF3NoaWJi\n\t\t\t\t\t\tb2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkBFiZzaGliYm9sZXRoLWFk\n\t\t\t\t\t\tbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALPB99M9iWjentrddY/rLgzKn1X0j4Ao191iyiowBBt/r/pmn2oz\n\t\t\t\t\t\tfrbONkkTVBB++mNtiufK6jyKnBM5mffPOkXHRo+K1DQec7TvpQ1PmLv/BpBgPrr9\n\t\t\t\t\t\tldViOSUnYJuB0IgJVV8oylgeH2Ay0XRkNPlBUjBA2fUPWVpXcvFe+aD2tLdVR9uO\n\t\t\t\t\t\tXvfTMxAEGqzxTU+OxO6pW2sBXNBmGvZQ0TRyovQh5+pTURY/lm0V/iWvRmRe51WE\n\t\t\t\t\t\tO/nhYyvRuMmNj8EL38o10S9TXuCkVzY00hK5cclaFge7gz/tfjmadVVcbe8xCVxc\n\t\t\t\t\t\tnb1lhmt1kH2XtKvU5hyZMTO+VUfXQvqcQyECAwEAAaN7MHkwCQYDVR0TBAIwADAs\n\t\t\t\t\t\tBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYD\n\t\t\t\t\t\tVR0OBBYEFJpUZq/XaW9/bPvjffkxX0IDvuPiMB8GA1UdIwQYMBaAFJpUZq/XaW9/\n\t\t\t\t\t\tbPvjffkxX0IDvuPiMA0GCSqGSIb3DQEBBQUAA4IBAQCq/FF56ZB1cL3KbniEJP99\n\t\t\t\t\t\tU9wTD6KpOrWxvqNbUSV1cefLf5cYHonOjy6oAJSSBSNuP7U5Q//0tXtkvlJoqGUY\n\t\t\t\t\t\tvqngmeg9wLZ/Fla3tXcDdTj0n1F+NZOx9vBDacIk0Ua4aHXDA4bdytzkV1QyZDRq\n\t\t\t\t\t\tQ8vq7RoQ8E5IF7Cll+kt2dZXQk8o6Qp3w2ppoMRtYdKOQassqn+V1MYcMPgdxZkS\n\t\t\t\t\t\tDrcgzktR/JMb5OmPrp4mSy1OWDGrFvUIigsLBPZV9tw1f7y42lnbmQas3RCS30yr\n\t\t\t\t\t\tCtUPT/PQDkCdBRViGmmMkYwjdaOTiHOJveWtrVXu8vLvO36pqFF4Kft0pgqlfvAE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.highwire.org/applications/secure-sp/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.highwire.org/applications/secure-sp/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.highwire.org/applications/secure-sp/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.highwire.org/applications/secure-sp/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.nuigalway.ie/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Diarmuid Murray"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:diarmuid.murray@nuigalway.ie"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Diarmuid Murray"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:diarmuid.murray@nuigalway.ie"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ISS Service Desk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@nuigalway.ie"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.nuigalway.ie/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2010-10-01T00:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.nuigalway.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.nuigalway.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.nuigalway.ie/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nuigalway.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://nuigalway.ie"
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/nuig.png",
                    "height": "68",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "225"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "National University of Ireland, Galway"
                  },
                  {
                    "lang": "ga",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "O\u00c9 Gaillimh"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.278923955103785,-9.060437679290771"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUaZj83WML6Ro0NOTyru/oCY9DaWcwDQYJKoZIhvcNAQEF\nBQAwGzEZMBcGA1UEAxMQaWRwLm51aWdhbHdheS5pZTAeFw0xMDA4MzAxNDUyMjJa\nFw0zMDA4MzAxNDUyMjJaMBsxGTAXBgNVBAMTEGlkcC5udWlnYWx3YXkuaWUwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCVTQr39i7dOPz//U7kaSk61ADv\n8zczZ4deMcSfUXGtBXwm1G913PqpjDkphmI5A5ehg7tOLjc1I/QXQI/MOi5EW5p8\n9mlrjtjuikIEZ1QJFnM0sGP2wNXUmFnfD3SX78lZbd6pqTDh/EyyO21q/6/7nIH3\n8Ds/R51LWZ4SHLXiVUj+xoLh9PaIWb1j2X9AS6t7FoUTfkQDTrNc78HNpTRy/RPN\nRKfzVUWsqmCbgCrVgz2k8ie5j9YDJ0IpFfGbdBOGUqaZuu53gyMzRTJ2KCmKIirH\nhMtk4fkx3lh9qaWMvpep9Ys9fcvv7h9ODKBDycRxoVJhfvKpRct3OmU38DFnAgMB\nAAGjZzBlMEQGA1UdEQQ9MDuCEGlkcC5udWlnYWx3YXkuaWWGJ2h0dHBzOi8vaWRw\nLm51aWdhbHdheS5pZS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUoSgXUY0R/R/L\nWeanf9/oteOvIL4wDQYJKoZIhvcNAQEFBQADggEBACenzaISa4sjW40cKZAdYMYp\nAj/83wlM5r5jNvK4XML3DuQdgvVfgDhU7DLbeQTPvcySE2Mfn87PHT7wdCXZoOu0\nCOH3D94Tc3/G3bu1uLg/VV6TGsNDHL7WqoUNnmHniZVOi6khONlufFLj4TbR3a8u\nxS/b1aO8RapnJUXY0Vhem17h/8bHmpw1RurScX0lXL1JA0PPEaF9nTCW5KfIOBVE\nYnwBW7s4pF85szVB4cSNiz6pRVenAw6s6bJ5AVYSXYGmkDRpm5OCzdVNzOzjlmrF\nkun2ue2G3ICbbxLefYZY3Y2Z8ASfN3caaadnEwn9ya6o47MywXTzmzIIbq1mvWc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "National University of Ireland, Galway"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://nuigalway.ie"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National University of Ireland, Galway"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib-idp.rpi.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "powela@rpi.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alan Powell"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib-idp.rpi.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-idp.rpi.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.rpi.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVANLgKXs6iKtLWK5YzJ889P9ABepqMA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEHNoaWItaWRwLnJwaS5lZHUwHhcNMTAxMDA3MTY1NTI5\nWhcNMzAxMDA3MTY1NTI5WjAbMRkwFwYDVQQDExBzaGliLWlkcC5ycGkuZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAjtNkbDoVYnm25A/D11tmoj2A\n4B4Le9Ckb0qOU5RajFnbr+h8NBHWzGHDF2nvjjmSX81h12nGY8X8a7Gn7ELABRQU\nkWPsGhljomBjD78xeZyrOAi38Klg+9MJP0DVg09SaJns9NQppG0uhwXEqpCXqO+9\niF0QDFS3xNM9hXyONGCWgCKkoSSVmNrjIcyFuqGTWDzngEnqwBh2K2xenopluFp9\nNrHSyT/X8KgqUk/PCn3OxPxf1isySvpnPvEhuLcXJGophWbYi8V7RbO0kTIQtV2b\nRpCAj+X1zcPh3n/zQR+UUWnirQrbVYhk8111tTbv6j9JE5Ei7jh3NRNHpKPfgwID\nAQABo2cwZTBEBgNVHREEPTA7ghBzaGliLWlkcC5ycGkuZWR1hidodHRwczovL3No\naWItaWRwLnJwaS5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFDED2miSXLhk\nZ1y9moAKrxbxM+j3MA0GCSqGSIb3DQEBBQUAA4IBAQBO4D8pHBfgLS6B8Q3TWuaU\nfPVUU5eRVoJMWWf+3BLW+lVUxudyTzRrUhREVwokroUvNQHwTQOTXU1CHZoAbsKz\nG+VDAqk7Ywb4/vrH74siaiZDRGemJ+IkcvmHsAhfH44ZyluuEvQVANtv5iVKJ6HA\nETfd87oqwGzPJmfcMzDuxemHaQx9GRxaDbVt90Dun2rjZvwn6eJl4vzGzUQRn7tD\npLAzcXdj85j7T2prc171AicsqFiKs7H0BbZJWzuby8mM0mSyydQot4AjKSEn3XjH\ntft1Upc9k4NmeGcokAOPbfZsqCBW8ESJxCqBQsrfVHb/8s5Za9BCRXlwKZYezeK6"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rpi.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib-idp.rpi.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-idp.rpi.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-idp.rpi.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-idp.rpi.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.rpi.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rpi.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rensselaer Polytechnic Institute"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVANLgKXs6iKtLWK5YzJ889P9ABepqMA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEHNoaWItaWRwLnJwaS5lZHUwHhcNMTAxMDA3MTY1NTI5\nWhcNMzAxMDA3MTY1NTI5WjAbMRkwFwYDVQQDExBzaGliLWlkcC5ycGkuZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAjtNkbDoVYnm25A/D11tmoj2A\n4B4Le9Ckb0qOU5RajFnbr+h8NBHWzGHDF2nvjjmSX81h12nGY8X8a7Gn7ELABRQU\nkWPsGhljomBjD78xeZyrOAi38Klg+9MJP0DVg09SaJns9NQppG0uhwXEqpCXqO+9\niF0QDFS3xNM9hXyONGCWgCKkoSSVmNrjIcyFuqGTWDzngEnqwBh2K2xenopluFp9\nNrHSyT/X8KgqUk/PCn3OxPxf1isySvpnPvEhuLcXJGophWbYi8V7RbO0kTIQtV2b\nRpCAj+X1zcPh3n/zQR+UUWnirQrbVYhk8111tTbv6j9JE5Ei7jh3NRNHpKPfgwID\nAQABo2cwZTBEBgNVHREEPTA7ghBzaGliLWlkcC5ycGkuZWR1hidodHRwczovL3No\naWItaWRwLnJwaS5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFDED2miSXLhk\nZ1y9moAKrxbxM+j3MA0GCSqGSIb3DQEBBQUAA4IBAQBO4D8pHBfgLS6B8Q3TWuaU\nfPVUU5eRVoJMWWf+3BLW+lVUxudyTzRrUhREVwokroUvNQHwTQOTXU1CHZoAbsKz\nG+VDAqk7Ywb4/vrH74siaiZDRGemJ+IkcvmHsAhfH44ZyluuEvQVANtv5iVKJ6HA\nETfd87oqwGzPJmfcMzDuxemHaQx9GRxaDbVt90Dun2rjZvwn6eJl4vzGzUQRn7tD\npLAzcXdj85j7T2prc171AicsqFiKs7H0BbZJWzuby8mM0mSyydQot4AjKSEn3XjH\ntft1Upc9k4NmeGcokAOPbfZsqCBW8ESJxCqBQsrfVHb/8s5Za9BCRXlwKZYezeK6"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Rensselaer Polytechnic Institute"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rpi.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Rensselaer Polytechnic Institute"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.crous-orleans-tours.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "LEROY Thierry"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "thierry.leroy@crous-orleans-tours.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "VINCENT R\u00e9gis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "regis.vincent@crous-orleans-tours.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.crous-orleans-tours.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-06-02T15:51:56Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.crous-orleans-tours.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.crous-orleans-tours.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.crous-orleans-tours.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "crous-orleans-tours.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.crous-orleans-tours.fr/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Crous Orl\u00e9ans-Tours staff"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Membres du personnel du Crous d'Orl\u00e9ans-Tours"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Orl\u00e9ans-Tours - Personnels"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Orl\u00e9ans-Tours - Personnels"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIVAMl6t3QQN7SBNiEk1q64K1duI81gMA0GCSqGSIb3DQEB\nBQUAMCUxIzAhBgNVBAMTGmlkcC5jcm91cy1vcmxlYW5zLXRvdXJzLmZyMB4XDTE0\nMDUyNjEzNTUwNVoXDTM0MDUyNjEzNTUwNVowJTEjMCEGA1UEAxMaaWRwLmNyb3Vz\nLW9ybGVhbnMtdG91cnMuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQDMVDqwA5RAg6HnDR7KyX0G3DKH0AnRsMZcbL2nU3Kt7eOnn/vKncGA/VoYPW7o\nCPWEPJZ8WsHODOtt//PCIVwfp7REAol0oUDPu2XYRHkKOtbhpp4mqF/CSuWT7bSQ\nEmLv94O9/aPjN5b/D1z8oj6di7EJz7JGr4ARHw9NEcVEgsg5b5gAT87A5wASoNbn\nT0fpOpmJQy2lCNfxAfJsq0O2PSa5Hfxg1KeVI6mDsSSLnlaS/n4uMXLGono7QbeB\n6tXq0D4wy3f2tUF54CiG9epe79VU+VqZQjb+33LO+r+DbizBbl0Q1pqvNHeaN07i\nrMVAuAFYBBquiReXwzXVlZ/pAgMBAAGjezB5MFgGA1UdEQRRME+CGmlkcC5jcm91\ncy1vcmxlYW5zLXRvdXJzLmZyhjFodHRwczovL2lkcC5jcm91cy1vcmxlYW5zLXRv\ndXJzLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQteIp+4pKTwpW1QSeCeYi3\nZwHBdDANBgkqhkiG9w0BAQUFAAOCAQEAa2opfhVRYW/GQmbtQC7HzNd/E5ovBrns\nl3Feh3q6gyL5kZlxcM2LasVUiv99v9hqw4eLmOhZrYtieQyPNTmijxGhFFqCCd+m\nsPQWi85i0R4/y7BKoZ7IkdeBuFxYsT9hGKMYtPXFHu2oNAAF9n19MY48vuVxJse5\n3W4/oX/WiSm1Fj+mDMmo11+zRjk2dwykd8TPKlo4klWxN0rcLrcUc9Zr1BRbZngi\n6wPYkfBTz+RpN3vmE3nMLlNTMS0OaU0BhOaL8hNBJKmPnWE7yJDZCFRE4pP8SojZ\nw7nR324InrWagttK/tkzxBOggWr5VB7dXlu+mc/Bhicd+yCGgLK1tg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS Orl\u00e9ans-Tours - Personnels"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.crous-orleans-tours.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS Orl\u00e9ans-Tours - Personnels"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://esdswp01.ds.man.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:international@esds.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ESDS International Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mimas-shib-tech@listserv.manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mimas Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://esdswp01.ds.man.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MIMAS: ESDS International Web Server One"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://esds.mcc.ac.uk//"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Manchester"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://esdswp01.ds.man.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://esdswp01.ds.man.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://esdswp01.ds.man.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://esdswp01.ds.man.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://esdswp01.ds.man.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://esdswp01.ds.man.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://esdswp01.ds.man.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJAKCst/LT2atiMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\n\t\t\t\t\t\tBAMTFWVzZHN3cDAxLmRzLm1hbi5hYy51azAeFw0xMTA4MjUxNDU3MzBaFw0yMTA4\n\t\t\t\t\t\tMjIxNDU3MzBaMCAxHjAcBgNVBAMTFWVzZHN3cDAxLmRzLm1hbi5hYy51azCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM2VrVToTVgEsS1K8MyHK+nvCOeV\n\t\t\t\t\t\tT5gtFk9LTY6C5vAVD/lIWp76KmwpvOCnc1ZwEOzpzTJKvsLmN6OpI0oB56DgAU30\n\t\t\t\t\t\teb7VE72IlrZzq41Jwt6pt5Eda08npE0YY4mzeSmjuZwzV/TsjtFbDjB4k22LDZrE\n\t\t\t\t\t\t1UHMNy9OP4FvBYm1eCKkYMpW7XGr2HZWMzVmavdCe8wtQzoIZCjvH+7gF/hokArN\n\t\t\t\t\t\t8RRKvw2HxBsQBMWPmoEaoosT//9RS+W/daVjqyU/47WFxOAJBMf3s7WqcNumPcbI\n\t\t\t\t\t\tIV4ApR+eaR5+xMsHx3sXxBGZrPkRm461XCSnrq/Rzb5Vc9ecJL+4h6m+eIECAwEA\n\t\t\t\t\t\tAaNDMEEwIAYDVR0RBBkwF4IVZXNkc3dwMDEuZHMubWFuLmFjLnVrMB0GA1UdDgQW\n\t\t\t\t\t\tBBQFfo7/j+0kUsgcDL9JM2MZB8uFgDANBgkqhkiG9w0BAQUFAAOCAQEAELePcQjX\n\t\t\t\t\t\tSTeh/K/A6eK5AzOXb76gtbtzdXAAOyPkQMI7nl1SmntgVtFb3SqbGmPyf24fwyjE\n\t\t\t\t\t\tghRwKp+cqkDTMRt4mAnky4gSVqFb978gN2+0qeLd1wOW+sSxCHy7QGnNv/+NMPTr\n\t\t\t\t\t\tqmSwMnuP3icuaClHB4wndhDLjuGHJI8hzVB/gvNMRY607Jj01vof3um3J6hZVELa\n\t\t\t\t\t\tQqvJf1p4AzkEqc/UVs5mNkeieg9eSkxCYMG7gWhu8P7peMnuEmRjenws3gh4gzWP\n\t\t\t\t\t\tZYoFe5iqgYhhtBTcwBEgRI825ISfRwE78qCfBOv8OS7rzGzjDO/lI8QuF12VNU5w\n\t\t\t\t\t\t1K0XFxLVLmEFpw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://esdswp01.ds.man.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://esdswp01.ds.man.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://esdswp01.ds.man.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://esdswp01.ds.man.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://esdswp01.ds.man.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://esdswp01.ds.man.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayf.au.dk",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayf.au.dk",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2012-07-26T08:47:03Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayf.au.dk/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "au.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Aarhus Universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Aarhus University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "au.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICrjCCAZYCAQcwDQYJKoZIhvcNAQELBQAwHTEbMBkGA1UEAwwSaHR0cHM6Ly93\nYXlmLmF1LmRrMB4XDTE1MDEwMTAwMDAwMFoXDTI1MTIzMTIzNTk1OVowHTEbMBkG\nA1UEAwwSaHR0cHM6Ly93YXlmLmF1LmRrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEAx4gMCmoQU7iOGfiCda4DnhIggst20fUCHtwaQrHoxQlOa0s5FgDa\nlbnNTw36dCXSGYaz17JgyUDJonTwhjyA0CqPm5Pmn9/hFBUvyP/t+bEgV9r3/odQ\nx72VfY7M55qUlY6ex2f1qD1gcpFgSTtADlZswec5WqpEt+ie+vsMXq8HabhMVZ2E\njXe90vgMk/xGfrVwDvupUPBS/2DJSZ1JEmkqi0hxctNQ9qgTZmEcAaQkuv3VGcsY\ntLeY/IISlA+ARzmVWr5+uSetnCXV4jnDEclACKeexl0Ky+tyra4yHF3Xavgmcmeb\nd+xHVDiM+No6BXMu9zBTp7cp5ShLzsNQSQIDAQABMA0GCSqGSIb3DQEBCwUAA4IB\nAQAVvkoFXRRj041T+0zfuek1vnNigD7AHUSXc9HX9HMS60IvaaSDFm5xZAfa09lm\ntJjC70nDZuUf9LGaX4a9ktzPRa6ri/r7mOMvEixTthJDHfh8sMepy44GFDyfC2u+\nO91Mg06oSGVoP935Pq2SU0BR9LuAmMVfi8t+JDHFq4DCgr7GmAV1YV0WcEIsc+YT\neA1YVSbbMHCIPAFOqX/ZaVvxwX38qbqwTEw8Pi+/D4/ZrpzWZH8rPpi0IjzdBUKd\nDUHV11GiFGG/Plav7r68E1e+WI0jwsFx2ktk82hPuiix9HNFqmcfNmJA6wxfw7Ow\nwaSgkcygO9PTBU5lKpmYMlUx"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Aarhus Universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Aarhus University"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.au.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.au.dk/en"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Aarhus Universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Aarhus University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.crous-creteil.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "informatique@crous-creteil.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.crous-creteil.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-03-06T15:51:29Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.crous-creteil.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.crous-creteil.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.crous-creteil.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "crous-creteil.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.crous-creteil.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administratifs"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administratifs"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Cr\u00e9teil"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Cr\u00e9teil"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEdjCCA16gAwIBAgIRAJ5lMINLv4KL948DJ4za9FIwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDAzMTAwMDAwMDBaFw0xNzAzMDkyMzU5NTlaMEIxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEdMBsGA1UEAxMUaWRwLmNyb3Vz\nLWNyZXRlaWwuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDhR4WQ\nmTRASe7QJ+SnbMD4o2Ol6ZGgThvO+B7UvPL63IVUydDq1bDO0S7QvFdg/79pX9GP\n+WyALvuCPLDNmLXo0akCstsXmDeDgbwSumE1vgH49bCyo8LsaIm4CGyEv8EyBGIf\n5ocwzeIChFZIz93+ckldwv2cANfPNFeZehC2pprBtQwZWpHaB773p/vkkJB9ZnAc\nFHCGBDZK83Z8diQ0gcGWT5I458Iyy/GsspkboahISiH4E3RXv/crfXA3NPiz1MEl\n0DJ2Fsa5FZbUPWBVrxyITyhr3D6CBS3uPBzr52d/hycV7sIu2yE1IouoMTnrDRix\ngIyzzBOuncz7XqR1AgMBAAGjggFxMIIBbTAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJ\nays3V0fqkOO57TAdBgNVHQ4EFgQU12L8b6JRjRbvP/2h8rSpSyj/NcwwDgYDVR0P\nAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsG\nAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1Ud\nHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NM\nQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50\nY3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6\nLy9vY3NwLnRjcy50ZXJlbmEub3JnMB8GA1UdEQQYMBaCFGlkcC5jcm91cy1jcmV0\nZWlsLmZyMA0GCSqGSIb3DQEBBQUAA4IBAQB1+6zzpZFAyRF9Sp3qwwPQkuV7bRLV\n5hLkfhEAfCMP25E9DuAMWC9Vb0rldlneSl06dk2pA72AHrQZ+n799wCmynxNzooB\nfJXUOunDwz37fDJAbb729YAXmt4iPPG8NCSlIu2WkueaOhH2GJPJOPatItGQIUEy\nHAJ1OzN3e3zX8iuyXkZJVa+ddsWEeUPrS59CBvjk1Y8SYe2uHRNv+g8DX0wVkjKq\nlaTKYcW1rY22QD6/RLQr0EpQ9BXoZbJq7CyGsBDPMs/K80DCYNaaOBxWyWNH1X9A\nJb3ZR1qKEgKubKYH73VLMDHwl1IEyS+6D44aMSlHdTqE8OJfTRKMANX8"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS Cr\u00e9teil"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.crous-creteil.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS Cr\u00e9teil"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.tandfebooks.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.tandfebooks.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-04-23T11:09:57Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Atypon Systems: Taylor & Francis Group eBooks"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tandfebooks.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDqzCCApOgAwIBAgIJAMt/QdGE5hPLMA0GCSqGSIb3DQEBBQUAMIGUMQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEUMBIGA1UEBxMLU2FudGEgQ2xh\n\t\t\t\t\t\tcmExHTAbBgNVBAoTFEF0eXBvbiBTeXN0ZW1zLCBJbmMuMR0wGwYDVQQLExRBdHlw\n\t\t\t\t\t\tb24gU3lzdGVtcywgSW5jLjEcMBoGA1UEAxMTd3d3LnRhbmRmZWJvb2tzLmNvbTAe\n\t\t\t\t\t\tFw0xMjAyMjAyMDI3NTNaFw0yMjAyMTcyMDI3NTNaMIGUMQswCQYDVQQGEwJVUzET\n\t\t\t\t\t\tMBEGA1UECBMKQ2FsaWZvcm5pYTEUMBIGA1UEBxMLU2FudGEgQ2xhcmExHTAbBgNV\n\t\t\t\t\t\tBAoTFEF0eXBvbiBTeXN0ZW1zLCBJbmMuMR0wGwYDVQQLExRBdHlwb24gU3lzdGVt\n\t\t\t\t\t\tcywgSW5jLjEcMBoGA1UEAxMTd3d3LnRhbmRmZWJvb2tzLmNvbTCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBAMTY5ygzkDHzb+UXnQrrh3qvPfzax9zG5v2G\n\t\t\t\t\t\tX8JszKRVebzH2Aq0a7/B1pWLbON6bA+EdW9AHhGabcK01VtRGA/pm6ASvozsO5I8\n\t\t\t\t\t\tTGrBc7Gzq2Pb92Wid4u7Ai7gm7lLZNbaRsEdMVy9EZu7an15+vLGoWp/TfNSCXmB\n\t\t\t\t\t\t1QyJH9uABduXp0dM6aophIIzbMzIVb2i0rmf7D3nUeGi/+0mqv7zCPykwdgRUORf\n\t\t\t\t\t\tSc5pC8QY2B6u/d1ZHZW/tfZtOHYBkY5bu6c20Y338lsiSCgA0rfpoBjArdsvmC+Y\n\t\t\t\t\t\tVKB4eNNZ3LqohYYcr9eukIHx0c9UYHnd68RM8W0rSIp5QdW3pzECAwEAATANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAhiPqifO9fklkF6j+//td0fJNsKxJsxKHRIeznMEt9Utk\n\t\t\t\t\t\tah8qEz6MLT/j51PnrXpG4n+YAtxmQ2JPO/FVH5NbqSxWERrvqbUxgp5+AiVr8Uvs\n\t\t\t\t\t\tBsmnNG7ZwgC0qxKJwSduW+Der4ss4L/pUm78+0xjPbQDczkZ9DTKR7p93JJlUaGG\n\t\t\t\t\t\t8dZf6/GkUSxNIzZiVH7Md8DA9d20feXFiWjMYURIn4HysYLsT0/14o+X41NogxIH\n\t\t\t\t\t\t7klAv8c4dTvFs80m4uZsDo6XpJGEfWJvkY6QqxCrwCMAc2lq9k1UqIjEV0BeoB2G\n\t\t\t\t\t\thcbFdcOTCuBK+8YKVxLElKzwQCc0OYx1mQkGYcA7eA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.tandfebooks.com/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.tandfebooks.com/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.tandfebooks.com/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth2.rwcmd.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tottle"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:gareth.tottle@rwcmd.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gareth"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tottle"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:gareth.tottle@rwcmd.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gareth"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth2.rwcmd.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-09-03T18:05:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID9DCCAtwCCQCCojb3OfH/lTANBgkqhkiG9w0BAQUFADCBuzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEDAOBgNVBAgTB0NhcmRpZmYxEDAOBgNVBAcTB0NhcmRpZmYxLzAtBgNVBAoT\n\t\t\t\t\t\tJlJveWFsIFdlbHNoIENvbGxlZ2Ugb2YgTXVzaWMgYW5kIERyYW1hMRYwFAYDVQQL\n\t\t\t\t\t\tEw1JVCBEZXBhcnRtZW50MSAwHgYDVQQDExdzaGliYm9sZXRoMi5yd2NtZC5hYy51\n\t\t\t\t\t\tazEdMBsGCSqGSIb3DQEJARYOaXRAcndjbWQuYWMudWswHhcNMTQwMTE1MTE0MjM4\n\t\t\t\t\t\tWhcNMjMxMDE1MTE0MjM4WjCBuzELMAkGA1UEBhMCR0IxEDAOBgNVBAgTB0NhcmRp\n\t\t\t\t\t\tZmYxEDAOBgNVBAcTB0NhcmRpZmYxLzAtBgNVBAoTJlJveWFsIFdlbHNoIENvbGxl\n\t\t\t\t\t\tZ2Ugb2YgTXVzaWMgYW5kIERyYW1hMRYwFAYDVQQLEw1JVCBEZXBhcnRtZW50MSAw\n\t\t\t\t\t\tHgYDVQQDExdzaGliYm9sZXRoMi5yd2NtZC5hYy51azEdMBsGCSqGSIb3DQEJARYO\n\t\t\t\t\t\taXRAcndjbWQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDK\n\t\t\t\t\t\tLb1ki7lYC9VR+7oMZTbIxAM8xRp25olZgAX2sXp6huwiCuhIpQKdiSNaC/CY2ExZ\n\t\t\t\t\t\tMtlABHncCP9yvaxZeQKsAlNi3LuPHtPoLwtfePDbaTxWgRt65yzKXYsdFCq5tSDa\n\t\t\t\t\t\trsRUSYyQPpdOzTolcwdyJBObpis3Mgzeg+Sid4rrDIVK+Ym+Z7CxC63O1eBgDi+8\n\t\t\t\t\t\tC78moSRVzQjhywJtxQp2tcKOV9X21TE08+s3B9QLswV0rFqkyToaAMV0EfAdk0oh\n\t\t\t\t\t\toQXQXuqD7QnfHkaQw2vca6uQRjR5PEK9VRHV0J7XTglqK+elUbENyeYeAVqzHZ6n\n\t\t\t\t\t\tKLmi8UcCPbvepguEL88fAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAK+dGhOQQSJ+\n\t\t\t\t\t\t8OHwaQkkDUciMrYx5V3fGSTxO76ZrK4Ix/mD6iaRqvd1rxPaDfxXITC8qTQLjSFK\n\t\t\t\t\t\tihgzoQqRM4EbL4XBpyLQw6Z7wtxsrWmm7iQXA2p+w39c8myPl4nTfXI4aGKfMvpO\n\t\t\t\t\t\t0Ee/EdEKxwC+QJ4WXiATs0V2+zWtsN2wOAbTw23MXKKQawAiDQpGZ7acpGFXrElS\n\t\t\t\t\t\tcwH6hlJACBs1fsuXyjkrQGe636ZQdjK/v7wCFQXTzg6bW6WiqW0DtdKYxD7bLN6q\n\t\t\t\t\t\tjJlh7/XeUvowweMSEk7iKrbGp4pHhMbPQsFo90i3BWBE9yot/DN+T/G9Z6W05Tsr\n\t\t\t\t\t\tPk3B5nn2ecE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rwcmd.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "glam.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth2.rwcmd.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2.rwcmd.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth2.rwcmd.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2.rwcmd.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth2.rwcmd.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2.rwcmd.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth2.rwcmd.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2.rwcmd.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rwcmd.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "glam.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID9DCCAtwCCQCCojb3OfH/lTANBgkqhkiG9w0BAQUFADCBuzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEDAOBgNVBAgTB0NhcmRpZmYxEDAOBgNVBAcTB0NhcmRpZmYxLzAtBgNVBAoT\n\t\t\t\t\t\tJlJveWFsIFdlbHNoIENvbGxlZ2Ugb2YgTXVzaWMgYW5kIERyYW1hMRYwFAYDVQQL\n\t\t\t\t\t\tEw1JVCBEZXBhcnRtZW50MSAwHgYDVQQDExdzaGliYm9sZXRoMi5yd2NtZC5hYy51\n\t\t\t\t\t\tazEdMBsGCSqGSIb3DQEJARYOaXRAcndjbWQuYWMudWswHhcNMTQwMTE1MTE0MjM4\n\t\t\t\t\t\tWhcNMjMxMDE1MTE0MjM4WjCBuzELMAkGA1UEBhMCR0IxEDAOBgNVBAgTB0NhcmRp\n\t\t\t\t\t\tZmYxEDAOBgNVBAcTB0NhcmRpZmYxLzAtBgNVBAoTJlJveWFsIFdlbHNoIENvbGxl\n\t\t\t\t\t\tZ2Ugb2YgTXVzaWMgYW5kIERyYW1hMRYwFAYDVQQLEw1JVCBEZXBhcnRtZW50MSAw\n\t\t\t\t\t\tHgYDVQQDExdzaGliYm9sZXRoMi5yd2NtZC5hYy51azEdMBsGCSqGSIb3DQEJARYO\n\t\t\t\t\t\taXRAcndjbWQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDK\n\t\t\t\t\t\tLb1ki7lYC9VR+7oMZTbIxAM8xRp25olZgAX2sXp6huwiCuhIpQKdiSNaC/CY2ExZ\n\t\t\t\t\t\tMtlABHncCP9yvaxZeQKsAlNi3LuPHtPoLwtfePDbaTxWgRt65yzKXYsdFCq5tSDa\n\t\t\t\t\t\trsRUSYyQPpdOzTolcwdyJBObpis3Mgzeg+Sid4rrDIVK+Ym+Z7CxC63O1eBgDi+8\n\t\t\t\t\t\tC78moSRVzQjhywJtxQp2tcKOV9X21TE08+s3B9QLswV0rFqkyToaAMV0EfAdk0oh\n\t\t\t\t\t\toQXQXuqD7QnfHkaQw2vca6uQRjR5PEK9VRHV0J7XTglqK+elUbENyeYeAVqzHZ6n\n\t\t\t\t\t\tKLmi8UcCPbvepguEL88fAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAK+dGhOQQSJ+\n\t\t\t\t\t\t8OHwaQkkDUciMrYx5V3fGSTxO76ZrK4Ix/mD6iaRqvd1rxPaDfxXITC8qTQLjSFK\n\t\t\t\t\t\tihgzoQqRM4EbL4XBpyLQw6Z7wtxsrWmm7iQXA2p+w39c8myPl4nTfXI4aGKfMvpO\n\t\t\t\t\t\t0Ee/EdEKxwC+QJ4WXiATs0V2+zWtsN2wOAbTw23MXKKQawAiDQpGZ7acpGFXrElS\n\t\t\t\t\t\tcwH6hlJACBs1fsuXyjkrQGe636ZQdjK/v7wCFQXTzg6bW6WiqW0DtdKYxD7bLN6q\n\t\t\t\t\t\tjJlh7/XeUvowweMSEk7iKrbGp4pHhMbPQsFo90i3BWBE9yot/DN+T/G9Z6W05Tsr\n\t\t\t\t\t\tPk3B5nn2ecE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Royal Welsh College of Music and Drama"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rwcmd.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Royal Welsh College of Music and Drama"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:cru.fr:federation:univ-montp3.fr",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "fed-admin@univ-montp3.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:cru.fr:federation:univ-montp3.fr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-03-23T15:18:07Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univ-montp3.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univ-montp3.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.univ-montp3.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-montp3.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-montp3.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Montpellier 3"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Montpellier 3"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIJAOUsRys+9vr2MA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEmlkcC51bml2LW1vbnRwMy5mcjAeFw0xNTEyMjExMzAzMjlaFw0xODEyMjAx\nMzAzMjlaMB0xGzAZBgNVBAMTEmlkcC51bml2LW1vbnRwMy5mcjCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALUFOkbwlvHlNFscNBuf7n11roHnrDcmoh8C\ncZDcUyPwNrI6rodXl5J4VUua1KyyF7Xiw+Sbt6B3FWTQyQ/9dVYDJlqcId858mm8\nbNHMu9006HyFUg14KE4sibps3aEdDc82u3lK7g8xVth2bNH6ikVB7nHspld12xXr\nMeZPerCrgPWYcI3FU81Ry44TbHl6A8Db6hVsURQyOwI3ejedUW/v09z/eKz7tWOi\nBTO2OMj/vmFXhdJSauL5EZDFiMqj2enribQEnKDsDaQvNJ9hzxhk8W1Re3prQQXi\n58O+vMnsidsAzvWl0riP1n3JBPGpfUVfl7s5Kwt2Cstu1vYUwLsCAwEAAaNrMGkw\nSAYDVR0RBEEwP4ISaWRwLnVuaXYtbW9udHAzLmZyhilodHRwczovL2lkcC51bml2\nLW1vbnRwMy5mci9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU4bXzVk5qn1dvwzKl\nElpuNcuFqYIwDQYJKoZIhvcNAQEFBQADggEBAH+IsgY+v2+KWjJ+UYVUo76mH5sC\nFmxpW4DtXdOkx4Vf1JNwRCKKTP7NYlD402zqbtOL/aIIQ/ev6v2WFBm7/pRiajpI\najY3W9S/W6QgjGMM7sTLgPJoiafHT6CzjeLCgdyJ5qqTxXePPRn5t15KKBMqVwki\nS2RyLxCNaG735iyf02pouXs/vGDaVj8q5Ime/lR/mpODOKQk5lJP9Z4U3xJamQd6\nzLXKMS8vUj2HIydQGDEuXNg0DT1j3c22b/tPPgfv0ZSDfLeHYTb7D+H3+sZdgeCv\nDanziiDRT48w7pw7CXw6+cSSmi8dtXnkK5kk1sS2DBFmroJ+IEFYvP7ZxmI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEhzCCA2+gAwIBAgIQBUjO9AwbhRtr7tjGUg65IjANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEyMTAwNTAwMDAwMFoXDTE1MTExMDIzNTk1OVowYDELMAkGA1UE\nBhMCRlIxNDAyBgNVBAoMK1VuaXZlcnNpdMOpIGRlIE1vbnRwZWxsaWVyIElJSSBQ\nYXVsLVZhbMOpcnkxGzAZBgNVBAMTEmlkcC51bml2LW1vbnRwMy5mcjCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBALZpRdTpeBT0QYYouJQgkJ8LsaGs/23e\nolnt9n23TfoECwAYnGNcK7+SeNPemO7gngsyU07ckiuuaxN19scxvIJ26Zi5a44s\nR1sIBNkTS9WL8bZeTBVZ3cwJMcMU/WyOG0MkzwuWfBSP0IihzvwWILDJgbz0BWTk\nL23+YPeRvsLcymStS9uNc9Cu5ak70LoCN8sEGVEAXilJP85cgMSLyJz33fK0ohsK\n6uIG4RVb8TdsVkZ5uWMAVZuiNKhwEHcLDPXIcZe9q7Wlz0sUrsrnN4GvpWCDk3oJ\nVhKQ95+4OYbC7iBGW7i0WyRNcG8zm0uHjwJAJAGHXKYHjRDcEBDZhFMCAwEAAaOC\nAWUwggFhMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdXR+qQ47ntMB0GA1UdDgQW\nBBT5oJbLv8ba7NKHSMXohclUTLaclDAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/\nBAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwGAYDVR0gBBEwDzAN\nBgsrBgEEAbIxAQICHTA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50\nZXJlbmEub3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYB\nBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0\nMCYGCCsGAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREE\nFjAUghJpZHAudW5pdi1tb250cDMuZnIwDQYJKoZIhvcNAQEFBQADggEBAIxg44rF\nEe0d90B3u9ZiGAhDOOKlU1TkVZ0fA7HFq6C+AYafAw9jac4sn8ZnYFZMHgZwvl6z\nOLW97uhQRL5MJ9w3ArZSQvumiD+DwVRn8V7bBN/mzUR/jIl3U4VQ9YcYk3vx2dzw\n+YnZGQLJGuiE9wcH5+Z3/oNBw9o5DB8juU9W/H/a2xGksZ8WbUnJW3kfcdIKqclr\nEv9JomAr2LzGTLq7YTwT9nuN0PgFXNMI/aM3ci5ni9DEfmNdfk1qn7HZLLqLAtPH\n94QXFSgFfkI0r/NMpslNQGn0NKSFItkhJGX5Su0RFEmX8kjNpYt6oPlXW7Vr7389\n9m9urGFyfVe5MQM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Montpellier 3"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-montp3.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Montpellier 3"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-19.ladok.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-19.ladok.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;19"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;19"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-19.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-19.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJALJTVfD+H9mUMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0xOS5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTQ0MzQ4WhcNMjQx\nMDA0MTQ0MzQ4WjAhMR8wHQYDVQQDExZsYWRvazMtMTkubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzpB/1DSoezs6kRVeY7ulb12d\nqb67A7+tVjMF7r0wsyQAzZFKaSEAFSO6SI9xkDYAbZZoW01UCbTZxs5WHYGdy86U\nm9WzPmVPrehRFtzWV9UdgRM5TXHmxFWMRotIPIwaOl/XeCU0oNZgh4FOihJAyFPd\n+BwYVn2/BiAzvvstFU8NGMjqsNLZwt1agYnORoyRHxLMnZntKGi8azgRn/8nkiQf\nwnCBGpydsRLnbhsHKr3TYarG4/+jxK/EKP83uak2/acHGDSNKeYvvrnGoCfeHn3f\nPOrLBrFUx9sTTnIiwM+A4jm9LKYGRUq390WCmryHyjdzoRtY3NsE3dDqadHN7QID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMTkubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0xOS5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUL4u5ZAOrCjPwFL+5D/VNUKJvwNUwDQYJKoZIhvcNAQEFBQADggEB\nAG27SJJpfeTklLFyu/yz/GBz8sj3bo1XuohAEU2/XHYVdmFX0t+TH6JaVdv3QUYB\nv+1WZaG09pu2Zk+aSbshuiLNZero0qZglqBOyXSWcxtaRzrhyj/uNbN6IulqRdYh\n55sEGpEVPcsDF9MPERcYAEoPhLhujcdylCXt0SUv87KyWq/VtosjLJ0xdi05OwSL\nQzIZe74hia5hrlMTEIBHrYRbTeO2q3LZcpmQhlIbNBEGfzfWGUGMHMaxlXtmkatv\nNAiBKYQ60AYd/AS/yPrpk2llTUHfd6tdvC4SqKuiEYsy2pYvfN//PPFrdI9mr+Ir\n6ZrQ7PTbuSPLTA2boFcCHgk="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-19.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://federation.rijksmuseum.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://federation.rijksmuseum.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-06-29T18:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/e04abc1f9c8858b3f9941f8fce892039",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rijksmuseum.nl"
              },
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Rijksmuseum Amsterdam"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Rijksmuseum Amsterdam"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/rijksmuseum_logo.png",
                    "height": "300",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "500"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Rijksmuseum Amsterdam"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Rijksmuseum Amsterdam"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rijksmuseum.nl/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rijksmuseum.nl/en"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Rijksmuseum Amsterdam"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Rijksmuseum Amsterdam"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp2.londonlibrary.co.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "David"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:will.david@londonlibrary.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Will"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "David"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:will.david@londonlibrary.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Will"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp2.londonlibrary.co.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDyzCCArOgAwIBAgIJAI6fjypmCFKGMA0GCSqGSIb3DQEBCwUAMHwxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMQ8wDQYDVQQIDAZMb25kb24xDzANBgNVBAcMBkxvbmRvbjEbMBkGA1UE\n\t\t\t\t\t\tCgwSVGhlIExvbmRvbiBMaWJyYXJ5MQswCQYDVQQLDAJJVDEhMB8GA1UEAwwYaWRw\n\t\t\t\t\t\tMi5sb25kb25saWJyYXJ5LmNvLnVrMB4XDTE1MDUwNjEwMzIwNloXDTMwMDUwMjEw\n\t\t\t\t\t\tMzIwNlowfDELMAkGA1UEBhMCR0IxDzANBgNVBAgMBkxvbmRvbjEPMA0GA1UEBwwG\n\t\t\t\t\t\tTG9uZG9uMRswGQYDVQQKDBJUaGUgTG9uZG9uIExpYnJhcnkxCzAJBgNVBAsMAklU\n\t\t\t\t\t\tMSEwHwYDVQQDDBhpZHAyLmxvbmRvbmxpYnJhcnkuY28udWswggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDLz0/zZAm2NbldxNTiJDzGZXSnYd4+ChVfhyhr\n\t\t\t\t\t\t0TmjysjE63tDfjc9bvMYkAORU6MSKGFeS3Zn+TwXgS2VmTUWSC48sf2e/ovYdlti\n\t\t\t\t\t\tOkoSy1ygfqWMGUVKB9zxiNxZOhkTKk3AA/wiMVH8vKTnXMKVVUVIje5e6O/71y1C\n\t\t\t\t\t\tbazwSjMf5mckzVFnZCNVEAob0Kw7Ms1D8rmWkRDrdECxauvyH4jnQ0TxL3qtmL3E\n\t\t\t\t\t\tQMuGZGn2J3obf4zGZvgkOGcQ17th+Ta6qoKTrMPHjTbNKvjHo/g0W7aVkUA5hTM5\n\t\t\t\t\t\tNXkGOoihx2D7blZeidPFXNpTmqvzXEB1V0V4JzCfPdNVnqONAgMBAAGjUDBOMB0G\n\t\t\t\t\t\tA1UdDgQWBBTPD5ppgnEREA7j25Qk5VcNYAX0aDAfBgNVHSMEGDAWgBTPD5ppgnER\n\t\t\t\t\t\tEA7j25Qk5VcNYAX0aDAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQB1\n\t\t\t\t\t\tmRcwuzPYKiMM0BbGTTtCn9ZzOzU/pUa6anWT4wl6eJjGgNLJhU9tGS7VKw2dCXHi\n\t\t\t\t\t\tZcwxqxPu2/3rM3SlMGo9YIelVwsT7O096dr7f/10S7Lozp4wKM+tZorBpH3Mbx8K\n\t\t\t\t\t\tgPqP2JhsFBU2T3RXTVEhLSCvaal/G/XWRiPIu1lFRTNzCkVHAM4HMy+MRjZPrbfy\n\t\t\t\t\t\t9IgGK+kNxGv0/l3y2cqh8ws6XrM3oXMtxTWwP8tbNCcmHgbHD+i7UdTXL0vkwwQj\n\t\t\t\t\t\tzOqx8FszNU4vcFPbk+rTBKmgWqMmmv+JjC6HRYKslyhaQrUN5BHjYDCJKGGMex7Y\n\t\t\t\t\t\ts39/czGWTVmmJjeLXzur"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "londonlibrary.co.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.londonlibrary.co.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.londonlibrary.co.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp2.londonlibrary.co.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.londonlibrary.co.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp2.londonlibrary.co.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2.londonlibrary.co.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.londonlibrary.co.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.londonlibrary.co.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "londonlibrary.co.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://idp4.londonlibrary.co.uk/idp/images/logo.png",
                    "height": "122",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "122"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "London Library TEST"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDyzCCArOgAwIBAgIJAI6fjypmCFKGMA0GCSqGSIb3DQEBCwUAMHwxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMQ8wDQYDVQQIDAZMb25kb24xDzANBgNVBAcMBkxvbmRvbjEbMBkGA1UE\n\t\t\t\t\t\tCgwSVGhlIExvbmRvbiBMaWJyYXJ5MQswCQYDVQQLDAJJVDEhMB8GA1UEAwwYaWRw\n\t\t\t\t\t\tMi5sb25kb25saWJyYXJ5LmNvLnVrMB4XDTE1MDUwNjEwMzIwNloXDTMwMDUwMjEw\n\t\t\t\t\t\tMzIwNlowfDELMAkGA1UEBhMCR0IxDzANBgNVBAgMBkxvbmRvbjEPMA0GA1UEBwwG\n\t\t\t\t\t\tTG9uZG9uMRswGQYDVQQKDBJUaGUgTG9uZG9uIExpYnJhcnkxCzAJBgNVBAsMAklU\n\t\t\t\t\t\tMSEwHwYDVQQDDBhpZHAyLmxvbmRvbmxpYnJhcnkuY28udWswggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDLz0/zZAm2NbldxNTiJDzGZXSnYd4+ChVfhyhr\n\t\t\t\t\t\t0TmjysjE63tDfjc9bvMYkAORU6MSKGFeS3Zn+TwXgS2VmTUWSC48sf2e/ovYdlti\n\t\t\t\t\t\tOkoSy1ygfqWMGUVKB9zxiNxZOhkTKk3AA/wiMVH8vKTnXMKVVUVIje5e6O/71y1C\n\t\t\t\t\t\tbazwSjMf5mckzVFnZCNVEAob0Kw7Ms1D8rmWkRDrdECxauvyH4jnQ0TxL3qtmL3E\n\t\t\t\t\t\tQMuGZGn2J3obf4zGZvgkOGcQ17th+Ta6qoKTrMPHjTbNKvjHo/g0W7aVkUA5hTM5\n\t\t\t\t\t\tNXkGOoihx2D7blZeidPFXNpTmqvzXEB1V0V4JzCfPdNVnqONAgMBAAGjUDBOMB0G\n\t\t\t\t\t\tA1UdDgQWBBTPD5ppgnEREA7j25Qk5VcNYAX0aDAfBgNVHSMEGDAWgBTPD5ppgnER\n\t\t\t\t\t\tEA7j25Qk5VcNYAX0aDAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQB1\n\t\t\t\t\t\tmRcwuzPYKiMM0BbGTTtCn9ZzOzU/pUa6anWT4wl6eJjGgNLJhU9tGS7VKw2dCXHi\n\t\t\t\t\t\tZcwxqxPu2/3rM3SlMGo9YIelVwsT7O096dr7f/10S7Lozp4wKM+tZorBpH3Mbx8K\n\t\t\t\t\t\tgPqP2JhsFBU2T3RXTVEhLSCvaal/G/XWRiPIu1lFRTNzCkVHAM4HMy+MRjZPrbfy\n\t\t\t\t\t\t9IgGK+kNxGv0/l3y2cqh8ws6XrM3oXMtxTWwP8tbNCcmHgbHD+i7UdTXL0vkwwQj\n\t\t\t\t\t\tzOqx8FszNU4vcFPbk+rTBKmgWqMmmv+JjC6HRYKslyhaQrUN5BHjYDCJKGGMex7Y\n\t\t\t\t\t\ts39/czGWTVmmJjeLXzur"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "London Library TEST"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.londonlibrary.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "London Library"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.cs.cas.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Van\u00ed\u010dek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vanicekp@utia.cas.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cs.cas.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2014-06-17T15:52:29Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/avcr"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAKK9oHWp4NhakdhRINFSNcMlO+RbMA0GCSqGSIb3DQEB\nBQUAMBgxFjAUBgNVBAMTDWlkcC5jcy5jYXMuY3owHhcNMTQwNDIzMDk0MjA0WhcN\nMzQwNDIzMDk0MjA0WjAYMRYwFAYDVQQDEw1pZHAuY3MuY2FzLmN6MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAjjkBmvDKH/5+UN1okmPOjP4WiCHwmGw7\nKQ9Zxk/myiYmAgk9qF/0PTHMdli5C4rbSbffG+G+28B6N+hJL8GoCL5+BSfKxjsq\n0EkXH81pbIl6/V9X888aitvMa8sKYcI5SUaTdv5DfO9KPizzDh4q7ckC3pyYvYT9\nfM30sxWOSoNHgMCPEg6kUt7BViZCGqzuucqJ/OIh01GLcsu56YH7FYWSQZ6gxCjk\nmqAPSwsFveWweKxIzv/Fudact5JA2OPv6E0QtxiZl2IrrbszCTfiihqvd4Kkh2gz\n3KAI7B8HS0obOhYoi6VSNVJ2CpyQOff2M1HmIeyTe0up4bEGnbu81QIDAQABo2Ew\nXzA+BgNVHREENzA1gg1pZHAuY3MuY2FzLmN6hiRodHRwczovL2lkcC5jcy5jYXMu\nY3ovaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFO+bvv+xOMV6uPQ6HEydpZESVVHW\nMA0GCSqGSIb3DQEBBQUAA4IBAQAIvc78aeMLcz35NBrOwdpFTkyjxddzw8In/WkZ\nf460lIhMMqc4wBe2fdqUx6OOkGDOGFTt4nWhLxp5+RI4v6ZwawGmZBxTBWxJgCrI\n2wOrZ+LAjcah4H+dESHtufvkv5GpcpHaqclECIJBSdBw40JO0GaIRHfNAnpLW8Uu\nQMhmIIxoZBWR/Fw+FJbKlseHsLR67FxmkuIrj9a+R3tL63j6xktGkzh3pvmjzTu9\nV7TvWrHG4VLa2B+cw1DTHx53iXciC7lcUmrv6FmsoEn023Vo9SMPCCpyoYGnKmRl\nDWUUP6NhKsUBrx0ErS47MREL3/a9Ck6rJ1bJssJLAir38Sk4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cs.cas.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cs.cas.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cs.cas.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cs.cas.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cs.cas.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cs.cas.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.cs.cas.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cs.cas.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.cs.cas.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cs.cas.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cs.cas.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cs.cas.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cs.cas.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ustavinformatiky.cz/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ustavinformatiky.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider ICS AV CR employees."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance UI AV \u010cR"
                  }
                ],
                "logo": [
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-ui-44.png",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-ui-400.png",
                    "height": "400",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "450"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Computer Science AS CR"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u00dastav informatiky AV \u010cR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAKK9oHWp4NhakdhRINFSNcMlO+RbMA0GCSqGSIb3DQEB\nBQUAMBgxFjAUBgNVBAMTDWlkcC5jcy5jYXMuY3owHhcNMTQwNDIzMDk0MjA0WhcN\nMzQwNDIzMDk0MjA0WjAYMRYwFAYDVQQDEw1pZHAuY3MuY2FzLmN6MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAjjkBmvDKH/5+UN1okmPOjP4WiCHwmGw7\nKQ9Zxk/myiYmAgk9qF/0PTHMdli5C4rbSbffG+G+28B6N+hJL8GoCL5+BSfKxjsq\n0EkXH81pbIl6/V9X888aitvMa8sKYcI5SUaTdv5DfO9KPizzDh4q7ckC3pyYvYT9\nfM30sxWOSoNHgMCPEg6kUt7BViZCGqzuucqJ/OIh01GLcsu56YH7FYWSQZ6gxCjk\nmqAPSwsFveWweKxIzv/Fudact5JA2OPv6E0QtxiZl2IrrbszCTfiihqvd4Kkh2gz\n3KAI7B8HS0obOhYoi6VSNVJ2CpyQOff2M1HmIeyTe0up4bEGnbu81QIDAQABo2Ew\nXzA+BgNVHREENzA1gg1pZHAuY3MuY2FzLmN6hiRodHRwczovL2lkcC5jcy5jYXMu\nY3ovaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFO+bvv+xOMV6uPQ6HEydpZESVVHW\nMA0GCSqGSIb3DQEBBQUAA4IBAQAIvc78aeMLcz35NBrOwdpFTkyjxddzw8In/WkZ\nf460lIhMMqc4wBe2fdqUx6OOkGDOGFTt4nWhLxp5+RI4v6ZwawGmZBxTBWxJgCrI\n2wOrZ+LAjcah4H+dESHtufvkv5GpcpHaqclECIJBSdBw40JO0GaIRHfNAnpLW8Uu\nQMhmIIxoZBWR/Fw+FJbKlseHsLR67FxmkuIrj9a+R3tL63j6xktGkzh3pvmjzTu9\nV7TvWrHG4VLa2B+cw1DTHx53iXciC7lcUmrv6FmsoEn023Vo9SMPCCpyoYGnKmRl\nDWUUP6NhKsUBrx0ErS47MREL3/a9Ck6rJ1bJssJLAir38Sk4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Computer Science Academy of Sciences of the Czech Republic"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u00dastav informatiky AV \u010cR, v.v.i."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ustavinformatiky.cz/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ustavinformatiky.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Computer Science Academy"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u00dastav informatiky AV \u010cR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp2.dcu.ie/idp/profile/Metadata/SAML",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Systems Group"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sysops@dcu.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "DCU ISS"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Donohue"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:fergus.donohue@dcu.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Fergus"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Doyle"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:john.l.doyle@dcu.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp2.dcu.ie/idp/profile/Metadata/SAML",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2010-10-06T21:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.dcu.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.dcu.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.dcu.ie/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dcu.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.dcu.ie"
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/dcu.png",
                    "height": "102",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "150"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "lang": "en",
                    "height": "102",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "150"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Dublin City University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "dcu.ie"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.385325,-6.257143"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "136.206.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.1.192.0/25"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEzCCAfugAwIBAgIUOQ3lfJ+Ec4wFEuvh3raF7kmMtUQwDQYJKoZIhvcNAQEF\nBQAwFTETMBEGA1UEAxMKaWRwLmRjdS5pZTAeFw0wOTA3MTcxMTQwNDZaFw0yOTA3\nMTcxMTQwNDZaMBUxEzARBgNVBAMTCmlkcC5kY3UuaWUwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQCADZFUTMBENyEv2jwnRDh9gSOYZfHUfndWcFHasU3S\nDqH5j/jA6jL4hqJNnzokDcMRr6veGwKLQ93fXbOHfHvNYGM/6b3V/wpZUqH4OPUY\nzmjJdP2EgJ2bq6Tx0uLQ/trbKqweGgXkzTcRNBtC3qItUddv8eXi1IrXHsAOFX+8\nb3IXXh1VrcHvrt8+WaAwnGDMmTGxUkOPYnmPef3rKA5gYQglVH8f8fKuPIDsKAUS\nXXTqniiU4TUcguCTQ/RrGvJgFyjtNK8loL8LcpLq9FoCjaQ/5iEt0xHPc2fHzJmc\n9VOEcH+RVazhCy9yx3uCI8ID4ZB3mQsce5F75POyVzGhAgMBAAGjWzBZMDgGA1Ud\nEQQxMC+CCmlkcC5kY3UuaWWGIWh0dHBzOi8vaWRwLmRjdS5pZS9pZHAvc2hpYmJv\nbGV0aDAdBgNVHQ4EFgQU++/qpuKky0Mag89lImDpPqFodkgwDQYJKoZIhvcNAQEF\nBQADggEBAG9D2HEMKqoKl/g+i0TrATEGkTf0bJuy1oWUxSNzFdzWqeGkZrZS9bmg\nfDsBhb5ETAnYfxwDHMGytK1a25wKL0nLHcQkGY/Rq3Epi/4FO2j8HzfavhkL4e81\nsbH1fWkpuYR0gxIcNQ4O8MCRT8KOd1RlEfPfGaG3aUuuG/6CmTT6kP32a6Wo4wQA\ngDMveZoQEcHqkqVGocb2Mu4fKzSzXH9hAbrUC3RPB7EaJtGhAiQ7dNHR50i1B26n\n1Ig0IsXth908GfvXb4d6qmavTSjAQKLHl64ujQTxSF8oz2wbFcGMsgXu9yb/s+KF\n3JP0HYE1idr7BJ2F14eWlzQIorChnzE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Dublin City University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dcu.ie/iss/contact.shtml"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Dublin City University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://topsy.ncl.ac.uk/shibboleth/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Beaty"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:michael.beaty@newcastle.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Beaty"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:michael.beaty@newcastle.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://topsy.ncl.ac.uk/shibboleth/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-12-09T15:37:31Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Newcastle University HPC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ncl.ac.uk/itservice"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Newcastle upon Tyne"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://topsy.ncl.ac.uk:7034/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://topsy.ncl.ac.uk:7034/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://topsy.ncl.ac.uk:7034/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://topsy.ncl.ac.uk:7034/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://topsy.ncl.ac.uk:7034/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://topsy.ncl.ac.uk:7034/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAPBsTOlcp3T8MA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\n\t\t\t\t\t\tBAMTD3RvcHN5Lm5jbC5hYy51azAeFw0xNTExMDIwODU0MzVaFw0yNTEwMzAwODU0\n\t\t\t\t\t\tMzVaMBoxGDAWBgNVBAMTD3RvcHN5Lm5jbC5hYy51azCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBAKDhYFk6OSQnhkHbK1COfMG79uS7/1DgsBv9kzGrhZsA\n\t\t\t\t\t\ta0xW/VyH5k7zSsxKHahopVaoYiMJx/P7xd5EhT5zE2qlhY4kMUOpQJHn0liHgz/0\n\t\t\t\t\t\t8IYtWo/Y0hB9g8QfseEJw/w3gqvEioU4W6ZHNlBVGPkjhUNM4zMpJ7B5katrMpPV\n\t\t\t\t\t\trFt+EV03n+zvEe4pJDf1qurX5zx1uiCVgRHGSY/QJMtgRKGjghJfKNSb2+9tR0ul\n\t\t\t\t\t\tzIMnjB4L9jpETY1tOSUUBxw1C1f2rBR+NQJgwHdljlJmmcFNKveOVGFAM5x3dKzN\n\t\t\t\t\t\tV2TIEqIUGXmopMMC8yFwgYjckazN6Hssje5mHSRwt6sCAwEAAaM9MDswGgYDVR0R\n\t\t\t\t\t\tBBMwEYIPdG9wc3kubmNsLmFjLnVrMB0GA1UdDgQWBBR7WDIAYoOL7Km73avRDBiM\n\t\t\t\t\t\t49zBFDANBgkqhkiG9w0BAQUFAAOCAQEAamTJ45UEzWN+1vLtwjgBQYOIraSShWkZ\n\t\t\t\t\t\tRej6vEP3UCcqU+c6D00Z0SCXx4/DE/q/l5brFpL4BLlxpBKVyMVu/mb2wKmIbfYa\n\t\t\t\t\t\tI6NnDKjrLbnTCM9ADugLNK2ZVOIYMm5fgUc9mDKJRSAbpfHQKCuIBChtqdP57pV7\n\t\t\t\t\t\tzAPYERoof+5Oi3prf8vgh0nEgFA/prgbSMEuglsrJyvkKGDNAtjeUWQRSjyvbRKe\n\t\t\t\t\t\tY0z2EV2wo0KW+VslQnBrD671nwFn+mblKs7fcPj73bKOcWn9zkF5jMSvIwNY/mXl\n\t\t\t\t\t\tdcIZsmnjhF5GCaYywNqr7GIHRaTzghpCWRYepkoaXLxoq3mKXOsdAg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://topsy.ncl.ac.uk:7034/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://topsy.ncl.ac.uk:7034/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://topsy.ncl.ac.uk:7034/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://topsy.ncl.ac.uk:7034/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://topsy.ncl.ac.uk:7034/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://topsy.ncl.ac.uk:7034/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib.gcu.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ddil@gcu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ddil@gcu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.gcu.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-04-03T11:52:43Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUGOsthEUhMn8ZqSRhbf29aeFD9OswDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGTEXMBUGA1UEAxMOc2hpYi5nY3UuYWMudWswHhcNMTQwNDAxMTUxOTAwWhcN\n\t\t\t\t\t\tMzQwNDAxMTUxOTAwWjAZMRcwFQYDVQQDEw5zaGliLmdjdS5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIchBd2lzuQ45cxGQVaDT0WpztTW9Bi1\n\t\t\t\t\t\t+oXgxor2jun7trjtQe93sHmkCfjsAvZad9+gSVxFV3gHFHfpDix+XRZu1l3/f1mW\n\t\t\t\t\t\tbDhQtsFi3ooMRb+z8eN6XsSzRXjOm+Zq/TtvG5ASVvJIqKM5zAZmbAjhlF3GyaWa\n\t\t\t\t\t\t+MFTc9Jk84Gfo9v7apFKx1LAUxnQaCYNSMSombtAyVUNSc74YqN56F/0V+jUnvMT\n\t\t\t\t\t\tNkkQ4YiiFYzcO7M6xut1avUzZn00aEjlnCFHB8beWH4UV+DXGKxb/k31IjOpox4K\n\t\t\t\t\t\tesz9S1J0UhZsqmLZdjxExfVzgZLvplKpSKfEpxyheSeSg525XURwl2kCAwEAAaNj\n\t\t\t\t\t\tMGEwQAYDVR0RBDkwN4IOc2hpYi5nY3UuYWMudWuGJWh0dHBzOi8vc2hpYi5nY3Uu\n\t\t\t\t\t\tYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFC2/w2ppSqmygKbmZGMoPqKT\n\t\t\t\t\t\tcbhrMA0GCSqGSIb3DQEBBQUAA4IBAQBCV7RJxCsiFIMkBwB9FwOCP3jGjOcUXde7\n\t\t\t\t\t\tfwMwb99pAuwEZPe2LwwHxZZSowsKkt3y7KEhqzG4mMxBvvf++mlmErnpvVW9xptc\n\t\t\t\t\t\tnRHfNCw44o/MXjTc5oK85iUDL0XW6NpaNlUFO68oYh+o5syUgLeSjtFVvrZn7Skd\n\t\t\t\t\t\tNyG6F7QvM6YMx7RFp0ij1h9/yGfUb2iVFTWOePRzTTJ+/u8zOay+fLHiFmL3u6Al\n\t\t\t\t\t\tOK8MOQIZBD6o4lZJNsg2YCUHuHMDE3hrYDZQjraE7R6GcyC9lkaHNonm1lQKf+oP\n\t\t\t\t\t\t/0/rNHQNKC7TUfL8iAQ4ZPlfaXK3Joo2G+NL8Pg6ldPP1hBDvnvt"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gcu.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.gcu.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.gcu.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.gcu.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.gcu.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.gcu.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.gcu.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.gcu.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.gcu.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.gcu.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.gcu.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.gcu.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gcu.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUGOsthEUhMn8ZqSRhbf29aeFD9OswDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGTEXMBUGA1UEAxMOc2hpYi5nY3UuYWMudWswHhcNMTQwNDAxMTUxOTAwWhcN\n\t\t\t\t\t\tMzQwNDAxMTUxOTAwWjAZMRcwFQYDVQQDEw5zaGliLmdjdS5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIchBd2lzuQ45cxGQVaDT0WpztTW9Bi1\n\t\t\t\t\t\t+oXgxor2jun7trjtQe93sHmkCfjsAvZad9+gSVxFV3gHFHfpDix+XRZu1l3/f1mW\n\t\t\t\t\t\tbDhQtsFi3ooMRb+z8eN6XsSzRXjOm+Zq/TtvG5ASVvJIqKM5zAZmbAjhlF3GyaWa\n\t\t\t\t\t\t+MFTc9Jk84Gfo9v7apFKx1LAUxnQaCYNSMSombtAyVUNSc74YqN56F/0V+jUnvMT\n\t\t\t\t\t\tNkkQ4YiiFYzcO7M6xut1avUzZn00aEjlnCFHB8beWH4UV+DXGKxb/k31IjOpox4K\n\t\t\t\t\t\tesz9S1J0UhZsqmLZdjxExfVzgZLvplKpSKfEpxyheSeSg525XURwl2kCAwEAAaNj\n\t\t\t\t\t\tMGEwQAYDVR0RBDkwN4IOc2hpYi5nY3UuYWMudWuGJWh0dHBzOi8vc2hpYi5nY3Uu\n\t\t\t\t\t\tYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFC2/w2ppSqmygKbmZGMoPqKT\n\t\t\t\t\t\tcbhrMA0GCSqGSIb3DQEBBQUAA4IBAQBCV7RJxCsiFIMkBwB9FwOCP3jGjOcUXde7\n\t\t\t\t\t\tfwMwb99pAuwEZPe2LwwHxZZSowsKkt3y7KEhqzG4mMxBvvf++mlmErnpvVW9xptc\n\t\t\t\t\t\tnRHfNCw44o/MXjTc5oK85iUDL0XW6NpaNlUFO68oYh+o5syUgLeSjtFVvrZn7Skd\n\t\t\t\t\t\tNyG6F7QvM6YMx7RFp0ij1h9/yGfUb2iVFTWOePRzTTJ+/u8zOay+fLHiFmL3u6Al\n\t\t\t\t\t\tOK8MOQIZBD6o4lZJNsg2YCUHuHMDE3hrYDZQjraE7R6GcyC9lkaHNonm1lQKf+oP\n\t\t\t\t\t\t/0/rNHQNKC7TUfL8iAQ4ZPlfaXK3Joo2G+NL8Pg6ldPP1hBDvnvt"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Glasgow Caledonian University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gcu.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Glasgow Caledonian University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.csusm.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "agrommo@csusm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "April Grommo"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kai@csusm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Diane Petersen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.csusm.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.csusm.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.csusm.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIURBObONYB1aVZUkchbN9Vm7i8Il4wDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNaWRwLmNzdXNtLmVkdTAeFw0wOTA4MjQxNzQ1MDZaFw0y\nOTA4MjQxNzQ1MDZaMBgxFjAUBgNVBAMTDWlkcC5jc3VzbS5lZHUwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCNxuYDajoiDXTQ4TvPcWGZy167mRRwlH1i\nrfxHV90o0XHKoL/FTJ3sh/Zj7S/7bCTPVB8mEXmIeTfGURUkwM8dSVeVLpX3j8jz\nDdtVhEGBxQUPtZsQPWt7vP+mk+w5t85nA8ShbKmvPNVS1kFBfb9+EYVVBwaN8aXH\nf0jXKVnt041DxOAXWGz958SaIetTVqa/P6XsBz6E9heulp3CgXSBLBlBQ/EKYcPz\n+NtLYG5iKbH9u6ka3zfTbefsZ1W/7fe8j416TgZdgUaKN7GNsgU9O/jCqHkGVURt\npN9/rtkN0feQhpcW8ZKWN727zmqbUIka6kPA8N0h8IVEMpgvzYCTAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDWlkcC5jc3VzbS5lZHWGJGh0dHBzOi8vaWRwLmNzdXNtLmVk\ndS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUUWLdnhv2ZxtBMXDDAlaFWeDgDaYw\nDQYJKoZIhvcNAQEFBQADggEBAEuAj7CnXZppeRZ149EiZ4T54Gq6GNlIFzWfoD8Z\nsxiIOxcJbM/lJ9rXGtHwV5RE1cxNXncLMfA7XAtDoRtHIDQ+KL0JEd7hqjZFz2/1\njNXMxjNO8oQnTEqtwuo6yH8fKuAxHGAoLK1/ZXOC4MV4Gj265hhR2vUOp7WzRWKk\nIUnVPqjV3HQd+eTL4yQQM1s4NANaMsCoQ/u0C/j5C92ERrYmKZ3axgVh5iuEMcRI\nnoZH8nkxLFKIpQhm5kJlWq5YOKrdyTUF9lF7lD3YqacBcK/gctKBxbAmHwPqn2kc\nerUVBDmnMbYvO+WkO29HAl4Q0MbsXjQOm0C8cdFfI7gnehE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csusm.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.csusm.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.csusm.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.csusm.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.csusm.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.csusm.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.csusm.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csusm.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "California State University, San Marcos"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIURBObONYB1aVZUkchbN9Vm7i8Il4wDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNaWRwLmNzdXNtLmVkdTAeFw0wOTA4MjQxNzQ1MDZaFw0y\nOTA4MjQxNzQ1MDZaMBgxFjAUBgNVBAMTDWlkcC5jc3VzbS5lZHUwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCNxuYDajoiDXTQ4TvPcWGZy167mRRwlH1i\nrfxHV90o0XHKoL/FTJ3sh/Zj7S/7bCTPVB8mEXmIeTfGURUkwM8dSVeVLpX3j8jz\nDdtVhEGBxQUPtZsQPWt7vP+mk+w5t85nA8ShbKmvPNVS1kFBfb9+EYVVBwaN8aXH\nf0jXKVnt041DxOAXWGz958SaIetTVqa/P6XsBz6E9heulp3CgXSBLBlBQ/EKYcPz\n+NtLYG5iKbH9u6ka3zfTbefsZ1W/7fe8j416TgZdgUaKN7GNsgU9O/jCqHkGVURt\npN9/rtkN0feQhpcW8ZKWN727zmqbUIka6kPA8N0h8IVEMpgvzYCTAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDWlkcC5jc3VzbS5lZHWGJGh0dHBzOi8vaWRwLmNzdXNtLmVk\ndS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUUWLdnhv2ZxtBMXDDAlaFWeDgDaYw\nDQYJKoZIhvcNAQEFBQADggEBAEuAj7CnXZppeRZ149EiZ4T54Gq6GNlIFzWfoD8Z\nsxiIOxcJbM/lJ9rXGtHwV5RE1cxNXncLMfA7XAtDoRtHIDQ+KL0JEd7hqjZFz2/1\njNXMxjNO8oQnTEqtwuo6yH8fKuAxHGAoLK1/ZXOC4MV4Gj265hhR2vUOp7WzRWKk\nIUnVPqjV3HQd+eTL4yQQM1s4NANaMsCoQ/u0C/j5C92ERrYmKZ3axgVh5iuEMcRI\nnoZH8nkxLFKIpQhm5kJlWq5YOKrdyTUF9lF7lD3YqacBcK/gctKBxbAmHwPqn2kc\nerUVBDmnMbYvO+WkO29HAl4Q0MbsXjQOm0C8cdFfI7gnehE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California State University, San Marcos"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csusm.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California State University, San Marcos"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://easydb.geschkult.fu-berlin.de/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT des Fachbereichs Geschichts- und Kulturwissenschaften"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servermaster@geschkult.fu-berlin.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Funktionsadresse"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT-Support des Fachbereichs Geschichts- und Kulturwissenschaften"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@geschkult.fu-berlin.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Funktionsadresse"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://easydb.geschkult.fu-berlin.de/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2014-10-21T05:40:43Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Freie Universit\u00e4t Berlin"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Freie Universit\u00e4t Berlin"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://identity.fu-berlin.de/idp-fub/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://identity.fu-berlin.de/idp-fub/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e5"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e5"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://easydb.geschkult.fu-berlin.de/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://easydb.geschkult.fu-berlin.de/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://easydb.geschkult.fu-berlin.de/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://easydb.geschkult.fu-berlin.de/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "EasyDB (Digitale Diathek) an der FU Berlin"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "EasyDB (Digitale Diathek) an der FU Berlin"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "EasyDB ist die gemeinsame Bilddatenbank der arch\u00e4ologischen und die kunsthistorischen F\u00e4cher des Fachbereich Geschichts- und Kulturwissenschaften der Freien Universit\u00e4t Berlin. Sie bietet Zugriff auf derzeit 250.000 Bilder f\u00fcr Forschung und Lehre."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "EasyDB ist die gemeinsame Bilddatenbank der arch\u00e4ologischen und die kunsthistorischen F\u00e4cher des Fachbereich Geschichts- und Kulturwissenschaften der Freien Universit\u00e4t Berlin. Sie bietet Zugriff auf derzeit 250.000 Bilder f\u00fcr Forschung und Lehre."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.geschkult.fu-berlin.de/e/khi/diathek/digitale_diathek/index.html"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.geschkult.fu-berlin.de/e/khi/diathek/digitale_diathek/index.html"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "EasyDB ist die gemeinsame Bilddatenbank der arch\u00e4ologischen und die kunsthistorischen F\u00e4cher des Fachbereich Geschichts- und Kulturwissenschaften der Freien Universit\u00e4t Berlin. Sie bietet Zugriff auf derzeit 250.000 Bilder f\u00fcr Forschung und Lehre."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "EasyDB ist die gemeinsame Bilddatenbank der arch\u00e4ologischen und die kunsthistorischen F\u00e4cher des Fachbereich Geschichts- und Kulturwissenschaften der Freien Universit\u00e4t Berlin. Sie bietet Zugriff auf derzeit 250.000 Bilder f\u00fcr Forschung und Lehre."
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EasyDB (Digitale Diathek) an der FU Berlin"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EasyDB (Digitale Diathek) an der FU Berlin"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "easydb.geschkult.fu-berlin.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGJTCCBQ2gAwIBAgIHGPlbfiq0XjANBgkqhkiG9w0BAQsFADCBtTELMAkGA1UE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\nVlBXGupf8n951icED+IDh47RglDOnvS8DpOvHDtysd/ctiSwZ8vJCOQ="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=easydb.geschkult.fu-berlin.de,OU=Fachbereich Geschichts- und Kulturwissenschaften,O=Freie Universitaet Berlin,L=Berlin,ST=Berlin,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://easydb.geschkult.fu-berlin.de/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://easydb.geschkult.fu-berlin.de/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://easydb.geschkult.fu-berlin.de/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://easydb.geschkult.fu-berlin.de/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://easydb.geschkult.fu-berlin.de/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://easydb.geschkult.fu-berlin.de/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://easydb.geschkult.fu-berlin.de/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://easydb.geschkult.fu-berlin.de/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://easydb.geschkult.fu-berlin.de/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://easydb.geschkult.fu-berlin.de/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://whoami.cesnet.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Oppolzer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jan.oppolzer@cesnet.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tomasek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jan.tomasek@cesnet.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://whoami.cesnet.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2010-09-15T11:47:38Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/other"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/sp-group/aa.cesnet.cz"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAPtcN7LUM3UEz0yqfmOvpr0tZtYOMA0GCSqGSIb3DQEB\nCwUAMBsxGTAXBgNVBAMMEHdob2FtaS5jZXNuZXQuY3owHhcNMTUxMjE0MDkyMjU4\nWhcNMzUxMjE0MDkyMjU4WjAbMRkwFwYDVQQDDBB3aG9hbWkuY2VzbmV0LmN6MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqlyX+ljxEHVNiX4Kt3AMYj6P\nUgWAGHkb5t1xZhrijzWspc6wTc6iNQnLzFTafl1KJktWMHBNmFvUQyHGjCVbski4\nWWUNS4rCFyY7USNjdjiKb7lHqw4OLwd6GMnI6njbUkY7tQJ/Dq3lGPjs+LJ9jPq3\n9l2kSbsMz55WN86aC7J+WwSjCv2BHYs/KEJ+127RUVBtloSmNRZfjJQcdKFsp+mS\nOyMP91WtZQwg3b7EXOOqSkm55esBWJiwII565SHfrl4aQe58xA/V2sHeFH4IbtH/\nIZsibhM/G0eBr9dvHtyfcWvnlA8cmQaD964nVqnYpFa/eXYfg53V1Ft6KQMvgwID\nAQABo2cwZTAdBgNVHQ4EFgQUXaI0YDr1Q2G4mM18pIXB3+nPUHUwRAYDVR0RBD0w\nO4IQd2hvYW1pLmNlc25ldC5jeoYnaHR0cHM6Ly93aG9hbWkuY2VzbmV0LmN6L2lk\ncC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQBzZ5sJtPabubBWaC5UAbl8\n+ZGzSrT72R9vfxW6+NJVK9C5LvCp6a6U3KDrZwMRb5hKvAbkQji1bPHAQ+Bt7qtj\niz4vxBDJueIuZCoHbSSkK9Xb5h9025TGICxNFtty3y4LvroPZ3wYACXdjA/Si3xK\nJF6us/yB6hcAf6ML7DyXW+o4q+35HHmAjBUssXHU70iLOiTnIfbEgxl54Af7xKpZ\n8Ww45V9t2dJ5YU6wzoa0Aqy0abm0RxkWu6igXjpcS+XaSl5n+J+tFEZBRtJZ5mBv\nEQWIvarHy4CabFyOcb1Bl3UHfvQyi3R4RfQsEIYaYBa/5c3LJr3KC8mWCA8vuPx+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUNHGiLWEdd83k9nZ70899LxlSksMwDQYJKoZIhvcNAQEL\nBQAwGzEZMBcGA1UEAwwQd2hvYW1pLmNlc25ldC5jejAeFw0xNTEyMTQwOTIyNTZa\nFw0zNTEyMTQwOTIyNTZaMBsxGTAXBgNVBAMMEHdob2FtaS5jZXNuZXQuY3owggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCNzxV/6eZL14fhksPzth+cv6bf\naoE/W/Z+Hrey2ZEUCexwPN4ogtL35gITcj7uctw5bxFPNO4Io9ooXC5nUBThc90g\njBxTLS8B5/pkbcuRFDX3w4C++mCQdiZ7+5aG1K31+Vw5XCd8Ai+UC3/oZI4vekfC\nZJ7wHYN/W2N15FJ6breDWOewk+z1ezag3SfY2U3aROFBuQJks2WKx7+bClXtVEYz\nSregJY/ZkuCsLsNwxqw+rw4njESLGTpfiK1raWdrBwiPacyCG9T9Fte+AGfoHuK0\nOMcpqPQsnnzB7UAnUCthpo0pllD3qJCL+SdX+Rka40Vps2HrV3Jk/fGxNuADAgMB\nAAGjZzBlMB0GA1UdDgQWBBRJtNZfYNTYii4s7L4/Y/SqT3SMKjBEBgNVHREEPTA7\nghB3aG9hbWkuY2VzbmV0LmN6hidodHRwczovL3dob2FtaS5jZXNuZXQuY3ovaWRw\nL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAGkcr3KAQV2zbSeviEblSyyr\n5tJ/TW2HbJCN/8sLGA+6TwLsCcjWkEtXpXskZlsxbCtgmqztaNa/vQsRSIsVA1Ph\nynUBMniJQ4wfiNhkbj73ukgE16NIY0WITgJNdwFj4Nb5cysCAo+Gqa6UTofB5p9/\nQkEL4dP6M+eo5ZIDvndTF+vb9Uxt+SFttFETS/2RzneYXzCsa/5wWDIsmwNwMRYN\n1RjGMhjQ0DLx4PyEhrOqzWBGFM00qSWypY29SQ/nYGRpjBkvOYasT8eHIovD9M8C\nbmD1QX2KicdJm3oC14xc3Amm2Ja4YeystmRZO0H4z0oVN/zhBT90pjKf4yuF+Bs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAMGRAZNgX7x88WED24sBgvq/prF/MA0GCSqGSIb3DQEB\nCwUAMBsxGTAXBgNVBAMMEHdob2FtaS5jZXNuZXQuY3owHhcNMTUxMjE0MDkyMjU3\nWhcNMzUxMjE0MDkyMjU3WjAbMRkwFwYDVQQDDBB3aG9hbWkuY2VzbmV0LmN6MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAg0TLTs5Cinlt6r2wcS+7NT+k\nO1synzXA9/VEvEDnXbqx5ryyDYyVB4tL4BEU1bsf95GD2RDOdU+rYDRgW+K2R9do\ngJfZ6SmDjdnxOcvLBMkpQTrD0XE35ZDohMf8EXHxuID+JxPDnd0ZU/SF6bH/5WHq\nWzPKIF1+OfIoeRY2IH5HrwKgz5EMvFJKUTcDxzNTFApIzLt46KbxxBxi4JPoPMKT\n9r889YOdknPCuVW4ZldJTljJCR9ZkjgTuIWVBgi3pbqjRtg5JUDrfBBvUUKLC2a8\n3PEnHpP9ukeErX5aVHPJ3dNNL1ACYzjZMGzeb6yDPunISnO/MW/cP8OBu3njcwID\nAQABo2cwZTAdBgNVHQ4EFgQUOJRY3ly/FY3E/c3BlIUAeVbpGkQwRAYDVR0RBD0w\nO4IQd2hvYW1pLmNlc25ldC5jeoYnaHR0cHM6Ly93aG9hbWkuY2VzbmV0LmN6L2lk\ncC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQBhsQ7KA7Furd6LFDZ9inh+\nyaVPlWcS2wBrvW6kgRU5/B+0sf3f/HKOtbYREOvtdI2Cf0rvTlvSACJzJ1Mlta5H\n9AK/M9qlrJf9Vrl5eik5Il1QZBfNniVojz0JImhZmr28sLT3yYMcLAERg1E6Yg35\ndQ4u7VaUTaGleUKF8dZfEc8okQUqeSNAIpTAxzAwQC3crVdtyhH4luP/vFvWwLMg\nV2DvXG/+7HDskpb5nE9Vy3lunkwSZLsBCJHFpU8GWSuhrXpIJjelw7yswEHpep0Q\nD/3xRElbMqPKyidtXPj29chPYs3GsBrvgaXjoNnOwQhB8lS1T2JbrvG/OPVIQojD"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cesnet.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://whoami.cesnet.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://whoami.cesnet.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://whoami.cesnet.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://whoami.cesnet.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://whoami.cesnet.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://whoami.cesnet.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://whoami.cesnet.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://whoami.cesnet.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://whoami.cesnet.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://whoami.cesnet.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://whoami.cesnet.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cesnet.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ces.net/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.cesnet.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for CESNET employees."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance CESNETu."
                  }
                ],
                "logo": [
                  {
                    "text": "https://pki.cesnet.cz/_media/cs/cesnet-logo-200.gif",
                    "height": "88",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "200"
                  },
                  {
                    "text": "https://pki.cesnet.cz/_media/cs/cesnet-logo-400.gif",
                    "height": "177",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "400"
                  },
                  {
                    "text": "https://pki.cesnet.cz/_media/cs/cesnet-logo-800.gif",
                    "height": "353",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "800"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CESNET"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CESNET"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAPtcN7LUM3UEz0yqfmOvpr0tZtYOMA0GCSqGSIb3DQEB\nCwUAMBsxGTAXBgNVBAMMEHdob2FtaS5jZXNuZXQuY3owHhcNMTUxMjE0MDkyMjU4\nWhcNMzUxMjE0MDkyMjU4WjAbMRkwFwYDVQQDDBB3aG9hbWkuY2VzbmV0LmN6MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqlyX+ljxEHVNiX4Kt3AMYj6P\nUgWAGHkb5t1xZhrijzWspc6wTc6iNQnLzFTafl1KJktWMHBNmFvUQyHGjCVbski4\nWWUNS4rCFyY7USNjdjiKb7lHqw4OLwd6GMnI6njbUkY7tQJ/Dq3lGPjs+LJ9jPq3\n9l2kSbsMz55WN86aC7J+WwSjCv2BHYs/KEJ+127RUVBtloSmNRZfjJQcdKFsp+mS\nOyMP91WtZQwg3b7EXOOqSkm55esBWJiwII565SHfrl4aQe58xA/V2sHeFH4IbtH/\nIZsibhM/G0eBr9dvHtyfcWvnlA8cmQaD964nVqnYpFa/eXYfg53V1Ft6KQMvgwID\nAQABo2cwZTAdBgNVHQ4EFgQUXaI0YDr1Q2G4mM18pIXB3+nPUHUwRAYDVR0RBD0w\nO4IQd2hvYW1pLmNlc25ldC5jeoYnaHR0cHM6Ly93aG9hbWkuY2VzbmV0LmN6L2lk\ncC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQBzZ5sJtPabubBWaC5UAbl8\n+ZGzSrT72R9vfxW6+NJVK9C5LvCp6a6U3KDrZwMRb5hKvAbkQji1bPHAQ+Bt7qtj\niz4vxBDJueIuZCoHbSSkK9Xb5h9025TGICxNFtty3y4LvroPZ3wYACXdjA/Si3xK\nJF6us/yB6hcAf6ML7DyXW+o4q+35HHmAjBUssXHU70iLOiTnIfbEgxl54Af7xKpZ\n8Ww45V9t2dJ5YU6wzoa0Aqy0abm0RxkWu6igXjpcS+XaSl5n+J+tFEZBRtJZ5mBv\nEQWIvarHy4CabFyOcb1Bl3UHfvQyi3R4RfQsEIYaYBa/5c3LJr3KC8mWCA8vuPx+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUNHGiLWEdd83k9nZ70899LxlSksMwDQYJKoZIhvcNAQEL\nBQAwGzEZMBcGA1UEAwwQd2hvYW1pLmNlc25ldC5jejAeFw0xNTEyMTQwOTIyNTZa\nFw0zNTEyMTQwOTIyNTZaMBsxGTAXBgNVBAMMEHdob2FtaS5jZXNuZXQuY3owggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCNzxV/6eZL14fhksPzth+cv6bf\naoE/W/Z+Hrey2ZEUCexwPN4ogtL35gITcj7uctw5bxFPNO4Io9ooXC5nUBThc90g\njBxTLS8B5/pkbcuRFDX3w4C++mCQdiZ7+5aG1K31+Vw5XCd8Ai+UC3/oZI4vekfC\nZJ7wHYN/W2N15FJ6breDWOewk+z1ezag3SfY2U3aROFBuQJks2WKx7+bClXtVEYz\nSregJY/ZkuCsLsNwxqw+rw4njESLGTpfiK1raWdrBwiPacyCG9T9Fte+AGfoHuK0\nOMcpqPQsnnzB7UAnUCthpo0pllD3qJCL+SdX+Rka40Vps2HrV3Jk/fGxNuADAgMB\nAAGjZzBlMB0GA1UdDgQWBBRJtNZfYNTYii4s7L4/Y/SqT3SMKjBEBgNVHREEPTA7\nghB3aG9hbWkuY2VzbmV0LmN6hidodHRwczovL3dob2FtaS5jZXNuZXQuY3ovaWRw\nL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAGkcr3KAQV2zbSeviEblSyyr\n5tJ/TW2HbJCN/8sLGA+6TwLsCcjWkEtXpXskZlsxbCtgmqztaNa/vQsRSIsVA1Ph\nynUBMniJQ4wfiNhkbj73ukgE16NIY0WITgJNdwFj4Nb5cysCAo+Gqa6UTofB5p9/\nQkEL4dP6M+eo5ZIDvndTF+vb9Uxt+SFttFETS/2RzneYXzCsa/5wWDIsmwNwMRYN\n1RjGMhjQ0DLx4PyEhrOqzWBGFM00qSWypY29SQ/nYGRpjBkvOYasT8eHIovD9M8C\nbmD1QX2KicdJm3oC14xc3Amm2Ja4YeystmRZO0H4z0oVN/zhBT90pjKf4yuF+Bs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAMGRAZNgX7x88WED24sBgvq/prF/MA0GCSqGSIb3DQEB\nCwUAMBsxGTAXBgNVBAMMEHdob2FtaS5jZXNuZXQuY3owHhcNMTUxMjE0MDkyMjU3\nWhcNMzUxMjE0MDkyMjU3WjAbMRkwFwYDVQQDDBB3aG9hbWkuY2VzbmV0LmN6MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAg0TLTs5Cinlt6r2wcS+7NT+k\nO1synzXA9/VEvEDnXbqx5ryyDYyVB4tL4BEU1bsf95GD2RDOdU+rYDRgW+K2R9do\ngJfZ6SmDjdnxOcvLBMkpQTrD0XE35ZDohMf8EXHxuID+JxPDnd0ZU/SF6bH/5WHq\nWzPKIF1+OfIoeRY2IH5HrwKgz5EMvFJKUTcDxzNTFApIzLt46KbxxBxi4JPoPMKT\n9r889YOdknPCuVW4ZldJTljJCR9ZkjgTuIWVBgi3pbqjRtg5JUDrfBBvUUKLC2a8\n3PEnHpP9ukeErX5aVHPJ3dNNL1ACYzjZMGzeb6yDPunISnO/MW/cP8OBu3njcwID\nAQABo2cwZTAdBgNVHQ4EFgQUOJRY3ly/FY3E/c3BlIUAeVbpGkQwRAYDVR0RBD0w\nO4IQd2hvYW1pLmNlc25ldC5jeoYnaHR0cHM6Ly93aG9hbWkuY2VzbmV0LmN6L2lk\ncC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQBhsQ7KA7Furd6LFDZ9inh+\nyaVPlWcS2wBrvW6kgRU5/B+0sf3f/HKOtbYREOvtdI2Cf0rvTlvSACJzJ1Mlta5H\n9AK/M9qlrJf9Vrl5eik5Il1QZBfNniVojz0JImhZmr28sLT3yYMcLAERg1E6Yg35\ndQ4u7VaUTaGleUKF8dZfEc8okQUqeSNAIpTAxzAwQC3crVdtyhH4luP/vFvWwLMg\nV2DvXG/+7HDskpb5nE9Vy3lunkwSZLsBCJHFpU8GWSuhrXpIJjelw7yswEHpep0Q\nD/3xRElbMqPKyidtXPj29chPYs3GsBrvgaXjoNnOwQhB8lS1T2JbrvG/OPVIQojD"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CESNET"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CESNET"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ces.net/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cesnet.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CESNET, a. l. e."
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CESNET, z. s. p. o."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.tamucc.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Phil.Hale@tamucc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Phil Hale"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Edward.Evans@tamucc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Edward Evans"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "OIS@tamucc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Office of Information Security"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ithelp@tamucc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.tamucc.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.tamucc.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.tamucc.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.tamucc.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.tamucc.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.tamucc.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tamucc.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.tamucc.edu"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Texas A&M University-Corpus Christi"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TAMU-CC Federated Identification Services"
                  }
                ],
                "logo": [
                  {
                    "text": "https://falcon.tamucc.edu/maint/idp/tamucc-logo.jpg",
                    "lang": "en",
                    "height": "446",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "254"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://it.tamucc.edu/informationsecurity/securitypolicies/index.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAOYKntKjtqsjK3XCDvOROln3UFB7MA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC50YW11Y2MuZWR1MB4XDTA5MDIyNjE1MjcwNVoX\nDTI5MDIyNjE1MjcwNVowGTEXMBUGA1UEAxMOaWRwLnRhbXVjYy5lZHUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCwST7lWouvG/O9UvsbOVn7RgXRuyil\nC6YNqNIwmSrVzt3nR7pu8K8A4aSCHzyM6nsIIvq27ga4zatdMm+B/dNcrJSVDk5z\nBp6CCVG0POW6MI8fhsPTfXmy97RdALIpjrLVpiJVL27ydRFnQ453yQSiWGG4fj7g\nmhbMuKaY6D1dY/IwDIbgyr/HXZETehIpo+1GduKy4FqD+uHObqN4bGs7rZF1EX/U\nEiQkk1nYsZ+D2xwt/H3F2YAjBh4ja8BtN5VQMA61+8A2rl90teMcqUOTQ83KNlIF\nYRE2791RmIt8nWo4cjPnsrJbwQkcWKtAZ2DUIrYMqd+7stvskuhL2PxrAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC50YW11Y2MuZWR1hiVodHRwczovL2lkcC50YW11\nY2MuZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBShMYoUS4SWFsMeAdQRWjTl\nnciIDjANBgkqhkiG9w0BAQUFAAOCAQEABDsRUn3L/8U6B8HBhwQPmOcvcvMHHihq\nLy3oTnJs3Z4q+nbv6EYozRIWxvZRlBtvzl6uAY4SqOlUgsvyo2ZmZMVwTwxphjqs\ns+rfqQwLmW5SFJDgLuw37Ad0QGDaIDPtkdZD23Va92uriNKAeCCCUFN1bt+cz36Y\nLMyX/IpxQDw5neIfiBge51m49GRFDQvvRdSurNf4uGF9ubBHwk+rqmwle/ypQWNg\n7LtWxJUTw7xMC8A+g7TQNRYxQVQetW8BeuiTLAD3wVEDTag2Jt4Wb2jEXHYkbnTo\n9pLuQGFhtWiswggmYR7TqvrVdoMuskIxwZmVPFx5EplQOQSW+fHYSw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Texas A&M University-Corpus Christi"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tamucc.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Texas A&M University-Corpus Christi"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.silverchair.com/asme/production/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ShibbolethAdmin@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Call"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benc@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ben"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.silverchair.com/asme/production/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-01-11T10:50:48Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Silverchair Production: ASME Digital Collection"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.asme.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Silverchair Science + Communications, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://asmedigitalcollection.asme.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://asmedigitalcollection.asme.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://asmedigitalcollection.asme.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://asmedigitalcollection.asme.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://asmedigitalcollection.asme.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://asmedigitalcollection.asme.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWjCCAkKgAwIBAgIJAOZ/+oV5563RMA0GCSqGSIb3DQEBBQUAMCkxJzAlBgNV\n\t\t\t\t\t\tBAMTHmFzbWVkaWdpdGFsY29sbGVjdGlvbi5hc21lLm9yZzAeFw0xNTA4MzExNTAy\n\t\t\t\t\t\tMzVaFw0yNTA4MjgxNTAyMzVaMCkxJzAlBgNVBAMTHmFzbWVkaWdpdGFsY29sbGVj\n\t\t\t\t\t\tdGlvbi5hc21lLm9yZzCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJXo\n\t\t\t\t\t\tb/YsW00Nn3yAK2H581CMJt6IJU68BDrj28kT91unuQxCCM3qloakx4bUtChqPlnl\n\t\t\t\t\t\tZ5jBOdh2Q+4tSOO3vnod5zjEBP9byD8J7MADDfRs4QFtq1t4FDsBb9FFlQZfxGUS\n\t\t\t\t\t\tID3lnrpdnMlqsU08vivE8B72glHOGvd7PmGwCo8XMyFxK8S9FK/QiZr7TB2lJLtm\n\t\t\t\t\t\tpNuHjcaBXkUXQR1EG06KrnipUfOh1CWGSSBp3jM9rs3jW6XS2U4X8zefdDqfXl7/\n\t\t\t\t\t\tafXJc1shFuT37iVS796k5ATN72gHHmY46BqC/zmPyT/WW8cgEOtUlgjX+SAXkwnY\n\t\t\t\t\t\tLxN+LHV8WExceiPu4z0CAwEAAaOBhDCBgTBgBgNVHREEWTBXgh5hc21lZGlnaXRh\n\t\t\t\t\t\tbGNvbGxlY3Rpb24uYXNtZS5vcmeGNWh0dHBzOi8vc3Auc2lsdmVyY2hhaXIuY29t\n\t\t\t\t\t\tL2FzbWUvcHJvZHVjdGlvbi9zaGliYm9sZXRoMB0GA1UdDgQWBBTYPBU1H5czcpL8\n\t\t\t\t\t\t0eqjApN6rfh3XzANBgkqhkiG9w0BAQUFAAOCAQEAKo3yAAeMIz7l7MKG+TJLBH/Q\n\t\t\t\t\t\tVXJEaqHCX0RF6vTU0UzkFBDjj91dDalhBtJF6K/P5Z5z3IbG0V2Fat3EsSA9gFQO\n\t\t\t\t\t\tpUjMdntBnjcRDV1NVMKM9zvX3KTzTABtAfwO9rFDxJYa9DpB/kyaJH5/8zZyXJ/D\n\t\t\t\t\t\tuHZGq92Tyd3X1C44w2so2CWbF4LETzGnSVh+LFSAB0JPsn5HVx4nCvaJfrvG13Xz\n\t\t\t\t\t\tMiR2KKNHBmqkQy1MBMyTQlNZ6WFCJwMZ4Av6gFvvx8aFshAP567LJ4EL9qJsaloa\n\t\t\t\t\t\tKDpHjZY1f4q5ikk+6A667DYhM+hUjrjUg/54DXVTvkBsIyZ8fdKZEt07OEMUhg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://asmedigitalcollection.asme.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://asmedigitalcollection.asme.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://asmedigitalcollection.asme.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://asmedigitalcollection.asme.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://asmedigitalcollection.asme.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://asmedigitalcollection.asme.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://l-aai.sztaki.hu/idp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sztaki AAI team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@sztaki.hu"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sztaki AAI team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@sztaki.hu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sztaki AAI team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@sztaki.hu"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://l-aai.sztaki.hu/idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "sztaki"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-edugain"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:geant:niif.hu:eduid.hu:entity-attributes:processing-info",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "hu",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://metadata.eduid.hu/registration_policy_1_0.txt"
              }
            ],
            "registration_instant": "2013-08-01T07:17:19.807Z",
            "registration_authority": "http://eduid.hu",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://l-aai.sztaki.hu/idp/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "l-aai.sztaki.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.sztaki.hu"
                  }
                ],
                "display_name": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "MTA Sztaki Munkat\u00e1rsak"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "MTA Sztaki staff"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Magyar Tudom\u00e1nyos Akad\u00e9mia Sz\u00e1m\u00edt\u00e1stechnikai \u00e9s Automatiz\u00e1l\u00e1si Kutat\u00f3int\u00e9zet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hungarian Academy of Sciences Institute for Computer Science and Control"
                  }
                ],
                "logo": [
                  {
                    "text": "https://ujwiki.sztaki.hu/sztaki/resources/assets/Sztaki_logo.png",
                    "height": "66",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "125"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.sztaki.hu"
                  }
                ]
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sztaki.hu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MTA SZTAKI - Magyar Tudom\u00e1nyos Akad\u00e9mia Sz\u00e1m\u00edt\u00e1stechnikai \u00e9s Automatiz\u00e1l\u00e1si Kutat\u00f3int\u00e9zet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Computer and Automation Research Institute, Hungarian Academy of Sciences"
          }
        ],
        "organization_url": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://sztaki.hu/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://sztaki.hu/?en"
          }
        ],
        "organization_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "MTA SZTAKI - Magyar Tudom\u00e1nyos Akad\u00e9mia Sz\u00e1m\u00edt\u00e1stechnikai \u00e9s Automatiz\u00e1l\u00e1si Kutat\u00f3int\u00e9zet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Computer and Automation Research Institute, Hungarian Academy of Sciences"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.worldscientific.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso-support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "sso-support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso-tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "sso-tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.worldscientific.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-09-24T08:34:41Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "World Scientific Publishing"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.worldscientific.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIJAMo7kaDwR+c9MA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\n\t\t\t\t\t\tBAMTF3d3dy53b3JsZHNjaWVudGlmaWMuY29tMB4XDTE0MDMxNDA1MDQwNVoXDTE3\n\t\t\t\t\t\tMDMxMzA1MDQwNVowIjEgMB4GA1UEAxMXd3d3Lndvcmxkc2NpZW50aWZpYy5jb20w\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDGcLg+eAUts7ESOKDmaCHr\n\t\t\t\t\t\tCR4FhKoGk5lLkb7RdU79RatgyUa5YAy4voE3Xa3N9b1dKPYiHwgmOli/hhNcJsEl\n\t\t\t\t\t\tYErh21SVUht8TReEUpwJcpDiqnqJg+EaRvthDoljOclsyeRfPVNMBHh12pPf3KL1\n\t\t\t\t\t\t846o5ylyoaZpUAAqf3nrkwY6EqjWNEbxn1vtg4IilmKbNdWGUi2+rTM+8QdIxKd0\n\t\t\t\t\t\ttiAmeuHUyzWMY51CS2bkAzl3LWP5MybEDWbvP/IuY6eZf+wyFM5VYINSHLY+AUfL\n\t\t\t\t\t\tevZxLOtTY3jfv44yVYk/la0HNueAFHPfY97Js2DBu61geLDP5uUYnH22jAY+TbuD\n\t\t\t\t\t\tAgMBAAGjcTBvME4GA1UdEQRHMEWCF3d3dy53b3JsZHNjaWVudGlmaWMuY29thipo\n\t\t\t\t\t\tdHRwczovL3d3dy53b3JsZHNjaWVudGlmaWMuY29tL3NoaWJib2xldGgwHQYDVR0O\n\t\t\t\t\t\tBBYEFGukXy0GMYv2ClAK5FQYuSzkY8qMMA0GCSqGSIb3DQEBBQUAA4IBAQBOoMR1\n\t\t\t\t\t\tMcB66UVo1ALKuGKjFAJ6f+Dwc95PyPqo7uQIKvWw2jTzcSXy+FrdKj3U0YI9Y9yV\n\t\t\t\t\t\tDidmgNaXXBfW/ISiD0VHQat49+6M8vVr7zbPvDhnSe8zT1Djn/yvZGQSp0ZkcwOe\n\t\t\t\t\t\tdOdZGH5zCaqrl/fBqA8c/LqGaQyExDhzhZkRrivC1fi36yeJ+mam1Ak8RibpkqLo\n\t\t\t\t\t\tWYgwF+sKuItTl9ILiv0lpTgVxUZ4mWCPDN9iMcZHpteNDx03JpkPbXXpEkYoDNJd\n\t\t\t\t\t\tnXDw4i3MX1B4IxF9F0PWb0z7OWVaaqRou/VfFhOB8mKEKCeXxmIseSXMJ+dZITvH\n\t\t\t\t\t\ttfeTpSAfBcbH1XmK"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.worldscientific.com/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.worldscientific.com/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.worldscientific.com/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib.courseleaf.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "wbachman@leepfrog.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Wes Bachman"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.courseleaf.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Leepfrog Technologies, Inc."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.leepfrog.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Leepfrog Technologies, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shib.courseleaf.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://courseleaf.com"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Leepfrog Technologies CourseLeaf"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CourseLeaf"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJALAsCdsphihDMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMME3NoaWIuY291cnNlbGVhZi5jb20wHhcNMTQwNDExMTYwMjAxWhcNMjQwNDA4\nMTYwMjAxWjAeMRwwGgYDVQQDDBNzaGliLmNvdXJzZWxlYWYuY29tMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtEXMRZGERUGU/S2fOfjXFCED6+d6k37L\n0p+qnU5lTKz3ry8f1fx8SAfbXUdmJWfnUocAbE6S7ldJr/y2McNqq24T4cMOpexP\nuUjO0QwdFYpl+zxccG9oMkBWvr9RSoaTY08oa7nwEkx1bZ12yq8K6Z1WUe/XaEWG\nQ/OGEQJ9K8TidElZr68PYh2bYYF+qiHBDQkWMqDV8fnb/ljjyIcmZijxJIQ0+FWO\n278UwCY85w3Vi0wMEF7jIrFEwoxf9NGrtJWn1hxaAqesJ5ILZTo3VFgXf52iZRhx\nLWwuxn8opZdA20oFJb0PxJvDfJldFhyacrml3DXkG0l6ysx3lweV9wIDAQABo1Aw\nTjAdBgNVHQ4EFgQUdh5Dd9hJbH8TwgiMchfyh/cYUfcwHwYDVR0jBBgwFoAUdh5D\nd9hJbH8TwgiMchfyh/cYUfcwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOC\nAQEAKGLyWTvE6CKxrlJAn/Z90Hp3O4phot0CDKkPZfTF145R523YFDlloJQ5pnMA\nMbPXdQ5Fk5qUzDwtWMW//gW3nSP3XpRnEwOR1EIUOil39wprH1Ny9Bxzb1dQue7i\nQgM1qiBUzw5ZYSzmuC44i6PuyPMresgopm5MRmrsGD3Nw86k2wc5nf0PVIKI7O6F\nEB9avy/o/5Ciu0/Iw/ogixkQoMvtDrh3cC4QdVz4d8OjQzP9xbPMtcWbzJIzf6/O\nEsvIY/ZNwb1RTkT8GIXwkC7EgO0m5UeRMJJWFU1K8Jk9chpCmebrXFcz1RqJBlUE\njhao0WXgTHHQUUpEzZXrh/Bzyw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.courseleaf.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.courseleaf.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shib.courseleaf.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shib.courseleaf.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shib.courseleaf.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currbulletin.wustl.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextbulletin.wustl.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://coursecatalog-new.web.cmu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://upcomingcatalog.uchicago.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://stagingcatalog.uchicago.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.odu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcatalog.odu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://next-catalog.ncsu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://current-catalog.ncsu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://exploredegrees-admin.stanford.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://exploredegrees-nextyear.stanford.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextbulletin.brown.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "18"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentbulletin.brown.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "19"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.uark.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "20"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcatalog.uark.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "21"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.utexas.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "22"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currcatalog.utexas.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "23"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://next.catalogue.uci.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "24"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://current.catalogue.uci.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "25"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcatalog-admin.calpoly.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "26"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog-admin.calpoly.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "27"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcatalog.missouri.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "28"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.missouri.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "29"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextbulletin.umsl.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "30"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentbulletin.umsl.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "31"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.mst.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "32"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcatalog.mst.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "33"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.sandburg.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "34"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcatalog.sandburg.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "35"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://next.catalog.utsa.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "36"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://current.catalog.utsa.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "37"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://catalog-next.uvm.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "38"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://catalog-current.uvm.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "39"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.lehigh.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "40"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcatalog.lehigh.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "41"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://courseadmin.ou.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "42"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.uthscsa.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "43"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcatalog.uthscsa.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "44"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://e-nextcatalog.jhu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "45"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://e-currentcatalog.jhu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "46"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://next.catalog.ku.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "47"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://current.catalog.ku.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "48"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.uoregon.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "49"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcatalog.uoregon.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "50"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.uis.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "51"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcatalog.uis.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "52"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.uic.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "53"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcatalog.uic.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "54"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://next.bulletin.gwu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "55"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://current.bulletin.gwu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "56"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcourses.illinois.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "57"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcourses.illinois.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "58"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextbulletin.csusb.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "59"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentbulletin.csusb.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "60"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.apu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "61"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcatalog.apu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "62"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.umkc.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "63"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://editcatalog.umkc.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "64"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.creighton.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "65"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcatalog.creighton.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "66"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://classplanning.northwestern.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "67"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.towson.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "68"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcatalog.towson.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "69"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uww-next.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "70"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uww-curr.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "71"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://next.catalog.njit.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "72"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://current.catalog.njit.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "73"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://northwestern-dev.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "74"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextbulletin.temple.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "75"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentbulletin.temple.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "76"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://next.catalogue.uci.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "77"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://current.catalogue.uci.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "78"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.mtholyoke.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "79"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcatalog.mtholyoke.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "80"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.uwgb.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "81"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcatalog.uwgb.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "82"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.twu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "83"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcatalog.twu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "84"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.stolaf.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "85"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currcatalog.stolaf.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "86"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://next.catalog.colostate.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "87"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://catalog-dev.mit.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "88"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mit-curr.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "89"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://colostate-curr.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "90"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.udayton.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "91"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcatalog.udayton.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "92"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://utexas-prior.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "93"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uic-prior.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "94"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://catalog-test.uwplatt.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "95"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://next.mycatalog.txstate.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "96"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://current.mycatalog.txstate.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "97"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://next-bulletin.miami.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "98"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://miami-curr.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "99"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.uah.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "100"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uah-curr.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "101"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextschedule.unomaha.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "102"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.shsu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "103"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shsu-curr.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "104"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.northeastern.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "105"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://northeastern-curr.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "106"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://stanford-test.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "107"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://easyschedule.fau.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "108"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uci-test.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "109"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.ou.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "110"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ou-curr.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "111"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://unomaha-test.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "112"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.uwec.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "113"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uwec-curr.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "114"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.registrar.iastate.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "115"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentcatalog.registrar.iastate.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "116"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://georgetown-next.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "117"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.uaf.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "118"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uaf-curr.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "119"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mines-test.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "120"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mines-prior.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "121"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextbulletin.mines.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "122"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://currentbulletin.mines.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "123"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gatech-curr.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "124"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://catalog-next.gatech.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "125"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://temple-test.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "126"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.uvu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "127"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uvu-curr.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "128"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uwplatt-curr.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "129"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextcatalog.unc.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "130"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://unc-curr.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "131"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nextbulletin.sfsu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "132"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sfsu-curr.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "133"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://devcatalog.utep.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "134"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://testcatalog.utep.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "135"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://next-guide.wisc.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "136"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wisc-curr.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "137"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uww-test.courseleaf.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "138"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CourseLeaf"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Leepfrog Technologies CourseLeaf"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.jvcs.ja.net/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "v-scene@ja.net"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.mcintosh@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "JVCS"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonnett"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul.bonnett@ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.jvcs.ja.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2012-10-19T11:50:58Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Janet Videoconference Booking Service (JVCS)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ja.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "JISC Collections and Janet Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://v-scene.ja.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vscene.jisc.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nhs-england.vscene.jisc.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nhs-wales.vscene.jisc.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nhs-scotland.vscene.jisc.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://belnet.vscene.jisc.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://heanet.vscene.jisc.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "8"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vscene.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "v-scene enables you to launch or schedule H323 and Desktop videoconferences, record, stream and add guests."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "v-scene"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIERjCCAy6gAwIBAgIJALrNeL2vzXUQMA0GCSqGSIb3DQEBCwUAMIGjMQswCQYD\n\t\t\t\t\t\tVQQGEwJVSzEQMA4GA1UECBMHRW5nbGFuZDEQMA4GA1UEBxMHQnJpc3RvbDEWMBQG\n\t\t\t\t\t\tA1UEChMNSmlzYyBTZXJ2aWNlczEaMBgGA1UECxMRSmlzYyBUZWNobm9sb2dpZXMx\n\t\t\t\t\t\tGjAYBgNVBAMTEXZzY2VuZS5qaXNjLmFjLnVrMSAwHgYJKoZIhvcNAQkBFhF2c2Nl\n\t\t\t\t\t\tbmVAamlzYy5hYy51azAeFw0xNTExMDMxNjMyNTFaFw0zNTEwMjkxNjMyNTFaMIGj\n\t\t\t\t\t\tMQswCQYDVQQGEwJVSzEQMA4GA1UECBMHRW5nbGFuZDEQMA4GA1UEBxMHQnJpc3Rv\n\t\t\t\t\t\tbDEWMBQGA1UEChMNSmlzYyBTZXJ2aWNlczEaMBgGA1UECxMRSmlzYyBUZWNobm9s\n\t\t\t\t\t\tb2dpZXMxGjAYBgNVBAMTEXZzY2VuZS5qaXNjLmFjLnVrMSAwHgYJKoZIhvcNAQkB\n\t\t\t\t\t\tFhF2c2NlbmVAamlzYy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAKHYHA0HVKuQM6QQP9JJzs7tpGi8eTQNgdMYrfG9NXU246aUl01R0HuZ+Su1\n\t\t\t\t\t\txduGGbvHZl6m++CKATfpZz7tt9fwJ6Y8AeldzuQLUZQBhq/wpPfcgL/67hjHqWLP\n\t\t\t\t\t\tRIlKGtwBOkLwahAiijoCXwc0u+VyUj9CI/2jtycfHu7VFQvo6O8g5AOlW9sxR/6H\n\t\t\t\t\t\tjuBd7iDrcEiTXWef0CvQXG9JL23K7orN9Ox6NyIu8mDkBmUSY44VoYVkKWQMXsgQ\n\t\t\t\t\t\ttmnUMdtmwom44QoHsBajYBGKxa0G8BkIS2grkY6lhbH7/1DD/abRQah1UsM/+Ihc\n\t\t\t\t\t\tIIJnbUBMBf35N2eIU8hA6tCY7YcCAwEAAaN7MHkwCQYDVR0TBAIwADAsBglghkgB\n\t\t\t\t\t\thvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYE\n\t\t\t\t\t\tFG3/iS8iRCNI4bCuX1P3mLDWIlC3MB8GA1UdIwQYMBaAFG3/iS8iRCNI4bCuX1P3\n\t\t\t\t\t\tmLDWIlC3MA0GCSqGSIb3DQEBCwUAA4IBAQBCUENyYiELCOaELvQF8s0YpZXbBMpe\n\t\t\t\t\t\tT9Tb/GLhxJvjR25G0o4j177aRvMUPP12FbtHafL4LtETzuKvhDP5Xgy86XwnR7mh\n\t\t\t\t\t\t/dk0JYirItS+zH11avaVGY8ZbzY2al1SEQNA/sQtBywnc8j5YYS9t9QmapaXk85t\n\t\t\t\t\t\tbXiZRuzrAT/U2VDjMGba6FlFeAqowGqWnt2vcrOi0hdpjqh07yy/W7oszgwx84t+\n\t\t\t\t\t\tLXX3Kfg5yiOFW+WsmdkZMCfAPJzrAq6rAg1JoyVC3v7Jk6CHNr5VnQPcNL+TaN9l\n\t\t\t\t\t\tFIL5YwZINvpuWpxQUrsAfi47Yi6YfPNy9Yu7rVhl9GpNX8VaZYu6q7bM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vscene.jisc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vscene.jisc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vscene.jisc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vscene.jisc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vscene.jisc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vscene.jisc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "18"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nhs-england.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "19"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://nhs-england.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "20"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nhs-england.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "21"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://nhs-england.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "22"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://nhs-england.vscene.jisc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "23"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://nhs-england.vscene.jisc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "24"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nhs-wales.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "25"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://nhs-wales.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "26"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nhs-wales.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "27"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://nhs-wales.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "28"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://nhs-wales.vscene.jisc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "29"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://nhs-wales.vscene.jisc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "30"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nhs-scotland.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "31"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://nhs-scotland.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "32"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nhs-scotland.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "33"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://nhs-scotland.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "34"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://nhs-scotland.vscene.jisc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "35"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://nhs-scotland.vscene.jisc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "36"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://belnet.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "37"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://belnet.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "38"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://belnet.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "39"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://belnet.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "40"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://belnet.vscene.jisc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "41"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://belnet.vscene.jisc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "42"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://heanet.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "43"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://heanet.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "44"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://heanet.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "45"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://heanet.vscene.jisc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "46"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://heanet.vscene.jisc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "47"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://heanet.vscene.jisc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "48"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "v-scene"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "v-scene enables you to launch or schedule H323 and Desktop videoconferences, record, stream and add guests."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonTargetedID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:incommon:ucdavis.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sysadmin@ucdavis.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Infrastructure Systems Management"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibadmin@ucdavis.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EAIS Shibboleth Group"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibadmin@ucdavis.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EAIS Shibboleth Group"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:ucdavis.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.ucdavis.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.ucdavis.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.ucdavis.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.ucdavis.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFTCCAf2gAwIBAgIJAPPcLMuZiVH8MA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMMFnNoaWJib2xldGgudWNkYXZpcy5lZHUwHhcNMTMwNDAzMjAxNDE2WhcNMzMw\nNTAzMjAxNDE2WjAhMR8wHQYDVQQDDBZzaGliYm9sZXRoLnVjZGF2aXMuZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsp192eOPILgmh31WyOOXSfAe\nHy26ZLQPynjO011vO2iN9WfpNnkw10jOYc8n++rmTBt+CPrld6zPm9vyF0YyhFgA\n3np8nEnsX94rdc/x4bZaVHDo5V0yUW7dqeZ0QpxMMBDLiJu+i5QyHzGORgrfA9vb\nditbtIF2yBKVhtwtuAJ4EMMVXMgDrddh3iwuYDIkizb9ro6wyb+g2BYft/rXYzV1\nQ5y7PJuu7/5tobEELnBPUX96NBtN0xHPRk69BmqIOHb0I3subojQd2mJMHAJZBa3\n1rVSqMoqDc1XvzRoNAnbFGVkoFsDJ7Pub/Bp9TwpY5M4x20xLereaW3XOU3+dQID\nAQABo1AwTjAdBgNVHQ4EFgQUgYNUwHp+5Mcj29XUBc82gYlyAGAwHwYDVR0jBBgw\nFoAUgYNUwHp+5Mcj29XUBc82gYlyAGAwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0B\nAQUFAAOCAQEAjx0V9ar1jRCHJQ/iZQ27oHbIOTW+eM0LDO6j9vESk5a+4CvpIJ+F\n+Wjom1eCaM6Hm1o0ZLcODJRQpJVuWEItoe3vaa3flN5L7KX7txP7/BQrfm6SY+RM\n4HtVAidvTfycM5nTxWpy84E19u2VU4THdwAWEBGcJUNxlNrgT9ELZpOorx5+g2v7\nwNQMjfSwPtyOLPTF/1jGkQcTao1ZdejLuVbwTykBVFPeFQ8kAU6wsQpXeG3atpQl\nzxm9ugFEeQnBFLCckELT9sAV/5yzXtAdSexhyi4+wJ4peM57Kncf/SfdKeMKiyWt\nEyhVP7yaI/7vtaqct2bie69yO4PiaRMyaQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucdavis.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://shibboleth.ucdavis.edu/icons/ucd_logo.png",
                    "lang": "en",
                    "height": "101",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "396"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of California, Davis"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of California, Davis"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ucdavis.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of California, Davis"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://cafe.sti.uff.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Uenes Vilaca"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "uenesvilaca@id.uff.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.sti.uff.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3jCCAcYCAQAwDQYJKoZIhvcNAQEFBQAwNTEMMAoGA1UECxMDQ1BEMQswCQYD\nVQQGEwJCUjEYMBYGA1UEAxMPY2FmZS5zdGkudWZmLmJyMB4XDTE1MDMwNjEzMjYz\nMloXDTIwMDMwNDEzMjYzMlowNTEMMAoGA1UECxMDQ1BEMQswCQYDVQQGEwJCUjEY\nMBYGA1UEAxMPY2FmZS5zdGkudWZmLmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEA174aH+85vMtUCFZixKVVagtPNB8dDsOZy1yfoBtt5doQbTJ940sE\nfZaqV7ZseZUywzki5ywXb1exPWVIRcfcm4MXq0W9Aa4+ObS4+MnB24rHzAOTB9gq\nD2vtr500abR7kKmoj/DelinGZ3yQmsvTOLFn0O9TH+dsVuJeF7HGkGhqmX77PGSB\nkii2+lO1ZVBap6NTacu8H7GEK9ci5Qjl4xXYaDCq8SXs0Ms0psSzG++wpyyyPV9W\nq2qNmLGVxxXd+hWwQwCieLYc3PuE9jeDkWJe8a25AvjwTmoIohyYciOw2P+3muN4\nPozn6TM3oFVw8cm41jTiuQJsUyxjFDAyTwIDAQABMA0GCSqGSIb3DQEBBQUAA4IB\nAQBkp0lu/zIeWo4OHVVhqTbPxcoMQ7UnBUJuku12ZmIfDb6FDiHlQitwTuBrep87\nA3oEmVN9BTLr/r8iw58Bfze/kYGQW9P7QOObOWaBDVuWPN2DLvBO2uvMSuOEZoI0\n3NCuLr5mi+Ahkwg+3Skgxa/LoT9ata18j2g11Jpa1z609buu7LJ2BBZ0etaxG6M9\n5zCCsP9j3MJ90/gsPT+dv/c2F3zOBq1hH7zzU2D16+wPX75vEd6ZQWzRacaUhaCu\nXBWbFnTZT9kXDNGoyyO5IgDXwprECJG1PeeqgD/j7iNWqeynNxuOQY7bKFMx8sjj\nnoYKknCKZFy1OZxKXL8q2O1w"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uff.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.sti.uff.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.sti.uff.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.sti.uff.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.sti.uff.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.sti.uff.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.sti.uff.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.sti.uff.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.sti.uff.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uff.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uff.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uff.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFF - Universidade Federal Fluminense"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFF - Universidade Federal Fluminense"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFF - Universidade Federal Fluminense"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFF - Universidade Federal Fluminense"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3jCCAcYCAQAwDQYJKoZIhvcNAQEFBQAwNTEMMAoGA1UECxMDQ1BEMQswCQYD\nVQQGEwJCUjEYMBYGA1UEAxMPY2FmZS5zdGkudWZmLmJyMB4XDTE1MDMwNjEzMjYz\nMloXDTIwMDMwNDEzMjYzMlowNTEMMAoGA1UECxMDQ1BEMQswCQYDVQQGEwJCUjEY\nMBYGA1UEAxMPY2FmZS5zdGkudWZmLmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEA174aH+85vMtUCFZixKVVagtPNB8dDsOZy1yfoBtt5doQbTJ940sE\nfZaqV7ZseZUywzki5ywXb1exPWVIRcfcm4MXq0W9Aa4+ObS4+MnB24rHzAOTB9gq\nD2vtr500abR7kKmoj/DelinGZ3yQmsvTOLFn0O9TH+dsVuJeF7HGkGhqmX77PGSB\nkii2+lO1ZVBap6NTacu8H7GEK9ci5Qjl4xXYaDCq8SXs0Ms0psSzG++wpyyyPV9W\nq2qNmLGVxxXd+hWwQwCieLYc3PuE9jeDkWJe8a25AvjwTmoIohyYciOw2P+3muN4\nPozn6TM3oFVw8cm41jTiuQJsUyxjFDAyTwIDAQABMA0GCSqGSIb3DQEBBQUAA4IB\nAQBkp0lu/zIeWo4OHVVhqTbPxcoMQ7UnBUJuku12ZmIfDb6FDiHlQitwTuBrep87\nA3oEmVN9BTLr/r8iw58Bfze/kYGQW9P7QOObOWaBDVuWPN2DLvBO2uvMSuOEZoI0\n3NCuLr5mi+Ahkwg+3Skgxa/LoT9ata18j2g11Jpa1z609buu7LJ2BBZ0etaxG6M9\n5zCCsP9j3MJ90/gsPT+dv/c2F3zOBq1hH7zzU2D16+wPX75vEd6ZQWzRacaUhaCu\nXBWbFnTZT9kXDNGoyyO5IgDXwprECJG1PeeqgD/j7iNWqeynNxuOQY7bKFMx8sjj\nnoYKknCKZFy1OZxKXL8q2O1w"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFF - Universidade Federal Fluminense"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFF - Universidade Federal Fluminense"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uff.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uff.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFF - Universidade Federal Fluminense"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFF - Universidade Federal Fluminense"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://play.fhs.se",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "saml_admin@kaltura.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://play.fhs.se",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "F\u00f6rsvarsh\u00f6gskolan (PROD)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://play.fhs.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "F\u00f6rsvarsh\u00f6gskolan (PROD)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://play.fhs.se/user/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is tThe Swedish Defence University's streaming service."
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Detta \u00e4r F\u00f6rsvarsh\u00f6gskolans play tj\u00e4nst"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The Swedish Defence University Play service"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "F\u00f6rsvarsh\u00f6gskolans Play tj\u00e4nst"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.fhs.se/user/authenticate",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.stmarysblackburn.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Holmes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:p.holmes@stmarysblackburn.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Holmes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:p.holmes@stmarysblackburn.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.stmarysblackburn.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-04-09T09:00:58Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDgDCCAmgCCQC1ZXdEMSkHoTANBgkqhkiG9w0BAQUFADCBgTELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEzARBgNVBAgMCkxhbmNhc2hpcmUxEjAQBgNVBAcMCUJsYWNrYnVybjEkMCIG\n\t\t\t\t\t\tA1UECgwbU3QgTWFyeSdzIENvbGxlZ2UgQmxhY2tidXJuMSMwIQYDVQQDDBppZHAu\n\t\t\t\t\t\tc3RtYXJ5c2JsYWNrYnVybi5hYy51azAeFw0xMzAzMjAxNDEyNDVaFw0zMzAzMTUx\n\t\t\t\t\t\tNDEyNDVaMIGBMQswCQYDVQQGEwJHQjETMBEGA1UECAwKTGFuY2FzaGlyZTESMBAG\n\t\t\t\t\t\tA1UEBwwJQmxhY2tidXJuMSQwIgYDVQQKDBtTdCBNYXJ5J3MgQ29sbGVnZSBCbGFj\n\t\t\t\t\t\ta2J1cm4xIzAhBgNVBAMMGmlkcC5zdG1hcnlzYmxhY2tidXJuLmFjLnVrMIIBIjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAso24AO1L+cxS493DDBKKkNoyjm+I\n\t\t\t\t\t\t1W022qP63HDSRvGa+QvKObXH9aj0jxwklj/wG4dr46Ok3cLciXZdBpzOUFlkBWkN\n\t\t\t\t\t\t36T3WWkkNrpmWU4lB+t3MB3qU+VPzzBLOJ7pHEb4bOOG8ymxLayA9TaCFeR0XXFg\n\t\t\t\t\t\tQqmCIdG/vPHAMxDZGbbDE5pUy2SupofDKDYdgNMfM1Z/REokXFVYHpIbzSf4jHKj\n\t\t\t\t\t\t30Gl/Cjdt54Yy7HVhHNBIZDOxP6FPDoYt3hfzzUQKSwas0g6DIZY/IoZaakcZe0D\n\t\t\t\t\t\tUXNqoqF4sPOH1lGI47lLYSsmuJCIp6cpfQzweH7vkQ0XgECTSTvc4HMPKwIDAQAB\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQBBW2P4fTo8YMSzw4BJUjVmuEVYwz8r25BxvuX9\n\t\t\t\t\t\tE43c436ZG2P3PlC3GrVFk7aF8saYheAG83CbY/zzD0qXHEHaVMTCOa26v6Ogs2Yo\n\t\t\t\t\t\tdM1TAz4fPra46Tt00NqvOD/HemosWu/XfvHgdsNNhNmiFkHYljNLL1ZKUJliZykW\n\t\t\t\t\t\tPY1+RYcg69jvR/QkbapO0QYSktgZLl81pZsnC1pfGewDtk3a8fQ8Iye1LBJhXGSo\n\t\t\t\t\t\tqhcvXbr3A6zI+vTJxGGyGo4Lt8mD0aQBg43Oxv+lOlKo4uayr4spvv1ZqUfwkkYP\n\t\t\t\t\t\tLKRxyHZph1dvVcdhDGXoTYr9SGxFP3969/Fei+O6fD6GP2xT"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stmarysblackburn.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.stmarysblackburn.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.stmarysblackburn.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.stmarysblackburn.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.stmarysblackburn.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.stmarysblackburn.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.stmarysblackburn.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.stmarysblackburn.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.stmarysblackburn.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stmarysblackburn.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://moodle.stmarysblackburn.ac.uk/images/logo.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://moodle.stmarysblackburn.ac.uk/images/logo-icon.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "St Mary's Blackburn College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDgDCCAmgCCQC1ZXdEMSkHoTANBgkqhkiG9w0BAQUFADCBgTELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEzARBgNVBAgMCkxhbmNhc2hpcmUxEjAQBgNVBAcMCUJsYWNrYnVybjEkMCIG\n\t\t\t\t\t\tA1UECgwbU3QgTWFyeSdzIENvbGxlZ2UgQmxhY2tidXJuMSMwIQYDVQQDDBppZHAu\n\t\t\t\t\t\tc3RtYXJ5c2JsYWNrYnVybi5hYy51azAeFw0xMzAzMjAxNDEyNDVaFw0zMzAzMTUx\n\t\t\t\t\t\tNDEyNDVaMIGBMQswCQYDVQQGEwJHQjETMBEGA1UECAwKTGFuY2FzaGlyZTESMBAG\n\t\t\t\t\t\tA1UEBwwJQmxhY2tidXJuMSQwIgYDVQQKDBtTdCBNYXJ5J3MgQ29sbGVnZSBCbGFj\n\t\t\t\t\t\ta2J1cm4xIzAhBgNVBAMMGmlkcC5zdG1hcnlzYmxhY2tidXJuLmFjLnVrMIIBIjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAso24AO1L+cxS493DDBKKkNoyjm+I\n\t\t\t\t\t\t1W022qP63HDSRvGa+QvKObXH9aj0jxwklj/wG4dr46Ok3cLciXZdBpzOUFlkBWkN\n\t\t\t\t\t\t36T3WWkkNrpmWU4lB+t3MB3qU+VPzzBLOJ7pHEb4bOOG8ymxLayA9TaCFeR0XXFg\n\t\t\t\t\t\tQqmCIdG/vPHAMxDZGbbDE5pUy2SupofDKDYdgNMfM1Z/REokXFVYHpIbzSf4jHKj\n\t\t\t\t\t\t30Gl/Cjdt54Yy7HVhHNBIZDOxP6FPDoYt3hfzzUQKSwas0g6DIZY/IoZaakcZe0D\n\t\t\t\t\t\tUXNqoqF4sPOH1lGI47lLYSsmuJCIp6cpfQzweH7vkQ0XgECTSTvc4HMPKwIDAQAB\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQBBW2P4fTo8YMSzw4BJUjVmuEVYwz8r25BxvuX9\n\t\t\t\t\t\tE43c436ZG2P3PlC3GrVFk7aF8saYheAG83CbY/zzD0qXHEHaVMTCOa26v6Ogs2Yo\n\t\t\t\t\t\tdM1TAz4fPra46Tt00NqvOD/HemosWu/XfvHgdsNNhNmiFkHYljNLL1ZKUJliZykW\n\t\t\t\t\t\tPY1+RYcg69jvR/QkbapO0QYSktgZLl81pZsnC1pfGewDtk3a8fQ8Iye1LBJhXGSo\n\t\t\t\t\t\tqhcvXbr3A6zI+vTJxGGyGo4Lt8mD0aQBg43Oxv+lOlKo4uayr4spvv1ZqUfwkkYP\n\t\t\t\t\t\tLKRxyHZph1dvVcdhDGXoTYr9SGxFP3969/Fei+O6fD6GP2xT"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "St Mary's Blackburn College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.stmarysblackburn.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "St Mary's College, Blackburn"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.sjcoxford.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Slater"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rslater@tcasonline.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rachel"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Amin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:famin@tcasonline.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Fazal"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.sjcoxford.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-15T10:42:38Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "TCAS Online"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://tcasonline.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "TCAS Online Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sjcoxford.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sjcoxford.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sjcoxford.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sjcoxford.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sjcoxford.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sjcoxford.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TCAS Online is a cloud-based management platform for student accommodation portfolios."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.sjcoxford.com/images/TCAS_header_06.png",
                    "height": "52",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "160"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TCAS Online"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6DCCAdCgAwIBAgIJANpmEKYj4D/2MA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\n\t\t\t\t\t\tBAMTC3RjYXNzZXJ2ZXIzMB4XDTE1MDUxMzA2NTgwM1oXDTI1MDUxMDA2NTgwM1ow\n\t\t\t\t\t\tFjEUMBIGA1UEAxMLdGNhc3NlcnZlcjMwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQDM4GH4iDtBb6K4ds+mmVkiV0VG0LlT6SHOiGaQLUrfImeF+hpddA/H\n\t\t\t\t\t\tv54p/+LQhNH6SuzLIkZpwD/BAhqdV9DsoPry27TzYWOOS9z4nC9jERf2jVUq/F6B\n\t\t\t\t\t\tlwaPYSSBhQpZQUhViZN6O77ArH45xcExWSWNXubjgDyQ4C1CpVswm08LuR2myVdR\n\t\t\t\t\t\tJ0/zChmFl9AoA7CLNzPmC3Dgx9+H/w3Fowmn61+8cY3T+Lxg6Lzb9D4SZQEhElMt\n\t\t\t\t\t\tNvyZaUaUaJ7x1U8bkeGGzLkhiQxdWQ331hJnFYM7mCt6afKooR4lP+c4qELrx0HF\n\t\t\t\t\t\tKPya0Ebi/f5Lu57zF1Ktjg+fbVUPw8yxAgMBAAGjOTA3MBYGA1UdEQQPMA2CC3Rj\n\t\t\t\t\t\tYXNzZXJ2ZXIzMB0GA1UdDgQWBBQXDwgHKZzS5BB0V3J6MICHxf8fBDANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAhe0e/UJdHzSnBgQKrDsbAe7RruoSVTVreNsrFkUE+UU9OSOQ\n\t\t\t\t\t\tL1zChTXHSfQDRIt//JcKdw7duA8SFgDx0sDf093FJ+HabaRjJz8PJPDjYVoKtjiV\n\t\t\t\t\t\tmGTwUldiVaKlwrkZWEwCMuLDQ/UrudeuIwjfcKncGyuAfuOMjBar/LGiOmzNzzZi\n\t\t\t\t\t\tRgCNiKgHPhXNGjKtViV1+Z4H6B3zLyYhbxuTxx/b5j3jAVSdc7UydShbzzs2QvD+\n\t\t\t\t\t\tdQrGI9VaOWtJVA0z8Z1zrnB3MvlQUZw0Ma2DsGpgZITKmLFc8hiR3uJtRyxMUzwK\n\t\t\t\t\t\t1Uj11XkAOJyNcStbwH7Cfr7OGdjeW4tYyLjfMw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sjcoxford.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sjcoxford.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sjcoxford.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sjcoxford.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sjcoxford.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sjcoxford.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://knowledge.sagepub.com/oa/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:onlinesupport@sagepub.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SAGE Online Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smith"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rob.smith@sagepub.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rob"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://knowledge.sagepub.com/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-05-19T10:12:27Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SAGE Knowledge"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sagepublications.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SAGE Publications Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://knowledge.sagepub.com/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://knowledge.sagepub.com/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://knowledge.sagepub.com/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://knowledge.sagepub.com/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIEUqnsnzANBgkqhkiG9w0BAQUFADA5MRcwFQYDVQQKEw5T\n\t\t\t\t\t\tQUdFIEtub3dsZWRnZTEeMBwGA1UEAxMVa25vd2xlZGdlLnNhZ2VwdWIuY29tMB4X\n\t\t\t\t\t\tDTEzMTIxMjE3MDQzMVoXDTIzMTIxMDE3MDQzMVowOTEXMBUGA1UEChMOU0FHRSBL\n\t\t\t\t\t\tbm93bGVkZ2UxHjAcBgNVBAMTFWtub3dsZWRnZS5zYWdlcHViLmNvbTCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN+8ZzgPSwEfb6WMoObF9tmbrlBloL2z\n\t\t\t\t\t\tOL7vldcop8YDfeOthyRQqOEGVnc83uJoz0Ut8TexVpSiaGAwDNNuFS9cgwZif/N6\n\t\t\t\t\t\t5mNhYRoxyqbBsm7WrIxT0zVjPKE2PWDtlaoNlcCvicnc4+1rdRlL19nz2EJIBcqb\n\t\t\t\t\t\tvqoSOCNqkcJxMNVoSlMVEln4Wwt77gKCJxSaegWRcviWacFpJ71IReD6mRcyelc+\n\t\t\t\t\t\tYm6DJNyomPgGiySW0WOJ4MvBcduRf0qTfceeJkq30wgCfs5z39pKA5y3W/eAAzCS\n\t\t\t\t\t\tBi9gi+M6+JeK1KJFz0kLs9yW0emRiuBeihFCrvss26OE3MeUqTsb6pECAwEAATAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAgbKk/wRJddJm1KFDE+vE9DYSS9tcUO20suWWrsyW\n\t\t\t\t\t\tEga1Id7xOB5EmYyFLeoHwnwjndInkf8LwyPeevraFWdyAlNYjPnte87trpM6AETp\n\t\t\t\t\t\t7ZFvAt6nVZuTzYLvqXRoLCOKCL8zyiYRRLSgPpbJzhdpb98cQWCe5Qr36/9EDRhc\n\t\t\t\t\t\twULr8Z8HJOgONxWQbNnZTPU8Z0lrisOhAbAu3QGk5Km4+6v9o8PQch1zECh7HEZa\n\t\t\t\t\t\tr5NoRY3Ztd9AOTg48jCeyumPUOyk3ZBSt17RfnyCqCuRujbDVCi1WH9+rOW3nBb6\n\t\t\t\t\t\tCgnionTlX4+VFoFbt4CJjGVxZuSczulc6XkpPlJnAvSuhQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIEUqnsnzANBgkqhkiG9w0BAQUFADA5MRcwFQYDVQQKEw5T\n\t\t\t\t\t\tQUdFIEtub3dsZWRnZTEeMBwGA1UEAxMVa25vd2xlZGdlLnNhZ2VwdWIuY29tMB4X\n\t\t\t\t\t\tDTEzMTIxMjE3MDQzMVoXDTIzMTIxMDE3MDQzMVowOTEXMBUGA1UEChMOU0FHRSBL\n\t\t\t\t\t\tbm93bGVkZ2UxHjAcBgNVBAMTFWtub3dsZWRnZS5zYWdlcHViLmNvbTCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN+8ZzgPSwEfb6WMoObF9tmbrlBloL2z\n\t\t\t\t\t\tOL7vldcop8YDfeOthyRQqOEGVnc83uJoz0Ut8TexVpSiaGAwDNNuFS9cgwZif/N6\n\t\t\t\t\t\t5mNhYRoxyqbBsm7WrIxT0zVjPKE2PWDtlaoNlcCvicnc4+1rdRlL19nz2EJIBcqb\n\t\t\t\t\t\tvqoSOCNqkcJxMNVoSlMVEln4Wwt77gKCJxSaegWRcviWacFpJ71IReD6mRcyelc+\n\t\t\t\t\t\tYm6DJNyomPgGiySW0WOJ4MvBcduRf0qTfceeJkq30wgCfs5z39pKA5y3W/eAAzCS\n\t\t\t\t\t\tBi9gi+M6+JeK1KJFz0kLs9yW0emRiuBeihFCrvss26OE3MeUqTsb6pECAwEAATAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAgbKk/wRJddJm1KFDE+vE9DYSS9tcUO20suWWrsyW\n\t\t\t\t\t\tEga1Id7xOB5EmYyFLeoHwnwjndInkf8LwyPeevraFWdyAlNYjPnte87trpM6AETp\n\t\t\t\t\t\t7ZFvAt6nVZuTzYLvqXRoLCOKCL8zyiYRRLSgPpbJzhdpb98cQWCe5Qr36/9EDRhc\n\t\t\t\t\t\twULr8Z8HJOgONxWQbNnZTPU8Z0lrisOhAbAu3QGk5Km4+6v9o8PQch1zECh7HEZa\n\t\t\t\t\t\tr5NoRY3Ztd9AOTg48jCeyumPUOyk3ZBSt17RfnyCqCuRujbDVCi1WH9+rOW3nBb6\n\t\t\t\t\t\tCgnionTlX4+VFoFbt4CJjGVxZuSczulc6XkpPlJnAvSuhQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SAGE's ebook and reference platform"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SAGE Knowledge"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://shibboleth2.liv.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gilbertson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webmaster@liv.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pretlove"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:T.Pretlove@liverpool.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth2.liv.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-06-29T09:49:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDaDCCAlACCQDWC0umrtoXlDANBgkqhkiG9w0BAQUFADB2MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEQMA4GA1UECAwHRW5nbGFuZDETMBEGA1UEBwwKTWVyc2V5c2lkZTEgMB4GA1UE\n\t\t\t\t\t\tCgwXVW5pdmVyc2l0eSBvZiBMaXZlcnBvb2wxHjAcBgNVBAMMFXNoaWJib2xldGgy\n\t\t\t\t\t\tLmxpdi5hYy51azAeFw0xNTA0MzAwOTUyMTBaFw0yNTA0MjcwOTUyMTBaMHYxCzAJ\n\t\t\t\t\t\tBgNVBAYTAkdCMRAwDgYDVQQIDAdFbmdsYW5kMRMwEQYDVQQHDApNZXJzZXlzaWRl\n\t\t\t\t\t\tMSAwHgYDVQQKDBdVbml2ZXJzaXR5IG9mIExpdmVycG9vbDEeMBwGA1UEAwwVc2hp\n\t\t\t\t\t\tYmJvbGV0aDIubGl2LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\n\t\t\t\t\t\tAQEAvpJmrHAHwvd5VyvTC8IbreA/RC6MAdosUKnleXdlNAztJNzYbrakgxzoKxML\n\t\t\t\t\t\tXo42eybvolKRu7tzjQsOSoYsi+VabKlvRPv6VZbWrBNNXm0YAwu9U5Qam0Q6iJj9\n\t\t\t\t\t\t+dVbV2AzMa59HY0csUhEuucpHwtcx3XjtUPl+h8jaqvRV0YP9GOHpIBXic9EHfIr\n\t\t\t\t\t\tbCiGvX+2GJArbAHGcx40sUN+Uxi2NFZRlz/Ra4HebL3+T1v+963q6J6srCyrb+9p\n\t\t\t\t\t\t1ZtQY7WN6fOeIouVIQb0K4eKUAz1rU/NH/xwBROCqW3Qe03570bDNVKRyMHBbZG5\n\t\t\t\t\t\tlQwmx4FpqHvGBKWH5eQIl8ET+wIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQBLpHce\n\t\t\t\t\t\tzwNxs0oKZMwrHJAip1zEWCvUuJ3Imt5sv81L9MK+BRfmTXw/LkBX8wVBUOZpHJf/\n\t\t\t\t\t\tZCAyT6OuAAyu/2f5XAB1hjWGG22qY3vCrFU2bqOQ9P//sWbZbHv09YM8Mnk8HQWa\n\t\t\t\t\t\t36i3gr2wyaw8ye0Binq8e7ogR3JlG4JErBwnNnFWZNyIhpPc6zPnBcFSkhIQ7LbE\n\t\t\t\t\t\t8SwM7+j8BNPXp5+JNfYWkprHLGpEnp59cXAPsXkkN/15ZwfIgfpKtu1q6uBGe8Qo\n\t\t\t\t\t\tSIk8ozzg9KvEhce6LWuJTSYgUNXkGjl84VhJAMK9ioFkQmdFaCXCs+Vp2bZJovkN\n\t\t\t\t\t\tt8ukc2Dgz1WJXVlP"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "liv.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth2.liv.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2.liv.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth2.liv.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2.liv.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth2.liv.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2.liv.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth2.liv.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2.liv.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "liv.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDaDCCAlACCQDWC0umrtoXlDANBgkqhkiG9w0BAQUFADB2MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEQMA4GA1UECAwHRW5nbGFuZDETMBEGA1UEBwwKTWVyc2V5c2lkZTEgMB4GA1UE\n\t\t\t\t\t\tCgwXVW5pdmVyc2l0eSBvZiBMaXZlcnBvb2wxHjAcBgNVBAMMFXNoaWJib2xldGgy\n\t\t\t\t\t\tLmxpdi5hYy51azAeFw0xNTA0MzAwOTUyMTBaFw0yNTA0MjcwOTUyMTBaMHYxCzAJ\n\t\t\t\t\t\tBgNVBAYTAkdCMRAwDgYDVQQIDAdFbmdsYW5kMRMwEQYDVQQHDApNZXJzZXlzaWRl\n\t\t\t\t\t\tMSAwHgYDVQQKDBdVbml2ZXJzaXR5IG9mIExpdmVycG9vbDEeMBwGA1UEAwwVc2hp\n\t\t\t\t\t\tYmJvbGV0aDIubGl2LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\n\t\t\t\t\t\tAQEAvpJmrHAHwvd5VyvTC8IbreA/RC6MAdosUKnleXdlNAztJNzYbrakgxzoKxML\n\t\t\t\t\t\tXo42eybvolKRu7tzjQsOSoYsi+VabKlvRPv6VZbWrBNNXm0YAwu9U5Qam0Q6iJj9\n\t\t\t\t\t\t+dVbV2AzMa59HY0csUhEuucpHwtcx3XjtUPl+h8jaqvRV0YP9GOHpIBXic9EHfIr\n\t\t\t\t\t\tbCiGvX+2GJArbAHGcx40sUN+Uxi2NFZRlz/Ra4HebL3+T1v+963q6J6srCyrb+9p\n\t\t\t\t\t\t1ZtQY7WN6fOeIouVIQb0K4eKUAz1rU/NH/xwBROCqW3Qe03570bDNVKRyMHBbZG5\n\t\t\t\t\t\tlQwmx4FpqHvGBKWH5eQIl8ET+wIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQBLpHce\n\t\t\t\t\t\tzwNxs0oKZMwrHJAip1zEWCvUuJ3Imt5sv81L9MK+BRfmTXw/LkBX8wVBUOZpHJf/\n\t\t\t\t\t\tZCAyT6OuAAyu/2f5XAB1hjWGG22qY3vCrFU2bqOQ9P//sWbZbHv09YM8Mnk8HQWa\n\t\t\t\t\t\t36i3gr2wyaw8ye0Binq8e7ogR3JlG4JErBwnNnFWZNyIhpPc6zPnBcFSkhIQ7LbE\n\t\t\t\t\t\t8SwM7+j8BNPXp5+JNfYWkprHLGpEnp59cXAPsXkkN/15ZwfIgfpKtu1q6uBGe8Qo\n\t\t\t\t\t\tSIk8ozzg9KvEhce6LWuJTSYgUNXkGjl84VhJAMK9ioFkQmdFaCXCs+Vp2bZJovkN\n\t\t\t\t\t\tt8ukc2Dgz1WJXVlP"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Liverpool (TEST do not use)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.liv.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Liverpool"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:cru.fr:federation:univ-nantes.fr",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@univ-nantes.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:cru.fr:federation:univ-nantes.fr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-02-23T15:56:05Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univ-nantes.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univ-nantes.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.univ-nantes.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-nantes.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-nantes.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Students and staff belonging to University of Nantes"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Etudiants et personnels de l'Universit\u00e9 de Nantes"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Nantes (FRANCE)"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Nantes"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUXhtC9sGfg8MZ1QOlWpmnARmmHMYwDQYJKoZIhvcNAQEF\nBQAwHTEbMBkGA1UEAxMSaWRwLnVuaXYtbmFudGVzLmZyMB4XDTA5MDMzMTA4MTA1\nOVoXDTI5MDMzMTA4MTA1OVowHTEbMBkGA1UEAxMSaWRwLnVuaXYtbmFudGVzLmZy\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAktwRMpbzUDURWbJkTiTj\n24JSlknu7dufbohqxC5S5MDGpRx4kZFZFIy+adMWMV/DhS85ggU059xm4PGdoWSd\nnLfYxWNFma2elqpE4ErVbrRyo66m5wP3Xs2VCQQJqcb9YUM5+8yBU04yXAEPYGUv\nQX4R6F2J4K6l2xFlX95aHycjJoAqFq3EPkBs3B8svjK3DWZAYPQP0LbxI1VGvzDn\nDkl4LrzwOPXTdGuJIQUWULWq1KV/RK9mdTTW7Xm5QBh61U1WQLl3EKJJUD5ziaq0\nKttLIND72IKHWYiU5YgC28J6J31BzI2L/TeKk0jmEJl34G6AJ/T82ulrpLZwzu3o\n1wIDAQABo2swaTBIBgNVHREEQTA/ghJpZHAudW5pdi1uYW50ZXMuZnKGKWh0dHBz\nOi8vaWRwLnVuaXYtbmFudGVzLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBR0\nv7zvoB8/1wVaVqBJiix3/eDmPTANBgkqhkiG9w0BAQUFAAOCAQEAY7x0Byy9iv25\n8QhZ7CAD5B0ewKhgS1UO4wmr5UC9bpCAqLdJ1B0PyMZ1Bx3c/TzGloEBoGfiJLu5\nDXg61rAdqYa4ihIC5hXCpt9l02EWxWXintKDZ07kcG2aama1EBRh0s3usR8QzLyB\ngiEcLiXmysSZgy1k/VAx2R5DaHimMFk9vJkTckprB/mSlB4aFFVtfsk6b6dxf0JY\npF1bmgLeWzeQlAtCz8sNNPwXDvAVbBLLHXnOUa8V9TzhaPlInHHhUs6DLNdGml/9\nfLM8XuyqV7zxR0P8IGEgoEuNDgaBilEU3IeExFo/eOojuKJbQkV9w18Q5cxIzGPR\n9yMUR1nBIg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Nantes"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-nantes.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Nantes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.era-test.lib.ed.ac.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:information.systems@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Information Systems"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Watt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:colin.watt@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Colin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.era-test.lib.ed.ac.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-03-28T16:29:18Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Test digital repository from the University of Edinburgh"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.era-test.lib.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.era-test.lib.ed.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.era-test.lib.ed.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.era-test.lib.ed.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.era-test.lib.ed.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.era-test.lib.ed.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.era-test.lib.ed.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFTCCAf2gAwIBAgIJALOvgJMUhk7DMA0GCSqGSIb3DQEBBQUAMCUxIzAhBgNV\n\t\t\t\t\t\tBAMTGmxhYy1yZXBvLXRlc3Q3LmlzLmVkLmFjLnVrMB4XDTEzMDEyODE1MjA1M1oX\n\t\t\t\t\t\tDTIzMDEyNjE1MjA1M1owJTEjMCEGA1UEAxMabGFjLXJlcG8tdGVzdDcuaXMuZWQu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC5EWuWmRSvs/o3\n\t\t\t\t\t\t6B8gmu0G99ZSTP42sQItX+evSRr++rXjZXVmqG0KqMD3adk8Ocj33u9r9PuxHyr1\n\t\t\t\t\t\tr5TyD0y9nzzm4zMLce4gy+xOWhswFkyJEwcxNxEwWi851g6eczVPoMrunNMijT8m\n\t\t\t\t\t\tk+LLc9wwYd6DtYimue774b4WNQf74/4JBbkzgpcc3himZHd+G07eOeEVa9f00djX\n\t\t\t\t\t\tCzvpoBj4NTc+MCh+cy2Tht1jfnJ+qDimwcalxKrqrh5gpkEKhhqDuae22O0YNvSc\n\t\t\t\t\t\tqn0UmcW8TMMfELxWoTCQqrhjUmj+W81pA3DscKjIBrCw5JO2jx26G7T7aVwup+4F\n\t\t\t\t\t\trxIoMVxFAgMBAAGjSDBGMCUGA1UdEQQeMByCGmxhYy1yZXBvLXRlc3Q3LmlzLmVk\n\t\t\t\t\t\tLmFjLnVrMB0GA1UdDgQWBBSrFc86IEslzFbTxavZOub0iPEckTANBgkqhkiG9w0B\n\t\t\t\t\t\tAQUFAAOCAQEAq8KlygpvbFKXBFSTMZ3LRXa0yaFzmF6O6LnzhxPqBixLAMf0r2p8\n\t\t\t\t\t\tVOodPnPCcxpJb0hb2I334gt8DEk+ZqSKhWXUvtwbzanyIek79mTfs6X0PF4a3RbQ\n\t\t\t\t\t\t1NzqpKPVebeZj1WytH4pbQ99vmkruwlg/gB8QDi1FGL2T8fDLPZ9s7ML//MyRvcI\n\t\t\t\t\t\tV2JsDcGNJie/kRsvOLHgX5UsHXVaCv6sLgbghj7y3YPiuIJP1INYmqdaVyIXOhrb\n\t\t\t\t\t\tRzkx2kzgZA00Wvk+0EvmAXnoxIUZfpugV1Bw17LC7a2MnihRHvndiqmj59snZ9VI\n\t\t\t\t\t\t74PyBeKyItPNiuEYH+2iw3VuHSvz91S6+A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.era-test.lib.ed.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.era-test.lib.ed.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.era-test.lib.ed.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.era-test.lib.ed.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.era-test.lib.ed.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.era-test.lib.ed.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cmu-shib.hosted.exlibrisgroup.com/shib",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cmu-shib.hosted.exlibrisgroup.com/shib",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-09-21T10:10:11Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cardiff Metropolitan University - Primo"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://exlibrisgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ex Libris (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cmu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cmu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cmu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cmu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cmu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://cmu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is an Ex Libris Primo Hosted SP on behalf of Cardiff Metropolitan University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Cardiff Metropolitan University - Primo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAKKaSFTxV8dnMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB2FpbzAwNDEwHhcNMTUwOTA5MTQ1NzE3WhcNMjUwOTA2MTQ1NzE3WjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdhaW8wMDQxMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\t7HenNoKW0sOzOSke2fmV1ttG/lSbImzvmxlxS5EW6o2Nh01usJSdf3ImvVCPEut1\n\t\t\t\t\t\t0Yn2uN/tXs+aU+nL3fyF5jFZCv6E134FkmJ/cWQj+cNWjlrlt0BB2m42Zzy/pdtv\n\t\t\t\t\t\tFAtQ36NfwmAVmhY+ceSktAKu783KGXQ5e9h/BZLHCojYT7vWHVINI0GIQymKJHm7\n\t\t\t\t\t\tHrGXw50/HlCkTVAzKOcnvgmbnQQaPEd4/8OWyn9DfQoICt0PdXLOC5nyBRXfJeaq\n\t\t\t\t\t\t4JjZGPRq4Au4Dxgd0eWnjSnBHM4bscmwea4Pu37yfHdR2ayUmAU4bytT/+j0WdkU\n\t\t\t\t\t\tQQDNkO3GT0742gl3x4iQ4wIDAQABozUwMzASBgNVHREECzAJggdhaW8wMDQxMB0G\n\t\t\t\t\t\tA1UdDgQWBBS3KSf/jmUF/5mPQMRe2U33IJwb/zANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\t0B9MYZK5HPyBkupXmCZ4bcWl/MN7m8CiVNeNqSJIsDvYYJz1jTr2FMIwY+xupjtK\n\t\t\t\t\t\tdDpowahzmGwZaZtgb0PUynPOjZvcYvauSKni5NNii1R3MaGiw4sT7qusccl8aTcb\n\t\t\t\t\t\tV5MRLYCeOvv2R5JA14kmLUko3QVlAi3Vetz/Q60BREl2g1rc5KLsN8vkD8iHlmqt\n\t\t\t\t\t\t6Zh+TeL2kcw9MHTCHhPD7h1u4dEAuq827QzHqcTeJRPIrJOyDbuwTbBT6Xe9roY9\n\t\t\t\t\t\tfIcDUibGOVOFVQkAUqV2gNUJfQgqkfbQGQJjeD3b7zNwTbpMaXwt/LCVNIJaWrwL\n\t\t\t\t\t\tbzjnfQcDrmHF1208OcY8Hw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cmu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cmu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cmu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://cmu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://wsso.vscht.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mares"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "antonin.mares@vscht.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Antonin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://wsso.vscht.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2012-10-22T11:17:38Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/university"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIJAKMDfYjjTNSxMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDXdzc28udnNjaHQuY3owHhcNMTUwODI4MTIyNTMwWhcNMTgwODI3MTIyNTMw\nWjAYMRYwFAYDVQQDEw13c3NvLnZzY2h0LmN6MIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEA4PhQlXne7imNIZ4BCXcA1mqNEdeVrf1G+IyF8LZbGDt83nfN\n3toWixvfE1dFAIB2m2QTlRShMk/rhSYZZ7YAd/9ujpnRg5abNXcOu2EYneJl70rU\nwbIcSuL47hjE0Wt5XOTgw+lIzOmERy7aP/eX4VMrlKo0Zr+3cGuinxCVNmkc914d\nbOoiBnU7w3MwUk0CFSGQ6DqFLdauYs7WoqubEBBAClXBLicEBPU8S2hvsa335NL4\nPUK88cW4tETDU89X6jRpxOMBKdVTDepZ4P1y+cRhbzf3Gl90u/oub/AXRHntwoMD\ngpX8wE7wIY75pFbRMNPfKsu2vZBiu73NSKlOhwIDAQABo2EwXzA+BgNVHREENzA1\ngg13c3NvLnZzY2h0LmN6hiRodHRwczovL3dzc28udnNjaHQuY3ovaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFMqTaylMN+eMOxsB5FGMO+nmXtZUMA0GCSqGSIb3DQEB\nBQUAA4IBAQAI9iwzEXoxwEaWztPrCiq1Q4bTeRRaHBc5E7aIQ9vNeZL3PwbDsorS\nv5y8HOEQmJgfNOyXvuR7bkOQIWS4HgLyMnwhBs5o2UNvaBOORUUUej6N7C4Yzumj\nbbSHKhb7Sw0eukh47Ojn/utVyEDb7DWYqt+fK398r/OszgQpKd0M5e8Rml8wEv3W\n6v/6GSFzctj5DmgQMvtHkwmOHfkdyjFUQkq61cdes3y0hO8wpNM4Jy9NfvFudKto\n5mv/AhMCzv8ZtyMuvpjtCcnr5jR6G5jpVbOnaMT12mF8M1pdcBWS8rg/PzDSVdfp\nwuwwICx8lcu0GWQYTWR2+DVgH2hebKgY"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vscht.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://wsso.vscht.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://wsso.vscht.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://wsso.vscht.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wsso.vscht.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://wsso.vscht.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://wsso.vscht.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://wsso.vscht.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://wsso.vscht.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vscht.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.vscht.cz/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.vscht.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for employees and students of the University of Chemistry and Technology in Prague"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance a studenty Vysok\u00e9 \u0161koly chemicko-technologick\u00e9 v Praze"
                  }
                ],
                "logo": [
                  {
                    "text": "https://wsso.vscht.cz/logo_vscht_40px.png",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "40"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Chemistry and Technology, Prague"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Vysok\u00e1 \u0161kola chemicko-technologick\u00e1 Praze"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIJAKMDfYjjTNSxMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDXdzc28udnNjaHQuY3owHhcNMTUwODI4MTIyNTMwWhcNMTgwODI3MTIyNTMw\nWjAYMRYwFAYDVQQDEw13c3NvLnZzY2h0LmN6MIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEA4PhQlXne7imNIZ4BCXcA1mqNEdeVrf1G+IyF8LZbGDt83nfN\n3toWixvfE1dFAIB2m2QTlRShMk/rhSYZZ7YAd/9ujpnRg5abNXcOu2EYneJl70rU\nwbIcSuL47hjE0Wt5XOTgw+lIzOmERy7aP/eX4VMrlKo0Zr+3cGuinxCVNmkc914d\nbOoiBnU7w3MwUk0CFSGQ6DqFLdauYs7WoqubEBBAClXBLicEBPU8S2hvsa335NL4\nPUK88cW4tETDU89X6jRpxOMBKdVTDepZ4P1y+cRhbzf3Gl90u/oub/AXRHntwoMD\ngpX8wE7wIY75pFbRMNPfKsu2vZBiu73NSKlOhwIDAQABo2EwXzA+BgNVHREENzA1\ngg13c3NvLnZzY2h0LmN6hiRodHRwczovL3dzc28udnNjaHQuY3ovaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFMqTaylMN+eMOxsB5FGMO+nmXtZUMA0GCSqGSIb3DQEB\nBQUAA4IBAQAI9iwzEXoxwEaWztPrCiq1Q4bTeRRaHBc5E7aIQ9vNeZL3PwbDsorS\nv5y8HOEQmJgfNOyXvuR7bkOQIWS4HgLyMnwhBs5o2UNvaBOORUUUej6N7C4Yzumj\nbbSHKhb7Sw0eukh47Ojn/utVyEDb7DWYqt+fK398r/OszgQpKd0M5e8Rml8wEv3W\n6v/6GSFzctj5DmgQMvtHkwmOHfkdyjFUQkq61cdes3y0hO8wpNM4Jy9NfvFudKto\n5mv/AhMCzv8ZtyMuvpjtCcnr5jR6G5jpVbOnaMT12mF8M1pdcBWS8rg/PzDSVdfp\nwuwwICx8lcu0GWQYTWR2+DVgH2hebKgY"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Chemistry and Technology Prague"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Vysok\u00e1 \u0161kola chemicko-technologick\u00e1 Praze"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vscht.cz/?jazyk=en"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vscht.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Chemistry and Technology Prague"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Vysok\u00e1 \u0161kola chemicko-technologick\u00e1 Praze"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.fife.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Campbell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paulcampbell@fife.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smith"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alastairsmith@fife.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alastair"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.fife.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-08-21T13:01:31Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.fife.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.fife.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.fife.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.fife.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.fife.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.fife.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fife.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "student.fife.ac.uk"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Fife College"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.fife.ac.uk/Style%20Library/Images/ASC/logo.png",
                    "height": "58",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "191"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Fife College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAMSH7t+3wR8HvHhTV60wiQbeGyS9MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMBkxFzAVBgNVBAMMDmlkcC5maWZlLmFjLnVrMB4XDTE1MDgxODEzNTUzN1oX\n\t\t\t\t\t\tDTM1MDgxODEzNTUzN1owGTEXMBUGA1UEAwwOaWRwLmZpZmUuYWMudWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCZUZMO2Jq43iFJUkENA3C2HAUa5D6h\n\t\t\t\t\t\tSSA13NIFOO2vD+8w+UCruVl70Q6dL8J8oamGnPmuXEX6j7s8xuPXh1jW8Bgg9qCf\n\t\t\t\t\t\t8oFn97naV7z4Q0v9wz7yrFZdhV695TwuuPqiSvfpQhV3fRDCAM8v2T0FLYnN6e2K\n\t\t\t\t\t\t0EuuN8nnXdIeTnUORTKuDSW8tUEo+Aifoq8w1Xxr4t63sTLZf7H2/S+RYS3llzT+\n\t\t\t\t\t\tlyeUFeN51KWTegrWBQ0e4y+v5p7waYr4CtgO652TlChL3zzl4dXi3ebW8oPwHfK6\n\t\t\t\t\t\tfnw7gTLNLeMe/X4IE/UBruP5egKmB7CPpFRaBWdKb3MeN6ha854tWkqRAgMBAAGj\n\t\t\t\t\t\tYzBhMB0GA1UdDgQWBBS4nOBhTboXA7kKfrJ4asvwp9dcajBABgNVHREEOTA3gg5p\n\t\t\t\t\t\tZHAuZmlmZS5hYy51a4YlaHR0cHM6Ly9pZHAuZmlmZS5hYy51ay9pZHAvc2hpYmJv\n\t\t\t\t\t\tbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAOVr86ThzRpiWYDEMTRaPc/qNUwUCu8+x\n\t\t\t\t\t\tVJ/72p/LNTKMapIJZM/riSbi6E0sCiGRmzVSYLISMXVOEdTQIH0EDTuxHd8HBQKP\n\t\t\t\t\t\tYNm4w51czi9Echtrb1d0ARGM/E8w09xv2pRDmf1VSIwAFjFxpzw765sFt13TD9sO\n\t\t\t\t\t\tX/jLji5/T0vcSRlwCI+xCAkFiGcECK/jBeA2DkgzqRecblufds5ncWZegy6Q1qXc\n\t\t\t\t\t\tZE6B8vB7q83XEaN04YQ3MoQuLZvAK8MAKI2XS5pOIysDZiLFXdHoW3ZcBT13NB3F\n\t\t\t\t\t\td4dRnvjAIVLYNByna61xG/WJVi5siHSmGZBoGt7qEl0LBQqv6V0txw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAL6RCJkK1lwbxWiAZtEZ4gUt74gZMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMBkxFzAVBgNVBAMMDmlkcC5maWZlLmFjLnVrMB4XDTE1MDgxODEzNTUzNVoX\n\t\t\t\t\t\tDTM1MDgxODEzNTUzNVowGTEXMBUGA1UEAwwOaWRwLmZpZmUuYWMudWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCtZj1WvUnkQUXPjTFrK10RUW4F5TS1\n\t\t\t\t\t\t0aaHRMl/bEHW2xugFMFRlYz/61d6DQ8J+g3vZMqLE42s9J8e6tYeORVQGVoeLkUm\n\t\t\t\t\t\tAb8NB1jGbg4Pst/DNLiJYTQHWl6RemiNjVNgDfMEbr6Uh/AYdKtH4H3DTOIBWzLD\n\t\t\t\t\t\tkJ7KwkC4pOmBs1rx3DjppTvmltUM+8oL1v/h5jw9r646gVjCkgrnquumbYUZoTSs\n\t\t\t\t\t\tApYExLeDmttSVEt080YpAF7b6LSAP5vBKdhbR/SZr0cRyGX9W/0vKW/6GxknM1Ih\n\t\t\t\t\t\tq22SklWPZMW4ayVEtm38JLPifvtlKprZCiVgcMbH4YdsLJRdQI3cLcoHAgMBAAGj\n\t\t\t\t\t\tYzBhMB0GA1UdDgQWBBSOGtYQOZyJe7EAgJ0oGjUfHiE7GDBABgNVHREEOTA3gg5p\n\t\t\t\t\t\tZHAuZmlmZS5hYy51a4YlaHR0cHM6Ly9pZHAuZmlmZS5hYy51ay9pZHAvc2hpYmJv\n\t\t\t\t\t\tbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAFD3TLoOSuo8WYapOqpR4UinnB+dks5ko\n\t\t\t\t\t\tVqe4KDFX8S4Q/1GpG+GOEvXOqFE1eir+XIX2oLYU+514FxJOGlPPJsG4ojVMmj/F\n\t\t\t\t\t\t6b8vWbjAHkUQfMgVVxT/G8kFzn9z5pm2/EGtC1xbP8Yub+hzL6B9tJzKMLu2MP1M\n\t\t\t\t\t\tBTvY1FM/OG/O+piRz+8OtKkwXgGf7B3uYZHZDV80KUK+E/laktIJJR3IEL/HYG5o\n\t\t\t\t\t\tVZvWsWhxkzf2C/EoORlAR/bdf/jHdVqJos/b+pDYixhpuYggrUqUEHzo2yCFxh57\n\t\t\t\t\t\tm9piTkbs/Wlkejr7HQmExiq37uFjZR62Pyp9nzTj20VFz8Pdca7G0Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIURu5IcL5iFuwZvk3l1cGg1/CZ/eYwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwGTEXMBUGA1UEAwwOaWRwLmZpZmUuYWMudWswHhcNMTUwODE4MTM1NTM2WhcN\n\t\t\t\t\t\tMzUwODE4MTM1NTM2WjAZMRcwFQYDVQQDDA5pZHAuZmlmZS5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIEI8ZGZ4tKFlRJvAocI8HKyfVJ0Xvwn\n\t\t\t\t\t\t4SGPTIJiB3+mha+HHizAd9qpwkpXivXKZHMBFVksfuPgQR9qIurHbUzPiBxCsdM/\n\t\t\t\t\t\twuwwJijyL1Im5thCFJkksWsod+rvlvvVVt1GI83D3inbKg116J0wKKg4TmhXB9QM\n\t\t\t\t\t\t0o1tB5d+XT9sYTst52PJT5bXI08awZou+z6To2aE2HgXLsqQTq88CZKSESCJaT8j\n\t\t\t\t\t\trVONzjG6Q87qlw8wH2JelG017wAPDLvcwBQhQNCp3V/j0ttfG0XtEuX4/zqVzD07\n\t\t\t\t\t\tl7lzUsIHPgXr+t27Z7Zx6RJwjgXBriTjEuz4UIw1tgbUDf6ooyxXH8MCAwEAAaNj\n\t\t\t\t\t\tMGEwHQYDVR0OBBYEFEyL2dSl3fdiPDu8eXNtSrrRYozMMEAGA1UdEQQ5MDeCDmlk\n\t\t\t\t\t\tcC5maWZlLmFjLnVrhiVodHRwczovL2lkcC5maWZlLmFjLnVrL2lkcC9zaGliYm9s\n\t\t\t\t\t\tZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQApwpwY0+dd+6MB3HLP+uXFHvHOatbRLjgi\n\t\t\t\t\t\tF3ox1F0Fgj9tAwER4LC1NSzap7kvVJgX85+owEkOcbWzrccZKu1vL3qfxMcRfz+G\n\t\t\t\t\t\tzav5Qr0R59j3agVwVUCPAq7ZXkCZhtwZv3REPf4Z5oHmGwCHGCndHVYtrm8rbRc8\n\t\t\t\t\t\tYCVw1iGpRQylmhpZrZdOAfDAGLDlMf4Ls3FAAg97IKhVBaxKj2RX4cnT/L70qpdB\n\t\t\t\t\t\t7qRSPgZKsX/P0D5zgX1ul8I0WaKhlb4q/eWw+p0EtJHgL+R6vO9mu+FalYW+CtXW\n\t\t\t\t\t\tVg3hbcA7wQhdcxyFQemk4H24VNtDXOP1KQOm5Gd2EgLi+OaTo3/Z"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Fife College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fife.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Fife College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.wpi.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jbanning@wpi.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jesse Banning"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "aej@wpi.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Allan E. Johannesen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@wpi.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WPI Computer Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.wpi.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.wpi.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.wpi.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUZcDEUesMNCAxqzW1X3lCXV3BW40wDQYJKoZIhvcNAQEF\nBQAwFjEUMBIGA1UEAxMLaWRwLndwaS5lZHUwHhcNMTEwMzA0MTgyOTIwWhcNMzEw\nMzA0MTgyOTIwWjAWMRQwEgYDVQQDEwtpZHAud3BpLmVkdTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAIAeq3YyX5BKUHSpXBIrHDlzrk2KnU9+rGTHX0yR\nt5qTDBYtMGZDwGEDW9iTTRVKpEUQRCLUdmYQGe10Tp4Wwwy8e3uBNP6CBUUO+uZ9\nv558CIpO8vknk+vRu3Rdxqryp34HWscbZZb8uAQjOwnFZ3eBJVTIEugeSSZVpor/\nxzI+tWYO2IurI3LyyN+aqZi+z2AlRxq7YR4nVDKfR2sTRe6SXYPrcpXrYYXMcKGY\n4gRXhhI5at0/FLT38DA6zxYE2PRLJsT0ViPdoacmfMrST7d5XVxSSuaqjPi0I7eX\nC67mjYNOL8Cd4HQNoodb4TM7iIYrtpZKGyroNeJ3i+MzM+ECAwEAAaNdMFswOgYD\nVR0RBDMwMYILaWRwLndwaS5lZHWGImh0dHBzOi8vaWRwLndwaS5lZHUvaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFOBwGRx8eH0sfoAq2pCao9AhQ66cMA0GCSqGSIb3\nDQEBBQUAA4IBAQAoQ/w1GrFkPfr0WPPk29OnXWRDFz1Y6V2mqn4EtOX7IniBWlwA\nZlQ75SrRTmx6rRSO/1kaf//5YIRC4QmWbyXwGUwvQL+OlM1BxUohtQ/12U/fAtSH\n1Dz1U7cIrnd+iLXq0GgXlMie0m6i570WJXWWDK1JYnCCa36JxfMdC8xMNwglNoSM\nWxgWsGCPSXCPTg+lGT7Hd8FID6VpnOWMrKQkdPga8xDre2YUmiIVMS9FEaSZL+Tj\noE+cFFxg0TXajhapymP2fMY1bGHiM0wThqXsaeB2MctDByiX1Cl3qPwMtBUEEI1w\nJJHUiO7JFs58BFW6Cbx0vbt8hmKGvdpkMBea"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wpi.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.wpi.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.wpi.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.wpi.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.wpi.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.wpi.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wpi.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.wpi.edu"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.wpi.edu/Images/template/wpilogo.gif",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "489"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Worcester Polytechnic Institute"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUZcDEUesMNCAxqzW1X3lCXV3BW40wDQYJKoZIhvcNAQEF\nBQAwFjEUMBIGA1UEAxMLaWRwLndwaS5lZHUwHhcNMTEwMzA0MTgyOTIwWhcNMzEw\nMzA0MTgyOTIwWjAWMRQwEgYDVQQDEwtpZHAud3BpLmVkdTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAIAeq3YyX5BKUHSpXBIrHDlzrk2KnU9+rGTHX0yR\nt5qTDBYtMGZDwGEDW9iTTRVKpEUQRCLUdmYQGe10Tp4Wwwy8e3uBNP6CBUUO+uZ9\nv558CIpO8vknk+vRu3Rdxqryp34HWscbZZb8uAQjOwnFZ3eBJVTIEugeSSZVpor/\nxzI+tWYO2IurI3LyyN+aqZi+z2AlRxq7YR4nVDKfR2sTRe6SXYPrcpXrYYXMcKGY\n4gRXhhI5at0/FLT38DA6zxYE2PRLJsT0ViPdoacmfMrST7d5XVxSSuaqjPi0I7eX\nC67mjYNOL8Cd4HQNoodb4TM7iIYrtpZKGyroNeJ3i+MzM+ECAwEAAaNdMFswOgYD\nVR0RBDMwMYILaWRwLndwaS5lZHWGImh0dHBzOi8vaWRwLndwaS5lZHUvaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFOBwGRx8eH0sfoAq2pCao9AhQ66cMA0GCSqGSIb3\nDQEBBQUAA4IBAQAoQ/w1GrFkPfr0WPPk29OnXWRDFz1Y6V2mqn4EtOX7IniBWlwA\nZlQ75SrRTmx6rRSO/1kaf//5YIRC4QmWbyXwGUwvQL+OlM1BxUohtQ/12U/fAtSH\n1Dz1U7cIrnd+iLXq0GgXlMie0m6i570WJXWWDK1JYnCCa36JxfMdC8xMNwglNoSM\nWxgWsGCPSXCPTg+lGT7Hd8FID6VpnOWMrKQkdPga8xDre2YUmiIVMS9FEaSZL+Tj\noE+cFFxg0TXajhapymP2fMY1bGHiM0wThqXsaeB2MctDByiX1Cl3qPwMtBUEEI1w\nJJHUiO7JFs58BFW6Cbx0vbt8hmKGvdpkMBea"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Worcester Polytechnic Institute"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wpi.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Worcester Polytechnic Institute"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://careergate.student.uu.se/simplesaml/module.php/saml/sp/metadata.php/gl_gateway",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Petersen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "morten@graduateland.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Morten"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://careergate.student.uu.se/simplesaml/module.php/saml/sp/metadata.php/gl_gateway",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "http://careergate.student.uu.se/simplesaml/module.php/saml/sp/saml2-logout.php/gl_gateway",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UU CareerGate \u00e4r en karri\u00e4rportal f\u00f6r Uppsala universitets studenter, h\u00e4r kan du s\u00f6ka praktikplatser, jobb och anm\u00e4la dig till Karri\u00e4revent etc."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UU CareerGate is a Career Portal for students at Uppsala University. Here you can find Internships, jobs and registrar for Career Events etc."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UU CareerGate"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UU CareerGate"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://careergate.student.uu.se/simplesaml/module.php/saml/sp/saml2-acs.php/gl_gateway",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "http://careergate.student.uu.se/simplesaml/module.php/saml/sp/saml1-acs.php/gl_gateway",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "http://careergate.student.uu.se/simplesaml/module.php/saml/sp/saml2-acs.php/gl_gateway",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "http://careergate.student.uu.se/simplesaml/module.php/saml/sp/saml1-acs.php/gl_gateway/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:profiles:holder-of-key:SSO:browser",
              "location": "http://careergate.student.uu.se/simplesaml/module.php/saml/sp/saml2-acs.php/gl_gateway",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.sciencespobordeaux.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rouger"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "p.rouger@sciencespobordeaux.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.sciencespobordeaux.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2011-04-29T13:03:14Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sciencespobordeaux.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sciencespobordeaux.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.sciencespobordeaux.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sciencespobordeaux.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "scpobx.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.sciencespobordeaux.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sciences Po Bordeaux"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sciences Po Bordeaux"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEuzCCA6OgAwIBAgIRAJ6cVoL9srwAECkklTq3u2gwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDAxMDkwMDAwMDBaFw0xNzAxMDgyMzU5NTlaMEcxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEiMCAGA1UEAxMZaWRwLnNjaWVu\nY2VzcG9ib3JkZWF1eC5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAP3E230Ei838R9qQO32a5tkzyJemr9fmhArIZKTQsQpr9TwEPoIyaDYTQELhcuMG\nbKEojJ716N+8hRNhghNFKGLMO0lGE0TZyxBC28MmttMmad6TLtOEZFv9Py/TTFrq\npgOy5v0Vb3v/81JwMYT1U9gTU256OSOZg9NSZUxsNbEbyibq0icxtzDceOotn7Bz\npBTjUtOxZ00igLSoWS7SLPZUyjX2jfgefrDOtZ0/hxrLo3Klx7YC2uJlrrCVZA0s\n87rMSCt0Ra7ECME4JGdNxs5l9EpjGvqvi7zqV9Sg9RtsWKc/Y+me7r7B+SVz3QoY\npSrgKTSG316/JcEYf6GeFkUCAwEAAaOCAbEwggGtMB8GA1UdIwQYMBaAFAy9k2gM\n896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBT0hWtM6+5tMUzDBzmPbfKO5mK3DzAO\nBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcD\nAQYIKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEw\nOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJF\nTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8v\nY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYa\naHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwXwYDVR0RBFgwVoIZaWRwLnNjaWVu\nY2VzcG9ib3JkZWF1eC5mcoIbbGRhcDIuc2NpZW5jZXNwb2JvcmRlYXV4LmZyghxz\ncnZpZHAuc2NpZW5jZXNwb2JvcmRlYXV4LmZyMA0GCSqGSIb3DQEBBQUAA4IBAQCU\nORaZfIPKIh9EZsSb+jKw2rZaU8E0l1j9RhtphhaxcXJND0CgjYdplldUDghacRk9\naYG3rlC6KLcGsUThOx70QbBZrX3MCYkhjNzRnxwm07aj/nV/GB5jYlgK7aMAT7PB\nqiZBvL/hVr86AIxZvzIzphIpy9Qq4GEnItVFhGOycQklELgKWE0nkfAqPfVEa6et\n6/0VcjuF7/2icJmG8FguWm8Bhjc7++RNdCN+XW0GMSNb7cJNIdrhV9pDPg9YUUuW\nxeoFJ3AMgEwyT4aPKYtJjFlKbGLLtW/CicdeXeWR7THWoA8uDWm1AnilOO6+YgM2\nBplU9dtwphlM6oz1pTHl"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEkDCCA3igAwIBAgIRAJzjTT6bg4+QhDI8IGescp8wDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xMTAyMDgwMDAwMDBaFw0xNDAyMDcyMzU5NTlaMGExCzAJBgNV\nBAYTAkZSMQ8wDQYDVQQHEwZQZXNzYWMxHTAbBgNVBAoTFFNjaWVuY2VzIFBvIEJv\ncmRlYXV4MSIwIAYDVQQDExlpZHAuc2NpZW5jZXNwb2JvcmRlYXV4LmZyMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0y1w1SapxrGmZ0kcubJtxA+a+DH/\nnv0R2Qg4WdacENkzIyNVOdzrwYzHyo4Qux1M+mpWF+0A34ILNTtZyD09uRoYnj5F\n7JmY6Rdd3sjliL+b8V0+gr68Hu6g6c/KD+VtYuW8OiapKLWcP6dHHSkLPt7Aipb+\nBaYAeV7zsKergliVKn9vdcTN4qFSYbZLsFCCq+TLWcb5Zt24soRf0Aig4ATEMO5X\nz8qZAHShZ/83yR5Ql5ChhnaH95ldUhyfVcbC2lcOUGol4UKIr9Ndl3WA2LRE4Y+Y\nslyGbVOt9v6hk3cAsJgw7T3K5E+AIi6SuL7k6p3x/yuiHquRUZjT8Owj3wIDAQAB\no4IBbDCCAWgwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH6pDjue0wHQYDVR0O\nBBYEFLJC1NFm9gAudgj7xxJCW095Qwl1MA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMB\nAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAYBgNVHSAEETAP\nMA0GCysGAQQBsjEBAgIdMDoGA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNz\nLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1Bggr\nBgEFBQcwAoYpaHR0cDovL2NydC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5j\ncnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9vY3NwLnRjcy50ZXJlbmEub3JnMCQGA1Ud\nEQQdMBuCGWlkcC5zY2llbmNlc3BvYm9yZGVhdXguZnIwDQYJKoZIhvcNAQEFBQAD\nggEBABM5crkQbXiRohcjJgae3y9MPJZcWT5EKLKVc751iA8KXo3wVF8rdwVhESQ8\ncmd2BV7qYQBh19mPfWA9A3nNRhc92ElackeBhF9nOQAoeiWCtTwyqQFlY+Sy9t7/\no+wpprhtqiBgLIVTduiDGGnlKasbWG9Gu5dX9SZ99YSRrYKN8bJAnyKgnhhPLpcz\nYKnhDvtia42oMyL42dNmMt3WC6fgacHKK5gn854jExb1zxOZ0EZ5Se0nWmUift1I\nxr6/zUxLKQsLBvsoMidrpEdtqp9m/OkQh5w2yKN4SzxuPzZsfMWK5p/jEgm7MMY5\nqdkYclgdqLgBlFr/yaGI1mcNQMY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Sciences Po Bordeaux"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sciencespobordeaux.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Sciences Po Bordeaux"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.nottingham.edu.cn/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itservicedesk@nottingham.edu.cn"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itservicedesk@nottingham.edu.cn"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.nottingham.edu.cn/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-03-23T11:38:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEHDCCAwQCCQDij8AO1ZyMHzANBgkqhkiG9w0BAQUFADCBzzELMAkGA1UEBhMC\n\t\t\t\t\t\tQ04xETAPBgNVBAgTCFpoZWppYW5nMQ8wDQYDVQQHEwZOaW5nYm8xLzAtBgNVBAoT\n\t\t\t\t\t\tJlVuaXZlcnNpdHkgb2YgTm90dGluZ2hhbSBOaW5nYm8sIENoaW5hMR0wGwYDVQQL\n\t\t\t\t\t\tExRJbmZvcm1hdGlvbiBTZXJ2aWNlczEeMBwGA1UEAxMVaWRwLm5vdHRpbmdoYW0u\n\t\t\t\t\t\tZWR1LmNuMSwwKgYJKoZIhvcNAQkBFh1pdC1zZXJ2aWNlc0Bub3R0aW5naGFtLmVk\n\t\t\t\t\t\tdS5jbjAeFw0xMTA1MTkwODM0NTVaFw0zMTA1MTQwODM0NTVaMIHPMQswCQYDVQQG\n\t\t\t\t\t\tEwJDTjERMA8GA1UECBMIWmhlamlhbmcxDzANBgNVBAcTBk5pbmdibzEvMC0GA1UE\n\t\t\t\t\t\tChMmVW5pdmVyc2l0eSBvZiBOb3R0aW5naGFtIE5pbmdibywgQ2hpbmExHTAbBgNV\n\t\t\t\t\t\tBAsTFEluZm9ybWF0aW9uIFNlcnZpY2VzMR4wHAYDVQQDExVpZHAubm90dGluZ2hh\n\t\t\t\t\t\tbS5lZHUuY24xLDAqBgkqhkiG9w0BCQEWHWl0LXNlcnZpY2VzQG5vdHRpbmdoYW0u\n\t\t\t\t\t\tZWR1LmNuMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtRiXnUTiNrTR\n\t\t\t\t\t\t/qHVEWqV50864Thqs3JI1frOi1sjQbaDCkh73hSsNdzxzg5FUdjdZfVrLeh7MVUf\n\t\t\t\t\t\tYjp0wWCMvrJDvaZwWgl2mMb2/pvZTkEvTmIwDL/n+G4oyWoUkEjXIrtui4Ie9bAT\n\t\t\t\t\t\t/tBBN2I+U3c0QTM4DUP21EqjhxwcV3D6gsbGAcay3k5ukpwOgrz30MFqb0b30baj\n\t\t\t\t\t\tErqpvWJMVjjV4n8koW4Xa8nt60uwHSbIzr6Fs+cqKgELxjwQ73jI0UfhbkMiu4T+\n\t\t\t\t\t\t41qg80xlxaXOo1UuAhSxGzinL9sPcQzrKYdBEsw+vYPt8SvbT0kdXjr6Bp997HqL\n\t\t\t\t\t\tpHMmuBrSjQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCX8yxPXzLmOpULOrxk9gOb\n\t\t\t\t\t\tuvUNnmaqugXeJU50AwNSvm1foJopXUke/h8wJBfQ3f/WNgW65Q9AStaT3UDdmDX/\n\t\t\t\t\t\t46g4PneVj7FCsdTMBg79e6uQoraSUb3ngO6hAo0ZBn1xi6Y0a2IBo+H7ln3a10eN\n\t\t\t\t\t\tprXFgovDfO86hcltDlYDOCTdSG/bWPeqLU0wBaB4oCPm/VsZTx4gg066UAa9HJkp\n\t\t\t\t\t\t3G1n/aMnGCwRrlQ4jfISBC5nsfksXem8w6Ur+bN2NUo7igMiANRnKJzJgKnT518Z\n\t\t\t\t\t\tjINg8Q+dQ+hdfSPa4BUC1LiOxbp8IdOkfbG5gtpnANO1Kw2HXWTBakjy+VjrejZp"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nottingham.edu.cn"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.nottingham.edu.cn:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nottingham.edu.cn:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.nottingham.edu.cn/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.nottingham.edu.cn/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.nottingham.edu.cn/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.nottingham.edu.cn/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.nottingham.edu.cn:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nottingham.edu.cn:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nottingham.edu.cn"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEHDCCAwQCCQDij8AO1ZyMHzANBgkqhkiG9w0BAQUFADCBzzELMAkGA1UEBhMC\n\t\t\t\t\t\tQ04xETAPBgNVBAgTCFpoZWppYW5nMQ8wDQYDVQQHEwZOaW5nYm8xLzAtBgNVBAoT\n\t\t\t\t\t\tJlVuaXZlcnNpdHkgb2YgTm90dGluZ2hhbSBOaW5nYm8sIENoaW5hMR0wGwYDVQQL\n\t\t\t\t\t\tExRJbmZvcm1hdGlvbiBTZXJ2aWNlczEeMBwGA1UEAxMVaWRwLm5vdHRpbmdoYW0u\n\t\t\t\t\t\tZWR1LmNuMSwwKgYJKoZIhvcNAQkBFh1pdC1zZXJ2aWNlc0Bub3R0aW5naGFtLmVk\n\t\t\t\t\t\tdS5jbjAeFw0xMTA1MTkwODM0NTVaFw0zMTA1MTQwODM0NTVaMIHPMQswCQYDVQQG\n\t\t\t\t\t\tEwJDTjERMA8GA1UECBMIWmhlamlhbmcxDzANBgNVBAcTBk5pbmdibzEvMC0GA1UE\n\t\t\t\t\t\tChMmVW5pdmVyc2l0eSBvZiBOb3R0aW5naGFtIE5pbmdibywgQ2hpbmExHTAbBgNV\n\t\t\t\t\t\tBAsTFEluZm9ybWF0aW9uIFNlcnZpY2VzMR4wHAYDVQQDExVpZHAubm90dGluZ2hh\n\t\t\t\t\t\tbS5lZHUuY24xLDAqBgkqhkiG9w0BCQEWHWl0LXNlcnZpY2VzQG5vdHRpbmdoYW0u\n\t\t\t\t\t\tZWR1LmNuMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtRiXnUTiNrTR\n\t\t\t\t\t\t/qHVEWqV50864Thqs3JI1frOi1sjQbaDCkh73hSsNdzxzg5FUdjdZfVrLeh7MVUf\n\t\t\t\t\t\tYjp0wWCMvrJDvaZwWgl2mMb2/pvZTkEvTmIwDL/n+G4oyWoUkEjXIrtui4Ie9bAT\n\t\t\t\t\t\t/tBBN2I+U3c0QTM4DUP21EqjhxwcV3D6gsbGAcay3k5ukpwOgrz30MFqb0b30baj\n\t\t\t\t\t\tErqpvWJMVjjV4n8koW4Xa8nt60uwHSbIzr6Fs+cqKgELxjwQ73jI0UfhbkMiu4T+\n\t\t\t\t\t\t41qg80xlxaXOo1UuAhSxGzinL9sPcQzrKYdBEsw+vYPt8SvbT0kdXjr6Bp997HqL\n\t\t\t\t\t\tpHMmuBrSjQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCX8yxPXzLmOpULOrxk9gOb\n\t\t\t\t\t\tuvUNnmaqugXeJU50AwNSvm1foJopXUke/h8wJBfQ3f/WNgW65Q9AStaT3UDdmDX/\n\t\t\t\t\t\t46g4PneVj7FCsdTMBg79e6uQoraSUb3ngO6hAo0ZBn1xi6Y0a2IBo+H7ln3a10eN\n\t\t\t\t\t\tprXFgovDfO86hcltDlYDOCTdSG/bWPeqLU0wBaB4oCPm/VsZTx4gg066UAa9HJkp\n\t\t\t\t\t\t3G1n/aMnGCwRrlQ4jfISBC5nsfksXem8w6Ur+bN2NUo7igMiANRnKJzJgKnT518Z\n\t\t\t\t\t\tjINg8Q+dQ+hdfSPa4BUC1LiOxbp8IdOkfbG5gtpnANO1Kw2HXWTBakjy+VjrejZp"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Nottingham Ningbo, China"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nottingham.edu.cn/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Nottingham"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.ate.uppfoljning.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.ate.uppfoljning.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ate.uppfoljning.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.ate.uppfoljning.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ate.uppfoljning.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ate.uppfoljning.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ate.uppfoljning.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.ate.uppfoljning.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.ate.uppfoljning.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.ate.uppfoljning.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.ate.uppfoljning.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.ate.uppfoljning.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.ate.uppfoljning.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.ate.uppfoljning.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIJAM50CTo8vcWjMA0GCSqGSIb3DQEBBQUAMCcxJTAjBgNV\nBAMTHHd3dy5hdGUudXBwZm9sam5pbmcubGFkb2suc2UwHhcNMTUwOTE1MTk0OTA2\nWhcNMjUwOTEyMTk0OTA2WjAnMSUwIwYDVQQDExx3d3cuYXRlLnVwcGZvbGpuaW5n\nLmxhZG9rLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1xaVe7fM\nwH15zllNOZkwnvkI5vmNBIWmFFXGx+fgK5aoJhYmDc3c7eCotLTXnzJsCeFpelIM\nMfYBHu0EAfTBWi4/WfQz4yRXQit0JfO1shurGQFeKe4kMTxnVf+BrJSvu/kAHitE\nt4pg9OhhgyMnMaOOON81W31XVK793Wi1B6wRWNtedK1R6InPGsBaW+/1ef4O7d7u\nsgJZBnZw+zSyOeP88cQNyTEU9eiR98i3Vzg7D0gB4u24Q3U6L3ioyVXGOj+IJNC7\nJsO7cQZUisj1yKgNEskL028HPPMzEXccOkAKsT313bHNF/jRI8bUAuh+S9CoEnBN\n3xL1RrWJU8K6MQIDAQABo3cwdTBUBgNVHREETTBLghx3d3cuYXRlLnVwcGZvbGpu\naW5nLmxhZG9rLnNlhitodHRwczovL3d3dy5hdGUudXBwZm9sam5pbmcubGFkb2su\nc2UvZ3VpLXNwMB0GA1UdDgQWBBT1BkMstixnC+ab1uCMPT25Kyzx0jANBgkqhkiG\n9w0BAQUFAAOCAQEAxxI4Vbl6i68RqbvTGKt58pZYkk/dP1JyeyDraZPY6KBC7rgd\nvgm580B7g3m24kicZbMiMCj0z3GxyxoEpgQuP8ESQk+S1NRZzVqeX0jvGvozlIOf\n1k7asGDKTqZP1c+y260sWuuzU/VZIH/p+qJmXKtK8YX95ArVvxZr2yjLspQfOLK5\nOqTR2DKWzLbkJQcG5hDnQ/EYa+OTbxp6UKeYQ2OScriCAakOkRntxMk6jrxg4b0+\nlX8dwmg8Mp9BuT1SxYDh3mV5JQMPzBT65+h8NAt3Df7p6rmfQeTzy92hMI9perKd\nDEEdI94A1MM6JIppqwHkwWgzUQo03hBtc1ypuQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.ate.uppfoljning.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ate.uppfoljning.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.ate.uppfoljning.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ate.uppfoljning.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ate.uppfoljning.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ate.uppfoljning.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ate.uppfoljning.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.ate.uppfoljning.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.ate.uppfoljning.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.ate.uppfoljning.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-04.ladok.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-04.ladok.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;04"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;04"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-04.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-04.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAL3TXy/wwu+RMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wNC5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTM0MzE0WhcNMjQx\nMDA0MTM0MzE0WjAhMR8wHQYDVQQDExZsYWRvazMtMDQubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzH1KJxI0E4cqpUL1IkUo8d85\n7ApTkh9nye8PEwXbhDKPa7hc0n+Kx3S47TxMoBqurFeXizCcH0sbpMr1z+HozfgE\nENm3RlVjiGQ0wtHYbYv+cdw7rmnf09l1OtG1qqpbeAKyouKd8s0BU6lC3lvRCKmi\nJX+1VX1/YOts3FFlmrs/Pcl035joPzPJIFIIJpr2KPMItqOJLuyQkPohKKM3j8js\n1jicg6MrKWWaVd0BNAUacAUN991KjVW05Q3+QWVgNfhTifTHLcS7Bl0V5TujRTPR\ng4UvFm1y5a18Q5/97aB9IirlZVAAhGnrQlLcSy3Uap0UhM/T1nD5OVn/5797BwID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMDQubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0wNC5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUPPx6zb2rYA7RRQos62PossCqg10wDQYJKoZIhvcNAQEFBQADggEB\nAETFnez41ZpCRZN2iCR1m7X2EK6qWOdiqB2VtAVyxmLHwUk0Odj6/56T2S7+EDCW\nfNhDVQ05fUcKCzK1dhW9l8kdLAMMK8/didPsqwOkv6vOdcPd1qOEiJcjViLkxZGz\nIvmTagde6ULzGzcMsuADFudN3YvVFr6CLmurYT33R1r0NNFxr8+d2RgwvfwvFRYw\nRqJJ+t3s5iLH4GJCSdH73Vwv0uf1xXlCJe6VTC9oYBFxZU3/gQY8/KwZgwqw5+bc\nMC2cthlcSY/kqOuqomLXDUSf/O098apNa7DKrLHOdnOsaDZBqT07RDutNo/d97o6\nNl/wC4jydXm9h5ZdZLZm55Q="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-04.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-04.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://platformdev-secure.nature.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ollier"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:j.ollier@nature.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ollier"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:j.ollier@nature.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://platformdev-secure.nature.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Nature Publishing Group (platformdev)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nature.com/npg_/company_info/index.html"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Macmillan Publishers Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDbzCCAlegAwIBAgIEL+I9azANBgkqhkiG9w0BAQsFADBoMQswCQYDVQQGEwJVSzEPMA0GA1UE\n\t\t\t\t\t\tBxMGTG9uZG9uMRIwEAYDVQQKEwlNYWNtaWxsYW4xDDAKBgNVBAsTA05QRzEmMCQGA1UEAxMdcGxh\n\t\t\t\t\t\tdGZvcm1kZXYtc2VjdXJlLm5hdHVyZS5jb20wHhcNMTUwMzEzMDQyNjA1WhcNMjUwMzEwMDQyNjA1\n\t\t\t\t\t\tWjBoMQswCQYDVQQGEwJVSzEPMA0GA1UEBxMGTG9uZG9uMRIwEAYDVQQKEwlNYWNtaWxsYW4xDDAK\n\t\t\t\t\t\tBgNVBAsTA05QRzEmMCQGA1UEAxMdcGxhdGZvcm1kZXYtc2VjdXJlLm5hdHVyZS5jb20wggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCjE+9CkWEKPCWmeVwaW2IVw7nZf6UNat6bmHixJzjW\n\t\t\t\t\t\t237phAfssFs+xLaEDhwk6LvpzSyONSdffPRGzcb/cpcLmDPH0ZzMYpsuJtBEsov9p4znpuIUvHSH\n\t\t\t\t\t\tQO88V12GhnodzF+bv/eSqfrRAgHXoad6j0YH6kbVWqV4W7QH5KAnYRn6kGy+US5XBY1N4e4WS/9z\n\t\t\t\t\t\tqxmV/NYVpzFkseOzvcPgkdvJqDiyGKY5fECWZc66Qu6CLWFhar5I8g9KqWLC0fsJ7f7XSL8ROwD8\n\t\t\t\t\t\tzfTIUkc8PfeMReRvabCEsUy4nUAtDgUDpLF1UwxmLxO67oLHbWvJydgCi9I927KSz776fkBRAgMB\n\t\t\t\t\t\tAAGjITAfMB0GA1UdDgQWBBTHP3Lmuw/WbmqWxKhlOkaTrPpA4TANBgkqhkiG9w0BAQsFAAOCAQEA\n\t\t\t\t\t\tEaqTVJlsC9+36JfI3/afjeD+6FvSXIcchh9XHbOCkwr9OV8HSa+ZP3U5TGGJktGnoJSiaTtZMn78\n\t\t\t\t\t\t70k8lS6wR/nmfnKR0oSOG8m2mP1Xak7+paRRDPUmidAVeg/1yrMssWVYaLho/aW0CERlQvZQhNdn\n\t\t\t\t\t\trn93k8jzdrmh3V7pn709An2bcIeeDPe+OVgB9Le1PSgaVZuhUCITlu24dC9Ht41vIyTtYUQZ5drg\n\t\t\t\t\t\t0D1XRieehGxNVTw8Wq2T6JnEMBILq0j7AneiDr3X1i7U/XjKjNGf6e7Plh0qWbf3MVQKdJcS39Y+\n\t\t\t\t\t\tJi+ncYi6N+RRa5z+89CVTAeLRdCUhwYunfZh4A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://platformdev-secure.nature.com/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://platformdev-secure.nature.com/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://platformdev-secure.nature.com/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://platformdev-secure.nature.com/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://lpwtest.it.ki.se/shibboleth",
    {
      "entity_id": "https://lpwtest.it.ki.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lpwtest.it.ki.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lpwtest.it.ki.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lpwtest.it.ki.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lpwtest.it.ki.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lpwtest.it.ki.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://lpwtest.it.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://lpwtest.it.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://lpwtest.it.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "kiladoktest01.it.ki.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJAMJ9LjHSUsvoMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmtpbGFkb2t0ZXN0MDEuaXQua2kuc2UwHhcNMTEwNTI2MTMyNTMzWhcNMjEw\nNTIzMTMyNTMzWjAhMR8wHQYDVQQDExZraWxhZG9rdGVzdDAxLml0LmtpLnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqOUmjHK3EDwdhiUDbm9oW/u8\nn/ksrSapvbz+TTMQ70a01QHdcU1d48Dq2rjOVUpiZvV+SVjrSsSaqoTW6X0jUwgO\nnzQZayVMGia9x5Y0zphksK0RIXrcZhN34zamHyg+ioVqumZWVfaXbfkDUphfJ25E\n+HzioYe9pzr+dWeS0bTMQ6kcgI+KZqVfpKYeNn/6c5zgfYFUy8lp7pYr5yRr7HKM\nxbezT7PTdMIXwqI291G4VaTed/jDFOtYInMI3nGcg1U75TjMxbJIjDl24hWMxb3t\nWP1vAQvQDhTYuAPaQZq/FPCYWBbbKmHUG2RcquSWYullHwvWgRnzXi04/8luwQID\nAQABo0QwQjAhBgNVHREEGjAYghZraWxhZG9rdGVzdDAxLml0LmtpLnNlMB0GA1Ud\nDgQWBBTm4IeB4clBD5Xy65Su9mR25oz94DANBgkqhkiG9w0BAQUFAAOCAQEApjAT\nZMzYK0b21AfhOC4ELmXzRIG7tjEqpG1S2KGjTML3OPQ3iqY0+6NH5ihcG7L5U+Ot\nS3HswID9RV4fRkvB2HJ1cBDSH8DbCCi6LyYydJPfJloYJ/AdrumlJQDVJRNyYD6T\n53on7zeJaKv3n9eJrhqdnoEy0ofJtTAydbEx+F3AT3tW+jjpo5biuyuOa6W0wv0J\nDICtfX5UbSz96NxJbSCjoD23hMXqMOcUT3Pllk1MuPeK18rxZWy8qwxVk+E/haLr\nOaQPhM+ucEz0I/gHI37mAyzAz8w9PSTjwN+GKKngB+8IcdOQcUVRIhhTtu+ukBjR\ne01/KT+BtiGpAdoAUA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=kiladoktest01.it.ki.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lpwtest.it.ki.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://lpwtest.it.ki.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lpwtest.it.ki.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://lpwtest.it.ki.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://lpwtest.it.ki.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://lpwtest.it.ki.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://beaumontcollege.org/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Couzins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:couzinsj@beaumontcollege.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Couzins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:couzinsj@beaumontcollege.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://beaumontcollege.org/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://runtime.beaumontcollege.net/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://runtime.beaumontcollege.net/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "beaumontcollege.org"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDqTCCApGgAwIBAgIJAIIf+NILbP9ZMA0GCSqGSIb3DQEBBQUAMEExGTAXBgNV\n\t\t\t\t\t\tBAoTEEJlYXVtb250IENvbGxlZ2UxJDAiBgNVBAMTG3J1bnRpbWUuYmVhdW1vbnRj\n\t\t\t\t\t\tb2xsZWdlLm5ldDAeFw0xMTA0MTkwOTM4NThaFw0yMTA0MTYwOTM4NThaMEExGTAX\n\t\t\t\t\t\tBgNVBAoTEEJlYXVtb250IENvbGxlZ2UxJDAiBgNVBAMTG3J1bnRpbWUuYmVhdW1v\n\t\t\t\t\t\tbnRjb2xsZWdlLm5ldDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANl6\n\t\t\t\t\t\t6JunNXqxiJRO9GiIkbXTEujWniTLPlfEWcmT+RCaHdZRQ7F3r7X71csvqkGoqsia\n\t\t\t\t\t\ttZ44njSv3Yy/Gpt5zpr2dPtuFIVLaXXhOmTMSx7uMMfMoVgSlextlg8sMe7xW54l\n\t\t\t\t\t\tfZtMV+K/+i3AfthnA0PtBuMf3CPR40oyxNS/mZLjLyksFMfNN805ab9f07a+8UXQ\n\t\t\t\t\t\t+poU1mJ38NUW+k9pNobehAAVty93wdYd9AqIcEoIx04gmHXBAeHb7yPph4h4jqal\n\t\t\t\t\t\tdmT8CN8sYd8m+gFQ4Kb75qxbXdUuD/h8FHPbWZjJ077Tt9qanI3WO/AxTCxRJIN+\n\t\t\t\t\t\tcwRiODuEA//RjF1LbuUCAwEAAaOBozCBoDAdBgNVHQ4EFgQUbHShUZqbjLWyOUDj\n\t\t\t\t\t\teMhjgP+pqsUwcQYDVR0jBGowaIAUbHShUZqbjLWyOUDjeMhjgP+pqsWhRaRDMEEx\n\t\t\t\t\t\tGTAXBgNVBAoTEEJlYXVtb250IENvbGxlZ2UxJDAiBgNVBAMTG3J1bnRpbWUuYmVh\n\t\t\t\t\t\tdW1vbnRjb2xsZWdlLm5ldIIJAIIf+NILbP9ZMAwGA1UdEwQFMAMBAf8wDQYJKoZI\n\t\t\t\t\t\thvcNAQEFBQADggEBAImljg1eaEGn3TKc1xh5go74zGJv2pNhRKoxoMZ/HOmbFe7h\n\t\t\t\t\t\tYlAyi2aSanJlLG9HmZ5uCTAve9TDyzNkYoFvD7sGy0Wf3BJ+z+EDnZVV8iqBradX\n\t\t\t\t\t\tkovQ19tQkwdel0FYwkxiNUQ0L4GzJWUaYKxFX2pWtoWPKE+7DnP/kUef7enRLnqQ\n\t\t\t\t\t\tGVbHpJZK/QDTcJ8tqdz+tDs/Z9r86RESEFm5Bod6q2TIDiZFSHu8nT1BDb/9Gk/j\n\t\t\t\t\t\tb//hRbeDkCGfHk9Rv/CPBzuPQGEM1xROe5YL7SJTnH8TAuhBOFx5flFhfmiTNSBy\n\t\t\t\t\t\t0oeR3asSGQqUrtsmH2BIYoeJXBtrWYJYWOGXG/8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDqTCCApGgAwIBAgIJAIIf+NILbP9ZMA0GCSqGSIb3DQEBBQUAMEExGTAXBgNV\n\t\t\t\t\t\tBAoTEEJlYXVtb250IENvbGxlZ2UxJDAiBgNVBAMTG3J1bnRpbWUuYmVhdW1vbnRj\n\t\t\t\t\t\tb2xsZWdlLm5ldDAeFw0xMTA0MTkwOTM4NThaFw0yMTA0MTYwOTM4NThaMEExGTAX\n\t\t\t\t\t\tBgNVBAoTEEJlYXVtb250IENvbGxlZ2UxJDAiBgNVBAMTG3J1bnRpbWUuYmVhdW1v\n\t\t\t\t\t\tbnRjb2xsZWdlLm5ldDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANl6\n\t\t\t\t\t\t6JunNXqxiJRO9GiIkbXTEujWniTLPlfEWcmT+RCaHdZRQ7F3r7X71csvqkGoqsia\n\t\t\t\t\t\ttZ44njSv3Yy/Gpt5zpr2dPtuFIVLaXXhOmTMSx7uMMfMoVgSlextlg8sMe7xW54l\n\t\t\t\t\t\tfZtMV+K/+i3AfthnA0PtBuMf3CPR40oyxNS/mZLjLyksFMfNN805ab9f07a+8UXQ\n\t\t\t\t\t\t+poU1mJ38NUW+k9pNobehAAVty93wdYd9AqIcEoIx04gmHXBAeHb7yPph4h4jqal\n\t\t\t\t\t\tdmT8CN8sYd8m+gFQ4Kb75qxbXdUuD/h8FHPbWZjJ077Tt9qanI3WO/AxTCxRJIN+\n\t\t\t\t\t\tcwRiODuEA//RjF1LbuUCAwEAAaOBozCBoDAdBgNVHQ4EFgQUbHShUZqbjLWyOUDj\n\t\t\t\t\t\teMhjgP+pqsUwcQYDVR0jBGowaIAUbHShUZqbjLWyOUDjeMhjgP+pqsWhRaRDMEEx\n\t\t\t\t\t\tGTAXBgNVBAoTEEJlYXVtb250IENvbGxlZ2UxJDAiBgNVBAMTG3J1bnRpbWUuYmVh\n\t\t\t\t\t\tdW1vbnRjb2xsZWdlLm5ldIIJAIIf+NILbP9ZMAwGA1UdEwQFMAMBAf8wDQYJKoZI\n\t\t\t\t\t\thvcNAQEFBQADggEBAImljg1eaEGn3TKc1xh5go74zGJv2pNhRKoxoMZ/HOmbFe7h\n\t\t\t\t\t\tYlAyi2aSanJlLG9HmZ5uCTAve9TDyzNkYoFvD7sGy0Wf3BJ+z+EDnZVV8iqBradX\n\t\t\t\t\t\tkovQ19tQkwdel0FYwkxiNUQ0L4GzJWUaYKxFX2pWtoWPKE+7DnP/kUef7enRLnqQ\n\t\t\t\t\t\tGVbHpJZK/QDTcJ8tqdz+tDs/Z9r86RESEFm5Bod6q2TIDiZFSHu8nT1BDb/9Gk/j\n\t\t\t\t\t\tb//hRbeDkCGfHk9Rv/CPBzuPQGEM1xROe5YL7SJTnH8TAuhBOFx5flFhfmiTNSBy\n\t\t\t\t\t\t0oeR3asSGQqUrtsmH2BIYoeJXBtrWYJYWOGXG/8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Beaumont College - A Scope College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.beaumontcollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Beaumont College - A Scope College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:alaska.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Q@Alaska.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David Bantz"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@alaska.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support Center"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "IAM@Alaska.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Identity & Access Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:alaska.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.alaska.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.alaska.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFDDCCA/SgAwIBAgIJALS9LfC6aZcBMA0GCSqGSIb3DQEBBQUAMIG0MQswCQYD\nVQQGEwJVUzEPMA0GA1UECBMGQWxhc2thMRIwEAYDVQQHEwlGYWlyYmFua3MxHTAb\nBgNVBAoTFFVuaXZlcnNpdHkgb2YgQWxhc2thMSkwJwYDVQQLEyBPZmZpY2Ugb2Yg\nSW5mb3JtYXRpb24gVGVjaG5vbG9neTEXMBUGA1UEAxMOaWRwLmFsYXNrYS5lZHUx\nHTAbBgkqhkiG9w0BCQEWDmlhbUBhbGFza2EuZWR1MB4XDTExMDcwNzAwMDE0OVoX\nDTE0MDcwNjAwMDE0OVowgbQxCzAJBgNVBAYTAlVTMQ8wDQYDVQQIEwZBbGFza2Ex\nEjAQBgNVBAcTCUZhaXJiYW5rczEdMBsGA1UEChMUVW5pdmVyc2l0eSBvZiBBbGFz\na2ExKTAnBgNVBAsTIE9mZmljZSBvZiBJbmZvcm1hdGlvbiBUZWNobm9sb2d5MRcw\nFQYDVQQDEw5pZHAuYWxhc2thLmVkdTEdMBsGCSqGSIb3DQEJARYOaWFtQGFsYXNr\nYS5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC4Rs8GyYexxFZl\nQpWQ3VhwDKUGOYF+cEiGa6eZwkw5HbeL021tnrg8kgwe4mYuSsgTVNxsp50eRfrz\nPDjBPaoSTVdahBfdVbeecMlSM3SeY6D3hhvGXqsaeFArZ9s30CkdBitgaKvTSAsX\nAnRa9B2olmU/AfUfSPmRwDxDJo5ktGYZOwwUjB4ghduRtXc02quLYjO3N9T4hzx2\nteO1dQ5bEwH7QiD06AA7+mKbdLM9spqv8cgVFKmyuKYsJsnUPOMHjvKh/s9mBwIi\nTeI3efm35XZjYLpcUUVmZDE8XyPD9xZtjJF/xX8R7BATCGdA/D0Z01OFID7lRxyl\nQRSAfO6ZAgMBAAGjggEdMIIBGTAdBgNVHQ4EFgQUFXeeBk0zF6ZzB/sHkOdb1EUs\nFTswgekGA1UdIwSB4TCB3oAUFXeeBk0zF6ZzB/sHkOdb1EUsFTuhgbqkgbcwgbQx\nCzAJBgNVBAYTAlVTMQ8wDQYDVQQIEwZBbGFza2ExEjAQBgNVBAcTCUZhaXJiYW5r\nczEdMBsGA1UEChMUVW5pdmVyc2l0eSBvZiBBbGFza2ExKTAnBgNVBAsTIE9mZmlj\nZSBvZiBJbmZvcm1hdGlvbiBUZWNobm9sb2d5MRcwFQYDVQQDEw5pZHAuYWxhc2th\nLmVkdTEdMBsGCSqGSIb3DQEJARYOaWFtQGFsYXNrYS5lZHWCCQC0vS3wummXATAM\nBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAacb/yix06YrkfWbVIFP+L\n9u58aq7WXRMehUQT7VCDPDctZ5SjtMWd0A2b4igZtv2OxcG7U6dpBiOAk+MGEGeY\nl+sw4KFNB+K3VCU4DwT7debVq0quJHmP23oAdmId92w0+JN9/0T1pJZfzyFZBgTM\nU7cIkWqnMdrGhal5MNzrYypOUvZhKOrf/E10e6ZuuB6+5liGus8YZbfu18Ur3k9f\nQ3gISQ3vKG1Z8ACyVD2peCbpoN2QEtjIrAsU1WHgDrviAd5k5slFHue5g6Ujen4T\nB89QgPCsFr20bV2LDmEEnxNO47F6pFVlHYnrdxQCsf9ETU/7gzgn2g5OX1wkmETL"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAMN6E6Kx9SACb2AMDLfMzBz7UbvtMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC5hbGFza2EuZWR1MB4XDTE0MDYxMzIxNTkyMFoX\nDTM0MDYxMzIxNTkyMFowGTEXMBUGA1UEAxMOaWRwLmFsYXNrYS5lZHUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCdI7JodYCEjG/v98W2vVFokOU6LtNb\nI1n24JGeTDtrx4dcJ27/rBJ80oniTKOu2bwF1j6k9D5ow5qIQ2JVD0RbSCyCXIlP\nuKuvGDrL9+HDdx/TTVJe0/tvWdTAEQj4O8ax3H4fXGUeAzXl01v+VMBZorLsSu6I\n/C10araiaoJGMqi32apVz/4UclGATAufG6l5ueuCSVvlZWe9v0Tyo3iEWbYz9wEI\nzjzF6gLi9lxy02RYbOqaCy0r8IrD7q8GJhltlz44F4WdaNedntjpjIW8BdK9fSkW\nJkDCH0TT+kd1mI8ZBZwf4OIX1eNMfXAaxhrxgTT0qqwLCjTgMRVlCfU/AgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC5hbGFza2EuZWR1hiVodHRwczovL2lkcC5hbGFz\na2EuZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSXTxXBFiKPCSyFK0VmHghD\nY/MDhzANBgkqhkiG9w0BAQUFAAOCAQEAlrgm8dHq0NpU4JuCrvCz2gBMBolvoZEM\n9YkaQMeMYsvHGQX0kvQzCWPV+Im4rCxNU1aZIfkJNJaSgp4kdyRvG2Sa6N3jPjOu\nCYPLJtm3wBGkMjoDBQb12Upl2RjtSCCRVFIWSv1D0ycfCel2iqddsSCziKHiN3RX\npp25mLVA1KlcLQOGhdnxa1EkHR5zekUukapNGaQGOSTHdwvi+xxDpVfZ1xj9jjt+\nQc8E7z0BxqW2QRaU1D7Jqc4QQbOD+wDnIWHtj2LzdyJknBeG+i9L0IKogsUgDDJr\nqkYa6vIOo4URe5e3Z1bGmENzaoHt2usblOWLGu2AV+CNwkbX65c9wg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "alaska.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.alaska.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.alaska.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.alaska.edu/idp/profile/SAML2/POST-SimipleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.alaska.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.alaska.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.alaska.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "alaska.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://iam.alaska.edu/trac/wiki/UAInCPOP.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Alaska Statewide System"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "InCommon federated IdP (identity provider) for all students, faculty, & staff at all campuses of the University of Alaska."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.alaska.edu/files/opa/color.jpg",
                    "lang": "en",
                    "height": "632",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "860"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://iam.alaska.edu/trac/wiki/IamUaArp"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFDDCCA/SgAwIBAgIJALS9LfC6aZcBMA0GCSqGSIb3DQEBBQUAMIG0MQswCQYD\nVQQGEwJVUzEPMA0GA1UECBMGQWxhc2thMRIwEAYDVQQHEwlGYWlyYmFua3MxHTAb\nBgNVBAoTFFVuaXZlcnNpdHkgb2YgQWxhc2thMSkwJwYDVQQLEyBPZmZpY2Ugb2Yg\nSW5mb3JtYXRpb24gVGVjaG5vbG9neTEXMBUGA1UEAxMOaWRwLmFsYXNrYS5lZHUx\nHTAbBgkqhkiG9w0BCQEWDmlhbUBhbGFza2EuZWR1MB4XDTExMDcwNzAwMDE0OVoX\nDTE0MDcwNjAwMDE0OVowgbQxCzAJBgNVBAYTAlVTMQ8wDQYDVQQIEwZBbGFza2Ex\nEjAQBgNVBAcTCUZhaXJiYW5rczEdMBsGA1UEChMUVW5pdmVyc2l0eSBvZiBBbGFz\na2ExKTAnBgNVBAsTIE9mZmljZSBvZiBJbmZvcm1hdGlvbiBUZWNobm9sb2d5MRcw\nFQYDVQQDEw5pZHAuYWxhc2thLmVkdTEdMBsGCSqGSIb3DQEJARYOaWFtQGFsYXNr\nYS5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC4Rs8GyYexxFZl\nQpWQ3VhwDKUGOYF+cEiGa6eZwkw5HbeL021tnrg8kgwe4mYuSsgTVNxsp50eRfrz\nPDjBPaoSTVdahBfdVbeecMlSM3SeY6D3hhvGXqsaeFArZ9s30CkdBitgaKvTSAsX\nAnRa9B2olmU/AfUfSPmRwDxDJo5ktGYZOwwUjB4ghduRtXc02quLYjO3N9T4hzx2\nteO1dQ5bEwH7QiD06AA7+mKbdLM9spqv8cgVFKmyuKYsJsnUPOMHjvKh/s9mBwIi\nTeI3efm35XZjYLpcUUVmZDE8XyPD9xZtjJF/xX8R7BATCGdA/D0Z01OFID7lRxyl\nQRSAfO6ZAgMBAAGjggEdMIIBGTAdBgNVHQ4EFgQUFXeeBk0zF6ZzB/sHkOdb1EUs\nFTswgekGA1UdIwSB4TCB3oAUFXeeBk0zF6ZzB/sHkOdb1EUsFTuhgbqkgbcwgbQx\nCzAJBgNVBAYTAlVTMQ8wDQYDVQQIEwZBbGFza2ExEjAQBgNVBAcTCUZhaXJiYW5r\nczEdMBsGA1UEChMUVW5pdmVyc2l0eSBvZiBBbGFza2ExKTAnBgNVBAsTIE9mZmlj\nZSBvZiBJbmZvcm1hdGlvbiBUZWNobm9sb2d5MRcwFQYDVQQDEw5pZHAuYWxhc2th\nLmVkdTEdMBsGCSqGSIb3DQEJARYOaWFtQGFsYXNrYS5lZHWCCQC0vS3wummXATAM\nBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAacb/yix06YrkfWbVIFP+L\n9u58aq7WXRMehUQT7VCDPDctZ5SjtMWd0A2b4igZtv2OxcG7U6dpBiOAk+MGEGeY\nl+sw4KFNB+K3VCU4DwT7debVq0quJHmP23oAdmId92w0+JN9/0T1pJZfzyFZBgTM\nU7cIkWqnMdrGhal5MNzrYypOUvZhKOrf/E10e6ZuuB6+5liGus8YZbfu18Ur3k9f\nQ3gISQ3vKG1Z8ACyVD2peCbpoN2QEtjIrAsU1WHgDrviAd5k5slFHue5g6Ujen4T\nB89QgPCsFr20bV2LDmEEnxNO47F6pFVlHYnrdxQCsf9ETU/7gzgn2g5OX1wkmETL"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAMN6E6Kx9SACb2AMDLfMzBz7UbvtMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC5hbGFza2EuZWR1MB4XDTE0MDYxMzIxNTkyMFoX\nDTM0MDYxMzIxNTkyMFowGTEXMBUGA1UEAxMOaWRwLmFsYXNrYS5lZHUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCdI7JodYCEjG/v98W2vVFokOU6LtNb\nI1n24JGeTDtrx4dcJ27/rBJ80oniTKOu2bwF1j6k9D5ow5qIQ2JVD0RbSCyCXIlP\nuKuvGDrL9+HDdx/TTVJe0/tvWdTAEQj4O8ax3H4fXGUeAzXl01v+VMBZorLsSu6I\n/C10araiaoJGMqi32apVz/4UclGATAufG6l5ueuCSVvlZWe9v0Tyo3iEWbYz9wEI\nzjzF6gLi9lxy02RYbOqaCy0r8IrD7q8GJhltlz44F4WdaNedntjpjIW8BdK9fSkW\nJkDCH0TT+kd1mI8ZBZwf4OIX1eNMfXAaxhrxgTT0qqwLCjTgMRVlCfU/AgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC5hbGFza2EuZWR1hiVodHRwczovL2lkcC5hbGFz\na2EuZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSXTxXBFiKPCSyFK0VmHghD\nY/MDhzANBgkqhkiG9w0BAQUFAAOCAQEAlrgm8dHq0NpU4JuCrvCz2gBMBolvoZEM\n9YkaQMeMYsvHGQX0kvQzCWPV+Im4rCxNU1aZIfkJNJaSgp4kdyRvG2Sa6N3jPjOu\nCYPLJtm3wBGkMjoDBQb12Upl2RjtSCCRVFIWSv1D0ycfCel2iqddsSCziKHiN3RX\npp25mLVA1KlcLQOGhdnxa1EkHR5zekUukapNGaQGOSTHdwvi+xxDpVfZ1xj9jjt+\nQc8E7z0BxqW2QRaU1D7Jqc4QQbOD+wDnIWHtj2LzdyJknBeG+i9L0IKogsUgDDJr\nqkYa6vIOo4URe5e3Z1bGmENzaoHt2usblOWLGu2AV+CNwkbX65c9wg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idp.alaska.edu/error.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Alaska Statewide System"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.alaska.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Alaska Statewide System"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-p11.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-p11.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p11.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p11.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p11.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p11.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p11.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-p11.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-p11.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;p11"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;p11"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-p11.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-p11.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQTCCAimgAwIBAgIJAKehdsNKqM2kMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2xhZG9rMy1wMTEubGFkb2sudW11LnNlMB4XDTE1MDIwOTEyMTQ1MVoXDTI1\nMDIwNjEyMTQ1MVowIjEgMB4GA1UEAxMXbGFkb2szLXAxMS5sYWRvay51bXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDU3zMW+LnR8zbNpL3zGxNZ\nwCHD75uUACoSzrzCkY5AOyJ3wq67G5tr+RxZTZ6vMf/y8mUVrKoy4eJZPZb45y4Z\ncoZsMQDgxy2TisLFD30FnpuiCWsT7mwjBevURhW3GxXaYUQAYYyXmV8dXpmug0oT\n7hLAw77yw46yo84pHprAbBRmxzlh4RVNeU/orX/u2GcMuvtREmUbLcT37FWPqixV\ntuwbGW18esarCIFcjBUluYOsxYeN3qiRGz2A+qzWxspDDvSfoz2m/3Qa6v34ag03\n0+8/B6HVHyZILr2Gx0HBlR4vppCgrghDBsilF0A5dVj35EqSHtvXVtObYqBih87n\nAgMBAAGjejB4MFcGA1UdEQRQME6CF2xhZG9rMy1wMTEubGFkb2sudW11LnNlhjNo\ndHRwczovL2xhZG9rMy1wMTEubGFkb2sudW11LnNlL3N0dWRlbnQtZnJvbnRlbmQt\nc3AwHQYDVR0OBBYEFIIKvFpin/kTtRfw1fVqTaMQUZRhMA0GCSqGSIb3DQEBBQUA\nA4IBAQDKRzoJiU2h68B0rt6AezOKAduvuv5kcpTfQErTt101x1nQBtLKP/C9E516\nnpOwoKVL4RCRkZnUzfiZyJhZqQ96pTQRlsVjN6RC+U0HWa1aOMHM84uI5fRaIWy6\nTOzzsV2mdUtHKEPuYdiqNo/+WqqLnNVbayfZ9bzHk7rSsSNumxvGtrnFPjA0VwI7\n3q1tLLTijrKE3shtVWmjeXVTg1/SqcOkTHsm09bE+jXLM0xAnj3SZ3BnyrgXA/4S\nEGXmplT32/6gc+5yZDyYoaqbAHJDwuSown5ID5/S8ZMwoVSykqFM3LowH3d+sCRu\ngtXEZlr2dLe/argHthcqudmMquP8"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-p11.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p11.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p11.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p11.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p11.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p11.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p11.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-p11.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-p11.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-p11.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cambro-test-26.umdc.umu.se/shibboleth",
    {
      "entity_id": "https://cambro-test-26.umdc.umu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/IDP",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/IDPUMU",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/IDPTST2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/CAMBROLOGIN",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "cambro-test-26.umdc.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICqzCCAhQCCQDVX0RWVzQSBzANBgkqhkiG9w0BAQUFADCBmTELMAkGA1UEBhMC\nU0UxFTATBgNVBAgMDFZhc3RlcmJvdHRlbjENMAsGA1UEBwwEVW1lYTEMMAoGA1UE\nCgwDSVRTMQwwCgYDVQQLDANJVFMxIzAhBgNVBAMMGmNhbWJyby10ZXN0LTI2LnVt\nZGMudW11LnNlMSMwIQYJKoZIhvcNAQkBFhRzdXBwb3J0QHVtZGFjLnVtdS5zZTAe\nFw0xMjA1MTYxMTEzNDhaFw0xNzA1MTUxMTEzNDhaMIGZMQswCQYDVQQGEwJTRTEV\nMBMGA1UECAwMVmFzdGVyYm90dGVuMQ0wCwYDVQQHDARVbWVhMQwwCgYDVQQKDANJ\nVFMxDDAKBgNVBAsMA0lUUzEjMCEGA1UEAwwaY2FtYnJvLXRlc3QtMjYudW1kYy51\nbXUuc2UxIzAhBgkqhkiG9w0BCQEWFHN1cHBvcnRAdW1kYWMudW11LnNlMIGfMA0G\nCSqGSIb3DQEBAQUAA4GNADCBiQKBgQDb+dHecvFHT1wRDICdogQp6T7knOMuxDii\nu1UBfemwQAWkB8f5q8C+9v37NeBCr+QoZayw3fBCTT/o+zMjeA1PbNoU/2iR6/2K\n7o2r8eoYYosZpOJg3n2vFNWdo6ewfxWWwJ0l5cSvact0kkV0ofJsrBrzN1vE3cQT\n3RJBJSs8+wIDAQABMA0GCSqGSIb3DQEBBQUAA4GBALg4w+Ata45FRiN333JwqWqe\nG0TlordU57tDpoVJ/CJrYg+1+jbkmgTu6qnVajo6vMdIKtWA+xXscEvpgzMUJfna\nDkaGWa/QXoo1dZB6ixU2qztCtoNnvikugb+vJ/aPhy98zrL2XI3kiPblbKJ8/zqd\nXOi6QTTaGpYW3p3/v0OI"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=support@umdac.umu.se,CN=cambro-test-26.umdc.umu.se,OU=ITS,O=ITS,L=Umea,ST=Vasterbotten,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://cambro-test-26.umdc.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.bsms.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@brighton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Holden"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ukfederation-tech@bsms.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.bsms.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUVPdR3/QgLrYLEH5e7QfhKE8r9VkwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGTEXMBUGA1UEAxMOaWRwLmJzbXMuYWMudWswHhcNMTIwMTExMTAxNzQ5WhcN\n\t\t\t\t\t\tMzIwMTExMTAxNzQ5WjAZMRcwFQYDVQQDEw5pZHAuYnNtcy5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBALnAV+wrTxO7xJI38Rgiug18H58qBLB0\n\t\t\t\t\t\t6WuUwpUieb4FL263NiSvFn/PF2JLjTUx/1/B2JHyfaDxFpgco9PjQvOizTW4VRHV\n\t\t\t\t\t\tT4Oh5anJHbMPzECm1MgxqBS8RXSuqBiTWXMCZG3X84Qq6BzGuAzEOh05JFx9xn3K\n\t\t\t\t\t\te8u3LTAFDiQS/Ig9u80NER1Coc0D8YXIsP+2A5XzfZ+o15aPPMaj+4oiKYzHj078\n\t\t\t\t\t\tvGA5krpb8hevv0n0meUo1iadCA5GUaGqEmV3J6mSHAE/28/ehFdj2SN4b5AkBsNa\n\t\t\t\t\t\tNvQ30i0ZZbMzV2F4LnJ0lIM+7Q73dfVS1IdUrH/e02ahbJal4ez5v2MCAwEAAaNf\n\t\t\t\t\t\tMF0wPAYDVR0RBDUwM4IOaWRwLmJzbXMuYWMudWuGIWh0dHBzOi8vaWRwLmJzbXMu\n\t\t\t\t\t\tYWMudWsvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUNEeuu+lzrJ9Cm/bRaeX/5qVeEsIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAA6T6+dtIoK6TMsHCgocxshlDa/fkPVc4QxVuf7+\n\t\t\t\t\t\tgqEGqiSdKs559ttMw12onBtfqEgLippyVo9M0mi8Xu5/iid+BYQrPKPh0ibVMaik\n\t\t\t\t\t\tmsKZhO1AlmgGwi0ZosGVywcVeYnADEuDYMAO3ENEOzcs3nwYrHgoPUT8ozEoWRfU\n\t\t\t\t\t\t36CbxIdpBxW9E8KbPY9ILo6EH/AeaPY9HNklJr/oaWYgFyHlasMruZrD77mgNwCI\n\t\t\t\t\t\tr2gkn2ffy5Z/2izMU7nHRjO8z93LBHAsUlZK1qdbnKQa9ft5SEqVl22Ww/xWvrCD\n\t\t\t\t\t\tDCf9hZ/XDTkhfXkdFY4uujO+3Qqlin9ufSQG5VHzUVZ4knc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brighton.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sussex.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.bsms.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.bsms.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.bsms.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.bsms.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.bsms.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.bsms.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.bsms.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.bsms.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brighton.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sussex.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://idp.bsms.ac.uk/idp/images/logo-bsms.ac.uk.png",
                    "height": "63",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "40"
                  },
                  {
                    "text": "https://idp.bsms.ac.uk/idp/images/favicon-bsms.ac.uk.ico",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Brighton and Sussex Medical School"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUVPdR3/QgLrYLEH5e7QfhKE8r9VkwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGTEXMBUGA1UEAxMOaWRwLmJzbXMuYWMudWswHhcNMTIwMTExMTAxNzQ5WhcN\n\t\t\t\t\t\tMzIwMTExMTAxNzQ5WjAZMRcwFQYDVQQDEw5pZHAuYnNtcy5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBALnAV+wrTxO7xJI38Rgiug18H58qBLB0\n\t\t\t\t\t\t6WuUwpUieb4FL263NiSvFn/PF2JLjTUx/1/B2JHyfaDxFpgco9PjQvOizTW4VRHV\n\t\t\t\t\t\tT4Oh5anJHbMPzECm1MgxqBS8RXSuqBiTWXMCZG3X84Qq6BzGuAzEOh05JFx9xn3K\n\t\t\t\t\t\te8u3LTAFDiQS/Ig9u80NER1Coc0D8YXIsP+2A5XzfZ+o15aPPMaj+4oiKYzHj078\n\t\t\t\t\t\tvGA5krpb8hevv0n0meUo1iadCA5GUaGqEmV3J6mSHAE/28/ehFdj2SN4b5AkBsNa\n\t\t\t\t\t\tNvQ30i0ZZbMzV2F4LnJ0lIM+7Q73dfVS1IdUrH/e02ahbJal4ez5v2MCAwEAAaNf\n\t\t\t\t\t\tMF0wPAYDVR0RBDUwM4IOaWRwLmJzbXMuYWMudWuGIWh0dHBzOi8vaWRwLmJzbXMu\n\t\t\t\t\t\tYWMudWsvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUNEeuu+lzrJ9Cm/bRaeX/5qVeEsIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAA6T6+dtIoK6TMsHCgocxshlDa/fkPVc4QxVuf7+\n\t\t\t\t\t\tgqEGqiSdKs559ttMw12onBtfqEgLippyVo9M0mi8Xu5/iid+BYQrPKPh0ibVMaik\n\t\t\t\t\t\tmsKZhO1AlmgGwi0ZosGVywcVeYnADEuDYMAO3ENEOzcs3nwYrHgoPUT8ozEoWRfU\n\t\t\t\t\t\t36CbxIdpBxW9E8KbPY9ILo6EH/AeaPY9HNklJr/oaWYgFyHlasMruZrD77mgNwCI\n\t\t\t\t\t\tr2gkn2ffy5Z/2izMU7nHRjO8z93LBHAsUlZK1qdbnKQa9ft5SEqVl22Ww/xWvrCD\n\t\t\t\t\t\tDCf9hZ/XDTkhfXkdFY4uujO+3Qqlin9ufSQG5VHzUVZ4knc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Brighton and Sussex Medical School"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bsms.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Brighton"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.cvt.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.cvt.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cvt.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.cvt.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cvt.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cvt.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cvt.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.cvt.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.cvt.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.cvt.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.cvt.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.cvt.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.cvt.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.cvt.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJAKIBaYTXA/UKMA0GCSqGSIb3DQEBCwUAMBsxGTAXBgNV\nBAMTEHd3dy5jdnQubGFkb2suc2UwHhcNMTYwMzE0MTI1MDE3WhcNMjYwMzEyMTI1\nMDE3WjAbMRkwFwYDVQQDExB3d3cuY3Z0LmxhZG9rLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA1BtDJ0yOznNEjxYdreMZIj5PAp4XVHbVJ7SVUfXK\nqaaLntdnhfUu4j1HMTmJynODaTMmGU7WuToHFDSvS7hF8W+uNtHgTqZ6KCXJP43x\nxlUHhwJ6NgDyav4DHELDxx1gbvYsS8XSJFSdz5ndzQdE4JVjIEMzz1EH3VgUh5N3\nf0l1oW+t9+Y2hug/DR/xgiof6aC/WTfcRE5X3syL1eFDdi5HcLtuqwsIr2ye4Z53\nsNasbH+CqRk3rEuz0Xn2g1xUlVVmHUl1U8DH1bVDwNoGhooiL6UjrfBjPpjnIq1t\nKStatxJLwnEdvx1GEJBJ1OQBsKro2wVrXwAU3mC5cbegJQIDAQABo18wXTA8BgNV\nHREENTAzghB3d3cuY3Z0LmxhZG9rLnNlhh9odHRwczovL3d3dy5jdnQubGFkb2su\nc2UvZ3VpLXNwMB0GA1UdDgQWBBQrZwcdAGn4uy7Y0JnGewF0MM1TxjANBgkqhkiG\n9w0BAQsFAAOCAQEAVJevYxixFe9Tv2RuJ9tEoUnp2bUyN/48rL5oDGb7JSeCNbg1\nkROhWl0wEU/Yf1gY4RUGFy+IWXMDMDY9hJ7MZE0mNE2tyXtUHA7sCJXeuyjo2cCA\neY2fmu0U60jbzZgahmxGdekdiDLeLAIJymhkGmMYT3v56KNr7DgqJ5HBdKKjFoRQ\ns1sd9atFeunYVqeqKSg3RpuOQfFtTNUReoCpsNyIvYIJD/Fii/eivqDDggaoSPRJ\nWnimKipRjtjA/SYLRR/nyoXAsQni3B9LlCSTmM5P6ydj8OgynYTf49JII2/kVohu\ny9GY07YaqJzsN7hRR+MqdDquFOn1kbK8mY+1EQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.cvt.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cvt.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.cvt.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cvt.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cvt.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cvt.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cvt.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.cvt.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.cvt.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.cvt.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ukdsdev01.ds.man.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Noble"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Susan.Noble@manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Susan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mimas-shib-tech@listserv.manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mimas Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ukdsdev01.ds.man.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-08-28T10:05:43Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MIMAS: UK Data Service Development Server 01"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mimas.ac.uk"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Manchester"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ukdsdev01.ds.man.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ukdsdev01.ds.man.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ukdsdev01.ds.man.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ukdsdev01.ds.man.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ukdsdev01.ds.man.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ukdsdev01.ds.man.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJAJQ6G0iUGwxqMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\n\t\t\t\t\t\tBAMTFnVrZHNkZXYwMS5kcy5tYW4uYWMudWswHhcNMTMwODI3MTExNDIwWhcNMjMw\n\t\t\t\t\t\tODI1MTExNDIwWjAhMR8wHQYDVQQDExZ1a2RzZGV2MDEuZHMubWFuLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA6jrshIhFr1+KeJ+y0r7iJ3A/\n\t\t\t\t\t\trBC1NRF37B6kkETjvys8fB3rlHd6FmYsN1Avz3CvlSXldom4yi7lJ7Qg7D5bn2Wy\n\t\t\t\t\t\tbuSPBi0OCCA9eHkbCpAwkFoTHQyfXWdGBOV/L1X5rfmetBbA21EjvxcZYzYndqBY\n\t\t\t\t\t\teUrYTrHZkwDfKf9L3+Qym2RWnGC5S/WmVmMmTNv0W49U80wZsPVHjL7ZS+2m2KhW\n\t\t\t\t\t\tgtQfo7ajDiRtNKwt+4ERVwu8D/kZk9hzlYwvHr1Gb7HVc5sRM5i4MCO5MAcLq80R\n\t\t\t\t\t\tFk7Hh7aLR0mnSk1DP6ZJgX9gOLaqq08NIZ+vuIiGOTL2j02Iw1LwMqFH9TJlJwID\n\t\t\t\t\t\tAQABo0QwQjAhBgNVHREEGjAYghZ1a2RzZGV2MDEuZHMubWFuLmFjLnVrMB0GA1Ud\n\t\t\t\t\t\tDgQWBBR1ncC2lP6ZoPxifhXf0uadQrtHYjANBgkqhkiG9w0BAQUFAAOCAQEAZKKU\n\t\t\t\t\t\tZ1Mulo7W/CRWi3gKja0RXSCnBpUxLmsK0t15x0yyzkl+32aFufv7KJnss3hVM8ad\n\t\t\t\t\t\tvg4P2x7N0/ynIXMAnnQ4oSoxcrcpTeHNmoxihWbHrr7fulyC7M5xOcnYbzJnZkl/\n\t\t\t\t\t\tEIR0cR/e6eNoGWlwT90ahXojm0dpWDhg0Mhd6K3WmBNYzj+kgzrMKz9HnMm/k0OI\n\t\t\t\t\t\tNjwwhBPTGbuTw70hTnAbdHtos1vz/wSFk+Eff5MzXnH2nmtw3TPIxviq2ZAoZRRa\n\t\t\t\t\t\t2l4Z2j1AtknzLhBHs0kVF8oFjRNb6DilqMa5avXU4QrNPMpVrJopPuEyJ8mJ/1F8\n\t\t\t\t\t\tRduyp41iuU+v6vWNtQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ukdsdev01.ds.man.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ukdsdev01.ds.man.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ukdsdev01.ds.man.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ukdsdev01.ds.man.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ukdsdev01.ds.man.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ukdsdev01.ds.man.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:cru.fr:federation:univ-ubs.fr",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "fed-admin@univ-ubs.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:cru.fr:federation:univ-ubs.fr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-04-09T16:11:54Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univ-ubs.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univ-ubs.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.univ-ubs.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-ubs.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-ubs.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Bretagne Sud"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Bretagne Sud"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUQf+bgYI+pflZTXe6Sw+Ijq7sDuwwDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPaWRwLnVuaXYtdWJzLmZyMB4XDTA5MDMyNjA5MzUxM1oX\nDTI5MDMyNjA4MzUxM1owGjEYMBYGA1UEAxMPaWRwLnVuaXYtdWJzLmZyMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzjVVD6f/m26YrFIXqyAhIIZOl5Jy\nKT/06NrJReinTL27+4mGRcK2Hy3CN412n3FLUlSra1E+1KtgdSXLGH0aipopxsF1\n4tNnr7XUGzX3jYLwEf9JAvMjkrmfg6XV+tRM0aEVhbk6T/0kSUVSu0OuY1OtnWMX\ntEOI5lxBIFiiF2IjkzXfT3IXtn43BLurAtwGEjVcU/h9p4XKAv1vXDnSZIYMV68h\nRfnt37Jbk4MOZC5G/b6ruegAWylpZ6/xd3eToWiTf6jf7cTL1rvVCBshyumkgF1z\nGUzmsUPIieAO2K1cAj6YSYO39Ya+TSpwmeGHfHU2ptmm0Pg+3FgVcQd0vQIDAQAB\no2UwYzBCBgNVHREEOzA5gg9pZHAudW5pdi11YnMuZnKGJmh0dHBzOi8vaWRwLnVu\naXYtdWJzLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRJzRQHNoeR8yfWTVGV\ncZxCUNFlVTANBgkqhkiG9w0BAQUFAAOCAQEAoKKviDAjDppeG/HLfBnHEGk3huwy\nQS7vwSXR8iQCkJeFzYJbQNW3C0pZ3gbTjXEwR8a7zyLm08LNTJy1b03oHEZvLf+5\nozxzL0Sj0L8eH/Edra2le2VYp7OpAIKXbktQ7tov7OrNjwvnEThp4emd6ffMNKBy\ntuagpJOU3yH1CJ1aV9Za1cvobQJryWlwGgvw2Z2ALFs5/BT435lBJbMjuNAR9mC8\nGKrzVJxuCZuaFkCNIGIA2lPmHA755Vf5rKi2/4A+qBzN9XJc1RBzTlg9PF1WQzb3\nKsqVsaQhhLja8zwz5NlpcXN89WMIL/Bg6T3t5KN4ajbKbWxX/7uMAVsEUw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Bretagne Sud"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-ubs.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Bretagne Sud"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.rediris.es/sir/rediristestidp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sir@rediris.es"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SIR helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.rediris.es/sir/rediristestidp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.rediris.es/sir/edugain/SIR_MRPS.pdf"
              }
            ],
            "registration_instant": "2012-10-09T13:08:24Z",
            "registration_authority": "http://www.rediris.es/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sir.rediris.es/simplesamlphp/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sir.rediris.es/simplesamlphp/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider run by RedIRIS"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Proveedor de identidad operado por RedIRIS"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RedIRIS - Spanish Research and Academic Network"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RedIRIS - Red acad\u00e9mica y de investigaci\u00f3n espa\u00f1ola"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEeTCCA2GgAwIBAgIQCP9faAGj247/+QVzgpX08zANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDcwMTAwMDAwMFoXDTE2MDYzMDIzNTk1OVowRDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMR8wHQYDVQQDExZzYW1saWRwLnNp\nci5yZWRpcmlzLmVzMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA5tO6\ntYAdozpFMDwS7QH1qm7eECkY05lG1sp14vcVOdyN0mAf8oai+M8dCQ5iyMxD/RaG\noSmhXfHUvJ+0x8Cp/NHYbKr0cXskANcYTI0JFMFypn9Uac62CGxUYZRhHQ/2LxiE\nvzNgKrm2JiXCvOQbWrbg0sZDEsONv2G1Ln3fvOLiSiO1AjWLvOeYFPNgkNy5dxxt\n7ms7mZ0bFth6Cj38BBL0I1RebVnMgAKZWSgICUXDx35nkB+iLtidIykBgz92ZQ5h\nUrVNndP5+lraoMRuIewESSFt+LBYVeUZFTBGlupiUZ/bi7rhtIuhMM8ahaKIstbu\nIgfQBHPqRkkiiKOJawIDAQABo4IBczCCAW8wHwYDVR0jBBgwFoAUDL2TaAzz3quj\nSWsrN1dH6pDjue0wHQYDVR0OBBYEFARoBLDWcsveEZQhaMVIR9mmJkUkMA4GA1Ud\nDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggr\nBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNV\nHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNT\nTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQu\ndGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRw\nOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAhBgNVHREEGjAYghZzYW1saWRwLnNpci5y\nZWRpcmlzLmVzMA0GCSqGSIb3DQEBBQUAA4IBAQB0gmr232YgpUC4HkwAHXaH91Zx\n8ZrwiEc8c4jGLh5VsaO0OqMfUEIXMuqZ+P9JNWVwlc6VLtmsypqTuqb9a06DS88q\n2o5sAUpbXZwhArhQs1bQnu5HJ6S84Ajn+NfMOyaO7NF8Colq/9lf3DihkT0jlD7i\nPHPMw2zauvtR/WPwdPszgfIOV/vkJ0rq9AjOXxSX7V2jpkxISGW/m93iahwXEoVF\nc8VXQhNjEfcm6uawmISjsyp6ta/U3e/8GJka2csDrF/bfipMBDSdWcLMscpYO8cb\nDC0L6vehZJ+lPz3wPH6YJmlstICZUdJIgDV3TUhmji6NNKa4p6by34QdYcDH"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEeTCCA2GgAwIBAgIQCP9faAGj247/+QVzgpX08zANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDcwMTAwMDAwMFoXDTE2MDYzMDIzNTk1OVowRDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMR8wHQYDVQQDExZzYW1saWRwLnNp\nci5yZWRpcmlzLmVzMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA5tO6\ntYAdozpFMDwS7QH1qm7eECkY05lG1sp14vcVOdyN0mAf8oai+M8dCQ5iyMxD/RaG\noSmhXfHUvJ+0x8Cp/NHYbKr0cXskANcYTI0JFMFypn9Uac62CGxUYZRhHQ/2LxiE\nvzNgKrm2JiXCvOQbWrbg0sZDEsONv2G1Ln3fvOLiSiO1AjWLvOeYFPNgkNy5dxxt\n7ms7mZ0bFth6Cj38BBL0I1RebVnMgAKZWSgICUXDx35nkB+iLtidIykBgz92ZQ5h\nUrVNndP5+lraoMRuIewESSFt+LBYVeUZFTBGlupiUZ/bi7rhtIuhMM8ahaKIstbu\nIgfQBHPqRkkiiKOJawIDAQABo4IBczCCAW8wHwYDVR0jBBgwFoAUDL2TaAzz3quj\nSWsrN1dH6pDjue0wHQYDVR0OBBYEFARoBLDWcsveEZQhaMVIR9mmJkUkMA4GA1Ud\nDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggr\nBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNV\nHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNT\nTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQu\ndGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRw\nOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAhBgNVHREEGjAYghZzYW1saWRwLnNpci5y\nZWRpcmlzLmVzMA0GCSqGSIb3DQEBBQUAA4IBAQB0gmr232YgpUC4HkwAHXaH91Zx\n8ZrwiEc8c4jGLh5VsaO0OqMfUEIXMuqZ+P9JNWVwlc6VLtmsypqTuqb9a06DS88q\n2o5sAUpbXZwhArhQs1bQnu5HJ6S84Ajn+NfMOyaO7NF8Colq/9lf3DihkT0jlD7i\nPHPMw2zauvtR/WPwdPszgfIOV/vkJ0rq9AjOXxSX7V2jpkxISGW/m93iahwXEoVF\nc8VXQhNjEfcm6uawmISjsyp6ta/U3e/8GJka2csDrF/bfipMBDSdWcLMscpYO8cb\nDC0L6vehZJ+lPz3wPH6YJmlstICZUdJIgDV3TUhmji6NNKa4p6by34QdYcDH"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RedIRIS"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RedIRIS"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rediris.es/index.php.en"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rediris.es/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RedIRIS"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RedIRIS"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://athens.bruford.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ellis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Zoe.Ellis@bruford.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Zoe"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wilson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:marc.wilson@bruford.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marc"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://athens.bruford.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://athens.bruford.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://athens.bruford.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bruford.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://portal.bruford.ac.uk/rbc_60x60.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  },
                  {
                    "text": "https://portal.bruford.ac.uk/rbc_16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rose Bruford College (Athens LA)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDoDCCAoigAwIBAgIJAIDJCuAZQOZXMA0GCSqGSIb3DQEBBQUAMD4xHTAbBgNV\n\t\t\t\t\t\tBAoTFFJvc2UgQnJ1Zm9yZCBDb2xsZWdlMR0wGwYDVQQDExRhdGhlbnMuYnJ1Zm9y\n\t\t\t\t\t\tZC5hYy51azAeFw0xMTA5MjIxNzA2MTJaFw0yMTA5MTkxNzA2MTJaMD4xHTAbBgNV\n\t\t\t\t\t\tBAoTFFJvc2UgQnJ1Zm9yZCBDb2xsZWdlMR0wGwYDVQQDExRhdGhlbnMuYnJ1Zm9y\n\t\t\t\t\t\tZC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMol/apZOolw\n\t\t\t\t\t\tgLqjxKayFRsnsSRFqMVmJxLdF9ATD/tm90corctZskNCt+MvfiPN98J/he37mOUt\n\t\t\t\t\t\tSuHxeGIyJgSDI+jj3/VVkIjJ+UMxnCTwhCMKnpio8ZEMKuBxbxkldCIg1M//ZOUc\n\t\t\t\t\t\tgeG/L1fTVUUAJZcVBTCOyRJ+S4UP6tnSlGp8nO1caceXR66pPlT+ziIKST3M1eRH\n\t\t\t\t\t\tdEpChP9repElvXsqcUST2FExVNGxaD/QUAnCHHY0QhmQ0abKwex8fU/np+ufIWZ5\n\t\t\t\t\t\ta8t4jbFoFJDB0VupAQfTPIs/ZPfYmVzk/vH4EBsXNfU39wtcnRTj9Xfkq/jq0QDH\n\t\t\t\t\t\tu0LgIpxuRdECAwEAAaOBoDCBnTAdBgNVHQ4EFgQUz9x2Vi5uTDixbL7zYpiTVSry\n\t\t\t\t\t\t9EowbgYDVR0jBGcwZYAUz9x2Vi5uTDixbL7zYpiTVSry9EqhQqRAMD4xHTAbBgNV\n\t\t\t\t\t\tBAoTFFJvc2UgQnJ1Zm9yZCBDb2xsZWdlMR0wGwYDVQQDExRhdGhlbnMuYnJ1Zm9y\n\t\t\t\t\t\tZC5hYy51a4IJAIDJCuAZQOZXMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAK5mVgWfbhwy9qJ/qT0bVTemdAjkXQU1uEEmfJc+cLMJtBtMV8nSE0s9cf1Q\n\t\t\t\t\t\tmsT/W7VCMWQp5IOoYO+xDDj/EMVmJNxHEG/DMn0iOUzdatNXgtfXbMjB0sChgTcH\n\t\t\t\t\t\tzqeg/kXgYSzQND40RRSB199nhy67qdtIF+aPJciCZ98u/xdPSL6kSPP7aPPLb1Wu\n\t\t\t\t\t\t+C6sZ+kdkNWDGLKgxanWSM2HDVta5MSm0n4Iy9kvlktFUcjiauWxV9MR3G0/bg+K\n\t\t\t\t\t\t/pqLuisfI0ssY3bi/CuLKBRAw8tabT34gYFnHPHxA7Cr9BBE1fUB/fA6q1utWatY\n\t\t\t\t\t\ttPNj67Bibl7d1TeU5BxZmOxrQKU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDoDCCAoigAwIBAgIJAIDJCuAZQOZXMA0GCSqGSIb3DQEBBQUAMD4xHTAbBgNV\n\t\t\t\t\t\tBAoTFFJvc2UgQnJ1Zm9yZCBDb2xsZWdlMR0wGwYDVQQDExRhdGhlbnMuYnJ1Zm9y\n\t\t\t\t\t\tZC5hYy51azAeFw0xMTA5MjIxNzA2MTJaFw0yMTA5MTkxNzA2MTJaMD4xHTAbBgNV\n\t\t\t\t\t\tBAoTFFJvc2UgQnJ1Zm9yZCBDb2xsZWdlMR0wGwYDVQQDExRhdGhlbnMuYnJ1Zm9y\n\t\t\t\t\t\tZC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMol/apZOolw\n\t\t\t\t\t\tgLqjxKayFRsnsSRFqMVmJxLdF9ATD/tm90corctZskNCt+MvfiPN98J/he37mOUt\n\t\t\t\t\t\tSuHxeGIyJgSDI+jj3/VVkIjJ+UMxnCTwhCMKnpio8ZEMKuBxbxkldCIg1M//ZOUc\n\t\t\t\t\t\tgeG/L1fTVUUAJZcVBTCOyRJ+S4UP6tnSlGp8nO1caceXR66pPlT+ziIKST3M1eRH\n\t\t\t\t\t\tdEpChP9repElvXsqcUST2FExVNGxaD/QUAnCHHY0QhmQ0abKwex8fU/np+ufIWZ5\n\t\t\t\t\t\ta8t4jbFoFJDB0VupAQfTPIs/ZPfYmVzk/vH4EBsXNfU39wtcnRTj9Xfkq/jq0QDH\n\t\t\t\t\t\tu0LgIpxuRdECAwEAAaOBoDCBnTAdBgNVHQ4EFgQUz9x2Vi5uTDixbL7zYpiTVSry\n\t\t\t\t\t\t9EowbgYDVR0jBGcwZYAUz9x2Vi5uTDixbL7zYpiTVSry9EqhQqRAMD4xHTAbBgNV\n\t\t\t\t\t\tBAoTFFJvc2UgQnJ1Zm9yZCBDb2xsZWdlMR0wGwYDVQQDExRhdGhlbnMuYnJ1Zm9y\n\t\t\t\t\t\tZC5hYy51a4IJAIDJCuAZQOZXMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAK5mVgWfbhwy9qJ/qT0bVTemdAjkXQU1uEEmfJc+cLMJtBtMV8nSE0s9cf1Q\n\t\t\t\t\t\tmsT/W7VCMWQp5IOoYO+xDDj/EMVmJNxHEG/DMn0iOUzdatNXgtfXbMjB0sChgTcH\n\t\t\t\t\t\tzqeg/kXgYSzQND40RRSB199nhy67qdtIF+aPJciCZ98u/xdPSL6kSPP7aPPLb1Wu\n\t\t\t\t\t\t+C6sZ+kdkNWDGLKgxanWSM2HDVta5MSm0n4Iy9kvlktFUcjiauWxV9MR3G0/bg+K\n\t\t\t\t\t\t/pqLuisfI0ssY3bi/CuLKBRAw8tabT34gYFnHPHxA7Cr9BBE1fUB/fA6q1utWatY\n\t\t\t\t\t\ttPNj67Bibl7d1TeU5BxZmOxrQKU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Rose Bruford College (Athens LA)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bruford.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Rose Bruford College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.upce.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sl\u00e1nsk\u00fd"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lukas.slansky@upce.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Luk\u00e1\u0161"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Krupi\u010dka"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "josef.krupicka@upce.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Josef"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "P\u0159ikryl"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pavel.prikryl@upce.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pavel"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.upce.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2010-09-22T11:28:45Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/university"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfzCCA2egAwIBAgIRANdGQbGBCwgib2T1mhEqCcMwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDA0MTAwMDAwMDBaFw0xNzA0MDkyMzU5NTlaMDkxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEUMBIGA1UEAxMLY2FzLnVwY2Uu\nY3owggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCldaLlEiSu8v6fIKmO\nw77MSNAC5Dbdy+rOcn1aNIqacXNOMOy+Nrky4mW8lm99WSd32JS4NuKVzRz6CFdJ\n1Xw5S8zw7wx0v2Shs6TkLdaj+vtiW4L3VEzrjv7EbpBGeVTwZ2QoqAkb6FxVPo66\nIItHvMJhL9FvzcSAlVNHBY4wwRkVRNr3e+sF++dbDG0n0IfwhV1BKxZkrS+tDcsu\nye0Q3nFyRegRXJL5DKOtyvn8m2m3FLr4j2YwfIyV3jP010i5LmfiH94h7luOi4iw\nNekD8S6ypSXW8Unbb6mF+s82d6ekiuRExmoyNA1JLhiZnkvgB9IRQNIxetAoOJhi\n3yxNAgMBAAGjggGDMIIBfzAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3V0fqkOO5\n7TAdBgNVHQ4EFgQUg+mGzfsymEgLzFJxq0ZNXjNrCggwDgYDVR0PAQH/BAQDAgWg\nMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMCIG\nA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1UdHwQzMDEwL6At\noCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3JsMG0G\nCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3MudGVyZW5h\nLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9vY3NwLnRj\ncy50ZXJlbmEub3JnMDEGA1UdEQQqMCiCC2Nhcy51cGNlLmN6ggtpZHAudXBjZS5j\neoIMaWRwMi51cGNlLmN6MA0GCSqGSIb3DQEBBQUAA4IBAQB0ON3JmGudQFnSxWvu\nHkRy7kq6+sV/WaV3TGYyRc6K7qpmjSP2OeT9fn86P28+jFpkA3GyXjjonBM8tn18\nhUc5UWW+8kYIrOmrZBvC4vemPLJX1azn8MYk29szd2BP+lpuzbDoDXVKf4g0pBZd\nKIGZ73yLT+O2bHOlpJGR+igW0nrpFAqPmlDyjsusiiXo1ynEkskpIMQyGFRkUfEz\nkobD7FV0OT6tgq+WtZEocauC5RF7ahIaMtvB5116857eV1L+dkwkcmXd6HEXch7r\nG5y8pHiwmqc1pqxprE0T8bp8kn8fTZ6VK6NI7nnWfcjeHCqegZcT48mMO47JpKPs\nwKnA"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "upce.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.upce.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.upce.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.upce.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.upce.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.upce.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.upce.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.upce.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.upce.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "upce.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.upce.cz/english/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.upce.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for University of Pardubice."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro Univerzitu Pardubice."
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.upce.cz/images/logo-40.png",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "37"
                  },
                  {
                    "text": "https://idp.upce.cz/images/logo-487-en.png",
                    "lang": "en",
                    "height": "487",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "745"
                  },
                  {
                    "text": "https://idp.upce.cz/images/logo-487-cs.png",
                    "lang": "cs",
                    "height": "487",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "792"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Pardubice"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Univerzita Pardubice"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfzCCA2egAwIBAgIRANdGQbGBCwgib2T1mhEqCcMwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDA0MTAwMDAwMDBaFw0xNzA0MDkyMzU5NTlaMDkxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEUMBIGA1UEAxMLY2FzLnVwY2Uu\nY3owggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCldaLlEiSu8v6fIKmO\nw77MSNAC5Dbdy+rOcn1aNIqacXNOMOy+Nrky4mW8lm99WSd32JS4NuKVzRz6CFdJ\n1Xw5S8zw7wx0v2Shs6TkLdaj+vtiW4L3VEzrjv7EbpBGeVTwZ2QoqAkb6FxVPo66\nIItHvMJhL9FvzcSAlVNHBY4wwRkVRNr3e+sF++dbDG0n0IfwhV1BKxZkrS+tDcsu\nye0Q3nFyRegRXJL5DKOtyvn8m2m3FLr4j2YwfIyV3jP010i5LmfiH94h7luOi4iw\nNekD8S6ypSXW8Unbb6mF+s82d6ekiuRExmoyNA1JLhiZnkvgB9IRQNIxetAoOJhi\n3yxNAgMBAAGjggGDMIIBfzAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3V0fqkOO5\n7TAdBgNVHQ4EFgQUg+mGzfsymEgLzFJxq0ZNXjNrCggwDgYDVR0PAQH/BAQDAgWg\nMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMCIG\nA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1UdHwQzMDEwL6At\noCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3JsMG0G\nCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3MudGVyZW5h\nLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9vY3NwLnRj\ncy50ZXJlbmEub3JnMDEGA1UdEQQqMCiCC2Nhcy51cGNlLmN6ggtpZHAudXBjZS5j\neoIMaWRwMi51cGNlLmN6MA0GCSqGSIb3DQEBBQUAA4IBAQB0ON3JmGudQFnSxWvu\nHkRy7kq6+sV/WaV3TGYyRc6K7qpmjSP2OeT9fn86P28+jFpkA3GyXjjonBM8tn18\nhUc5UWW+8kYIrOmrZBvC4vemPLJX1azn8MYk29szd2BP+lpuzbDoDXVKf4g0pBZd\nKIGZ73yLT+O2bHOlpJGR+igW0nrpFAqPmlDyjsusiiXo1ynEkskpIMQyGFRkUfEz\nkobD7FV0OT6tgq+WtZEocauC5RF7ahIaMtvB5116857eV1L+dkwkcmXd6HEXch7r\nG5y8pHiwmqc1pqxprE0T8bp8kn8fTZ6VK6NI7nnWfcjeHCqegZcT48mMO47JpKPs\nwKnA"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Pardubice"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Univerzita Pardubice"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.upce.cz/english/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.upce.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Pardubice"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Univerzita Pardubice"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.hct.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Darch"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:DarchT@hlcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tony"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cooley"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:CooleyD@hlcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.hct.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2010-01-12T15:47:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDdjCCAl4CCQDfc3alqzccaDANBgkqhkiG9w0BAQUFADB9MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjERMA8GA1UECBMISGVyZWZvcmQxEzARBgNVBAcTCkZvbGx5IExhbmUxJzAlBgNV\n\t\t\t\t\t\tBAoTHkhlcmVmb3JkIENvbGxlZ2Ugb2YgVGVjaG5vbG9neTEdMBsGA1UEAxMUc2hp\n\t\t\t\t\t\tYmJvbGV0aC5oY3QuYWMudWswHhcNMTMwODI3MDkyNzIzWhcNMzMwODIyMDkyNzIz\n\t\t\t\t\t\tWjB9MQswCQYDVQQGEwJHQjERMA8GA1UECBMISGVyZWZvcmQxEzARBgNVBAcTCkZv\n\t\t\t\t\t\tbGx5IExhbmUxJzAlBgNVBAoTHkhlcmVmb3JkIENvbGxlZ2Ugb2YgVGVjaG5vbG9n\n\t\t\t\t\t\teTEdMBsGA1UEAxMUc2hpYmJvbGV0aC5oY3QuYWMudWswggEiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tAQUAA4IBDwAwggEKAoIBAQDJUQE1iW+9qx6vTJryX7gJC751rIfdGGscSfDDeU9h\n\t\t\t\t\t\tajg6x36EmcA8+c4FYCDQ74uPS7rjSAedaj4AyZTeowz9BWF6vj+YaF8myeVZ/RSt\n\t\t\t\t\t\tvnc9YqOitKw9i1h9TGoQgR2t8PU+hp+47mtlyAT2WtD9DAHHteT7RjK+nwR3Q4iX\n\t\t\t\t\t\tCjQrmZuwUUrAraFDjhQtTPopUYe082QcwirOqL2DBICET6RCsTdlNfXTKWNYLRU0\n\t\t\t\t\t\t+Itxl1jX+o9bQaZdNeiiJD1f2+E0CCQmjB2Bovw3Lg3NQ1Namtn1u4t7VyWF7xs4\n\t\t\t\t\t\t0N0r9K0lgiPaawL3AuXIlAxnP1EhsxMXv7nOZSB0qftZAgMBAAEwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBADTTj8sJmX8p5EnhiLOWYFpKgkHrsmwEKYCwWzc+dLuH2DD8ixZ0\n\t\t\t\t\t\tg2xPQ/OjhsU/kH0DH7DCgLyn8Y0hzeZSV2w+aeJqxgIZirTa1snIIsYIZGYKpSqm\n\t\t\t\t\t\tLtF4rEYgkYUzZhU7Sg1F3/uuMZcxU30ZzI6LoBZiXjd4tlgwe7IB8WYNpm8wVq9w\n\t\t\t\t\t\tzCsZ4C4OWoz56oDjCrFYo4PJlF9/ERp+XPVpQ1rbAwQsbZzKY22ypn8D1dkIz6Cm\n\t\t\t\t\t\tc4KXdtRkv2kke2tteJOByaXt54uFj+NNJVic/IMJCVik7RFLyY+P5ut+1Gs90OIS\n\t\t\t\t\t\t1smsVkYPhj+xDQZ/npJN8HkOaB0rPVtrDmg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hct.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.hct.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.hct.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.hct.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.hct.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.hct.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.hct.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.hct.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.hct.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hct.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDdjCCAl4CCQDfc3alqzccaDANBgkqhkiG9w0BAQUFADB9MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjERMA8GA1UECBMISGVyZWZvcmQxEzARBgNVBAcTCkZvbGx5IExhbmUxJzAlBgNV\n\t\t\t\t\t\tBAoTHkhlcmVmb3JkIENvbGxlZ2Ugb2YgVGVjaG5vbG9neTEdMBsGA1UEAxMUc2hp\n\t\t\t\t\t\tYmJvbGV0aC5oY3QuYWMudWswHhcNMTMwODI3MDkyNzIzWhcNMzMwODIyMDkyNzIz\n\t\t\t\t\t\tWjB9MQswCQYDVQQGEwJHQjERMA8GA1UECBMISGVyZWZvcmQxEzARBgNVBAcTCkZv\n\t\t\t\t\t\tbGx5IExhbmUxJzAlBgNVBAoTHkhlcmVmb3JkIENvbGxlZ2Ugb2YgVGVjaG5vbG9n\n\t\t\t\t\t\teTEdMBsGA1UEAxMUc2hpYmJvbGV0aC5oY3QuYWMudWswggEiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tAQUAA4IBDwAwggEKAoIBAQDJUQE1iW+9qx6vTJryX7gJC751rIfdGGscSfDDeU9h\n\t\t\t\t\t\tajg6x36EmcA8+c4FYCDQ74uPS7rjSAedaj4AyZTeowz9BWF6vj+YaF8myeVZ/RSt\n\t\t\t\t\t\tvnc9YqOitKw9i1h9TGoQgR2t8PU+hp+47mtlyAT2WtD9DAHHteT7RjK+nwR3Q4iX\n\t\t\t\t\t\tCjQrmZuwUUrAraFDjhQtTPopUYe082QcwirOqL2DBICET6RCsTdlNfXTKWNYLRU0\n\t\t\t\t\t\t+Itxl1jX+o9bQaZdNeiiJD1f2+E0CCQmjB2Bovw3Lg3NQ1Namtn1u4t7VyWF7xs4\n\t\t\t\t\t\t0N0r9K0lgiPaawL3AuXIlAxnP1EhsxMXv7nOZSB0qftZAgMBAAEwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBADTTj8sJmX8p5EnhiLOWYFpKgkHrsmwEKYCwWzc+dLuH2DD8ixZ0\n\t\t\t\t\t\tg2xPQ/OjhsU/kH0DH7DCgLyn8Y0hzeZSV2w+aeJqxgIZirTa1snIIsYIZGYKpSqm\n\t\t\t\t\t\tLtF4rEYgkYUzZhU7Sg1F3/uuMZcxU30ZzI6LoBZiXjd4tlgwe7IB8WYNpm8wVq9w\n\t\t\t\t\t\tzCsZ4C4OWoz56oDjCrFYo4PJlF9/ERp+XPVpQ1rbAwQsbZzKY22ypn8D1dkIz6Cm\n\t\t\t\t\t\tc4KXdtRkv2kke2tteJOByaXt54uFj+NNJVic/IMJCVik7RFLyY+P5ut+1Gs90OIS\n\t\t\t\t\t\t1smsVkYPhj+xDQZ/npJN8HkOaB0rPVtrDmg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Herefordshire and Ludlow College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hct.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Herefordshire and Ludlow College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://wiki.osris.org",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "bmeekhof@umich.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benjeman Meekhof"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "bmeekhof@umich.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benjeman Meekhof"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "smckee@umich.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shawn McKee"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://wiki.osris.org",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Michigan"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.umich.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Michigan"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wiki.osris.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://wiki.osris.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://wiki.osris.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://wiki.osris.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.osris.org"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "OSiRIS will provide a distributed, multi-institutional storage infrastructure that lets researchers write, manage, and share data from their own computing facility locations."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Open Storage Research Infrastructure"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJAPPtURtwvG1+MA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDndpa2kub3NyaXMub3JnMB4XDTE2MDExNTIwMDQ1N1oXDTI2MDExMjIwMDQ1\nN1owGTEXMBUGA1UEAxMOd2lraS5vc3Jpcy5vcmcwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDxrrZ2C+1OdxvrF/d8xT1FUnZtnVVz0tQ+LnWF/J+kwyZP\nUqaVU/TwE47SqzxNi2EsUyd1xeD0gKtWnBi49oaEFnZlOmbQHQJk80XCVloNhh05\nUHevAlSvj+ZocxYtO7pEnxrRCSRFSnc1Sa31t/koaDJG8TFLWwgJcPhmYj18Clmi\nbZ85/+wxS7AmMaG/rYysvBRJu5ukyIQNRTPqZWmVxTAuQVbyDRpUHhtEvgSOWGzU\nrI/ey8O1T8zxjlLYSu/BPb/IVLrlHvIiTLnEw9KHzSgDGDwS5mk/a8pWlP7egUJ1\ncDeRkd/eZKzAUUg0+cg2F91US5WpFf1ZO2OyQAoNAgMBAAGjPDA6MBkGA1UdEQQS\nMBCCDndpa2kub3NyaXMub3JnMB0GA1UdDgQWBBSwVB2ckkXkWzGakcc94iSNBhbR\nNDANBgkqhkiG9w0BAQUFAAOCAQEA3mUqiLg+6dNh39h+dnqxba1j4zCWHd8rYfl9\nSZeZib1QQiCmUxyq2UbktxvvJeiPTgJO4VNSwL2RC4OaFmmpDob23TC0BjNrDeGJ\nGwvpWl7Y60MxyalNn4qcqpyaE4macMbIUFX9Z7dl6omabFtDaAvxs18OzwT0AN0D\n0Y5kLjJ8nV8DEC/A+h9A5ahVTSZ2TCYcmgcDNzmjLawa0Pw5Y3Mn5QGW3Uv1iqum\nfnCGgpa42xnggcZe/ghOHK2MbL0B4Q/R5Gmmj9QKbb6FzGFuyXZr3EmqZM4toGLD\n5WjtmZyVsNlqGoDtO350UYicc4AHu2Bic9RtuyvJq5ONACyMNw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wiki.osris.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://wiki.osris.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wiki.osris.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://wiki.osris.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Open Storage Research Infrastructure"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "OSiRIS will provide a distributed, multi-institutional storage infrastructure that lets researchers write, manage, and share data from their own computing facility locations."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ct0.cirqahosting.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Orchard"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lee@isoxford.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lee"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Salvesen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:david@isoxford.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ct0.cirqahosting.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-01-23T14:28:05Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IS Oxford Heritage Cirqa Test Server 0"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.isoxford.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IS Oxford Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ct0.cirqahosting.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ct0.cirqahosting.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ct0.cirqahosting.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ct0.cirqahosting.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ct0.cirqahosting.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IS Oxford's test server zero for Heritage Cirqa and Heritage Online."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IS Oxford Heritage Cirqa Test Server 0"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ct0.cirqahosting.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ct0.cirqahosting.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFTCCAf2gAwIBAgIJAJXCrMqE2P9KMA0GCSqGSIb3DQEBBQUAMCUxIzAhBgNV\n\t\t\t\t\t\tBAMTGmN0MC5pc294Zm9yZC1ob3N0aW5nLmxvY2FsMB4XDTE1MDEyMjE2MDMzOFoX\n\t\t\t\t\t\tDTI1MDExOTE2MDMzOFowJTEjMCEGA1UEAxMaY3QwLmlzb3hmb3JkLWhvc3Rpbmcu\n\t\t\t\t\t\tbG9jYWwwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDF0P3NYvYeSAcJ\n\t\t\t\t\t\tpb6PAVJ3BJlwqOYn/gI32UQyMkDx1tuma1YMguN+qFhPXjPelPGLQjTu5uiVUKxq\n\t\t\t\t\t\t923GT3K+zOjeHA2PYLEPb87c/4gEKNcISQ4+7HRbcQ4CNpka/gMYZwoj2n03AWR2\n\t\t\t\t\t\t+3cLDIjFkxgGLUvCqf+woMCe4ibfDnNdNfHIRGHqf9Ig5/kA0rLLwdWiG3Ni3lS6\n\t\t\t\t\t\tXnfbZiFlrl+pGphxn7DTz/kIOO30eyLqsMYTbN4a7stsTognmIvMn81SsHZFDlmc\n\t\t\t\t\t\tbjG6Li4pup93azLJ/oL71lpCjq8X1UpkWjPPSnCVUcyGyhlbgt2MXAKDyzYyxW0i\n\t\t\t\t\t\tFfWy+L6/AgMBAAGjSDBGMCUGA1UdEQQeMByCGmN0MC5pc294Zm9yZC1ob3N0aW5n\n\t\t\t\t\t\tLmxvY2FsMB0GA1UdDgQWBBT8AZVMa93QvqUSr3jzjjqrnQbrUTANBgkqhkiG9w0B\n\t\t\t\t\t\tAQUFAAOCAQEAYjPmH6RGRlaX8F7nFlBvBw3emJiDWM37n5AsaOFpFvT4cM9+821E\n\t\t\t\t\t\ttkRHXx6RUgQsY0wtEDgGnfwUiOSMWZgDwHQ1tJIU3ZiUJX5jGvmVVXXQc1DP2aqS\n\t\t\t\t\t\t7+W3hpSjMDqSg4UEdbdIRK6tp33FDU+N3ODPpMQiA9BO/9+I5HlVF9qTf3bboMRn\n\t\t\t\t\t\tvzlz8MaQdTjd0WCNIWwgwHDV9oarqFVlR2ua47I4S0+uFZuVvANjT3aWHrs+HQEC\n\t\t\t\t\t\t2d+z3aSYxXX1niPf2VzWZAt+EsudeCodby4bcK/ZAyJzWi4PaJ9RAlk7JFfVclmd\n\t\t\t\t\t\tklAUpve3xeJcOQJGYv1NItVmF0PCkrmu0Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ct0.cirqahosting.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ct0.cirqahosting.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ct0.cirqahosting.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ct0.cirqahosting.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ct0.cirqahosting.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ct0.cirqahosting.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.incommonfederation.org/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "techsupport@internet2.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tech Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.incommonfederation.org/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.incommonfederation.org/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.incommonfederation.org/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.incommonfederation.org/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.incommonfederation.org/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.incommonfederation.org:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "incommonfederation.org"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "incommon.org"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "InCommon Operations"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIBADANBgkqhkiG9w0BAQQFADAlMSMwIQYDVQQDExppZHAu\naW5jb21tb25mZWRlcmF0aW9uLm9yZzAeFw0xMjA4MjcyMDUyMzFaFw0yMjA4MjUy\nMDUyMzFaMCUxIzAhBgNVBAMTGmlkcC5pbmNvbW1vbmZlZGVyYXRpb24ub3JnMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAt+GeQ4P+Zj5FoWT/4EpmKRSN\nZQ1dNgYvMZDPLpfEbY6Ugumn9CjZeTOXS678k7o83Otrzk1fWzjenOGRDnvSasgE\nFASa5ZFYOfG/7IsAvta1IE/TQsFQ3I79IU53lGSpNFoE+5n56sNii1IGYc8vnkDa\nYKfyaOd6jESVjDOP7kh9Fs6lAe/bnpJhmAzXEgFtg48ABPDuC3CMQkXhNmMz822Z\nT2LGnxACgqYIJRRzoC+NMnHH4sp4c+mBNvVIrEkn4YUKUVLuXoGpS7NKURyrDfcF\nsZ7iXaEA58JgFUfEK9enE6f7UAI28aYzNm4OpZmNA3+XuPuiG+7juxJci39umQID\nAQABo34wfDAdBgNVHQ4EFgQU8BBxA91k1pP0f/luBTRl3sPNQNIwTQYDVR0jBEYw\nRIAU8BBxA91k1pP0f/luBTRl3sPNQNKhKaQnMCUxIzAhBgNVBAMTGmlkcC5pbmNv\nbW1vbmZlZGVyYXRpb24ub3JnggEAMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEE\nBQADggEBAIMEpWyaYAfJZsULpiJqFjkNACXpQmLIEVCudv4U7xxHi9wnlAFHc3zM\nArolddB+y8ff9DorJNe2OM9+Xi39vtVkV8eqspmhJL4iW0uXcHeD+02z0w8JySGv\nIsdNGAFeVZn/1v9+nv34z8rvnfFDvP5kfyL2xXeV0rn9ChD/utvf3C0+6HvT1Zls\n1AG71uT/nnMWTGj7xg2rP9+bxVlZLpWliArevXac0/OjOOKQp8x6n+DHE0NVSENK\n5QOJmNi7uAS1xr5AvbV8eVrOGtqemGVlSxJAtjG7DStzfLGDoMKOR5NkBmUzK+8i\nFZHt70mZqw2O8mIkp6DuO+EJLYkB1/4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "InCommon Operations"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.incommon.org"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "InCommon LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-07.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-07.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-07.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-07.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-07.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-07.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-07.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-07.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-07.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;07"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;07"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-07.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-07.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJALmf8Dsfzo7FMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wNy5sYWRvay51bXUuc2UwHhcNMTIwNjI5MTIwODExWhcNMjIw\nNjI3MTIwODExWjAhMR8wHQYDVQQDExZsYWRvazMtMDcubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzEG4o2J3L67j6nYIHR3QLRDG\nUHr3fslU7DbyUWXCt/KFZ0kvKPMu8tZRhMDyY30sPcb+q/Y3j2sLAL+e9zfw99Jb\n3FWya100c8/G+Rj0MB/YKGE+FDqknSCCz4Lqq24ZTBcx/PZeg7dOD1PuNPLcf70q\nJq2Sv20JCV1HWx1IcYXy2lz7xOelBem0l80J7Wvmmxm2lXNwDFk8BieMAZB3IILy\nczbEkv57c7n7nladzP8h+N6Tjl1970/FSONPjzmCluzA+1HEBV+k74xL4UqhzVeT\n4qtb1U+1SjT1ptXMZXrSdTQu6OJZsHHkRlcQ3tXyV6mcERGlgfKjmMPGYFEcVwID\nAQABo2swaTBIBgNVHREEQTA/ghZsYWRvazMtMDcubGFkb2sudW11LnNlhiVodHRw\nczovL2xhZG9rMy0wNy5sYWRvay51bXUuc2UvZ3VpLXNwMB0GA1UdDgQWBBSZUY2a\nI5a11kJUImB9vYgmMRHMXTANBgkqhkiG9w0BAQUFAAOCAQEAMiC2g5BTkeg2Hbv+\nlQKqQQr98luYHRvq73X29VugyQ6M/P45a+WoNZYhdcZY6H0xiOhabLNRS5tuyXHo\n7jiViy978WQ+j3n57I+PfhYRIBTtAePxPTktQg/jXfgvCT5NJmh+MC2EIeaMH4cR\nYP9Jt8TrLyBOiIpQGnPmxbagAb4X0VNJ1kwA7SkpRexxxESZcHBE4fTveG5H14+l\nr4n/T3toliD0lP8WA2tafbkPzdQUgtsCNzL0L/6CW5RsrlokMKOGZBQBS4EPbtgw\nLRt4O9+n+IeXQn445+k59QZ72enbnRThjnGDHA4Xw620T5LlKVHywEozdtaXBQSK\nLB5BtA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-07.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-07.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-07.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-07.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-07.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-07.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-07.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-07.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-07.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-07.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibtest.zetoc.mimas.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:zetoc@mimas.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Zetoc Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mimas-shib-tech@listserv.manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mimas Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibtest.zetoc.mimas.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MIMAS Zetoc Service Test"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://mimas.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Manchester"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibtest.zetoc.mimas.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibtest.zetoc.mimas.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibtest.zetoc.mimas.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibtest.zetoc.mimas.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID+jCCAuKgAwIBAgIJALJQK6WnWBR9MA0GCSqGSIb3DQEBBQUAMH4xCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRMwEQYDVQQHEwpNYW5jaGVzdGVyMSUwIwYDVQQKExxUaGUgVW5pdmVy\n\t\t\t\t\t\tc2l0eSBvZiBNYW5jaGVzdGVyMQ4wDAYDVQQLEwVNaW1hczEjMCEGA1UEAxMac2hp\n\t\t\t\t\t\tYnRlc3QuemV0b2MubWltYXMuYWMudWswHhcNMTMwMTMwMTIyODQwWhcNMjMwMTI4\n\t\t\t\t\t\tMTIyODQwWjB+MQswCQYDVQQGEwJHQjETMBEGA1UEBxMKTWFuY2hlc3RlcjElMCMG\n\t\t\t\t\t\tA1UEChMcVGhlIFVuaXZlcnNpdHkgb2YgTWFuY2hlc3RlcjEOMAwGA1UECxMFTWlt\n\t\t\t\t\t\tYXMxIzAhBgNVBAMTGnNoaWJ0ZXN0LnpldG9jLm1pbWFzLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAwYrzV9W4FRjd960nw7LQiR5ThpyMeY1K\n\t\t\t\t\t\ttDzt4WG6K3hKfPrvbddxa5RjsQV2HbnTjEguOwM5pVqgYClgEP5TDRPWzzKwp/uF\n\t\t\t\t\t\tl1RNPFAdzpYZry3+b5IOyTipOLaH0lSX2sxGeHzeM42Qk7sv5ze8M1OifovcMEUK\n\t\t\t\t\t\tNZER6/evAJbUSwIpuYrom6WSyRP9cPFz/8aLHoQjVsk1GcXXEcfACGWKCHO4ImaB\n\t\t\t\t\t\ty1+PfLgM7z8x4hGYM0Ovrmy6S3F4lnoS9E44l1nee2eicPEWRFepdprKEcl8sdF+\n\t\t\t\t\t\tt/uhBeDX7AH2D3dzCJ7yxRzNKtOeKCKgpUjNxCTl75XmhGTLk4f4LwIDAQABo3sw\n\t\t\t\t\t\teTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBD\n\t\t\t\t\t\tZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUwxHyq5lUAiW+S9Wcs0KtNf9+mGswHwYDVR0j\n\t\t\t\t\t\tBBgwFoAUwxHyq5lUAiW+S9Wcs0KtNf9+mGswDQYJKoZIhvcNAQEFBQADggEBAGf5\n\t\t\t\t\t\tLwIB+2JMqPXXkE8giX64mlkKDUDvwht3dlkN5vV9pbejCghaY/aEFGGOw88tmGhw\n\t\t\t\t\t\tL+as0lPq0kCvdUGRP1/N5zU198gLOvL6i6Oo3psCVgSIobEd+eIjBqJj+/KcjyU9\n\t\t\t\t\t\tyhembQl9SuEgzUiGzkE2giwOv1SnD605/sSjrnBuPdI2PU3/r0tsipB1IN4PXRtK\n\t\t\t\t\t\tepdNWNz3pMY8i82Zt86ehzgR/V1UJhAgJ53v8UCaAj+OuQGSiiOBUGnG8eDbm9ET\n\t\t\t\t\t\tbA1OE1Qdd7atomQvFpRilpWvYVFDjd9v7oEovrcc0oZJ9ObIcFug951Kfpvhk4d7\n\t\t\t\t\t\tXR9LvyjviSLUKhaEZa0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibtest.zetoc.mimas.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibtest.zetoc.mimas.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibtest.zetoc.mimas.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibtest.zetoc.mimas.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibtest.zetoc.mimas.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibtest.zetoc.mimas.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibtest.zetoc.mimas.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibtest.zetoc.mimas.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibtest.zetoc.mimas.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibtest.zetoc.mimas.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://login.ligo.org/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "scott.koranda@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Scott Koranda"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "warren.anderson@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Warren Anderson"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rt-auth@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LIGO Identity Management Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lsc-seccomm@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LIGO Security Committee"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://login.ligo.org/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login1.ligo.org:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEljCCA36gAwIBAgICAJwwDQYJKoZIhvcNAQEFBQAwgYcxEzARBgoJkiaJk/Is\nZAEZFgNvcmcxFDASBgoJkiaJk/IsZAEZFgRsaWdvMQ0wCwYDVQQKEwRMSUdPMSAw\nHgYDVQQLExdDZXJ0aWZpY2F0ZSBBdXRob3JpdGllczEVMBMGA1UECxMMV2ViIFNl\ncnZpY2VzMRIwEAYDVQQDEwlMSUdPIENBIDEwHhcNMTMxMTEyMjEzNjI3WhcNMjMx\nMTEyMjEzNjI3WjBzMRMwEQYKCZImiZPyLGQBGRYDb3JnMRQwEgYKCZImiZPyLGQB\nGRYEbGlnbzENMAsGA1UEChMETElHTzEVMBMGA1UECxMMV2ViIFNlcnZpY2VzMSAw\nHgYDVQQDExdsaWdvLWxvZ2luLnBoeXMudXdtLmVkdTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAMQHAdPnOmQc9Wa++z1KJUY8wNdX+NsGa7VdFwBcgrnr\nU6qY0OrUpKKGP1q9+3rbdhw+26D3NtCeydn5MQEr2bwrFQOPZqhFNsgGRmXtJc7T\n4uJOJN9cllEZN1hqU0EqXD9Gi+SQ07BTLO1HG0t70DkydQxXI2M4OQ0sDP/7SSab\nnSvztjXeAj98pVyqLj44JTOETFQTceJ0KcMnaAjlZKTFvU1l2lW8uPyQEgQP5cLM\nQS7ZuYtkp6M2vwViQMMksKqSzx0MXjjWH5Hs8ozfHF84tyJUq/2BtmqHhWoWCq+3\nEYEbS4GULfWbyK4oOIl/F3pNgR8WixtUXPz6dy1+Q7ECAwEAAaOCAR0wggEZMAwG\nA1UdEwEB/wQCMAAwDgYDVR0PAQH/BAQDAgSwMB0GA1UdJQQWMBQGCCsGAQUFBwMB\nBggrBgEFBQcDAjAZBgNVHSAEEjAQMA4GDCsGAQQBgfpGAgECATA5BgNVHR8EMjAw\nMC6gLKAqhihodHRwOi8vY2EubGlnby5vcmcvNTQxNDA0YzMvNTQxNDA0YzMuY3Js\nMB8GA1UdIwQYMBaAFFJu3Xuqb4VcCCLTl5+tfyNWHmrRMGMGA1UdEQRcMFqCF2xp\nZ28tbG9naW4ucGh5cy51d20uZWR1gg5sb2dpbi5saWdvLm9yZ4IPbG9naW4xLmxp\nZ28ub3JnggxpZHAubGlnby5vcmeBEHJ0LWF1dGhAbGlnby5vcmcwDQYJKoZIhvcN\nAQEFBQADggEBAF5M6bIShQM33qnNK6/WmtzNP/+x/tW+OKKzdp6Aynl5fGm0QmdK\n0qeI2T3fYHqT7KTVJqA6NFcXbQUrHmJwEAtIlD8gklHMI3LVcy460SBfkRXwEIXt\nrQ+vktmJxzU725XT8VLzkt5i8c+xibVTJVrpYXYWXEDLP/tkMRqMtWO72aek2RV0\npFApwEgu91iPFEL5DU31dbf+tUFQglt1lofm2EiLAq6auTphsTs6nu5b8k+eh26y\n4f7CtSOMPJoOvBC7ZZj5spPMYP1nWcDsQIF6LylwyNI2XxBIll/FuM9mSBAZ6fSL\nQSLgCeM9S63LSKOHx0cXPde6ccFKoDtcNiY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEaTCCA1GgAwIBAgIBKTANBgkqhkiG9w0BAQUFADCBhzETMBEGCgmSJomT8ixk\nARkWA29yZzEUMBIGCgmSJomT8ixkARkWBGxpZ28xDTALBgNVBAoTBExJR08xIDAe\nBgNVBAsTF0NlcnRpZmljYXRlIEF1dGhvcml0aWVzMRUwEwYDVQQLEwxXZWIgU2Vy\ndmljZXMxEjAQBgNVBAMTCUxJR08gQ0EgMTAeFw0xMDEyMjAxOTQzMjFaFw0yMDEy\nMTkxOTQzMjFaMHMxEzARBgoJkiaJk/IsZAEZFgNvcmcxFDASBgoJkiaJk/IsZAEZ\nFgRsaWdvMQ0wCwYDVQQKEwRMSUdPMRUwEwYDVQQLEwxXZWIgU2VydmljZXMxIDAe\nBgNVBAMTF2xpZ28tbG9naW4ucGh5cy51d20uZWR1MIIBIjANBgkqhkiG9w0BAQEF\nAAOCAQ8AMIIBCgKCAQEA5aWnGpOBykQtq5ybHIORdGTB+2VZ/2btQDb28/c3ClCI\nXmDte4OSxxon33EVPZcdWWAts03dWvvR3EZCsIqUADwAsG97pyCPqJ5A44/Cp3XN\nYc2sGnnn8/iKdjaTuiD0huf075a/QcqO6qhE6RQ0Zybw9UmV//iYCb1CqG0NbuTZ\nsBm+SK/9MkkLYaKYXP5dR1qxiHRDcH1WRn/lcTG3Ln6WOrwJn+e7dVRObGMAIDzi\nNJH/2B4PcgEW4Gc/FwghkcZ61Qj15NpuTg0Y9NwsCrpuXaTkuwVKU8w8rS7gOgdl\nOCa+aMeU6sKVvjDxmQC5FboZUwlGIAwAHkT2pVCv9wIDAQABo4HyMIHvMAwGA1Ud\nEwEB/wQCMAAwDgYDVR0PAQH/BAQDAgSwMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggr\nBgEFBQcDAjAZBgNVHSAEEjAQMA4GDCsGAQQBgfpGAgECATA5BgNVHR8EMjAwMC6g\nLKAqhihodHRwOi8vY2EubGlnby5vcmcvNTQxNDA0YzMvNTQxNDA0YzMuY3JsMB8G\nA1UdIwQYMBaAFFJu3Xuqb4VcCCLTl5+tfyNWHmrRMDkGA1UdEQQyMDCCLmxpZ28t\nbG9naW4ucGh5cy51d20uZWR1OnNjb3R0LmtvcmFuZGFAbGlnby5vcmcwDQYJKoZI\nhvcNAQEFBQADggEBADd3Vkq5UNNf0q0Tm4tM19o8Zo5vSA9qA09qOHH270MKakVh\nNXeikHm4FMJKE731D8vwqUDFX0PqN9ndkWLqI9+vtPstqbl7xEbhXfFAjvAj6ieP\nAlKinu+VwG8lqcSRzrgDl40DGZbxYwcqaLqkY3DvJQphcL9+cMVNwixR+2ceACVU\n9nJhBjNdtVo5HiayNy1qIHoVnyxfRJcET5Z9fl9WoTGBkQgd2+XNBxe3ECLpe4gw\nGKBexp0LpbBvqRLMito7jIbPE5NzCjw69NpcIE+COkQc+ifV8FbD0OQOin06/qDi\n0+fCAYmI2uE8jfuGOhKWTsSUWe35LFWIOuaIPZo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ligo.org"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.ligo.org/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.ligo.org/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.ligo.org/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.ligo.org/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login1.ligo.org:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ligo.org"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://dcc.ligo.org/cgi-bin/DocDB/ShowDocument?docid=89286"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "LIGO Scientific Collaboration"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Laser Interferometer Gravitational-Wave Observatory (LIGO)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.ligo.org/SAML2/metadata/ui/ligologo80x60.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://dcc.ligo.org/cgi-bin/DocDB/ShowDocument?docid=89243"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEljCCA36gAwIBAgICAJwwDQYJKoZIhvcNAQEFBQAwgYcxEzARBgoJkiaJk/Is\nZAEZFgNvcmcxFDASBgoJkiaJk/IsZAEZFgRsaWdvMQ0wCwYDVQQKEwRMSUdPMSAw\nHgYDVQQLExdDZXJ0aWZpY2F0ZSBBdXRob3JpdGllczEVMBMGA1UECxMMV2ViIFNl\ncnZpY2VzMRIwEAYDVQQDEwlMSUdPIENBIDEwHhcNMTMxMTEyMjEzNjI3WhcNMjMx\nMTEyMjEzNjI3WjBzMRMwEQYKCZImiZPyLGQBGRYDb3JnMRQwEgYKCZImiZPyLGQB\nGRYEbGlnbzENMAsGA1UEChMETElHTzEVMBMGA1UECxMMV2ViIFNlcnZpY2VzMSAw\nHgYDVQQDExdsaWdvLWxvZ2luLnBoeXMudXdtLmVkdTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAMQHAdPnOmQc9Wa++z1KJUY8wNdX+NsGa7VdFwBcgrnr\nU6qY0OrUpKKGP1q9+3rbdhw+26D3NtCeydn5MQEr2bwrFQOPZqhFNsgGRmXtJc7T\n4uJOJN9cllEZN1hqU0EqXD9Gi+SQ07BTLO1HG0t70DkydQxXI2M4OQ0sDP/7SSab\nnSvztjXeAj98pVyqLj44JTOETFQTceJ0KcMnaAjlZKTFvU1l2lW8uPyQEgQP5cLM\nQS7ZuYtkp6M2vwViQMMksKqSzx0MXjjWH5Hs8ozfHF84tyJUq/2BtmqHhWoWCq+3\nEYEbS4GULfWbyK4oOIl/F3pNgR8WixtUXPz6dy1+Q7ECAwEAAaOCAR0wggEZMAwG\nA1UdEwEB/wQCMAAwDgYDVR0PAQH/BAQDAgSwMB0GA1UdJQQWMBQGCCsGAQUFBwMB\nBggrBgEFBQcDAjAZBgNVHSAEEjAQMA4GDCsGAQQBgfpGAgECATA5BgNVHR8EMjAw\nMC6gLKAqhihodHRwOi8vY2EubGlnby5vcmcvNTQxNDA0YzMvNTQxNDA0YzMuY3Js\nMB8GA1UdIwQYMBaAFFJu3Xuqb4VcCCLTl5+tfyNWHmrRMGMGA1UdEQRcMFqCF2xp\nZ28tbG9naW4ucGh5cy51d20uZWR1gg5sb2dpbi5saWdvLm9yZ4IPbG9naW4xLmxp\nZ28ub3JnggxpZHAubGlnby5vcmeBEHJ0LWF1dGhAbGlnby5vcmcwDQYJKoZIhvcN\nAQEFBQADggEBAF5M6bIShQM33qnNK6/WmtzNP/+x/tW+OKKzdp6Aynl5fGm0QmdK\n0qeI2T3fYHqT7KTVJqA6NFcXbQUrHmJwEAtIlD8gklHMI3LVcy460SBfkRXwEIXt\nrQ+vktmJxzU725XT8VLzkt5i8c+xibVTJVrpYXYWXEDLP/tkMRqMtWO72aek2RV0\npFApwEgu91iPFEL5DU31dbf+tUFQglt1lofm2EiLAq6auTphsTs6nu5b8k+eh26y\n4f7CtSOMPJoOvBC7ZZj5spPMYP1nWcDsQIF6LylwyNI2XxBIll/FuM9mSBAZ6fSL\nQSLgCeM9S63LSKOHx0cXPde6ccFKoDtcNiY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEaTCCA1GgAwIBAgIBKTANBgkqhkiG9w0BAQUFADCBhzETMBEGCgmSJomT8ixk\nARkWA29yZzEUMBIGCgmSJomT8ixkARkWBGxpZ28xDTALBgNVBAoTBExJR08xIDAe\nBgNVBAsTF0NlcnRpZmljYXRlIEF1dGhvcml0aWVzMRUwEwYDVQQLEwxXZWIgU2Vy\ndmljZXMxEjAQBgNVBAMTCUxJR08gQ0EgMTAeFw0xMDEyMjAxOTQzMjFaFw0yMDEy\nMTkxOTQzMjFaMHMxEzARBgoJkiaJk/IsZAEZFgNvcmcxFDASBgoJkiaJk/IsZAEZ\nFgRsaWdvMQ0wCwYDVQQKEwRMSUdPMRUwEwYDVQQLEwxXZWIgU2VydmljZXMxIDAe\nBgNVBAMTF2xpZ28tbG9naW4ucGh5cy51d20uZWR1MIIBIjANBgkqhkiG9w0BAQEF\nAAOCAQ8AMIIBCgKCAQEA5aWnGpOBykQtq5ybHIORdGTB+2VZ/2btQDb28/c3ClCI\nXmDte4OSxxon33EVPZcdWWAts03dWvvR3EZCsIqUADwAsG97pyCPqJ5A44/Cp3XN\nYc2sGnnn8/iKdjaTuiD0huf075a/QcqO6qhE6RQ0Zybw9UmV//iYCb1CqG0NbuTZ\nsBm+SK/9MkkLYaKYXP5dR1qxiHRDcH1WRn/lcTG3Ln6WOrwJn+e7dVRObGMAIDzi\nNJH/2B4PcgEW4Gc/FwghkcZ61Qj15NpuTg0Y9NwsCrpuXaTkuwVKU8w8rS7gOgdl\nOCa+aMeU6sKVvjDxmQC5FboZUwlGIAwAHkT2pVCv9wIDAQABo4HyMIHvMAwGA1Ud\nEwEB/wQCMAAwDgYDVR0PAQH/BAQDAgSwMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggr\nBgEFBQcDAjAZBgNVHSAEEjAQMA4GDCsGAQQBgfpGAgECATA5BgNVHR8EMjAwMC6g\nLKAqhihodHRwOi8vY2EubGlnby5vcmcvNTQxNDA0YzMvNTQxNDA0YzMuY3JsMB8G\nA1UdIwQYMBaAFFJu3Xuqb4VcCCLTl5+tfyNWHmrRMDkGA1UdEQQyMDCCLmxpZ28t\nbG9naW4ucGh5cy51d20uZWR1OnNjb3R0LmtvcmFuZGFAbGlnby5vcmcwDQYJKoZI\nhvcNAQEFBQADggEBADd3Vkq5UNNf0q0Tm4tM19o8Zo5vSA9qA09qOHH270MKakVh\nNXeikHm4FMJKE731D8vwqUDFX0PqN9ndkWLqI9+vtPstqbl7xEbhXfFAjvAj6ieP\nAlKinu+VwG8lqcSRzrgDl40DGZbxYwcqaLqkY3DvJQphcL9+cMVNwixR+2ceACVU\n9nJhBjNdtVo5HiayNy1qIHoVnyxfRJcET5Z9fl9WoTGBkQgd2+XNBxe3ECLpe4gw\nGKBexp0LpbBvqRLMito7jIbPE5NzCjw69NpcIE+COkQc+ifV8FbD0OQOin06/qDi\n0+fCAYmI2uE8jfuGOhKWTsSUWe35LFWIOuaIPZo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://login.ligo.org/support.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "LIGO Scientific Collaboration"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ligo.caltech.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LIGO Scientific Collaboration"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.renater.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@support.renater.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.renater.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2010-10-15T16:51:48Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.renater.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.renater.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.renater.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "renater.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.renater.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "15",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "GIP RENATER"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "GIP RENATER"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAOKBqJWqJFq6T2dHTEfrhVJRssecMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC5yZW5hdGVyLmZyMB4XDTEzMDMwMTEwMjUwNVoX\nDTMzMDMwMTEwMjUwNVowGTEXMBUGA1UEAxMOaWRwLnJlbmF0ZXIuZnIwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCo6i0pn7lTyN4PkneU7/zJAG4k0P/W\nvBzSmAnTQuNtq9z4GsZztrXofycWCF/ekQcWPOK17NNx1zcE28Fhun3/lNWjE+X+\ntDqoB14T5M2lOGdlk5JIuE6N240cuaZGQmvIvCgvup9ESEEDjdyx6V7KR1s5rz3n\ndiaTygk2FU51vknOqoMvHWOZjp2tbYo7KVHrauxKxbXbVewmKcN8LKeRL+qZs5wQ\n5Yrd1/juM99r37kF+1QVVGa3/OQicHal1qJG+UNlH3FuUHu3TCmLxWP4WW1WtKCi\nBP+RIm/WHaWD7bPPDH/XTYLFfJqJ0ZbXLA92jlo1dZ7qhiehl7ubk2KRAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC5yZW5hdGVyLmZyhiVodHRwczovL2lkcC5yZW5h\ndGVyLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQYy83Ve884R0jR3BqE159U\nzbFhDzANBgkqhkiG9w0BAQUFAAOCAQEAOxYs5vfum4LbmsePdGng6mKi8PFcpGKh\ndcFvxOxggLD1YX+R4C1MooN69a3Nf+YY1GzYZO8rUKd+3YL/BhJb0ouE31CzxwLP\nuXCctT3re8BW6GKy3JGju9H3sJ8AJUog3rHCegIJrA7PYarIAQUokEgCzaE5M/sT\nxY7nHrrdSo+QUQSyIYb/Ue7003/wr+8yRc42lx/hbHAcj9vIkrVvFpPCAg86rS0N\nBer/c4EoBOTHkNkGxaFSWKA8trRJUecsobHum/jjuwwJBahR8Jvf+p0a0ADCrsqN\nJA+a0emlAOfEnZeRkpSunkghdezhsTvs0DB3QVZyrFRKmxA5IiORVg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GIP RENATER"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.renater.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GIP RENATER"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayf.kea.dk/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayf.kea.dk/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2013-07-24T15:44:02Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayf.kea.dk/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kea.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "KEA \u2013 K\u00f8benhavns Erhvervsakademi"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "KEA \u2013 Copenhagen School of Design and Technology"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "kea.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3jCCAcYCAQcwDQYJKoZIhvcNAQELBQAwNTEzMDEGA1UEAwwqaHR0cHM6Ly93\nYXlmLmtlYS5kay9zYW1sMi9pZHAvbWV0YWRhdGEucGhwMB4XDTE1MDEwMTAwMDAw\nMFoXDTI1MTIzMTIzNTk1OVowNTEzMDEGA1UEAwwqaHR0cHM6Ly93YXlmLmtlYS5k\nay9zYW1sMi9pZHAvbWV0YWRhdGEucGhwMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEAx4gMCmoQU7iOGfiCda4DnhIggst20fUCHtwaQrHoxQlOa0s5FgDa\nlbnNTw36dCXSGYaz17JgyUDJonTwhjyA0CqPm5Pmn9/hFBUvyP/t+bEgV9r3/odQ\nx72VfY7M55qUlY6ex2f1qD1gcpFgSTtADlZswec5WqpEt+ie+vsMXq8HabhMVZ2E\njXe90vgMk/xGfrVwDvupUPBS/2DJSZ1JEmkqi0hxctNQ9qgTZmEcAaQkuv3VGcsY\ntLeY/IISlA+ARzmVWr5+uSetnCXV4jnDEclACKeexl0Ky+tyra4yHF3Xavgmcmeb\nd+xHVDiM+No6BXMu9zBTp7cp5ShLzsNQSQIDAQABMA0GCSqGSIb3DQEBCwUAA4IB\nAQBdrSXj2W3UAEcxPJUX953tiYwrSssEpmsa2TJjvuOFlf7Len2qkXwKFuqa6fkX\nzpaUpnwK8KdAT2OVgImQDduegBz62MMvgwsynVHKSbtogJnDTBVawnm50uX+elOJ\n+8W5tx4mmkWs3RSHII3aoxw4UWtqlTEdAxzjgysT9OKg0J9PhNpggGsE0Zl9BrFG\n/YyzGW8oEQcLPgFcO+EKd4IUQXTx4vyXeUoxBx+cq0SeOL4c4B0ozGBzBUI49TtW\nI0OwbOKPwRiX893Ccv+YmiFMj2fF97H8tyDo1KQ22YmrNvQuEvL1/JXycaism+sk\np+TiM/eBbXCraZ32+zNbKfPC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "KEA \u2013 K\u00f8benhavns Erhvervsakademi"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "KEA \u2013 Copenhagen School of Design and Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kea.dk/da"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kea.dk/en"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "KEA \u2013 K\u00f8benhavns Erhvervsakademi"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "KEA \u2013 Copenhagen School of Design and Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.eso.org/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Heissenhuber"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:fheissen@eso.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Florian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Heissenhuber"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:fheissen@eso.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Florian"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.eso.org/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2014-10-22T16:13:35Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.eso.org"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGWDCCBUCgAwIBAgIHGGCD/SMRJzANBgkqhkiG9w0BAQsFADCBlzELMAkGA1UE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\n26ev5dBb9dYdJ92x6RFKiD6kvBVZSNaN7KY5ogvz8WmWnXlllor+GGdxQkA="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=trustmaster@eso.org,CN=idp.eso.org,O=ESO - European Organisation for Astronomical Research,L=Garching,ST=Bayern,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eso.org"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.eso.org:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.eso.org:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.eso.org/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.eso.org/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.eso.org:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.eso.org/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.eso.org/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.eso.org/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.eso.org/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.eso.org:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.eso.org:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eso.org"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.eso.org/public/germany/about-eso/esoglance/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.eso.org/public/about-eso/esoglance/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ESO - European Southern Observatory"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ESO - European Southern Observatory"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ESo baut und betreibt astronomische Teleskope"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ESO builds and operates astronomical telescopes"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.eso.org/images/eso-logo-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://www.eso.org/images/eso-logo.ico",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.eso.org/public/privacy.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.eso.org"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGWDCCBUCgAwIBAgIHGGCD/SMRJzANBgkqhkiG9w0BAQsFADCBlzELMAkGA1UE\nBhMCREUxPjA8BgNVBAoTNUVTTyAtIEV1cm9wZWFuIE9yZ2FuaXNhdGlvbiBmb3Ig\nQXN0cm9ub21pY2FsIFJlc2VhcmNoMQwwCgYDVQQLEwNURUMxFjAUBgNVBAMTDUVT\nTyBQS0kgLSBHMDIxIjAgBgkqhkiG9w0BCQEWE3RydXN0bWFzdGVyQGVzby5vcmcw\nHhcNMTQxMDE3MTIwNzA5WhcNMTkwNzA5MjM1OTAwWjCBqzELMAkGA1UEBhMCREUx\nDzANBgNVBAgTBkJheWVybjERMA8GA1UEBxMIR2FyY2hpbmcxPjA8BgNVBAoTNUVT\nTyAtIEV1cm9wZWFuIE9yZ2FuaXNhdGlvbiBmb3IgQXN0cm9ub21pY2FsIFJlc2Vh\ncmNoMRQwEgYDVQQDEwtpZHAuZXNvLm9yZzEiMCAGCSqGSIb3DQEJARYTdHJ1c3Rt\nYXN0ZXJAZXNvLm9yZzCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL/y\nweMbb9mXT+teqXFEevPWlvO48gTjIqNAcrGs9XvZtLCQB91hftXOkS21aNhpO1jD\npJeU6WRjH7WEU3/oXGGqXztxV3I6giyMm8UB0qNLtDm2MuGhYT4CqIwunIzqYKJG\nnvvhi6NTAqhO2wP+XIK7dCnYhehRPhAivMKwLWabKKHF4SPV1X4R/AIMPbu2QFnK\nlM3grdo6lctuGWGcJ9n2UU/9ywQmiZmczQigimkjPp6K/1GFZI5TmIP5uO+Wv+sD\nJxETIOvsYQK5y+CmU5fl1kSPKUwpa+ssfKldRZIpTc2sukFlnU8XAmMpSmjyzsXL\nwEoojn5FmgPgdHLQrwUCAwEAAaOCApEwggKNME8GA1UdIARIMEYwEQYPKwYBBAGB\nrSGCLAEBBAMCMBEGDysGAQQBga0hgiwCAQQDATAPBg0rBgEEAYGtIYIsAQEEMA0G\nCysGAQQBga0hgiweMAkGA1UdEwQCMAAwCwYDVR0PBAQDAgXgMB0GA1UdJQQWMBQG\nCCsGAQUFBwMCBggrBgEFBQcDATAdBgNVHQ4EFgQUSPnc6DulTXOTEQM+i/fbNpxx\n6OowHwYDVR0jBBgwFoAUsR53NN55AbLmThsm4pt3idg5vn0weAYDVR0RBHEwb4IR\nYXdlYjQwLmhxLmVzby5vcmeCD2lkcC5hZHMuZXNvLm9yZ4ILaWRwLmVzby5vcmeC\nDmlkcC5ocS5lc28ub3Jngg9zZHAuYWRzLmVzby5vcmeCC3NkcC5lc28ub3Jngg5z\nZHAuaHEuZXNvLm9yZzB7BgNVHR8EdDByMDegNaAzhjFodHRwOi8vY2RwMS5wY2Eu\nZGZuLmRlL2Vzby1jYS9wdWIvY3JsL2dfY2FjcmwuY3JsMDegNaAzhjFodHRwOi8v\nY2RwMi5wY2EuZGZuLmRlL2Vzby1jYS9wdWIvY3JsL2dfY2FjcmwuY3JsMIHLBggr\nBgEFBQcBAQSBvjCBuzAzBggrBgEFBQcwAYYnaHR0cDovL29jc3AucGNhLmRmbi5k\nZS9PQ1NQLVNlcnZlci9PQ1NQMEEGCCsGAQUFBzAChjVodHRwOi8vY2RwMS5wY2Eu\nZGZuLmRlL2Vzby1jYS9wdWIvY2FjZXJ0L2dfY2FjZXJ0LmNydDBBBggrBgEFBQcw\nAoY1aHR0cDovL2NkcDIucGNhLmRmbi5kZS9lc28tY2EvcHViL2NhY2VydC9nX2Nh\nY2VydC5jcnQwDQYJKoZIhvcNAQELBQADggEBAL10jELuLO7BfdWD2GV/chZe20xt\nM8NthmUA4i6VG9/MRTIFzhR9qwnl0nBQPGCisGH07EU6DvKH6XVMBtW2XidOL2Xq\nvyw9Ztvs5H2ypRnV6FDUKRf1PdbdY6pqTInn5Yt8cw8Rv9h5FDNCXLoLjkRuBNQf\nxgdPNKcKNSTAAI+bnXftMKiV6JHYQxbxsL+x4qVYlHQT425U12ZWwYuE28GzjhUf\nqkP9zWDiEtC88Nxn/NisXmpRJul/cG0ddb3N9XAfvBvjIMN4+rxLvb1ehqLreZFf\n26ev5dBb9dYdJ92x6RFKiD6kvBVZSNaN7KY5ogvz8WmWnXlllor+GGdxQkA="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=trustmaster@eso.org,CN=idp.eso.org,O=ESO - European Organisation for Astronomical Research,L=Garching,ST=Bayern,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ESO - European Organisation for Astronomical Research"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ESO - European Organisation for Astronomical Research"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eso.org"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eso.org"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e446"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e446"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.univ-ag.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Robert BOLIN"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "robert.bolin@martinique.univ-ag.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Patrick PLACIDE"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "patrick.placide@martinique.univ-ag.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.univ-ag.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-10-25T15:08:43Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univ-ag.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univ-ag.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.univ-ag.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-ag.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-ag.fr/"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 des Antilles et de la Guyane"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 des Antilles et de la Guyane"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAPFkF2BmO6RVikcivryW27wULvteMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC51bml2LWFnLmZyMB4XDTEyMTAyMzE3MzIxMFoX\nDTMyMTAyMzE3MzIxMFowGTEXMBUGA1UEAxMOaWRwLnVuaXYtYWcuZnIwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCyyPP8wKSxUpAuUcbFtn+p3mDRnybq\n+qU1qFwxF8J3v2RW63VhgFX+6eKUsULLv5hgDoqY5tsJbUZ0wVGDX+2w6CeurITl\n5amBB0oFuO6Ml7uiYD56w1WQOAYD8L9Nu7kA0XcOb8O4BXngVk19k1lUKlTVHxrQ\n4dRzMPfYuqLYxk1/g8/6Q4ULcBZvqqAlupcgJPmZMh5XPK4PJZYOVHVJhutLY5m9\nTDuo4Sor+BCOLew0aM38rUDTPGydculwZja1R4K8+BHLATq1SFCi4a6ETIpWhy5x\nSAOvoM+W1KyyXSk99QbfmaZVVUlkBTDlupctvegv2sXR42+copiHxcJtAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC51bml2LWFnLmZyhiVodHRwczovL2lkcC51bml2\nLWFnLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTyUENeLeP0xMWsvdAWL29A\nS6V69jANBgkqhkiG9w0BAQUFAAOCAQEAcpTVb3RoQCDVNshZVyM1F0+3Jd4u2gAF\nEy2DVRfgXcWETmUy2dOO5ZZ+YJtwOi+txpwr1yCbPMrdNCdJxLvVkkFwf5rLVesL\nTIm7h5PeO2fs5rurRWXarWSQCinkV7xE1a3xOMPDooCkmBHSICwY5At5fwwUA74X\nEzGjS76Zk6gvDgTTtG15vQvaq31e1eHB7nCYe7zHuFObyujLpKHJHMrIW4Q8o18y\nNCDZWNuuZJO1dzUQrzyUXufytEqv1w1SGYWedTxxXIm+sQ3HaR4d3TDCmTw27pnr\nTZeKHGCI5BfQ0oQ0Mao+E/hZqbDzdp6KBUrALSf/R3JSDtmdnL+gvQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 des Antilles et de la Guyane"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-ag.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 des Antilles et de la Guyane"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.uta.fi/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Heino"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:haka@uta.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Leena"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.uta.fi/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEbzCCA1egAwIBAgIQWJ0Uu68P2AMpFdKpOgOPRDANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMTIxMTAwMDAwMFoXDTE3MDEwODIzNTk1OVowPzEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRowGAYDVQQDExFzaGliYm9sZXRo\nLnV0YS5maTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKdw/yo3Lbk+\njpCHDDZ4M3At6zmkcEjMXmoyIEf/JtrdS7jictu5JbtdBq2tF1pghbwam0OoebBt\nJOeMhA5kRT8L4A7q75SlOAgLOGn8pF+Nmzeh4GMdUM0bNMQU35yuVv2mqzoWk2bf\ngfzHaUPyClu1YYus09CXCqDTKYzzWdSOLLm/Gwh2hcq93sdQnG2bnL5VB7Aranw5\nJxp7Lr1cGv8TLVh/UxusZAY230Tg2E9J2MiHtiXBC6zIVWMFqH46xVLpaEj5qq83\ny0CDtUuTg9iNOnujnBW0p0c0ncHWo1J1NN3KQNep8qBRlXeDfpYd0tyQXElsLHwA\nCFMRl0Qb0t0CAwEAAaOCAW4wggFqMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdX\nR+qQ47ntMB0GA1UdDgQWBBQHZ33wMzTaJ63+SHUEjeM0I81mBzAOBgNVHQ8BAf8E\nBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUH\nAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0fBDMw\nMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5j\ncmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50\nZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29j\nc3AudGNzLnRlcmVuYS5vcmcwHAYDVR0RBBUwE4IRc2hpYmJvbGV0aC51dGEuZmkw\nDQYJKoZIhvcNAQEFBQADggEBAImCKMUf2qlnocIu68mg7acEc+Wqbjmkg/Y0NEUr\nesosCNMWkyWrvugRL2sXJ2JKOlzn3ivS5V7d2KbAOWIaX3WURTCoinUMjXoKu7av\n1rHxYbexNPEcZZWlpzP9POTFQsKkMn8skqOADHTawOnTrQ8mAf9w93E0MuEzArCN\nWZxb93Oky2XoDssu7YLnMurBAq5odfc+UEN4xAiKHOrIRYlswcQq9s6GVMO6GX5L\nfK2v/tIcR6ODF7srxhs3AMZchoWljFoWBl+ZZwuyN7Sioh+5gRaFT9DhTaWw0WxM\nJFOZQrlkdonIfIBEIk8JTF6Wg6Hp6dr33wBB7xapJqAhTjM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uta.fi"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.uta.fi/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "true",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.uta.fi/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uta.fi"
              },
              {
                "information_url": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uta.fi/"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uta.fi/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uta.fi/en/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Tampere"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Tampereen yliopisto"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Tammerfors universitet"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.uta.fi/resurssit/kuvat/tay_300x300.png",
                    "height": "300",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "300"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Tampere"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Tampereen yliopisto"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Tammerfors universitet"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "uta.fi"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:61.50634,23.82306"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:61.49441,23.78066"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "153.1.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:708:320::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "kalmar"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "finland"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "tags",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEbzCCA1egAwIBAgIQWJ0Uu68P2AMpFdKpOgOPRDANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMTIxMTAwMDAwMFoXDTE3MDEwODIzNTk1OVowPzEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRowGAYDVQQDExFzaGliYm9sZXRo\nLnV0YS5maTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKdw/yo3Lbk+\njpCHDDZ4M3At6zmkcEjMXmoyIEf/JtrdS7jictu5JbtdBq2tF1pghbwam0OoebBt\nJOeMhA5kRT8L4A7q75SlOAgLOGn8pF+Nmzeh4GMdUM0bNMQU35yuVv2mqzoWk2bf\ngfzHaUPyClu1YYus09CXCqDTKYzzWdSOLLm/Gwh2hcq93sdQnG2bnL5VB7Aranw5\nJxp7Lr1cGv8TLVh/UxusZAY230Tg2E9J2MiHtiXBC6zIVWMFqH46xVLpaEj5qq83\ny0CDtUuTg9iNOnujnBW0p0c0ncHWo1J1NN3KQNep8qBRlXeDfpYd0tyQXElsLHwA\nCFMRl0Qb0t0CAwEAAaOCAW4wggFqMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdX\nR+qQ47ntMB0GA1UdDgQWBBQHZ33wMzTaJ63+SHUEjeM0I81mBzAOBgNVHQ8BAf8E\nBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUH\nAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0fBDMw\nMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5j\ncmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50\nZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29j\nc3AudGNzLnRlcmVuYS5vcmcwHAYDVR0RBBUwE4IRc2hpYmJvbGV0aC51dGEuZmkw\nDQYJKoZIhvcNAQEFBQADggEBAImCKMUf2qlnocIu68mg7acEc+Wqbjmkg/Y0NEUr\nesosCNMWkyWrvugRL2sXJ2JKOlzn3ivS5V7d2KbAOWIaX3WURTCoinUMjXoKu7av\n1rHxYbexNPEcZZWlpzP9POTFQsKkMn8skqOADHTawOnTrQ8mAf9w93E0MuEzArCN\nWZxb93Oky2XoDssu7YLnMurBAq5odfc+UEN4xAiKHOrIRYlswcQq9s6GVMO6GX5L\nfK2v/tIcR6ODF7srxhs3AMZchoWljFoWBl+ZZwuyN7Sioh+5gRaFT9DhTaWw0WxM\nJFOZQrlkdonIfIBEIk8JTF6Wg6Hp6dr33wBB7xapJqAhTjM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Tampereen yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Tampere"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Tampereen yliopisto"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uta.fi"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uta.fi"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uta.fi"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Tampereen yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Tampere"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Tampereen yliopisto"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.anglia.ac.uk/openathens",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Collins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alex.collins@anglia.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Collins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alex.collins@anglia.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.anglia.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-05-17T17:30:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.anglia.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.anglia.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "anglia.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEbjCCA1agAwIBAgIJAKgOBqreKA7kMA0GCSqGSIb3DQEBBQUAMIG3MQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEOMAwGA1UECAwFRXNzZXgxEzARBgNVBAcMCkNoZWxtc2ZvcmQxITAf\n\t\t\t\t\t\tBgNVBAoMGEFuZ2xpYSBSdXNraW4gVW5pdmVyc2l0eTEbMBkGA1UECwwSVW5pdmVy\n\t\t\t\t\t\tc2l0eSBMaWJyYXJ5MRkwFwYDVQQDDBBpZHAuYW5nbGlhLmFjLnVrMSgwJgYJKoZI\n\t\t\t\t\t\thvcNAQkBFhlhbGV4LmNvbGxpbnNAYW5nbGlhLmFjLnVrMB4XDTEzMDQyMzEyMTcy\n\t\t\t\t\t\tMFoXDTIzMDQyMTEyMTcyMFowgbcxCzAJBgNVBAYTAkdCMQ4wDAYDVQQIDAVFc3Nl\n\t\t\t\t\t\teDETMBEGA1UEBwwKQ2hlbG1zZm9yZDEhMB8GA1UECgwYQW5nbGlhIFJ1c2tpbiBV\n\t\t\t\t\t\tbml2ZXJzaXR5MRswGQYDVQQLDBJVbml2ZXJzaXR5IExpYnJhcnkxGTAXBgNVBAMM\n\t\t\t\t\t\tEGlkcC5hbmdsaWEuYWMudWsxKDAmBgkqhkiG9w0BCQEWGWFsZXguY29sbGluc0Bh\n\t\t\t\t\t\tbmdsaWEuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC9zvXg\n\t\t\t\t\t\tKC3ZqFlCLXKPIkXy3+RBCGjq6MdFPna0mTN78dDm3BGxDa5ZSGOAbmymkLifZQAO\n\t\t\t\t\t\tauoab/IP4+cwRLk1mVZs64zGr7HkWjisEJxJ1prP+L7Vhxx5im1SITbMcf3YbfRu\n\t\t\t\t\t\te88es/O2pJuAMNl3FG6ZskxKxT1cwKuvd9exelplJfBwYI0lbKZkQLMTvGfMr7B2\n\t\t\t\t\t\tX0HXeGnb4mVRAI3C/uLQ3Y3zCgHyFoofvLUEugAh8zfInnLsk6CQee4tmdL/Vhj1\n\t\t\t\t\t\t2FoKZcAywTv0MxR0zvROKkB/9N1ARtnqUQ6+wndtTJmKkvAEZjC33l5VuguzAbgr\n\t\t\t\t\t\tLmgzQJBSbcb5r8a7AgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8W\n\t\t\t\t\t\tHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBRC1E3gBT7m\n\t\t\t\t\t\tKDcJFkGEIMx61RnTrTAfBgNVHSMEGDAWgBRC1E3gBT7mKDcJFkGEIMx61RnTrTAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAFnUD7xfFhO6ypILsd3MSTO9piV3Wn+aNbtHHvZTk\n\t\t\t\t\t\tcwwQzPAX3ZeZfSRbXA8VANOMedxhWnAppPy3qus8kwMtM7YrZe9yYasppou7+uWp\n\t\t\t\t\t\tdSKq0fC8MLIKyC4JSujcTDKNB7aBNm9OPGE0oCoeYDIyTrWMHX2GFzR5xf/N6o/M\n\t\t\t\t\t\taHYdqraRkIveOsr8qqIX0ivXULDDVobITuWReZDqvPKnnbMbuSAt/2gp5+5+RN28\n\t\t\t\t\t\tIR9hHcyp+OyjkSQAtk4aR3EG4ETL1DRg1lOn4vLx0iZvunV414E+oz4AjRor9NDO\n\t\t\t\t\t\tjhjABmtX2fYOehXDJQvAW8f+ExSl+RlQHZNyTQX3V3xJXA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Anglia Ruskin University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://libweb.anglia.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Anglia Ruskin University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.overtsoftware.com/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Andre"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Andre"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.overtsoftware.com/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDiDCCAnACCQDi5A+IRiQjlDANBgkqhkiG9w0BAQUFADCBhTELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFzAVBgNVBAgTDldvcmNlc3RlcnNoaXJlMRYwFAYDVQQHEw1LaWRkZXJtaW5z\n\t\t\t\t\t\tdGVyMSUwIwYDVQQKExxPdmVydCBTb2Z0d2FyZSBTb2x1dGlvbnMgTHRkMR4wHAYD\n\t\t\t\t\t\tVQQDExVpZHAub3ZlcnRzb2Z0d2FyZS5jb20wHhcNMTIwNTI0MTYwMzQzWhcNMzIw\n\t\t\t\t\t\tNTE5MTYwMzQzWjCBhTELMAkGA1UEBhMCR0IxFzAVBgNVBAgTDldvcmNlc3RlcnNo\n\t\t\t\t\t\taXJlMRYwFAYDVQQHEw1LaWRkZXJtaW5zdGVyMSUwIwYDVQQKExxPdmVydCBTb2Z0\n\t\t\t\t\t\td2FyZSBTb2x1dGlvbnMgTHRkMR4wHAYDVQQDExVpZHAub3ZlcnRzb2Z0d2FyZS5j\n\t\t\t\t\t\tb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC6aE+W0BP9ibXUGpPZ\n\t\t\t\t\t\tdRcSNO7frD1wgMjPhtpJfeiI69Yc3gkJGaWKrtkmCuFydQ+rO5fbuKyrZzIQssN5\n\t\t\t\t\t\tcLHxu8ABHtGMqtk0puKa3ymFvfjgp8IAh/tYgBw8/WLX4VuGA9NOKqXcOME5icCc\n\t\t\t\t\t\tBaCxseQCwEy/5YT+UAhP7BzUbRg1OEnb8IYGJKAWRoO5hE6CiGugOoplpGv9ovmJ\n\t\t\t\t\t\ti16CAuSBqbsHKkT9ADJp9DMZpYa/izn9j+/ONW5DcVWasosw6wDewiIp+ttW+Ice\n\t\t\t\t\t\tEFJ6KbWJHNjRlkdp7FXjvDdVks5sc/ZfSvzF4G9mm2lv//aJu774kZzijkF+Bio4\n\t\t\t\t\t\tIIxBAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAEd9OhZ0ZAB7Cpr+YwzWY+4S8c/w\n\t\t\t\t\t\t19dwjLqufSlmMqq7fw00mcWxmx2n3ovzqplTRvOxbFiNc00hF85Lf3TRs+ieENWp\n\t\t\t\t\t\tTHQ7KNev/peJ3kggXArmlKBzZmM7xVimwm1d0ehp8359gAH08oGxZFqc1F1VuPyM\n\t\t\t\t\t\tiXEieN+YvMjmfUs4/O1cDWLcOlrEzb+wDRSgF7osUlqjGxlZ6tfaayMeWcDfJ2hy\n\t\t\t\t\t\t+lZSS6znrw8dTZ2CYA0JGA1jE/jExB+P5rfGsBSO3ZJZG/YyOJZSxtds2iqCY055\n\t\t\t\t\t\tapotaZklObBpbolG8BoHy6sqsIpVMVDZqFu9AF5ryJJsaVF8mcWVDDwRnXY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "overtsoftware.com"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.overtsoftware.com:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.overtsoftware.com:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.overtsoftware.com/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.overtsoftware.com/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.overtsoftware.com:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.overtsoftware.com/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.overtsoftware.com/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.overtsoftware.com/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.overtsoftware.com/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.overtsoftware.com:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.overtsoftware.com:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "overtsoftware.com"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDiDCCAnACCQDi5A+IRiQjlDANBgkqhkiG9w0BAQUFADCBhTELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFzAVBgNVBAgTDldvcmNlc3RlcnNoaXJlMRYwFAYDVQQHEw1LaWRkZXJtaW5z\n\t\t\t\t\t\tdGVyMSUwIwYDVQQKExxPdmVydCBTb2Z0d2FyZSBTb2x1dGlvbnMgTHRkMR4wHAYD\n\t\t\t\t\t\tVQQDExVpZHAub3ZlcnRzb2Z0d2FyZS5jb20wHhcNMTIwNTI0MTYwMzQzWhcNMzIw\n\t\t\t\t\t\tNTE5MTYwMzQzWjCBhTELMAkGA1UEBhMCR0IxFzAVBgNVBAgTDldvcmNlc3RlcnNo\n\t\t\t\t\t\taXJlMRYwFAYDVQQHEw1LaWRkZXJtaW5zdGVyMSUwIwYDVQQKExxPdmVydCBTb2Z0\n\t\t\t\t\t\td2FyZSBTb2x1dGlvbnMgTHRkMR4wHAYDVQQDExVpZHAub3ZlcnRzb2Z0d2FyZS5j\n\t\t\t\t\t\tb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC6aE+W0BP9ibXUGpPZ\n\t\t\t\t\t\tdRcSNO7frD1wgMjPhtpJfeiI69Yc3gkJGaWKrtkmCuFydQ+rO5fbuKyrZzIQssN5\n\t\t\t\t\t\tcLHxu8ABHtGMqtk0puKa3ymFvfjgp8IAh/tYgBw8/WLX4VuGA9NOKqXcOME5icCc\n\t\t\t\t\t\tBaCxseQCwEy/5YT+UAhP7BzUbRg1OEnb8IYGJKAWRoO5hE6CiGugOoplpGv9ovmJ\n\t\t\t\t\t\ti16CAuSBqbsHKkT9ADJp9DMZpYa/izn9j+/ONW5DcVWasosw6wDewiIp+ttW+Ice\n\t\t\t\t\t\tEFJ6KbWJHNjRlkdp7FXjvDdVks5sc/ZfSvzF4G9mm2lv//aJu774kZzijkF+Bio4\n\t\t\t\t\t\tIIxBAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAEd9OhZ0ZAB7Cpr+YwzWY+4S8c/w\n\t\t\t\t\t\t19dwjLqufSlmMqq7fw00mcWxmx2n3ovzqplTRvOxbFiNc00hF85Lf3TRs+ieENWp\n\t\t\t\t\t\tTHQ7KNev/peJ3kggXArmlKBzZmM7xVimwm1d0ehp8359gAH08oGxZFqc1F1VuPyM\n\t\t\t\t\t\tiXEieN+YvMjmfUs4/O1cDWLcOlrEzb+wDRSgF7osUlqjGxlZ6tfaayMeWcDfJ2hy\n\t\t\t\t\t\t+lZSS6znrw8dTZ2CYA0JGA1jE/jExB+P5rfGsBSO3ZJZG/YyOJZSxtds2iqCY055\n\t\t\t\t\t\tapotaZklObBpbolG8BoHy6sqsIpVMVDZqFu9AF5ryJJsaVF8mcWVDDwRnXY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Overt Software Solutions Ltd"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.overtsoftware.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Overt Software Solutions Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://se.timeedit.net/lu-employee-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@evolvera.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TimeEdit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://se.timeedit.net/lu-employee-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://se.timeedit.net/web/lu/db1/timeedit/ssoLogout/lu_pers_saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TimeEdit, utvecklat av Evolvera AB"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TimeEdit, developed by Evolvera AB"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TimeEdit f\u00f6r anst\u00e4llda vid Lunds universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TimeEdit for employees at Lund University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAggCCQDSfJxeKVOg3jANBgkqhkiG9w0BAQUFADBSMQswCQYDVQQGEwJTRTESMBAGA1UE\nBxQJR8O2dGVib3JnMRQwEgYDVQQKEwtUaW1lRWRpdCBBQjEZMBcGA1UEAxMQYXV0aC50aW1lZWRp\ndC5zZTAeFw0xMzA2MTQwNzE0MTlaFw0xNTA2MTQwNzE0MTlaMFIxCzAJBgNVBAYTAlNFMRIwEAYD\nVQQHFAlHw7Z0ZWJvcmcxFDASBgNVBAoTC1RpbWVFZGl0IEFCMRkwFwYDVQQDExBhdXRoLnRpbWVl\nZGl0LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoL+lyBleTM0UGwGPLXPcfBMr\nomnPqP8+qlE+rOs0mEbvNyXdEWT0Z5P/XoMVfERJQQ6v5DAJF4c3o1BiPshZL8cj6QdLuJXLfVNG\nu5mzq/lKpB/n38Y4cWYxIyNtBcV9vcKDIRUbQP/27nEPMsbs2IaCXf6V3l3yQqbymZTyd8nBfZZF\nG95zDKBTSD5UQ3XW+LbvjKSZY4qDjyFkeOfj8kVyltWTHRMvKTKGLeNrGyCFiaMY/vfyA22gOyz4\nO2cY/oqFs8+82AOs3Si4+eGkFAq3CdEWSE4c69oDrzEWk+bKgxw5qyhWQ/13eh8AiZMDeqhT7q32\nRthqEp8GfwPM1QIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCRsLvMI4OJ076STPIyxnwk6bXRG5RL\nMR1pJ3umMNCa1LR1RnH1feuvm9dxerUTow7bPIsarJarh0iEIj2kLtu/prPm+ZcAKeEjh27pSM7m\n1F0XBkDqeP1msR+7g0aHlt0MzrKm/Esb1JX9YCO3MHl1XFc8xSnv2bxKWvER+tmDWkFrC0y1u2+H\nB/CfyES8ntBP6F7aZ6UQ4GTrqF0MZNGBoWFyXecGe5XEwWJwP4otSrJ2q7cbQU33xEcri0dHiMMl\nTiN/6f25dSm5UFCxqWGGAQndGfn/tE5FSqJlrHnbF2M6x4eH3MEIbHebI+nJlk6ASPdgIssvsDcd\nGImnaeS4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://se.timeedit.net/web/lu/db1/timeedit/ssoResponse/lu_pers_saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "false"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://ucl.sisoshibboleth.co.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Info"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Oates"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ucl.sisoshibboleth.co.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-01-17T14:43:39Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SiSo University College London Online Resource Booking"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.siso.uk.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "TechEthika Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://avcucl.siso.co/sso/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://avcucl.siso.co/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://avcucl.siso.co/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SiSo University College London Online Resource Booking"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.siso.co/siso-logo60x60.jpg",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SiSo University College London Online Resource Booking"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAOSUhyDXVj7AMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB3Npc28uY28wHhcNMTMwMTA3MTYzMTIxWhcNMjMwMTA1MTYzMTIxWjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdzaXNvLmNvMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\txDnj9YFJVXclawo/8rs1aWYAgk6rKi8A/Cyycq0mW5yOKLLh8MUIgDeOGL7bLl7p\n\t\t\t\t\t\tMBeZM4ILlNaeJhICWm1tuLB6SYzREnXwpO7+lvx13xsRHW2TjCPGV3yUgz55vRYj\n\t\t\t\t\t\tbseFrwFHJ8IrL24UTLcpX/R//9cMkZpSqM+77Hn22dxbYvGUOQCHOQzL78AO91qz\n\t\t\t\t\t\tdUaxKzYWyWM7w2U4APP41Zvd0flyUtRZXp8W+WwlUDffFoNndsjR4L/9wuXvOcrH\n\t\t\t\t\t\t+VZtMLy60+cB9bpvVlaQVlt+1stEABdMVvuGNkJ9wIjRjP2b9OLUI76QmgwIDtdE\n\t\t\t\t\t\t5BS0Bv0Puz66L96r2MunRQIDAQABozUwMzASBgNVHREECzAJggdzaXNvLmNvMB0G\n\t\t\t\t\t\tA1UdDgQWBBRRosxNbUQXXwtWDl/kYMScRImh5TANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tgrfjza9Btcz+9WvzcjDTZ+KSrWWvrthA3zc6Q+C/MIBG8CCuxMO+uwFBnXIopGlX\n\t\t\t\t\t\tbLa/QtVLjOugsnizFxjaEFTG4jGndtPJ8+9V8Eja5RlOazuM2LT738+Um8/1Frhr\n\t\t\t\t\t\tGXa0Hdv9ZWEbIhil65fFqZNOmOteja6xxAQ9NgGG/XUnTVTbr7msihEAYTTcS40/\n\t\t\t\t\t\tGSYpT9nQwiryfSWDNJ17Zyl44389kSw+FCUsu8Ns9VSDEDWr/R+97ZMcjN6hAfJL\n\t\t\t\t\t\tdji3X1aaAC/JbnJl/v+yR1TH/sdHyObVaM7FToUGKiyjX9VpfOe64d0hjogzEr0x\n\t\t\t\t\t\tfirJubLNu96jbGctasqcpQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://avcucl.siso.co/sso/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://avcucl.siso.co/sso/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://avcucl.siso.co/sso/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://avcucl.siso.co/sso/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://avcucl.siso.co/sso/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://avcucl.siso.co/sso/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://athens.gcc.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Waller"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:andyw@gcc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Flash"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:andrewf@gcc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://athens.gcc.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-09-28T11:32:51Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://athens.gcc.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://athens.gcc.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gcc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIIZDkGkl9vMnswDQYJKoZIhvcNAQEFBQAwQTEkMCIGA1UE\n\t\t\t\t\t\tCgwbR3JlZW53aWNoIENvbW11bml0eSBDb2xsZWdlMRkwFwYDVQQDDBBhdGhlbnMu\n\t\t\t\t\t\tZ2NjLmFjLnVrMB4XDTEyMDkyNjA5MTE1OFoXDTIyMDkyNjA5MTE1OFowQTEkMCIG\n\t\t\t\t\t\tA1UECgwbR3JlZW53aWNoIENvbW11bml0eSBDb2xsZWdlMRkwFwYDVQQDDBBhdGhl\n\t\t\t\t\t\tbnMuZ2NjLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAjizt\n\t\t\t\t\t\tiasQN9XJEROq+jKdGAyMC/ZPA5WlWSiow8EtKCLgfVBteMtBQYfNdC46NimD/9R9\n\t\t\t\t\t\tZuz7J2rVyECCS1LJQ0DEBNMuoXjTURe8WcqzuwqtQmDNfxXR1KXl7oK7j9toSEfV\n\t\t\t\t\t\tsjewKskG95BnUl/444TLhjdmFQITLRlouj95dTtisqlWaEkhEIcyY2A2tUPy6K03\n\t\t\t\t\t\t2AJd6sAAeJtC3JY3dmrQmsKz0KKLXJPocr9gHffyssJLSCo0AeBWpryfNKBrefft\n\t\t\t\t\t\tAS8/yEnULpnaoBvsyM/9Zbqhr3Fk0HDJ2/nImrQmd9qPVDy7JhZVaupXi/EGRleG\n\t\t\t\t\t\tKr0z1Eg5UHihgiGwMQIDAQABo1AwTjAdBgNVHQ4EFgQU/23/DDRDFN+xOV/RwtEC\n\t\t\t\t\t\tjlykbJowHwYDVR0jBBgwFoAU/23/DDRDFN+xOV/RwtECjlykbJowDAYDVR0TBAUw\n\t\t\t\t\t\tAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAiG3o2/x1+ylakkGBN0jlX/qur0bYrGZx\n\t\t\t\t\t\t1PN45rIOKbtrXmg9DxZ1n4whmxkTbtaXrkTHoufaOy45HRwYC3uo3lb567BHGT28\n\t\t\t\t\t\tRX6A4eoRSNtOdkhV+FG/N6nrXcRE6e0zrinevb9zaXc2W/BdHhckAoiy/p6O7mkC\n\t\t\t\t\t\tkdNeb73Roa/dVMKAqhadpN5GOjB5C8zJslHi1xz00mr8R536+yXXGVFrvNrxVz1i\n\t\t\t\t\t\tUUbYQ08xGTNbEu0lWUKMXvu/o1UGff7xbocTLduVR2b7m3Trx3aQqHs9uQDDieFE\n\t\t\t\t\t\toHLQY5r0sjjy+wGMUU1G3PVqM24A0ZUlAtJLg3tpc6KvlMWetkbJmA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIIZDkGkl9vMnswDQYJKoZIhvcNAQEFBQAwQTEkMCIGA1UE\n\t\t\t\t\t\tCgwbR3JlZW53aWNoIENvbW11bml0eSBDb2xsZWdlMRkwFwYDVQQDDBBhdGhlbnMu\n\t\t\t\t\t\tZ2NjLmFjLnVrMB4XDTEyMDkyNjA5MTE1OFoXDTIyMDkyNjA5MTE1OFowQTEkMCIG\n\t\t\t\t\t\tA1UECgwbR3JlZW53aWNoIENvbW11bml0eSBDb2xsZWdlMRkwFwYDVQQDDBBhdGhl\n\t\t\t\t\t\tbnMuZ2NjLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAjizt\n\t\t\t\t\t\tiasQN9XJEROq+jKdGAyMC/ZPA5WlWSiow8EtKCLgfVBteMtBQYfNdC46NimD/9R9\n\t\t\t\t\t\tZuz7J2rVyECCS1LJQ0DEBNMuoXjTURe8WcqzuwqtQmDNfxXR1KXl7oK7j9toSEfV\n\t\t\t\t\t\tsjewKskG95BnUl/444TLhjdmFQITLRlouj95dTtisqlWaEkhEIcyY2A2tUPy6K03\n\t\t\t\t\t\t2AJd6sAAeJtC3JY3dmrQmsKz0KKLXJPocr9gHffyssJLSCo0AeBWpryfNKBrefft\n\t\t\t\t\t\tAS8/yEnULpnaoBvsyM/9Zbqhr3Fk0HDJ2/nImrQmd9qPVDy7JhZVaupXi/EGRleG\n\t\t\t\t\t\tKr0z1Eg5UHihgiGwMQIDAQABo1AwTjAdBgNVHQ4EFgQU/23/DDRDFN+xOV/RwtEC\n\t\t\t\t\t\tjlykbJowHwYDVR0jBBgwFoAU/23/DDRDFN+xOV/RwtECjlykbJowDAYDVR0TBAUw\n\t\t\t\t\t\tAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAiG3o2/x1+ylakkGBN0jlX/qur0bYrGZx\n\t\t\t\t\t\t1PN45rIOKbtrXmg9DxZ1n4whmxkTbtaXrkTHoufaOy45HRwYC3uo3lb567BHGT28\n\t\t\t\t\t\tRX6A4eoRSNtOdkhV+FG/N6nrXcRE6e0zrinevb9zaXc2W/BdHhckAoiy/p6O7mkC\n\t\t\t\t\t\tkdNeb73Roa/dVMKAqhadpN5GOjB5C8zJslHi1xz00mr8R536+yXXGVFrvNrxVz1i\n\t\t\t\t\t\tUUbYQ08xGTNbEu0lWUKMXvu/o1UGff7xbocTLduVR2b7m3Trx3aQqHs9uQDDieFE\n\t\t\t\t\t\toHLQY5r0sjjy+wGMUU1G3PVqM24A0ZUlAtJLg3tpc6KvlMWetkbJmA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Greenwich Community College OALA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gcc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Greenwich Community College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp2.hv.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 520 223193"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Magnus Andersson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Magnus.Andersson@hv.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University West"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 520 223189"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Christian Jiresj\u00f6"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Christian.Jiresjo@hv.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University West"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 520 223300"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Servicedesk H\u00f6gkoslan V\u00e4st"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@hv.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University West"
          }
        }
      ],
      "entity_id": "https://idp2.hv.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVALAAqmf9+n0EkV7vMRq5ZDh3UVEHMA0GCSqGSIb3DQEB\nBQUAMB8xHTAbBgNVBAMTFGxzYW1sMDMuc2VydmVyLmh2LnNlMB4XDTEyMTEyNjA5\nNTgyNloXDTMyMTEyNjA5NTgyNlowHzEdMBsGA1UEAxMUbHNhbWwwMy5zZXJ2ZXIu\naHYuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCAwm0DgWJkMIvo\nooXb2NlHLLPl59NDgh5MXYPBCETWU20T2voM+g2M7d5c/Jb1iMVC/kP3FYuK8Nmy\nl6o3VLSaRIENTcZTOLEjHPO301NCu6dRIgM+iwkZnZ0luUgfxEf9aBnmwA0V7vKp\nRliOzNDYmZ7FL6z6ZDh6ULjnPV6KeGd4bQIrW2ywTOirz+BGGn0UXChuOanDnEvo\nfv3Vrr1wh1bbGmr0G6w5JlSLPPKtoKG5DGRjzkq3mfiP97N6ZgI4F0e815Sbb3B7\nVLCZ/JZMRxOj9bP5Q7LhpDn0+LpmK/DS/YAs8rivg1WgKkuJgiYTOAlewyZTZT6v\n1m9x3LexAgMBAAGjbzBtMEwGA1UdEQRFMEOCFGxzYW1sMDMuc2VydmVyLmh2LnNl\nhitodHRwczovL2xzYW1sMDMuc2VydmVyLmh2LnNlL2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBR9Gm8Z5H9QjIJK2yvAM0y2i1hkpzANBgkqhkiG9w0BAQUFAAOCAQEA\nKXF5jmIhYbIVM425IZMSH9vb6Gm5R3rk0s6h4BGyeMPpLQ/ECjnwitsQFTZG2dci\nvvi4JbU8mryOVDt9NlNUtdgzbiaP3VcrkWHq7at+DsW+ipD5ioMIWZa6/hIqMU7U\neQLX7YM4sjy3b4aa6rdTh+r2yp2GcFmpbJNhSncXA3lgH5I+BBKUgKIrLHdsdkGj\nIebD+y3AIEczoLLKVQ7W5d81Ifrh1JLJ8IVOt4S+9LUsgGJmu04NQaeQyaQcodTs\ndqEra6A3S5DN0BAWsLH3aBkA3fL/f6f3HUQwmd7dG+OUOtP+5DaB1YdeeXYMz5Wj\naRQKNbVQdPN5ht6TrINjDQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hv.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.hv.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.hv.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp2.hv.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.hv.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp2.hv.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2.hv.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.hv.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.hv.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hv.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.hv.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.hv.se/en"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r H\u00f6gskolan V\u00e4st"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for University West"
                  }
                ],
                "logo": [
                  {
                    "text": "https://logo.hv.se/logo-sv.jpg",
                    "lang": "sv",
                    "height": "103",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "200"
                  },
                  {
                    "text": "https://logo.hv.se/logo-en.jpg",
                    "lang": "en",
                    "height": "103",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "200"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "H\u00f6gskolan V\u00e4st"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University West"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "hv.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:58.2822,12.2934"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.188.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.192.0/20"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.234.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.236.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "212.25.132.0/23"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVALAAqmf9+n0EkV7vMRq5ZDh3UVEHMA0GCSqGSIb3DQEB\nBQUAMB8xHTAbBgNVBAMTFGxzYW1sMDMuc2VydmVyLmh2LnNlMB4XDTEyMTEyNjA5\nNTgyNloXDTMyMTEyNjA5NTgyNlowHzEdMBsGA1UEAxMUbHNhbWwwMy5zZXJ2ZXIu\naHYuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCAwm0DgWJkMIvo\nooXb2NlHLLPl59NDgh5MXYPBCETWU20T2voM+g2M7d5c/Jb1iMVC/kP3FYuK8Nmy\nl6o3VLSaRIENTcZTOLEjHPO301NCu6dRIgM+iwkZnZ0luUgfxEf9aBnmwA0V7vKp\nRliOzNDYmZ7FL6z6ZDh6ULjnPV6KeGd4bQIrW2ywTOirz+BGGn0UXChuOanDnEvo\nfv3Vrr1wh1bbGmr0G6w5JlSLPPKtoKG5DGRjzkq3mfiP97N6ZgI4F0e815Sbb3B7\nVLCZ/JZMRxOj9bP5Q7LhpDn0+LpmK/DS/YAs8rivg1WgKkuJgiYTOAlewyZTZT6v\n1m9x3LexAgMBAAGjbzBtMEwGA1UdEQRFMEOCFGxzYW1sMDMuc2VydmVyLmh2LnNl\nhitodHRwczovL2xzYW1sMDMuc2VydmVyLmh2LnNlL2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBR9Gm8Z5H9QjIJK2yvAM0y2i1hkpzANBgkqhkiG9w0BAQUFAAOCAQEA\nKXF5jmIhYbIVM425IZMSH9vb6Gm5R3rk0s6h4BGyeMPpLQ/ECjnwitsQFTZG2dci\nvvi4JbU8mryOVDt9NlNUtdgzbiaP3VcrkWHq7at+DsW+ipD5ioMIWZa6/hIqMU7U\neQLX7YM4sjy3b4aa6rdTh+r2yp2GcFmpbJNhSncXA3lgH5I+BBKUgKIrLHdsdkGj\nIebD+y3AIEczoLLKVQ7W5d81Ifrh1JLJ8IVOt4S+9LUsgGJmu04NQaeQyaQcodTs\ndqEra6A3S5DN0BAWsLH3aBkA3fL/f6f3HUQwmd7dG+OUOtP+5DaB1YdeeXYMz5Wj\naRQKNbVQdPN5ht6TrINjDQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "H\u00f6gskolan V\u00e4st"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University West"
          }
        ],
        "organization_url": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hv.se"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hv.se"
          }
        ],
        "organization_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HV"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HV"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.purdue.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "accounts@purdue.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Purdue Identity and Access Management Office"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "accounts@purdue.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Purdue Identity and Access Management Office"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "accounts@purdue.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Purdue Identity and Access Management Office"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "abuse@purdue.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Purdue Security Team"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://idp.purdue.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://www.purdue.edu/apps/idphs/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.purdue.edu/apps/idphs/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.purdue.edu/apps/idphs/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.purdue.edu/apps/idphs/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUL2tBWJ/vs2e4Qf4PHC+BalWFzDwwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOaWRwLnB1cmR1ZS5lZHUwHhcNMTEwNTEwMTkwNjM3WhcN\nMzEwNTEwMTkwNjM3WjAZMRcwFQYDVQQDEw5pZHAucHVyZHVlLmVkdTCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKHqHnSjOFIWQZsoUTY6SXCck1rBihn5\noBWL/+o4qoWIyXNpqDwpd5PshPXFpe8nSl42ElRFXdkgAIHE2NxpETXZAbDGcbaO\nhjo9z3JP2DBh8NpJAUeRLK3+FaJkKaTs7qQ6T5q1o8q3rMKaYOOET1Dve/3P0z0b\n2ysnvku3/1F+KXan0JxRUFUacK76qMsC/3r0LF3eiS1Qgg8aPYL18axYM1NXavy+\nlGiI+NDX78qTEhNY+nIp/qirSqp7sMCiFxL5EWO8MZKA4WVgntuUVDYM0ajkH1Q9\nYgNzl+ENrHmQUs8q0kQxtxHOGHEroyA7Qv3Pmv8vOVEc/awUABgUqZECAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOaWRwLnB1cmR1ZS5lZHWGJWh0dHBzOi8vaWRwLnB1cmR1\nZS5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFBq6iuVS/4AY9WgPsd0tdrpq\nTqrqMA0GCSqGSIb3DQEBBQUAA4IBAQBXsn2jnWXISPczONsw/9TsnD8CdM2Z3F8r\nkoEs0OmiZzLr2QJE3BtGYa5YRmydw4vNblcQ7POmeXy3vtq6hFpVzGZJKVSQ7J4j\nwwHJPWtEWmgyco8e1843rS5fCXYB6JD+zJgK9f1dm91cJnTAI3rq7u2A+p4V6Umo\n2/Y6gdKaJJyL9D6ZF0NnndAgrd3fq5fSBY9Q6+B5kEdclo4a1WF+3PvzxZFKrLWe\nLupT/r3MCfWJjCiG6bV98tLeoSHrAME5EXI5pRSedGHkRdHoOT5ONWzj16pnaGsh\nB6EDsv+wL3C3eeQWHJQIYMTpI+DP3bJmfNSPOBnrHbtx2q4ydRF4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "purdue.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://www.purdue.edu//purdue/globals/graphics/v4_purdue/PU_signature_white_bg_215x80.png",
                    "lang": "en",
                    "height": "80",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "215"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.purdue.edu/policies/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Purdue University Main Campus"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Purdue University Main Campus"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.purdue.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Purdue University Main Campus"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib-idp.uni-osnabrueck.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Nienh\u00fcser"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Werner.Nienhueser@Uni-Osnabrueck.DE"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Werner"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Nienh\u00fcser"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Werner.Nienhueser@Uni-Osnabrueck.DE"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Werner"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib-idp.uni-osnabrueck.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2011-11-09T14:39:44Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shib-idp.uni-osnabrueck.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGhjCCBW6gAwIBAgIHGeLo0fIbejANBgkqhkiG9w0BAQsFADCBkTELMAkGA1UE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\nzYfn5UP+rfVyScJjmLxneyX4yu4iwS+Bv9CpJ/lBl8hJkf5YEJ+Tkr9b"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=shib-idp.uni-osnabrueck.de,OU=Rechenzentrum,O=Universitaet Osnabrueck,L=Osnabrueck,ST=Niedersachsen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uni-osnabrueck.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-idp.uni-osnabrueck.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.uni-osnabrueck.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-idp.uni-osnabrueck.de/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-idp.uni-osnabrueck.de/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.uni-osnabrueck.de:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib-idp.uni-osnabrueck.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-idp.uni-osnabrueck.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib-idp.uni-osnabrueck.de/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-idp.uni-osnabrueck.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-idp.uni-osnabrueck.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.uni-osnabrueck.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uni-osnabrueck.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uni-osnabrueck.de/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uni-osnabrueck.de/"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00fcr die Mitglieder der Universit\u00e4t Osnabr\u00fcck"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00fcr die Mitglieder der Universit\u00e4t Osnabr\u00fcck"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e4t Osnabr\u00fcck"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e4t Osnabr\u00fcck"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shib-idp.uni-osnabrueck.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGhjCCBW6gAwIBAgIHGeLo0fIbejANBgkqhkiG9w0BAQsFADCBkTELMAkGA1UE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\nzYfn5UP+rfVyScJjmLxneyX4yu4iwS+Bv9CpJ/lBl8hJkf5YEJ+Tkr9b"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=shib-idp.uni-osnabrueck.de,OU=Rechenzentrum,O=Universitaet Osnabrueck,L=Osnabrueck,ST=Niedersachsen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e4t Osnabr\u00fcck"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e4t Osnabr\u00fcck"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-osnabrueck.de/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-osnabrueck.de/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e303"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e303"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://identite.intranet.univ-lille.fr/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "VIEVILLE CLAUDE"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "claude.vieville@univ-lille1.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "WALLON ANTOINE"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ines.wallon@univ-lille1.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://identite.intranet.univ-lille.fr/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-09-15T14:45:34Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/web"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/local"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 des Sciences Techniques de Lille 1"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-lille1.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 des Sciences Techniques de Lille 1"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://identite.univ-lille.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This platform allows the responsables of the communication to load digital identification elements they need"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Cette plate-forme permet aux responsables de communication de charger les \u00e9l\u00e9ments d'identification num\u00e9rique"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Lille - plate-forme charte digitale (identit\u00e9)"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Lille - plate-forme charte digitale (identit\u00e9)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFTCCAf2gAwIBAgIJALIbtMdZhxM2MA0GCSqGSIb3DQEBBQUAMCUxIzAhBgNV\nBAMTGmRydXBhbC13ZWIxLnVuaXYtbGlsbGUxLmZyMB4XDTE0MDgwMTA3NDM1NloX\nDTI0MDcyOTA3NDM1NlowJTEjMCEGA1UEAxMaZHJ1cGFsLXdlYjEudW5pdi1saWxs\nZTEuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCrnebq+nhIUfCL\n6I0Zs/hG4XeRItJBgsQQ2AB2JndoMZaRewzKT/9Ht/EqObllh5C3qFhMDitBd5Au\nE6/+Dhff00q4GGskt3Nf0qsV9EuOvyr2z2kx94wnilABMm+dZo4j0NBLuGo+vPNc\nsbjUjmo/fmD5N47iI3+UqcZPmKlp5mnfJ/QfMWYhkE9xSknu+jwr85mtYPJlMLLR\nbYwaVoCpNNn/dI9AmKPV0j4Hy7Wi3ZHehqg1e2qHaejGdTt61W5hzVfzXgc/VznF\nkISdtz8ohNq5NqXNKdddyDY60miygAtY/3BVf5/FQklalDtVWnVbFR2iqDLiRhpm\nXKBzPwIbAgMBAAGjSDBGMCUGA1UdEQQeMByCGmRydXBhbC13ZWIxLnVuaXYtbGls\nbGUxLmZyMB0GA1UdDgQWBBR4MjERy9HNblRVIBMMXv6lw+oJxjANBgkqhkiG9w0B\nAQUFAAOCAQEAJhvOYbbYtxKGw3GfYyAIag15zgdx/Zv0R8/aMtq4lum5ibJeh559\ntpJBBtqclTvMPzA0pjO61NWavFC+ROU4FMDL4HZF2fJN44VBloK2qSExD+jU3ARy\niH7gAMMeRvnUUanQaefaacSKvrIL1EU2PCcaTHyRGqzILBi6ZbvmmZLhFB1OmlYH\nFwPWP4omGY8/MYNYuW5oU/HtpkdLWUed9DqGQSJDodBVdJHyjWEzNwf+mxBlwSXa\n4VEJouPfrQAD6PqFhsz9qQpx8gYuNN3iUVSL0CIjthzBGp/B2d+813Haio+5qsOL\nDj+RBXEEXq6BPJ4ZI/vQ8DB6K34mTzfQKg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFTCCAf2gAwIBAgIJALIbtMdZhxM2MA0GCSqGSIb3DQEBBQUAMCUxIzAhBgNV\nBAMTGmRydXBhbC13ZWIxLnVuaXYtbGlsbGUxLmZyMB4XDTE0MDgwMTA3NDM1NloX\nDTI0MDcyOTA3NDM1NlowJTEjMCEGA1UEAxMaZHJ1cGFsLXdlYjEudW5pdi1saWxs\nZTEuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCrnebq+nhIUfCL\n6I0Zs/hG4XeRItJBgsQQ2AB2JndoMZaRewzKT/9Ht/EqObllh5C3qFhMDitBd5Au\nE6/+Dhff00q4GGskt3Nf0qsV9EuOvyr2z2kx94wnilABMm+dZo4j0NBLuGo+vPNc\nsbjUjmo/fmD5N47iI3+UqcZPmKlp5mnfJ/QfMWYhkE9xSknu+jwr85mtYPJlMLLR\nbYwaVoCpNNn/dI9AmKPV0j4Hy7Wi3ZHehqg1e2qHaejGdTt61W5hzVfzXgc/VznF\nkISdtz8ohNq5NqXNKdddyDY60miygAtY/3BVf5/FQklalDtVWnVbFR2iqDLiRhpm\nXKBzPwIbAgMBAAGjSDBGMCUGA1UdEQQeMByCGmRydXBhbC13ZWIxLnVuaXYtbGls\nbGUxLmZyMB0GA1UdDgQWBBR4MjERy9HNblRVIBMMXv6lw+oJxjANBgkqhkiG9w0B\nAQUFAAOCAQEAJhvOYbbYtxKGw3GfYyAIag15zgdx/Zv0R8/aMtq4lum5ibJeh559\ntpJBBtqclTvMPzA0pjO61NWavFC+ROU4FMDL4HZF2fJN44VBloK2qSExD+jU3ARy\niH7gAMMeRvnUUanQaefaacSKvrIL1EU2PCcaTHyRGqzILBi6ZbvmmZLhFB1OmlYH\nFwPWP4omGY8/MYNYuW5oU/HtpkdLWUed9DqGQSJDodBVdJHyjWEzNwf+mxBlwSXa\n4VEJouPfrQAD6PqFhsz9qQpx8gYuNN3iUVSL0CIjthzBGp/B2d+813Haio+5qsOL\nDj+RBXEEXq6BPJ4ZI/vQ8DB6K34mTzfQKg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://identite.intranet.univ-lille.fr/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://identite.intranet.univ-lille.fr/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Universit\u00e9 de Lille - plate-forme charte digitale (identit\u00e9)"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Universit\u00e9 de Lille - plate-forme charte digitale (identit\u00e9)"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Cette plate-forme permet aux responsables de communication de charger les \u00e9l\u00e9ments d'identification num\u00e9rique"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This platform allows the responsables of the communication to load digital identification elements they need"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://catalogue.clouds.geant.net/saml2/entityid",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "geant-cloud-catalogue@grnet.gr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "geant-cloud-catalogue@grnet.gr"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://catalogue.clouds.geant.net/saml2/entityid",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "G\u00c9ANT Association"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.geant.org"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "G\u00c9ANT Association"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://catalogue.clouds.geant.net"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "GEANT Cloud Catalogue"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://catalogue.clouds.geant.net/#/privacy-statement"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "GEANT Cloud Catalogue"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://catalogue.clouds.geant.net/api/login/saml/callback",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "GEANT Cloud Catalogue"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "GEANT Cloud Catalogue"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://meetingtools.nordu.net/shibboleth",
    {
      "entity_id": "https://meetingtools.nordu.net/shibboleth",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://meetingtools.nordu.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://meetingtools.nordu.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://meetingtools.nordu.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://meetingtools.nordu.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "NORDUnet E-Meeting Tools"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "NORDUnet E-Meeting Tools"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://meetingtools.nordu.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://meetingtools.nordu.net/Shibboleth.sso/DS/idp.nordu.net",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "meetingtools.nordu.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJAMw0JbtsXnrGMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFm1lZXRpbmd0b29scy5ub3JkdS5uZXQwHhcNMTExMDA3MjE0MjU3WhcNMjEx\nMDA0MjE0MjU3WjAhMR8wHQYDVQQDExZtZWV0aW5ndG9vbHMubm9yZHUubmV0MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApF6eyxvsRmbALxDE1Mlxt1IV\nSY9pEr28vv1T3HDQFW0TI2SQeMQlkXmfjux0qxY3F+qI15zejcAwzhZottruFP6M\nTGTgcfC3w2H1esB2O29okFddXBtyaXWW6hVAjF1Bmgy0UwBDWWxCHo4BhXQRyIBe\ncK+hf+xgpgOdFhgC8BJERinuVtZjCRiHqyoZ9WH9/+Qd09BuGGdCXRTrmk/SO/NT\nNcpbvyb4rLriW7xGgHScc3rdmgJnmMeXXKdMQt8q0kjbaSeibq1Z3Jqa7nDQa//1\n1VauaXNcLtiU6eTYP7vf9qLo1evQ7tkIo8PGeqX92dp4fse7lv6zVQdKlP/GiQID\nAQABo0QwQjAhBgNVHREEGjAYghZtZWV0aW5ndG9vbHMubm9yZHUubmV0MB0GA1Ud\nDgQWBBQiAOf3NZwStjuODYT1PI8wpOYO2jANBgkqhkiG9w0BAQUFAAOCAQEAasFD\nWphqHBIxJMIx1TR5LCoabp9ZM8yN7TNpmneCnhSotjNxDRhzHANKsotjRsmV80tA\n5v4yN0ORHXDjN18C1YtkaYZNGSPwEbaLWeY2MulBcgJq0nvNOxDeGhkO57u+stgY\n8Wi/UNX1X9L5TJ60AdR+jE3gVsAA7DqhKRWqSvsh6jfSwUg83A/QYIp7Qi5LfejS\nLjjhavn6zDPLc+ILO7PDrwLBw8FD9bsff4wpngUvwQb1c1jgAy1FNGO/lK5KfX45\nasFBcvwcrKqc1WoJd5PodrX9RFw/bbIceEm5ifzg2KzsS+rWxah/RVXsXWio/nY5\npcqH0yzoEFA0VHDdXA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=meetingtools.nordu.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "meetingtools.nordu.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJAMw0JbtsXnrGMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFm1lZXRpbmd0b29scy5ub3JkdS5uZXQwHhcNMTExMDA3MjE0MjU3WhcNMjEx\nMDA0MjE0MjU3WjAhMR8wHQYDVQQDExZtZWV0aW5ndG9vbHMubm9yZHUubmV0MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApF6eyxvsRmbALxDE1Mlxt1IV\nSY9pEr28vv1T3HDQFW0TI2SQeMQlkXmfjux0qxY3F+qI15zejcAwzhZottruFP6M\nTGTgcfC3w2H1esB2O29okFddXBtyaXWW6hVAjF1Bmgy0UwBDWWxCHo4BhXQRyIBe\ncK+hf+xgpgOdFhgC8BJERinuVtZjCRiHqyoZ9WH9/+Qd09BuGGdCXRTrmk/SO/NT\nNcpbvyb4rLriW7xGgHScc3rdmgJnmMeXXKdMQt8q0kjbaSeibq1Z3Jqa7nDQa//1\n1VauaXNcLtiU6eTYP7vf9qLo1evQ7tkIo8PGeqX92dp4fse7lv6zVQdKlP/GiQID\nAQABo0QwQjAhBgNVHREEGjAYghZtZWV0aW5ndG9vbHMubm9yZHUubmV0MB0GA1Ud\nDgQWBBQiAOf3NZwStjuODYT1PI8wpOYO2jANBgkqhkiG9w0BAQUFAAOCAQEAasFD\nWphqHBIxJMIx1TR5LCoabp9ZM8yN7TNpmneCnhSotjNxDRhzHANKsotjRsmV80tA\n5v4yN0ORHXDjN18C1YtkaYZNGSPwEbaLWeY2MulBcgJq0nvNOxDeGhkO57u+stgY\n8Wi/UNX1X9L5TJ60AdR+jE3gVsAA7DqhKRWqSvsh6jfSwUg83A/QYIp7Qi5LfejS\nLjjhavn6zDPLc+ILO7PDrwLBw8FD9bsff4wpngUvwQb1c1jgAy1FNGO/lK5KfX45\nasFBcvwcrKqc1WoJd5PodrX9RFw/bbIceEm5ifzg2KzsS+rWxah/RVXsXWio/nY5\npcqH0yzoEFA0VHDdXA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=meetingtools.nordu.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://meetingtools.nordu.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://meetingtools.nordu.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://meetingtools.nordu.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://meetingtools.nordu.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://meetingtools.nordu.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://meetingtools.nordu.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://meetingtools.nordu.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://meetingtools.nordu.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://meetingtools.nordu.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://meetingtools.nordu.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp-test.swamid.se/shibboleth",
    {
      "entity_id": "https://sp-test.swamid.se/shibboleth",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish Academic Identity Federation (SWAMID)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.swamid.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SWAMID"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp-test.swamid.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp-test.swamid.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp-test.swamid.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp-test.swamid.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp-test.swamid.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp-test.swamid.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp-test.swamid.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp-test.swamid.se/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp-test.swamid.se/Shibboleth.sso/DS/test-ds.nordu.net",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "4"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp-test.swamid.se/Shibboleth.sso/DS/kalmar2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "5"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.swamid.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.swamid.se"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Detta \u00e4r en applikation som l\u00e5ter dig testa federerad inloggning."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is an application for testing federated authentication."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SWAMID Test SP"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SWAMID Test SP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "sp-test.swamid.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+jCCAeKgAwIBAgIJANmYETA8gTbGMA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\nBAMTEXNwLXRlc3Quc3dhbWlkLnNlMB4XDTE1MDEyODE0NDkzNVoXDTI1MDEyNTE0\nNDkzNVowHDEaMBgGA1UEAxMRc3AtdGVzdC5zd2FtaWQuc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDB9LT9HoTmLjPiMQvo9zujGS3cLF6TbukK8A0B\nCfA/A6JJkwLpbHbGzL4VRnaSzS8qW+6TvehFFDlh+u1W91rOodiqkpAubHcO97O2\nth677wXUyyOWsnlyxnOWQVBrtWJFfV1zjmr8AfdHW1zbpstWWz+orEUNBE7X39dd\nZq7eorJZD+rD07XU40cwXUwKUy7m73XLHlW3sXuJXddZ/1qs4UilC9LRflaL7j4A\nUmUbil+Md+xm3rEuiEjN3hiZiyjSTja7NIP2unhzxJSoAC9X/6cj5aWrEjO6oplf\ns+xei1Rya8qzFHcLvGRME2tFMb047sTCGl6oCkoizC4hCCfpAgMBAAGjPzA9MBwG\nA1UdEQQVMBOCEXNwLXRlc3Quc3dhbWlkLnNlMB0GA1UdDgQWBBSsTWqxt6/xVeVD\nRW62Ap+udtmTNzANBgkqhkiG9w0BAQUFAAOCAQEAIB6TPgX+qJ5pa8oLETXnArQg\nC946h+Im7zjT8kuCpeiL7/lfohqclaJB3PfYOs82FwmOOkmA3kcZdk4aaOXXZkh9\n05ZoxxYo64mssvXLNcB0ydOJ1o82gdPzL2dTR+iT1IlanJkAyI6OR6ZO6q69+sFJ\nZ7BVMhzPKNxFNlHEJOEVenCxPNn/B4pVV3W7pq2EKYgi6e2MtpQGKb0IKWaZzVLz\nbqvHv30vxBnEMgIgSmDtVTlSKFzulp153JSZJpb/88H0RPZY6odIakCuDzOkVhIj\nCUgd8Vxw9b2Xr/McJ4HsCt/ebBUvDnW98Sk+e03ZX2PQNLhKOtyKaF0l+o0K8g=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=sp-test.swamid.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp-test.swamid.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp-test.swamid.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp-test.swamid.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp-test.swamid.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp-test.swamid.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp-test.swamid.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp-test.swamid.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp-test.swamid.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp-test.swamid.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp-test.swamid.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://login.cmu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth-team@andrew.cmu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Support Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "it-help@cmu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Computing Services Help Center"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jeaton@cmu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeffrey Eaton"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dschill@cmu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Deborah Schill"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.cmu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.cmu.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.cmu.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAO1Zt6Sg0xhmMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDWxvZ2luLmNtdS5lZHUwHhcNMTQwMTIyMTkzMDM2WhcNMzAwNjI5MTkzMDM2\nWjAYMRYwFAYDVQQDEw1sb2dpbi5jbXUuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEA4yIV5lVs9/7jdmRTi23AINTzGQTrL+p8EXmV1iL48YAZ36T+\nxnDpTXt2RDaioI34/P9vHYpSKY6C5gDNyXGQZYTrgJQHQRgJAGTsXshYoDeBboZZ\n9ax+7m86rKqmHZAprHALONubY0UtPDEGQKdMeeetAUAOh8kIKpGvKp96I+4pIT6S\n/p5VtBB80veOK6woqbzU0Qr9q1FbcZfJ6AjG8as9lBa9Si6vc/fGvFrjsJL3+cpv\nECuyG/yHp9obdwXLgxlQNPtXNeBgclgiaJJE8zWcZBUxWPboVeuC2Jfv7spIOcCy\nKPKTGUlobBoANGHqGMqbK+/7YzQ+J/s/4n0tvwIDAQABo3kwdzAdBgNVHQ4EFgQU\noZye8kn1Hznd+tCaxJ3elowNIbYwSAYDVR0jBEEwP4AUoZye8kn1Hznd+tCaxJ3e\nlowNIbahHKQaMBgxFjAUBgNVBAMTDWxvZ2luLmNtdS5lZHWCCQDtWbekoNMYZjAM\nBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCp51hb/WPVfRtdQNZm6OQj\n8I6HwDGWmu5PzUycJAkD/VYd3wCM1zLwd32LMbxbA2ArKWBstErEsUog94zvMBWy\nAeT3Q5Gyghji0emF0nbZpNjPjE9bXavMbUppXF2/VHbuBtzEMBxIKV53X2et2MMc\n9mnNzZN1rofuIB//W9Fg9IWV5PLVbsvEYI98IkJ5t4JP92/V5p497O8jMj6oLhy7\nmI4FNx0pQnirAvrQxxgFTwVV5SEm87DBYRblUb4ba0yYVSBQg0EVbIb7QEDxHFWb\nzt4+NLolAQAMSQW+SJKf9V7+6+4uhMwpJxQwezzn41u9kGTIg9F8/s0IrgsTlAm3"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "andrew.cmu.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.cmu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.cmu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.cmu.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.cmu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.cmu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.cmu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "andrew.cmu.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Carnegie Mellon University Identity Provider"
                  }
                ],
                "logo": [
                  {
                    "text": "https://identity.andrew.cmu.edu/incommon/cmu-181x125.gif",
                    "lang": "en",
                    "height": "125",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "181"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Carnegie Mellon University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAO1Zt6Sg0xhmMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDWxvZ2luLmNtdS5lZHUwHhcNMTQwMTIyMTkzMDM2WhcNMzAwNjI5MTkzMDM2\nWjAYMRYwFAYDVQQDEw1sb2dpbi5jbXUuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEA4yIV5lVs9/7jdmRTi23AINTzGQTrL+p8EXmV1iL48YAZ36T+\nxnDpTXt2RDaioI34/P9vHYpSKY6C5gDNyXGQZYTrgJQHQRgJAGTsXshYoDeBboZZ\n9ax+7m86rKqmHZAprHALONubY0UtPDEGQKdMeeetAUAOh8kIKpGvKp96I+4pIT6S\n/p5VtBB80veOK6woqbzU0Qr9q1FbcZfJ6AjG8as9lBa9Si6vc/fGvFrjsJL3+cpv\nECuyG/yHp9obdwXLgxlQNPtXNeBgclgiaJJE8zWcZBUxWPboVeuC2Jfv7spIOcCy\nKPKTGUlobBoANGHqGMqbK+/7YzQ+J/s/4n0tvwIDAQABo3kwdzAdBgNVHQ4EFgQU\noZye8kn1Hznd+tCaxJ3elowNIbYwSAYDVR0jBEEwP4AUoZye8kn1Hznd+tCaxJ3e\nlowNIbahHKQaMBgxFjAUBgNVBAMTDWxvZ2luLmNtdS5lZHWCCQDtWbekoNMYZjAM\nBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCp51hb/WPVfRtdQNZm6OQj\n8I6HwDGWmu5PzUycJAkD/VYd3wCM1zLwd32LMbxbA2ArKWBstErEsUog94zvMBWy\nAeT3Q5Gyghji0emF0nbZpNjPjE9bXavMbUppXF2/VHbuBtzEMBxIKV53X2et2MMc\n9mnNzZN1rofuIB//W9Fg9IWV5PLVbsvEYI98IkJ5t4JP92/V5p497O8jMj6oLhy7\nmI4FNx0pQnirAvrQxxgFTwVV5SEm87DBYRblUb4ba0yYVSBQg0EVbIb7QEDxHFWb\nzt4+NLolAQAMSQW+SJKf9V7+6+4uhMwpJxQwezzn41u9kGTIg9F8/s0IrgsTlAm3"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://login.cmu.edu/error"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Carnegie Mellon University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cmu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Carnegie Mellon University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://konto.weblogin.uu.se/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 18 4714400"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT Servicedesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@uu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Uppsala universitet"
          }
        }
      ],
      "entity_id": "https://konto.weblogin.uu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Uppsala University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uu.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Uppsala universitet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://konto.weblogin.uu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://konto.weblogin.uu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://konto.weblogin.uu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://konto.weblogin.uu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://konto.weblogin.uu.se"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://konto.weblogin.uu.se"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "As a new user you use this service to activate your university user account. You can also use this service to reset your password A for your user account after the account activation."
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Denna tj\u00e4nst anv\u00e4nds f\u00f6r att du som ny vid universitetet ska kunna aktivera ditt anv\u00e4ndarkonto vid universitetet. Om du redan har ett aktivt konto kan du s\u00e4tta ett nytt l\u00f6senord A om du gl\u00f6mt bort det."
                  }
                ],
                "logo": [
                  {
                    "text": "https://weblogin.uu.se/idp/UUlogin/img/logga-50.png",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "https://weblogin.uu.se/idp/UUlogin/img/logga-50.png",
                    "lang": "sv",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Uppsala University user account activation and password reset"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Uppsala universitets kontoaktivering och l\u00f6senords\u00e5terst\u00e4llning"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAI/Rhjc/wAcdMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2FlZG9uLml0cy51dS5zZTAeFw0xNDA1MDUxMjIyMjBaFw0yNDA1MDIxMjIy\nMjBaMBoxGDAWBgNVBAMTD2FlZG9uLml0cy51dS5zZTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAMLJHukRi8ySdl/DeCCF+XB0KN6Ky92ibQ6aTQdu+q1G\naQcFwJTapkMG5+KApWspnM9GWnTgNRaZwF98xzFUyaj7Z88BG2Rn8kAJf16Je7LN\nmVgUXhZN6nQzZGb+4L++vIB2EcWvAXalRP0V6Y6WTJBDDI+HG548gb7vWN68HHE1\niBm2QZr7yBnhZrG4OsNRCuKUK9e0yXBqhSW1EOwPXloM6FgXZjTnrb99lmXyfPt/\n7G/dLT9oY/sYCpmRBDDUNaAVZuxzazkCFV0ZtmzMyLcFDV/caclGWTW86GNJulw+\nffDfBDfG7bhsHNqa3ar8mpQEIo/8kUoNcH9OS1/asyUCAwEAAaM9MDswGgYDVR0R\nBBMwEYIPYWVkb24uaXRzLnV1LnNlMB0GA1UdDgQWBBQcAKnb0JlKlMYIoq5GshvP\nDIjHVzANBgkqhkiG9w0BAQUFAAOCAQEAMCEWlxpp+ghjA7EOnciNnGZem76Hef9s\npzzHcnHiPvsK9Y4s4OjyYx3EXNjux+r+gkAqFk4p7Mfc9L/4v51aW5P069Ttwu/T\nrCmWdcPDQZ45OLMD3s5Yvp0k3IP/HiEhfDAPqo224vsfrgJXU+5rNAG8h1l6YutX\nk6mytFVNBJaLEJYG9IRo0GZTyeK2xyrEZxJvAl/SyjsHWwXbw+jbdeSWB7uyyIPW\nBtIN3xWoW7aN5Yg1C9JTu/1SjtZp4Zz5o9cAWUJ12W9yTjp8Eck5ygXiYjLrfnO3\nzs343t8msFatMz3jlO+DgmZS0btlHkYSvRDAGaXOAkwGnE3nzjsLKA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://konto.weblogin.uu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://konto.weblogin.uu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://konto.weblogin.uu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://konto.weblogin.uu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://konto.weblogin.uu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.caltech.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "zleite@caltech.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Zailo Leite"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ruthanne@caltech.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "RuthAnne Bevier"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.caltech.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.caltech.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.caltech.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUC0Z5A7Hz0aGgHdvfgWBw/TW939IwDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPaWRwLmNhbHRlY2guZWR1MB4XDTEwMDIwNDAwMzgxNFoX\nDTMwMDIwNDAwMzgxNFowGjEYMBYGA1UEAxMPaWRwLmNhbHRlY2guZWR1MIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAjUfvISEj5BkXO8k4dKr7C1NdlDIs\nosNxbjP39/8oVwgGaMSnkfMhY6xct9gnxTzCRXe49MU+UyVRlljTqTeIJf8VG0K2\naPSRk9xpzWje/fEkUHgpOjLDM0TNB2tWIQbHQwHz7HsuB/Au870PBMv4EfVz4us8\nyTmYvY2ZJPe192BnIbNyLub138HXjr7TrLBxMg7KulnanGnN75UrVjueRzAvFZlE\nlAZ+shDsjVYAoceEaFn7TF37ehVdjbXwOegtu+vU0kjjCS3cQUXXOs1Ojz6Vood/\noP1SOisW3bEhboKMUCWEcDckUXHVd/qCekbUsJEt5KAK6Gmf5Ygha748kQIDAQAB\no2UwYzBCBgNVHREEOzA5gg9pZHAuY2FsdGVjaC5lZHWGJmh0dHBzOi8vaWRwLmNh\nbHRlY2guZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRlqKQBRnVFASGfdigd\na/ihuq365zANBgkqhkiG9w0BAQUFAAOCAQEAck8P9JfpOWTpgc4LCyaY3WiJFIGe\nWT25D+6Gj7ADxj7+o2UZCcB2sI5LvyFJaetQSB/7p0F+hmU8/csunwoWARnbOcJt\nSmbyiJQ6eKUXOklOEqxEpGZRa2MbRwukfVx+v6U3N75JxoyuNfqC/G3tKzOIo4qz\nuxiE+1ntesuGTmWuLx9dIKILJ6XuD/rmGSkeKWljLC1jNQEjHioskqIFhcF1JxDv\nqnn8IBfnaoc4GX6AV3fEHifdQEOu7GdicUeA8o+cKqddCZf1PoUTSPby1NcFeDO6\nPPYq4pWYGD1Sc8SOXB+99YOD8hJObGIcskF0VRwv1Kg7rrTBqPLic7kcRA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "caltech.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.caltech.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.caltech.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.caltech.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.caltech.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.caltech.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.caltech.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "caltech.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "California Institute of Technology"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUC0Z5A7Hz0aGgHdvfgWBw/TW939IwDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPaWRwLmNhbHRlY2guZWR1MB4XDTEwMDIwNDAwMzgxNFoX\nDTMwMDIwNDAwMzgxNFowGjEYMBYGA1UEAxMPaWRwLmNhbHRlY2guZWR1MIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAjUfvISEj5BkXO8k4dKr7C1NdlDIs\nosNxbjP39/8oVwgGaMSnkfMhY6xct9gnxTzCRXe49MU+UyVRlljTqTeIJf8VG0K2\naPSRk9xpzWje/fEkUHgpOjLDM0TNB2tWIQbHQwHz7HsuB/Au870PBMv4EfVz4us8\nyTmYvY2ZJPe192BnIbNyLub138HXjr7TrLBxMg7KulnanGnN75UrVjueRzAvFZlE\nlAZ+shDsjVYAoceEaFn7TF37ehVdjbXwOegtu+vU0kjjCS3cQUXXOs1Ojz6Vood/\noP1SOisW3bEhboKMUCWEcDckUXHVd/qCekbUsJEt5KAK6Gmf5Ygha748kQIDAQAB\no2UwYzBCBgNVHREEOzA5gg9pZHAuY2FsdGVjaC5lZHWGJmh0dHBzOi8vaWRwLmNh\nbHRlY2guZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRlqKQBRnVFASGfdigd\na/ihuq365zANBgkqhkiG9w0BAQUFAAOCAQEAck8P9JfpOWTpgc4LCyaY3WiJFIGe\nWT25D+6Gj7ADxj7+o2UZCcB2sI5LvyFJaetQSB/7p0F+hmU8/csunwoWARnbOcJt\nSmbyiJQ6eKUXOklOEqxEpGZRa2MbRwukfVx+v6U3N75JxoyuNfqC/G3tKzOIo4qz\nuxiE+1ntesuGTmWuLx9dIKILJ6XuD/rmGSkeKWljLC1jNQEjHioskqIFhcF1JxDv\nqnn8IBfnaoc4GX6AV3fEHifdQEOu7GdicUeA8o+cKqddCZf1PoUTSPby1NcFeDO6\nPPYq4pWYGD1Sc8SOXB+99YOD8hJObGIcskF0VRwv1Kg7rrTBqPLic7kcRA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idp.caltech.edu/idp/profile/error"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California Institute of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.caltech.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California Institute of Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.sdeo.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:admin@sdeo.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Admin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@abdn.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@abdn.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Service Desk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.sdeo.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-10-23T09:02:25Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Scottish Dental Education Online"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sdeo.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Aberdeen"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.sdeo.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.sdeo.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.sdeo.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.sdeo.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.sdeo.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.sdeo.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.sdeo.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Interactive online learning and teaching resources to support dental education."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.sdeo.ac.uk/logo.png",
                    "height": "146",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "300"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Scottish Dental Education Online"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJAPNguqNnSFj+MA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\n\t\t\t\t\t\tBAMTDnd3dy5zZGVvLmFjLnVrMB4XDTE0MDgxNDE0MzMzMVoXDTI0MDgxMTE0MzMz\n\t\t\t\t\t\tMVowGTEXMBUGA1UEAxMOd3d3LnNkZW8uYWMudWswggEiMA0GCSqGSIb3DQEBAQUA\n\t\t\t\t\t\tA4IBDwAwggEKAoIBAQC8jVkdArAQ8ngJOd4S1c7ChUaYBpxSv4MwhugEoyFjHqC8\n\t\t\t\t\t\ttzhQHYHQEgCY5WxqnNaVExWXVqKPaQxgHtDQbiKU019yOYlpXK3+FfCjLBgEMDni\n\t\t\t\t\t\tMUrUAhBaOQlIdkbfXSq5dRfDx3KjRmXbeuhKfC/pHSLJ1Fer0c8r7z6zN6iXgzsI\n\t\t\t\t\t\t5iVQL5lPJvCeBh6Af/fbp2FHkmIAqctN8yQfpfskCMugxebH1sUa/nvrVJtf8fqQ\n\t\t\t\t\t\tDAZrmF5foRy7pENW0bPvdZDhH2nL0O4Qw6mNO8n1b438vS4fiYuXEU/bE4cp9YuZ\n\t\t\t\t\t\t9MqDdXhHT2LvqqBmVLAHV85Xos/1W6NHXxoK9XpzAgMBAAGjPDA6MBkGA1UdEQQS\n\t\t\t\t\t\tMBCCDnd3dy5zZGVvLmFjLnVrMB0GA1UdDgQWBBR6m5nWMYxvlH0uKtTjMCJOFX9B\n\t\t\t\t\t\t+jANBgkqhkiG9w0BAQUFAAOCAQEAgTX3B7chPGaD1758ssHPw7v5HzwtV4KUzM5t\n\t\t\t\t\t\ta3UvzNYQoSlipXieO2ySckD66K/UM7i3ORF5TJW/2xzo54yKBaZDg/mTZGp3v0tv\n\t\t\t\t\t\tZ4qvT5tlbygizHMz+Cdh8Ete8uBbRIG87Sr7GaR8ZMRNjaz7v3mqgKB6zUBdjjWx\n\t\t\t\t\t\tL2+UFp82CgxFjkZDWabONQV+bRRku0wBsRYqikrarLzcV7wS0EM4Li3LVAyj2P9e\n\t\t\t\t\t\t+3eucC8gDxQ8AjjNOg/SKGcRLQe5fYa6X2GYy2yLY0QpN7VwP0cVRHyNy+cdWlQ6\n\t\t\t\t\t\tLhzcTCIPjQ9bO+7235hm6tzlYYfOG6yAcAolWtWiQuVcnHbbkA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.sdeo.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.sdeo.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.sdeo.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.sdeo.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.sdeo.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.sdeo.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://sts.wur.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://sts.wur.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-06-08T20:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/4ff1ecb290680df5b2ee5c631c2fc102",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wur.nl"
              },
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Wageningen UR"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Wageningen UR"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/wur.png",
                    "height": "17",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Wageningen UR"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Wageningen UR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Wageningen UR"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wageningenur.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Wageningen UR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.yorkcollege.ac.uk/entity",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Iqbal"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aiqbal@yorkcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Azhar"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Iqbal"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aiqbal@yorkcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Azhar"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.yorkcollege.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-08-12T16:32:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVANXRdn2uq2aNgUyIN3af5+JhI22qMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCAxHjAcBgNVBAMTFWlkcC55b3JrY29sbGVnZS5hYy51azAeFw0xNDA3MjIx\n\t\t\t\t\t\tMjU3MDVaFw0zNDA3MjIxMjU3MDVaMCAxHjAcBgNVBAMTFWlkcC55b3JrY29sbGVn\n\t\t\t\t\t\tZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKyCyLcm8cm/\n\t\t\t\t\t\t4wDpVwulDJF1aG3tUj6h/vsHjLGDrzvgYByEPa1vBMUwQYJKTWcgk+Ap/YUCMPIv\n\t\t\t\t\t\tByctJI3zW6I8P5KjgppkkTA5YuRNEFRApoa8XGufuX/LdZ8pZtD0NvlWgiXooazy\n\t\t\t\t\t\tu/nKaQC5A1KKKG23dXVojX4SOEbOJBk3BeS5STd0BTBGBEyBQbGIAn9KspvkyFFm\n\t\t\t\t\t\tBn5EqnNE2l0H1d6IpEDiwSQ4PxtR3zZ3vjzrxToSAKKAsu/uQGZ30xQq/Qpcgpu5\n\t\t\t\t\t\tD2vk71cvhTqaJgYNhnjNfcMhLgkwkdFbvS+E2jVBHiIt5uKq5YydUP7NvCItKdI0\n\t\t\t\t\t\tIDiO9Qoc3AsCAwEAAaNxMG8wTgYDVR0RBEcwRYIVaWRwLnlvcmtjb2xsZWdlLmFj\n\t\t\t\t\t\tLnVrhixodHRwczovL2lkcC55b3JrY29sbGVnZS5hYy51ay9pZHAvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQUxrFZaYCOWnFDHol052uaf+yiXrswDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAKOWPrRWqDYsTi7VQ+AKih6nUV7iNeD8f5WFNuc2xCII9ggSgvTVAzkaYDqH\n\t\t\t\t\t\tX4M/2Z2vhHRpiVcNKpsW+v6Fzhgy7yhDv3PrDfxgvDm2bQ3X4KH0X1hrWmxaUgxg\n\t\t\t\t\t\tProTJFt6kDIaesBYHt93RhZv/gCBCyVxDfXMvgqq7/4+Lr2Q0Be8+RQ69asVA5S/\n\t\t\t\t\t\t0PZS97qMeLD5HveS6DkV1D1K7YWVXiPEawLkKN9fywU6GA9QrUyUxI2z+YngAskU\n\t\t\t\t\t\tU+QmvDADLGZ7a7dJ8UUavfaxPiYA8eOdir52Q+eFdMEdL4CsWxjmQF+ubm0YPKQF\n\t\t\t\t\t\tPL5wY3K8+WVnAlA7MY/oR6rJJQo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "yorkcollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.yorkcollege.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.yorkcollege.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.yorkcollege.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.yorkcollege.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.yorkcollege.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shiblogin.yorkcollege.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shiblogin.yorkcollege.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shiblogin.yorkcollege.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shiblogin.yorkcollege.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.yorkcollege.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.yorkcollege.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "yorkcollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVANXRdn2uq2aNgUyIN3af5+JhI22qMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCAxHjAcBgNVBAMTFWlkcC55b3JrY29sbGVnZS5hYy51azAeFw0xNDA3MjIx\n\t\t\t\t\t\tMjU3MDVaFw0zNDA3MjIxMjU3MDVaMCAxHjAcBgNVBAMTFWlkcC55b3JrY29sbGVn\n\t\t\t\t\t\tZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKyCyLcm8cm/\n\t\t\t\t\t\t4wDpVwulDJF1aG3tUj6h/vsHjLGDrzvgYByEPa1vBMUwQYJKTWcgk+Ap/YUCMPIv\n\t\t\t\t\t\tByctJI3zW6I8P5KjgppkkTA5YuRNEFRApoa8XGufuX/LdZ8pZtD0NvlWgiXooazy\n\t\t\t\t\t\tu/nKaQC5A1KKKG23dXVojX4SOEbOJBk3BeS5STd0BTBGBEyBQbGIAn9KspvkyFFm\n\t\t\t\t\t\tBn5EqnNE2l0H1d6IpEDiwSQ4PxtR3zZ3vjzrxToSAKKAsu/uQGZ30xQq/Qpcgpu5\n\t\t\t\t\t\tD2vk71cvhTqaJgYNhnjNfcMhLgkwkdFbvS+E2jVBHiIt5uKq5YydUP7NvCItKdI0\n\t\t\t\t\t\tIDiO9Qoc3AsCAwEAAaNxMG8wTgYDVR0RBEcwRYIVaWRwLnlvcmtjb2xsZWdlLmFj\n\t\t\t\t\t\tLnVrhixodHRwczovL2lkcC55b3JrY29sbGVnZS5hYy51ay9pZHAvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQUxrFZaYCOWnFDHol052uaf+yiXrswDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAKOWPrRWqDYsTi7VQ+AKih6nUV7iNeD8f5WFNuc2xCII9ggSgvTVAzkaYDqH\n\t\t\t\t\t\tX4M/2Z2vhHRpiVcNKpsW+v6Fzhgy7yhDv3PrDfxgvDm2bQ3X4KH0X1hrWmxaUgxg\n\t\t\t\t\t\tProTJFt6kDIaesBYHt93RhZv/gCBCyVxDfXMvgqq7/4+Lr2Q0Be8+RQ69asVA5S/\n\t\t\t\t\t\t0PZS97qMeLD5HveS6DkV1D1K7YWVXiPEawLkKN9fywU6GA9QrUyUxI2z+YngAskU\n\t\t\t\t\t\tU+QmvDADLGZ7a7dJ8UUavfaxPiYA8eOdir52Q+eFdMEdL4CsWxjmQF+ubm0YPKQF\n\t\t\t\t\t\tPL5wY3K8+WVnAlA7MY/oR6rJJQo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "York College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.yorkcollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "York College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://vlab-chemsub.explizit.se/shibboleth",
    {
      "entity_id": "https://vlab-chemsub.explizit.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vlab-chemsub.explizit.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vlab-chemsub.explizit.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vlab-chemsub.explizit.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vlab-chemsub.explizit.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vlab-chemsub.explizit.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://vlab-chemsub.explizit.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.explizit.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEqjCCA5KgAwIBAgIJAN6mS+uZRU41MA0GCSqGSIb3DQEBBQUAMIGUMQswCQYD\nVQQGEwJzZTEVMBMGA1UECBMMdmFzdGVyYm90dGVuMRMwEQYDVQQHEwpza2VsbGVm\ndGVhMREwDwYDVQQKEwhleHBsaXppdDEYMBYGA1UEAxMPd3d3LmV4cGxpeml0LnNl\nMSwwKgYJKoZIhvcNAQkBFh1mcmVkcmlrLmJlcmdxdmlzdEBleHBsaXppdC5zZTAe\nFw0xMDExMTYxOTE1MjlaFw0xMTExMTYxOTE1MjlaMIGUMQswCQYDVQQGEwJzZTEV\nMBMGA1UECBMMdmFzdGVyYm90dGVuMRMwEQYDVQQHEwpza2VsbGVmdGVhMREwDwYD\nVQQKEwhleHBsaXppdDEYMBYGA1UEAxMPd3d3LmV4cGxpeml0LnNlMSwwKgYJKoZI\nhvcNAQkBFh1mcmVkcmlrLmJlcmdxdmlzdEBleHBsaXppdC5zZTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBANX+SLcvpJ/NxWOqJE6zPJ9KTwJGkMKWtxoq\n0mNtBapZHoJISDHH4+j1ZylEkRzst2lEvmAfjGmSj3wN5WW/ul+YrHAu+bYkYJRi\nHt1WwC5NKUD0gtTh9AvESrsvlL/YJx62YYJI9sTGMQOYfvF85TlY2ecOY1vl3dru\n6joF45lrftn9GC2WL3wRY6oRnwTaBTN/w1hDjuOLERlxu32I6df2doyLTw6Qvrvz\n6ZnHQ9L4Ulz+K0tsVJwjvboO7UoC+AzU8UHby00arGfWODUDOsQIsmCRMaJI0A1i\niTsDdrjqXuxLA1kMRhGaDkeRRBPiLHrSHtoHUEW1pB61Yo3FMhMCAwEAAaOB/DCB\n+TAdBgNVHQ4EFgQUV+ffRtxJ/B2a02nS5+osFl16QhQwgckGA1UdIwSBwTCBvoAU\nV+ffRtxJ/B2a02nS5+osFl16QhShgZqkgZcwgZQxCzAJBgNVBAYTAnNlMRUwEwYD\nVQQIEwx2YXN0ZXJib3R0ZW4xEzARBgNVBAcTCnNrZWxsZWZ0ZWExETAPBgNVBAoT\nCGV4cGxpeml0MRgwFgYDVQQDEw93d3cuZXhwbGl6aXQuc2UxLDAqBgkqhkiG9w0B\nCQEWHWZyZWRyaWsuYmVyZ3F2aXN0QGV4cGxpeml0LnNlggkA3qZL65lFTjUwDAYD\nVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAiDgwRGjIWirACtcocF0UFvP9\nI5vCeLeMy2ED4ueG8bIeLJsPlCdLqjK60chpGMq/L2A4T1aCOJsZIhrMllxAqEUv\niAGo7DOLwdukDpLgns1l2UiEkhd+sbQy3cu5Rwn1KQTQPcr9rY2rXdJvWxmJsmOi\nqRNp//HTq6pRy3MufxqH60x1UIIe9MjMsHSPxyN7by6KC3p0GZqUOZsc6QX3T69A\nBdl9r05UYKKJuoMtavur87wqk8OpunbdQgRjaioJ2EV/YjlBL5KdCS5TuBuAu584\nC619vYmdUbDbxVdkkAhza7RsUHau77TY9QaTxvvnzT5ANR78jkgdjNhO9Ono8Q=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=fredrik.bergqvist@explizit.se,CN=www.explizit.se,O=explizit,L=skelleftea,ST=vasterbotten,C=se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.explizit.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEqjCCA5KgAwIBAgIJAN6mS+uZRU41MA0GCSqGSIb3DQEBBQUAMIGUMQswCQYD\nVQQGEwJzZTEVMBMGA1UECBMMdmFzdGVyYm90dGVuMRMwEQYDVQQHEwpza2VsbGVm\ndGVhMREwDwYDVQQKEwhleHBsaXppdDEYMBYGA1UEAxMPd3d3LmV4cGxpeml0LnNl\nMSwwKgYJKoZIhvcNAQkBFh1mcmVkcmlrLmJlcmdxdmlzdEBleHBsaXppdC5zZTAe\nFw0xMDExMTYxOTE1MjlaFw0xMTExMTYxOTE1MjlaMIGUMQswCQYDVQQGEwJzZTEV\nMBMGA1UECBMMdmFzdGVyYm90dGVuMRMwEQYDVQQHEwpza2VsbGVmdGVhMREwDwYD\nVQQKEwhleHBsaXppdDEYMBYGA1UEAxMPd3d3LmV4cGxpeml0LnNlMSwwKgYJKoZI\nhvcNAQkBFh1mcmVkcmlrLmJlcmdxdmlzdEBleHBsaXppdC5zZTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBANX+SLcvpJ/NxWOqJE6zPJ9KTwJGkMKWtxoq\n0mNtBapZHoJISDHH4+j1ZylEkRzst2lEvmAfjGmSj3wN5WW/ul+YrHAu+bYkYJRi\nHt1WwC5NKUD0gtTh9AvESrsvlL/YJx62YYJI9sTGMQOYfvF85TlY2ecOY1vl3dru\n6joF45lrftn9GC2WL3wRY6oRnwTaBTN/w1hDjuOLERlxu32I6df2doyLTw6Qvrvz\n6ZnHQ9L4Ulz+K0tsVJwjvboO7UoC+AzU8UHby00arGfWODUDOsQIsmCRMaJI0A1i\niTsDdrjqXuxLA1kMRhGaDkeRRBPiLHrSHtoHUEW1pB61Yo3FMhMCAwEAAaOB/DCB\n+TAdBgNVHQ4EFgQUV+ffRtxJ/B2a02nS5+osFl16QhQwgckGA1UdIwSBwTCBvoAU\nV+ffRtxJ/B2a02nS5+osFl16QhShgZqkgZcwgZQxCzAJBgNVBAYTAnNlMRUwEwYD\nVQQIEwx2YXN0ZXJib3R0ZW4xEzARBgNVBAcTCnNrZWxsZWZ0ZWExETAPBgNVBAoT\nCGV4cGxpeml0MRgwFgYDVQQDEw93d3cuZXhwbGl6aXQuc2UxLDAqBgkqhkiG9w0B\nCQEWHWZyZWRyaWsuYmVyZ3F2aXN0QGV4cGxpeml0LnNlggkA3qZL65lFTjUwDAYD\nVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAiDgwRGjIWirACtcocF0UFvP9\nI5vCeLeMy2ED4ueG8bIeLJsPlCdLqjK60chpGMq/L2A4T1aCOJsZIhrMllxAqEUv\niAGo7DOLwdukDpLgns1l2UiEkhd+sbQy3cu5Rwn1KQTQPcr9rY2rXdJvWxmJsmOi\nqRNp//HTq6pRy3MufxqH60x1UIIe9MjMsHSPxyN7by6KC3p0GZqUOZsc6QX3T69A\nBdl9r05UYKKJuoMtavur87wqk8OpunbdQgRjaioJ2EV/YjlBL5KdCS5TuBuAu584\nC619vYmdUbDbxVdkkAhza7RsUHau77TY9QaTxvvnzT5ANR78jkgdjNhO9Ono8Q=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=fredrik.bergqvist@explizit.se,CN=www.explizit.se,O=explizit,L=skelleftea,ST=vasterbotten,C=se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vlab-chemsub.explizit.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vlab-chemsub.explizit.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vlab-chemsub.explizit.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vlab-chemsub.explizit.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vlab-chemsub.explizit.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vlab-chemsub.explizit.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vlab-chemsub.explizit.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vlab-chemsub.explizit.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vlab-chemsub.explizit.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vlab-chemsub.explizit.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://c.yz.yamagata-u.ac.jp/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ito"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:virtual-amenity@yahoogroups.jp"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tomohiro"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://c.yz.yamagata-u.ac.jp/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.gakunin.jp/en-Join/"
              },
              {
                "lang": "ja",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.gakunin.jp/join/"
              }
            ],
            "registration_instant": "2010-06-21T00:00:00Z",
            "registration_authority": "https://www.gakunin.jp",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Database Amenity Laboratory of Virtual Research Institute, Yamagata University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://a.yamagata-u.ac.jp/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Yamagata University"
          },
          {
            "lang": "ja",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u5c71\u5f62\u5927\u5b66"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://c.yz.yamagata-u.ac.jp/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "ja",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://a.yamagata-u.ac.jp/amenity/menu/shibbolethmenu.aspx"
                  }
                ],
                "description": [
                  {
                    "lang": "ja",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "\u79d1\u5b66\u6280\u8853\u306e\u5b66\u8853\u60c5\u5831\u5171\u6709\u306e\u305f\u3081\u306e\u53cc\u65b9\u5411\u30b3\u30df\u30e5\u30cb\u30b1\u30fc\u30b7\u30e7\u30f3\u30b5\u30fc\u30d3\u30b9"
                  }
                ],
                "logo": [
                  {
                    "text": "https://a.yamagata-u.ac.jp/amenity/jpg/youzan_banner8831.jpg",
                    "height": "31",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "88"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Database Amenity Laboratory of Virtual Research Institute, Yamagata University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE/zCCA+egAwIBAgIIMLbuBJa4k+gwDQYJKoZIhvcNAQELBQAwbTELMAkGA1UE\nBhMCSlAxEDAOBgNVBAcTB0FjYWRlbWUxKjAoBgNVBAoTIU5hdGlvbmFsIEluc3Rp\ndHV0ZSBvZiBJbmZvcm1hdGljczEgMB4GA1UEAxMXTklJIE9wZW4gRG9tYWluIENB\nIC0gRzQwHhcNMTUwNjI2MTE1MjA1WhcNMTcwNzI2MTE1MjA1WjCBkjELMAkGA1UE\nBhMCSlAxEDAOBgNVBAcTB0FjYWRlbWUxHDAaBgNVBAoTE1lhbWFnYXRhIFVuaXZl\ncnNpdHkxMzAxBgNVBAsTKkdyYWR1YXRlIFNjaG9vbCBvZiBTY2llbmNlIGFuZCBF\nbmdpbmVlcmluZzEeMBwGA1UEAxMVYy55ei55YW1hZ2F0YS11LmFjLmpwMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuAYAAne6u5CO2buLsDjIY23w0sd+\nCmnjApy+W6ZckaHQan0VNRCNGstQQEqeHJpIG67DI7q7vPnlESqLIzcflwNsIht8\n5YQlzBKojEVo9zMcz/vmJKlZT/fonJhj7ONiGUtPDdHNOSbI26/+qWJbERTVCYMH\nTfFOQDeHTeMbqA0MkK/kIMkp2HyiuXHmfODV9KI6SuNmvfOXha1/77aF3HPpgr3x\nFxD4kvb/Woqns3eLy66+q9kgLs5Cc+RdeRFJjIVpQRt1WElVTe2+NnX7DMCzHDDy\n8JyWoKUo45XPnW7EWdUTTBbhX4Qnfb52JU50uMc9M0XBJqbJINSAG/OPVQIDAQAB\no4IBezCCAXcwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMB8GA1UdIwQY\nMBaAFBkLbzkfMQM0X+TSQB835o3nYjl8MEoGA1UdHwRDMEEwP6A9oDuGOWh0dHA6\nLy9yZXBvMS5zZWNvbXRydXN0Lm5ldC9zcHBjYS9uaWkvb2RjYTMvZnVsbGNybGc0\nLmNybDAOBgNVHQ8BAf8EBAMCBaAwHQYDVR0OBBYEFE8jKb6jbyN9P8NhmBxP7OJD\nCqmVMFoGA1UdIARTMFEwTwYMKwYBBAGB/AgDAgEBMD8wPQYIKwYBBQUHAgEWMWh0\ndHBzOi8vcmVwbzEuc2Vjb210cnVzdC5uZXQvc3BjcHAvY3BzL2luZGV4Lmh0bWww\nPAYIKwYBBQUHAQEEMDAuMCwGCCsGAQUFBzABhiBodHRwOi8vbmlpZzQub2NzcC5z\nZWNvbXRydXN0Lm5ldDAgBgNVHREEGTAXghVjLnl6LnlhbWFnYXRhLXUuYWMuanAw\nDQYJKoZIhvcNAQELBQADggEBAHUFyHUnBJzkH50yZ9EmZ4ZWCmtyAO0TYM+Tods4\nj5lYP3wjusX55AwatVubnmLgXzvG64PTLMJNhm89tyh1zVhvzb6IguEIjjKlHepg\nyRIpS0TnNzdmdz1WB3ZcNVa+I3QBslApb2Ar5mtqXBumKV7Dr/YBSRgtclfHCK1O\nOgltILmP8cKGwNC36e7NWcqvCdeCL5tSE5A3/j5JltqUMqHxd70XwnQoOcs50p+Q\nsSZfNqJriE0uwFipMv3u1OytFGr+guLQxz7yk1F2hdad8idH/lKbQMKX7IXWcSaY\nrdoKB+QdOSwBBEq7tKdGK4syHTCTtwxDQ23w2l+3yJx4Osc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE4jCCA8qgAwIBAgIIfCMzoF9ue+4wDQYJKoZIhvcNAQEFBQAwfTELMAkGA1UE\nBhMCSlAxETAPBgNVBAcTCEFjYWRlbWUyMSowKAYDVQQKEyFOYXRpb25hbCBJbnN0\naXR1dGUgb2YgSW5mb3JtYXRpY3MxDTALBgNVBAsTBFVQS0kxIDAeBgNVBAsTF05J\nSSBPcGVuIERvbWFpbiBDQSAtIEcyMB4XDTEzMTAwMzA4NTMwOVoXDTE1MTEwMjA5\nMDMwOVowgZAxCzAJBgNVBAYTAkpQMREwDwYDVQQHEwhBY2FkZW1lMjEcMBoGA1UE\nChMTWWFtYWdhdGEgVW5pdmVyc2l0eTEwMC4GA1UECxMnTmV0d29ya2luZyBhbmQg\nQ29tcHV0aW5nIFNlcnZpY2UgQ2VudGVyMR4wHAYDVQQDExVjLnl6LnlhbWFnYXRh\nLXUuYWMuanAwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC53hi5ZLsf\nw7TtCOZ/VmjjF+QlbbJw9/m79AKafPq5pgp/1+rdpouGVG9eqwsBk8TMY+0mN7e8\n9jrgeoOI2Lq1G2S9Q+WOyrr3QVrnFLEeMr/nhYKFzTGh18SsvvL1Rn4GxELPHFpm\nxyK5L3VFgDMQxXN+eNyAt9k/jsn/ugyJrMWAIwPZ3gN45KP1FzcAV5wCNNUK1vAw\nf91V+WzzuotlMUexXiVh+BPI6trkr7d1qAGHhQ3pOCE5akkWQ7qea4cfDHZDAXCK\n5+lajN2IsZK6p1mHxKUBw41To9RVJFIfptpBa+NMiK/wRNHVdQNur5EWojW1RgPo\nuv+3iWeOf8fNAgMBAAGjggFQMIIBTDAOBgNVHQ8BAf8EBAMCBaAwEwYDVR0lBAww\nCgYIKwYBBQUHAwEwHQYDVR0OBBYEFDoI009Wwrb56X0V/UCYX4Li65gMMB8GA1Ud\nIwQYMBaAFHsKB/cYyowO1tq8UIBsLEcC0Q37MCAGA1UdEQQZMBeCFWMueXoueWFt\nYWdhdGEtdS5hYy5qcDBmBgNVHSAEXzBdME0GCiqDCIycHgECAgEwPzA9BggrBgEF\nBQcCARYxaHR0cHM6Ly9yZXBvMS5zZWNvbXRydXN0Lm5ldC9zcGNwcC9jcHMvaW5k\nZXguaHRtbDAMBgoqgwiMmxtkhwUBMEgGA1UdHwRBMD8wPaA7oDmGN2h0dHA6Ly9y\nZXBvMS5zZWNvbXRydXN0Lm5ldC9zcHBjYS9uaWkvb2RjYTIvZnVsbGNybC5jcmww\nEQYJYIZIAYb4QgEBBAQDAgZAMA0GCSqGSIb3DQEBBQUAA4IBAQBcEuFzX4c1vnJw\nB0Y+uN7gr0EO/yFG2cnzEh6EhwAWTrDdF2uDY58HDKbRR0GGqojATgZvtXkE8jn+\n5REAlF0cu+qa5lXTbxYb2ArMjQHY/qTOBnO6/b/lo43+M3x3OXoc/2mV1zHBrh8c\n/NPWl6girCzKqTUd1JJUvjM/VPic8abmzOxIhWLa444jWgFWkA+EqQkJpe9p8r9M\n0h+lJYRn/zZsWA2AbYF0ppkixzk3hHbUwZuuTEZzkAebZh2ZPXZnS0CFfr3VrZbr\ns33kSvCLr3uJ6cetUI0He33NAju0L76lTrfm8lbstwvfvMaruo7tntGmBGL2WRrM\nZH4U1IHm"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://c.yz.yamagata-u.ac.jp/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://c.yz.yamagata-u.ac.jp/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://c.yz.yamagata-u.ac.jp/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://c.yz.yamagata-u.ac.jp/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://c.yz.yamagata-u.ac.jp/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "ja",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "\u79d1\u5b66\u6280\u8853\u306e\u5b66\u8853\u60c5\u5831\u5171\u6709\u306e\u305f\u3081\u306e\u53cc\u65b9\u5411\u30b3\u30df\u30e5\u30cb\u30b1\u30fc\u30b7\u30e7\u30f3\u30b5\u30fc\u30d3\u30b9"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Database Amenity Laboratory of Virtual Research Institute, Yamagata University"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "organizationName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://athens.petroc.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McDonald"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:library@petroc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Phil"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fox"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:simon.fox@petroc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://athens.petroc.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://athens.petroc.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://athens.petroc.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "petroc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDczCCAlugAwIBAgIJAP49f9/KNkx3MA0GCSqGSIb3DQEBBQUAMC8xDzANBgNV\n\t\t\t\t\t\tBAoTBlBFVFJPQzEcMBoGA1UEAxMTYXRoZW5zLnBldHJvYy5hYy51azAeFw0xMTEy\n\t\t\t\t\t\tMTUwOTM4MzdaFw0yMTEyMTIwOTM4MzdaMC8xDzANBgNVBAoTBlBFVFJPQzEcMBoG\n\t\t\t\t\t\tA1UEAxMTYXRoZW5zLnBldHJvYy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBAMhXweFC/U8mUhT+V2vJsH5ELaEs6xDfXD3ihHvvl1AEQtDyRcs0\n\t\t\t\t\t\tN2Zh9QvTgRPWSl569JtcHVQ1G3FIxcUophl5tzKAbI/gxwfkIS1hGSUwKc65pUhY\n\t\t\t\t\t\t4R5HyO26gC9TuHUTXFXL80K+e3IxXoPwaJzabncOz2DGfhXiDZ6PU+ahr+d14YYA\n\t\t\t\t\t\tQZ46a0FsaO2msccY+kr4sdV1O1hXHotooIyyK0131Lt52dcK7mZ7a0LUdEey2TEf\n\t\t\t\t\t\t/zYSPRUMkcxSDzwRlY4FUYLN5wjF4x+bCDlTU3tZZi7+qKH5rmnvHwu63/UbXxhr\n\t\t\t\t\t\t+Z4fBSe8Liyca4xRIxPg1mJtYUb/9JexfGsCAwEAAaOBkTCBjjAdBgNVHQ4EFgQU\n\t\t\t\t\t\tRH/geX2D4EXsTNSy0YbMV9SpA/wwXwYDVR0jBFgwVoAURH/geX2D4EXsTNSy0YbM\n\t\t\t\t\t\tV9SpA/yhM6QxMC8xDzANBgNVBAoTBlBFVFJPQzEcMBoGA1UEAxMTYXRoZW5zLnBl\n\t\t\t\t\t\tdHJvYy5hYy51a4IJAP49f9/KNkx3MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQADggEBALE84Lanege19wQ+QI/SfH7mz1X86E+HwT+Yq1g8PvE/WG82p8DyHbNm\n\t\t\t\t\t\tnKibsrJhHI8bIIvx4FFswl5jlrZf4cXIgTyl2ccesWkk3cCFuaydFUxDzODIWop/\n\t\t\t\t\t\ti7lcvme96nRYyyRXkJ1hh0kp+w7cylnYrP9oilR9XBMj7PQ/9PkHofIq+3U9bM5S\n\t\t\t\t\t\tV9AuL7fbjfXXHWdszx56GKEEwvAhOy9Hfq2/oyRTPKUHNtveFH7WehyMJ0O0FMiC\n\t\t\t\t\t\t6fwieIKJwU2kPV2L8cbfOxRa7nuqXWfqUFMCkx/ptt5joISvGLJqwNlIDzz5zIcu\n\t\t\t\t\t\tQI6O4PXRJe/bHRba/8ghVSi3FUEfb5g="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDczCCAlugAwIBAgIJAP49f9/KNkx3MA0GCSqGSIb3DQEBBQUAMC8xDzANBgNV\n\t\t\t\t\t\tBAoTBlBFVFJPQzEcMBoGA1UEAxMTYXRoZW5zLnBldHJvYy5hYy51azAeFw0xMTEy\n\t\t\t\t\t\tMTUwOTM4MzdaFw0yMTEyMTIwOTM4MzdaMC8xDzANBgNVBAoTBlBFVFJPQzEcMBoG\n\t\t\t\t\t\tA1UEAxMTYXRoZW5zLnBldHJvYy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBAMhXweFC/U8mUhT+V2vJsH5ELaEs6xDfXD3ihHvvl1AEQtDyRcs0\n\t\t\t\t\t\tN2Zh9QvTgRPWSl569JtcHVQ1G3FIxcUophl5tzKAbI/gxwfkIS1hGSUwKc65pUhY\n\t\t\t\t\t\t4R5HyO26gC9TuHUTXFXL80K+e3IxXoPwaJzabncOz2DGfhXiDZ6PU+ahr+d14YYA\n\t\t\t\t\t\tQZ46a0FsaO2msccY+kr4sdV1O1hXHotooIyyK0131Lt52dcK7mZ7a0LUdEey2TEf\n\t\t\t\t\t\t/zYSPRUMkcxSDzwRlY4FUYLN5wjF4x+bCDlTU3tZZi7+qKH5rmnvHwu63/UbXxhr\n\t\t\t\t\t\t+Z4fBSe8Liyca4xRIxPg1mJtYUb/9JexfGsCAwEAAaOBkTCBjjAdBgNVHQ4EFgQU\n\t\t\t\t\t\tRH/geX2D4EXsTNSy0YbMV9SpA/wwXwYDVR0jBFgwVoAURH/geX2D4EXsTNSy0YbM\n\t\t\t\t\t\tV9SpA/yhM6QxMC8xDzANBgNVBAoTBlBFVFJPQzEcMBoGA1UEAxMTYXRoZW5zLnBl\n\t\t\t\t\t\tdHJvYy5hYy51a4IJAP49f9/KNkx3MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQADggEBALE84Lanege19wQ+QI/SfH7mz1X86E+HwT+Yq1g8PvE/WG82p8DyHbNm\n\t\t\t\t\t\tnKibsrJhHI8bIIvx4FFswl5jlrZf4cXIgTyl2ccesWkk3cCFuaydFUxDzODIWop/\n\t\t\t\t\t\ti7lcvme96nRYyyRXkJ1hh0kp+w7cylnYrP9oilR9XBMj7PQ/9PkHofIq+3U9bM5S\n\t\t\t\t\t\tV9AuL7fbjfXXHWdszx56GKEEwvAhOy9Hfq2/oyRTPKUHNtveFH7WehyMJ0O0FMiC\n\t\t\t\t\t\t6fwieIKJwU2kPV2L8cbfOxRa7nuqXWfqUFMCkx/ptt5joISvGLJqwNlIDzz5zIcu\n\t\t\t\t\t\tQI6O4PXRJe/bHRba/8ghVSi3FUEfb5g="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PETROC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.petroc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Petroc College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.hartlepoolfe.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.hartlepoolfe.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/hartlepoolfe.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/hartlepoolfe.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hartlepoolfe.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hartlepool College of FE"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hartlepoolfe.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://harper-adams.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Thomas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cthomas@harper-adams.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Curwen"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@harper-adams.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Service Desk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://harper-adams.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-09-13T13:06:17Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.harper-adams.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.harper-adams.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "harper-adams.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEAjCCAuoCCQDNHBk2GcsHfjANBgkqhkiG9w0BAQUFADCBwjELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEzARBgNVBAgTClNocm9wc2hpcmUxEDAOBgNVBAcTB05ld3BvcnQxIDAeBgNV\n\t\t\t\t\t\tBAoTF0hhcnBlciBBZGFtcyBVbml2ZXJzaXR5MR0wGwYDVQQLExRJbmZvcm1hdGlv\n\t\t\t\t\t\tbiBTZXJ2aWNlczEfMB0GA1UEAxMWaWRwLmhhcnBlci1hZGFtcy5hYy51azEqMCgG\n\t\t\t\t\t\tCSqGSIb3DQEJARYbc29mdHdhcmVAaGFycGVyLWFkYW1zLmFjLnVrMB4XDTE0MDcy\n\t\t\t\t\t\tMzE2NTk0MVoXDTI0MDcyMDE2NTk0MVowgcIxCzAJBgNVBAYTAkdCMRMwEQYDVQQI\n\t\t\t\t\t\tEwpTaHJvcHNoaXJlMRAwDgYDVQQHEwdOZXdwb3J0MSAwHgYDVQQKExdIYXJwZXIg\n\t\t\t\t\t\tQWRhbXMgVW5pdmVyc2l0eTEdMBsGA1UECxMUSW5mb3JtYXRpb24gU2VydmljZXMx\n\t\t\t\t\t\tHzAdBgNVBAMTFmlkcC5oYXJwZXItYWRhbXMuYWMudWsxKjAoBgkqhkiG9w0BCQEW\n\t\t\t\t\t\tG3NvZnR3YXJlQGhhcnBlci1hZGFtcy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQAD\n\t\t\t\t\t\tggEPADCCAQoCggEBALEONJ55wbiivBF8gwlBSeXD7Dj/fQIEYzghkwoB72twLO8t\n\t\t\t\t\t\tWruKDBri6vZPmw+ghlF91JCyLrCci5BWqV7Bmy+OacuYFyVOoYUj9fwcRXDvDp8A\n\t\t\t\t\t\t3aUHn0Hbv11SsHdR/d24zleK0L5TMN/h0XcGJqvod/suJwzniFY8/kvoZGHV1LQA\n\t\t\t\t\t\ttPz3lhlmcnh1dtdVKt+lskVzhoylO7YOFIYoyxQEt1JclHAFfHwmhu1um3A3/6xY\n\t\t\t\t\t\tn9IrMQUI4RDZgM97dFb1HcxWI+gAVXj/CFOeLBVLomVeuTj6SeUL9IYYFPRR1cdY\n\t\t\t\t\t\t+PbsPtha5BuH3v4aNugdNN63gQRndk2/RtiDjVUCAwEAATANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAQZJQOD87UQCXBk5JnTar9EKuoBApbvwMSyAIQ05PQPoSWaEeevFcN/1y\n\t\t\t\t\t\tuxOEzWHfXoNjj1+88Y6CfSDShnpXZAXKacwaq1Aw6oCRZLhV5UZVN483s+Ca6DEF\n\t\t\t\t\t\tFhQrDXkhfUIS5nd28ftvFaJ+KCSNNQX9F7ceWvY5osqU2rz1QdXN5eeIXYC4q151\n\t\t\t\t\t\tltkIk3Qy1uShE+B9c13u2PoaUZa4PcsBbympy7adBqF/W1kf9a9UF0NGpQ8UZ5/V\n\t\t\t\t\t\tGhSMUg8KVy3+6yjCxLtd0T1O0Lz2AEfwD7I867d+Sj5jiy1R11reQZojvEW5PVmV\n\t\t\t\t\t\tFwo9FhtsbeJO4cy9AuY7t9MOXGA4/g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Harper Adams University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.harper-adams.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Harper Adams University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.mbro.ac.uk/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.mbro.ac.uk/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/mbro.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/mbro.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mbro.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Middlesbrough College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mbro.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.crous-strasbourg.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "serviceinfo@crous.u-strasbg.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.crous-strasbourg.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-04-28T11:03:43Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.crous-strasbourg.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.crous-strasbourg.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.crous-strasbourg.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "crous-strasbourg.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.crous.u-strasbg.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administrative staff CROUS"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "personnel administratif du CROUS"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Strasbourg"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Strasbourg"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEezCCA2OgAwIBAgIQeZpbhzUV4+gL9K3eNTs3hDANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDMyNDAwMDAwMFoXDTE3MDMyMzIzNTk1OVowRTEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMSAwHgYDVQQDExdpZHAuY3JvdXMt\nc3RyYXNib3VyZy5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL6w\nf8Zbcbh3/fHcTMnr9qtmvV/DDfhwhpMNlZ3WIKp4LDeX3rq/qsS6xVPrfOMOj7+p\nFHvyGJKzY9BKCVVwioRYkx5UG7hZaxJ4vEAfremNqFB/5/BL3iNs//Xgg3J/TdXQ\nRQIrv3Wimj/Fa/2jalr6jPJC2PlBCfxwS9a3vtuqo2qs0v5B3/gDBQGzZYQlHeGP\naCrJ+luS/dBZDzsMfDE4gqm1hvGT1tabfuUZGmBxXNDpBgoqQRkqbFo7wHzwaTgD\nXBzLUrXz3s2CaAslDF+U/anQ+bMT126KRo+FxrlTvMoRADYYaf9V2GbRzzRQqpG0\nBVqR6KfiAyauyGSysGECAwEAAaOCAXQwggFwMB8GA1UdIwQYMBaAFAy9k2gM896r\no0lrKzdXR+qQ47ntMB0GA1UdDgQWBBSAAdpSjTa8MV+nybPYNenLhdM5bDAOBgNV\nHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYI\nKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYD\nVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFT\nU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0\nLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0\ncDovL29jc3AudGNzLnRlcmVuYS5vcmcwIgYDVR0RBBswGYIXaWRwLmNyb3VzLXN0\ncmFzYm91cmcuZnIwDQYJKoZIhvcNAQEFBQADggEBAHkNtIeJ+9SmBfRSCUGVgfLK\nLk9TXjYP3kBgfvu/brnuC9XcaNnpWK6bLU6+ok+iVbexVKE0H5+41wfNV2WfTAiI\nFRhT0gAh4Ian/8DVfJTci9AyowV0vNo6jiolia3jrj7pT2JV0zi68D7ia7qCq+8W\n1BcH7QcZhbEla3A4vYWXDL2ZkOGVtHwu8+bISH5kkwbAR1kSj1W6j68WOMHzzk2q\n9Trm+VsJgWqE1qZ2MQ+IDhK8126oFKyh4s4HUWs789FtwQCpaDlGJeD0pyNDvabl\n3Is6+m8rCoctcDmdACGX08QdzxMKStXnVoM31v5H3CDiAroDNYunnrntdief2+I="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS Strasbourg"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.crous.u-strasbg.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS Strasbourg"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.mediafora.net/simplesaml/module.php/saml/sp/metadata.php/media-network-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:netdrift@deic.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Administrator"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.mediafora.net/simplesaml/module.php/saml/sp/metadata.php/media-network-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.mediafora.net/simplesaml/module.php/saml/sp/saml2-logout.php/media-network-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "MediaFora aims to provide a platform for exchange of knowledge on media services at higher education"
                  },
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "MediaFora har til hensigt at skabe en platform for udveksling af viden om medietjenester ved de videreg\u00e5ende uddannels"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.mediafora.net/mediafora-logo.png",
                    "height": "120",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "120"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.mediafora.net/simplesaml/privacy-statement/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "MediaFora"
                  },
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "MediaFora"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.mediafora.net/simplesaml/module.php/saml/sp/saml2-acs.php/media-network-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.mediafora.net/simplesaml/module.php/saml/sp/saml1-acs.php/media-network-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.mediafora.net/simplesaml/module.php/saml/sp/saml2-acs.php/media-network-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.mediafora.net/simplesaml/module.php/saml/sp/saml1-acs.php/media-network-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Media network forum"
                },
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Media netv&aelig;rks forum"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "MediaFora aims to provide a platform for exchange of knowledge on media services at higher education"
                },
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "MediaFora har til hensigt at skabe en platform for udveksling af viden om medietjenester ved de videreg\u00e5ende uddannels"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://kurser.math.su.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://kurser.math.su.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://kurser.math.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://kurser.math.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://kurser.math.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://kurser.math.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "H\u00e4r finner du information om aktuella kurser i matematik och matematisk statistik vid Matematiska institutionen, Stockholms universitet."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Here you can find information and material for courses in mathematics and mathematical statistics at Stockholm University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kurssidor i matematik och matematisk statistik vid Stockholms universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Course pages in mathematics and mathematical statistics at Stockholm University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "kurser.math.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEcDCCA1igAwIBAgIQE1y2ZmHRWdeouH6Sf5z+WjANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEwMDExOTAwMDAwMFoXDTEzMDExODIzNTk1OVowSjELMAkGA1UE\nBhMCU0UxHzAdBgNVBAoTFlN0b2NraG9sbXMgdW5pdmVyc2l0ZXQxGjAYBgNVBAMT\nEWt1cnNlci5tYXRoLnN1LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEA6BmSQGmI4Efp95B1PMcAPi0/KsW6CZHRku76vh8IS+DBD3zV/A5EFWwlGIBt\nTohN+f6dp5ed4/9C6zlfdSyUblqb607LLeCTsmA4YPFWVon63VdE5GQL0x6Ii55I\nmD+z5d9fhNcL/NAffDAVDLB5HH7YEeX1CBa56NWQO6FHb4f2xX1eURt9+TRxCijQ\nLxhUt/RyMSCujqXE8a2j6JO5UksK7549uHd2zFXwpNMmMr8XnsEwcSj7jCT2MXyZ\njQoGXTTCOORX2tBsWdN/q0XunCxWybZntLih2G3Q5WF0+6NVDuJtVPWsooqZlnre\njYsPPvMiryeEVv1l6uGq6G+/FwIDAQABo4IBZDCCAWAwHwYDVR0jBBgwFoAUDL2T\naAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFAZIY/QOfeb6IU8E3CmoV4n7u57a\nMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUF\nBwMBBggrBgEFBQcDAjAYBgNVHSAEETAPMA0GCysGAQQBsjEBAgIdMDoGA1UdHwQz\nMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0Eu\nY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3Mu\ndGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9v\nY3NwLnRjcy50ZXJlbmEub3JnMBwGA1UdEQQVMBOCEWt1cnNlci5tYXRoLnN1LnNl\nMA0GCSqGSIb3DQEBBQUAA4IBAQCfqwDPk9vrMyV/Lv9bzX5nCQKWAuAYlo6qX9lI\nW2IM1IES3LYHzBOt1Rbde4r56HYVy/F8z1DiG/SDTT/WZciArryOozZSTmjfkD1J\nBoRtWsNKnGckWCigaxDS/ai1aGl+X8kZTxUAMQtHIJtkeLZaz1aYv5BMCK0aDPCz\n+jK9xMSMbBhWrVhs6HnkFnGhr71s7ZFbMxRv6psLSPl055grTLQK4eLQ63pWNeTM\norcBunWAqfoXXOHt4HTclLpL01R8y9T5LvZBWpEN75u3fkRHWS/kQIXHprWp07xv\n2Zkq+NG9O7ixLXCdQrd/dZlG8/RITegnw2rhMIpEf25eTkvl"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=kurser.math.su.se,O=Stockholms universitet,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "kurser.math.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEcDCCA1igAwIBAgIQE1y2ZmHRWdeouH6Sf5z+WjANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEwMDExOTAwMDAwMFoXDTEzMDExODIzNTk1OVowSjELMAkGA1UE\nBhMCU0UxHzAdBgNVBAoTFlN0b2NraG9sbXMgdW5pdmVyc2l0ZXQxGjAYBgNVBAMT\nEWt1cnNlci5tYXRoLnN1LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEA6BmSQGmI4Efp95B1PMcAPi0/KsW6CZHRku76vh8IS+DBD3zV/A5EFWwlGIBt\nTohN+f6dp5ed4/9C6zlfdSyUblqb607LLeCTsmA4YPFWVon63VdE5GQL0x6Ii55I\nmD+z5d9fhNcL/NAffDAVDLB5HH7YEeX1CBa56NWQO6FHb4f2xX1eURt9+TRxCijQ\nLxhUt/RyMSCujqXE8a2j6JO5UksK7549uHd2zFXwpNMmMr8XnsEwcSj7jCT2MXyZ\njQoGXTTCOORX2tBsWdN/q0XunCxWybZntLih2G3Q5WF0+6NVDuJtVPWsooqZlnre\njYsPPvMiryeEVv1l6uGq6G+/FwIDAQABo4IBZDCCAWAwHwYDVR0jBBgwFoAUDL2T\naAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFAZIY/QOfeb6IU8E3CmoV4n7u57a\nMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUF\nBwMBBggrBgEFBQcDAjAYBgNVHSAEETAPMA0GCysGAQQBsjEBAgIdMDoGA1UdHwQz\nMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0Eu\nY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3Mu\ndGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9v\nY3NwLnRjcy50ZXJlbmEub3JnMBwGA1UdEQQVMBOCEWt1cnNlci5tYXRoLnN1LnNl\nMA0GCSqGSIb3DQEBBQUAA4IBAQCfqwDPk9vrMyV/Lv9bzX5nCQKWAuAYlo6qX9lI\nW2IM1IES3LYHzBOt1Rbde4r56HYVy/F8z1DiG/SDTT/WZciArryOozZSTmjfkD1J\nBoRtWsNKnGckWCigaxDS/ai1aGl+X8kZTxUAMQtHIJtkeLZaz1aYv5BMCK0aDPCz\n+jK9xMSMbBhWrVhs6HnkFnGhr71s7ZFbMxRv6psLSPl055grTLQK4eLQ63pWNeTM\norcBunWAqfoXXOHt4HTclLpL01R8y9T5LvZBWpEN75u3fkRHWS/kQIXHprWp07xv\n2Zkq+NG9O7ixLXCdQrd/dZlG8/RITegnw2rhMIpEf25eTkvl"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=kurser.math.su.se,O=Stockholms universitet,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://kurser.math.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://kurser.math.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://kurser.math.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://kurser.math.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://kurser.math.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://kurser.math.su.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://kurser.math.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://kurser.math.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://kurser.math.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://kurser.math.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib-sp.unity.ac/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Potter"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:unity-sso@researchresearch.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Potter"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:unity-sso@researchresearch.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib-sp.unity.ac/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-10-09T12:53:11Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Unity"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://researchresearch.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Research Research Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-sp.unity.ac/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-sp.unity.ac/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-sp.unity.ac/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib-sp.unity.ac/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-sp.unity.ac/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib-sp.unity.ac/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unity.ac"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "*Unity"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIJALWq54jw0HS7MA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHNoaWItc3AudW5pdHkuYWMwHhcNMTQxMDAzMTA0ODI1WhcNMjQwOTMwMTA0\n\t\t\t\t\t\tODI1WjAbMRkwFwYDVQQDExBzaGliLXNwLnVuaXR5LmFjMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAwS2lW2kzzr/Kwa45pah/4TVU66zHOku2Fots9M5f\n\t\t\t\t\t\tbdzB0Q0be5rh5k2Ne3LCucEJlp2n0rIAeuuHhDIVE+opQTy0I28c5R83Bt1TY8W7\n\t\t\t\t\t\tQSa8hg7YK/Im0dSLx4ENSEHxMuPBuynl01qdNfGGg8qjBRjZ62SvQIzA8FBgJu2g\n\t\t\t\t\t\tDA27J3EMQrXC9ELL9ifE+IdUGflr3BuDrefipnxv67mkOZ6LCxY0+ME7w4ooZcSB\n\t\t\t\t\t\tBrG+r7RWkv1Qzcb5xzd19MqVaDuZLv/tynE6VQ88iyz79zvYsNL9vIhwpO/OgND3\n\t\t\t\t\t\tDOMr47v6Q5GmG3KdVfMJwvINBNQmfqxWk6+1sQRY67MFzwIDAQABo2MwYTBABgNV\n\t\t\t\t\t\tHREEOTA3ghBzaGliLXNwLnVuaXR5LmFjhiNodHRwczovL3NoaWItc3AudW5pdHku\n\t\t\t\t\t\tYWMvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUVcMrT2HHLPUMrdzGkObutsQRt4cwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBABxD0edMnpEUBFe0UmeSKmhBGOPUKbDJUC3xAnAjEnQR\n\t\t\t\t\t\tl8DHsxWji4F5KMPHN/CCHVI83XvcnvB2gsp8np3xQoxVZ5ckHYkBO2p4967BgqWc\n\t\t\t\t\t\tBwj8AlcNkK+CcsY6WbtzAUlIl/FTguFZ08mAV5YK88hh3qfZKHPYj6AibBiB6mqf\n\t\t\t\t\t\tQ9x6aKcEZ9texjswuDsvMxxGZhORHo5SErlJRuO+g3KuQdE56tPdwcQLQ8uKUXvW\n\t\t\t\t\t\tPUPWRVqOa6ad3PTyhntihn88t5k8KA5HvwE3iX9JX/a+OLLKLbHbieX4F5FT02gK\n\t\t\t\t\t\tEfBbdfskIzAWEJ158qAfJe4Sx4Jy0PCJHMOqVW6uySw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-sp.unity.ac/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib-sp.unity.ac/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib-sp.unity.ac/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shib-sp.unity.ac/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shib-sp.unity.ac/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shib-sp.unity.ac/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "https://shib-sp.unity.ac/shibboleth"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "false",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "false",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonTargetedID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "false",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://access.wigan-leigh.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Unsworth"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:a.unsworth@wigan-leigh.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andy"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Parr"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:i.parr@wigan-leigh.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://access.wigan-leigh.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-05-17T18:09:30Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://access.wigan-leigh.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://access.wigan-leigh.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wigan-leigh.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDrzCCApegAwIBAgIJAP1hnrR7xnq9MA0GCSqGSIb3DQEBBQUAMEMxHjAcBgNV\n\t\t\t\t\t\tBAoMFVdpZ2FuICYgTGVpZ2ggQ29sbGVnZTEhMB8GA1UEAxMYYWNjZXNzLndpZ2Fu\n\t\t\t\t\t\tLWxlaWdoLmFjLnVrMB4XDTExMTEyOTE0MTYzOVoXDTIxMTEyNjE0MTYzOVowQzEe\n\t\t\t\t\t\tMBwGA1UECgwVV2lnYW4gJiBMZWlnaCBDb2xsZWdlMSEwHwYDVQQDExhhY2Nlc3Mu\n\t\t\t\t\t\td2lnYW4tbGVpZ2guYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQC6QW6py7ewUg2xeF0DDyZEoQbF5FGK4aaTpNUIgruhXkT1kkBQx4/3CWNYN7Sy\n\t\t\t\t\t\tJ5zZzL85S42jX+R6ZpLFKLXZWRn0vMZkHfsAoBbE9DBu7EAS7GPHy+QzQ9nLOnT3\n\t\t\t\t\t\tTn2W4LB6v4ysmY4XQRqnk1ftLUJgsjiacJ36+cSVpJmsgRWYCVpQ0E/W5WRUnO0Q\n\t\t\t\t\t\tQ9Hl5kj3uHo2c+oD3syu0YiLmoeDU8dOzcfCwrgB+y5EQ3tYxskRZmxMNEB76g5/\n\t\t\t\t\t\tA5nz5HY0eMyIgc4HPsFNTNCZKzPx2RvVnxtvJFf1u6tziU5d9xIPptwLHA6Ljt/4\n\t\t\t\t\t\twe1xqSZWQUwYvFhg6KDcYn+dAgMBAAGjgaUwgaIwHQYDVR0OBBYEFJliefRZwjmv\n\t\t\t\t\t\tUd7SvS1grr1Hw0/yMHMGA1UdIwRsMGqAFJliefRZwjmvUd7SvS1grr1Hw0/yoUek\n\t\t\t\t\t\tRTBDMR4wHAYDVQQKDBVXaWdhbiAmIExlaWdoIENvbGxlZ2UxITAfBgNVBAMTGGFj\n\t\t\t\t\t\tY2Vzcy53aWdhbi1sZWlnaC5hYy51a4IJAP1hnrR7xnq9MAwGA1UdEwQFMAMBAf8w\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBABegtgKN+GXn4YH45KPg0LV3+JWXOvstp/DjvP9E\n\t\t\t\t\t\tsWyLu8Oky2stpykPFIi75LKilSR9JaVAGVuOUATp7i8YpxOlEI07yyR7TTCvswLc\n\t\t\t\t\t\tO5/XnV+ASpnnedAjSKwGb0DYRi6uiPD+NvCUyugp8kY9JT4uqairyOqrZcQBOhGu\n\t\t\t\t\t\t3A2StwhfBUAmLiCs9/QLLe8vDiMz18rBA6k50NQHAo0uudsq4NNC4jmhwFjrPQuK\n\t\t\t\t\t\txuuv1aUDSSlQzhhLu0jCC+7TQRXm6Kj3TCdjIaSFyO0XCC/EPjkcBPpIvsq9hWLG\n\t\t\t\t\t\tZyqGxjHf9L6xy9iMR9HUdmPg+ajohCQYHHGiubPT1YvWKqk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDrzCCApegAwIBAgIJAP1hnrR7xnq9MA0GCSqGSIb3DQEBBQUAMEMxHjAcBgNV\n\t\t\t\t\t\tBAoMFVdpZ2FuICYgTGVpZ2ggQ29sbGVnZTEhMB8GA1UEAxMYYWNjZXNzLndpZ2Fu\n\t\t\t\t\t\tLWxlaWdoLmFjLnVrMB4XDTExMTEyOTE0MTYzOVoXDTIxMTEyNjE0MTYzOVowQzEe\n\t\t\t\t\t\tMBwGA1UECgwVV2lnYW4gJiBMZWlnaCBDb2xsZWdlMSEwHwYDVQQDExhhY2Nlc3Mu\n\t\t\t\t\t\td2lnYW4tbGVpZ2guYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQC6QW6py7ewUg2xeF0DDyZEoQbF5FGK4aaTpNUIgruhXkT1kkBQx4/3CWNYN7Sy\n\t\t\t\t\t\tJ5zZzL85S42jX+R6ZpLFKLXZWRn0vMZkHfsAoBbE9DBu7EAS7GPHy+QzQ9nLOnT3\n\t\t\t\t\t\tTn2W4LB6v4ysmY4XQRqnk1ftLUJgsjiacJ36+cSVpJmsgRWYCVpQ0E/W5WRUnO0Q\n\t\t\t\t\t\tQ9Hl5kj3uHo2c+oD3syu0YiLmoeDU8dOzcfCwrgB+y5EQ3tYxskRZmxMNEB76g5/\n\t\t\t\t\t\tA5nz5HY0eMyIgc4HPsFNTNCZKzPx2RvVnxtvJFf1u6tziU5d9xIPptwLHA6Ljt/4\n\t\t\t\t\t\twe1xqSZWQUwYvFhg6KDcYn+dAgMBAAGjgaUwgaIwHQYDVR0OBBYEFJliefRZwjmv\n\t\t\t\t\t\tUd7SvS1grr1Hw0/yMHMGA1UdIwRsMGqAFJliefRZwjmvUd7SvS1grr1Hw0/yoUek\n\t\t\t\t\t\tRTBDMR4wHAYDVQQKDBVXaWdhbiAmIExlaWdoIENvbGxlZ2UxITAfBgNVBAMTGGFj\n\t\t\t\t\t\tY2Vzcy53aWdhbi1sZWlnaC5hYy51a4IJAP1hnrR7xnq9MAwGA1UdEwQFMAMBAf8w\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBABegtgKN+GXn4YH45KPg0LV3+JWXOvstp/DjvP9E\n\t\t\t\t\t\tsWyLu8Oky2stpykPFIi75LKilSR9JaVAGVuOUATp7i8YpxOlEI07yyR7TTCvswLc\n\t\t\t\t\t\tO5/XnV+ASpnnedAjSKwGb0DYRi6uiPD+NvCUyugp8kY9JT4uqairyOqrZcQBOhGu\n\t\t\t\t\t\t3A2StwhfBUAmLiCs9/QLLe8vDiMz18rBA6k50NQHAo0uudsq4NNC4jmhwFjrPQuK\n\t\t\t\t\t\txuuv1aUDSSlQzhhLu0jCC+7TQRXm6Kj3TCdjIaSFyO0XCC/EPjkcBPpIvsq9hWLG\n\t\t\t\t\t\tZyqGxjHf9L6xy9iMR9HUdmPg+ajohCQYHHGiubPT1YvWKqk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Wigan & Leigh College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wigan-leigh.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Wigan & Leigh College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.itslearning.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Akhtar"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Waseem.Akhtar@itslearning.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Waseemr"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Akhtar"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Waseem.Akhtar@itslearning.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Waseemr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.itslearning.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "it's learning UK Limited"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.itslearning.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "it's learning UK Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.itslearning.com/elogin/logout.aspx",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIJAOCa2W5sQVpdMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\n\t\t\t\t\t\tBAMTFmVsb2dpbi5pdHNsZWFybmluZy5jb20wHhcNMTEwMTI1MDk0MTIyWhcNMjEw\n\t\t\t\t\t\tMTIyMDk0MTIyWjAhMR8wHQYDVQQDExZlbG9naW4uaXRzbGVhcm5pbmcuY29tMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA3/pjEfFtjLzqjahh8G57a4bE\n\t\t\t\t\t\txgDVLPMsVrYkxMwmjR0fvMjGD/WIldj/XKBga7EzMfSSqAtGcluHwcQotZn3VKzI\n\t\t\t\t\t\t+pp5SDGnjaZLb5Dlx4Pqn8QXtv9fFdTU8bkk4nWJLAabrBV1PDNlc9TvLYo4BEKh\n\t\t\t\t\t\tuK6WvNIZqshS4NX241PcyIW+/tbs3gY4ZpqCIgF21cX+UHX+JWxHrgKzWRXlpYRX\n\t\t\t\t\t\t8/La7yxJxNsgeQfsNO9et8nAGcMFpATGGK9N4IcSzdlZM0vPLTcP5NrYhVrc4p/v\n\t\t\t\t\t\tSh2wVgCAX0RM4xXTKZSPiv2bbXqz1m+61cdY+097umpFqKP/4LcgRrOWyn8DoQID\n\t\t\t\t\t\tAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVy\n\t\t\t\t\t\tYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUK1LiEqSXXlTIZiRAUXIdhrxt50Yw\n\t\t\t\t\t\tHwYDVR0jBBgwFoAUK1LiEqSXXlTIZiRAUXIdhrxt50YwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAF2W34ZCfjR4aZcTcNwLwAJBJZWNoJTpkzl6DiTLSTpmXjcDSVQQCUontqjp\n\t\t\t\t\t\tWDatCmrM/5JamvZaNfyJ1tHrkNwvKEsvTzalLFs00E9GcOQq8I/Xfj6uBGAYICB5\n\t\t\t\t\t\teSKnhIHMJDlSc6ilYxDlB8KJM4UFXQ+SIsJLcX9AbsdHI0X/s68c42/teSQgN2Yc\n\t\t\t\t\t\twtiCUhjKgaY1iI6B/CaS0akF+hK4wi3+vV9Iis3zjOPZgmf6K+n/5HGKmplQF2H4\n\t\t\t\t\t\tffAJBB8DdkCd3njov1flLlnfQHDh0o0/yPSJkkdknqxhFs7yvEV+c92gwZCFjwka\n\t\t\t\t\t\tJ4ZzgrTMRBGb/0XGn/eHvuvUdYY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://www.itslearning.com/elogin/default.aspx",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cafe.unifap.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Samir Patrice"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "samir@unifap.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.unifap.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvDCCAqQCAQAwDQYJKoZIhvcNAQEFBQAwgaMxLzAtBgNVBAoTJlVOSUZBUCAt\nIFVuaXZlcnNpZGFkZSBGZWRlcmFsIGRvIEFtYXBhMQwwCgYDVQQLEwNOVEkxHjAc\nBgkqhkiG9w0BCQEWD3NhbWlyQHVuaWZhcC5icjEPMA0GA1UEBxMGTWFjYXBhMQsw\nCQYDVQQIEwJBUDELMAkGA1UEBhMCQlIxFzAVBgNVBAMTDmNhZmUudW5pZmFwLmJy\nMB4XDTE1MDUwNDE3MTgwN1oXDTIwMDUwMjE3MTgwN1owgaMxLzAtBgNVBAoTJlVO\nSUZBUCAtIFVuaXZlcnNpZGFkZSBGZWRlcmFsIGRvIEFtYXBhMQwwCgYDVQQLEwNO\nVEkxHjAcBgkqhkiG9w0BCQEWD3NhbWlyQHVuaWZhcC5icjEPMA0GA1UEBxMGTWFj\nYXBhMQswCQYDVQQIEwJBUDELMAkGA1UEBhMCQlIxFzAVBgNVBAMTDmNhZmUudW5p\nZmFwLmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAucOkVrIgxjos\nZI3yuv38anNRJ+bMVxVG3UoXo2ow4gvgcU851otZxY6wo1pRAFskGI48PhMNz/WK\nFTpfndRu1fswIsmiLNHu+Ts1CqWHHB+6gIR2LtVqrZJGNOBfmgtX45s7GNOrJInJ\nl4X/3KPjDT8zMTWKBP1D/k34T10NsHNrfaYbc1yNLI8sfb/I2er7GBE6dP2mUYoT\nTJZ6Sxy7TG+XgdWHqELRBmbMd8cOxCc4+zb4ehYr40Mr5DXd0/JOdFDZ1SnJdR2X\nc2OQWSeQa0mQSE2Ty17iAd+R0tn8QxJhC3esCbgK/vcLHwhI5dJy5oFTCx9z1G+y\n13in/sAXUQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCe8znxlId/tpZn7q3EFr1t\n3s6gzOSZUlptq6MJZ6T5ibUYKv4whoQyoH/a1yPghHv4/ib5VoptSUMi50OoeaWp\nMAXkNP/L+/nLqSSMQCLPAioBmChEo+1+YuWtiHnBI668wUCozM8/k05Av0hfDgJn\nD8EK/3Lh1QJZWEXPei1+1RbK7GNo/Ip9zYMMS2fpR6rk48GuzIMEYjsEkhuUHfNE\nf2DQku+sFfLt5dI95sKDGx3uDKc+E0jHonDK0R3lqwXXp+OcSZgbjhIlC4eez0zi\nR4cuF01gV99fli7Pjp5flwVN7ArlDg5a52acuOmSVVqF+8BZzNBDkMtz/8QvgGhx"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unifap.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.unifap.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.unifap.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.unifap.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.unifap.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.unifap.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.unifap.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.unifap.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.unifap.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unifap.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unifap.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unifap.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNIFAP -  Universidade Federal do Amapa"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNIFAP -  Universidade Federal do Amapa"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNIFAP -  Universidade Federal do Amapa"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNIFAP -  Universidade Federal do Amapa"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvDCCAqQCAQAwDQYJKoZIhvcNAQEFBQAwgaMxLzAtBgNVBAoTJlVOSUZBUCAt\nIFVuaXZlcnNpZGFkZSBGZWRlcmFsIGRvIEFtYXBhMQwwCgYDVQQLEwNOVEkxHjAc\nBgkqhkiG9w0BCQEWD3NhbWlyQHVuaWZhcC5icjEPMA0GA1UEBxMGTWFjYXBhMQsw\nCQYDVQQIEwJBUDELMAkGA1UEBhMCQlIxFzAVBgNVBAMTDmNhZmUudW5pZmFwLmJy\nMB4XDTE1MDUwNDE3MTgwN1oXDTIwMDUwMjE3MTgwN1owgaMxLzAtBgNVBAoTJlVO\nSUZBUCAtIFVuaXZlcnNpZGFkZSBGZWRlcmFsIGRvIEFtYXBhMQwwCgYDVQQLEwNO\nVEkxHjAcBgkqhkiG9w0BCQEWD3NhbWlyQHVuaWZhcC5icjEPMA0GA1UEBxMGTWFj\nYXBhMQswCQYDVQQIEwJBUDELMAkGA1UEBhMCQlIxFzAVBgNVBAMTDmNhZmUudW5p\nZmFwLmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAucOkVrIgxjos\nZI3yuv38anNRJ+bMVxVG3UoXo2ow4gvgcU851otZxY6wo1pRAFskGI48PhMNz/WK\nFTpfndRu1fswIsmiLNHu+Ts1CqWHHB+6gIR2LtVqrZJGNOBfmgtX45s7GNOrJInJ\nl4X/3KPjDT8zMTWKBP1D/k34T10NsHNrfaYbc1yNLI8sfb/I2er7GBE6dP2mUYoT\nTJZ6Sxy7TG+XgdWHqELRBmbMd8cOxCc4+zb4ehYr40Mr5DXd0/JOdFDZ1SnJdR2X\nc2OQWSeQa0mQSE2Ty17iAd+R0tn8QxJhC3esCbgK/vcLHwhI5dJy5oFTCx9z1G+y\n13in/sAXUQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCe8znxlId/tpZn7q3EFr1t\n3s6gzOSZUlptq6MJZ6T5ibUYKv4whoQyoH/a1yPghHv4/ib5VoptSUMi50OoeaWp\nMAXkNP/L+/nLqSSMQCLPAioBmChEo+1+YuWtiHnBI668wUCozM8/k05Av0hfDgJn\nD8EK/3Lh1QJZWEXPei1+1RbK7GNo/Ip9zYMMS2fpR6rk48GuzIMEYjsEkhuUHfNE\nf2DQku+sFfLt5dI95sKDGx3uDKc+E0jHonDK0R3lqwXXp+OcSZgbjhIlC4eez0zi\nR4cuF01gV99fli7Pjp5flwVN7ArlDg5a52acuOmSVVqF+8BZzNBDkMtz/8QvgGhx"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNIFAP -  Universidade Federal do Amapa"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNIFAP -  Universidade Federal do Amapa"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unifap.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unifap.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNIFAP - Universidade Federal do Amapa"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNIFAP - Universidade Federal do Amapa"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.rio.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kmeyer@rio.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kingsley Meyer"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@rio.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rio Grande Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@rio.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rio Grande Technical Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@rio.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rio Grande Technical Support"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://shib.rio.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.rio.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.rio.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.rio.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.rio.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.rio.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rio.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.rio.edu/about/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Rio Grande"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for the University of Rio Grande and Rio Grande Community College"
                  }
                ],
                "logo": [
                  {
                    "text": "https://shib.rio.edu/idp/images/rio-icon.jpg",
                    "lang": "en",
                    "height": "185",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "149"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.rio.edu/camptech/Policies.cfm"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUaUJi0vL1gnTjBfKAu4Q0FSERZxkwDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAwwMc2hpYi5yaW8uZWR1MB4XDTE1MDQyMTE0NDgwNloXDTM1\nMDQyMTE0NDgwNlowFzEVMBMGA1UEAwwMc2hpYi5yaW8uZWR1MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmteOxWDQLIqLj/a7Q/Lc43hZfYeQaPPcLUh+\nl4LR2J6sYpDVtS+Fg+fYthSMPSPUr5QbSkCD1SHzFFVUnDLSR9syfYREceonFRpD\njBIfeNiJguPYS5doOyc77sRRfayxVZiDLls23e+c0iV9euQ/5DTtbvx4pW2i7+vZ\nS+adbaoRpJQHQ4+Mtxg8ypXQCP7nf0OW6P50Sb4sPYGAPzs1GHDctwNLpLREZzF3\n8WLbNlCgDhDurcmd19h4dWBB53wBqTEjNLvKx5gAG8EnXJYA+tBGN/ttfctvHRgO\nzMohfBQpjDgIeSPC9rtlT5HsFo4ETWu7kETLJKSn0+2Y8csnOwIDAQABo18wXTAd\nBgNVHQ4EFgQUKSr2j30PDNjuGnPlGcd486Z6ewIwPAYDVR0RBDUwM4IMc2hpYi5y\naW8uZWR1hiNodHRwczovL3NoaWIucmlvLmVkdS9pZHAvc2hpYmJvbGV0aDANBgkq\nhkiG9w0BAQUFAAOCAQEASe+1I4d5Q+FF+aDq3x5ux2EiQ/pDTyK2UnYaMgjr4iRe\nCobMVK43vfWVrokhBFrr5csu0Ei9aypy6LU8lTATGIRWcZf0FiB2hB8K2ADNVh71\nGx3bVGkcUJRhX2Ti19rzkq1+LsIYw53/htCZCzvDAvJix9p+L9EGzXGaMLMPMGjq\nOKOmJecKqgmREgX4UNBLvnCRSC5IQfcQtC3gwlwVHy0JsMaoOOW/4jUcpaZ8wX4d\ntL65yo0BeCIJZLm4krEnwTp4IRJDitiRgvxX/TtD3ukGkSWstdktq9kAT9dGP753\nuXkfozJhPiwV90P6DNBkmS6MeSVPWoggq75BbFMFCg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Rio Grande"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rio.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Rio Grande"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://akino.hh.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://akino.hh.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://akino.hh.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://akino.hh.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://akino.hh.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://akino.hh.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://akino.hh.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "akino.hh.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6DCCAdCgAwIBAgIJANFCVxC7y6BWMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC2FraW5vLmhoLnNlMB4XDTA5MTAyNzA4MjU1N1oXDTE5MTAyNTA4MjU1N1ow\nFjEUMBIGA1UEAxMLYWtpbm8uaGguc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQD2Y7TZAeEnPMmlwz3hoXDa/wFIRy6Bodm63LdzbL1cy8PQwgtZM5n7\n8CqSy0tE5dpGeGK3oqEJkalbQa9mY/+HGf4ENC7CzlRnJ/xYpLSBiAHCz0ch9+Tc\nZqbbB7IDEhWEiwj25dZ3OG6wqveHtZGQueju34RwF9slrjAPHkXrHC0zSHLVB+hr\nupH8FHTCEJhTY80mZy1DVBEVU6s0DFDjhTX7zYeytM51tKh5iSqJ/dI4jp7GAWx5\n0pDslYxX29aGUbBaKUL83L4RpLW4hecbPiWYeG4tw5Z3pEhifCo0YEffwFJjTGsh\nTP3XAeiOVEInvmH1jK+LgUpzz7rnyy7pAgMBAAGjOTA3MBYGA1UdEQQPMA2CC2Fr\naW5vLmhoLnNlMB0GA1UdDgQWBBQavhHSFdU5J1TVygW7QNzSuG4QTDANBgkqhkiG\n9w0BAQUFAAOCAQEAlxMSNZxBeI4qFUaUBdH0S8FSheF5ynIutcj5bXfmst4rBxRa\nCZIB+NLzwGIp2rwNM53uB3P1osDr+BilLeFUvgSiGwMYFdAHkr9Bg2WqJj9/phW3\nscmeVlwizwXyQscs8fYr9UQGGjrt+tYIJ8NbZCp7bLyjZdwjC2MGe2bDQzA/S2ye\nJfTpxJCZp5ocIfNyPCGmpf6pLBYjQbVfqO4bNJOvaArHylA8wYb5nYO1HFoqKOB/\n7ayOBgrV5oO97iUTRmBU9Ka8GIqJqdC4LIUwj6HcmCJ94rQbldH5/nbitL9ND2oY\ns2ozMUSsHZxcwpFZ7NQ4lLsgm9VihBDXZ4mTXQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=akino.hh.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "akino.hh.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6DCCAdCgAwIBAgIJANFCVxC7y6BWMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC2FraW5vLmhoLnNlMB4XDTA5MTAyNzA4MjU1N1oXDTE5MTAyNTA4MjU1N1ow\nFjEUMBIGA1UEAxMLYWtpbm8uaGguc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQD2Y7TZAeEnPMmlwz3hoXDa/wFIRy6Bodm63LdzbL1cy8PQwgtZM5n7\n8CqSy0tE5dpGeGK3oqEJkalbQa9mY/+HGf4ENC7CzlRnJ/xYpLSBiAHCz0ch9+Tc\nZqbbB7IDEhWEiwj25dZ3OG6wqveHtZGQueju34RwF9slrjAPHkXrHC0zSHLVB+hr\nupH8FHTCEJhTY80mZy1DVBEVU6s0DFDjhTX7zYeytM51tKh5iSqJ/dI4jp7GAWx5\n0pDslYxX29aGUbBaKUL83L4RpLW4hecbPiWYeG4tw5Z3pEhifCo0YEffwFJjTGsh\nTP3XAeiOVEInvmH1jK+LgUpzz7rnyy7pAgMBAAGjOTA3MBYGA1UdEQQPMA2CC2Fr\naW5vLmhoLnNlMB0GA1UdDgQWBBQavhHSFdU5J1TVygW7QNzSuG4QTDANBgkqhkiG\n9w0BAQUFAAOCAQEAlxMSNZxBeI4qFUaUBdH0S8FSheF5ynIutcj5bXfmst4rBxRa\nCZIB+NLzwGIp2rwNM53uB3P1osDr+BilLeFUvgSiGwMYFdAHkr9Bg2WqJj9/phW3\nscmeVlwizwXyQscs8fYr9UQGGjrt+tYIJ8NbZCp7bLyjZdwjC2MGe2bDQzA/S2ye\nJfTpxJCZp5ocIfNyPCGmpf6pLBYjQbVfqO4bNJOvaArHylA8wYb5nYO1HFoqKOB/\n7ayOBgrV5oO97iUTRmBU9Ka8GIqJqdC4LIUwj6HcmCJ94rQbldH5/nbitL9ND2oY\ns2ozMUSsHZxcwpFZ7NQ4lLsgm9VihBDXZ4mTXQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=akino.hh.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://akino.hh.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://akino.hh.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://akino.hh.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://akino.hh.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://akino.hh.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://akino.hh.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://akino.hh.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://akino.hh.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://akino.hh.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://akino.hh.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ck.olmstaging.com/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smith"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Tim.Smith@olmgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smith"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Tim.Smith@olmgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ck.olmstaging.com/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-08-14T13:15:39Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CareKnowledge Staging Environment"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.pavpub.com/about-us/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "OLM Pavilion Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The staging website for CareKnowledge"
                  }
                ],
                "logo": [
                  {
                    "text": "https://ck.olmstaging.com/App_Themes/ck/img/logo-full-colour.gif",
                    "height": "110",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "275"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CareKnowledge Staging Environment"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDdjCCAl6gAwIBAgIJALNePh/3on5UMA0GCSqGSIb3DQEBBQUAMDAxEjAQBgNV\n\t\t\tBAoTCU9MTSBHcm91cDEaMBgGA1UEAxMRY2sub2xtc3RhZ2luZy5jb20wHhcNMTUw\n\t\t\tNjAyMTI0OTIxWhcNMjUwNTMwMTI0OTIxWjAwMRIwEAYDVQQKEwlPTE0gR3JvdXAx\n\t\t\tGjAYBgNVBAMTEWNrLm9sbXN0YWdpbmcuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\tAQ8AMIIBCgKCAQEAwmLnKk7fe5gs6kVPp477T1IzSbIl+y6DPy0Ds0XWRTQh1/1I\n\t\t\txa9B1DQhvtwc2OPO96uNPl3HU8/rcAhYURVqWHlAm38SFvi2Or5FM3hhh3fdUa/p\n\t\t\tu1PbEoRf2+nDzW5BCtFRniqXzM34XQOm2mNjDOaucsTetXUQRmCxzRHNEzjgEcrG\n\t\t\tESm2lEzR6cdhnXE+/8mETLp+WSgf8+O6Dnyk9zN1CRtYz50UjjNXPMw8UkA5v+/b\n\t\t\t/DRZjvNDWUcqZVHG0+p9XdhUQ7ebs/n1QYfoTwjv8ONGdyu/3kfXYywv79QVx0+y\n\t\t\tTPCD0KWCX27G80mKNinmBrXf0pCr+XG7hSpYIQIDAQABo4GSMIGPMB0GA1UdDgQW\n\t\t\tBBSqrJuw1LWg1iY+WoKutOruPT3UtDBgBgNVHSMEWTBXgBSqrJuw1LWg1iY+WoKu\n\t\t\ttOruPT3UtKE0pDIwMDESMBAGA1UEChMJT0xNIEdyb3VwMRowGAYDVQQDExFjay5v\n\t\t\tbG1zdGFnaW5nLmNvbYIJALNePh/3on5UMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcN\n\t\t\tAQEFBQADggEBAD08S1DnwxS6Jqq/1VZIRw95rtx0JdfliMpUyFxirezrt7XcD4Jr\n\t\t\t6fdBonhZmsv71d7kVF0wTC9pRfW77N6of8VIHhiQnmRd8kwgqruKtZdaJTvMa4OY\n\t\t\tHh7SMHyrM0roCkiqAdJCc9KDyk9pR0sgvZ5OuVi2qHuGiWBASCEutsemgfYGWoMm\n\t\t\tXeFiHXI26wrBIpENvidELyX4KSqLQQGVExi5PGaj6bRkgGZDehMlHUYc3BbmEV2c\n\t\t\ttKmjS4MQl35ipYwwPIZzpDfqiD1ZfNgD5b7ucFtN8y9SWoyYziYeLLwmtjQvb9O3\n\t\t\thYtzTdNb6ow8U/5Qy7n3G2+T9I/AuYIhlGA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDdjCCAl6gAwIBAgIJALNePh/3on5UMA0GCSqGSIb3DQEBBQUAMDAxEjAQBgNV\n\t\t\tBAoTCU9MTSBHcm91cDEaMBgGA1UEAxMRY2sub2xtc3RhZ2luZy5jb20wHhcNMTUw\n\t\t\tNjAyMTI0OTIxWhcNMjUwNTMwMTI0OTIxWjAwMRIwEAYDVQQKEwlPTE0gR3JvdXAx\n\t\t\tGjAYBgNVBAMTEWNrLm9sbXN0YWdpbmcuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\tAQ8AMIIBCgKCAQEAwmLnKk7fe5gs6kVPp477T1IzSbIl+y6DPy0Ds0XWRTQh1/1I\n\t\t\txa9B1DQhvtwc2OPO96uNPl3HU8/rcAhYURVqWHlAm38SFvi2Or5FM3hhh3fdUa/p\n\t\t\tu1PbEoRf2+nDzW5BCtFRniqXzM34XQOm2mNjDOaucsTetXUQRmCxzRHNEzjgEcrG\n\t\t\tESm2lEzR6cdhnXE+/8mETLp+WSgf8+O6Dnyk9zN1CRtYz50UjjNXPMw8UkA5v+/b\n\t\t\t/DRZjvNDWUcqZVHG0+p9XdhUQ7ebs/n1QYfoTwjv8ONGdyu/3kfXYywv79QVx0+y\n\t\t\tTPCD0KWCX27G80mKNinmBrXf0pCr+XG7hSpYIQIDAQABo4GSMIGPMB0GA1UdDgQW\n\t\t\tBBSqrJuw1LWg1iY+WoKutOruPT3UtDBgBgNVHSMEWTBXgBSqrJuw1LWg1iY+WoKu\n\t\t\ttOruPT3UtKE0pDIwMDESMBAGA1UEChMJT0xNIEdyb3VwMRowGAYDVQQDExFjay5v\n\t\t\tbG1zdGFnaW5nLmNvbYIJALNePh/3on5UMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcN\n\t\t\tAQEFBQADggEBAD08S1DnwxS6Jqq/1VZIRw95rtx0JdfliMpUyFxirezrt7XcD4Jr\n\t\t\t6fdBonhZmsv71d7kVF0wTC9pRfW77N6of8VIHhiQnmRd8kwgqruKtZdaJTvMa4OY\n\t\t\tHh7SMHyrM0roCkiqAdJCc9KDyk9pR0sgvZ5OuVi2qHuGiWBASCEutsemgfYGWoMm\n\t\t\tXeFiHXI26wrBIpENvidELyX4KSqLQQGVExi5PGaj6bRkgGZDehMlHUYc3BbmEV2c\n\t\t\ttKmjS4MQl35ipYwwPIZzpDfqiD1ZfNgD5b7ucFtN8y9SWoyYziYeLLwmtjQvb9O3\n\t\t\thYtzTdNb6ow8U/5Qy7n3G2+T9I/AuYIhlGA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://ck.olmstaging.com/ukfed/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ck.olmstaging.com/ukfed/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://scatfam.shrewsbury.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Booth"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:richard.booth@shrewsbury.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Breakwell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:robinb@shrewsbury.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://scatfam.shrewsbury.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-01-30T12:52:22Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEDjCCAvYCCQDdX07L9v0VEjANBgkqhkiG9w0BAQUFADCByDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEzARBgNVBAgMClNocm9wc2hpcmUxEzARBgNVBAcMClNocmV3c2J1cnkxGzAZ\n\t\t\t\t\t\tBgNVBAoMElNocmV3c2J1cnkgQ29sbGVnZTErMCkGA1UECwwidGVjaG5pY2FsIGFu\n\t\t\t\t\t\tZCBJbmZvcm1hdGlvbiBTZXJ2aWNlczEdMBsGA1UEAwwUaWRwLnNocmV3c2J1cnku\n\t\t\t\t\t\tYWMudWsxJjAkBgkqhkiG9w0BCQEWF3JvYmluYkBzaHJld3NidXJ5LmFjLnVrMB4X\n\t\t\t\t\t\tDTE2MDExMzA5MjM1MFoXDTI2MDExMDA5MjM1MFowgcgxCzAJBgNVBAYTAkdCMRMw\n\t\t\t\t\t\tEQYDVQQIDApTaHJvcHNoaXJlMRMwEQYDVQQHDApTaHJld3NidXJ5MRswGQYDVQQK\n\t\t\t\t\t\tDBJTaHJld3NidXJ5IENvbGxlZ2UxKzApBgNVBAsMInRlY2huaWNhbCBhbmQgSW5m\n\t\t\t\t\t\tb3JtYXRpb24gU2VydmljZXMxHTAbBgNVBAMMFGlkcC5zaHJld3NidXJ5LmFjLnVr\n\t\t\t\t\t\tMSYwJAYJKoZIhvcNAQkBFhdyb2JpbmJAc2hyZXdzYnVyeS5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBALJ0i3cBulkagk4eJfEi1rDUgIKiKE0q\n\t\t\t\t\t\tthBsZkKW7OT+HTcCOBEwqylbKsdBP6GUWN7CktVnRCN5Bjvq+ykgHE72bhsG+Hdv\n\t\t\t\t\t\tGa4HqEjZnttqmgfHIt1uJL/BMBzwCkMqJmckQxcwAIDvGpKpkpWXFtHh1h011iVZ\n\t\t\t\t\t\taO1NiveCTvjyEPFwOWxcfuMgI2CKKgXkuOyxGPUL3r/otBdbeflj6EQPJwYFCMI/\n\t\t\t\t\t\tB7lmxvVyEzcC5ydc3MIsGNGapkwOHAMzIa4kyOdYB8FEZTUuIEcQM+B/deQSYroc\n\t\t\t\t\t\tOF/m2IK8C5gwzO8IOdiP2DNWe2CTfeYP5/O/JIjt82QpUwvurgNRqP0CAwEAATAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAhtf0dSWtdyPMzdFbbHiaJyzkZZU5v46w61ubxJjM\n\t\t\t\t\t\tyXjAmoqMVHT4nG8MZ75kLulGP/CLhZhbe/9iTqRwpeIvdy9+TkcXBbEiA74FNCp8\n\t\t\t\t\t\tcHsz9P2D/rSIQDTa6nYx5Q677110fr1qtllErKy0iy5RB73Iynb+GaXiIB0n/2vh\n\t\t\t\t\t\tYFmpj9sDjgTSEn/HN2BaUxFubIt4nZt9xPT3jgQutfysWtNhXfJn/qB8uX04KVxP\n\t\t\t\t\t\tu2ROhvMTtYALUGQBvH5xDdSya1yqjjg/wC68x2bn3XEsQqWZsEHQ2wJPtCv0IsFX\n\t\t\t\t\t\tdPv/acSrfyFVxIZgbRRTDcPSN2uF5wLsH/Ib7aNIsvxj+Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "shrewsbury.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.shrewsbury.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.shrewsbury.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.shrewsbury.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.shrewsbury.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.shrewsbury.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.shrewsbury.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.shrewsbury.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.shrewsbury.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "shrewsbury.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEDjCCAvYCCQDdX07L9v0VEjANBgkqhkiG9w0BAQUFADCByDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEzARBgNVBAgMClNocm9wc2hpcmUxEzARBgNVBAcMClNocmV3c2J1cnkxGzAZ\n\t\t\t\t\t\tBgNVBAoMElNocmV3c2J1cnkgQ29sbGVnZTErMCkGA1UECwwidGVjaG5pY2FsIGFu\n\t\t\t\t\t\tZCBJbmZvcm1hdGlvbiBTZXJ2aWNlczEdMBsGA1UEAwwUaWRwLnNocmV3c2J1cnku\n\t\t\t\t\t\tYWMudWsxJjAkBgkqhkiG9w0BCQEWF3JvYmluYkBzaHJld3NidXJ5LmFjLnVrMB4X\n\t\t\t\t\t\tDTE2MDExMzA5MjM1MFoXDTI2MDExMDA5MjM1MFowgcgxCzAJBgNVBAYTAkdCMRMw\n\t\t\t\t\t\tEQYDVQQIDApTaHJvcHNoaXJlMRMwEQYDVQQHDApTaHJld3NidXJ5MRswGQYDVQQK\n\t\t\t\t\t\tDBJTaHJld3NidXJ5IENvbGxlZ2UxKzApBgNVBAsMInRlY2huaWNhbCBhbmQgSW5m\n\t\t\t\t\t\tb3JtYXRpb24gU2VydmljZXMxHTAbBgNVBAMMFGlkcC5zaHJld3NidXJ5LmFjLnVr\n\t\t\t\t\t\tMSYwJAYJKoZIhvcNAQkBFhdyb2JpbmJAc2hyZXdzYnVyeS5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBALJ0i3cBulkagk4eJfEi1rDUgIKiKE0q\n\t\t\t\t\t\tthBsZkKW7OT+HTcCOBEwqylbKsdBP6GUWN7CktVnRCN5Bjvq+ykgHE72bhsG+Hdv\n\t\t\t\t\t\tGa4HqEjZnttqmgfHIt1uJL/BMBzwCkMqJmckQxcwAIDvGpKpkpWXFtHh1h011iVZ\n\t\t\t\t\t\taO1NiveCTvjyEPFwOWxcfuMgI2CKKgXkuOyxGPUL3r/otBdbeflj6EQPJwYFCMI/\n\t\t\t\t\t\tB7lmxvVyEzcC5ydc3MIsGNGapkwOHAMzIa4kyOdYB8FEZTUuIEcQM+B/deQSYroc\n\t\t\t\t\t\tOF/m2IK8C5gwzO8IOdiP2DNWe2CTfeYP5/O/JIjt82QpUwvurgNRqP0CAwEAATAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAhtf0dSWtdyPMzdFbbHiaJyzkZZU5v46w61ubxJjM\n\t\t\t\t\t\tyXjAmoqMVHT4nG8MZ75kLulGP/CLhZhbe/9iTqRwpeIvdy9+TkcXBbEiA74FNCp8\n\t\t\t\t\t\tcHsz9P2D/rSIQDTa6nYx5Q677110fr1qtllErKy0iy5RB73Iynb+GaXiIB0n/2vh\n\t\t\t\t\t\tYFmpj9sDjgTSEn/HN2BaUxFubIt4nZt9xPT3jgQutfysWtNhXfJn/qB8uX04KVxP\n\t\t\t\t\t\tu2ROhvMTtYALUGQBvH5xDdSya1yqjjg/wC68x2bn3XEsQqWZsEHQ2wJPtCv0IsFX\n\t\t\t\t\t\tdPv/acSrfyFVxIZgbRRTDcPSN2uF5wLsH/Ib7aNIsvxj+Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Shrewsbury College of Arts and Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.shrewsbury.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Shrewsbury College of Arts and Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://integration.wcn.co.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Forsyth"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:duncan@wcn.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Duncan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Forsyth"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:duncan@wcn.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Duncan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://integration.wcn.co.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "World Careers Network plc"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wcn.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "World Careers Network plc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://integration.wcn.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://integration.wcn.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://integration.wcn.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://integration.wcn.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://integration.wcn.co.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth.wcn.co.uk/Shibboleth.sso/UKfederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.wcn.co.uk/Shibboleth.sso/UKfederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.wcn.co.uk/Shibboleth.sso/BAML",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.wcn.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFjDCCA3QCCQDY/5lx43eOoTANBgkqhkiG9w0BAQUFADCBhzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxDzANBgNVBAgTBkxvbmRvbjEPMA0GA1UEBxMGTG9uZG9uMSIwIAYDVQQKExlX\n\t\t\t\t\t\tb3JsZCBDYXJlZXJzIE5ldHdvcmsgUExDMRIwEAYDVQQLEwl0ZWNobmljYWwxHjAc\n\t\t\t\t\t\tBgNVBAMTFWludGVncmF0aW9uLndjbi5jby51azAeFw0wOTEyMTYxNTE2NDJaFw0x\n\t\t\t\t\t\tOTEyMTcxNTE2NDJaMIGHMQswCQYDVQQGEwJHQjEPMA0GA1UECBMGTG9uZG9uMQ8w\n\t\t\t\t\t\tDQYDVQQHEwZMb25kb24xIjAgBgNVBAoTGVdvcmxkIENhcmVlcnMgTmV0d29yayBQ\n\t\t\t\t\t\tTEMxEjAQBgNVBAsTCXRlY2huaWNhbDEeMBwGA1UEAxMVaW50ZWdyYXRpb24ud2Nu\n\t\t\t\t\t\tLmNvLnVrMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAvrf1ETn8BhT8\n\t\t\t\t\t\ts52CBJ9LyGmGnTtM/C083rx8h3es5OxrP28+dAL4aD5OBtocpJDWhbtDBjYJKF8P\n\t\t\t\t\t\tZJOCK6AkmsRb/NoLifWNDcguwkhETSGjoYdp3CqmeSbaPsCsCqb3vRfP5OH/BXTB\n\t\t\t\t\t\tvVv6NwfotXYsp5zTyQawyG2C/bMZk3bBjOlwZ0kKK0RjvAivfODIIylDsbueBvrL\n\t\t\t\t\t\t5Te328/fQt+cmKHdpCLDZk0x8WUuEpcZIVrysEAivAQbQjddBZULs0nVnmacAjl0\n\t\t\t\t\t\tLzwGJSkVxu2JhECPHh5KXvauTqD66ZC6PToNXX1b6gmW9N4SZH5X8C1vbltLTiL2\n\t\t\t\t\t\tOzNKHY4ZhPsQmaZTcIhxNSJcypK0HwXxbGqodIqdLub7buF4ZiqXsocG0QQiDMsF\n\t\t\t\t\t\taMjjS76MpUqSrIEXtt8HsGlJeYvvSiuoU+US1YHMK3iKOycErKTM2eHOBUlijZ4N\n\t\t\t\t\t\t42YCaI01PJrs/M0fvtKxsS9xl7BMg69gLpChTYYOy9ieMSiinfqRY/f5EWW9SePE\n\t\t\t\t\t\tvrXliik8CBjhz5CIwdLbUTP6MM12WSFPYmNQJ2k3SgETi2uxSkM8CoJp2WH/8YOd\n\t\t\t\t\t\t9Z+tvDCvyzcgJwBITet8kNq/GeFrl00CtYMC+zojnllzD7FQjAogE5SB0ibgi1dW\n\t\t\t\t\t\tPBKuRgYISMVS+4J2wp9qEkjWL6JETdsCAwEAATANBgkqhkiG9w0BAQUFAAOCAgEA\n\t\t\t\t\t\tWl7cp7aSpDSfHW35edbOQdDnJwPBhb61DtP2ypyLr5TXtCGUy04le6Isqa0n0JC7\n\t\t\t\t\t\tWjvm3mW4WmEKJIdijAV0ILdKLxdIpX7qyEbIY39S7G6q7867DxW4J0ANvo3B2MkM\n\t\t\t\t\t\tn91Hj0ZeDie1Oiha9Ul94seEqz5/oxIvzUI7uULfBDisVzlnYJS/seXDBq3D0h+s\n\t\t\t\t\t\tD6tZ4DIr6HrGqkb47heg+mwLgQBEpmB4x+qhAnkrTGE1Fw2OSPt3p/ayddRzdKQX\n\t\t\t\t\t\ttk0si7mWSfWo8W1rfBuy0EErIFByBxGhtNq4Wlxf5yzt0Ln/T1KBDHTgilYqhSgQ\n\t\t\t\t\t\tXvvgTcBa1pmiaRdZ5T6LT5hVybhpoFAm6xQecURFvXhlFHjK+H/Ia7H5Ecr1vcQq\n\t\t\t\t\t\tLbD07pGwTVUcJAJ5VM5g2jfGzYCHlBiUPiE3J3Aj506duKDJZRwuDQfnl4IGG1ca\n\t\t\t\t\t\tb9KTU0KPPBNSynKb++GcCyUtoknrMDGMSnfDcs2SsqzuFQHHA87p2ookjrC5z8//\n\t\t\t\t\t\tmIdiC4GxRRby9bddF2uF4kFjGYhHGP0ELHD+McESSUPqfG1Ooyw7XRhgl+DRl8Re\n\t\t\t\t\t\t9ARQE6+zAMp2Rx7N8cOYipc2h+eZF+jjgoCByAJiOB81x+/diB5UmCLwLx0u2BQq\n\t\t\t\t\t\t2KalbJoEekyZZ3ki7yfgLvyquDs9xGAqGbQ7pVnYKHM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFjDCCA3QCCQDY/5lx43eOoTANBgkqhkiG9w0BAQUFADCBhzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxDzANBgNVBAgTBkxvbmRvbjEPMA0GA1UEBxMGTG9uZG9uMSIwIAYDVQQKExlX\n\t\t\t\t\t\tb3JsZCBDYXJlZXJzIE5ldHdvcmsgUExDMRIwEAYDVQQLEwl0ZWNobmljYWwxHjAc\n\t\t\t\t\t\tBgNVBAMTFWludGVncmF0aW9uLndjbi5jby51azAeFw0wOTEyMTYxNTE2NDJaFw0x\n\t\t\t\t\t\tOTEyMTcxNTE2NDJaMIGHMQswCQYDVQQGEwJHQjEPMA0GA1UECBMGTG9uZG9uMQ8w\n\t\t\t\t\t\tDQYDVQQHEwZMb25kb24xIjAgBgNVBAoTGVdvcmxkIENhcmVlcnMgTmV0d29yayBQ\n\t\t\t\t\t\tTEMxEjAQBgNVBAsTCXRlY2huaWNhbDEeMBwGA1UEAxMVaW50ZWdyYXRpb24ud2Nu\n\t\t\t\t\t\tLmNvLnVrMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAvrf1ETn8BhT8\n\t\t\t\t\t\ts52CBJ9LyGmGnTtM/C083rx8h3es5OxrP28+dAL4aD5OBtocpJDWhbtDBjYJKF8P\n\t\t\t\t\t\tZJOCK6AkmsRb/NoLifWNDcguwkhETSGjoYdp3CqmeSbaPsCsCqb3vRfP5OH/BXTB\n\t\t\t\t\t\tvVv6NwfotXYsp5zTyQawyG2C/bMZk3bBjOlwZ0kKK0RjvAivfODIIylDsbueBvrL\n\t\t\t\t\t\t5Te328/fQt+cmKHdpCLDZk0x8WUuEpcZIVrysEAivAQbQjddBZULs0nVnmacAjl0\n\t\t\t\t\t\tLzwGJSkVxu2JhECPHh5KXvauTqD66ZC6PToNXX1b6gmW9N4SZH5X8C1vbltLTiL2\n\t\t\t\t\t\tOzNKHY4ZhPsQmaZTcIhxNSJcypK0HwXxbGqodIqdLub7buF4ZiqXsocG0QQiDMsF\n\t\t\t\t\t\taMjjS76MpUqSrIEXtt8HsGlJeYvvSiuoU+US1YHMK3iKOycErKTM2eHOBUlijZ4N\n\t\t\t\t\t\t42YCaI01PJrs/M0fvtKxsS9xl7BMg69gLpChTYYOy9ieMSiinfqRY/f5EWW9SePE\n\t\t\t\t\t\tvrXliik8CBjhz5CIwdLbUTP6MM12WSFPYmNQJ2k3SgETi2uxSkM8CoJp2WH/8YOd\n\t\t\t\t\t\t9Z+tvDCvyzcgJwBITet8kNq/GeFrl00CtYMC+zojnllzD7FQjAogE5SB0ibgi1dW\n\t\t\t\t\t\tPBKuRgYISMVS+4J2wp9qEkjWL6JETdsCAwEAATANBgkqhkiG9w0BAQUFAAOCAgEA\n\t\t\t\t\t\tWl7cp7aSpDSfHW35edbOQdDnJwPBhb61DtP2ypyLr5TXtCGUy04le6Isqa0n0JC7\n\t\t\t\t\t\tWjvm3mW4WmEKJIdijAV0ILdKLxdIpX7qyEbIY39S7G6q7867DxW4J0ANvo3B2MkM\n\t\t\t\t\t\tn91Hj0ZeDie1Oiha9Ul94seEqz5/oxIvzUI7uULfBDisVzlnYJS/seXDBq3D0h+s\n\t\t\t\t\t\tD6tZ4DIr6HrGqkb47heg+mwLgQBEpmB4x+qhAnkrTGE1Fw2OSPt3p/ayddRzdKQX\n\t\t\t\t\t\ttk0si7mWSfWo8W1rfBuy0EErIFByBxGhtNq4Wlxf5yzt0Ln/T1KBDHTgilYqhSgQ\n\t\t\t\t\t\tXvvgTcBa1pmiaRdZ5T6LT5hVybhpoFAm6xQecURFvXhlFHjK+H/Ia7H5Ecr1vcQq\n\t\t\t\t\t\tLbD07pGwTVUcJAJ5VM5g2jfGzYCHlBiUPiE3J3Aj506duKDJZRwuDQfnl4IGG1ca\n\t\t\t\t\t\tb9KTU0KPPBNSynKb++GcCyUtoknrMDGMSnfDcs2SsqzuFQHHA87p2ookjrC5z8//\n\t\t\t\t\t\tmIdiC4GxRRby9bddF2uF4kFjGYhHGP0ELHD+McESSUPqfG1Ooyw7XRhgl+DRl8Re\n\t\t\t\t\t\t9ARQE6+zAMp2Rx7N8cOYipc2h+eZF+jjgoCByAJiOB81x+/diB5UmCLwLx0u2BQq\n\t\t\t\t\t\t2KalbJoEekyZZ3ki7yfgLvyquDs9xGAqGbQ7pVnYKHM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://integration.wcn.co.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://integration.wcn.co.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://integration.wcn.co.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://integration.wcn.co.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://integration.wcn.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://integration.wcn.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://integration.wcn.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://integration.wcn.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://integration.wcn.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://integration.wcn.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.wcn.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.wcn.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.wcn.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth.wcn.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.wcn.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.wcn.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://fedauth.london.edu/oala/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:help@london.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT-Library Help"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Eaton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jeaton@london.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jonathan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://fedauth.london.edu/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-02-27T13:03:24Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://fedauth.london.edu/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://fedauth.london.edu/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "london.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTjCCAjagAwIBAgIIFcy1w+ieQigwDQYJKoZIhvcNAQEFBQAwPjEfMB0GA1UE\n\t\t\t\t\t\tCgwWTG9uZG9uIEJ1c2luZXNzIFNjaG9vbDEbMBkGA1UEAwwSZmVkYXV0aC5sb25k\n\t\t\t\t\t\tb24uZWR1MB4XDTEzMDIyNjEzMDk0MFoXDTIzMDIyNjEzMDk0MFowPjEfMB0GA1UE\n\t\t\t\t\t\tCgwWTG9uZG9uIEJ1c2luZXNzIFNjaG9vbDEbMBkGA1UEAwwSZmVkYXV0aC5sb25k\n\t\t\t\t\t\tb24uZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmuoPnUfdF5F/\n\t\t\t\t\t\tmWAfYMh6b3QPssEJRxpSepwoygicWu/BnpK2ZEJ/VhmcODjHYObT4et0XyQLSelg\n\t\t\t\t\t\thKZhkUbxpxpI7AeVZHthIKymXC06ihIHVtzA10jjskWmy97R0HB5NZ92taNa23kK\n\t\t\t\t\t\tI9UEhy0+fYsf2zgbjB1X6sEMEWWGQ5mR3fiEKxL6ttyZ8+Sue1oPxnrX8rGr0wiT\n\t\t\t\t\t\ta6HJFZwmYA7qkXpAHlQq7nPIqvYPoG3KIBubl+6iKJ0VHfiV1JQ8Zfmb13pHpjEr\n\t\t\t\t\t\tnoiTZlUm/88+EQj4TVaFaQUH/gbHrk3TOS+5s/11fhqd4QEWe2Rxl/xGcGpaGxr4\n\t\t\t\t\t\tm114hKQKSQIDAQABo1AwTjAdBgNVHQ4EFgQU0Pk2SB/JtZVI4qSyB/cgh1R3A+Mw\n\t\t\t\t\t\tHwYDVR0jBBgwFoAU0Pk2SB/JtZVI4qSyB/cgh1R3A+MwDAYDVR0TBAUwAwEB/zAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEASVcMlTZG8x4IF2uXi2BIHuJLgyqHBKGi0OIZkIvX\n\t\t\t\t\t\tsZWkXqoUDoodThj+U5HzXoDAJ3dNRmJ1fx4FKOi2elJtkWuQqk4qLUuugvND1no1\n\t\t\t\t\t\tgPqqWJh2fP3/WoP16gK3J8k5Loq8BjpTHc8qsRuQi7keFgVTst2HolaeWBGoIJi1\n\t\t\t\t\t\tB17UjY+cQDtzk+fdzACii21YhFEEEV0/jYQNmPlzW4LKLDOrjlvBZXfGUoh4cB6G\n\t\t\t\t\t\t1+hOSOP088MsXmqmwytyAn9lF/V0DuHgYuUNEUiX0oUWSpqLyaWxfForagSk3yYA\n\t\t\t\t\t\tWQo5UCat9zUgUtjVh8qsUJDnrzFRrQcRzyeWnvIRG0cd/w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTjCCAjagAwIBAgIIFcy1w+ieQigwDQYJKoZIhvcNAQEFBQAwPjEfMB0GA1UE\n\t\t\t\t\t\tCgwWTG9uZG9uIEJ1c2luZXNzIFNjaG9vbDEbMBkGA1UEAwwSZmVkYXV0aC5sb25k\n\t\t\t\t\t\tb24uZWR1MB4XDTEzMDIyNjEzMDk0MFoXDTIzMDIyNjEzMDk0MFowPjEfMB0GA1UE\n\t\t\t\t\t\tCgwWTG9uZG9uIEJ1c2luZXNzIFNjaG9vbDEbMBkGA1UEAwwSZmVkYXV0aC5sb25k\n\t\t\t\t\t\tb24uZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmuoPnUfdF5F/\n\t\t\t\t\t\tmWAfYMh6b3QPssEJRxpSepwoygicWu/BnpK2ZEJ/VhmcODjHYObT4et0XyQLSelg\n\t\t\t\t\t\thKZhkUbxpxpI7AeVZHthIKymXC06ihIHVtzA10jjskWmy97R0HB5NZ92taNa23kK\n\t\t\t\t\t\tI9UEhy0+fYsf2zgbjB1X6sEMEWWGQ5mR3fiEKxL6ttyZ8+Sue1oPxnrX8rGr0wiT\n\t\t\t\t\t\ta6HJFZwmYA7qkXpAHlQq7nPIqvYPoG3KIBubl+6iKJ0VHfiV1JQ8Zfmb13pHpjEr\n\t\t\t\t\t\tnoiTZlUm/88+EQj4TVaFaQUH/gbHrk3TOS+5s/11fhqd4QEWe2Rxl/xGcGpaGxr4\n\t\t\t\t\t\tm114hKQKSQIDAQABo1AwTjAdBgNVHQ4EFgQU0Pk2SB/JtZVI4qSyB/cgh1R3A+Mw\n\t\t\t\t\t\tHwYDVR0jBBgwFoAU0Pk2SB/JtZVI4qSyB/cgh1R3A+MwDAYDVR0TBAUwAwEB/zAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEASVcMlTZG8x4IF2uXi2BIHuJLgyqHBKGi0OIZkIvX\n\t\t\t\t\t\tsZWkXqoUDoodThj+U5HzXoDAJ3dNRmJ1fx4FKOi2elJtkWuQqk4qLUuugvND1no1\n\t\t\t\t\t\tgPqqWJh2fP3/WoP16gK3J8k5Loq8BjpTHc8qsRuQi7keFgVTst2HolaeWBGoIJi1\n\t\t\t\t\t\tB17UjY+cQDtzk+fdzACii21YhFEEEV0/jYQNmPlzW4LKLDOrjlvBZXfGUoh4cB6G\n\t\t\t\t\t\t1+hOSOP088MsXmqmwytyAn9lF/V0DuHgYuUNEUiX0oUWSpqLyaWxfForagSk3yYA\n\t\t\t\t\t\tWQo5UCat9zUgUtjVh8qsUJDnrzFRrQcRzyeWnvIRG0cd/w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "London Business School"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.london.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "London Business School"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://publishing.rcseng.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso-support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso-tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://publishing.rcseng.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-06-02T13:59:42Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Royal College of Surgeons of England SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rcseng.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://publishing.rcseng.ac.uk/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://publishing.rcseng.ac.uk/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://publishing.rcseng.ac.uk/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIJAMhKH6y9Hoa3MA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\n\t\t\t\t\t\tBAMTF3B1Ymxpc2hpbmcucmNzZW5nLmFjLnVrMB4XDTE1MDUxOTIwMTExOVoXDTE4\n\t\t\t\t\t\tMDUxODIwMTExOVowIjEgMB4GA1UEAxMXcHVibGlzaGluZy5yY3NlbmcuYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCcqP1nsR6RR63+tt7m6VpG\n\t\t\t\t\t\tFe0N63jWc+L75Yx/XcifuQzUgCwaUIWCDMry+0owhAp+gEKyvS6PRD8882uMz3zF\n\t\t\t\t\t\tTV+CgO6zQhcJjnyveppcMncbMfalY3zOw1YjleoR4XLdzpyW4LuY5tNVnMAZXQVC\n\t\t\t\t\t\tVtHG2p+9/8XfG0MlsHbY2nZ+yZgT9vkIyPtIWpXi/idj1EN+ZdLCtsL3yzGqWAve\n\t\t\t\t\t\tQi9kYWS+ggG5r2pQfLVkbvVmsTL23JBqRld1A9qRVUTdnpXFabP8JpOjvXE3snd1\n\t\t\t\t\t\tsyyqznSclUa/CyNxaOjHIdRwwla8uTgjBzptM+cYxVoyhmoix40D+2TM8lxMalDn\n\t\t\t\t\t\tAgMBAAGjcTBvME4GA1UdEQRHMEWCF3B1Ymxpc2hpbmcucmNzZW5nLmFjLnVrhipo\n\t\t\t\t\t\tdHRwczovL3B1Ymxpc2hpbmcucmNzZW5nLmFjLnVrL3NoaWJib2xldGgwHQYDVR0O\n\t\t\t\t\t\tBBYEFNz9EzNV6uHR8X7nyRFUHHnHpGOFMA0GCSqGSIb3DQEBBQUAA4IBAQAFEZps\n\t\t\t\t\t\txzkFcuj9fOp4h+TzbjL3/sEHVrKx4Dh2tVMPfGk0SMrBqKFNHAXiSNoAo6215SuU\n\t\t\t\t\t\tEzm1gXadzcNjJPqm7RUk3gAc5bYw1sjNSFi0Te5GSuZZZSw/WwkN0gM/FYVp4FnK\n\t\t\t\t\t\thQhCaQ+juVlDE5rb8ghlrI5jrtwepYPteWaxu++m5qZTlAxvvtx2pRfUyukVJjMZ\n\t\t\t\t\t\tPkaOYchDb5r9Z+twVephYe+xxrDxLwiy0CeyVTKxwjs/tDipulBOmB5r306v8upD\n\t\t\t\t\t\t3wvxMOAwc73Gkm2Zrkckq+6SBwQx++uWHktS09fWnbdpLOjEVAlziJ2Dibj/6rQ3\n\t\t\t\t\t\tJSRe52fl1W9ziYsM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://publishing.rcseng.ac.uk"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Royal College of Surgeons of England publishes the Annals, Bulletin and FDJ journals."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Royal College of Surgeons of England SP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://idp.surfnet.nl",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.surfnet.nl",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2011-06-08T00:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/ba573f07093978e3852ddef0d2465b84",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "surfnet.nl"
              },
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SURFnet bv"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SURFnet bv"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/surfnet.png",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SURFnet bv"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SURFnet bv"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SURFnet bv"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.surfnet.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SURFnet bv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://openathens.aston.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:isa_sysadm@aston.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Team Mailbox"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hunt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:t.d.hunt@aston.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tom"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:isa_sysadm@aston.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Team Mailbox"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hunt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:t.d.hunt@aston.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tom"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://openathens.aston.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-07-03T16:14:48Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://openathens.aston.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://openathens.aston.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aston.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSjCCAjKgAwIBAgIIeTpa4BHO1jIwDQYJKoZIhvcNAQEFBQAwPDEZMBcGA1UE\n\t\t\t\t\t\tCgwQQXN0b24gVW5pdmVyc2l0eTEfMB0GA1UEAwwWb3BlbmF0aGVucy5hc3Rvbi5h\n\t\t\t\t\t\tYy51azAeFw0xMjA2MjUxNTAxMzNaFw0yMjA2MjUxNTAxMzNaMDwxGTAXBgNVBAoM\n\t\t\t\t\t\tEEFzdG9uIFVuaXZlcnNpdHkxHzAdBgNVBAMMFm9wZW5hdGhlbnMuYXN0b24uYWMu\n\t\t\t\t\t\tdWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCiynBTPNB1iYMl464O\n\t\t\t\t\t\t8yQghrgRuIll2drDAQX4uoytwUsPYzlR1Vg//tu/lfk/nPZvt5P3cuxnoFRjKu30\n\t\t\t\t\t\tjDp+D0BlrJGBVKxcWwcstBl95GPLzJk6iLN2XzkQk5CEOvE/hieTfaAVts/UWSpy\n\t\t\t\t\t\tXjmo6lW99KsOLd5bHrJUJ3glw8wYv3q5Uy769KbQmsVi3+kfwvKWBg6uWi4C0Ea9\n\t\t\t\t\t\tPkGzykek7n2GvjHLvwFLPFW32F6Vc3RJlCiE+eJ3iDE3DWG76GG9rJdDQCeN8aYK\n\t\t\t\t\t\txe8wMZaSPve76I5X8EKBdgVtOnJb2IfG6wUNFiWpDR45fWox+6oE3IydEe6nV7dg\n\t\t\t\t\t\tWE4xAgMBAAGjUDBOMB0GA1UdDgQWBBT+uPA5lqwqcWsIWFERADKcdDri+jAfBgNV\n\t\t\t\t\t\tHSMEGDAWgBT+uPA5lqwqcWsIWFERADKcdDri+jAMBgNVHRMEBTADAQH/MA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQAIe+0nlbX41IeZ/2YZOmGp9OQjj2vDoDg3YDRlkP7UoMQL\n\t\t\t\t\t\tBVBXKb0m2sCCRQVvlfcIzDORdlkH+YO/QCJDwzgKB/Lb4CtMvUrE/EItN+ZO8EtZ\n\t\t\t\t\t\t0hoEdCagdPCJa8QhNx5oy1T45OLidoTxWrafZsWN4Jw6Gpm1luyzLIU4HtwABhW9\n\t\t\t\t\t\tyYFFhJjiOOrlQ8ANkt+gMTFL3hYwDGTJt4iFjH4zqAAxR9yn9gCu8ajniBrQNVO7\n\t\t\t\t\t\tEEFJkraetkDgv0vtW68UBadRK51sYcS2m/WBe7jtynskjvRaqwX+Ui8kCFkbMcEC\n\t\t\t\t\t\tY2CHAtp5TNRdXvcrmNE/yyOdqVfCJk0D7WJjCp8w"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSjCCAjKgAwIBAgIIeTpa4BHO1jIwDQYJKoZIhvcNAQEFBQAwPDEZMBcGA1UE\n\t\t\t\t\t\tCgwQQXN0b24gVW5pdmVyc2l0eTEfMB0GA1UEAwwWb3BlbmF0aGVucy5hc3Rvbi5h\n\t\t\t\t\t\tYy51azAeFw0xMjA2MjUxNTAxMzNaFw0yMjA2MjUxNTAxMzNaMDwxGTAXBgNVBAoM\n\t\t\t\t\t\tEEFzdG9uIFVuaXZlcnNpdHkxHzAdBgNVBAMMFm9wZW5hdGhlbnMuYXN0b24uYWMu\n\t\t\t\t\t\tdWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCiynBTPNB1iYMl464O\n\t\t\t\t\t\t8yQghrgRuIll2drDAQX4uoytwUsPYzlR1Vg//tu/lfk/nPZvt5P3cuxnoFRjKu30\n\t\t\t\t\t\tjDp+D0BlrJGBVKxcWwcstBl95GPLzJk6iLN2XzkQk5CEOvE/hieTfaAVts/UWSpy\n\t\t\t\t\t\tXjmo6lW99KsOLd5bHrJUJ3glw8wYv3q5Uy769KbQmsVi3+kfwvKWBg6uWi4C0Ea9\n\t\t\t\t\t\tPkGzykek7n2GvjHLvwFLPFW32F6Vc3RJlCiE+eJ3iDE3DWG76GG9rJdDQCeN8aYK\n\t\t\t\t\t\txe8wMZaSPve76I5X8EKBdgVtOnJb2IfG6wUNFiWpDR45fWox+6oE3IydEe6nV7dg\n\t\t\t\t\t\tWE4xAgMBAAGjUDBOMB0GA1UdDgQWBBT+uPA5lqwqcWsIWFERADKcdDri+jAfBgNV\n\t\t\t\t\t\tHSMEGDAWgBT+uPA5lqwqcWsIWFERADKcdDri+jAMBgNVHRMEBTADAQH/MA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQAIe+0nlbX41IeZ/2YZOmGp9OQjj2vDoDg3YDRlkP7UoMQL\n\t\t\t\t\t\tBVBXKb0m2sCCRQVvlfcIzDORdlkH+YO/QCJDwzgKB/Lb4CtMvUrE/EItN+ZO8EtZ\n\t\t\t\t\t\t0hoEdCagdPCJa8QhNx5oy1T45OLidoTxWrafZsWN4Jw6Gpm1luyzLIU4HtwABhW9\n\t\t\t\t\t\tyYFFhJjiOOrlQ8ANkt+gMTFL3hYwDGTJt4iFjH4zqAAxR9yn9gCu8ajniBrQNVO7\n\t\t\t\t\t\tEEFJkraetkDgv0vtW68UBadRK51sYcS2m/WBe7jtynskjvRaqwX+Ui8kCFkbMcEC\n\t\t\t\t\t\tY2CHAtp5TNRdXvcrmNE/yyOdqVfCJk0D7WJjCp8w"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Aston University OpenAthens"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aston.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Aston University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://testaprisma.vr.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://testaprisma.vr.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://testaprisma.vr.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://testaprisma.vr.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://testaprisma.vr.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://testaprisma.vr.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://testaprisma.vr.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://testaprisma.vr.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://testaprisma.vr.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "I Prisma kan du ans\u00f6ka om forskningsmedel och hantera dina beviljade bidrag."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Prisma is a joint portal used by several research funders."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Prisma - testaprisma.vr.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Prisma - testaprisma.vr.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "testaprisma.vr.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+jCCAeKgAwIBAgIJALyDb0U/kwgyMA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\nBAMTEXRlc3RhcHJpc21hLnZyLnNlMB4XDTE0MDUwMjA4MzYwOFoXDTI0MDQyOTA4\nMzYwOFowHDEaMBgGA1UEAxMRdGVzdGFwcmlzbWEudnIuc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQC6ojfwiDlOFQMYd/ENAcVUaW3YQ1k1L+JlE81K\nZ8ZZh796aWxwwVisbmZqBek/H6eNWpxLR//D77YEx8TwdmMzDuB9RbNLsbp28uu6\nUssH7qVUIdw5nnpEAywK+NGsLJbVEhrZerp8ydpAu5Qj9Th0WIiLThXiXc/9WH4S\nVeEkHD22LI1FjsgXQjlcVxyvyIDlHgnkzQmrUfwAtyVY67ASFEsy4SkJAeuGzi2I\nvMPrc938LPUANRHtJrECcbBUsmnpZBeU24DBdR5rYLL1BPjYrsWkyrHVciP/zT4j\nN+fvnJC1I8NflYhtdxQx2nJbHiNw1mvFt3jsAs6eeaLpwEbHAgMBAAGjPzA9MBwG\nA1UdEQQVMBOCEXRlc3RhcHJpc21hLnZyLnNlMB0GA1UdDgQWBBRZtyMF+9cE8Bgi\nypEcHApzkfy4CTANBgkqhkiG9w0BAQUFAAOCAQEAdruGJJ79YxJMkORE7Li8jATg\ns2+bU8dnTEDNls2RBfRYKlYHQg+mjtyYYdZR7qTy0aJibwofgo6ieXdX6Jg5eMU9\n/+93xCFYTPEofWj9pZy5BDx6AvxyhgQ9XjtdsMDphGMRoWTc92BGdNjAAw/Oag75\nH9PjoorE61MIqluiO6Pb/W+bE2mYgeIWsqsutJQfa6Duk9UjnVVYAMspkRyQ9Z0f\nJeN4ASzWWgxCEmOjT+bj6VFvnRwPDOlTi7paqdpasPoxKVSx/S/4bgpH23vNtu9b\nDy3oscht7rhlGhTsIsDulx5tPZY9ZyOVoZ6d6RQxvIwExf5Tt7QW1w0i0Pb9xA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=testaprisma.vr.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://testaprisma.vr.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://testaprisma.vr.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://testaprisma.vr.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://testaprisma.vr.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://testaprisma.vr.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.brighton.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@brighton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Holden"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ukfederation-tech@brighton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.brighton.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAJtTrJ6fUZBDJiA/AL+K10ByMCF5MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB0xGzAZBgNVBAMTEmlkcC5icmlnaHRvbi5hYy51azAeFw0xMjAxMTExMDE3\n\t\t\t\t\t\tMzlaFw0zMjAxMTExMDE3MzlaMB0xGzAZBgNVBAMTEmlkcC5icmlnaHRvbi5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK78vKo40NZ7No1AlT01\n\t\t\t\t\t\toewusm35cDYzGHmgVI+Blb8Pd1LmwfIIGOTyyOab+3+qV/PTVwTPIjQBRDINhUk6\n\t\t\t\t\t\tTFZN/AspdbZQhAGLKbW7QAwvJEiHDjEPYpwIByCPz3dr9OM3awLThovrdoegnYg1\n\t\t\t\t\t\ts+nhT0ub2TI43rYRZds0P1xx8uBBst4Q1dTfeRN3aq2XUtMoR0d5O4fSVpfZ1mBe\n\t\t\t\t\t\tWZTLlbfrS+j0I5IsCd2EXmKaeIeJtyTr2qIfFk+0RdT5RqI2vt513+zwNHi3dJmb\n\t\t\t\t\t\twlR5rQdTphXcQkgsegdvpxom59vRwjvGrwohDwWvjKgAmede4SjRS0Fwbas6wylX\n\t\t\t\t\t\tfjMCAwEAAaNnMGUwRAYDVR0RBD0wO4ISaWRwLmJyaWdodG9uLmFjLnVrhiVodHRw\n\t\t\t\t\t\tczovL2lkcC5icmlnaHRvbi5hYy51ay9zaGliYm9sZXRoMB0GA1UdDgQWBBSa7vVm\n\t\t\t\t\t\tylujM9iFlPHXlbcIG3n5oDANBgkqhkiG9w0BAQUFAAOCAQEAUmCdQF3CHxz5dfbv\n\t\t\t\t\t\t28Mrc83FzRVCexxa6iHL/lDlsIRxN0M+sN/qj0EovgUh7rYITpCZ30daaawUUbM5\n\t\t\t\t\t\tj1XOYsvkiAOjYJ/hDwpKm+6Ww+Rl6yhDFTRX5cyDiOwZFIBhTZwkiQ1aJ6xpuDI6\n\t\t\t\t\t\tBQTHaVODaE+nKb2CKSmozuIejYEvRVxKRQJgzpgv1AaLI0MTwMpk3gVoz5MzPCod\n\t\t\t\t\t\tJGjYZQTFlvBAGdjsXeKfXxxDk8W+lO2Nb4+gE8HEN1hAXTKRJZW0G1M/wFJ+MSUd\n\t\t\t\t\t\t7E1eO+mot7dPa60wFfoDkGGIq7OBnXwFjXxBOmrjpr9tEA41vVu4MNQCEG9Omt1y\n\t\t\t\t\t\tLmAj9g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brighton.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.brighton.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.brighton.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.brighton.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.brighton.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.brighton.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.brighton.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.brighton.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.brighton.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brighton.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://idp.brighton.ac.uk/idp/images/logo-brighton.ac.uk.png",
                    "height": "30",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "32"
                  },
                  {
                    "text": "https://idp.brighton.ac.uk/idp/images/favicon-brighton.ac.uk.ico",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Brighton"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAJtTrJ6fUZBDJiA/AL+K10ByMCF5MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB0xGzAZBgNVBAMTEmlkcC5icmlnaHRvbi5hYy51azAeFw0xMjAxMTExMDE3\n\t\t\t\t\t\tMzlaFw0zMjAxMTExMDE3MzlaMB0xGzAZBgNVBAMTEmlkcC5icmlnaHRvbi5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK78vKo40NZ7No1AlT01\n\t\t\t\t\t\toewusm35cDYzGHmgVI+Blb8Pd1LmwfIIGOTyyOab+3+qV/PTVwTPIjQBRDINhUk6\n\t\t\t\t\t\tTFZN/AspdbZQhAGLKbW7QAwvJEiHDjEPYpwIByCPz3dr9OM3awLThovrdoegnYg1\n\t\t\t\t\t\ts+nhT0ub2TI43rYRZds0P1xx8uBBst4Q1dTfeRN3aq2XUtMoR0d5O4fSVpfZ1mBe\n\t\t\t\t\t\tWZTLlbfrS+j0I5IsCd2EXmKaeIeJtyTr2qIfFk+0RdT5RqI2vt513+zwNHi3dJmb\n\t\t\t\t\t\twlR5rQdTphXcQkgsegdvpxom59vRwjvGrwohDwWvjKgAmede4SjRS0Fwbas6wylX\n\t\t\t\t\t\tfjMCAwEAAaNnMGUwRAYDVR0RBD0wO4ISaWRwLmJyaWdodG9uLmFjLnVrhiVodHRw\n\t\t\t\t\t\tczovL2lkcC5icmlnaHRvbi5hYy51ay9zaGliYm9sZXRoMB0GA1UdDgQWBBSa7vVm\n\t\t\t\t\t\tylujM9iFlPHXlbcIG3n5oDANBgkqhkiG9w0BAQUFAAOCAQEAUmCdQF3CHxz5dfbv\n\t\t\t\t\t\t28Mrc83FzRVCexxa6iHL/lDlsIRxN0M+sN/qj0EovgUh7rYITpCZ30daaawUUbM5\n\t\t\t\t\t\tj1XOYsvkiAOjYJ/hDwpKm+6Ww+Rl6yhDFTRX5cyDiOwZFIBhTZwkiQ1aJ6xpuDI6\n\t\t\t\t\t\tBQTHaVODaE+nKb2CKSmozuIejYEvRVxKRQJgzpgv1AaLI0MTwMpk3gVoz5MzPCod\n\t\t\t\t\t\tJGjYZQTFlvBAGdjsXeKfXxxDk8W+lO2Nb4+gE8HEN1hAXTKRJZW0G1M/wFJ+MSUd\n\t\t\t\t\t\t7E1eO+mot7dPa60wFfoDkGGIq7OBnXwFjXxBOmrjpr9tEA41vVu4MNQCEG9Omt1y\n\t\t\t\t\t\tLmAj9g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Brighton"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.brighton.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Brighton"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.testa.universityadmissions.se/aws-sp-en",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al2"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://www.swamid.se/assurance-requirement",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.testa.universityadmissions.se/aws-sp-en",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.testa.universityadmissions.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.testa.universityadmissions.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.testa.universityadmissions.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.testa.universityadmissions.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.testa.universityadmissions.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.testa.universityadmissions.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.testa.universityadmissions.se/aws-sp-en"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.testa.universityadmissions.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYTCCAkmgAwIBAgIJALaHWD91lN/0MA0GCSqGSIb3DQEBBQUAMCwxKjAoBgNV\nBAMTIXd3dy50ZXN0YS51bml2ZXJzaXR5YWRtaXNzaW9ucy5zZTAeFw0xMjAxMTIw\nODUyMTJaFw0yMjAxMDkwODUyMTJaMCwxKjAoBgNVBAMTIXd3dy50ZXN0YS51bml2\nZXJzaXR5YWRtaXNzaW9ucy5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\nggEBALbfTMa6QUT6f3OMkFHSpDQFwuEc9lU5jq3t4VJZXJjbYtRe1wq6P8NAPE0X\niE+GGm+E3rO7D6XlRNUSMhYCByL5sF8fcuU8mv/dnyrktSt6Bpznys7nkG+tZ3G1\nBqFbNRkn4RqhS7f2DcyRDENIfpVX+8kqI9AtHhcvr2c94jHjeXezTSSSt104eb5F\nk2hqUx3F+8G4VH3QPXPxm24k9ka1QY8c3362OOJEV7X/TBg444AM/l/Et/NxI47j\ns0XOHw9ThUNx/MCdd80xGA62hmwIu+iewstfgmvSp8Y9+0sUEXtTcwrJi7/GFJ2a\n9P8OlIfZ+XM8a6s9wn1U1us+boUCAwEAAaOBhTCBgjBhBgNVHREEWjBYgiF3d3cu\ndGVzdGEudW5pdmVyc2l0eWFkbWlzc2lvbnMuc2WGM2h0dHBzOi8vd3d3LnRlc3Rh\nLnVuaXZlcnNpdHlhZG1pc3Npb25zLnNlL2F3cy1zcC1lbjAdBgNVHQ4EFgQUrWWQ\nAHLNSBUZDheT8ClXNWdru0cwDQYJKoZIhvcNAQEFBQADggEBAFwOmKvbegaxrx6k\nxnrA6maO2O6r5CMKtinTFu1E5IdkEh+FesDl7X8T1ccy6bkGBAg4L3Vd1J6GfoNy\n7wPoVJsL+DwFZ8LUccweI8PDBmrTx3z5ji3fdiYhBNCbu8x/jJ7D8zfd6WCnRmmP\nhzQNYoV1JN8UBP5Rs1YaXJHBKSw0lkU1sf/esYTJdBA1hmloykA6P45Qez92pHdl\nuVnNfkBr7UdYjz8IiPTitv+Yn7FUuXSacFejhLoHOeeskNdYJ3W4CtY9kB2FO4cF\nTEgTnrYK7hYZuU8O+wJUDDJkahZN9Kuf56JVejRBQZZ6mpVdMHs/Mj2XzxpHlDTe\naERyA2E="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.testa.universityadmissions.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.testa.universityadmissions.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.testa.universityadmissions.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.testa.universityadmissions.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.testa.universityadmissions.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.testa.universityadmissions.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.testa.universityadmissions.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.testa.universityadmissions.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.testa.universityadmissions.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.testa.universityadmissions.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.testa.universityadmissions.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://garr-idp-prod.irccs.garr.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:system.support@garr.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "System Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://garr-idp-prod.irccs.garr.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2013-07-31T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkCgAwIBAgIVAPZKMgdGcoQkXqZIfy0VDEQIQwOIMA0GCSqGSIb3DQEB\nBQUAMCYxJDAiBgNVBAMTG2dhcnItaWRwLXByb2QuaXJjY3MuZ2Fyci5pdDAeFw0x\nMzA3MjYxMjI1MTRaFw0zMzA3MjYxMjI1MTRaMCYxJDAiBgNVBAMTG2dhcnItaWRw\nLXByb2QuaXJjY3MuZ2Fyci5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\nggEBAJHeyOXSuq5y8ZW7+87i+ytu5woxrwcXfXLyGEO5ELCwqfv2KR3BEhmxg5xR\n3DSOdStOAt2gzKn+MbJbUgsbSrUr3jyYoy2lggZuLtKl8QSs/tIvV2FSsi4JdI9k\nvDRcNtIPoiKzhMQmduvEFwBHt7mZ2p3Sq4PmQ2ZFCb1S5Na9isbtJxuyxB2wnMXM\nLvkR6zfbVvVZcgAlJ8ZP299aI0U3gWfO75qhhoLs4ZZpEzg/a9M6yHKjxj+Vg1Vl\nPp9WASd3fV2yHVAsDvsCsBin4DDsFUt0WDpt4mNsutTIdgNxofCDaPcdlN0504DJ\nV9ZjIpkBMBs/DPo24jRPurHiUy0CAwEAAaN9MHswWgYDVR0RBFMwUYIbZ2Fyci1p\nZHAtcHJvZC5pcmNjcy5nYXJyLml0hjJodHRwczovL2dhcnItaWRwLXByb2QuaXJj\nY3MuZ2Fyci5pdC9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUtvMwiFgS2v2SqYoH\nspgVmkVreXowDQYJKoZIhvcNAQEFBQADggEBAEqUfDgfRPY88jYVuF8+kHAtyUep\nVoXt6jqZqrjAw0bt22Je+StgCVx1d9ymK7YW2LGRtaTmn2P/u+5a7imm5eiOzXQu\nWom9Jpo9eO0Sgt6JGWxn84JEesHX84lOtq1Zk4vt6ikCiO+b4PZXvFX57VzfINKZ\naS6FPyIB0+6O6G+9e2T9N5w7GegZ6efHE4L5FqV/pmo1B6PIggQjwLdg2U5IQdbh\nyhRCuth3zwD/h8ugGBcivPvvI2MCU7rg/ylb5LyKPBg7m2sGeMVurm2iHnHGWGcY\n5PpfNjgfzle0x8qz7zUxVJN9yxVTPLkeCzCR68erStGXb3E1UalZJUC/6sQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "garr.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://garr-idp-prod.irccs.garr.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://garr-idp-prod.irccs.garr.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://garr-idp-prod.irccs.garr.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://garr-idp-prod.irccs.garr.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://garr-idp-prod.irccs.garr.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://garr-idp-prod.irccs.garr.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://garr-idp-prod.irccs.garr.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://garr-idp-prod.irccs.garr.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "garr.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://garr-idp-prod.irccs.garr.it/idp/info.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://garr-idp-prod.irccs.garr.it/idp/info.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IDP in the Cloud Project (GARR)"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Progetto IDP in the Cloud (GARR)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Test IDP dedicated to GARR's \"IDP in the Cloud\" Project"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IDP di Test per il progetto \"IDP in the Cloud\" del GARR"
                  }
                ],
                "logo": [
                  {
                    "text": "https://garr-idp-prod.irccs.garr.it/idp/images/institutionLogo-32x32_en.png",
                    "lang": "en",
                    "height": "32",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "32"
                  },
                  {
                    "text": "https://garr-idp-prod.irccs.garr.it/idp/images/institutionLogo-160x120_en.png",
                    "lang": "en",
                    "height": "120",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "160"
                  },
                  {
                    "text": "https://garr-idp-prod.irccs.garr.it/idp/images/institutionLogo-32x32_it.png",
                    "lang": "it",
                    "height": "32",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "32"
                  },
                  {
                    "text": "https://garr-idp-prod.irccs.garr.it/idp/images/institutionLogo-160x120_it.png",
                    "lang": "it",
                    "height": "120",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "160"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://garr-idp-prod.irccs.garr.it/idp/privacy.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://garr-idp-prod.irccs.garr.it/idp/privacy.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkCgAwIBAgIVAPZKMgdGcoQkXqZIfy0VDEQIQwOIMA0GCSqGSIb3DQEB\nBQUAMCYxJDAiBgNVBAMTG2dhcnItaWRwLXByb2QuaXJjY3MuZ2Fyci5pdDAeFw0x\nMzA3MjYxMjI1MTRaFw0zMzA3MjYxMjI1MTRaMCYxJDAiBgNVBAMTG2dhcnItaWRw\nLXByb2QuaXJjY3MuZ2Fyci5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\nggEBAJHeyOXSuq5y8ZW7+87i+ytu5woxrwcXfXLyGEO5ELCwqfv2KR3BEhmxg5xR\n3DSOdStOAt2gzKn+MbJbUgsbSrUr3jyYoy2lggZuLtKl8QSs/tIvV2FSsi4JdI9k\nvDRcNtIPoiKzhMQmduvEFwBHt7mZ2p3Sq4PmQ2ZFCb1S5Na9isbtJxuyxB2wnMXM\nLvkR6zfbVvVZcgAlJ8ZP299aI0U3gWfO75qhhoLs4ZZpEzg/a9M6yHKjxj+Vg1Vl\nPp9WASd3fV2yHVAsDvsCsBin4DDsFUt0WDpt4mNsutTIdgNxofCDaPcdlN0504DJ\nV9ZjIpkBMBs/DPo24jRPurHiUy0CAwEAAaN9MHswWgYDVR0RBFMwUYIbZ2Fyci1p\nZHAtcHJvZC5pcmNjcy5nYXJyLml0hjJodHRwczovL2dhcnItaWRwLXByb2QuaXJj\nY3MuZ2Fyci5pdC9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUtvMwiFgS2v2SqYoH\nspgVmkVreXowDQYJKoZIhvcNAQEFBQADggEBAEqUfDgfRPY88jYVuF8+kHAtyUep\nVoXt6jqZqrjAw0bt22Je+StgCVx1d9ymK7YW2LGRtaTmn2P/u+5a7imm5eiOzXQu\nWom9Jpo9eO0Sgt6JGWxn84JEesHX84lOtq1Zk4vt6ikCiO+b4PZXvFX57VzfINKZ\naS6FPyIB0+6O6G+9e2T9N5w7GegZ6efHE4L5FqV/pmo1B6PIggQjwLdg2U5IQdbh\nyhRCuth3zwD/h8ugGBcivPvvI2MCU7rg/ylb5LyKPBg7m2sGeMVurm2iHnHGWGcY\n5PpfNjgfzle0x8qz7zUxVJN9yxVTPLkeCzCR68erStGXb3E1UalZJUC/6sQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IDP in the Cloud Project (GARR)"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Progetto IDP in the Cloud (GARR)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.garr.it/b/eng"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.garr.it"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consortium GARR"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consortium GARR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:johnshopkins.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "andrew.baldwin@jhu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew Baldwin"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "enterpriseauth@jhmi.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Enterprise Authenticaion Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "eweintra@jhmi.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Etan Weintraub"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:johnshopkins.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://incommon.johnshopkins.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://incommon.johnshopkins.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTzCCAjegAwIBAgIUB/OyD4uWMP6wD8bB45UeirMblPAwDQYJKoZIhvcNAQEF\nBQAwJDEiMCAGA1UEAxMZaW5jb21tb24uam9obnNob3BraW5zLmVkdTAeFw0xMDA1\nMTAxODQ1NTlaFw0zMDA1MTAxODQ1NTlaMCQxIjAgBgNVBAMTGWluY29tbW9uLmpv\naG5zaG9wa2lucy5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCa\ndXUykxcqSVXo9zk+8KsxzXBBiSdQP3nYOvBaTNyBOrsTOM3grW6u12TjMtmBuevg\n0708FNY03w4vJYho60I1JO4eNgXsQUxyj2XiVxrcOnq1vBc0T1NtkzcXV0X3+7n6\nBoCOXt8akO8tC4jSFg4dY7hzH7pGfSqHFHw9o76bvKu264gHsEwubm0kPIebifWI\neWg5D4CvY4F36Tb7RmIbxu+pLXT8RiI4UWGkzLarRiKucMcR5NBNqlSiwp+fts7X\nYTh7vkJ+R36O5h2EVIMm2eJZyal195wRUu12IO/mZ9L2Iu6hcfnZ3oy56+VV3Eq2\nl3EhbsU43VSjBLC0Mq2RAgMBAAGjeTB3MFYGA1UdEQRPME2CGWluY29tbW9uLmpv\naG5zaG9wa2lucy5lZHWGMGh0dHBzOi8vaW5jb21tb24uam9obnNob3BraW5zLmVk\ndS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU4RjF7xk9rqSty02DIgPQOLnf6P8w\nDQYJKoZIhvcNAQEFBQADggEBACFPG1uKNWz6cMxtzL4gRRCjfP9AKmHEb5yhg2MI\nrVg3Tw1UkFnFcU6jfesVE3MPdabU2gquCrhnL6SKuZ4Gk19UZk7fBla/59AIIb8v\ncy0123fJow5yKtSNe5O70ouN4S2HCErl6NH30Z5iJn8tWMor5NEMI1u7QcFr108/\nGnAWzBvbr5GNrOnCQ8k35KVK6d+xwr3f+3H346CWcklxTNAYEn5+N3vR0F+uw0wP\n96QOFedHSLC7JwfG66uSWijmLy+QhtTiNEA1b8rn5Wq4AZnqwcjXoilz1yjSS1tT\nWYVvBm6n6IU0hHNWwnYCQT6WSHABz7vlkqM0c7A0oqltFPQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "johnshopkins.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://incommon.johnshopkins.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://incommon.johnshopkins.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://incommon.johnshopkins.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://incommon.johnshopkins.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://incommon.johnshopkins.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://incommon.johnshopkins.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "johnshopkins.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://login.johnshopkins.edu/login/images/jhlogo.gif",
                    "lang": "en",
                    "height": "52",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "266"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Johns Hopkins"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTzCCAjegAwIBAgIUB/OyD4uWMP6wD8bB45UeirMblPAwDQYJKoZIhvcNAQEF\nBQAwJDEiMCAGA1UEAxMZaW5jb21tb24uam9obnNob3BraW5zLmVkdTAeFw0xMDA1\nMTAxODQ1NTlaFw0zMDA1MTAxODQ1NTlaMCQxIjAgBgNVBAMTGWluY29tbW9uLmpv\naG5zaG9wa2lucy5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCa\ndXUykxcqSVXo9zk+8KsxzXBBiSdQP3nYOvBaTNyBOrsTOM3grW6u12TjMtmBuevg\n0708FNY03w4vJYho60I1JO4eNgXsQUxyj2XiVxrcOnq1vBc0T1NtkzcXV0X3+7n6\nBoCOXt8akO8tC4jSFg4dY7hzH7pGfSqHFHw9o76bvKu264gHsEwubm0kPIebifWI\neWg5D4CvY4F36Tb7RmIbxu+pLXT8RiI4UWGkzLarRiKucMcR5NBNqlSiwp+fts7X\nYTh7vkJ+R36O5h2EVIMm2eJZyal195wRUu12IO/mZ9L2Iu6hcfnZ3oy56+VV3Eq2\nl3EhbsU43VSjBLC0Mq2RAgMBAAGjeTB3MFYGA1UdEQRPME2CGWluY29tbW9uLmpv\naG5zaG9wa2lucy5lZHWGMGh0dHBzOi8vaW5jb21tb24uam9obnNob3BraW5zLmVk\ndS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU4RjF7xk9rqSty02DIgPQOLnf6P8w\nDQYJKoZIhvcNAQEFBQADggEBACFPG1uKNWz6cMxtzL4gRRCjfP9AKmHEb5yhg2MI\nrVg3Tw1UkFnFcU6jfesVE3MPdabU2gquCrhnL6SKuZ4Gk19UZk7fBla/59AIIb8v\ncy0123fJow5yKtSNe5O70ouN4S2HCErl6NH30Z5iJn8tWMor5NEMI1u7QcFr108/\nGnAWzBvbr5GNrOnCQ8k35KVK6d+xwr3f+3H346CWcklxTNAYEn5+N3vR0F+uw0wP\n96QOFedHSLC7JwfG66uSWijmLy+QhtTiNEA1b8rn5Wq4AZnqwcjXoilz1yjSS1tT\nWYVvBm6n6IU0hHNWwnYCQT6WSHABz7vlkqM0c7A0oqltFPQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Johns Hopkins"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jhu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Johns Hopkins University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayf.aams.dk/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayf.aams.dk/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2015-06-10T11:47:30Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayf.aams.dk/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aams.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Aarhus Maskinmesterskole"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Aarhus School of Marine and Technical Engineering"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "aams.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9jCCAd4CAQcwDQYJKoZIhvcNAQELBQAwQTE/MD0GA1UEAww2aHR0cHM6Ly93\nYXlmLmFhbXMuZGsvc2ltcGxlc2FtbC9zYW1sMi9pZHAvbWV0YWRhdGEucGhwMB4X\nDTE1MDEwMTAwMDAwMFoXDTI1MTIzMTIzNTk1OVowQTE/MD0GA1UEAww2aHR0cHM6\nLy93YXlmLmFhbXMuZGsvc2ltcGxlc2FtbC9zYW1sMi9pZHAvbWV0YWRhdGEucGhw\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAx4gMCmoQU7iOGfiCda4D\nnhIggst20fUCHtwaQrHoxQlOa0s5FgDalbnNTw36dCXSGYaz17JgyUDJonTwhjyA\n0CqPm5Pmn9/hFBUvyP/t+bEgV9r3/odQx72VfY7M55qUlY6ex2f1qD1gcpFgSTtA\nDlZswec5WqpEt+ie+vsMXq8HabhMVZ2EjXe90vgMk/xGfrVwDvupUPBS/2DJSZ1J\nEmkqi0hxctNQ9qgTZmEcAaQkuv3VGcsYtLeY/IISlA+ARzmVWr5+uSetnCXV4jnD\nEclACKeexl0Ky+tyra4yHF3Xavgmcmebd+xHVDiM+No6BXMu9zBTp7cp5ShLzsNQ\nSQIDAQABMA0GCSqGSIb3DQEBCwUAA4IBAQAil2QnUmBwaz7KiQ5tsJkYjlirObMb\nSTXByWsBbi97KpEJ6gubtbCAlEIBXHXZAToD0UKO9Xa+hsea7eueYW056riZq2n4\nHmKkOB+JvruqTrUp7+cmtGfTgIfr+dz4YrlSTeFsGvtD3112xa5CBMqQwzUi6Qwe\nFReoiwel15f1uhAqesNqCZRNG6S1yu9r5GhdljqgWmd5h5IpSh744scr9ZzZYspf\nwHyqhe9hre8z70TSKJP2YnfedEEDZ0ZrFIbzeJo3Jscm8Z3Lv99QF0UXcXGJyte+\ny6n+48evSVkVMMX88HffZUVp9ZyNULPR3CbMua8+D0Omtx6NhUN9QPoE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Aarhus Maskinmesterskole"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Aarhus School of Marine and Technical Engineering"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aams.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aams.dk/en-GB/Home.aspx"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Aarhus Maskinmesterskole"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Aarhus School of Marine and Technical Engineering"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://stage.qmplus.qmul.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:its-helpdesk@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Services helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:moodle-support@ulcc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Moodle Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://stage.qmplus.qmul.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-07-13T08:25:32Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Queen Mary and Westfield College, University of London: Staging QMPlus"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qmul.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Queen Mary and Westfield College, University of London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://stage.qmplus.qmul.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://stage.qmplus.qmul.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://stage.qmplus.qmul.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://stage.qmplus.qmul.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://stage.qmplus.qmul.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://stage.qmplus.qmul.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJALKxAgePakkwMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\n\t\t\t\t\t\tBAMTF3N0YWdlLnFtcGx1cy5xbXVsLmFjLnVrMB4XDTEyMDYwNzE0NTMzMFoXDTIy\n\t\t\t\t\t\tMDYwNTE0NTMzMFowIjEgMB4GA1UEAxMXc3RhZ2UucW1wbHVzLnFtdWwuYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQD9ivAZ6UNVeUCEdXQpkMrd\n\t\t\t\t\t\t4Vlqxd5DYH1EqZmXDyS7aPuHGCf0TRwe4f/gwrjW9pufpcvJdWIx5xVA050CO9x1\n\t\t\t\t\t\t5tIaRoGpwGLpi57IBQEYjPpjocF/h8TsrG+/lqD2goznu4jVmNSqFd23uXQd93mE\n\t\t\t\t\t\tAFWaqoUWc9PN14pwMfqeChg6R9EaBdmtjBPVjX+Nc2NWDvM5oQv8XlFO1BnA+tIt\n\t\t\t\t\t\teyWFAiTs7YlbvMoc40XUjuIfZb6JNklpI5zLwR3+aMeEm02TXfRZeNtJx59kgTf+\n\t\t\t\t\t\twehHjLurwoAmzsq9+YUxfvxZrL+mWyRTz15x4LwxAL9uTUh7dWE5/Zb7DDbPsrkt\n\t\t\t\t\t\tAgMBAAGjRTBDMCIGA1UdEQQbMBmCF3N0YWdlLnFtcGx1cy5xbXVsLmFjLnVrMB0G\n\t\t\t\t\t\tA1UdDgQWBBSFCiz/saHI8JKRz6iF3iUjGLJtCDANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\t7Szt9KT41JWd/xxX1MHzpAvnoBM4mX+1d1s2YjJDVmKiojZ6ugbcLf0b/su3Z/Pa\n\t\t\t\t\t\tzWqW0DTHT2M9tlzcsO58Jom2e5KHlYi6JW53OdJt5BLkeAg/2pFxwWpLH08aa3JL\n\t\t\t\t\t\tYY3BYCduezz4W6bFDKuO77ItOso7AA3ht0YitAcLqbQrRwcw2wWMCXFbL8xPIeeV\n\t\t\t\t\t\tc4YFVQd6DXqsHBJR5oh7qENv5xR0T09lAOq+MJxeLw5SPODqAUTHj+vQWffkxX3L\n\t\t\t\t\t\tikizbM30rhdKp+IkmknYtk/BD69rNZRebjpTLH2VXDqgfF5/Ebg9DV7HZA2x4um5\n\t\t\t\t\t\tKM/oUrQbIhU0GvL2LaL7rQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://stage.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://stage.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://stage.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://stage.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://stage.qmplus.qmul.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://stage.qmplus.qmul.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.climatescience.cam.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:falcon-support@ucs.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Falcon Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:falcon-support@ucs.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Falcon Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.climatescience.cam.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-03-05T15:47:46Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cambridge Centre for Climate Science"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.climatescience.cam.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Cambridge"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.climatescience.cam.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.climatescience.cam.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.climatescience.cam.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.climatescience.cam.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.climatescience.cam.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.climatescience.cam.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.climatescience.cam.ac.uk/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.climatescience.cam.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.climatescience.cam.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAOB8D/FajzX8MA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHd3dy1mYWxjb24uY3N4LmNhbS5hYy51azAeFw0xMDAxMTgxMTAwMDdaFw0y\n\t\t\t\t\t\tMDAxMTYxMTAwMDdaMCMxITAfBgNVBAMTGHd3dy1mYWxjb24uY3N4LmNhbS5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKpU2AuemKJSIeDmgjkZ\n\t\t\t\t\t\ttPgKaPPkM5CKu3QUHm5JzmtnG3UFMxbOumt6sxWWF72ceXQNPgBNGqFI/sFdaCIo\n\t\t\t\t\t\tHxZj+Z2i+k7/IVXhc4wjs72YUfrjvTMDhHHzndm3KkJS8imsIYQ8/bBnJEF93zVJ\n\t\t\t\t\t\tgPYTrX1C8JxqF/wfY/XCGbEqHgJtqDrSEvK+vLF7LaYI4oTotZOg/vhN7uwaEa7n\n\t\t\t\t\t\tGU2+bKuhcAL+rolEM6sbdrQAj3KarTafacfh9IiAclzyOQTA6pfjFWrucNIuWXc4\n\t\t\t\t\t\tYhaEPyOMubMsp+0eXZAwEPTJ61x+nQZd3UAf7Rm5v7agrzRAdqdwpnqb4yyprJlI\n\t\t\t\t\t\t+lkCAwEAAaNGMEQwIwYDVR0RBBwwGoIYd3d3LWZhbGNvbi5jc3guY2FtLmFjLnVr\n\t\t\t\t\t\tMB0GA1UdDgQWBBTz/ES/EvNaSsqqXUxLuIFc9YHi/TANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAAvFTJS2L6StZuqKA935AD3bBOHe5pg+LCF6ydHdTuyWEJYIWBRJ1WXsKMyaG\n\t\t\t\t\t\tyvdlX60XziJARq2UiYxt4yRjuGLAjQl9kNdrlqeb2AJFnA5E1Mt56FtzPiwu2zrC\n\t\t\t\t\t\tTQlklC4Xfie1Yaw2kEVO2vAoRfg9bgSBfyvFC4oR3vCery3Z687oCeQqDp7LPRcn\n\t\t\t\t\t\t+k5qQD8pout57IYzwyo7GPeVkYEPb3GO2KYmoENlDR/xah2VcsTZF7aIsMBFxaPv\n\t\t\t\t\t\tO+oqrQcnQXTviY9yWLbAlSrPPqGNYDxayVHn+zDSO4scLlOoqZJ8iC5NboNKqFyB\n\t\t\t\t\t\tRsenNm/aXp0wIU+jHVmi/GAPCQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.climatescience.cam.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.climatescience.cam.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.climatescience.cam.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.climatescience.cam.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.climatescience.cam.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.climatescience.cam.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.climatescience.cam.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.climatescience.cam.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.climatescience.cam.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.climatescience.cam.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cafe.accamargo.org.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bruno Alencar"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "infra@accamargo.org.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.accamargo.org.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID3jCCAsYCAQAwDQYJKoZIhvcNAQEFBQAwgbQxIjAgBgNVBAoTGUEuQy5DYW1h\ncmdvIENhbmNlciBDZW50ZXIxCzAJBgNVBAsTAlRJMSUwIwYJKoZIhvcNAQkBFhZp\nbmZyYUBhY2NhbWFyZ28ub3JnLmJyMRIwEAYDVQQHEwlTYW8gUGF1bG8xEjAQBgNV\nBAgTCVNhbyBQYXVsbzELMAkGA1UEBhMCQlIxJTAjBgNVBAMTHGFjY2FmZS5jb3Jw\nLmFjY2FtYXJnby5vcmcuYnIwHhcNMTQwNzIyMTgwOTU4WhcNMTcwNzIxMTgwOTU4\nWjCBtDEiMCAGA1UEChMZQS5DLkNhbWFyZ28gQ2FuY2VyIENlbnRlcjELMAkGA1UE\nCxMCVEkxJTAjBgkqhkiG9w0BCQEWFmluZnJhQGFjY2FtYXJnby5vcmcuYnIxEjAQ\nBgNVBAcTCVNhbyBQYXVsbzESMBAGA1UECBMJU2FvIFBhdWxvMQswCQYDVQQGEwJC\nUjElMCMGA1UEAxMcYWNjYWZlLmNvcnAuYWNjYW1hcmdvLm9yZy5icjCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBALY7jcZgj0WKZ4s0bkWLRwBKf7hOkYT9\nm4lQhe2Wg4nN6LiBEmcSbHdCOgFD/rpz6GptT0Z6nApwTmdIHsn7vzK+Jd9bbh/j\nz7fcvsk+r94PSrOLoRz9R77jq58k5OnEcAIZiz5YSWg9l5r9n7+YpMsIA8sARrVe\nEFjcqnXUcC24HfPlppXpUF03CROWXjuwUWMelVeFpAS2UKD1O01S9ch12PFqz0Tj\n5owqgBT9Vcn6hv6hfN8ogU6Ob7lyzgrVmlIFeAVfx58FbpW2z3tKSCAFXh1AdzsA\nTgABmcYBaMDTaOY7NsNBGQVIIhSalGPxpNEbJV+9YLg/c1KTszCSV5ECAwEAATAN\nBgkqhkiG9w0BAQUFAAOCAQEAk0bRv4nd7W6HTFmSGEsKPPM2ZKY8/c1EiZT283Gz\nVO27NGBym9ZhTv9bHftimmoMSvlOAdXILfwJsGdbFFh+B8s+7VDmbx1pRnq1kimU\nKaAy2jaC+ci8zFK7jN4Q6KgqzC1zZs8BTE8DCgEvXQM2dTIVr72bEPttKOCCbNIs\n9w0dgvDMZINHqX9D7fe3NBLD+3qT6huDlE2ZNwSyc+X8+u2eF2hnNzGpPEhXx/in\nWPQ16QixB5B6rtqjbR5194ASzPcn83Nq3+yCt0kYxyBx2zsH8TS1gkkMWhH+ryVi\nqityQ40gZWuWRd8gfBbCoN4OslA5NohCqtIm+5YasOdyzw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "org.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.accamargo.org.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.accamargo.org.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.accamargo.org.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.accamargo.org.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.accamargo.org.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.accamargo.org.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.accamargo.org.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.accamargo.org.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "org.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.accamargo.org.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.accamargo.org.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ACC - A.C.Camargo Cancer Center"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ACC - A.C.Camargo Cancer Center"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ACC - A.C.Camargo Cancer Center"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ACC - A.C.Camargo Cancer Center"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID3jCCAsYCAQAwDQYJKoZIhvcNAQEFBQAwgbQxIjAgBgNVBAoTGUEuQy5DYW1h\ncmdvIENhbmNlciBDZW50ZXIxCzAJBgNVBAsTAlRJMSUwIwYJKoZIhvcNAQkBFhZp\nbmZyYUBhY2NhbWFyZ28ub3JnLmJyMRIwEAYDVQQHEwlTYW8gUGF1bG8xEjAQBgNV\nBAgTCVNhbyBQYXVsbzELMAkGA1UEBhMCQlIxJTAjBgNVBAMTHGFjY2FmZS5jb3Jw\nLmFjY2FtYXJnby5vcmcuYnIwHhcNMTQwNzIyMTgwOTU4WhcNMTcwNzIxMTgwOTU4\nWjCBtDEiMCAGA1UEChMZQS5DLkNhbWFyZ28gQ2FuY2VyIENlbnRlcjELMAkGA1UE\nCxMCVEkxJTAjBgkqhkiG9w0BCQEWFmluZnJhQGFjY2FtYXJnby5vcmcuYnIxEjAQ\nBgNVBAcTCVNhbyBQYXVsbzESMBAGA1UECBMJU2FvIFBhdWxvMQswCQYDVQQGEwJC\nUjElMCMGA1UEAxMcYWNjYWZlLmNvcnAuYWNjYW1hcmdvLm9yZy5icjCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBALY7jcZgj0WKZ4s0bkWLRwBKf7hOkYT9\nm4lQhe2Wg4nN6LiBEmcSbHdCOgFD/rpz6GptT0Z6nApwTmdIHsn7vzK+Jd9bbh/j\nz7fcvsk+r94PSrOLoRz9R77jq58k5OnEcAIZiz5YSWg9l5r9n7+YpMsIA8sARrVe\nEFjcqnXUcC24HfPlppXpUF03CROWXjuwUWMelVeFpAS2UKD1O01S9ch12PFqz0Tj\n5owqgBT9Vcn6hv6hfN8ogU6Ob7lyzgrVmlIFeAVfx58FbpW2z3tKSCAFXh1AdzsA\nTgABmcYBaMDTaOY7NsNBGQVIIhSalGPxpNEbJV+9YLg/c1KTszCSV5ECAwEAATAN\nBgkqhkiG9w0BAQUFAAOCAQEAk0bRv4nd7W6HTFmSGEsKPPM2ZKY8/c1EiZT283Gz\nVO27NGBym9ZhTv9bHftimmoMSvlOAdXILfwJsGdbFFh+B8s+7VDmbx1pRnq1kimU\nKaAy2jaC+ci8zFK7jN4Q6KgqzC1zZs8BTE8DCgEvXQM2dTIVr72bEPttKOCCbNIs\n9w0dgvDMZINHqX9D7fe3NBLD+3qT6huDlE2ZNwSyc+X8+u2eF2hnNzGpPEhXx/in\nWPQ16QixB5B6rtqjbR5194ASzPcn83Nq3+yCt0kYxyBx2zsH8TS1gkkMWhH+ryVi\nqityQ40gZWuWRd8gfBbCoN4OslA5NohCqtIm+5YasOdyzw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ACC - A.C.Camargo Cancer Center"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ACC - A.C.Camargo Cancer Center"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.accamargo.org.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.accamargo.org.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ACC - A.C.Camargo Cancer Center"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ACC - A.C.Camargo Cancer Center"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://tophat.com/sso/shibboleth/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@tophat.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Green"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:brennen@tophat.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brennan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jones"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:josh@tophat.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Josh"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://tophat.com/sso/shibboleth/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-03-14T12:45:16Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Top Hat"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tophat.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Top Hat Monocle"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://app.tophat.com/sso/shibboleth/slo",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Top Hat Classroom Response System"
                  }
                ],
                "logo": [
                  {
                    "text": "https://s3.amazonaws.com/thm-corporate/tophat-logo-blue.png",
                    "height": "30",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "110"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Top Hat"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBTCCAe2gAwIBAgIJAJBdLHPlzYOPMA0GCSqGSIb3DQEBBQUAMBUxEzARBgNV\n\t\t\t\t\t\tBAMTCnRvcGhhdC5jb20wHhcNMTQxMDE2MTg0OTU4WhcNMjQxMDEzMTg0OTU4WjAV\n\t\t\t\t\t\tMRMwEQYDVQQDEwp0b3BoYXQuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAtJvhoZ3zRb7UbxCE+NNCxTtUMwunQPa06R+JmvuYZdSOGwPW6W5ff3NE\n\t\t\t\t\t\tJm7S/EzcnXNeQLEdSombqATN5gOIo4vFfTpwBW/P5syvc0EBphXvoqkLeJcPrMm3\n\t\t\t\t\t\tCR0QMerSe7i8xMXc/2o80aKHw5Cl99/ujvamrF6B+n4LbSi/Eo78G9JGIEFhOYYz\n\t\t\t\t\t\t3UsGrm3b+pS9tn9NQXoCAL/YfUc70LV+CdKrxtW/psQMGjmbvR3saSnVoimyEcUq\n\t\t\t\t\t\tdOhpyfYnVjNZsIANE/PoG4TYYU0zetTao5PD47mRIQ81FNxlXz2fg2LCzb8h06CU\n\t\t\t\t\t\tRi4NFAI7hBlZpQe+WhptkBa+gt5qgwIDAQABo1gwVjA1BgNVHREELjAsggp0b3Bo\n\t\t\t\t\t\tYXQuY29thh51cm46bWFjZTp1bXUuc2U6c2FtbDp0b3BoYXQ6c3AwHQYDVR0OBBYE\n\t\t\t\t\t\tFEN/h+ezcP/7CqNsqgpTxRWvbwTNMA0GCSqGSIb3DQEBBQUAA4IBAQCQmBmsKvMr\n\t\t\t\t\t\t/PZVvszcGM9Ea/PulcPp0BbAHAdjaiFiw0SQkyaEY9fLi8yWOb/Gy0TVAGLxwBY7\n\t\t\t\t\t\tdm6VZnVPxhvxL0RBswpJxs1XK4LYL0oj0ZHCHdQRktOBmuZ/rfkVheEBv8ek0sy5\n\t\t\t\t\t\tshomaKJuTBEQd06ZeRZl71IUn6ytyUAp1ZCw3+bKh0cYYNzEYsd5PEq7yaG0tNTR\n\t\t\t\t\t\tZ1eDZ10E6yP+f7eCFegs9qutMyxLhvefdGt2t4GvK4kbhjBRDAQwrAnXMixVkUkr\n\t\t\t\t\t\tDsQPDtPsT1ONS2VZMmtQir8qUybJV5BfREoepLCOMIAbCRrRM0dQKK9C0HVXsNe3\n\t\t\t\t\t\tF3yzDCsg02aQ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBTCCAe2gAwIBAgIJAJBdLHPlzYOPMA0GCSqGSIb3DQEBBQUAMBUxEzARBgNV\n\t\t\t\t\t\tBAMTCnRvcGhhdC5jb20wHhcNMTQxMDE2MTg0OTU4WhcNMjQxMDEzMTg0OTU4WjAV\n\t\t\t\t\t\tMRMwEQYDVQQDEwp0b3BoYXQuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAtJvhoZ3zRb7UbxCE+NNCxTtUMwunQPa06R+JmvuYZdSOGwPW6W5ff3NE\n\t\t\t\t\t\tJm7S/EzcnXNeQLEdSombqATN5gOIo4vFfTpwBW/P5syvc0EBphXvoqkLeJcPrMm3\n\t\t\t\t\t\tCR0QMerSe7i8xMXc/2o80aKHw5Cl99/ujvamrF6B+n4LbSi/Eo78G9JGIEFhOYYz\n\t\t\t\t\t\t3UsGrm3b+pS9tn9NQXoCAL/YfUc70LV+CdKrxtW/psQMGjmbvR3saSnVoimyEcUq\n\t\t\t\t\t\tdOhpyfYnVjNZsIANE/PoG4TYYU0zetTao5PD47mRIQ81FNxlXz2fg2LCzb8h06CU\n\t\t\t\t\t\tRi4NFAI7hBlZpQe+WhptkBa+gt5qgwIDAQABo1gwVjA1BgNVHREELjAsggp0b3Bo\n\t\t\t\t\t\tYXQuY29thh51cm46bWFjZTp1bXUuc2U6c2FtbDp0b3BoYXQ6c3AwHQYDVR0OBBYE\n\t\t\t\t\t\tFEN/h+ezcP/7CqNsqgpTxRWvbwTNMA0GCSqGSIb3DQEBBQUAA4IBAQCQmBmsKvMr\n\t\t\t\t\t\t/PZVvszcGM9Ea/PulcPp0BbAHAdjaiFiw0SQkyaEY9fLi8yWOb/Gy0TVAGLxwBY7\n\t\t\t\t\t\tdm6VZnVPxhvxL0RBswpJxs1XK4LYL0oj0ZHCHdQRktOBmuZ/rfkVheEBv8ek0sy5\n\t\t\t\t\t\tshomaKJuTBEQd06ZeRZl71IUn6ytyUAp1ZCw3+bKh0cYYNzEYsd5PEq7yaG0tNTR\n\t\t\t\t\t\tZ1eDZ10E6yP+f7eCFegs9qutMyxLhvefdGt2t4GvK4kbhjBRDAQwrAnXMixVkUkr\n\t\t\t\t\t\tDsQPDtPsT1ONS2VZMmtQir8qUybJV5BfREoepLCOMIAbCRrRM0dQKK9C0HVXsNe3\n\t\t\t\t\t\tF3yzDCsg02aQ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://app.tophat.com/sso/shibboleth/acs",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Top Hat"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp-test.wmin.ac.uk/idp/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it-servicedesk@westminster.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "FixIT"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@proofid.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ProofID"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-test.wmin.ac.uk/idp/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-07T09:38:05Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUO4Z4TGad3zOqf20WubZJx3X2ObgwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHjEcMBoGA1UEAwwTaWRwLXRlc3Qud21pbi5hYy51azAeFw0xNTAzMzAxMDM2\n\t\t\t\t\t\tMzdaFw0zNTAzMzAxMDM2MzdaMB4xHDAaBgNVBAMME2lkcC10ZXN0LndtaW4uYWMu\n\t\t\t\t\t\tdWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCAVH3CIndACrrHHL1i\n\t\t\t\t\t\tTFzRPgE7dMzkdy4PkKi7FN16c90JN0GjtZkPwDerouxDLHWhzrjbwYLmAezRJDCE\n\t\t\t\t\t\tdsR2p59gNxDeM/0qe1F2K/o1UHlSazvoR1hsBHUJVPkGGah+KyI8p7sAK+4koQvS\n\t\t\t\t\t\tRoCrbNs0XZjPfG66e7QlWMnsSx1m2duQcp6m8mUtRZNLxZ14Q/2OVM38Ym3v5cyw\n\t\t\t\t\t\tMz42Ty0sFj3ywaDp7NaU98FqpdunRn/MZjZIHg1sXtdvxeLuhiCchPl1JcUXQm5+\n\t\t\t\t\t\tznqS+VWcG1/Dzu1ldk4VYMLFOpIRAvFM3v6y3Qvopt4CswMfSgJSvn/EGu3MiDjk\n\t\t\t\t\t\t5WoHAgMBAAGjbTBrMB0GA1UdDgQWBBQpHLN33OnCZT8LJuWmDca/QEKgSDBKBgNV\n\t\t\t\t\t\tHREEQzBBghNpZHAtdGVzdC53bWluLmFjLnVrhipodHRwczovL2lkcC10ZXN0Lndt\n\t\t\t\t\t\taW4uYWMudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEFBQADggEBAGjR1lvn\n\t\t\t\t\t\tmipDI/6XMFVHHH7z++YN2qzI1a/LvV1G7cZ7b8dprmPDg0DggzrKC7T1EceWKEF+\n\t\t\t\t\t\tNWIWh5Kcu0sO6uwA515FrjuvRoVGFHq7LT0LaWBmpLHYxxX6RIiRuRxsbHDqTXPp\n\t\t\t\t\t\tz2tCp10b38xJ3QxKgOxc8TCd2jccTiaEUDwePu6N3R4h3X8z5+pq+LtVucEvWjfy\n\t\t\t\t\t\tjTXJc8V4EoN98r0wsyFC21jc9D0aOM+ZpE1JznXFFnOdqiQZuWa9ckpkymJ0BpWM\n\t\t\t\t\t\tRMBgwrAipmgIcDLOeMl+oGrjXtnN+8bFdNpaf+h+VHa3y27tX/6HhP4/Fo+qhOO+\n\t\t\t\t\t\t6/Qdq15NW15ehGY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wmin.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-test.wmin.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-test.wmin.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-test.wmin.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-test.wmin.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-test.wmin.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-test.wmin.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-test.wmin.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-test.wmin.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-test.wmin.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-test.wmin.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-test.wmin.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wmin.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUO4Z4TGad3zOqf20WubZJx3X2ObgwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHjEcMBoGA1UEAwwTaWRwLXRlc3Qud21pbi5hYy51azAeFw0xNTAzMzAxMDM2\n\t\t\t\t\t\tMzdaFw0zNTAzMzAxMDM2MzdaMB4xHDAaBgNVBAMME2lkcC10ZXN0LndtaW4uYWMu\n\t\t\t\t\t\tdWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCAVH3CIndACrrHHL1i\n\t\t\t\t\t\tTFzRPgE7dMzkdy4PkKi7FN16c90JN0GjtZkPwDerouxDLHWhzrjbwYLmAezRJDCE\n\t\t\t\t\t\tdsR2p59gNxDeM/0qe1F2K/o1UHlSazvoR1hsBHUJVPkGGah+KyI8p7sAK+4koQvS\n\t\t\t\t\t\tRoCrbNs0XZjPfG66e7QlWMnsSx1m2duQcp6m8mUtRZNLxZ14Q/2OVM38Ym3v5cyw\n\t\t\t\t\t\tMz42Ty0sFj3ywaDp7NaU98FqpdunRn/MZjZIHg1sXtdvxeLuhiCchPl1JcUXQm5+\n\t\t\t\t\t\tznqS+VWcG1/Dzu1ldk4VYMLFOpIRAvFM3v6y3Qvopt4CswMfSgJSvn/EGu3MiDjk\n\t\t\t\t\t\t5WoHAgMBAAGjbTBrMB0GA1UdDgQWBBQpHLN33OnCZT8LJuWmDca/QEKgSDBKBgNV\n\t\t\t\t\t\tHREEQzBBghNpZHAtdGVzdC53bWluLmFjLnVrhipodHRwczovL2lkcC10ZXN0Lndt\n\t\t\t\t\t\taW4uYWMudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEFBQADggEBAGjR1lvn\n\t\t\t\t\t\tmipDI/6XMFVHHH7z++YN2qzI1a/LvV1G7cZ7b8dprmPDg0DggzrKC7T1EceWKEF+\n\t\t\t\t\t\tNWIWh5Kcu0sO6uwA515FrjuvRoVGFHq7LT0LaWBmpLHYxxX6RIiRuRxsbHDqTXPp\n\t\t\t\t\t\tz2tCp10b38xJ3QxKgOxc8TCd2jccTiaEUDwePu6N3R4h3X8z5+pq+LtVucEvWjfy\n\t\t\t\t\t\tjTXJc8V4EoN98r0wsyFC21jc9D0aOM+ZpE1JznXFFnOdqiQZuWa9ckpkymJ0BpWM\n\t\t\t\t\t\tRMBgwrAipmgIcDLOeMl+oGrjXtnN+8bFdNpaf+h+VHa3y27tX/6HhP4/Fo+qhOO+\n\t\t\t\t\t\t6/Qdq15NW15ehGY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Westminster - Test"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.westminster.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Westminster"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://osms.maps-ict.com",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lynch"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:declan.lynch@sherston.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Declan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lynch"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:declan.lynch@sherston.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Declan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://osms.maps-ict.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-12-02T15:37:46Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Sherston Subscription Service"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tagassessment.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Sherston Software Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://osms.maps-ict.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://osms.maps-ict.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://osms.maps-ict.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://osms.maps-ict.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://osms.maps-ict.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "logo": [
                  {
                    "text": "https://osms.maps-ict.com/sherston_logo.png",
                    "height": "170",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "289"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sherston Subscription Service"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://osms.maps-ict.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://osms.maps-ict.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAJyVBMODdwzEMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\n\t\t\t\t\t\tBAMTD2lwLTEwLTMyLTE5LTEwNjAeFw0xMzExMjgxNjQ3NDZaFw0yMzExMjYxNjQ3\n\t\t\t\t\t\tNDZaMBoxGDAWBgNVBAMTD2lwLTEwLTMyLTE5LTEwNjCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBANTrpuu5ybIeAyxaWJnZxMplwrKL/mgJny/7/nSMJwsg\n\t\t\t\t\t\tFJ3StMih3uGlOcpjAryS1LgwRZf8P/Y9zsUkT6OSsytGhBbJr9z8H4bMK3ADfDAm\n\t\t\t\t\t\t/kM1A1t57z4aw6d/N8MHsJxyXTjVq+9xx9fpDuq3G+ypWotiOhhZ5N8MbMH6WOwN\n\t\t\t\t\t\tcPYZv5/kXhuLwJvGgEH8rNjzGI0eIeNJg2OMtuZ3PQG7l+Lzy2b0T4d9Zhg22vJt\n\t\t\t\t\t\t5k2ErBjDWW5Q2sdAjYv64lZJMEiaWlXmxi9TU/N4TaABd8FUKOAOng109uAkoDKX\n\t\t\t\t\t\tJ8dUJJI7qxQsp4hMlPzk6VFutijpVdK/YFu3BEa2Ot0CAwEAAaM9MDswGgYDVR0R\n\t\t\t\t\t\tBBMwEYIPaXAtMTAtMzItMTktMTA2MB0GA1UdDgQWBBR2v7XhnQu0Ul9J+aahR2Zw\n\t\t\t\t\t\tGvD2ajANBgkqhkiG9w0BAQUFAAOCAQEAW3w9Vga1Y1e+dGRpO91PdxEPfbb46/XK\n\t\t\t\t\t\tU3G9ljGdtXj1cC+TRnzFWJefIafn29U2ZMDzeofZeohOxyJhPgqo5Slq7c8DOamm\n\t\t\t\t\t\tHk4NjPmAf5g8UkuROx6qIYBkj7nlJY89bGibNgAUS0k77W8+i9sDnEA7+GiXCLyS\n\t\t\t\t\t\txWZrqNLhfdUH4yPJ+++IRfG7Ov4gg6lLjpHtah6YXmB30VFQl8rDc2XHr/O/q64w\n\t\t\t\t\t\tB3tRPkqeEqxBP0OMhXB4BU8EohPtO02B6PDd632lslHonLb/NXlmSzMAprmsxToO\n\t\t\t\t\t\tLdmvhFHg3oy+klnOhP9enbBVBy75/UO4+mJ0gfHhoQjjKw4/CmdTWQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://osms.maps-ict.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://osms.maps-ict.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://osms.maps-ict.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://osms.maps-ict.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://osms.maps-ict.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://osms.maps-ict.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://qml.corefacilities.org/account/saml/qml",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ilabsolutions.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:integrations_id@ilabsolutions.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ID Integration support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://qml.corefacilities.org/account/saml/qml",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-12-16T11:59:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "iLab Solutions"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ilabsolutions.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "iLab Solutions, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "authn_requests_signed": "false",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDezCCAmOgAwIBAgIJAJ2ckmy8lsPeMA0GCSqGSIb3DQEBBQUAMFQxCzAJBgNV\n\t\t\t\t\t\tBAYTAlVTMRYwFAYDVQQIDA1NYXNzYWNodXNldHRzMQ8wDQYDVQQHDAZCb3N0b24x\n\t\t\t\t\t\tHDAaBgNVBAoME2lMYWIgU29sdXRpb25zLCBMTEMwHhcNMTMxMjExMTUyNTA3WhcN\n\t\t\t\t\t\tMjQxMjExMTUyNTA3WjBUMQswCQYDVQQGEwJVUzEWMBQGA1UECAwNTWFzc2FjaHVz\n\t\t\t\t\t\tZXR0czEPMA0GA1UEBwwGQm9zdG9uMRwwGgYDVQQKDBNpTGFiIFNvbHV0aW9ucywg\n\t\t\t\t\t\tTExDMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2VPbpu2uPVmE3NDD\n\t\t\t\t\t\tE+aGuO9Zf2eLz+61ubkjuwz6ipY01oHliSId5iETSwGT3r1gJvTnpP3ndGMFq8X0\n\t\t\t\t\t\t4xcsNb2cU2ZxCZ4+GE9XFriD2eskrfCuuBX6bKeW/yYeMNVoSBF/2YeEC+5kZ+2y\n\t\t\t\t\t\tB7neQsUFKpB2J4kO7TlFKDAa0aj+ani0TOWdjejcYrZWNfR74Bft3IOFWxvapYvZ\n\t\t\t\t\t\t9k6LMU/VouCVM8TqfmmTkwHemaB2bdk5rgaZpV3UgsiO5yXS9CDLlrijQSb95I1l\n\t\t\t\t\t\tQZ2hMtbDu70xKoVOAbMhYcuVZppOObeketCXOoN4MIWEn/dYPhwHsWnGR9sOZhaB\n\t\t\t\t\t\t9PVJzwIDAQABo1AwTjAdBgNVHQ4EFgQUfo3FkNz5UDtfW6QR5ostJDL7z1owHwYD\n\t\t\t\t\t\tVR0jBBgwFoAUfo3FkNz5UDtfW6QR5ostJDL7z1owDAYDVR0TBAUwAwEB/zANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAF4BJ6QX/Y6WV0rMGZYmydg/vE8SgtVB++/rGMfohXW6P\n\t\t\t\t\t\ts/NEKrzOdIt/Nhannnn77RrjujDLkz5wp3u5zabjffHk/bPqP9yucOBMlIdyggKA\n\t\t\t\t\t\tSQhzrFygr1kgA2JmUYrmrlKPSSrjfTGJj33qgbo23hzioLULaFFSbvEcZdP8x5lG\n\t\t\t\t\t\tx8UndDxLcOxRMdxGTdMTu4q/TMnJlugnOe5YmIhg9jbYMwwm8JYVJ86llO5piiUv\n\t\t\t\t\t\tYVcHQX0UCb4Iw4FoEKIzAsQW2aIQnE39DD7410/7YUzwCGVn6F6TGQuglZjGrTWe\n\t\t\t\t\t\tITzWFNwFKHtFqy1whxR7MarmC24an1bJCi/yQDHxDQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://qml.corefacilities.org/account/saml/qml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://qml-testing.ilabsolutions.com/account/saml/qml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://qmul.corefacilities.org/account/saml/qml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://student.test.grayzone.ladok.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://student.test.grayzone.ladok.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.test.grayzone.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.test.grayzone.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.test.grayzone.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.test.grayzone.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.test.grayzone.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://student.test.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://student.test.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://student.test.grayzone.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok student.test.grayzone.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok student.test.grayzone.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://student.test.grayzone.ladok.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "student.test.grayzone.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIJAOowkJXVqISdMA0GCSqGSIb3DQEBCwUAMCkxJzAlBgNV\nBAMTHnN0dWRlbnQudGVzdC5ncmF5em9uZS5sYWRvay5zZTAeFw0xNjAzMjMwODM2\nMTVaFw0yNjAzMjEwODM2MTVaMCkxJzAlBgNVBAMTHnN0dWRlbnQudGVzdC5ncmF5\nem9uZS5sYWRvay5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOGU\nNKa5sTalFItChmOxO4Z0yv6bxxgjLl2ocYUdQ1jA9Kh6YU9REbKwsQEmFXzp4J2f\ndG2oWf2Jdf0mjBohQY/GAr6Lgy+2gtyc46G0Rz9mDgH4WuGN+wGeSJ6PQmbVO6pZ\nlpSlFdes3lmxS50aMEcO8HefZjb59UEJXzlzVNHKpX3pi684WvpsLa8h42lLLorZ\nQlknnFZP6H+ANBJ1K70T1/mknGqET791EU5KcK+EAW7eLJxuiJtEFbT04Ax7heSY\nPs3eg7i3QrL/Sah2aWp1JcBRJ0fzAZqAPgmD9wW9jI4PrBAaLm6Aginb4jy8IvaO\nCFZC+5HIGuViHHX7iz8CAwEAAaN7MHkwWAYDVR0RBFEwT4Iec3R1ZGVudC50ZXN0\nLmdyYXl6b25lLmxhZG9rLnNlhi1odHRwczovL3N0dWRlbnQudGVzdC5ncmF5em9u\nZS5sYWRvay5zZS9ndWktc3AwHQYDVR0OBBYEFCnD8SZEql3o+hm3K4Q7AKxag9yy\nMA0GCSqGSIb3DQEBCwUAA4IBAQADTKXCoXrQxJz7ZWVOqLhTLAroHZBNO2iB9gqO\nBpyHScmT424Y91yaGgNN9hIY27v2NvkYrsgkB4IkwH96xpKwthQlSIQHqjk3xnOU\nHWcj4hLCvA2TLWNARRRcUuVJWaX9bqUZVdkySe3z/bh6t+pWTGVCcM+7STDGx5ai\nkC++gEkI/T09nbYiBFV6+WNM41z+DyhO9yGbKj6nhJqFo4A0jsw8Im8xoN+r969R\nZq8CVQyNB59hRQFosEp1CYTocOE8N6apt6JeuZBIGEnpjxQIQ7D++/GHisdrqyVS\n3cs/hJKNAfqLA4JHw6hRIEVyLVvBbnbuEhWkPDhXcWl94OfN"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=student.test.grayzone.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.test.grayzone.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.test.grayzone.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.test.grayzone.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.test.grayzone.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.test.grayzone.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.test.grayzone.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://student.test.grayzone.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://student.test.grayzone.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://student.test.grayzone.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idpr.tem-tsp.eu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "infomatique@tem-tsp.eu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idpr.tem-tsp.eu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-02-26T10:38:50Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idpr.tem-tsp.eu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idpr.tem-tsp.eu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idpr.tem-tsp.eu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "int-evry.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "it-sudparis.eu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "telecom-em.eu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "telecom-sudparis.eu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tem-tsp.eu"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.tem-tsp.eu"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Members of Evry Campus of Institute Mines Telecom, Telecom School of Management and Telecom SudParis"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Membres du Campus d'Evry de l'Institut Mines Telecom , Telecom \u00e9cole de  Management et Telecom SudParis"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Telecom School of Management and Telecom SudParis"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Telecom SudParis et Telecom Management"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUDJP/m/P4o+WqTNaBH+2OVPzIENUwDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPaWRwci50ZW0tdHNwLmV1MB4XDTE0MDUxNDA4MzEzNVoX\nDTM0MDUxNDA4MzEzNVowGjEYMBYGA1UEAxMPaWRwci50ZW0tdHNwLmV1MIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAjLvgF4BoRYbMI6NurGUHCG7sR5po\nXoKijYZaS3RQLV+TsdSXcwOFLrdlpEQHlniiI09Jdhstm4rCuXyD5XK9ov7mUBVM\nNGPBIMEdu97DDkmymRQp6duNlfcFpjdeGUPtQmXyG9vvleUrLr/09mr9pDzA+/H8\nyHw4f6TnbnGuJ3bjoo/D1bXsSmVlDJE1Fr37kSORcD4PCumbqcIzwrrv7FamoR++\nBhxHcBMeyM8lft2shYwdXt/PD/HB1sks/JRcxcjd+JjXRgHVkyoSXMQJEkbdUdIR\nZIRk5Rc/mABlwXIzbQZPQbW7+kxcc9wFeXqZWNQviHIP54TFFSDPrbkFuQIDAQAB\no2UwYzBCBgNVHREEOzA5gg9pZHByLnRlbS10c3AuZXWGJmh0dHBzOi8vaWRwci50\nZW0tdHNwLmV1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSu7Oapkp9YZQ/+RMAq\n6lHe0V5SwDANBgkqhkiG9w0BAQUFAAOCAQEAAKsatorEb5X1Kip2lxjHMg31km9n\n8ARKM0sfr7hvnl8TidzcTXW5xYvTy/YsOrYSpc+IJgSP+UNvS1a96fcNNswDNGOv\nMfBtVkxXOSWDGJbh2xC8NymyRAzZXWym+kLABAkTWYjaXdypM+lL7femxFuxHtEs\nV8HZzsUOdJsa5F0WieIy6ENpxXqDsn54w/zLub+s+ZzJoX+jzD1ZAtOaRwmUCa8q\npqwDllq5XdnRupVTEi5djUgqxLX1GZUhxJal+nW51SoZR8exZSikJlfRhrH2lgOj\nnY0kBaFLyUpV84QgSKKM4CoxwLx+J96/Obnkk5BpUp59XyUh75DR54XUQA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAJv2l61sKf1VgzgHPgGRdmvIdBeGMA0GCSqGSIb3DQEB\nBQUAMCIxIDAeBgNVBAMTF3NoaWJpZHAxLml0LXN1ZHBhcmlzLmV1MB4XDTA4MTIw\nNDA4MjIwNFoXDTI4MTIwNDA4MjIwNFowIjEgMB4GA1UEAxMXc2hpYmlkcDEuaXQt\nc3VkcGFyaXMuZXUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDI6RH6\n/i1p4Fwnp+SxINDTFESSAByc3/a7gL4uIjufRKaraJIIuUfQ/8PQud6mTnKmTSY1\n+174E9r78IAThKTbdX0Y86JxcAlPXkaPFj3G2aMZEy7YkjxHg7bEqKmrtEmEi5ls\n69NQXJae1/v3ReBfNmsmb4lpfLqnspHzN0kM2x9ieuCUTuw6Umwc65Za9GK9J0n/\n8G370vVn9MUWcObx4qeqmeKvXK61KpAQQ5VPSrobB0NafFHq2OHb4Eq6NJmjb3xH\nQ0jNrga28YNDxKSjLF8hUolTr4bdBroqFKqqRK2DOukXsgkYgy6mTwxMbHlbzTX/\nURM7K655kFIcojcpAgMBAAGjdTBzMFIGA1UdEQRLMEmCF3NoaWJpZHAxLml0LXN1\nZHBhcmlzLmV1hi5odHRwczovL3NoaWJpZHAxLml0LXN1ZHBhcmlzLmV1L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBS6EIElOxCx56mi697wUipVtEHCsjANBgkqhkiG\n9w0BAQUFAAOCAQEAxSHKlhfZ3cHud+7KJHl0seAdQpwOC11jLz9eOsIzjPSVnPJQ\nW8rUAUA2kWKiMrmQS6t6nEpPKnx5BcySXMLi5wuvcQ40IWUnPtebALmh26KSheiE\n7rmFxq4bKZhG+ZoOqYphlDhqPoDLVpMny5jgePyq5gvLFO03a7e3DsLeH1Shf6sk\n17+1tixG41PVxw5Lfl8ODvBF2wmY/josVaZfJ3CbJoQhByUDAGH/Cf327CcefloP\nPoLdCyt/DO1aGflUdiQA/DF96+XlbGEQL7edHtEsELKz66Z8WK6fasHqNInlTe+S\nSA354+sPezlzSyImVbYaHH6naLQuFV7cmUNPOQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Telecom SudParis et Telecom Management"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tem-tsp.eu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Telecom SudParis et Telecom Management"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ens-lyon.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "admin-system@ens-lyon.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ens-lyon.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-12-03T15:29:37Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ens-lyon.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ens-lyon.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ens-lyon.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ens-lyon.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identification de la population interne globale de l'\u00e9tablissement (personnels, \u00e9tudiants, enseignants, chercheurs)."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identification de la population interne globale de l'\u00e9tablissement (personnels, \u00e9tudiants, enseignants, chercheurs)."
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAMAAAAoLQ9TAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAAZQTFRFAAAA////pdmf3QAAACZJREFUeNpiYMAAjCiALAFGRgwlQEEGJAqXCrBuslWQ4XQ0ABBgAFz4AK1qB6hoAAAAAElFTkSuQmCC",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENS de Lyon"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENS de Lyon"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUCjo8NcX8SWH/BIutFKcHBN2SANwwDQYJKoZIhvcNAQEL\nBQAwGjEYMBYGA1UEAwwPaWRwLmVucy1seW9uLmZyMB4XDTE1MTIwMjEwMTMxMloX\nDTM1MTIwMjEwMTMxMlowGjEYMBYGA1UEAwwPaWRwLmVucy1seW9uLmZyMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApvOxms3Y9j7s+QNHnBpHFqTXfzD8\n8um63VgRIy7DJRGj4edqjOPNA2BxiKm8BxfbIQOo64Wl5PW1qzpO3V5cEx0bIooy\nyf4QieheDDRHEftSZwESJymQirDchUDk+f1iMLhq7uZnajgJtNvGDfvVHy+3NGW8\n9lU+C9AzzkRjf98oXgEgHfXc7c+BF+gf5kZ9DBOolM5wUOzdMPzVrYQySMU4p66h\nM+SeWhmXSFOtyO1yQ9jZQixPQV9BjfpJwX32LCtj8H9NAH0M+MJIJNwYOEzKxmQU\nP4lZaJ6ptW5Eql9ZjHlUtY1StL4Gy08KkfbLYy5e2NwE44RhrPU7iGuxhQIDAQAB\no2UwYzAdBgNVHQ4EFgQUzQJbbWPpKODNc2ZtGjZ4YcxaKIAwQgYDVR0RBDswOYIP\naWRwLmVucy1seW9uLmZyhiZodHRwczovL2lkcC5lbnMtbHlvbi5mci9pZHAvc2hp\nYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAnc0hRfhQjJGytv8Ums5ONzxvENVe\nXkfv3vjJV21QIgULRSFELjKsAavLCFODvzzipsnI6C+Un0HxTJt4Kh+6FFIYpHWI\neTrZTRKpldD689GD4qyD0g22mDWEstMv3dmHppQg3TGs9tt4bNazO81WfcNrzWxT\nJDfCWl7BhmHXy0hYNIh68qHirU+IT58GKMnzTYIo4KllfxdStkJevmAJppBIU5NF\njuVlrAL3JgI2g34uUXn/rbAK5B8/4Hq9+vlfGi1U3mv6Dmacp7WU+QQBfF0dtBi0\nwY3Iq8Pwz25k54GWyxAA4v0Tk4DmRxsLPCbz49pdjflECO6DV24J8go58g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAJByGytG/KTvT1AUmP+sgH8R3Q90MA0GCSqGSIb3DQEB\nCwUAMBoxGDAWBgNVBAMMD2lkcC5lbnMtbHlvbi5mcjAeFw0xNTEyMDIxMDEzMTNa\nFw0zNTEyMDIxMDEzMTNaMBoxGDAWBgNVBAMMD2lkcC5lbnMtbHlvbi5mcjCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALe2F106wXVs4qCeJeSc10gjOS/8\n9pmEg6lpQGkYdGvUxjfq+2Q5zkl1N9q1VtjR2s3iidxikqbVhLT5gxd31GPw+qJu\nWyMF+S2sipUO8YcapAkdrYiLajzzTUT+PG4u4K3c19flOWnuCLfXy372lDvdeCuW\n9ITbDxlX8OqwF/A7M/cfr628/xLqcSOWNRGmr04w9OCyQtyNfGsWpCEvsuotaC9p\nyYCu/VfPqxoTLJMDy/Qa6oZZo5AKaf321BgZw1FE7zq5Qrj6g6jidQWJSLm2+tJR\nQIPhS3Ay5yGG/ahubuDV4X4SU7tliFZj7VgFjLgRzf57YEOjTud2iFylp0sCAwEA\nAaNlMGMwHQYDVR0OBBYEFExUauMbwb27yyS/CHCtKlc4sJ7JMEIGA1UdEQQ7MDmC\nD2lkcC5lbnMtbHlvbi5mcoYmaHR0cHM6Ly9pZHAuZW5zLWx5b24uZnIvaWRwL3No\naWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAB5ZuySbr1B1eHwwDN/VtWfbI4F7\niKxfJvDC/yFQ0boSBIK9dGPkTJJQjGwhq424tV+85O3qsa6MAEbs4AxSKdhKOeQk\n3X5g7kB5mTGqVgBeu1P70ghoAPHwR3ej3adVGheplD/6R2qSFX3Peti+zxryzz8X\nzMIDLN+/fiNyEL8GjkGk6AEHUrx4RgOBM/X1MyImWg5PI2AlYmocXYGC6eIMcBFH\ng/kniRNzxKUhoGI+AJN1AeEBVGTqm5OnS0rQGTtM3lHRqJXrhlm6C1Ae1RgBqn70\nzIykQBVWdeDI/sVOSYwmk9MsLXzUas8jniWGC8CTsrKyfp7HtsVctGzfNSA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ENS de Lyon"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ens-lyon.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ENS de Lyon"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibb-idp.cymoedd.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Joseph"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Chris.Joseph@cymoedd.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Joseph"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Chris.Joseph@cymoedd.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibb-idp.cymoedd.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-12-20T15:44:06Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRzCCAi+gAwIBAgIULRO7ZHUs0SJDRM62ZW0iCOUY4fQwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwIjEgMB4GA1UEAxMXc2hpYmItaWRwLmN5bW9lZGQuYWMudWswHhcNMTMxMjE4\n\t\t\t\t\t\tMTMyNTQ2WhcNMzMxMjE4MTMyNTQ2WjAiMSAwHgYDVQQDExdzaGliYi1pZHAuY3lt\n\t\t\t\t\t\tb2VkZC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALC7lzGf\n\t\t\t\t\t\tWahC/hN3q1zfeZNpJQHnhPrxXWw9VZ5IJ6YZtk88fKlV6dPp1SAUPS4bq0FcjJ/3\n\t\t\t\t\t\t8Pue5g9qIFS1q9xrBnYZzmaQhNxZRyYBc7KRQW9PaxUgGZ70GzYu1hQ/dPv4J7jd\n\t\t\t\t\t\t+Y1RjDAu/Z1WbsFFUZD3eJjmZw5OKDmQ/fWAWTMt8jMN7D8RG5Fu9/qTCpskNlPK\n\t\t\t\t\t\tCXO8md73Khe8Gj/0lrxv46e36AtFNEaU70Gta2pGAyRmYjrqEshADb8m1swPWRgH\n\t\t\t\t\t\tkL0bLR8VAw+QMu27wID1uE1InC4lGL7lYm3l98+2IN+pA0t2BGdBywBcpyKWGKL1\n\t\t\t\t\t\tGC/lpoa7+tEcwxUCAwEAAaN1MHMwUgYDVR0RBEswSYIXc2hpYmItaWRwLmN5bW9l\n\t\t\t\t\t\tZGQuYWMudWuGLmh0dHBzOi8vc2hpYmItaWRwLmN5bW9lZGQuYWMudWsvaWRwL3No\n\t\t\t\t\t\taWJib2xldGgwHQYDVR0OBBYEFGV/KcZ9mmkWUCs5f8fBqJPndCu/MA0GCSqGSIb3\n\t\t\t\t\t\tDQEBBQUAA4IBAQAVU8CEJc6dLNj3fs3Ec+hBH5YZcHHe8nMS1SZY0y8lM+os3n2/\n\t\t\t\t\t\t7HRf3c9z1sFRNW44cAcnIpAu2nRlHrE5dk/EiL473wzZQ3vRMqbQR15FKRJvgMoH\n\t\t\t\t\t\tAHSzhYPddx22CM/y9YDphk+LDM+DGVMmINO2Uc2BYnD3f+AefKfUuNCLvhXrY27R\n\t\t\t\t\t\tjhEtJPVTHnkMndHjGw4cWPO0F6Ve9Ta6ztDhdfYyUrEF2lr6qD+8ujpDMl5ngI7T\n\t\t\t\t\t\tZFTP7dCtcvT15Mg9ASKN2e6jNKbZm5YaAPPY8NJMZ88jcCvqk6t/r+qD1OU8fcFM\n\t\t\t\t\t\tlBlhGNippVT4jOwxY47G+V1Xc7aPz6F/X6Tm"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cymoedd.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibb-idp.cymoedd.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibb-idp.cymoedd.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibb-idp.cymoedd.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibb-idp.cymoedd.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibb-idp.cymoedd.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibb-idp.cymoedd.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibb-idp.cymoedd.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibb-idp.cymoedd.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibb-idp.cymoedd.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibb-idp.cymoedd.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibb-idp.cymoedd.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cymoedd.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://sam.cymoedd.ac.uk/shibbolethlogos/cymoeddlogo.png",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://sam.cymoedd.ac.uk/shibbolethlogos/cymoeddlogo.ico",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Coleg y Cymoedd"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRzCCAi+gAwIBAgIULRO7ZHUs0SJDRM62ZW0iCOUY4fQwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwIjEgMB4GA1UEAxMXc2hpYmItaWRwLmN5bW9lZGQuYWMudWswHhcNMTMxMjE4\n\t\t\t\t\t\tMTMyNTQ2WhcNMzMxMjE4MTMyNTQ2WjAiMSAwHgYDVQQDExdzaGliYi1pZHAuY3lt\n\t\t\t\t\t\tb2VkZC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALC7lzGf\n\t\t\t\t\t\tWahC/hN3q1zfeZNpJQHnhPrxXWw9VZ5IJ6YZtk88fKlV6dPp1SAUPS4bq0FcjJ/3\n\t\t\t\t\t\t8Pue5g9qIFS1q9xrBnYZzmaQhNxZRyYBc7KRQW9PaxUgGZ70GzYu1hQ/dPv4J7jd\n\t\t\t\t\t\t+Y1RjDAu/Z1WbsFFUZD3eJjmZw5OKDmQ/fWAWTMt8jMN7D8RG5Fu9/qTCpskNlPK\n\t\t\t\t\t\tCXO8md73Khe8Gj/0lrxv46e36AtFNEaU70Gta2pGAyRmYjrqEshADb8m1swPWRgH\n\t\t\t\t\t\tkL0bLR8VAw+QMu27wID1uE1InC4lGL7lYm3l98+2IN+pA0t2BGdBywBcpyKWGKL1\n\t\t\t\t\t\tGC/lpoa7+tEcwxUCAwEAAaN1MHMwUgYDVR0RBEswSYIXc2hpYmItaWRwLmN5bW9l\n\t\t\t\t\t\tZGQuYWMudWuGLmh0dHBzOi8vc2hpYmItaWRwLmN5bW9lZGQuYWMudWsvaWRwL3No\n\t\t\t\t\t\taWJib2xldGgwHQYDVR0OBBYEFGV/KcZ9mmkWUCs5f8fBqJPndCu/MA0GCSqGSIb3\n\t\t\t\t\t\tDQEBBQUAA4IBAQAVU8CEJc6dLNj3fs3Ec+hBH5YZcHHe8nMS1SZY0y8lM+os3n2/\n\t\t\t\t\t\t7HRf3c9z1sFRNW44cAcnIpAu2nRlHrE5dk/EiL473wzZQ3vRMqbQR15FKRJvgMoH\n\t\t\t\t\t\tAHSzhYPddx22CM/y9YDphk+LDM+DGVMmINO2Uc2BYnD3f+AefKfUuNCLvhXrY27R\n\t\t\t\t\t\tjhEtJPVTHnkMndHjGw4cWPO0F6Ve9Ta6ztDhdfYyUrEF2lr6qD+8ujpDMl5ngI7T\n\t\t\t\t\t\tZFTP7dCtcvT15Mg9ASKN2e6jNKbZm5YaAPPY8NJMZ88jcCvqk6t/r+qD1OU8fcFM\n\t\t\t\t\t\tlBlhGNippVT4jOwxY47G+V1Xc7aPz6F/X6Tm"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Coleg y Cymoedd"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cymoedd.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Coleg y Cymoedd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://projets-webent.univ-lille1.fr/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "WALLON Ines"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ines.wallon@univ-lille1.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://projets-webent.univ-lille1.fr/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-12-13T20:21:34Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/collaboratif"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/local"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 des Sciences Techniques de Lille 1"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-lille1.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 des Sciences Techniques de Lille 1"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://projets-webent.univ-lille1.fr/"
                  }
                ],
                "description": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Cette plate-forme  permet faire de la gestion de projets inter-\u00e9tablissements."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 of Lille 1 - projets-webent"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Lille 1 - projets-webent"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHjCCAgagAwIBAgIJANuKP33h+ACZMA0GCSqGSIb3DQEBBQUAMCgxJjAkBgNV\nBAMTHXByb2pldHMtd2ViZW50LnVuaXYtbGlsbGUxLmZyMB4XDTE0MTAzMTIwMTkz\nNloXDTI0MTAyODIwMTkzNlowKDEmMCQGA1UEAxMdcHJvamV0cy13ZWJlbnQudW5p\ndi1saWxsZTEuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC3ahHB\nITQNVrQ3DtL06800VBbSg5jrG4ZhCayO1dGJKNV4Emt07FVG2Z1zB0hRoVIes8lN\nJYorBcx/Yq58ndOoC2YUXyl5Dw2pFE2D+IeQ8dazLjrP5dgUvgZBn1X8/NYjZR9R\noWzUDqpBSViMsmV9GdRhL/dQMID2wAG9XnLmv81UZQE55U62o8712yIryrshOUoN\nNd/NzlHJWD9emh17BSISI8prU6Po+rtJ+dZlydRRNVGNVASMkbj4UvptPcmY6OIQ\nGbHz7cXCjxZuDgdM36SYBz/IWlyg8F5vpv/VbZYTPM0y7ipZDX0H8SbFi+qo+gFd\n2zW8BgCJpRPjWvqTAgMBAAGjSzBJMCgGA1UdEQQhMB+CHXByb2pldHMtd2ViZW50\nLnVuaXYtbGlsbGUxLmZyMB0GA1UdDgQWBBRsXy4YirWGf4b8wtEVd61o5xc0hTAN\nBgkqhkiG9w0BAQUFAAOCAQEAMBFk5MKCWfJpPnVXlabonKnkSeKSHc6zSnoT0yUq\ns73y86na8++jcAzQVUVnyvkmDNRTmdCXqTHrMAZ5uPz8MpTmhk1duJJSI9C/PjJK\nlOe5wvHFaMw0ShsSXCLKLOSfmWwOrikw71G8ErbD5mgF05qu/neiwPsoEtYZes7N\niHvbEQrYZkHXCJfubSWDTRGW1QN8kbWPQ1B2JplKVlcrB39KzDqnhGQM7xnVJ1op\nJ2AcE45AwuM2i0eK9IR+/f4JCJh4R/ikJii2S/HiDn1DZu4M5hexcBxk16tC7nMR\ny2eIDhGMnEJp23NcEvLJPGEHx+9XwZcSkn8aNI8r7LwaXA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHjCCAgagAwIBAgIJANuKP33h+ACZMA0GCSqGSIb3DQEBBQUAMCgxJjAkBgNV\nBAMTHXByb2pldHMtd2ViZW50LnVuaXYtbGlsbGUxLmZyMB4XDTE0MTAzMTIwMTkz\nNloXDTI0MTAyODIwMTkzNlowKDEmMCQGA1UEAxMdcHJvamV0cy13ZWJlbnQudW5p\ndi1saWxsZTEuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC3ahHB\nITQNVrQ3DtL06800VBbSg5jrG4ZhCayO1dGJKNV4Emt07FVG2Z1zB0hRoVIes8lN\nJYorBcx/Yq58ndOoC2YUXyl5Dw2pFE2D+IeQ8dazLjrP5dgUvgZBn1X8/NYjZR9R\noWzUDqpBSViMsmV9GdRhL/dQMID2wAG9XnLmv81UZQE55U62o8712yIryrshOUoN\nNd/NzlHJWD9emh17BSISI8prU6Po+rtJ+dZlydRRNVGNVASMkbj4UvptPcmY6OIQ\nGbHz7cXCjxZuDgdM36SYBz/IWlyg8F5vpv/VbZYTPM0y7ipZDX0H8SbFi+qo+gFd\n2zW8BgCJpRPjWvqTAgMBAAGjSzBJMCgGA1UdEQQhMB+CHXByb2pldHMtd2ViZW50\nLnVuaXYtbGlsbGUxLmZyMB0GA1UdDgQWBBRsXy4YirWGf4b8wtEVd61o5xc0hTAN\nBgkqhkiG9w0BAQUFAAOCAQEAMBFk5MKCWfJpPnVXlabonKnkSeKSHc6zSnoT0yUq\ns73y86na8++jcAzQVUVnyvkmDNRTmdCXqTHrMAZ5uPz8MpTmhk1duJJSI9C/PjJK\nlOe5wvHFaMw0ShsSXCLKLOSfmWwOrikw71G8ErbD5mgF05qu/neiwPsoEtYZes7N\niHvbEQrYZkHXCJfubSWDTRGW1QN8kbWPQ1B2JplKVlcrB39KzDqnhGQM7xnVJ1op\nJ2AcE45AwuM2i0eK9IR+/f4JCJh4R/ikJii2S/HiDn1DZu4M5hexcBxk16tC7nMR\ny2eIDhGMnEJp23NcEvLJPGEHx+9XwZcSkn8aNI8r7LwaXA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://projets-webent.univ-lille1.fr/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://projets-webent.univ-lille1.fr/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Universit\u00e9 de Lille 1 - projets-webent"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Universit\u00e9 of Lille 1 - projets-webent"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Cette plate-forme  permet faire de la gestion de projets inter-\u00e9tablissements."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibidp.ku.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "itcsc@ku.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Information Technology Customer Service Center"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "itsi@ku.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Information Technology System Integration"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "incommon-admin@ku.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "InCommon Admin"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibidp.ku.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.ku.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.ku.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUDA++q9rOZ3sgUuUAKIcSiarF79UwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOc2hpYmlkcC5rdS5lZHUwHhcNMTIwOTI0MjEyOTIyWhcN\nMzIwOTI0MjEyOTIyWjAZMRcwFQYDVQQDEw5zaGliaWRwLmt1LmVkdTCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMn7ncS5QpUgnr8ORzo+LaSN5LEyh+f3\n8V9hAFJwrAA23dG8qAXP5OjqzZjyqLtW38dMaoh6TZHGGbCv+R5OM2nPSzp0d798\n4348ZR86bgz7qJHabSZ6ZpjJMzr0YSrHYyBUaR39JIBcX05GZd+Vo9yoA/sxnbS9\ndGZ1Ft3kPW33b5dviC+6EniDkuM0pntQ/UzmVQgDNZzUlRfIeQiL03z6yjBfPILf\n0dGqRXMxkvrFZcDtbYp+lS+A624Mxo9xYhtysPKd+pXVVi1SxqHps8F0W9NepJQD\nZXZ48AEL6Ya9dv2OgrggOwjpXUlSK1/L3t0ilkn/VwavE8Co0KKaR9MCAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOc2hpYmlkcC5rdS5lZHWGJWh0dHBzOi8vc2hpYmlkcC5r\ndS5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFG8yu32aqrSfKvXLbhIUkzN4\nqxHDMA0GCSqGSIb3DQEBBQUAA4IBAQCCRwNh/6tHIbS3ORonmj5+4XnqXBQ7vg+x\nZIwY4SEx/6AbkYxmvjHiAr6brqe3aTlMTfp2mit7O7ucOt0T7ifmj7dDatcIUxRu\nQNVyGISL1Jqo0Cf2Hbx/oBpZG0ZfQWp1yjRQEGIY0rPmoUAXiMwS84QejZaAhYEo\n/42bNCo5JZQWtbd2KpWdLLp25NH1m8c7zBkDQ667EspTc9GZRlHHGxwcHRwVpD92\n8VSJChX0odckTkyR9tIRsamzggitwOZFBcfe5tActER8pWSwoV3TI51wWUkgHCPC\nWhg3BytKZnscULFupWbLbJq8TAVX/WfUAomsXvqpxn+N1PEybPMC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ku.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.ku.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.ku.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.ku.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.ku.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.ku.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ku.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ku.edu"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Kansas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The University of Kansas"
                  }
                ],
                "logo": [
                  {
                    "text": "https://webmedia.ku.edu/css/template2012/login/logo.png",
                    "lang": "en",
                    "height": "139",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "180"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://policy.ku.edu/IT/info-access-control-policy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUDA++q9rOZ3sgUuUAKIcSiarF79UwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOc2hpYmlkcC5rdS5lZHUwHhcNMTIwOTI0MjEyOTIyWhcN\nMzIwOTI0MjEyOTIyWjAZMRcwFQYDVQQDEw5zaGliaWRwLmt1LmVkdTCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMn7ncS5QpUgnr8ORzo+LaSN5LEyh+f3\n8V9hAFJwrAA23dG8qAXP5OjqzZjyqLtW38dMaoh6TZHGGbCv+R5OM2nPSzp0d798\n4348ZR86bgz7qJHabSZ6ZpjJMzr0YSrHYyBUaR39JIBcX05GZd+Vo9yoA/sxnbS9\ndGZ1Ft3kPW33b5dviC+6EniDkuM0pntQ/UzmVQgDNZzUlRfIeQiL03z6yjBfPILf\n0dGqRXMxkvrFZcDtbYp+lS+A624Mxo9xYhtysPKd+pXVVi1SxqHps8F0W9NepJQD\nZXZ48AEL6Ya9dv2OgrggOwjpXUlSK1/L3t0ilkn/VwavE8Co0KKaR9MCAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOc2hpYmlkcC5rdS5lZHWGJWh0dHBzOi8vc2hpYmlkcC5r\ndS5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFG8yu32aqrSfKvXLbhIUkzN4\nqxHDMA0GCSqGSIb3DQEBBQUAA4IBAQCCRwNh/6tHIbS3ORonmj5+4XnqXBQ7vg+x\nZIwY4SEx/6AbkYxmvjHiAr6brqe3aTlMTfp2mit7O7ucOt0T7ifmj7dDatcIUxRu\nQNVyGISL1Jqo0Cf2Hbx/oBpZG0ZfQWp1yjRQEGIY0rPmoUAXiMwS84QejZaAhYEo\n/42bNCo5JZQWtbd2KpWdLLp25NH1m8c7zBkDQ667EspTc9GZRlHHGxwcHRwVpD92\n8VSJChX0odckTkyR9tIRsamzggitwOZFBcfe5tActER8pWSwoV3TI51wWUkgHCPC\nWhg3BytKZnscULFupWbLbJq8TAVX/WfUAomsXvqpxn+N1PEybPMC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "http://technology.ku.edu/personal-accounts"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Kansas"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ku.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Kansas"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ig.cas.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Van\u00ed\u010dek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vanicekp@utia.cas.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ig.cas.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2016-04-06T13:47:02Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/avcr"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUW5TBaaB6SfKUuLQgLg+XaF0y3J4wDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNaWRwLmlnLmNhcy5jejAeFw0xNjA0MDUxMzI0MTlaFw0z\nNjA0MDUxMzI0MTlaMBgxFjAUBgNVBAMTDWlkcC5pZy5jYXMuY3owggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCvMAk1nwttucujjFQOSyuiS4jPK4M7TVip\n5rRgjz3M7Jmp4X0ZwYCcokPvD1iC+hQFHUiQdEGyvxPcl/3q7lKcrxFhbJUhP4yl\nZgrJysS91zx9LxEgFeNRIObSGCDLe5+EKRBoyScHhBkBrbIMVhqTjwvIBPuzqmi0\n8sew/BijdVsP9JkGfTr15qw/U6rzE3kh6HY65P5x50D2gLl8dwyAkgdbTdrwZ+Z9\nil1x9sVlVasM+//2OFdhEtjqPAg0M2+azek3NxjYhnsM+ca22yLD5js8cMCVkheZ\n9KA94ic+4hd7NHqgUrmMETQEeOVUbZ5PndJI9lV+whxm5uWtEph9AgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDWlkcC5pZy5jYXMuY3qGJGh0dHBzOi8vaWRwLmlnLmNhcy5j\nei9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUDghEtRanFH4cZQ/+Lclh2VR5bJYw\nDQYJKoZIhvcNAQEFBQADggEBAHwmYx8J6PauVsJg0DZs8d2qXv0vMJObff+rrEEV\nfOCRFu7xGfMNGFq8vIGk8iWeFE4XOk/uUntjuHCRmPiqeBifukhBWPXwwflpmimn\nlYW0fYbfDG5bqOa/fGv2ztq6cpKkWN81KI9bzXAuyYIgzYPXhodUXICa8OFYH2a/\nj91+yHDcBb/Kpl6ReAK4qj9GO0Z2k7dnNsbDtVCdi1DJpDWjElJszPl6dc1+5F6i\nZY9vTx0lCROCttAMuKYs5fcReLwk+/o2IlfIxdxdAVWXDa74bGoWicPV4IvMYax9\niAMUVpLKlI8Ml/V8Qgk4piCGEo3pgoP8PlIY9phZL+b1IZo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ig.cas.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ig.cas.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ig.cas.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ig.cas.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ig.cas.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ig.cas.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ig.cas.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ig.cas.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ig.cas.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ig.cas.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ig.cas.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ig.cas.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ig.cas.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ig.cas.cz/en"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ig.cas.czu"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider IG AV CR employees."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance GF\u00da AV \u010cR"
                  }
                ],
                "logo": [
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-gfu-44.png",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "30"
                  },
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-gfu-146.png",
                    "height": "146",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Geophysics of the CAS, v.v.i."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Geofyzik\u00e1ln\u00ed \u00fastav AV \u010cR, v.v.i."
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUW5TBaaB6SfKUuLQgLg+XaF0y3J4wDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNaWRwLmlnLmNhcy5jejAeFw0xNjA0MDUxMzI0MTlaFw0z\nNjA0MDUxMzI0MTlaMBgxFjAUBgNVBAMTDWlkcC5pZy5jYXMuY3owggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCvMAk1nwttucujjFQOSyuiS4jPK4M7TVip\n5rRgjz3M7Jmp4X0ZwYCcokPvD1iC+hQFHUiQdEGyvxPcl/3q7lKcrxFhbJUhP4yl\nZgrJysS91zx9LxEgFeNRIObSGCDLe5+EKRBoyScHhBkBrbIMVhqTjwvIBPuzqmi0\n8sew/BijdVsP9JkGfTr15qw/U6rzE3kh6HY65P5x50D2gLl8dwyAkgdbTdrwZ+Z9\nil1x9sVlVasM+//2OFdhEtjqPAg0M2+azek3NxjYhnsM+ca22yLD5js8cMCVkheZ\n9KA94ic+4hd7NHqgUrmMETQEeOVUbZ5PndJI9lV+whxm5uWtEph9AgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDWlkcC5pZy5jYXMuY3qGJGh0dHBzOi8vaWRwLmlnLmNhcy5j\nei9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUDghEtRanFH4cZQ/+Lclh2VR5bJYw\nDQYJKoZIhvcNAQEFBQADggEBAHwmYx8J6PauVsJg0DZs8d2qXv0vMJObff+rrEEV\nfOCRFu7xGfMNGFq8vIGk8iWeFE4XOk/uUntjuHCRmPiqeBifukhBWPXwwflpmimn\nlYW0fYbfDG5bqOa/fGv2ztq6cpKkWN81KI9bzXAuyYIgzYPXhodUXICa8OFYH2a/\nj91+yHDcBb/Kpl6ReAK4qj9GO0Z2k7dnNsbDtVCdi1DJpDWjElJszPl6dc1+5F6i\nZY9vTx0lCROCttAMuKYs5fcReLwk+/o2IlfIxdxdAVWXDa74bGoWicPV4IvMYax9\niAMUVpLKlI8Ml/V8Qgk4piCGEo3pgoP8PlIY9phZL+b1IZo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Geophysics of the CAS, v.v.i."
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Geofyzik\u00e1ln\u00ed \u00fastav AV \u010cR, v.v.i."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ig.cas.cz/en"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ig.cas.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Geophysics of the CAS"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Geofyzik\u00e1ln\u00ed \u00fastav AV \u010cR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://uat-nsuk.elsevieremea.com/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Isaacs"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:g.isaacs@elsevier.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Graham"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Clifton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:t.clifton@elsevier.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Terence"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://uat-nsuk.elsevieremea.com/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-03-18T15:51:46Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Elsevier Clinical Skills (UAT)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.elsevierclinicalskills.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Elsevier B.V."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDgjCCAmqgAwIBAgIJAIPaQ409Yt0iMA0GCSqGSIb3DQEBBQUAMDQxDjAMBgNV\n\t\t\t\t\t\tBAoTBU1OU1VLMSIwIAYDVQQDExl1YXQtbnN1ay5lbHNldmllcmVtZWEuY29tMB4X\n\t\t\t\t\t\tDTEyMTEyOTAyNTIxM1oXDTIyMTEyNzAyNTIxM1owNDEOMAwGA1UEChMFTU5TVUsx\n\t\t\t\t\t\tIjAgBgNVBAMTGXVhdC1uc3VrLmVsc2V2aWVyZW1lYS5jb20wggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDhnZp/bmCr/TQS5osRk8lfgcUeGptgZSid/7fI\n\t\t\t\t\t\tLYQUzL1Dsl3hXmfucOS/Db+De0TqEFwkxZ2kf4qxn91X/rFnqWGiRfTy1LOFc5MW\n\t\t\t\t\t\teZ2XdU36cfq2Gt8Wq/bF0lVgvPqqM9z4b0fgMt3xMta9XHJXRE/HFSAuJ77FpDUw\n\t\t\t\t\t\tYkCTIIzUvFPimdEFpSyltqlO0r77a2nrvGgDA0FwYYwQ0iRKT16RANcRAL07pzWe\n\t\t\t\t\t\t1ECO4H79bvuDyeYmeHCNTbQ4lovqEjeGgu+I0i+jf2pod6KX6ILaPXPjWdZPW+u2\n\t\t\t\t\t\tCTTqnDPt2oBmQJHHibn2r7yPPIXz2UlzT4u1/xSqMZu82n/vAgMBAAGjgZYwgZMw\n\t\t\t\t\t\tHQYDVR0OBBYEFElTHK+kxkQmCYiclyw5swDyhIqEMGQGA1UdIwRdMFuAFElTHK+k\n\t\t\t\t\t\txkQmCYiclyw5swDyhIqEoTikNjA0MQ4wDAYDVQQKEwVNTlNVSzEiMCAGA1UEAxMZ\n\t\t\t\t\t\tdWF0LW5zdWsuZWxzZXZpZXJlbWVhLmNvbYIJAIPaQ409Yt0iMAwGA1UdEwQFMAMB\n\t\t\t\t\t\tAf8wDQYJKoZIhvcNAQEFBQADggEBAJPUl/JrhkaUwhHrrTzP9IojhhX/2lumXjNL\n\t\t\t\t\t\tOIGtDF0A0yMuq6OuRwrQ6IEvCTgXNOpIZShkbzPPWR0YF240zLB3IobMDpfH8G1r\n\t\t\t\t\t\tlycsXjuhgAT4oluZg08Ogs4EpzlQfxmzsiL8a+NV7JasoksJll1yZnHCt1BmaNZx\n\t\t\t\t\t\t76fl5ti7eOha51lhC0p4dPM7nVjPklk1yOTbhAeLIqIiD+QbczadBc97lY0KqLvk\n\t\t\t\t\t\tjPtJI7U9vKBxMR021fjAxGMnKeJfhh4QJRD+mwdOJdiQ+G7GiswHRNQP+IOPufWl\n\t\t\t\t\t\tRs0tLu8YVVeOHOZilxI8ij68b5gcBJozjTOBwwH0BTCLt1Q7dj4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDgjCCAmqgAwIBAgIJAIPaQ409Yt0iMA0GCSqGSIb3DQEBBQUAMDQxDjAMBgNV\n\t\t\t\t\t\tBAoTBU1OU1VLMSIwIAYDVQQDExl1YXQtbnN1ay5lbHNldmllcmVtZWEuY29tMB4X\n\t\t\t\t\t\tDTEyMTEyOTAyNTIxM1oXDTIyMTEyNzAyNTIxM1owNDEOMAwGA1UEChMFTU5TVUsx\n\t\t\t\t\t\tIjAgBgNVBAMTGXVhdC1uc3VrLmVsc2V2aWVyZW1lYS5jb20wggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDhnZp/bmCr/TQS5osRk8lfgcUeGptgZSid/7fI\n\t\t\t\t\t\tLYQUzL1Dsl3hXmfucOS/Db+De0TqEFwkxZ2kf4qxn91X/rFnqWGiRfTy1LOFc5MW\n\t\t\t\t\t\teZ2XdU36cfq2Gt8Wq/bF0lVgvPqqM9z4b0fgMt3xMta9XHJXRE/HFSAuJ77FpDUw\n\t\t\t\t\t\tYkCTIIzUvFPimdEFpSyltqlO0r77a2nrvGgDA0FwYYwQ0iRKT16RANcRAL07pzWe\n\t\t\t\t\t\t1ECO4H79bvuDyeYmeHCNTbQ4lovqEjeGgu+I0i+jf2pod6KX6ILaPXPjWdZPW+u2\n\t\t\t\t\t\tCTTqnDPt2oBmQJHHibn2r7yPPIXz2UlzT4u1/xSqMZu82n/vAgMBAAGjgZYwgZMw\n\t\t\t\t\t\tHQYDVR0OBBYEFElTHK+kxkQmCYiclyw5swDyhIqEMGQGA1UdIwRdMFuAFElTHK+k\n\t\t\t\t\t\txkQmCYiclyw5swDyhIqEoTikNjA0MQ4wDAYDVQQKEwVNTlNVSzEiMCAGA1UEAxMZ\n\t\t\t\t\t\tdWF0LW5zdWsuZWxzZXZpZXJlbWVhLmNvbYIJAIPaQ409Yt0iMAwGA1UdEwQFMAMB\n\t\t\t\t\t\tAf8wDQYJKoZIhvcNAQEFBQADggEBAJPUl/JrhkaUwhHrrTzP9IojhhX/2lumXjNL\n\t\t\t\t\t\tOIGtDF0A0yMuq6OuRwrQ6IEvCTgXNOpIZShkbzPPWR0YF240zLB3IobMDpfH8G1r\n\t\t\t\t\t\tlycsXjuhgAT4oluZg08Ogs4EpzlQfxmzsiL8a+NV7JasoksJll1yZnHCt1BmaNZx\n\t\t\t\t\t\t76fl5ti7eOha51lhC0p4dPM7nVjPklk1yOTbhAeLIqIiD+QbczadBc97lY0KqLvk\n\t\t\t\t\t\tjPtJI7U9vKBxMR021fjAxGMnKeJfhh4QJRD+mwdOJdiQ+G7GiswHRNQP+IOPufWl\n\t\t\t\t\t\tRs0tLu8YVVeOHOZilxI8ij68b5gcBJozjTOBwwH0BTCLt1Q7dj4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "want_assertions_signed": "false",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://uat-nsuk.elsevieremea.com/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://uat-nsuk.elsevieremea.com/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uat-nsuk.elsevieremea.com/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uat-nsuk.elsevieremea.com/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://ci.nordu.net/shibboleth",
    {
      "entity_id": "https://ci.nordu.net/shibboleth",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ci.nordu.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ci.nordu.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ci.nordu.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ci.nordu.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ci.nordu.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ci.nordu.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ci.nordu.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ni.nordu.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6zCCAdOgAwIBAgIJAK2SQ9c+AOzcMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDG5pLm5vcmR1Lm5ldDAeFw0xMzAzMjIxNDMxMTBaFw0yMzAzMjAxNDMxMTBa\nMBcxFTATBgNVBAMTDG5pLm5vcmR1Lm5ldDCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBANg878PB2YXrJRpa3MqD4kMqkvw/yZfE3ze3RWoL8My8pfdQFUIE\nNTR+OH3i4Sa7yclxqKJo02z07L3wM7Fj6zmtfCvrIQ0+XDN6K++7M30iXLROvDrK\nqElF+J4wOFejy1Up+9/fFFmGn7RVMlgzGMka7ZcSasXeWRBHROA0VV5bkwdZiJDG\nLF56HH8lPvkNWyfFBCuVBeA4woZtOnm0OceK2MIgB9u0nLgWpo8146dgRj+KVnfL\nLMuD2eXAOfACXypa+FbxTHZsKBCV/E+5XFG7z+4eZx2kEczTXbpbencfppYaPBSA\nDz75BkEtensalbDyzBybTYgbxzqrNDxwjykCAwEAAaM6MDgwFwYDVR0RBBAwDoIM\nbmkubm9yZHUubmV0MB0GA1UdDgQWBBRJI7codf8CcvUc1dW43cTlM98aZzANBgkq\nhkiG9w0BAQUFAAOCAQEAUM9s74eqkCL3C9Hh9iAVgzhdRyNJ4+Dq2zhSPIcn0rvp\nBN0Gtl8pWL/z5vLmAhhRKnJQlXrObFH1/N5FTY3iMP4ll1GGwkYs1Ne4rXkF/2Eo\n6qkaXnxW3Xo/zEsA/QHT84UVpciMV6zakrQ/xpEAegjDkYAZpenFnwlw9WxwTHAb\nYTCXdqLn6JZBIRq0O4XPDH4LLY9BDK6LhQ4o47Y8hBshp7JtqyvyDK/EtnKOijbt\nPOkVsnFGi1sMSYsm3v40Wmlr75LG2M7QOOVX6JDjNHFJSFMEyncUiDjCfuqOI3Ka\nNgx5k0w6C4avz1ua/NNuUD5WoB1mXA+YiQiIEUTnPQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ni.nordu.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ci.nordu.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ci.nordu.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ci.nordu.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ci.nordu.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ci.nordu.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ci.nordu.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ufrb.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Anderson Lago Gomes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cotec@proplan.ufrb.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ufrb.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEAjCCAuoCAQAwDQYJKoZIhvcNAQEFBQAwgcYxOjA4BgNVBAoTMVVGUkIgLSBV\nbml2ZXJzaWRhZGUgRmVkZXJhbCBkbyBSZWNvbmNhdm8gZGEgQmFoaWExDjAMBgNV\nBAsTBUNPVEVDMSgwJgYJKoZIhvcNAQkBFhljb3RlY0Bwcm9wbGFuLnVmcmIuZWR1\nLmJyMRcwFQYDVQQHEw5DcnV6IGRhcyBBbG1hczEOMAwGA1UECBMFQmFoaWExCzAJ\nBgNVBAYTAkJSMRgwFgYDVQQDEw9pZHAudWZyYi5lZHUuYnIwHhcNMTQxMjEzMDU0\nNzA3WhcNMTcxMjEyMDU0NzA3WjCBxjE6MDgGA1UEChMxVUZSQiAtIFVuaXZlcnNp\nZGFkZSBGZWRlcmFsIGRvIFJlY29uY2F2byBkYSBCYWhpYTEOMAwGA1UECxMFQ09U\nRUMxKDAmBgkqhkiG9w0BCQEWGWNvdGVjQHByb3BsYW4udWZyYi5lZHUuYnIxFzAV\nBgNVBAcTDkNydXogZGFzIEFsbWFzMQ4wDAYDVQQIEwVCYWhpYTELMAkGA1UEBhMC\nQlIxGDAWBgNVBAMTD2lkcC51ZnJiLmVkdS5icjCCASIwDQYJKoZIhvcNAQEBBQAD\nggEPADCCAQoCggEBALV2LAx8VdH5wtvvjaYjhD3Mz41PVxj2XpKSetDPlMktll17\n2cdu0tghyOWXCsfWoE3j0G1uKcxw3c6s07RsV0IQNb5pcZ8RIftRz6FEJ+WLc/vc\nwv7O189b2B8gj7Q4ciTAQ2IX28eV0kIfRUzDRGd6LAe4LkQbNZjIC+RJJh3mJpZO\nqOxR43SX82ub7cfCxIdriBnkrADgbpbqmSGci79FPWqCxN7gFpStc6xsSruyJGyq\nnq557NsaXVaAEVEdW/5nDMipTKFmMSjroyYGzuNQQ8Ob8G6EOxlVub/b2abw0hUI\nZzpEU8ap8a4qWNUmgAakXbbDIY4mb+F6pp7eUTUCAwEAATANBgkqhkiG9w0BAQUF\nAAOCAQEAAmgaLH2G1dzR7vJ+FwYJyB4wg6USlFD6iPaF5F0LpabpUGNw5Twlu66v\n1jutrGMM3/rB0cy/vqCYKtdzwk2OqXT5xCAitgtVr3/iJtUq7FfQkdi7ck3Bm/4p\ncdCuK6i9mF0TGQzIRHK5SliZSt/vrmF6e44psIgdV6ZY6bjqY40d5lk0biXk4gei\nNUQS7h3jSQc8/tEZ8ri/ZYvL1H51ifaIF3UgsxkaygobrrjWMMHqd+BpLFI25dhT\nkkWUdTXk30J1kWyts6YUVmzxOd3b40Pvv5sQQw2XX0gkDK/INOQbCbIWCyB3W/QG\nIZlmLPTqQz7twruX1Dqbaf/ocy9s4g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ufrb.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ufrb.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ufrb.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ufrb.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ufrb.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ufrb.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ufrb.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ufrb.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufrb.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufrb.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFRB - Universidade Federal do Reconcavo da Bahia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFRB - Universidade Federal do Reconcavo da Bahia"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFRB - Universidade Federal do Reconcavo da Bahia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFRB - Universidade Federal do Reconcavo da Bahia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEAjCCAuoCAQAwDQYJKoZIhvcNAQEFBQAwgcYxOjA4BgNVBAoTMVVGUkIgLSBV\nbml2ZXJzaWRhZGUgRmVkZXJhbCBkbyBSZWNvbmNhdm8gZGEgQmFoaWExDjAMBgNV\nBAsTBUNPVEVDMSgwJgYJKoZIhvcNAQkBFhljb3RlY0Bwcm9wbGFuLnVmcmIuZWR1\nLmJyMRcwFQYDVQQHEw5DcnV6IGRhcyBBbG1hczEOMAwGA1UECBMFQmFoaWExCzAJ\nBgNVBAYTAkJSMRgwFgYDVQQDEw9pZHAudWZyYi5lZHUuYnIwHhcNMTQxMjEzMDU0\nNzA3WhcNMTcxMjEyMDU0NzA3WjCBxjE6MDgGA1UEChMxVUZSQiAtIFVuaXZlcnNp\nZGFkZSBGZWRlcmFsIGRvIFJlY29uY2F2byBkYSBCYWhpYTEOMAwGA1UECxMFQ09U\nRUMxKDAmBgkqhkiG9w0BCQEWGWNvdGVjQHByb3BsYW4udWZyYi5lZHUuYnIxFzAV\nBgNVBAcTDkNydXogZGFzIEFsbWFzMQ4wDAYDVQQIEwVCYWhpYTELMAkGA1UEBhMC\nQlIxGDAWBgNVBAMTD2lkcC51ZnJiLmVkdS5icjCCASIwDQYJKoZIhvcNAQEBBQAD\nggEPADCCAQoCggEBALV2LAx8VdH5wtvvjaYjhD3Mz41PVxj2XpKSetDPlMktll17\n2cdu0tghyOWXCsfWoE3j0G1uKcxw3c6s07RsV0IQNb5pcZ8RIftRz6FEJ+WLc/vc\nwv7O189b2B8gj7Q4ciTAQ2IX28eV0kIfRUzDRGd6LAe4LkQbNZjIC+RJJh3mJpZO\nqOxR43SX82ub7cfCxIdriBnkrADgbpbqmSGci79FPWqCxN7gFpStc6xsSruyJGyq\nnq557NsaXVaAEVEdW/5nDMipTKFmMSjroyYGzuNQQ8Ob8G6EOxlVub/b2abw0hUI\nZzpEU8ap8a4qWNUmgAakXbbDIY4mb+F6pp7eUTUCAwEAATANBgkqhkiG9w0BAQUF\nAAOCAQEAAmgaLH2G1dzR7vJ+FwYJyB4wg6USlFD6iPaF5F0LpabpUGNw5Twlu66v\n1jutrGMM3/rB0cy/vqCYKtdzwk2OqXT5xCAitgtVr3/iJtUq7FfQkdi7ck3Bm/4p\ncdCuK6i9mF0TGQzIRHK5SliZSt/vrmF6e44psIgdV6ZY6bjqY40d5lk0biXk4gei\nNUQS7h3jSQc8/tEZ8ri/ZYvL1H51ifaIF3UgsxkaygobrrjWMMHqd+BpLFI25dhT\nkkWUdTXk30J1kWyts6YUVmzxOd3b40Pvv5sQQw2XX0gkDK/INOQbCbIWCyB3W/QG\nIZlmLPTqQz7twruX1Dqbaf/ocy9s4g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFRB - Universidade Federal do Reconcavo da Bahia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFRB - Universidade Federal do Reconcavo da Bahia"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufrb.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufrb.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFRB - Universidade Federal do Reconcavo da Bahia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFRB - Universidade Federal do Reconcavo da Bahia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://vea-idp.lanet.lv",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ITserviss"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itserviss@lu.lv"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://vea-idp.lanet.lv",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://laife.lanet.lv/wiki/Latvian-Academic-Identity-Federation-Policy.pdf"
              }
            ],
            "registration_instant": "2013-10-10T10:10:10Z",
            "registration_authority": "http://laife.lanet.lv/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vea-idp.lanet.lv/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vea-idp.lanet.lv/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:56.950974,24.116292"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ventspils University College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ventspils University College - VEA IDP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://laife.lanet.lv/"
          },
          {
            "lang": "lv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.venta.lv/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LAIFE - VEA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.ntua.gr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:noc@ntua.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "National Technical University of Athens"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+30-210-772-1861"
            }
          ]
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+30-210-772-1861"
            }
          ],
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:help-data@noc.ntua.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "National Technical University of Athens"
          },
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NOC Helpdesk"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rania@noc.ntua.gr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ourania Lambrou"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.ntua.gr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIJAOE9jL5hLZ+yMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n                            BAMTDWxvZ2luLm50dWEuZ3IwHhcNMTMxMjExMTMyNzM3WhcNMjMxMjA5MTMyNzM3\n                            WjAYMRYwFAYDVQQDEw1sb2dpbi5udHVhLmdyMIIBIjANBgkqhkiG9w0BAQEFAAOC\n                            AQ8AMIIBCgKCAQEA9PPd/C1Smrn+DH1bYdJ24qqvA7aDt7izs/c9bmsF1/zOumIj\n                            3Tmi9V/zmeNt2yiV/Nva2ZU3M/cTUxZST7XYWz+758EyqmvKVvHgyOmmF8JdV+9r\n                            hFT3R3DEdDnGnep4N7QZySOQ/mOp3IsY2Wxqka3NU672keZq/VhV/B1MPDqhqPGt\n                            TPeW/NJGjo2UrMKkeyJLCHQJeNbKOOSzefc5TJYFJHLXqGs7DWIXwqqab0MPJ3Na\n                            N7Ap0SEIZWpNS7u/lAAS//1HJQ26zW15GcUhxgi2pMk3GHs6uwWF+DYLEbWg17MQ\n                            Er9MFbftJjf9V4GOfUILDvgNlutCPnmM6aB4gQIDAQABo2EwXzA+BgNVHREENzA1\n                            gg1sb2dpbi5udHVhLmdyhiRodHRwczovL2xvZ2luLm50dWEuZ3IvaWRwL3NoaWJi\n                            b2xldGgwHQYDVR0OBBYEFNP8/C26TomQ3yAZFMY2W84V40ihMA0GCSqGSIb3DQEB\n                            BQUAA4IBAQAv4cC1fu39MNQlvoSY/k/kV7cbkmS30FfVlsuwdfZQJO/3r2a/E7kd\n                            l9QR9Us+Eraabx6ccq6BYbtsMaXkDrgKPL6KfXFWNIjbizqmmvgdlB2ptYYKN7d0\n                            Bz2L7y0ZWkKApEBDVMUwmBHsS18xs35xchKyezTAralRy3tHBAop93jBumHiRRYF\n                            RuRSEM4KM01/DkDDwkCXWEWu0TolnSozTFtYddwi1u48s0tq4TSBkYk3C7XoyCol\n                            PCUfUb8+3VLdMNqkSkE22WQx9th9BNNWs3e4QdrRgnh/9gKInZCzmrXU8ymWBhmj\n                            1f80WSd+TnQAp2UMPIXxxOOSGhI5NyQn"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ntua.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.ntua.gr:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.ntua.gr:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.ntua.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.ntua.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.ntua.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.ntua.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.ntua.gr:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.ntua.gr:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ntua.gr"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://login.ntua.gr"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://login.ntua.gr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "National Technical University of Athens Identity Provider"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "\u03a5\u03c0\u03b7\u03c1\u03b5\u03c3\u03af\u03b1 \u03a4\u03b1\u03c5\u03c4\u03cc\u03c4\u03b7\u03c4\u03b1\u03c2 \u03c4\u03bf\u03c5 \u0395\u03b8\u03bd\u03b9\u03ba\u03bf\u03cd \u039c\u03b5\u03c4\u03c3\u03cc\u03b2\u03b9\u03bf\u03c5 \u03a0\u03bf\u03bb\u03c5\u03c4\u03b5\u03c7\u03bd\u03b5\u03af\u03bf\u03c5"
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.ntua.gr/images/pyrforos300.png",
                    "height": "302",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "300"
                  },
                  {
                    "text": "https://login.ntua.gr/images/pyrforos150.png",
                    "height": "151",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "150"
                  },
                  {
                    "text": "https://login.ntua.gr/images/pyrforos50.png",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "National Technical University of Athens"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u0395\u03b8\u03bd\u03b9\u03ba\u03cc \u039c\u03b5\u03c4\u03c3\u03cc\u03b2\u03b9\u03bf \u03a0\u03bf\u03bb\u03c5\u03c4\u03b5\u03c7\u03bd\u03b5\u03af\u03bf"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "ntua.gr"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:37.977413,23.782694"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.102.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:648:2000::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIJAOE9jL5hLZ+yMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n                            BAMTDWxvZ2luLm50dWEuZ3IwHhcNMTMxMjExMTMyNzM3WhcNMjMxMjA5MTMyNzM3\n                            WjAYMRYwFAYDVQQDEw1sb2dpbi5udHVhLmdyMIIBIjANBgkqhkiG9w0BAQEFAAOC\n                            AQ8AMIIBCgKCAQEA9PPd/C1Smrn+DH1bYdJ24qqvA7aDt7izs/c9bmsF1/zOumIj\n                            3Tmi9V/zmeNt2yiV/Nva2ZU3M/cTUxZST7XYWz+758EyqmvKVvHgyOmmF8JdV+9r\n                            hFT3R3DEdDnGnep4N7QZySOQ/mOp3IsY2Wxqka3NU672keZq/VhV/B1MPDqhqPGt\n                            TPeW/NJGjo2UrMKkeyJLCHQJeNbKOOSzefc5TJYFJHLXqGs7DWIXwqqab0MPJ3Na\n                            N7Ap0SEIZWpNS7u/lAAS//1HJQ26zW15GcUhxgi2pMk3GHs6uwWF+DYLEbWg17MQ\n                            Er9MFbftJjf9V4GOfUILDvgNlutCPnmM6aB4gQIDAQABo2EwXzA+BgNVHREENzA1\n                            gg1sb2dpbi5udHVhLmdyhiRodHRwczovL2xvZ2luLm50dWEuZ3IvaWRwL3NoaWJi\n                            b2xldGgwHQYDVR0OBBYEFNP8/C26TomQ3yAZFMY2W84V40ihMA0GCSqGSIb3DQEB\n                            BQUAA4IBAQAv4cC1fu39MNQlvoSY/k/kV7cbkmS30FfVlsuwdfZQJO/3r2a/E7kd\n                            l9QR9Us+Eraabx6ccq6BYbtsMaXkDrgKPL6KfXFWNIjbizqmmvgdlB2ptYYKN7d0\n                            Bz2L7y0ZWkKApEBDVMUwmBHsS18xs35xchKyezTAralRy3tHBAop93jBumHiRRYF\n                            RuRSEM4KM01/DkDDwkCXWEWu0TolnSozTFtYddwi1u48s0tq4TSBkYk3C7XoyCol\n                            PCUfUb8+3VLdMNqkSkE22WQx9th9BNNWs3e4QdrRgnh/9gKInZCzmrXU8ymWBhmj\n                            1f80WSd+TnQAp2UMPIXxxOOSGhI5NyQn"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "National Technical University of Athens"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u0395\u03b8\u03bd\u03b9\u03ba\u03cc \u039c\u03b5\u03c4\u03c3\u03cc\u03b2\u03b9\u03bf \u03a0\u03bf\u03bb\u03c5\u03c4\u03b5\u03c7\u03bd\u03b5\u03af\u03bf"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ntua.gr"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ntua.gr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NTUA"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u0395\u039c\u03a0"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ne-worcs.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kings"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dkings@howcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kings"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dkings@howcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ne-worcs.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_instant": "2013-05-13T12:19:41Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDrDCCApQCCQCVGi7e0Pph5TANBgkqhkiG9w0BAQUFADCBlzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFzAVBgNVBAgMDldvcmNlc3RlcnNoaXJlMREwDwYDVQQHDAhSZWRkaXRjaDEq\n\t\t\t\t\t\tMCgGA1UECgwhTm9ydGggRWFzdCBXb3JjZXN0ZXJzaGlyZSBDb2xsZWdlMRMwEQYD\n\t\t\t\t\t\tVQQLDApJVCBTdXBwb3J0MRswGQYDVQQDDBJpZHAubmUtd29yY3MuYWMudWswHhcN\n\t\t\t\t\t\tMTMwMTI1MTAwMzQzWhcNMzMwMTIwMTAwMzQzWjCBlzELMAkGA1UEBhMCR0IxFzAV\n\t\t\t\t\t\tBgNVBAgMDldvcmNlc3RlcnNoaXJlMREwDwYDVQQHDAhSZWRkaXRjaDEqMCgGA1UE\n\t\t\t\t\t\tCgwhTm9ydGggRWFzdCBXb3JjZXN0ZXJzaGlyZSBDb2xsZWdlMRMwEQYDVQQLDApJ\n\t\t\t\t\t\tVCBTdXBwb3J0MRswGQYDVQQDDBJpZHAubmUtd29yY3MuYWMudWswggEiMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDCVcflAUC6XOzv8yhdkX9Zf83iZoUpiKVh\n\t\t\t\t\t\tPj0ATct/aPsWsLDQndOzo4sM0FXmrDChA0jvUGlJ5q0R/Sfl/qjNBNBnvvnXsmjj\n\t\t\t\t\t\tfAzZcMCX7YfKfXgzF0uIdujjGkx1Y6fvD2azVXxf1fAa3IyhM0o+ObfIyErerhNU\n\t\t\t\t\t\tvxJ4uP1dUrBxIry9qsNwMM51TEOtF6Atvcy1toGdC7dOYHk7+sB+WW8m2QWch2TT\n\t\t\t\t\t\t4/Q3hNBjXBRQkyY/QIqJLMCGdi6B8bNF2RViiC7yJqqYCnzZQ4YUHMxIJqm3krX5\n\t\t\t\t\t\tAkEKVXiFZ6TalR3BRyVOyylGQpz8X2Ykzog2E3Lz0erUEjbm7zJfAgMBAAEwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBAI94qHrZZvoCZdgGlQg6vl2A+GwvQuQ2ZIr+CWtq6DzS\n\t\t\t\t\t\t4IDYqY8GPBBk1zuDx3StGeYfqO7s6jrgup0/gKJD7l4oV8Dq/VUHXdWt11+aMdlb\n\t\t\t\t\t\tW185fYQw++jcYaEZyr2LzDqOHO7dgbgyrCypjiFtU279lrf+Uz0XDf3FFQm+wg9+\n\t\t\t\t\t\tHXoRWAAYwZQaMOMADo/70fUHKEe7IH5u81m0Sh1REjX/erBmWoBNXrMBLNa+vhPT\n\t\t\t\t\t\tuVHlFJixhZuiIvAi/QzgjZruWzKySCZGWSajHqHBdxcojzB4Oao82vsJu4S3Mv/W\n\t\t\t\t\t\ttT1EKx/axaYI5jW/ThK191F3j5568qM0exHyrfCZbIw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ne-worcs.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ne-worcs.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ne-worcs.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ne-worcs.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ne-worcs.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ne-worcs.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ne-worcs.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ne-worcs.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ne-worcs.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ne-worcs.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDrDCCApQCCQCVGi7e0Pph5TANBgkqhkiG9w0BAQUFADCBlzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFzAVBgNVBAgMDldvcmNlc3RlcnNoaXJlMREwDwYDVQQHDAhSZWRkaXRjaDEq\n\t\t\t\t\t\tMCgGA1UECgwhTm9ydGggRWFzdCBXb3JjZXN0ZXJzaGlyZSBDb2xsZWdlMRMwEQYD\n\t\t\t\t\t\tVQQLDApJVCBTdXBwb3J0MRswGQYDVQQDDBJpZHAubmUtd29yY3MuYWMudWswHhcN\n\t\t\t\t\t\tMTMwMTI1MTAwMzQzWhcNMzMwMTIwMTAwMzQzWjCBlzELMAkGA1UEBhMCR0IxFzAV\n\t\t\t\t\t\tBgNVBAgMDldvcmNlc3RlcnNoaXJlMREwDwYDVQQHDAhSZWRkaXRjaDEqMCgGA1UE\n\t\t\t\t\t\tCgwhTm9ydGggRWFzdCBXb3JjZXN0ZXJzaGlyZSBDb2xsZWdlMRMwEQYDVQQLDApJ\n\t\t\t\t\t\tVCBTdXBwb3J0MRswGQYDVQQDDBJpZHAubmUtd29yY3MuYWMudWswggEiMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDCVcflAUC6XOzv8yhdkX9Zf83iZoUpiKVh\n\t\t\t\t\t\tPj0ATct/aPsWsLDQndOzo4sM0FXmrDChA0jvUGlJ5q0R/Sfl/qjNBNBnvvnXsmjj\n\t\t\t\t\t\tfAzZcMCX7YfKfXgzF0uIdujjGkx1Y6fvD2azVXxf1fAa3IyhM0o+ObfIyErerhNU\n\t\t\t\t\t\tvxJ4uP1dUrBxIry9qsNwMM51TEOtF6Atvcy1toGdC7dOYHk7+sB+WW8m2QWch2TT\n\t\t\t\t\t\t4/Q3hNBjXBRQkyY/QIqJLMCGdi6B8bNF2RViiC7yJqqYCnzZQ4YUHMxIJqm3krX5\n\t\t\t\t\t\tAkEKVXiFZ6TalR3BRyVOyylGQpz8X2Ykzog2E3Lz0erUEjbm7zJfAgMBAAEwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBAI94qHrZZvoCZdgGlQg6vl2A+GwvQuQ2ZIr+CWtq6DzS\n\t\t\t\t\t\t4IDYqY8GPBBk1zuDx3StGeYfqO7s6jrgup0/gKJD7l4oV8Dq/VUHXdWt11+aMdlb\n\t\t\t\t\t\tW185fYQw++jcYaEZyr2LzDqOHO7dgbgyrCypjiFtU279lrf+Uz0XDf3FFQm+wg9+\n\t\t\t\t\t\tHXoRWAAYwZQaMOMADo/70fUHKEe7IH5u81m0Sh1REjX/erBmWoBNXrMBLNa+vhPT\n\t\t\t\t\t\tuVHlFJixhZuiIvAi/QzgjZruWzKySCZGWSajHqHBdxcojzB4Oao82vsJu4S3Mv/W\n\t\t\t\t\t\ttT1EKx/axaYI5jW/ThK191F3j5568qM0exHyrfCZbIw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "North East Worcestershire College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ne-worcs.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Heart of Worcestershire College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://pa2836.peopleadmin.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "praveen.pinto@peopleadmin.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Praveen Pinto"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "amanda.merritt@peopleadmin.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Amanda Merritt"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://pa2836.peopleadmin.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PeopleAdmin, Inc."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.peopleadmin.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "PeopleAdmin, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jobs.baylor.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://baylor-training.peopleadmin.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://baylor-sb.peopleadmin.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAK9qYIpSXmuLMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD3Blb3BsZWFkbWluLmNvbTAeFw0xMzA4MDYwNDExMjJaFw0yMzA4MDQwNDEx\nMjJaMBoxGDAWBgNVBAMTD3Blb3BsZWFkbWluLmNvbTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAPNJA6keJeqd1d8rBtHYenYT+2Z5p14STKAMxI+OHzTF\n1ILCp/tXfaTeWggztaCCSGYFwSJkCaKeaLC4+easqoqS18zen4j6OEG6UWF5sUd7\nj6GumoZmFa4bYTcTpkdpa9ENG+0OKLRzWz/TTyzSdBhR3J1b1Vt+6fF/clKR1CWT\npdHsRYwGCn9jBRN7gZkNEagh4hrjfpIMgfJ7K6FRiXb5yj5pEusFm9T9ZElMFat3\npy7PQEv9F78wKbgqqFSTnnE3rWRPy8+5tTa5kpNd6GlzqiwlhY/Yqbof1lgABcNP\nN+AX1ZRRybQheE/2e53y+5/J/F4aIUHx1WJaInD35zECAwEAAaM9MDswGgYDVR0R\nBBMwEYIPcGVvcGxlYWRtaW4uY29tMB0GA1UdDgQWBBRojmrNNN8S7AEfM20TF5MI\nRPnSnDANBgkqhkiG9w0BAQUFAAOCAQEA0yEXDmrQwS7s2gSMqMm7NXlMAAwzNDhI\nOujZiSHZ1KL71bKzKHQVz5oenjJwVem/gxo7GVsuIdIZ3vKe8PYsnLu1QDTp4ZHv\nmzgRlx4kuqGjwSNs2ub2NlVc9wy9uC0pjJL58RaOxPpHDddCAs+xINF2S1ZJEM2D\nXkMvb1xhaOLox1HGhENf99ka10jWMdMt2bj1lT8WM/Qg+XgOnoQvTyjOtELM/QuA\nOVuT1bTdGg4K398O7jlTzoo7LFhPBl99HDx3cDhhhX9NdWyFyQ32MhYa6361v+eG\nDvoszRsTTKZLYbNvWoo8BZMCxK5tQ6EqNyQTmekHxw+peNCaQ+nDKw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PeopleAdmin 7 Baylor University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://saml.edusafe.nordu.net",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "stathopou@ceid.upatras.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University of Patras"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://saml.edusafe.nordu.net",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2015-06-04T14:43:01Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "DeIC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.deic.dk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Danish e-Infrastructure Cooperation"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://edusafe.nordu.net/saml/LogoutServiceHTTPRedirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Form\u00e5let er at muligg\u00f8re enkel oprettelse og h\u00e5ndtering af VPN'er."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The purpose is to facilitate the easy creation and management of VPNs."
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "eduSAFE"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "eduSAFE"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDgzCCAmugAwIBAgIEdheO2zANBgkqhkiG9w0BAQsFADByMRAwDgYDVQQGEwdV bmtub3duMRAwDgYDVQQIEwdVbmtub3duMRAwDgYDVQQHEwdVbmtub3duMRMwEQYD VQQKEwprZXltYW5hZ2VyMRMwEQYDVQQLEwpvaW9zYW1sLXNwMRAwDgYDVQQDEwdV bmtub3duMB4XDTE2MDIwMzEyMzAzNFoXDTI1MTIxMjEyMzAzNFowcjEQMA4GA1UE BhMHVW5rbm93bjEQMA4GA1UECBMHVW5rbm93bjEQMA4GA1UEBxMHVW5rbm93bjET MBEGA1UEChMKa2V5bWFuYWdlcjETMBEGA1UECxMKb2lvc2FtbC1zcDEQMA4GA1UE AxMHVW5rbm93bjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ5hrfBP CSKMhqgFBXUq0HLzLCXukjoP3CXaUj6uDYp1iYR3enV7TnX3uHOzPXcSvPsx4E50 hH58yEUQKuncECWPLsC4OYOWii0UvvC7yY3TcIwLu8yv4ThIwkR9a7cneAfz/5AO d7Lcf2nb3d4yW3oPCiZqWQ21MeKBsh61Cu72bwP0gtetShJu9stPBkkztbTbWlhL 4CQTbl1WowtrXo6+o2zbofcQz4xijW6uQJLsCJz8/RHsaF99OV5P4ioVmxb20kVZ ARtGKcf3rPrDALmjaY66FhoScxuuXTPdzlregXN0Wj55bJIVs2wyd6kGzcIqUkYW sLLYsZN1ysD+xsECAwEAAaMhMB8wHQYDVR0OBBYEFHMn1/gTgQf+nIzzdwjf3DBB mBEKMA0GCSqGSIb3DQEBCwUAA4IBAQCIwXubLDBN+fpWkuQ+RkTeo9CrC2eHd7ZP nnB+CnfUqiiaM8qr8aJsR8Ft16YBTIKganYOCrRZLtlzI5KfKf+2TM0zwinm03SB ee//5Zetj/TRDi64vbQ3X/TdomkFyDdD1Pg4pxIcMb3hmnuNI94ToFlXqCRKvIOJ VlgmqbYNPyj/aRPEvUtpiN+RrZUYPjQXrSDownJkks+5I8/ZodRZ5TFccQPsQRti spB/Tj/mY3fOUQfzKlCmd5QvziIbKa9yJheLWAgHyNDT07oy1KbfK+c8jU6KN+Hb NSY/TWRXqv7IIeDw/yJkTX4CD7q3UGi90sz4g9IptXjseJ827dQg"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://edusafe.nordu.net/saml/SAMLAssertionConsumer",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Form\u00e5let er at muligg\u00f8re enkel oprettelse og h\u00e5ndtering af VPN'er."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The purpose is to facilitate the easy creation and management of VPNs."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "eduSAFE"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "eduSAFE"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:incommon:rutgers.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "hedrick@rutgers.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Charles Hedrick"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "hedrick@rutgers.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Charles Hedrick"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:rutgers.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.oirt.rutgers.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.oirt.rutgers.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVAOTYftoWG9W/AvT7rTrVdDCpXO4RMA0GCSqGSIb3DQEB\nBQUAMCAxHjAcBgNVBAMTFXNoaWIub2lydC5ydXRnZXJzLmVkdTAeFw0xMzA5MTEy\nMDIwMjRaFw0zMzA5MTEyMDIwMjRaMCAxHjAcBgNVBAMTFXNoaWIub2lydC5ydXRn\nZXJzLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMfg5MXL8GWK\nzQ8e4eSixF5KQRsw+xjrbECuPR0hKXU+gAi9rIBX35VmBHTaTqOU3jWYK7MOJg4C\nCoVQdgB8z0wfFefcuDdeK5IdTPXA0slYZbkjM4Rqa896a0Z4ZDXcsZoH1/tLGcOy\n7WgILHlZaMv2pnYoXn4K/TAGW/dN1AqC027n7iiZAiv9MFU/rkULOKkVEQMdWMgF\n3QpVGGB5FQW7Cul6uhpoChPD1sucdqUYdKPoMtoFRZBGDC4NKDS9jW8RTFJbrqP/\n7KFaYLguSQOINSLITJvFHDWQh+PitHHfMU0S5A1Pe5R4u4oPn/trghch4vlp7r/a\nNpo/0B3Xoy8CAwEAAaNxMG8wTgYDVR0RBEcwRYIVc2hpYi5vaXJ0LnJ1dGdlcnMu\nZWR1hixodHRwczovL3NoaWIub2lydC5ydXRnZXJzLmVkdS9pZHAvc2hpYmJvbGV0\naDAdBgNVHQ4EFgQUFli4zyOx/sujMoYan3mtmvJlrrkwDQYJKoZIhvcNAQEFBQAD\nggEBACEULFPT0JlJyy+70AKed4pbpJI6xpujTqBSqQF0KWaCfzrYHj5o+Jf6O+NH\nzbMcDT52D8wdIYR9tRfim5RHGa9KB6yHGRjYTUUs4pWwg+eTxPjBOKGuNGGDYL8+\nRer4N3tq/406sxErmH3iAa0iJIKD9RHlfdKqpBxsHVgm4tF4tf4nvKJJ0Htr/iG/\nPt4R1i6XhTrkL6noEiUY0wfVtA7JFe+beGB3jgmtAo8tV/uFO703ZHotLq+F2tx9\n79bLcfGy+NHx/95l7BNs6olcWipRkoQaSxmorqt2gShsvP8uNYSWOzgsAwtDU7J0\nhIzMRisvrfUsWonX0n1qZzmLU64="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRTCCAi2gAwIBAgIJAKL5nzW/yD3hMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\nBAMTFXNoaWIub2lydC5ydXRnZXJzLmVkdTAeFw0xMDA5MjcyMTIyNDlaFw0xMzA5\nMjYyMTIyNDlaMCAxHjAcBgNVBAMTFXNoaWIub2lydC5ydXRnZXJzLmVkdTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJnjpOLwGkp/fU6u2s1tl7VTlb5W\n4BrslbD+MOAz/04FOVzbMBwHrffMRuVSATeD0285i8hpu2PvRdCyhK0FniAFFnL8\nWQklcOZEbpqMzLYSAUVnEavZU6S2gme5/GGULnFpbVPva0kbHR2MzSWUJVxgfkvS\nNS6mE0YZ9W60bPVLK1lqhILIdmlvZBqsPujuagI7pqzjaHAQZsPclnjS79rQdZMP\nAZxISKB6uAI+S5tsYMfI6l2QVsSiQGCr9Cmr3ParyeVRj3Qnsn79XKkj5Ag5C5f+\nn2PncVjG9FXtqjGZCTmP8MdM9axPtOEapREXmTehS0v5IrXG/WIXNa+96bcCAwEA\nAaOBgTB/MB0GA1UdDgQWBBQntgwltpzp+hsU37PV3OIXFypGpjBQBgNVHSMESTBH\ngBQntgwltpzp+hsU37PV3OIXFypGpqEkpCIwIDEeMBwGA1UEAxMVc2hpYi5vaXJ0\nLnJ1dGdlcnMuZWR1ggkAovmfNb/IPeEwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0B\nAQUFAAOCAQEAG2gptNgQMx6l5TvN5iKAXCLqCbFTrhKdelCTC2ir+v6m27jKf05p\n2UaAIHwVUj+mSXjWbjiBrdRAio1OgFa09FPOyesnyAhg6bT83O6rwfZ5Th8V0xJZ\n3ROJlO+65bmw53uSCJ1zWL3Vrcp+ncWz3GT7C72S0PsYrG4EwU7naX6nnUgaHZnL\no0k7iWRN5QzdkASXGDT6/4T4FzWGliv7obqfzG/MLstwFnR7haHgsWVNFX9X761+\n0cyUtC/ut8Rl3SifbyOoM91MVIg6hGOh2I4qcZO2OZWIui+7DXV8Jb88OtKmOxgT\nYnlJ2VP4+HqggzFa+Vth0GCTBBCFs16HRQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rutgers.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.oirt.rutgers.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.oirt.rutgers.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.oirt.rutgers.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.oirt.rutgers.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.oirt.rutgers.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.oirt.rutgers.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rutgers.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rutgers, The State University of New Jersey"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVAOTYftoWG9W/AvT7rTrVdDCpXO4RMA0GCSqGSIb3DQEB\nBQUAMCAxHjAcBgNVBAMTFXNoaWIub2lydC5ydXRnZXJzLmVkdTAeFw0xMzA5MTEy\nMDIwMjRaFw0zMzA5MTEyMDIwMjRaMCAxHjAcBgNVBAMTFXNoaWIub2lydC5ydXRn\nZXJzLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMfg5MXL8GWK\nzQ8e4eSixF5KQRsw+xjrbECuPR0hKXU+gAi9rIBX35VmBHTaTqOU3jWYK7MOJg4C\nCoVQdgB8z0wfFefcuDdeK5IdTPXA0slYZbkjM4Rqa896a0Z4ZDXcsZoH1/tLGcOy\n7WgILHlZaMv2pnYoXn4K/TAGW/dN1AqC027n7iiZAiv9MFU/rkULOKkVEQMdWMgF\n3QpVGGB5FQW7Cul6uhpoChPD1sucdqUYdKPoMtoFRZBGDC4NKDS9jW8RTFJbrqP/\n7KFaYLguSQOINSLITJvFHDWQh+PitHHfMU0S5A1Pe5R4u4oPn/trghch4vlp7r/a\nNpo/0B3Xoy8CAwEAAaNxMG8wTgYDVR0RBEcwRYIVc2hpYi5vaXJ0LnJ1dGdlcnMu\nZWR1hixodHRwczovL3NoaWIub2lydC5ydXRnZXJzLmVkdS9pZHAvc2hpYmJvbGV0\naDAdBgNVHQ4EFgQUFli4zyOx/sujMoYan3mtmvJlrrkwDQYJKoZIhvcNAQEFBQAD\nggEBACEULFPT0JlJyy+70AKed4pbpJI6xpujTqBSqQF0KWaCfzrYHj5o+Jf6O+NH\nzbMcDT52D8wdIYR9tRfim5RHGa9KB6yHGRjYTUUs4pWwg+eTxPjBOKGuNGGDYL8+\nRer4N3tq/406sxErmH3iAa0iJIKD9RHlfdKqpBxsHVgm4tF4tf4nvKJJ0Htr/iG/\nPt4R1i6XhTrkL6noEiUY0wfVtA7JFe+beGB3jgmtAo8tV/uFO703ZHotLq+F2tx9\n79bLcfGy+NHx/95l7BNs6olcWipRkoQaSxmorqt2gShsvP8uNYSWOzgsAwtDU7J0\nhIzMRisvrfUsWonX0n1qZzmLU64="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRTCCAi2gAwIBAgIJAKL5nzW/yD3hMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\nBAMTFXNoaWIub2lydC5ydXRnZXJzLmVkdTAeFw0xMDA5MjcyMTIyNDlaFw0xMzA5\nMjYyMTIyNDlaMCAxHjAcBgNVBAMTFXNoaWIub2lydC5ydXRnZXJzLmVkdTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJnjpOLwGkp/fU6u2s1tl7VTlb5W\n4BrslbD+MOAz/04FOVzbMBwHrffMRuVSATeD0285i8hpu2PvRdCyhK0FniAFFnL8\nWQklcOZEbpqMzLYSAUVnEavZU6S2gme5/GGULnFpbVPva0kbHR2MzSWUJVxgfkvS\nNS6mE0YZ9W60bPVLK1lqhILIdmlvZBqsPujuagI7pqzjaHAQZsPclnjS79rQdZMP\nAZxISKB6uAI+S5tsYMfI6l2QVsSiQGCr9Cmr3ParyeVRj3Qnsn79XKkj5Ag5C5f+\nn2PncVjG9FXtqjGZCTmP8MdM9axPtOEapREXmTehS0v5IrXG/WIXNa+96bcCAwEA\nAaOBgTB/MB0GA1UdDgQWBBQntgwltpzp+hsU37PV3OIXFypGpjBQBgNVHSMESTBH\ngBQntgwltpzp+hsU37PV3OIXFypGpqEkpCIwIDEeMBwGA1UEAxMVc2hpYi5vaXJ0\nLnJ1dGdlcnMuZWR1ggkAovmfNb/IPeEwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0B\nAQUFAAOCAQEAG2gptNgQMx6l5TvN5iKAXCLqCbFTrhKdelCTC2ir+v6m27jKf05p\n2UaAIHwVUj+mSXjWbjiBrdRAio1OgFa09FPOyesnyAhg6bT83O6rwfZ5Th8V0xJZ\n3ROJlO+65bmw53uSCJ1zWL3Vrcp+ncWz3GT7C72S0PsYrG4EwU7naX6nnUgaHZnL\no0k7iWRN5QzdkASXGDT6/4T4FzWGliv7obqfzG/MLstwFnR7haHgsWVNFX9X761+\n0cyUtC/ut8Rl3SifbyOoM91MVIg6hGOh2I4qcZO2OZWIui+7DXV8Jb88OtKmOxgT\nYnlJ2VP4+HqggzFa+Vth0GCTBBCFs16HRQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Rutgers, The State University of New Jersey"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rutgers.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Rutgers, The State University of New Jersey"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:asu.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ednateam@asu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UTO EDNA Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ednateam@asu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UTO EDNA Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Jack.Hsu@asu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jack Hsu"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ops.ss.certificates@mainex1.asu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Certificate Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:asu.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2.asu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2.asu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAIEaja/L6bBgSu+JKg1QGKs5jXFJMA0GCSqGSIb3DQEB\nBQUAMB4xHDAaBgNVBAMTE3NoaWJib2xldGgyLmFzdS5lZHUwHhcNMTIxMjA2MDA1\nODU4WhcNMzIxMjA2MDA1ODU4WjAeMRwwGgYDVQQDExNzaGliYm9sZXRoMi5hc3Uu\nZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAg/vJpDGOPsQ//Gew\n8luCxJ6PxezIHYovddn246ZlkFKPKN0RJpZuCLxkWUBbz2P69Be7pbU9nuNHcfjG\nkzcxHM90hYvihcutx4cP79bJK/97HTonsiQw8DT+rsFkagsOfNSpUKPREgENFlTX\nKc0KNBF4l+AbczLlYs/QygB1NjAWezQaJpElhtlpaaQoVizo9oFNbtQc5mEWnxEq\nwFR0k/HD1A7oI2hd819yMu+I4IbJVvvMyXTJaadInLxFw9mXR8A1JDI0QkHX5xSa\nG3gFnNMmVNfwCAQG2ZeRcdfiZ/WSGdrYM34QhyYDL1/qDdr3gDGm5Jj0wC2W8D0b\n4MSG3QIDAQABo20wazBKBgNVHREEQzBBghNzaGliYm9sZXRoMi5hc3UuZWR1hipo\ndHRwczovL3NoaWJib2xldGgyLmFzdS5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0O\nBBYEFDp/jP+Da0W8YoAWrzOzM/Y6Z3KuMA0GCSqGSIb3DQEBBQUAA4IBAQBkS0zf\nyDXzS/dRqqCmwinbR8mVcvsyBWsuGJQDiFIj/6WqT7lrYtp2igZXeu1V3R8XCQ4A\nJWuxXUB2zAvri8plWMhs/4s1HkeF8OZ647yoonTMxdMLheUyf/Ph+PKBs9SxANVj\nI4IYpbZZShg8HnDIDl8GdR/DTXC96VCARffmf1uu8ixzqceTMwhR6V1DgM4DIVQr\nE2VLaHwxQUzc7qxfLLwl8J+W7dd+LaTndoFtkpW7QLQUandHQWLzGt4lt7ahfbvz\n/InkWSyJ1jS/ihPrRrjyu7A3iTXITNxMow2gC1/u0Ho6FqzunXlgC4bcdGPcQiDK\nCatfNOBqeNRAh5p0"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "asu.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Arizona State University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Arizona State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.asu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Arizona State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ill.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fabien Pinet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pinet@ill.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jean-Fran\u00e7ois Perrin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "perrin@ill.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ill.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2016-02-03T13:42:22Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ill.fr/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ill.fr/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ill.fr/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ill.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ill.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ill.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ill.eu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ill.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ill.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Institut Laue-Langevin staff"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnel de l' Institut Laue-Langevin"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/x-icon;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institut Laue-Langevin"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institut Laue-Langevin"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAPh1tLy+FaH+WftVWsG4GWw7G8FgMA0GCSqGSIb3DQEB\nCwUAMBkxFzAVBgNVBAMMDmlkcHNoaWIuaWxsLmZyMB4XDTE2MDEyMDEyMjMyOFoX\nDTM2MDEyMDEyMjMyOFowGTEXMBUGA1UEAwwOaWRwc2hpYi5pbGwuZnIwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDdeEdx5Pnx0T/kATDfudIdkBpDUiOf\np6Mr9e79VhIm/Wy2X3Jm6kR9dGZMSUkUwsoKTe12L9RqmWBbc11C87Ug3C08+fXF\nEEBImeNAFqHkaal6YEClbwQYcL+YjJvK5zOdFxGTsWCqppp8rT4Uh/Jyx6brCUSm\nMVXYY9yspiWLhr5szy/1yIaLP+ZXgQjMEQWrJIex62N9GlXj4Lu1kHqaC7Oa+iOQ\nbxPN3V4x/MttDoxsXcOboP8UgudKIjlo3ODYC1Iw1Lv8aSET3BH+LljvYBNkOc76\njF/pokZfNecyIwDRdKomSSwyvOJEWbekApBL5NWh6M5usE4UbknmqhH7AgMBAAGj\nYzBhMB0GA1UdDgQWBBSbwf8yBKxR3J/O/1BD/ZMGMvsdSzBABgNVHREEOTA3gg5p\nZHBzaGliLmlsbC5mcoYlaHR0cHM6Ly9pZHBzaGliLmlsbC5mci9pZHAvc2hpYmJv\nbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAV9aMRpuOeaRTrWaCv0yyVomMU+BO9JAD\nvDb24KxeOiTiZ0Hl8cbF3lckBsA38eXegIkWkprQyNlsu4lAAd+11ocj6iLr2cYu\noomeohlNkcYvxGOQEdbMz0jkyvWHgy7A8JvgQJE8qJjKQHpt2axMAe9S4Pg2V5dr\ntjuEqopY4pc6Sp7DQaw4YxFhu+cxfrcRgAeRlyW2i9x0m5ZmKMdvmbJd0q8oScTN\n2FmYHprUiwFwHtlGuM8fKyB3Bv0Ys+F3ux5OfxWNykRV5hFwFtdEr1uiaClt9AHD\nE0ardMDf+phlxOcVQexaMrV2+3E+1Y12S/6z761q8J2WqyTX/KYsEQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institut Laue-Langevin"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ill.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institut Laue-Langevin"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.uta.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth-admin@uta.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UTA Shibboleth Administrators"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "hardy@uta.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jason Hardy"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth-admin@uta.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UTA Shibboleth"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uta.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.uta.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uta.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uta.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.uta.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uta.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uta.edu"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.uta.edu/oit/policy/Internet-privacy.php"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Texas at Arlington"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUC7oT6rb9pNSoCFZr77ngoXR+YG8wDQYJKoZIhvcNAQEF\nBQAwFjEUMBIGA1UEAxMLaWRwLnV0YS5lZHUwHhcNMTAwMTIwMTYxMTAyWhcNMzAw\nMTIwMTYxMTAyWjAWMRQwEgYDVQQDEwtpZHAudXRhLmVkdTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAJU8jgMoNNy0Wyvrp4oZRJRXPYeoWfTQV5svLHkz\nYCldQcgDkSHzT2M4PYt7gCAHUUu8FNWjdBlwsFvdnxp+0IOcXyKrNo9cIFavSaJZ\nFKBuHoYZC4t1BGoFMexS1TWj1Il0SIya/N0Z4J5aJocfPdu+JBSTMlI6OEBzNlW0\nQl231Rc4G1c17QBA4dXI0eCHP9jKutKU3NM+SCoubqwPjCnJYO2cXR4/CrBEmB7z\nqW+wKfBoPugFHkmKPZ14AOAb6pvt+ry/qppJwNQtPi27pu3M/wmIE5Ce1mhVB6vB\nZEwceCSslLIH669NNRKS/FgWY2cqVAHqE3wYSn5jqMDio1sCAwEAAaNdMFswOgYD\nVR0RBDMwMYILaWRwLnV0YS5lZHWGImh0dHBzOi8vaWRwLnV0YS5lZHUvaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFMj8dZUqAfFFMWV+9FjbtpOTg6xCMA0GCSqGSIb3\nDQEBBQUAA4IBAQBYOtZIVgRc/oCxwQ8+BMCnHNkfJ1zOfP62mjsRzoNlIBrj9cG+\nYhbEBG/OAYL4vlBRJTLUnZipi9Lz4QbB+nA2gS6D19vrxQv2tfg/I0Hr2crmPsD7\nF8a0cgjHXlUIPW6E/gtOLowuueFDEs5jpunYa2dVMyHhWhzveSANkrhqXjoiVFvX\nk7TvCpFqKCBxLTfs7tqZ7UfbliMLALsrHfa2IIuDy0JfFd74TSj9KbtNAL4hyTPB\nZPCie/YOLYcIFe7kKPlvkHB9DKXTlq2dPomPA3doG4aIjGK+GspD2OTsHs40W+Nj\nDhuK7YWFCjC6UIAyL63IXO/wa3uFVz2naO/3"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "error_url": "http://www.uta.edu/error"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Texas at Arlington"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uta.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Texas at Arlington"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://passporttest.lu.se/activateaccount/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://passporttest.lu.se/activateaccount/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://passporttest.lu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://passporttest.lu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://passporttest.lu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://passporttest.lu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://passporttest.lu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://passporttest.lu.se/Shibboleth.sso/Login-antagning",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://passporttest.lu.se/Shibboleth.sso/Login-eduid",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://passporttest.lu.se/Shibboleth.sso/Login-lu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://passporttest.lu.se/activateaccount"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://passporttest.lu.se/activateaccount"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "As a new user you use this service to activate your university user account."
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Denna tj\u00e4nst anv\u00e4nds f\u00f6r att du som ny vid universitetet ska kunna aktivera ditt anv\u00e4ndarkonto vid universitetet."
                  }
                ],
                "logo": [
                  {
                    "text": "http://www.lunduniversity.lu.se/sites/www.lunduniversity.lu.se/files/lund_university_logotype.png",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "http://www.lu.se/sites/www.lu.se/files/logo.png",
                    "lang": "sv",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lund University user account activation and password reset"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lund universitets kontoaktivering och l\u00f6senords\u00e5terst\u00e4llning"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "uwtestws01.uwtest.lu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAIXu3O5M/nIOMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF3V3dGVzdHdzMDEudXd0ZXN0Lmx1LnNlMB4XDTE0MTAyMTE1MDAyNFoXDTI0\nMTAxODE1MDAyNFowIjEgMB4GA1UEAxMXdXd0ZXN0d3MwMS51d3Rlc3QubHUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC5CSxXWUV+CxQKCIvis/Li\nounrcRbo5wb+6EUvyTNo5v8kiY+g6FTkVYypzYu2zMQMbMZMbLC6gIYHmoCTY4a4\n5SfP0UBrKFMr1fhnXNrRMhx3e2yRCMDQ6MW5TeTHyKqWt5LnQza5gdXF8rddXapU\nG3o7/6J9siYqJFS4qJ4flOtI98WA49jmiHJFutir6tS0FVqdLVNfmUIfo8+ua4dm\nWU7CXyKJkFIYfuCUyAWk7WWdrmjLMg+ujmbWG+lFRy0rU7JpMnOZ/4xnm4DdYYdT\noBka1qpxzdu4i7zKRwBvMpdeik6pbwMXcj9/qAq5wDm7OWulYwOceKbHLR/zUm1F\nAgMBAAGjRTBDMCIGA1UdEQQbMBmCF3V3dGVzdHdzMDEudXd0ZXN0Lmx1LnNlMB0G\nA1UdDgQWBBTHsEqrpHmU4lcM2mhVlQGMNN/agDANBgkqhkiG9w0BAQUFAAOCAQEA\nRbk93Mxqs96mm8RgxuogewDXQIwRsxEpdikP6VjhcHkCkM/oRpeXsGjgqY44BNuW\n8PwPRMjYlbqen8bzbOP9YknrC5QczVVgKIUFMRqE2TgU9pLl6MpLaH+weT8hKX/H\nEBmKKnmi55mNxx5bq3pu8vUL03VnqtjpssKXGLdY0waAdssxf0df72gNpKdQ+TMH\nhLW84PHAzXW4q3d3FK8RTe41YPbyFaosVULPyBrKm91A5qbfIdCvyz9rCYYeNiTC\ntnp8qHXMMEECQXRq8CM7UGqBJY9BUPRwGsyk0YpsRyqQzk2CR7IqQwj85V5HdQxi\nFLZnYYc2YEZAVn2+7pTtmA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=uwtestws01.uwtest.lu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://passporttest.lu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://passporttest.lu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://passporttest.lu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://passporttest.lu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://passporttest.lu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://passporttest.lu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://passporttest.lu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://passporttest.lu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://passporttest.lu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://dmp-stage.cdlib.org",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ken.weiss@ucop.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ken Weiss"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "marisa.strong@ucop.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marisa Strong"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "perry.willett@ucop.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Perry Willett"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dmp-stage.cdlib.org",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of California - Office of the President"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ucop.edu/welcome.html"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of California - Office of the President"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dmp-stage.cdlib.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dmp2-stg.cdlib.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dmp2-staging.cdlib.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://stg.dmptool.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "4"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://uc3-dmp2-stg.cdlib.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "5"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dmp-aws-stg.cdlib.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "6"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://dmptool.org/about"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DMP Tool Stage Instance"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Create, share, review, and publish Data Management Plans conforming to Institution and Funder requirements"
                  }
                ],
                "logo": [
                  {
                    "text": "https://dmp.cdlib.org/img/dmptool_logo.svg",
                    "lang": "en",
                    "height": "90",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "643"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://dmptool.org/privacy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAP8nYUVoOwwuMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDWRtcC5jZGxpYi5vcmcwHhcNMTEwODI2MTU0NDM2WhcNMjEwODIzMTU0NDM2\nWjAYMRYwFAYDVQQDEw1kbXAuY2RsaWIub3JnMIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAv+SS70RQmx9eI6GAAPKhb7G79Oz6VM9zoCc2RMihR0PsXH+4\nH8jr0OrrTYXw6Bvoy4q+nYoE/O94L427ayngaxsZGG99LOkqOnNJqx8YyhcHU+2V\nzE1H1puwHGtHjC8HaG5RAE2u+GBdfRFo7YwDiWZcovnxw1ADXpAebIIM6R6jFaam\ndRVAJld1USuxwe+v4BxhaQ983VNlDWD7tB/ppBYFIxaxc5eRYQ5Xhdc/tFbO7/R+\n7mNv1zEyx4j1d397abzLiWyUAfLYT9AnYY+G6JiXxiQ1Keq3Twkg3XGp6zI70RZR\n+CERZwZdV7T87DlVTRH+SLhlyL98NM8ftn+fqQIDAQABo3kwdzAdBgNVHQ4EFgQU\nNLEE8UmJURVhhxGQ9wjQTaLqwDUwSAYDVR0jBEEwP4AUNLEE8UmJURVhhxGQ9wjQ\nTaLqwDWhHKQaMBgxFjAUBgNVBAMTDWRtcC5jZGxpYi5vcmeCCQD/J2FFaDsMLjAM\nBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBVMgL73mP25ZYAyPUZlI/Z\ncO90zkhwQcoTYtIpdS2KE+XvLpC9yYFk7Xz+IaCbU7KYey/ZpW7MUTvddoSzRPDS\nulbxSugdfV7QVrt9bzaHSe8w20yMaVtRWAN8E9mFJNwJ8VSptxacc0ZdScHfmc76\nHejyMr9it7EuvpsxFQqDbgHqeXhqwdXrLiwTjn75bhx9+uT251W1wYG4gQ3R6Zly\nGSxO/I6if4vmR2y2vdDtugBNlmkIMwcE1pHTWxN0gHIQnItco+nQVrTzYmIgHMwv\nIdAUy0C4K5PdSbV8IUX1OZkeZyiQCdMs74p3IvKE57weopAz5Kxhiq9FlMh/LTx3"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dmp-stage.cdlib.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dmp-stage.cdlib.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dmp-stage.cdlib.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dmp2-stg.cdlib.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dmp2-stg.cdlib.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dmp2-stg.cdlib.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dmp2-stg.cdlib.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dmp2-stg.cdlib.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dmp2-staging.cdlib.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dmp2-staging.cdlib.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dmp2-staging.cdlib.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dmp2-staging.cdlib.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dmp2-staging.cdlib.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://stg.dmptool.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://stg.dmptool.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://stg.dmptool.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://stg.dmptool.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://stg.dmptool.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "18"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uc3-dmp2-stg.cdlib.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "19"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uc3-dmp2-stg.cdlib.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "20"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://uc3-dmp2-stg.cdlib.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "21"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dmp-aws-stg.cdlib.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "22"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dmp-aws-stg.cdlib.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "23"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dmp-aws-stg.cdlib.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "24"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "DMP Tool Stage Instance"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Create, share, review, and publish Data Management Plans conforming to Institution and Funder requirements"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-01.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-01.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-01.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-01.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-01.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-01.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-01.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-01.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-01.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;01"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;01"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-01.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-01.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJAIp2R64De+1HMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wMS5sYWRvay51bXUuc2UwHhcNMTIwNjI5MTE0NzE4WhcNMjIw\nNjI3MTE0NzE4WjAhMR8wHQYDVQQDExZsYWRvazMtMDEubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuwt+lqNvFGei/9H+xjcCTR6r\ngI5yUPlyK2ysVPvEk74oeWxFaCcHuvaiNUGjMwTyPiHSGijnyX9rHPfDTjphasn0\nM+OXn0j4RIBv6+tfLWr0NVM4CDK11/Dl34OivYe0bIx0hLhT+bXGddtb7AhNrzyi\nyN7eMtH8xVE4W0aZerCO0u7RR8fH/M8NE/Ge13cnoBgZH/oTVnQw4ZxwHmjGP9Ex\ntigoTyTwfYYGLt/Yx2Vg2dxJJPQ2oIiiaWN0/XxDy/hd3A5M9m5ZuJIzeflmVJLh\n4b9XsBzlbsK8KKiEKxDOUl9Gd8Lngl77kpFeephnngOMZoGQelFXPPalEndiUQID\nAQABo2swaTBIBgNVHREEQTA/ghZsYWRvazMtMDEubGFkb2sudW11LnNlhiVodHRw\nczovL2xhZG9rMy0wMS5sYWRvay51bXUuc2UvZ3VpLXNwMB0GA1UdDgQWBBTOzWRf\nEnLCvB5g3eADi4xLMzCoszANBgkqhkiG9w0BAQUFAAOCAQEAST3NMUyn+LDBfrts\ndfWxEJqOwHRplwn8eLNJHIdHkGjuLoR4cd1p40TLoMZrA/p6zU65oNrH9RYGiAOx\nAac35aJFgxDJm1R/x1mt6cAa7OmuJ0Zt2m4TCUsapPbpkKlZFwwH3JLqAyUXo/8d\nxcMCpGhUSP5Cs4L/HeJhFwQpf1UnQB1s8z4dfctQtzTkj5z3uZeHYir6U+slvK7w\n0zvLTz/CibUY0lmIhwyt5TvkJBqQ2ybSOwOtHL5ysMthtFoNGIXznFAITAMk8eOu\n/HIhJOQBcAW1bMonM41YOZsCP/FtAoskCFRWYck704VF6IKzZAxoq0PiN22YFjL7\np012eg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-01.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-01.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-01.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-01.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-01.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-01.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-01.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-01.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-01.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-01.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-20.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-20.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-20.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-20.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-20.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-20.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-20.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-20.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-20.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;20"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;20"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-20.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-20.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJAP9i/C5uDS/9MA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0yMC5sYWRvay51bXUuc2UwHhcNMTQwOTAxMTQ0NTM3WhcNMjQw\nODI5MTQ0NTM3WjAhMR8wHQYDVQQDExZsYWRvazMtMjAubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAyITHGtqwtjQ17vUS9ekptyke\n8HMK6m74SM+29ELjhpWa8IXQCVTtyl2v+YaOMB+CjEQoX2AxFvOrQRp5n5sFl//f\nCWSlaUXw0yG7NmIsANb9+MzeJDaTlSx9XXwfU7OnNhhEH08ztJZLxJ/9OM3RZYYB\n2UMwsVUjngP6R8VAy6A0Nk0AzPmI2s7jvdTZduQVtjhq1MwKG2ZwwpT2hcHVX9Eh\naFSOrm/ElqO6NzGrUFXGMC9JIJKn59MdP1aAbl79wKWocJGFSO/nP7H+p85h/2DA\nuGh4OS2ZcBYwYIllKCrJeBBc3xlUCS5jy7JRph6omYQheHhpfUCG5fZwDW5MgQID\nAQABo2swaTBIBgNVHREEQTA/ghZsYWRvazMtMjAubGFkb2sudW11LnNlhiVodHRw\nczovL2xhZG9rMy0yMC5sYWRvay51bXUuc2UvZ3VpLXNwMB0GA1UdDgQWBBRRjewj\n+RkDbgBzUYhv1AtAm78xVTANBgkqhkiG9w0BAQUFAAOCAQEANtzq/m6r8ixYw7X9\npCmG8lUBhlL+d0kpZao0R7M10ovxG9BNwdUDBiyR5TP1bBkhv8KNnD3Y0vMtP1sF\nxD3ZG05TvmmKV8Xla4M7FjZ6dXnHP1KexAvrXUdBxOuhG88673UdRFHr47Rvm1IR\nlA/ergBFuPzr5pBE5V6s/xHChP14goY7iKUeWdS43OZ5LlUEfc3qO3jwW/Ap2tfS\nd9eoM0DDTIkn/j0WuqB37APPzQYsVieCzwfSmyHSm5mBCUj+n7K5r2EtcBswCL2m\nplB0nnsLw+yXr4em7Eyf+h9YDEgAdvXqtGstp37+xxUjAsHEHVVs+Ouo47J8mM0J\nzxjcig=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-20.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-20.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-20.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-20.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-20.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-20.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-20.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-20.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-20.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-20.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.csustan.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "CWincentsen@csustan.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris Wincentsen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "CCardoza@csustan.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Corey Cardoza"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.csustan.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.csustan.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.csustan.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUGMBL/KES+CItQJGiZd2xZSh8rJkwDQYJKoZIhvcNAQEF\nBQAwITEfMB0GA1UEAxMWc2hpYmJvbGV0aC5jc3VzdGFuLmVkdTAeFw0wOTA5MDEy\nMTExMDlaFw0yOTA5MDEyMTExMDlaMCExHzAdBgNVBAMTFnNoaWJib2xldGguY3N1\nc3Rhbi5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCjiFi9hRTI\nuF6n0w82/XQHlhhj34q59TzPvf9vPh9pjgxd6sju/hCY1tx/hmAf5Woa2ilegpVt\niy+G3tZCKgaJdVLq49zgEmKU0VYXCliGaLW1gtpwKdUYLY3M47oReql3lGlb0ml9\nzC4f8yeg7tCP1+OpnSt2EGR38SqNKqGSpdtsNVP007G4FYOZ5I/bDwCGbdyMrEuH\nG8hmXVSZOtt36Z8uXnVZb8ZWMruEvwm4Ch4SYp1ArSXF7eqyWI5juNQA8orzBjCe\nC/vpF08H/iZsAJ5ZtRYU77046cJwvzsRuFyfl74A6p4iFUl9botcIAE6O+kix2z/\n4QnLRK7kpLTzAgMBAAGjczBxMFAGA1UdEQRJMEeCFnNoaWJib2xldGguY3N1c3Rh\nbi5lZHWGLWh0dHBzOi8vc2hpYmJvbGV0aC5jc3VzdGFuLmVkdS9pZHAvc2hpYmJv\nbGV0aDAdBgNVHQ4EFgQU0+lADdpb6oUYg9Oc96Zjx/cFThswDQYJKoZIhvcNAQEF\nBQADggEBAFqASbOPNSUo4KijkXfQv9yemFmjX5g0FBO3quSUtmX0XFHMkJrAfkUQ\n34KIwGE1NKEnR5DE2CMhi+CMLM3UwsV/AH54PfMnFZYxKOeya1h5ou99rliwYfE/\noERIMqkMdqfZI2eVOmjKMfgZMpjhSAjqkvuZ0lJSrHM6GhJTZGVF1qHHxAniNJuL\nEiG0dCIfR86g8fLLIKB2T6NExYY6yYJHobC9h8G9IiR+2QAf/UxuC6hEGAQAnUWj\nNqWgMu7TiZy0oedXYZYYaAHmWQDJWXt2SGC11bB8qtEU2tcccppV75MWjC7SYqko\n+1hpIr+zlLqhBIi73qZPIVggyEH8HpE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csustan.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.csustan.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.csustan.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.csustan.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.csustan.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.csustan.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.csustan.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csustan.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "California State University, Stanislaus"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUGMBL/KES+CItQJGiZd2xZSh8rJkwDQYJKoZIhvcNAQEF\nBQAwITEfMB0GA1UEAxMWc2hpYmJvbGV0aC5jc3VzdGFuLmVkdTAeFw0wOTA5MDEy\nMTExMDlaFw0yOTA5MDEyMTExMDlaMCExHzAdBgNVBAMTFnNoaWJib2xldGguY3N1\nc3Rhbi5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCjiFi9hRTI\nuF6n0w82/XQHlhhj34q59TzPvf9vPh9pjgxd6sju/hCY1tx/hmAf5Woa2ilegpVt\niy+G3tZCKgaJdVLq49zgEmKU0VYXCliGaLW1gtpwKdUYLY3M47oReql3lGlb0ml9\nzC4f8yeg7tCP1+OpnSt2EGR38SqNKqGSpdtsNVP007G4FYOZ5I/bDwCGbdyMrEuH\nG8hmXVSZOtt36Z8uXnVZb8ZWMruEvwm4Ch4SYp1ArSXF7eqyWI5juNQA8orzBjCe\nC/vpF08H/iZsAJ5ZtRYU77046cJwvzsRuFyfl74A6p4iFUl9botcIAE6O+kix2z/\n4QnLRK7kpLTzAgMBAAGjczBxMFAGA1UdEQRJMEeCFnNoaWJib2xldGguY3N1c3Rh\nbi5lZHWGLWh0dHBzOi8vc2hpYmJvbGV0aC5jc3VzdGFuLmVkdS9pZHAvc2hpYmJv\nbGV0aDAdBgNVHQ4EFgQU0+lADdpb6oUYg9Oc96Zjx/cFThswDQYJKoZIhvcNAQEF\nBQADggEBAFqASbOPNSUo4KijkXfQv9yemFmjX5g0FBO3quSUtmX0XFHMkJrAfkUQ\n34KIwGE1NKEnR5DE2CMhi+CMLM3UwsV/AH54PfMnFZYxKOeya1h5ou99rliwYfE/\noERIMqkMdqfZI2eVOmjKMfgZMpjhSAjqkvuZ0lJSrHM6GhJTZGVF1qHHxAniNJuL\nEiG0dCIfR86g8fLLIKB2T6NExYY6yYJHobC9h8G9IiR+2QAf/UxuC6hEGAQAnUWj\nNqWgMu7TiZy0oedXYZYYaAHmWQDJWXt2SGC11bB8qtEU2tcccppV75MWjC7SYqko\n+1hpIr+zlLqhBIi73qZPIVggyEH8HpE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California State University, Stanislaus"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csustan.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California State University, Stanislaus"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://engine.surfconext.nl/authentication/sp/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Technical Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrative Contact"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://engine.surfconext.nl/authentication/sp/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2011-06-08T02:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SURFnet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SURFnet"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.surfnet.nl/nl/Pages/default.aspx"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.surfnet.nl/en/Pages/default.aspx"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SURFnet BV"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SURFnet BV"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SURFconext is een samenwerkingsinfrastructuur die nieuwe vormen van samenwerken mogelijk maakt door diensten van verschillende aanbieders te combineren."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SURFconext is a collaboration infrastructure that creates new opportunities to collaborate online based on a combination of applications from different providers."
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/media/idp/surfnet.png",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SURFconext | SURFnet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SURFconext | SURFnet"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "want_assertions_signed": "true",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://engine.surfconext.nl/authentication/sp/consume-assertion",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "nl",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SURFconext - Engine | SURFnet"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SURFconext - Engine | SURFnet"
                }
              ],
              "service_description": [
                {
                  "lang": "nl",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "SURFconext is een samenwerkingsinfrastructuur die nieuwe vormen van samenwerken mogelijk maakt door diensten van verschillende aanbieders te combineren."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "SURFconext is a collaboration infrastructure that creates new opportunities to collaborate online based on a combination of applications from different providers."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:mace:dir:attribute-def:mail",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:mace:dir:attribute-def:displayName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:mace:dir:attribute-def:sn",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:mace:dir:attribute-def:givenName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:mace:terena.org:attribute-def:schacHomeOrganization",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:mace:terena.org:attribute-def:schacHomeOrganizationType",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:mace:dir:attribute-def:uid",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:mace:dir:attribute-def:cn",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonEntitlement",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:mace:dir:attribute-def:preferredLanguage",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://primotest.abdn.ac.uk/shib",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Macarthur"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:c.macarthur@abdn.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chrissie"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Macarthur"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:c.macarthur@abdn.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chrissie"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://primotest.abdn.ac.uk/shib",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Aberdeen: Primo Resource Discovery (test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.abdn.ac.uk/library/about.shtml"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Aberdeen"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://primotest.abdn.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://primotest.abdn.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://primotest.abdn.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://primotest.abdn.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://primotest.abdn.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://primotest.abdn.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://primotest.abdn.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJANJZVmK8+XpGMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\n\t\t\t\t\t\tBAMTFHByaW1vdGVzdC5hYmRuLmFjLnVrMB4XDTExMDcxMzA3NTEzNloXDTIxMDcx\n\t\t\t\t\t\tMDA3NTEzNlowHzEdMBsGA1UEAxMUcHJpbW90ZXN0LmFiZG4uYWMudWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQD5eVGCkyjaiKuouemgreU03zdLqREO\n\t\t\t\t\t\tVwxuwzd/eUQ1wymVUOjlxofXiT2zbsn0U++WUmD0MgR4DMs2ZFxfSBWJDuVHk7DW\n\t\t\t\t\t\tbnpkC2U1ookX8Um63uYnmx6MF7BaM9MOyYAEYKMlZNMOX28zbaSOVuGAc1Q9yFkL\n\t\t\t\t\t\tU2WN6pZKIXQC5gSYo4Y3YwQqAqiK6ShU3NQrZPdHX0kgfpVCEyODA3fTCxczCTss\n\t\t\t\t\t\td5xvMq/Y6HhrAOOCNm7l8hPsIwnRyIqio3PdfDCUPBZ48fHQCEWazaUtLEYwu9NL\n\t\t\t\t\t\tYFQmGQIe9qv6dJ/wd/M+XbDhZ8k/9Lh6kuOrzEqcD3LEHYu9hyF/vz3bAgMBAAGj\n\t\t\t\t\t\tQjBAMB8GA1UdEQQYMBaCFHByaW1vdGVzdC5hYmRuLmFjLnVrMB0GA1UdDgQWBBSL\n\t\t\t\t\t\th1KihDFxRIVjQQ4CxS58qfCXZjANBgkqhkiG9w0BAQUFAAOCAQEAlysZy/rmOO6c\n\t\t\t\t\t\tFwbLDhIDKqdqCMm9Dq8jBZTwxd4z2AwOienEaMp0tmWc2fMSLYu+UQhEb36dDjOi\n\t\t\t\t\t\tLbAsMsI1TcZIc6WERZ8BdpP9LG6v1NvyfOmDaw8oBT9UJyOPleeXtv/4OqrOdbAk\n\t\t\t\t\t\tRpHvoxq6fmeJpbQeEZqbRszVqCO/yTjJlx/eSIS92NHk8Y0so14/Not8QWFRCVxH\n\t\t\t\t\t\tNta2tgU0F6QZ4efIfZjyquoIZcDzEZJJdp/6HTmtkffnGCYDBICrm7p7AZXHLwWS\n\t\t\t\t\t\tKKuNQE75OgaFXXpH1sbGq6ZGQk6Lc2YIY4NxolHMzWFhuF+ERp73ZMgItrKlGGez\n\t\t\t\t\t\toBMSqs6ZDw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://primotest.abdn.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://primotest.abdn.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://primotest.abdn.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://primotest.abdn.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://primotest.abdn.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://primotest.abdn.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://saml-delegation.data.kit.edu/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hardt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hardt@kit.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marcus"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hardt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hardt@kit.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marcus"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hayrapetyan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:arsen.hayrapetyan@kit.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Arsen"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://saml-delegation.data.kit.edu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-02-03T14:35:45Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Karlsruher Institut f\u00fcr Technologie (KIT)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Karlsruhe Institute of Technology (KIT)"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.scc.kit.edu/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.scc.kit.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e148"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e148"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://saml-delegation.data.kit.edu/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://saml-delegation.data.kit.edu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://saml-delegation.data.kit.edu/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://saml-delegation.data.kit.edu/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SAML Delegation"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SAML Delegation"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SAML Delegation"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SAML Delegation"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "saml-delegation.data.kit.edu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGBjCCBO6gAwIBAgIHF7FBl8mW2DANBgkqhkiG9w0BAQsFADCBvzELMAkGA1UE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\ngwAMmqDbvXQigg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=saml-delegation.data.kit.edu,O=Karlsruhe Institute of Technology,L=Karlsruhe,ST=Baden-Wuerttemberg,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://saml-delegation.data.kit.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://saml-delegation.data.kit.edu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://saml-delegation.data.kit.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://saml-delegation.data.kit.edu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://saml-delegation.data.kit.edu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://saml-delegation.data.kit.edu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SAML Delegation"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SAML Delegation"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "SAML Delegation"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "SAML Delegation"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ufe.cas.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Van\u00ed\u010dek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vanicekp@utia.cas.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ufe.cas.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2014-06-12T10:58:21Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/avcr"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUcKS5gFpqf8X/ZLLjYuIQpzjjeXkwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOaWRwLnVmZS5jYXMuY3owHhcNMTQwNTI3MTIxMDE5WhcN\nMzQwNTI3MTIxMDE5WjAZMRcwFQYDVQQDEw5pZHAudWZlLmNhcy5jejCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL5cOnmanq68cqOF7oxg6U5BGUKlj5Wo\nsVPtKUjmSy57yzhLnrIZ9UMKESIuPuBuSKbyTnt7JbjounGkMiwhCIf61hJiOs8b\nJlptSG7WXnLbHcOhMWjiCmbWawWVTLyPNWTlUvUaq3JB5zGNQXOlILfn/UkHnbMl\nIja8zQ5yhAYvHZ/maGHsnkx92ds87Kcxtz6CjIDlcbo/XAVoLizNWAedeji1FUbc\nEdOdDiJZN+OOnfVxPbDYcRc2uls3YloLsZtbyXO8lKViCiUSlPGPEelx8NxinDDY\nIwZ8hPpiu94Uv5lCkvo9XdAG7RBZsmqiodz0oXGIEsFscS6PKTa3MEUCAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOaWRwLnVmZS5jYXMuY3qGJWh0dHBzOi8vaWRwLnVmZS5j\nYXMuY3ovaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFPVVqO7eJSBY4afM8pfpuTFT\n3rfqMA0GCSqGSIb3DQEBBQUAA4IBAQAg2FJw4TFDfXuCmJP3iPqVLlf+e5ViqQdo\nhum8X97d5zxkPtUShw6U5SLy4Styi36BdaIKsWiGodF+pmqse7QPeJyxRqDtUBUB\n9X4eWbxuhghrbROsP75/QmpqFJVBQiNYd+AyDNSmROseXxqMVqeZ+EzLtHPki0Yj\n3Os7z22eK8t8BBMnOrUskvKYEfFDHyf7rCirwK1vL53LHyPh1gSF7vPwvJ6Zvojh\nJNJvSY9ZNxjgsFNR7HEgyGNt59E+ITrLP2u4Ch2iy0n/tqZgiu6xjXJtIO1l+dDu\nhDT+yeRSzypRvdHOYKvyiqoNLBc/64BpcsCwvR2xGXwDjT2frVjp"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufe.cas.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ufe.cas.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ufe.cas.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ufe.cas.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ufe.cas.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ufe.cas.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ufe.cas.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ufe.cas.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ufe.cas.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ufe.cas.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ufe.cas.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ufe.cas.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufe.cas.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufe.cz/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufe.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider UFE AV CR employees."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance \u00daFE AV \u010cR"
                  }
                ],
                "logo": [
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-ufe-44.png",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-ufe-216.png",
                    "height": "216",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "247"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Photonics and Electronics of the AS CR"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u00dastav fotoniky a elektroniky, Akademie v\u011bd \u010cR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUcKS5gFpqf8X/ZLLjYuIQpzjjeXkwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOaWRwLnVmZS5jYXMuY3owHhcNMTQwNTI3MTIxMDE5WhcN\nMzQwNTI3MTIxMDE5WjAZMRcwFQYDVQQDEw5pZHAudWZlLmNhcy5jejCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL5cOnmanq68cqOF7oxg6U5BGUKlj5Wo\nsVPtKUjmSy57yzhLnrIZ9UMKESIuPuBuSKbyTnt7JbjounGkMiwhCIf61hJiOs8b\nJlptSG7WXnLbHcOhMWjiCmbWawWVTLyPNWTlUvUaq3JB5zGNQXOlILfn/UkHnbMl\nIja8zQ5yhAYvHZ/maGHsnkx92ds87Kcxtz6CjIDlcbo/XAVoLizNWAedeji1FUbc\nEdOdDiJZN+OOnfVxPbDYcRc2uls3YloLsZtbyXO8lKViCiUSlPGPEelx8NxinDDY\nIwZ8hPpiu94Uv5lCkvo9XdAG7RBZsmqiodz0oXGIEsFscS6PKTa3MEUCAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOaWRwLnVmZS5jYXMuY3qGJWh0dHBzOi8vaWRwLnVmZS5j\nYXMuY3ovaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFPVVqO7eJSBY4afM8pfpuTFT\n3rfqMA0GCSqGSIb3DQEBBQUAA4IBAQAg2FJw4TFDfXuCmJP3iPqVLlf+e5ViqQdo\nhum8X97d5zxkPtUShw6U5SLy4Styi36BdaIKsWiGodF+pmqse7QPeJyxRqDtUBUB\n9X4eWbxuhghrbROsP75/QmpqFJVBQiNYd+AyDNSmROseXxqMVqeZ+EzLtHPki0Yj\n3Os7z22eK8t8BBMnOrUskvKYEfFDHyf7rCirwK1vL53LHyPh1gSF7vPwvJ6Zvojh\nJNJvSY9ZNxjgsFNR7HEgyGNt59E+ITrLP2u4Ch2iy0n/tqZgiu6xjXJtIO1l+dDu\nhDT+yeRSzypRvdHOYKvyiqoNLBc/64BpcsCwvR2xGXwDjT2frVjp"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Photonics and Electronics of the AS CR, v.v.i."
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u00dastav fotoniky a elektroniky, Akademie v\u011bd \u010cR, v.v.i."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufe.cz/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufe.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Photonics and Electronics of the AS CR"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u00dastav fotoniky a elektroniky, Akademie v\u011bd \u010cR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.inp-toulouse.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Vincent CHONG-WING"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vincent.chong-wing@inp-toulouse.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.inp-toulouse.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-09-27T14:12:08Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.inp-toulouse.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.inp-toulouse.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.inp-toulouse.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "inp-toulouse.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.inp-toulouse.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INPT - Institut National Polytechnique de Toulouse"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INPT - Institut National Polytechnique de Toulouse"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUT/ZV7f3Lusa+9lbOZVbS0YCpfgwwDQYJKoZIhvcNAQEF\nBQAwHjEcMBoGA1UEAxMTaWRwLmlucC10b3Vsb3VzZS5mcjAeFw0xMzA5MjcwOTA1\nMzJaFw0zMzA5MjcwOTA1MzJaMB4xHDAaBgNVBAMTE2lkcC5pbnAtdG91bG91c2Uu\nZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDCjHZkvuctwIDMU/L1\n5Ob1BjzGWbbGwan/PZ3bilttwf37Ve/ZsFHBfI7YF6tFw8guYRRl1dmAkHxxZCIB\nzo4PGcFQFUkb8K1+hi1ev6f71LP2BOEJWsQ9NsO4HDbpTzqGrCrXgG7LlTGpBhOT\nCRevT5z7hd9qTk6pW+nbG3mY2NnKTm2WpjFaycYZiF07yFJGBWIh5ndkhfyBF21R\nN2D7sHRqByVLBzU4vZfRuo8cG6Ufx76whxZGRqZq8kmTWuU1sBPhore83Y1NuYIs\ncM/BhndXVwdN0GSE3eeJpIHJ3txhPtk8HbU8jz6y7qOHPMgLmnxkpFdMn47hmGCF\nt+lvAgMBAAGjbTBrMEoGA1UdEQRDMEGCE2lkcC5pbnAtdG91bG91c2UuZnKGKmh0\ndHBzOi8vaWRwLmlucC10b3Vsb3VzZS5mci9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4E\nFgQUTWqwiYs7axsJyzXQr+TFjSLuKLEwDQYJKoZIhvcNAQEFBQADggEBAB3fpoVO\nbwmHRurLoU76J1fK/eoaNGL6+TRUW6DlV8nw1qDI+staKmlmbiKlzHCYCXGw8+hX\nNnaHlYPj/89d9A9XnA9UgsTio3p2SxaL+Z2XQg7mmrG4zNGrSDByNRsmG43H0W3U\nI/1OI5Pc27jS97gnIrbgdh7c9W0EuzBMYB1X2n+FXC4IJVRbRap4w5okGxztKYdv\nnJWM2NmnEkHvKTR2q49aCZGjI//t6qrUyOpt03XVabmbBfhYrNbv1ox9cYDWQ6zK\n6ry/CkIwbFwR9jLRuE67WIfLURxILClIr1NlUymiFsuPB4NV90s9HNf1bYPQdJ2C\nlr6eMsR0+Pc7BjU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEczCCA1ugAwIBAgIQUvXDGTom14VWyQKZ9c5IAjANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDkyNzAwMDAwMFoXDTE2MDkyNjIzNTk1OVowQTEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRwwGgYDVQQDExNpZHAuaW5wLXRv\ndWxvdXNlLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA7A4XoLiZ\nKxOT2emX//nkJR8xl1027xOPLZrzxafUvNxSvIiAknbYdq7fqBE2VONDG9/IwRyW\nw76e/jHbYpd+fZppURwGHPXh47gX8DvMOHf3EYFC1WdiaKWT9ZnO3QDKgVUm+uqV\n4aZtQG/NLjfW2lQNjLR59YDCFeLG7KJKXo49yRpSlE9+xG/aw/XYk+GepUiwUkyY\nhF5OfMzvJobYfW2FZFARkfl8hSsumasyTPTNPL2JR0SvjkNdneh8aYDV+o3E8gQM\nhw1aX6xcuAArW576MEtgYHOK+u9jsC24MxNYws5P7Xr8HhwBFdHlcbwv6nTUPhoi\n/HLjV++A91qkOQIDAQABo4IBcDCCAWwwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsr\nN1dH6pDjue0wHQYDVR0OBBYEFP8muWtxJiygf1agWB042qtYx8P3MA4GA1UdDwEB\n/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEF\nBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8E\nMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENB\nLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNz\nLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8v\nb2NzcC50Y3MudGVyZW5hLm9yZzAeBgNVHREEFzAVghNpZHAuaW5wLXRvdWxvdXNl\nLmZyMA0GCSqGSIb3DQEBBQUAA4IBAQDBuKUisPU8fheH+AhEa2g+FBZM77HHMJr6\nLvRgxynTPLStnsMLJ5AvRB5A5lp01OYxVWMUY1MvuJN3qbTbemfYqPrjl/iT6sQW\nSfqE3lvWtl+yqUtFJ5LSU0506dsuQTRoifxnkUKLWLmwnOiSMbO6FMrr8DCirVND\nVOMMA2MQMmQm+e+bKYxc4SFtCWqbMgAtwbYayZ5B1Essntx2tiYZqB4V00BvbBR8\nQitJtSVJ5UEYiVLK35rrj7909QURc7UsgZ9iJeueTGvFsYqo+CY6piFLJR7AH4ig\ngx11BVKtBfjtJ60W2R+4M63zQHh+58b7FR3/AYpWkWtFgxac775M"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INPT - Institut National Polytechnique de Toulouse"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.inp-toulouse.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INPT - Institut National Polytechnique de Toulouse"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.cndp.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Alexandre LUCAS"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "alexandre.lucas@cndp.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Simon BIGOT"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "simon.bigot@cndp.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.cndp.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-10-31T15:08:09Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.cndp.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.cndp.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.cndp.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cndp.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.cndp.fr"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CNDP - Centre National de Documentation P\u00e9dagogique"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CNDP - Centre National de Documentation P\u00e9dagogique"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAPGwxNIFT88TgM2ndmBAqxnLIgA6MA0GCSqGSIb3DQEB\nBQUAMB0xGzAZBgNVBAMTEnNoaWJib2xldGguY25kcC5mcjAeFw0xMzEwMzEwODE0\nMTJaFw0zMzEwMzEwODE0MTJaMB0xGzAZBgNVBAMTEnNoaWJib2xldGguY25kcC5m\ncjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANcmMpskeoFHzssZUII5\n4pz7M6i7OXbgHJZR9pMGoAz5vOOt9cjmPsh+ZFkW2tjGAk4dEMzUrdk3lqhMjwdr\n06Nw2FBqUYKG/OP//lPOaYYyF7VaUei4Da7KL+NMsUW4S8gACmwl7NwqCTnhaXQ9\nD8J6ChWjaxQmvUDYVG8ktDsqwbrzUqq+yAbCd6i5EOZOJ169Xg/Y0IUiPMREU7ho\nyQfQHnw7bmkMSIOjoOkEFZK7zZzr0+ce3ZUTjCimv9ys7NCLDSJWVvifwHt2lRFG\niRaIPyn6Oh308mmoizVTCalVRoYV0w+gVu9d0/WOt3Zj+DaCKIB+eOL0YTylZNTr\n4g0CAwEAAaNrMGkwSAYDVR0RBEEwP4ISc2hpYmJvbGV0aC5jbmRwLmZyhilodHRw\nczovL3NoaWJib2xldGguY25kcC5mci9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\nB/TrtIJ0tEcByCbKeQMho+xJCQMwDQYJKoZIhvcNAQEFBQADggEBAF+sG6yrz/ao\n30uEN8NpTHFmuiFjFeInMboFMb987yjaA1RonVH3+VquF92H1e8ZDBZK/VRdP7xi\nV42K4OajjP8NYPl0+JwHEvJaGNEhXOm1NNhCw6o/H+VYcqtriqunZc5Ob4p6vsXA\n8IC4FI56+0/UFMFrCPpXh5f/3JrjYAzLACLZAOsD4G3eBWdtnfn5oEz1Prpq6U6a\nRk5+4EQFr07QmhKWuVCb73np6gGnQfI5qs2cUeDEwKSnw9yJfpiuwlGPakiFrfpI\nAUNVNoq0d2wvNKP1kf4vaGmG1/S/s5cBKDp7z5amg6TauBbDwnoKGyoIY9602jMK\nk93krCoGtSQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CNDP - Centre National de Documentation P\u00e9dagogique"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cndp.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CNDP - Centre National de Documentation P\u00e9dagogique"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://yorksj.idm.oclc.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Support Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Support Desk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://yorksj.idm.oclc.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-12-08T10:21:53Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "York St John University Hosted EZProxy"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oclc.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "OCLC (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://login.yorksj.idm.oclc.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.yorksj.idm.oclc.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.yorksj.idm.oclc.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.yorksj.idm.oclc.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEAjCCAuqgAwIBAgIBAjANBgkqhkiG9w0BAQUFADBjMR4wHAYDVQQDFBUqLnlv\n\t\t\t\t\t\tcmtzai5pZG0ub2NsYy5vcmcxCzAJBgNVBAYTAlVLMQ0wCwYDVQQKEwRPQ0xDMSUw\n\t\t\t\t\t\tIwYJKoZIhvcNAQkBFhZjYXJsLnByZW50aWNlQG9jbGMub3JnMB4XDTE1MTIwMzEy\n\t\t\t\t\t\tMTczNFoXDTI1MTIwMjEyMTczNFowYzEeMBwGA1UEAxQVKi55b3Jrc2ouaWRtLm9j\n\t\t\t\t\t\tbGMub3JnMQswCQYDVQQGEwJVSzENMAsGA1UEChMET0NMQzElMCMGCSqGSIb3DQEJ\n\t\t\t\t\t\tARYWY2FybC5wcmVudGljZUBvY2xjLm9yZzCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBAL+tfKrFFd1ymOHjZD7zJ7rQkv4lFreDEmN4D5lfsSj8erf41o9u\n\t\t\t\t\t\tkG0l7AXh9UbI1LBg3v3jOOzCQg9C8PWZNs0vbQzw4mxaiSueFwH7GzhvgDujWeGx\n\t\t\t\t\t\tPI+mdJZUvaZ52V7QXrSrpw+H1+ZIw5JwPpqBOU3BaMPWnQiXHGKltkdifUB3IEBb\n\t\t\t\t\t\tbUlMhitpbpUh0qJQ4eBDSzlCn6kAaZPWfsagxOw0fwhcDPgsDGUyg2JmVUDbOKiR\n\t\t\t\t\t\tLDyHy/NQ5SxliXHLchAE8GSyYjxiLgvMBgE23UM07r4fpjDdkJd3oKfZGP+Orn6/\n\t\t\t\t\t\tnigLso1sDrentFJGFqeq5CmDHSPJR7HHUtUCAwEAAaOBwDCBvTAdBgNVHQ4EFgQU\n\t\t\t\t\t\tM+bNiK6Tcy3ZVKVsImZjdPHoUZgwgY0GA1UdIwSBhTCBgoAUM+bNiK6Tcy3ZVKVs\n\t\t\t\t\t\tImZjdPHoUZihZ6RlMGMxHjAcBgNVBAMUFSoueW9ya3NqLmlkbS5vY2xjLm9yZzEL\n\t\t\t\t\t\tMAkGA1UEBhMCVUsxDTALBgNVBAoTBE9DTEMxJTAjBgkqhkiG9w0BCQEWFmNhcmwu\n\t\t\t\t\t\tcHJlbnRpY2VAb2NsYy5vcmeCAQIwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAQvX5qoqjU9sj+AK3btvsmKTagxOQ7dTwWYm5+cwx1wmIf/5sZ67XxBB4\n\t\t\t\t\t\tui7ASYoxOb9sRrhyRnCpLt5PjfnFxNxX8RDwm2H/t6cFya/fNssw+GnvQZAgSZpR\n\t\t\t\t\t\t3L1HNTI6YbR4m6onKlLMXu3VrgqcA/g8bDhKq9JB5g4/3592j15GXiDFQ9JA788V\n\t\t\t\t\t\tHZ+vwB/5IDoKQoji7ssjOsIWWlX43lMxUY6WvPacUbNafLpThg5+OdPRvDdUodYX\n\t\t\t\t\t\tx8+iWhypU+0PMmbT7UrlG2+/uSRmRLNeaCoQVr+14W0xwHxhCJDmtj9b7zeOpo83\n\t\t\t\t\t\t0HjZ+GpyGsL30j9kUcEvOhsYYDPKvA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://login.yorksj.idm.oclc.org/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://openarchive.ki.se/shibboleth",
    {
      "entity_id": "https://openarchive.ki.se/shibboleth",
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Karolinska Institutet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ki.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "KI"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://openarchive.ki.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://openarchive.ki.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://openarchive.ki.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://openarchive.ki.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://openarchive.ki.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Arkiv f\u00f6r fulltextpublicering av publikationer vid Karolinska Institutet."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Archive for full text publications from Karolinska Institutet."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "KI Open Archive"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "KI Open Archive"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "publications.ki.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE+jCCA+KgAwIBAgIJAOQykWZUCZpqMA0GCSqGSIb3DQEBBQUAMIGuMQswCQYD\nVQQGEwJTRTETMBEGA1UECBMKU29tZS1TdGF0ZTEOMAwGA1UEBxMFU29sbmExHjAc\nBgNVBAoTFUthcm9saW5za2EgSW5zdGl0dXRldDEbMBkGA1UECxMSVU5JVkVSU0lU\nWSBMSUJSQVJZMRswGQYDVQQDExJwdWJsaWNhdGlvbnMua2kuc2UxIDAeBgkqhkiG\n9w0BCQEWEXViaXRkb3NAa2liLmtpLnNlMB4XDTEwMDMyMzE1MzQ0OFoXDTIwMDMy\nMDE1MzQ0OFowga4xCzAJBgNVBAYTAlNFMRMwEQYDVQQIEwpTb21lLVN0YXRlMQ4w\nDAYDVQQHEwVTb2xuYTEeMBwGA1UEChMVS2Fyb2xpbnNrYSBJbnN0aXR1dGV0MRsw\nGQYDVQQLExJVTklWRVJTSVRZIExJQlJBUlkxGzAZBgNVBAMTEnB1YmxpY2F0aW9u\ncy5raS5zZTEgMB4GCSqGSIb3DQEJARYRdWJpdGRvc0BraWIua2kuc2UwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC11ax7K5PjR3GFpvzT37OKa1ycH3Rt\nz0GNApRMQtS7x9q1wgRjA3dqdTSIIJettkBgyEUOfB0f1MgcaMtaNIPhDJfMCqdr\nQ6dPKp+F0b7P7jWezyWNt8gVKXSOaeJYjze56zURO+MK8CA4sTpttqgcOOv5pnhN\nwyEuYmQBYtKGvcH13jJPStsQ+s5LZ9NX/5gV64DrRI4s64d9r0FH78lHzkM2TqHI\n0ce2KeZdn3AgXy1tOW58nUKVlUNgsFZyg/GH0ICZ08tOo1YHWBu1iuZQrzfKI655\nj8R4gElSbT+Sp770OoC9qgoBsQQdh3N/Pj+/RvgSTMG3cOmtIlNu/YjpAgMBAAGj\nggEXMIIBEzAdBgNVHQ4EFgQUjs01iDGc22yXqpCThMLfgM12WCAwgeMGA1UdIwSB\n2zCB2IAUjs01iDGc22yXqpCThMLfgM12WCChgbSkgbEwga4xCzAJBgNVBAYTAlNF\nMRMwEQYDVQQIEwpTb21lLVN0YXRlMQ4wDAYDVQQHEwVTb2xuYTEeMBwGA1UEChMV\nS2Fyb2xpbnNrYSBJbnN0aXR1dGV0MRswGQYDVQQLExJVTklWRVJTSVRZIExJQlJB\nUlkxGzAZBgNVBAMTEnB1YmxpY2F0aW9ucy5raS5zZTEgMB4GCSqGSIb3DQEJARYR\ndWJpdGRvc0BraWIua2kuc2WCCQDkMpFmVAmaajAMBgNVHRMEBTADAQH/MA0GCSqG\nSIb3DQEBBQUAA4IBAQBcI4P5JLCJuTCKie7Ze/NucF3tBgcXllnSYo7z4NSafr0i\nCrsoBPoxg1Sr7cFXSCRWLUr7Di2WfdQLrn3ZY1sPTYKWlgEmWVYFiSph2HYv04L9\nI72Jn8DLvaNCqew7KYgCODkSFRUFxzGDlWho0cXHMwP31/dEVEa2mUwmMEzG+ScQ\nDII+Op9QBwqJ7VgT7RLwhH6txbcicwNdfQYktXy/C7ysmUAS6XW1vE3H3LDd6Oc5\n98OMIxMcebzCxLN0jT93KgoWEq2eaGQi0h4TPZ7ZGmCkVQICVvSNjEKguACD/j9o\nryntMn54coBlF2Vqrm4Fa2XUyUIkurCv3FZtdN5W"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=ubitdos@kib.ki.se,CN=publications.ki.se,OU=UNIVERSITY LIBRARY,O=Karolinska Institutet,L=Solna,ST=Some-State,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "publications.ki.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE+jCCA+KgAwIBAgIJAOQykWZUCZpqMA0GCSqGSIb3DQEBBQUAMIGuMQswCQYD\nVQQGEwJTRTETMBEGA1UECBMKU29tZS1TdGF0ZTEOMAwGA1UEBxMFU29sbmExHjAc\nBgNVBAoTFUthcm9saW5za2EgSW5zdGl0dXRldDEbMBkGA1UECxMSVU5JVkVSU0lU\nWSBMSUJSQVJZMRswGQYDVQQDExJwdWJsaWNhdGlvbnMua2kuc2UxIDAeBgkqhkiG\n9w0BCQEWEXViaXRkb3NAa2liLmtpLnNlMB4XDTEwMDMyMzE1MzQ0OFoXDTIwMDMy\nMDE1MzQ0OFowga4xCzAJBgNVBAYTAlNFMRMwEQYDVQQIEwpTb21lLVN0YXRlMQ4w\nDAYDVQQHEwVTb2xuYTEeMBwGA1UEChMVS2Fyb2xpbnNrYSBJbnN0aXR1dGV0MRsw\nGQYDVQQLExJVTklWRVJTSVRZIExJQlJBUlkxGzAZBgNVBAMTEnB1YmxpY2F0aW9u\ncy5raS5zZTEgMB4GCSqGSIb3DQEJARYRdWJpdGRvc0BraWIua2kuc2UwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC11ax7K5PjR3GFpvzT37OKa1ycH3Rt\nz0GNApRMQtS7x9q1wgRjA3dqdTSIIJettkBgyEUOfB0f1MgcaMtaNIPhDJfMCqdr\nQ6dPKp+F0b7P7jWezyWNt8gVKXSOaeJYjze56zURO+MK8CA4sTpttqgcOOv5pnhN\nwyEuYmQBYtKGvcH13jJPStsQ+s5LZ9NX/5gV64DrRI4s64d9r0FH78lHzkM2TqHI\n0ce2KeZdn3AgXy1tOW58nUKVlUNgsFZyg/GH0ICZ08tOo1YHWBu1iuZQrzfKI655\nj8R4gElSbT+Sp770OoC9qgoBsQQdh3N/Pj+/RvgSTMG3cOmtIlNu/YjpAgMBAAGj\nggEXMIIBEzAdBgNVHQ4EFgQUjs01iDGc22yXqpCThMLfgM12WCAwgeMGA1UdIwSB\n2zCB2IAUjs01iDGc22yXqpCThMLfgM12WCChgbSkgbEwga4xCzAJBgNVBAYTAlNF\nMRMwEQYDVQQIEwpTb21lLVN0YXRlMQ4wDAYDVQQHEwVTb2xuYTEeMBwGA1UEChMV\nS2Fyb2xpbnNrYSBJbnN0aXR1dGV0MRswGQYDVQQLExJVTklWRVJTSVRZIExJQlJB\nUlkxGzAZBgNVBAMTEnB1YmxpY2F0aW9ucy5raS5zZTEgMB4GCSqGSIb3DQEJARYR\ndWJpdGRvc0BraWIua2kuc2WCCQDkMpFmVAmaajAMBgNVHRMEBTADAQH/MA0GCSqG\nSIb3DQEBBQUAA4IBAQBcI4P5JLCJuTCKie7Ze/NucF3tBgcXllnSYo7z4NSafr0i\nCrsoBPoxg1Sr7cFXSCRWLUr7Di2WfdQLrn3ZY1sPTYKWlgEmWVYFiSph2HYv04L9\nI72Jn8DLvaNCqew7KYgCODkSFRUFxzGDlWho0cXHMwP31/dEVEa2mUwmMEzG+ScQ\nDII+Op9QBwqJ7VgT7RLwhH6txbcicwNdfQYktXy/C7ysmUAS6XW1vE3H3LDd6Oc5\n98OMIxMcebzCxLN0jT93KgoWEq2eaGQi0h4TPZ7ZGmCkVQICVvSNjEKguACD/j9o\nryntMn54coBlF2Vqrm4Fa2XUyUIkurCv3FZtdN5W"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=ubitdos@kib.ki.se,CN=publications.ki.se,OU=UNIVERSITY LIBRARY,O=Karolinska Institutet,L=Solna,ST=Some-State,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://openarchive.ki.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://openarchive.ki.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://openarchive.ki.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://openarchive.ki.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://openarchive.ki.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://openarchive.ki.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://openarchive.ki.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://openarchive.ki.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://openarchive.ki.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib-sp.mediacore.tv",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bentley"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@mediacore.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Maddy"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cross"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james@mediacore.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Vliet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:matthew@mediacore.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matthew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib-sp.mediacore.tv",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-07-23T09:25:15Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MediaCore Video Learning Platform"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://mediacore.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Mediacore (EMEA) Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-sp.mediacore.tv/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "authn_requests_signed": "1",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib-sp.mediacore.tv/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shib-sp.mediacore.tv/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDITCCAgmgAwIBAgIJAKfy0phoffhNMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\n\t\t\t\t\t\tBAMTFHNoaWItc3AubWVkaWFjb3JlLnR2MB4XDTE1MDMyNTAwNTQxN1oXDTM1MDMy\n\t\t\t\t\t\tMDAwNTQxN1owHzEdMBsGA1UEAxMUc2hpYi1zcC5tZWRpYWNvcmUudHYwggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCeswwiTpucsYIEakeHwJSr1FnqOOiV\n\t\t\t\t\t\t2nwT2WqoB/cKyJrxzc0I1v1CftJ7dTCr3WLlqy7Sc3KE9+w3nl2t1TiyQlZTXHBQ\n\t\t\t\t\t\tWVrK4qJ7/4N9pqEpuTEBusaQXnxSxEoIyeTBGytNjZpnupEGkte6opS+2IhUiKNk\n\t\t\t\t\t\tYnicB79+CDLPyoAPzGUeHaJignnRvsXGjzUgCaI2n4pVXWv99iRyeB6osbA+uZo1\n\t\t\t\t\t\t6dMv18n+XbnaMjJ2QujakfaffYKGvptWLExwHVEPhbAT5+pzFpZn/cwk7U38Fs8s\n\t\t\t\t\t\tJBaqTlua0ffk3VckVSaxlJ8cdRPJ0aYZrDZRTzsqfEjwh7hRyFXP6gIdAgMBAAGj\n\t\t\t\t\t\tYDBeMD0GA1UdEQQ2MDSCFHNoaWItc3AubWVkaWFjb3JlLnR2hhxodHRwczovL3No\n\t\t\t\t\t\taWItc3AubWVkaWFjb3JlLnR2MB0GA1UdDgQWBBSGpfJo72jI4LNnm4nlmaanNFH3\n\t\t\t\t\t\tezANBgkqhkiG9w0BAQUFAAOCAQEAm4VWgi/YuI+w8azykybKTarvUMr2ZUE/j0XH\n\t\t\t\t\t\tXphbG6j+dpsUbIO5TcaULlRTZE5oVESfLalasQlX7ZwlZDYfQlEOpA1K3Y5bpPeR\n\t\t\t\t\t\tIJbsFvgvVIpto4DhlBnkSk/GrhTQ3l5IIQQ2Yk79rw7wG6FkdxGGE6YIQudAC+nf\n\t\t\t\t\t\tjPcSUn0+5pvGtGTxcQIH9JflDqI6hK8YfsDm4n5GVx0DCSSZLd/RsjjHRJKJsQzO\n\t\t\t\t\t\txlVZV+KkIj289EpGS6soJhh1Fq7yUmXpeXW9rZ5AMBIqiIHzauoIVIDnxZ/594eJ\n\t\t\t\t\t\tImZdG1OeHzR4UnAhWvd4uMM5Raah+XPIvd6mFHE+KETjsMohIw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-sp.mediacore.tv/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib-sp.mediacore.tv/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib-sp.mediacore.tv/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shib-sp.mediacore.tv/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shib-sp.mediacore.tv/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shib-sp.mediacore.tv/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol"
        }
      ]
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayfeadania.itcn.dk/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayfeadania.itcn.dk/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2014-08-21T11:09:38Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayfeadania.itcn.dk/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eadania.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Erhvervsakademi Dania"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Dania \u2013 Danish Academy of Business and Technology"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "eadania.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBDCCAewCAQcwDQYJKoZIhvcNAQELBQAwSDFGMEQGA1UEAww9aHR0cHM6Ly93\nYXlmZWFkYW5pYS5pdGNuLmRrL3NpbXBsZXNhbWwvc2FtbDIvaWRwL21ldGFkYXRh\nLnBocDAeFw0xNTAxMDEwMDAwMDBaFw0yNTEyMzEyMzU5NTlaMEgxRjBEBgNVBAMM\nPWh0dHBzOi8vd2F5ZmVhZGFuaWEuaXRjbi5kay9zaW1wbGVzYW1sL3NhbWwyL2lk\ncC9tZXRhZGF0YS5waHAwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDH\niAwKahBTuI4Z+IJ1rgOeEiCCy3bR9QIe3BpCsejFCU5rSzkWANqVuc1PDfp0JdIZ\nhrPXsmDJQMmidPCGPIDQKo+bk+af3+EUFS/I/+35sSBX2vf+h1DHvZV9jsznmpSV\njp7HZ/WoPWBykWBJO0AOVmzB5zlaqkS36J76+wxerwdpuExVnYSNd73S+AyT/EZ+\ntXAO+6lQ8FL/YMlJnUkSaSqLSHFy01D2qBNmYRwBpCS6/dUZyxi0t5j8ghKUD4BH\nOZVavn65J62cJdXiOcMRyUAIp57GXQrL63KtrjIcXddq+CZyZ5t37EdUOIz42joF\ncy73MFOntynlKEvOw1BJAgMBAAEwDQYJKoZIhvcNAQELBQADggEBACwrTDkX0NVu\naejzyGzGmNSb859ysfYWCM0pFT25khFQ4Ryi4H7Kywn/0ezDtVzlIifAYz+xiXk5\nHR0uRept/bOjP9Wy++UjE19fYQZrVqJWD+D7x3+lDIQ1GqZpQRTm/ZWT58m9B79t\n1hHhfYZHg+61j9UJZaz3eoGvp0q0Pjc+TJ9msuhHYOkFJ7IQiHH22xIUToi/Gjw2\nnSuM1kVbF1P4INZsCI7hE6VDj2HvrrteIsjQbH+uQUaskG/bYE35mo3AeiUlCml8\nlsZ14BWXRzkq1VI5Y+Zp/Zq3t8JSNW+T0O/TJXvjt5mdYhu9YKFTMVMujjE4v7qv\n2dNDLRpjcI8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Erhvervsakademi Dania"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Dania \u2013 Danish Academy of Business and Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eadania.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://eadania.dk/quicklinks/english"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Erhvervsakademi Dania"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Dania \u2013 Danish Academy of Business and Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.udsu.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.udsu.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-11-04T09:51:46Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Derby Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.udsu.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.udsu.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.udsu.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.udsu.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.udsu.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.udsu.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.udsu.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.udsu.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.udsu.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.udsu.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.udsu.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.udsu.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.udsu.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.udsu.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.slcollege.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lowe"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:austen.lowe@slcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Austen"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lowe"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:austen.lowe@slcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Austen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.slcollege.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-04-30T12:06:34Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAL6tdh1Q1lgaE74wTineZn7NGaKtMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB4xHDAaBgNVBAMTE2lkcC5zbGNvbGxlZ2UuYWMudWswHhcNMTQwNDAxMTA1\n\t\t\t\t\t\tNDIxWhcNMzQwNDAxMTA1NDIxWjAeMRwwGgYDVQQDExNpZHAuc2xjb2xsZWdlLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAz5xw2zn0ZCNoGTF0\n\t\t\t\t\t\tIzSScZwrds6DeeibqHIPU/zOo4RCc1xz60BHSDsHyWCE5PNjnzB15yZXN0cqRTbN\n\t\t\t\t\t\t5i8xRWgC0RJj6IguR5ntRhqMA8i+j0rU8J3w8wagV8bueDdp8o2iEBUgw8+VQA+Q\n\t\t\t\t\t\tk7JP4sWi9yhU6ekSLeGeEl8dWLOS9Jn2siB9KTg8pqp1PwXKR+KVW+gsInoFms+L\n\t\t\t\t\t\tODiNsZ+HKEV2OVM0OarV2cND2gxH5VKxlA/KD9YQi0jc7oYWebMuwi0St6YzlgTL\n\t\t\t\t\t\t872Y071YoUdZorsiIq9SFA/YpJIom8jz011y8xxzxR19IaOQoP8sGX12m+WP5gZn\n\t\t\t\t\t\tASNciwIDAQABo20wazBKBgNVHREEQzBBghNpZHAuc2xjb2xsZWdlLmFjLnVrhipo\n\t\t\t\t\t\tdHRwczovL2lkcC5zbGNvbGxlZ2UuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0O\n\t\t\t\t\t\tBBYEFPoignDUHhoa37ZM0Tx243itVTW2MA0GCSqGSIb3DQEBBQUAA4IBAQBxj1L0\n\t\t\t\t\t\tHCYdoJo/fjTVOkUck2y9g9RfKryJOIPt3is6CfBzonqVFIOTsMeMMrtr1axl5E0h\n\t\t\t\t\t\tTe3ZIOmDvb63wEOBziqsvemzVwFSOsuTiT9dniNZ4Udg5DhORFPhLrxmdYBI2sl1\n\t\t\t\t\t\tGDpEUrr3RKPnj7zfgBZxwIE9BxeZnDFxl/O7582Lis1ClEmFnb9TxrtzcLIH7TCY\n\t\t\t\t\t\tQ0IhONFmkgClsAB/Wn35x/yNcLxGhiWd/G3gzbLxjmWdc0e8GAVMzRHD6NjHvLKc\n\t\t\t\t\t\tq3+sje0KNER0ehuD6eKVixp6SOf6RXLVLtB7m+eI3V/gRRjnckVd2mRXj7bLuQru\n\t\t\t\t\t\tyaqmpEaqpQzn1fUy"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "slcollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.slcollege.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.slcollege.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.slcollege.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.slcollege.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.slcollege.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.slcollege.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.slcollege.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.slcollege.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.slcollege.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.slcollege.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.slcollege.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "slcollege.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://www.slcollege.ac.uk/images/logo.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://www.slcollege.ac.uk/images/logo-icon.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "South Leicestershire College (Shibboleth)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAL6tdh1Q1lgaE74wTineZn7NGaKtMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB4xHDAaBgNVBAMTE2lkcC5zbGNvbGxlZ2UuYWMudWswHhcNMTQwNDAxMTA1\n\t\t\t\t\t\tNDIxWhcNMzQwNDAxMTA1NDIxWjAeMRwwGgYDVQQDExNpZHAuc2xjb2xsZWdlLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAz5xw2zn0ZCNoGTF0\n\t\t\t\t\t\tIzSScZwrds6DeeibqHIPU/zOo4RCc1xz60BHSDsHyWCE5PNjnzB15yZXN0cqRTbN\n\t\t\t\t\t\t5i8xRWgC0RJj6IguR5ntRhqMA8i+j0rU8J3w8wagV8bueDdp8o2iEBUgw8+VQA+Q\n\t\t\t\t\t\tk7JP4sWi9yhU6ekSLeGeEl8dWLOS9Jn2siB9KTg8pqp1PwXKR+KVW+gsInoFms+L\n\t\t\t\t\t\tODiNsZ+HKEV2OVM0OarV2cND2gxH5VKxlA/KD9YQi0jc7oYWebMuwi0St6YzlgTL\n\t\t\t\t\t\t872Y071YoUdZorsiIq9SFA/YpJIom8jz011y8xxzxR19IaOQoP8sGX12m+WP5gZn\n\t\t\t\t\t\tASNciwIDAQABo20wazBKBgNVHREEQzBBghNpZHAuc2xjb2xsZWdlLmFjLnVrhipo\n\t\t\t\t\t\tdHRwczovL2lkcC5zbGNvbGxlZ2UuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0O\n\t\t\t\t\t\tBBYEFPoignDUHhoa37ZM0Tx243itVTW2MA0GCSqGSIb3DQEBBQUAA4IBAQBxj1L0\n\t\t\t\t\t\tHCYdoJo/fjTVOkUck2y9g9RfKryJOIPt3is6CfBzonqVFIOTsMeMMrtr1axl5E0h\n\t\t\t\t\t\tTe3ZIOmDvb63wEOBziqsvemzVwFSOsuTiT9dniNZ4Udg5DhORFPhLrxmdYBI2sl1\n\t\t\t\t\t\tGDpEUrr3RKPnj7zfgBZxwIE9BxeZnDFxl/O7582Lis1ClEmFnb9TxrtzcLIH7TCY\n\t\t\t\t\t\tQ0IhONFmkgClsAB/Wn35x/yNcLxGhiWd/G3gzbLxjmWdc0e8GAVMzRHD6NjHvLKc\n\t\t\t\t\t\tq3+sje0KNER0ehuD6eKVixp6SOf6RXLVLtB7m+eI3V/gRRjnckVd2mRXj7bLuQru\n\t\t\t\t\t\tyaqmpEaqpQzn1fUy"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "South Leicestershire College (Shibboleth)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.slcollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "South Leicestershire College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ens2m.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cri@ens2m.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ens2m.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-06-23T15:44:56Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ens2m.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ens2m.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ens2m.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ens2m.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ens2m.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for National School of Mechanical and Microtechnology (ENSMM) in Besan\u00e7on (France)."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Fournisseur d'identit\u00e9s de l'Ecole Nationale Sup\u00e9rieure de M\u00e9canique et des Microtechniques (ENSMM) de Besan\u00e7on (France)."
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENSMM Besan\u00e7on - National School of Mechanical and Microtechnology"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENSMM Besan\u00e7on - Ecole Nationale Sup\u00e9rieure de M\u00e9canique et des Microtechniques"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUCPhPfM614xhs9L5rQkMnQiu0FLEwDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAwwMaWRwLmVuczJtLmZyMB4XDTE1MDYxODEyMjMyOFoXDTM1\nMDYxODEyMjMyOFowFzEVMBMGA1UEAwwMaWRwLmVuczJtLmZyMIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0ACNvQOiYEZqAMH2dLBn0NdBFBWB8GFQC2OF\ndZhEgSdnlWCDlOnFsO2kjG5sEzzIR3h2qbMlYjj8FvEDRbYjGINN0SvJL/PAN1d2\nqNKYqhSIYFsFcgnH1xpiG6eg8QKtbjOmzJj1eAXbrFR2aLIu09HNjVZopYDzNXY2\nC9/vzPUbJehxs0CRGk1frrF8SlGeB0qiScxHZ8b85pmEQmEqoifJjySYX+ptu7CF\nbiJJfpo6BfOXx7dooOEK3+f6lG73nXyXG1iRUiOzi+9zSCULZSNTo6NnFLeqKj9o\nkdpiEA5++CJI8GKX1yJdzROLg3QUa/rbuv8fLXOYzNj6L0EJOQIDAQABo18wXTAd\nBgNVHQ4EFgQUudW36zQf0nUJolV6lgXTQ5ay3GkwPAYDVR0RBDUwM4IMaWRwLmVu\nczJtLmZyhiNodHRwczovL2lkcC5lbnMybS5mci9pZHAvc2hpYmJvbGV0aDANBgkq\nhkiG9w0BAQUFAAOCAQEAHMtuDl2N6BGSsGLDzo6QzkF58TT1iuZFErOEqYOKKxVh\nyvcqgeUtZXLbUDsktHbyhLB/7iY7Ir0GLKhoARf/FzONjEXVMoZahSINF+ofD1N8\nGNBaks//DsTG2CZYX0RJOuB5ZtGxVMiFuRS9pLvAidTW54tJhQFg8ijRSLrxyRTF\nsmhsf28+MyQdS2YwI9Dd0AYr13lbpIG6gSM31pZcTlZgIcG8fpmpKOmSeI7OjON9\nIAHuePwMdXUtlSEjSNksGIsPneqPNxZAviKRYZSgreG1UfwjelD81/gaPq/YYnpd\ngxA3odPxwH4odsi5EqqsqUhod7C5oBdc5fgaYPNrPQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ENSMM Besan\u00e7on - Ecole Nationale Sup\u00e9rieure de M\u00e9canique et des Microtechniques"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ens2m.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ENSMM Besan\u00e7on - Ecole Nationale Sup\u00e9rieure de M\u00e9canique et des Microtechniques"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.tigtagworld.co.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Munn"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dmunn@twig-world.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Munn"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dmunn@twig-world.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.tigtagworld.co.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-12-10T11:25:15Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "TigTag UK Shibboleth SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.twig-world.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Twig World Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.tigtagworld.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.tigtagworld.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.tigtagworld.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.tigtagworld.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.tigtagworld.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.tigtagworld.co.uk/Shibboleth.sso/Glow",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.tigtagworld.co.uk/Shibboleth.sso/shibtest",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.tigtagworld.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIJAPUDpIXdPLQCMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\n\t\t\t\t\t\tBAMTFXd3dy50aWd0YWd3b3JsZC5jby51azAeFw0xMzEyMDkxNTE0MDNaFw0yMzEy\n\t\t\t\t\t\tMDcxNTE0MDNaMCAxHjAcBgNVBAMTFXd3dy50aWd0YWd3b3JsZC5jby51azCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM2eUNw4sKscVcTmTWYUqKpujQA6\n\t\t\t\t\t\tYsyi/nwDvPo8PfQU6wTmMdEcKXMOjZsow/QutghdQuVq1jNr4A13BLUrgvdMfZLj\n\t\t\t\t\t\te1P+2kYuDJU0A1iVtin30x7GqZpgD3OMlszQGaV/TUNypgY62x9Sqh88zzX+8r+t\n\t\t\t\t\t\t/xWvd47jDO5m6vhP2zZHY3Fz+Jrs4V7H3zNk2NCMEumHbOVgX45selWJfp7Ro6v8\n\t\t\t\t\t\tHN2G9eH719bhFdQliSbBAkjnfjU0sTadWvXBx8OF1Ecq98O+hxxnNuSBYTZvTpAw\n\t\t\t\t\t\tdaBjD/kcLVs96PKYXP8VtA5IQpRyYdjlOaqEDDZF+i20hdcvlQx/U/pkE4sCAwEA\n\t\t\t\t\t\tAaNwMG4wTQYDVR0RBEYwRIIVd3d3LnRpZ3RhZ3dvcmxkLmNvLnVrhitodHRwczov\n\t\t\t\t\t\tL3d3dy50aWd0YWd3b3JsZC5jby51ay9zaGliYm9sZXRoLXNwMB0GA1UdDgQWBBRy\n\t\t\t\t\t\tio1sVRyt8tHXK4jOqpqBVVfwRzANBgkqhkiG9w0BAQUFAAOCAQEAbq3uePohbhLy\n\t\t\t\t\t\tjcS7TYj0mDHXyF9spiYzADXfhX88P43MjdBzMkqUqNR/22LC1W6nSbRBTU4Zj17E\n\t\t\t\t\t\tB1ZHHXZR8tP47JZEqmmzuFreaONr7aHOczJdYQirG7IA6MJlFZDErzeHG9QqdFbH\n\t\t\t\t\t\tf/Ky6+S0GChOxccumyBfRKtwIs7NP3fkDqh8KU0evdItzSoZtMBFEKR9v7116+Mv\n\t\t\t\t\t\tEhuVc4TsNZNqufBQ3yxvERxMyX5Uvhb+2TGfzZAshDfBcvn34Ga7VfUM5CJILNXZ\n\t\t\t\t\t\tgKZ8fY0XYWXYveYelRTKkOYKLV85AfdHOq/6OTSu39hDlFjhTQXFqeIsrBn1YmUX\n\t\t\t\t\t\to+Sieepoag=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.tigtagworld.co.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.tigtagworld.co.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.tigtagworld.co.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.tigtagworld.co.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.tigtagworld.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.tigtagworld.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.tigtagworld.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.tigtagworld.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.tigtagworld.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.tigtagworld.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.braidense.it/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "AAI CILEA"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:staff_aai@cilea.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Staff"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.braidense.it/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2012-06-11T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.braidense.it/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.braidense.it/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "braidense.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.braidense.it/servizi/idem.php"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.braidense.it/index_en.php"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Biblioteca Nazionale Braidense users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti della Biblioteca Nazionale Braidense"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.braidense.it/servizi/idem.php"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Biblioteca Nazionale Braidense"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Biblioteca Nazionale Braidense"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEvTCCA6WgAwIBAgIJAKoe0ICAn2PqMA0GCSqGSIb3DQEBBQUAMIGaMQswCQYD\nVQQGEwJJVDETMBEGA1UECBMKU29tZS1TdGF0ZTEPMA0GA1UEBxMGTWlsYW5vMScw\nJQYDVQQKEx5CaWJsaW90ZWNhIE5hemlvbmFsZSBCcmFpZGVuc2UxGTAXBgNVBAMT\nEGlkcC5icmFpZGVuc2UuaXQxITAfBgkqhkiG9w0BCQEWEnN0YWZmX2FhaUBjaWxl\nYS5pdDAeFw0xMjA1MTcwODQ3NDNaFw0yMjA1MTcwODQ3NDNaMIGaMQswCQYDVQQG\nEwJJVDETMBEGA1UECBMKU29tZS1TdGF0ZTEPMA0GA1UEBxMGTWlsYW5vMScwJQYD\nVQQKEx5CaWJsaW90ZWNhIE5hemlvbmFsZSBCcmFpZGVuc2UxGTAXBgNVBAMTEGlk\ncC5icmFpZGVuc2UuaXQxITAfBgkqhkiG9w0BCQEWEnN0YWZmX2FhaUBjaWxlYS5p\ndDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOJ+4MEKxdD1YuwbybMg\nH+LV0vmw9YsLmktL3WkJkHUpEYl6RomsaP+4fz4ugrnSUI3RZuKY1+Hz4RWXeweP\nc1vetbHoz0wzBtZuARj6fC9tQW7It0lRGeWIyO4mnMexfa2IGuUn8YD21WUT4be5\naYICi10JM1muUcEGuqcV7/cGHGsTdgFubLGUrXq84Yb8Cjg7tG6RkBymNbA/xmod\niuuIDrODJsQI17MXgzeedyy85FhgqIqsOrBOKUqf40XA6oBP54S04VJF+82rRkgT\nTfrjSilxITya8+Bez1WWPccFBjdamCtmOwwvazX7k2QCocQJXgQYdFtJ8vNAJxdx\ntd8CAwEAAaOCAQIwgf8wHQYDVR0OBBYEFLepRlg0/cmwZl7TagT4ZuiSARbJMIHP\nBgNVHSMEgccwgcSAFLepRlg0/cmwZl7TagT4ZuiSARbJoYGgpIGdMIGaMQswCQYD\nVQQGEwJJVDETMBEGA1UECBMKU29tZS1TdGF0ZTEPMA0GA1UEBxMGTWlsYW5vMScw\nJQYDVQQKEx5CaWJsaW90ZWNhIE5hemlvbmFsZSBCcmFpZGVuc2UxGTAXBgNVBAMT\nEGlkcC5icmFpZGVuc2UuaXQxITAfBgkqhkiG9w0BCQEWEnN0YWZmX2FhaUBjaWxl\nYS5pdIIJAKoe0ICAn2PqMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEB\nANTSsYzqWdHwD0LPMAlL8bccFq3j2JihAhMVomPBnwxiwUosRneHmvzn6AQW0YbV\nck7UAH5dgpVd9ztlhFP/Bhq+1slodFz61fz3DkU8rDpTrQKhIYvcNCY2vwhKq12n\nJJN/GoYkTr0NlMmPD+pUr0BMuiic2d5rKQBv5UWNbYoT9gBrujIToVjg45uzqL5S\nRTijkVLaaEAn1KpGCcPr04bXH3ENXJOzF/+wf/GCgcdgNHPbhAblGwSWiPCISzdw\nep81NcbzNK0XZJLI4dVtJnvr8eE3YyRROe0lT8f7Oa1btTk2n8RNWA6UCdJtAOw3\nA0BHS0jXr1yTM2p2/tqoNbc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEvTCCA6WgAwIBAgIJAKoe0ICAn2PqMA0GCSqGSIb3DQEBBQUAMIGaMQswCQYD\nVQQGEwJJVDETMBEGA1UECBMKU29tZS1TdGF0ZTEPMA0GA1UEBxMGTWlsYW5vMScw\nJQYDVQQKEx5CaWJsaW90ZWNhIE5hemlvbmFsZSBCcmFpZGVuc2UxGTAXBgNVBAMT\nEGlkcC5icmFpZGVuc2UuaXQxITAfBgkqhkiG9w0BCQEWEnN0YWZmX2FhaUBjaWxl\nYS5pdDAeFw0xMjA1MTcwODQ3NDNaFw0yMjA1MTcwODQ3NDNaMIGaMQswCQYDVQQG\nEwJJVDETMBEGA1UECBMKU29tZS1TdGF0ZTEPMA0GA1UEBxMGTWlsYW5vMScwJQYD\nVQQKEx5CaWJsaW90ZWNhIE5hemlvbmFsZSBCcmFpZGVuc2UxGTAXBgNVBAMTEGlk\ncC5icmFpZGVuc2UuaXQxITAfBgkqhkiG9w0BCQEWEnN0YWZmX2FhaUBjaWxlYS5p\ndDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOJ+4MEKxdD1YuwbybMg\nH+LV0vmw9YsLmktL3WkJkHUpEYl6RomsaP+4fz4ugrnSUI3RZuKY1+Hz4RWXeweP\nc1vetbHoz0wzBtZuARj6fC9tQW7It0lRGeWIyO4mnMexfa2IGuUn8YD21WUT4be5\naYICi10JM1muUcEGuqcV7/cGHGsTdgFubLGUrXq84Yb8Cjg7tG6RkBymNbA/xmod\niuuIDrODJsQI17MXgzeedyy85FhgqIqsOrBOKUqf40XA6oBP54S04VJF+82rRkgT\nTfrjSilxITya8+Bez1WWPccFBjdamCtmOwwvazX7k2QCocQJXgQYdFtJ8vNAJxdx\ntd8CAwEAAaOCAQIwgf8wHQYDVR0OBBYEFLepRlg0/cmwZl7TagT4ZuiSARbJMIHP\nBgNVHSMEgccwgcSAFLepRlg0/cmwZl7TagT4ZuiSARbJoYGgpIGdMIGaMQswCQYD\nVQQGEwJJVDETMBEGA1UECBMKU29tZS1TdGF0ZTEPMA0GA1UEBxMGTWlsYW5vMScw\nJQYDVQQKEx5CaWJsaW90ZWNhIE5hemlvbmFsZSBCcmFpZGVuc2UxGTAXBgNVBAMT\nEGlkcC5icmFpZGVuc2UuaXQxITAfBgkqhkiG9w0BCQEWEnN0YWZmX2FhaUBjaWxl\nYS5pdIIJAKoe0ICAn2PqMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEB\nANTSsYzqWdHwD0LPMAlL8bccFq3j2JihAhMVomPBnwxiwUosRneHmvzn6AQW0YbV\nck7UAH5dgpVd9ztlhFP/Bhq+1slodFz61fz3DkU8rDpTrQKhIYvcNCY2vwhKq12n\nJJN/GoYkTr0NlMmPD+pUr0BMuiic2d5rKQBv5UWNbYoT9gBrujIToVjg45uzqL5S\nRTijkVLaaEAn1KpGCcPr04bXH3ENXJOzF/+wf/GCgcdgNHPbhAblGwSWiPCISzdw\nep81NcbzNK0XZJLI4dVtJnvr8eE3YyRROe0lT8f7Oa1btTk2n8RNWA6UCdJtAOw3\nA0BHS0jXr1yTM2p2/tqoNbc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Biblioteca Nazionale Braidense"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Biblioteca Nazionale Braidense"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.braidense.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.braidense.it/index_en.php"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Biblioteca Nazionale Braidense"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Biblioteca Nazionale Braidense"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://id.vse.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ku\u010dera"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "frantisek.kucera@vse.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Franti\u0161ek"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://id.vse.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2012-01-18T18:57:08Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/university"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEpDCCAowCCQCHTyuMkLIypDANBgkqhkiG9w0BAQUFADAUMRIwEAYDVQQDEwlp\nZC52c2UuY3owHhcNMTQwNzAzMTIxMjQ3WhcNMjQwNjMwMTIxMjQ3WjAUMRIwEAYD\nVQQDEwlpZC52c2UuY3owggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQDA\nKcUzwd4FJSmiZKSwuDNtK6LXqRsqxID8o+BDYZ2xJEnLHLU0IXV+eUGCdX28aGqC\nuZ0RzwhZVAJHCjJ8kM5c7KxpKRXHXM6KennjFCYJEkwyX0al29wSlpBh9Vce3rST\nOXdU7m3zZ7G6rc276Fg21fNaYFfi5NYqzsR/BXJfsrUzTFztQwbBlSRg+fjRyL5k\nZxRRNTzVaIoVNmRB9vsB7rRvCAENxckJdndTJ76iBiAviOhFGXvjFfAZRsNmNva5\nxO3MLLx1MLUwwBXJe144ucXg/v1OTDPllgD7Wyc/4rc/XoFB6KrsBfoPNVwg/A0b\n42Im+ArAWZCnXmh/d4Pip+aBaKC5tBeRYtzFSjkMQQlgOtDWbIW91MmHbBBNpdbi\n44nCj1kD2aJxLuXXlsnYQCTnImaC1YeLzXqn+zBVvY2RApD5VPyNGp87bTz0bdKG\nNUzZOylSa4zbDK8tgztconVSXTN288dp+gZ9vtwIuG/sOqYTlMc0tcnJe8DcqL35\n8QVSEqEx+YxEwBxQ3iBD6LcyBFY2lINoqe/kzO/pF8fRQ62cpGjOg0duYDvd+hco\nEA/GbkJYvM04Q9j59d3Zqh1SQ2Sp/Cj6U1fh9DA98alpXss1WZcV7MQVXFwoFhPi\nsSfTCL/tTFbOMM015TowWA6YIw7Bn/Hld5KSAKqFqwIDAQABMA0GCSqGSIb3DQEB\nBQUAA4ICAQC4Rv4jmbW3BA7oLMZjuUF58iSGwMd8YiEqs9YYBO/2ZCDMPfMAyEhl\niuep69Fy//3RY5/ERyJ4f27dE4eFpVteV38ldDPhEda1XtZH60e4DuqiLmbpP0p/\nPMoNONBSARX/+SfPWrBayggrLekar4+N2Ghb9A22cBmcGh3KZ9c5VI+WKCryUoxV\nV1FLZDUAeRzKITdSvUXLdjG9fobl8/cjicBf5OPcmDRmlF7l1XIRDAj3XdL40OOr\nZclXpiBDcV4mrtfrIOoKM51TqLVv85uAGwsLIqelivJ5dU7PcZ9zarAyd6JK5jhC\nLBwXc8cFRPFNAS7T+Nj3FvU4ket0wahnvZYsMPXfYjihhIPu3Y1W2eYP6tOld7Dl\ncDGsv4OjlepMz/Xrap7qCwcoSa++HIg2iM/5tgypk/lRGuRzwoHv9jwfHpYndUnc\nONYmPl02Fc1jPaQwANyGkrLrHWMneYoF5AnplmIDH3WbwOPpv0Wik8MXqBHPL361\nl01SPOCJFlWu0nvMeKsy1uhscAnniafoWL+SLUzJRv4ee4ylw9K5aumIoPp5P1np\nZp153289Ap8h0heOCVxDY/rtRdtlQRqo1C2KOxcU/qplUQnkibJGM4Vys29QxTqt\nYQ64+nivdRsScVzeuMXntKwi7OYEp9k2pif+9Zt1Jwhr8J4arLgdGA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vse.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://id.vse.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://id.vse.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://id.vse.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://id.vse.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://id.vse.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://id.vse.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://id.vse.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://id.vse.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vse.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.vse.cz/english/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.vse.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for University of Economics, Prague."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Poskytovatel identit (IdP) pro Vysokou \u0161kolu ekonomickou v\u00a0Praze."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www2.eduid.cz/idp-loga/vse.png",
                    "height": "132",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "132"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Economics, Prague"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Vysok\u00e1 \u0161kola ekonomick\u00e1 v Praze"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEpDCCAowCCQCHTyuMkLIypDANBgkqhkiG9w0BAQUFADAUMRIwEAYDVQQDEwlp\nZC52c2UuY3owHhcNMTQwNzAzMTIxMjQ3WhcNMjQwNjMwMTIxMjQ3WjAUMRIwEAYD\nVQQDEwlpZC52c2UuY3owggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQDA\nKcUzwd4FJSmiZKSwuDNtK6LXqRsqxID8o+BDYZ2xJEnLHLU0IXV+eUGCdX28aGqC\nuZ0RzwhZVAJHCjJ8kM5c7KxpKRXHXM6KennjFCYJEkwyX0al29wSlpBh9Vce3rST\nOXdU7m3zZ7G6rc276Fg21fNaYFfi5NYqzsR/BXJfsrUzTFztQwbBlSRg+fjRyL5k\nZxRRNTzVaIoVNmRB9vsB7rRvCAENxckJdndTJ76iBiAviOhFGXvjFfAZRsNmNva5\nxO3MLLx1MLUwwBXJe144ucXg/v1OTDPllgD7Wyc/4rc/XoFB6KrsBfoPNVwg/A0b\n42Im+ArAWZCnXmh/d4Pip+aBaKC5tBeRYtzFSjkMQQlgOtDWbIW91MmHbBBNpdbi\n44nCj1kD2aJxLuXXlsnYQCTnImaC1YeLzXqn+zBVvY2RApD5VPyNGp87bTz0bdKG\nNUzZOylSa4zbDK8tgztconVSXTN288dp+gZ9vtwIuG/sOqYTlMc0tcnJe8DcqL35\n8QVSEqEx+YxEwBxQ3iBD6LcyBFY2lINoqe/kzO/pF8fRQ62cpGjOg0duYDvd+hco\nEA/GbkJYvM04Q9j59d3Zqh1SQ2Sp/Cj6U1fh9DA98alpXss1WZcV7MQVXFwoFhPi\nsSfTCL/tTFbOMM015TowWA6YIw7Bn/Hld5KSAKqFqwIDAQABMA0GCSqGSIb3DQEB\nBQUAA4ICAQC4Rv4jmbW3BA7oLMZjuUF58iSGwMd8YiEqs9YYBO/2ZCDMPfMAyEhl\niuep69Fy//3RY5/ERyJ4f27dE4eFpVteV38ldDPhEda1XtZH60e4DuqiLmbpP0p/\nPMoNONBSARX/+SfPWrBayggrLekar4+N2Ghb9A22cBmcGh3KZ9c5VI+WKCryUoxV\nV1FLZDUAeRzKITdSvUXLdjG9fobl8/cjicBf5OPcmDRmlF7l1XIRDAj3XdL40OOr\nZclXpiBDcV4mrtfrIOoKM51TqLVv85uAGwsLIqelivJ5dU7PcZ9zarAyd6JK5jhC\nLBwXc8cFRPFNAS7T+Nj3FvU4ket0wahnvZYsMPXfYjihhIPu3Y1W2eYP6tOld7Dl\ncDGsv4OjlepMz/Xrap7qCwcoSa++HIg2iM/5tgypk/lRGuRzwoHv9jwfHpYndUnc\nONYmPl02Fc1jPaQwANyGkrLrHWMneYoF5AnplmIDH3WbwOPpv0Wik8MXqBHPL361\nl01SPOCJFlWu0nvMeKsy1uhscAnniafoWL+SLUzJRv4ee4ylw9K5aumIoPp5P1np\nZp153289Ap8h0heOCVxDY/rtRdtlQRqo1C2KOxcU/qplUQnkibJGM4Vys29QxTqt\nYQ64+nivdRsScVzeuMXntKwi7OYEp9k2pif+9Zt1Jwhr8J4arLgdGA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Vysok\u00e1 \u0161kola ekonomick\u00e1 v Praze"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Economics, Prague"
          }
        ],
        "organization_url": [
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vse.cz/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vse.cz/english/"
          }
        ],
        "organization_name": [
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Vysok\u00e1 \u0161kola ekonomick\u00e1 v Praze"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Economics, Prague"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.rediris.es/sir/ifaeidp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jos\u00e9 Manuel Mac\u00edas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sir@rediris.es"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.rediris.es/sir/ifaeidp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.rediris.es/sir/edugain/SIR_MRPS.pdf"
              }
            ],
            "registration_instant": "2016-04-19T09:06:00Z",
            "registration_authority": "http://www.rediris.es/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "regexp": "false",
            "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
            "text": "ifae.es"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "response_location": "http://sir.rediris.es/ifae/saml2/idp/SingleLogoutService.php",
              "location": "http://sir.rediris.es/ifae/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "http://sir.rediris.es/ifae/shib13/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "http://sir.rediris.es/ifae/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Identity Provider of Institute for High Energy Physics at the Universitat Aut\u00f2noma de Barcelona"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "El proveedor de identidad del Instituto de F\u00edsica de Altas Energ\u00edas en la Universitat Aut\u00f2noma de Barcelona"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFAE - Institute for High Energy Physics at the Universitat Aut\u00f2noma de Barcelona"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFAE - Instituto de F\u00edsica de Altas Energ\u00edas en la Universitat Aut\u00f2noma de Barcelona"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ifae.es"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Instituto de F\u00edsica de Altas Energ\u00edas en la Universitat Aut\u00f2noma de Barcelona"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifae.es/eng"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute for High Energy Physics at the Universitat Aut\u00f2noma de Barcelona"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.urca.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Herbert Novais"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "herbert.novais@urca.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.urca.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC5DCCAcwCAQAwDQYJKoZIhvcNAQEFBQAwODENMAsGA1UEChMEVVJDQTEMMAoG\nA1UECxMDQ1BEMQswCQYDVQQGEwJCUjEMMAoGA1UEAxMDaWRwMB4XDTE0MDcyMzE0\nNDMwNVoXDTE3MDcyMjE0NDMwNVowODENMAsGA1UEChMEVVJDQTEMMAoGA1UECxMD\nQ1BEMQswCQYDVQQGEwJCUjEMMAoGA1UEAxMDaWRwMIIBIjANBgkqhkiG9w0BAQEF\nAAOCAQ8AMIIBCgKCAQEA587p9iqaMIWfFLDlFeSo4dp9k0p3Mdc45vL7+hSiTjCT\nL/GqgQNSRyLvDzwVttKglapDi2GrPSifMlT1lrP6xJIg22NzhV5CmlDis2FF0DZB\njCnxhfXVpbMGGqwg2B8quc6FItanXjUbRD+leyI8+/jUUfb++XpYo5q6cQSc+jP2\nyzIxh1nRPd7r89S6C36b5LMxGOT178VD7jI9AI78p/v8sbIDi8qE5xvg65HrGgyQ\n7LamfWhHfKzzAecxkJA+BgIW1H+f9srfPXtTL2EUem4p1sSI+XgrhkWXkYc4fZ/L\nqGFt3o7PmBaPmctNe126ljxzwXq17fWdqvzCVCbHbQIDAQABMA0GCSqGSIb3DQEB\nBQUAA4IBAQCrtCCtbhDkpx6uvImEuQ91Bl8YXTxJLOxO4G/cRSvPdQ5pE7umbyLm\nOhFEXa79Ssf3jmDHf/J23X2SJHsqKR/5NbeSyPjPBiDuSDy/Pav0oKMcPvkEXXsp\noDwJV6Tx1q6ngm10GvU62R5shb7uG1SOUO8A9/pElqiekGziCbsyEqrgl4lfEDRQ\nDWRRPsto+fYtJ3u4acVvDRODzIS/eJBbDyRIGby8WojHR1GQ8zteK8QZbSlCP9YP\nnI8CCcU5SWNtrokzTBcf0Vb71RV+JaxGLod48itA1dStZHDr4N8tcLO6c2xYEwGo\nxJ+47QxRYCpCLQW0WKXIYNcPqobfLQsA"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "urca.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.urca.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.urca.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.urca.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.urca.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.urca.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.urca.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.urca.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.urca.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "urca.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.urca.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.urca.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "URCA - Universidade Regional do Cariri"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "URCA - Universidade Regional do Cariri"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "URCA - Universidade Regional do Cariri"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "URCA - Universidade Regional do Cariri"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC5DCCAcwCAQAwDQYJKoZIhvcNAQEFBQAwODENMAsGA1UEChMEVVJDQTEMMAoG\nA1UECxMDQ1BEMQswCQYDVQQGEwJCUjEMMAoGA1UEAxMDaWRwMB4XDTE0MDcyMzE0\nNDMwNVoXDTE3MDcyMjE0NDMwNVowODENMAsGA1UEChMEVVJDQTEMMAoGA1UECxMD\nQ1BEMQswCQYDVQQGEwJCUjEMMAoGA1UEAxMDaWRwMIIBIjANBgkqhkiG9w0BAQEF\nAAOCAQ8AMIIBCgKCAQEA587p9iqaMIWfFLDlFeSo4dp9k0p3Mdc45vL7+hSiTjCT\nL/GqgQNSRyLvDzwVttKglapDi2GrPSifMlT1lrP6xJIg22NzhV5CmlDis2FF0DZB\njCnxhfXVpbMGGqwg2B8quc6FItanXjUbRD+leyI8+/jUUfb++XpYo5q6cQSc+jP2\nyzIxh1nRPd7r89S6C36b5LMxGOT178VD7jI9AI78p/v8sbIDi8qE5xvg65HrGgyQ\n7LamfWhHfKzzAecxkJA+BgIW1H+f9srfPXtTL2EUem4p1sSI+XgrhkWXkYc4fZ/L\nqGFt3o7PmBaPmctNe126ljxzwXq17fWdqvzCVCbHbQIDAQABMA0GCSqGSIb3DQEB\nBQUAA4IBAQCrtCCtbhDkpx6uvImEuQ91Bl8YXTxJLOxO4G/cRSvPdQ5pE7umbyLm\nOhFEXa79Ssf3jmDHf/J23X2SJHsqKR/5NbeSyPjPBiDuSDy/Pav0oKMcPvkEXXsp\noDwJV6Tx1q6ngm10GvU62R5shb7uG1SOUO8A9/pElqiekGziCbsyEqrgl4lfEDRQ\nDWRRPsto+fYtJ3u4acVvDRODzIS/eJBbDyRIGby8WojHR1GQ8zteK8QZbSlCP9YP\nnI8CCcU5SWNtrokzTBcf0Vb71RV+JaxGLod48itA1dStZHDr4N8tcLO6c2xYEwGo\nxJ+47QxRYCpCLQW0WKXIYNcPqobfLQsA"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "URCA - Universidade Regional do Cariri"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "URCA - Universidade Regional do Cariri"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.urca.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.urca.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "URCA - Universidade Regional do Cariri"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "URCA - Universidade Regional do Cariri"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.hkr.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 44 20 3030"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Service desk 3030"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:3030@hkr.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "H\u00f6gskolan Kristianstad"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 44 20 3030"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Service desk 3030"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:3030@hkr.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "H\u00f6gskolan Kristianstad"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 44 20 3030"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Service desk 3030"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:3030@hkr.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "H\u00f6gskolan Kristianstad"
          }
        }
      ],
      "entity_id": "https://idp.hkr.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oasis:names:tc:SAML:attribute:assurance-certification",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAJFwJo5KjpvOv/slniklC/Nf19gKMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC5oa3Iuc2UwHhcNMTAxMjEwMTExMDM2WhcNMzAx\nMjEwMTExMDM2WjAVMRMwEQYDVQQDEwppZHAuaGtyLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAmLMMJQyBS/1Caas2d1zoAj1jlxYs9axLJPDujiP0\nfJ8F3gjMxtl/A7Y+eVFqnRFzHNuaEKaqZ8S+XGnRi8kw3AdPbPJZB4g+LTRPI8WB\nxDo49uubfZbpyi8zZUqoqOSLeNxMKFqgkq9bd0Yeh4bI7r/bjuvcx4tioOP3UnT4\nCBfTL6uxyCWFW8mP9TbmnQ4lZN5O4elIKrea+8XiumRa2q5qpXVtdqF5h9YI+jYK\n6zj9pMzUlPPvIyOzGFLxLSN0KRM7EgV3FRD65y9hCnTzuQtFrqwktBOVs5fwavyr\nbKht5KrIaVrozMBscr8STgQ8SKEDMCDqxu/hS0IqoweTyQIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAuaGtyLnNlhiFodHRwczovL2lkcC5oa3Iuc2UvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFLIjYPKZGp/Bncfc+KnH8Pdf7FukMA0GCSqGSIb3DQEB\nBQUAA4IBAQCQ3m4eN6leAlXf9v8xcZjrzQhHCg4ceDnixMUINTsFfXktfYsSSonr\nCdh/mhttMxnk/34Tu1XMfYn8ABPVxvvcaBZ9Brl21BBsvk3MOdbDNO6cB05GXdms\nexr3aJFvRwY6Vy0AWtUgDFXdYPiIVPUrpC7NA+X78fq3IVmPn0WFlQ9KpM8hXNz0\nHwlY06myFNjI7dvt8xjAqJy+ICilu06RTs7oCynE45nkrLaZjpploIn3xcYt0ceK\nqU1LY9aaqaEgKSsNHlPoCW9eH4oUP3f/X8h21pAtgGA8AIt2RegT6HfVqnZPAtUk\nkgLpO4NuqQRRqV5FxbnmTvt25NApGY5k"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hkr.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.hkr.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.hkr.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.hkr.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.hkr.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.hkr.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.hkr.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.hkr.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.hkr.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hkr.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.hkr.se/sv/om-hkr/organisation/administration-och-stodverksamhet/it-service/kontoinformation/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.hkr.se/en/study-at-hkr/service-and-support/it-support-for-students/user-name-and-password/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Inloggning i webbtj\u00e4nster f\u00f6r anst\u00e4llda och studenter vid H\u00f6gskolan Kristianstad."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Kristianstad University Login Service is used by employees and students at the university."
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.hkr.se/idp/images/hkrsmall.png",
                    "lang": "sv",
                    "height": "84",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "96"
                  },
                  {
                    "text": "https://idp.hkr.se/idp/images/hkrsmall.png",
                    "lang": "en",
                    "height": "84",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "96"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "H\u00f6gskolan Kristianstad"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kristianstad University Sweden"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "hkr.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:56.04848,14.14416"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "194.47.24.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "194.47.32.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "194.47.40.0/21"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAJFwJo5KjpvOv/slniklC/Nf19gKMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC5oa3Iuc2UwHhcNMTAxMjEwMTExMDM2WhcNMzAx\nMjEwMTExMDM2WjAVMRMwEQYDVQQDEwppZHAuaGtyLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAmLMMJQyBS/1Caas2d1zoAj1jlxYs9axLJPDujiP0\nfJ8F3gjMxtl/A7Y+eVFqnRFzHNuaEKaqZ8S+XGnRi8kw3AdPbPJZB4g+LTRPI8WB\nxDo49uubfZbpyi8zZUqoqOSLeNxMKFqgkq9bd0Yeh4bI7r/bjuvcx4tioOP3UnT4\nCBfTL6uxyCWFW8mP9TbmnQ4lZN5O4elIKrea+8XiumRa2q5qpXVtdqF5h9YI+jYK\n6zj9pMzUlPPvIyOzGFLxLSN0KRM7EgV3FRD65y9hCnTzuQtFrqwktBOVs5fwavyr\nbKht5KrIaVrozMBscr8STgQ8SKEDMCDqxu/hS0IqoweTyQIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAuaGtyLnNlhiFodHRwczovL2lkcC5oa3Iuc2UvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFLIjYPKZGp/Bncfc+KnH8Pdf7FukMA0GCSqGSIb3DQEB\nBQUAA4IBAQCQ3m4eN6leAlXf9v8xcZjrzQhHCg4ceDnixMUINTsFfXktfYsSSonr\nCdh/mhttMxnk/34Tu1XMfYn8ABPVxvvcaBZ9Brl21BBsvk3MOdbDNO6cB05GXdms\nexr3aJFvRwY6Vy0AWtUgDFXdYPiIVPUrpC7NA+X78fq3IVmPn0WFlQ9KpM8hXNz0\nHwlY06myFNjI7dvt8xjAqJy+ICilu06RTs7oCynE45nkrLaZjpploIn3xcYt0ceK\nqU1LY9aaqaEgKSsNHlPoCW9eH4oUP3f/X8h21pAtgGA8AIt2RegT6HfVqnZPAtUk\nkgLpO4NuqQRRqV5FxbnmTvt25NApGY5k"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "H\u00f6gskolan Kristianstad"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Kristianstad University Sweden"
          }
        ],
        "organization_url": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hkr.se"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hkr.se/en/english-start-page/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HKR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.ripfa.org.uk/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Catling"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:robin.catling@ripfa.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mangan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul@headmonaut.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.ripfa.org.uk/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-01-21T13:50:02Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Research in Practice for Adults (RIPFA)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rip.org.uk/about-us"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Dartington Hall Trust"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Research in Practice for Adults (RIPFA)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.ripfa.org.uk/images/ripfa_logo.png",
                    "height": "76",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "132"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Research in Practice for Adults (RIPFA)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWzCCAkOgAwIBAgIJAP9VQ0E4SPcHMA0GCSqGSIb3DQEBBQUAMCcxDjAMBgNV\n\t\t\t\t\t\tBAoTBVJpUGZBMRUwEwYDVQQDEwxyaXBmYS5vcmcudWswHhcNMTQwMTA1MDkwOTUx\n\t\t\t\t\t\tWhcNMjQwMTAzMDkwOTUxWjAnMQ4wDAYDVQQKEwVSaVBmQTEVMBMGA1UEAxMMcmlw\n\t\t\t\t\t\tZmEub3JnLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzo3T6m/Q\n\t\t\t\t\t\tIHr+ZiZqoRWpNcavL2ObQCXGrKMGo9SP/zsKZGSTWj0w+pKNTQAC+o4issxq+2f2\n\t\t\t\t\t\tcwBBKQmaJmvs+6FDzynRZ4RZTrCgT0ZV6wiqnHSRALLDEe1GatE5YatnAl9JqDcy\n\t\t\t\t\t\toOC144EXG3Q2z31ts0/9Xbmz9VPvfBPcXZnhBmdeqKLoCM3nxOMIiiNwp4gZID+y\n\t\t\t\t\t\tORveB5zn7lg4vfW63/fCN2ea4Vwbg4wUcwwBZplDn+z2wApU92OA9/WTYIK6gtgw\n\t\t\t\t\t\tJalJXnFI9yCzQyBQUYGpJi8hSGX0qyT69/7r1QdBg2pIE5Lw/b79lN4kdXFhrX3u\n\t\t\t\t\t\tBAOMKUiKpok3+wIDAQABo4GJMIGGMB0GA1UdDgQWBBR48j+MpOWAOUt0lOLls9z/\n\t\t\t\t\t\tOgulhzBXBgNVHSMEUDBOgBR48j+MpOWAOUt0lOLls9z/Ogulh6ErpCkwJzEOMAwG\n\t\t\t\t\t\tA1UEChMFUmlQZkExFTATBgNVBAMTDHJpcGZhLm9yZy51a4IJAP9VQ0E4SPcHMAwG\n\t\t\t\t\t\tA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAEBIsOYvJUIw4bpOEHHOIYwt\n\t\t\t\t\t\tZHaIfAyIjoW2jZ0MyEjHUS5V/pPWgf6shc5oG8OgDkgp7AumeexNA6L4EEae+9N2\n\t\t\t\t\t\toWq3NIKXZazjdDeVR7w7RAmMRqc0ApAE3OT4jemdM6kbqqo+GRK4XhvtMD0O9BWx\n\t\t\t\t\t\tLT5rvxT/bO7gASiBWGDIYiXrtoc/FPu33Sy4JQrbUZLU/fpfRfwfrzA9f2+6SRJQ\n\t\t\t\t\t\tMd1x+QWoWBLqma/MqkZcUrdm2BlEZD2HCtv6lzaTy0t8jSLyaeYxHhemrVGZpcHm\n\t\t\t\t\t\tm1WhrEyo1V1gcUfonTxnCTTA6Wp4Qz2rVwAwpzfDPa7vS6rlp+XgtPhVXqNWfwE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWzCCAkOgAwIBAgIJAP9VQ0E4SPcHMA0GCSqGSIb3DQEBBQUAMCcxDjAMBgNV\n\t\t\t\t\t\tBAoTBVJpUGZBMRUwEwYDVQQDEwxyaXBmYS5vcmcudWswHhcNMTQwMTA1MDkwOTUx\n\t\t\t\t\t\tWhcNMjQwMTAzMDkwOTUxWjAnMQ4wDAYDVQQKEwVSaVBmQTEVMBMGA1UEAxMMcmlw\n\t\t\t\t\t\tZmEub3JnLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzo3T6m/Q\n\t\t\t\t\t\tIHr+ZiZqoRWpNcavL2ObQCXGrKMGo9SP/zsKZGSTWj0w+pKNTQAC+o4issxq+2f2\n\t\t\t\t\t\tcwBBKQmaJmvs+6FDzynRZ4RZTrCgT0ZV6wiqnHSRALLDEe1GatE5YatnAl9JqDcy\n\t\t\t\t\t\toOC144EXG3Q2z31ts0/9Xbmz9VPvfBPcXZnhBmdeqKLoCM3nxOMIiiNwp4gZID+y\n\t\t\t\t\t\tORveB5zn7lg4vfW63/fCN2ea4Vwbg4wUcwwBZplDn+z2wApU92OA9/WTYIK6gtgw\n\t\t\t\t\t\tJalJXnFI9yCzQyBQUYGpJi8hSGX0qyT69/7r1QdBg2pIE5Lw/b79lN4kdXFhrX3u\n\t\t\t\t\t\tBAOMKUiKpok3+wIDAQABo4GJMIGGMB0GA1UdDgQWBBR48j+MpOWAOUt0lOLls9z/\n\t\t\t\t\t\tOgulhzBXBgNVHSMEUDBOgBR48j+MpOWAOUt0lOLls9z/Ogulh6ErpCkwJzEOMAwG\n\t\t\t\t\t\tA1UEChMFUmlQZkExFTATBgNVBAMTDHJpcGZhLm9yZy51a4IJAP9VQ0E4SPcHMAwG\n\t\t\t\t\t\tA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAEBIsOYvJUIw4bpOEHHOIYwt\n\t\t\t\t\t\tZHaIfAyIjoW2jZ0MyEjHUS5V/pPWgf6shc5oG8OgDkgp7AumeexNA6L4EEae+9N2\n\t\t\t\t\t\toWq3NIKXZazjdDeVR7w7RAmMRqc0ApAE3OT4jemdM6kbqqo+GRK4XhvtMD0O9BWx\n\t\t\t\t\t\tLT5rvxT/bO7gASiBWGDIYiXrtoc/FPu33Sy4JQrbUZLU/fpfRfwfrzA9f2+6SRJQ\n\t\t\t\t\t\tMd1x+QWoWBLqma/MqkZcUrdm2BlEZD2HCtv6lzaTy0t8jSLyaeYxHhemrVGZpcHm\n\t\t\t\t\t\tm1WhrEyo1V1gcUfonTxnCTTA6Wp4Qz2rVwAwpzfDPa7vS6rlp+XgtPhVXqNWfwE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://www.ripfa.org.uk/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.ripfa.org.uk/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ripfa.org.uk/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ripfa.org.uk/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.crous-nice.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "admin@crous-nice.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.crous-nice.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-05-28T10:27:56Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.crous-nice.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.crous-nice.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.crous-nice.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "crous-nice.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.crous-nice.fr/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Access to buisiness software via Identity Federation."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Acc\u00e8s aux applications m\u00e9tiers du CNOUS par la f\u00e9d\u00e9ration d'identit\u00e9."
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS de Nice - Employee"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS de Nice - Personnels"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEnTCCA4WgAwIBAgIRALWuRLNLEVeuImgWjTlsB5wwDQYJKoZIhvcNAQELBQAw\nZDELMAkGA1UEBhMCTkwxFjAUBgNVBAgTDU5vb3JkLUhvbGxhbmQxEjAQBgNVBAcT\nCUFtc3RlcmRhbTEPMA0GA1UEChMGVEVSRU5BMRgwFgYDVQQDEw9URVJFTkEgU1NM\nIENBIDIwHhcNMTUwNjIyMDAwMDAwWhcNMTgwNjIxMjM1OTU5WjA/MSEwHwYDVQQL\nExhEb21haW4gQ29udHJvbCBWYWxpZGF0ZWQxGjAYBgNVBAMTEWlkcC5jcm91cy1u\naWNlLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAv+s0X6a4wci3\nrmTkh4xxRhWHM5Y9WfwuA6b9avcjmPUopag4ShXtaAUysZQYPHa44V94wrYGg2k7\nY8RmFMFa26Zaw3CyZNSpLY4ZDHxGQYrkeQwRNGlKkBRmdwBFj3PrNhYADXHghnQj\nqBYrd9zh5oHT7vI6tYBKl4EZKypdyjViKR4dNgr+WiUvJCR7kfxsLX9/2sJ05rbF\nVjWemEVz2RQ4R5xkWXnraVTgwhKeykGKiDWuBYrVmuuBgYUDZZauazF/v5jhqqtD\nCoBNEfzecuO47/bhumxf5tAqRjqaLnvlqXdAwr05idgZ3xQsP3uryIktA8t/h7zm\ne3ZF/5sxIQIDAQABo4IBbTCCAWkwHwYDVR0jBBgwFoAUW9CKHJoyW+C13ZZUG+GG\nKLD9tr0wHQYDVR0OBBYEFOhlPBId5zoytuUUEuvPr9WifWqAMA4GA1UdDwEB/wQE\nAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcD\nAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAx\nMC+gLaArhilodHRwOi8vY3JsLnVzZXJ0cnVzdC5jb20vVEVSRU5BU1NMQ0EyLmNy\nbDBsBggrBgEFBQcBAQRgMF4wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudXNlcnRy\ndXN0LmNvbS9URVJFTkFTU0xDQTIuY3J0MCUGCCsGAQUFBzABhhlodHRwOi8vb2Nz\ncC51c2VydHJ1c3QuY29tMBwGA1UdEQQVMBOCEWlkcC5jcm91cy1uaWNlLmZyMA0G\nCSqGSIb3DQEBCwUAA4IBAQBQgxw83uEggYS9E40PJf40hjkl26GVcwMrW5H2MtrV\nPlHy2rpfcKoBkxpuNOOvUOeo9cIzGqppXyMVrpRZcZK66DGLOaHx8LDxUBnwTR7M\n24+UNiPWT39qKat/H5kXZy4TOsdF4puPiWitVfCH/u8eDRw1NDfqoBhdD1IzZSrO\n7tE8qkrqW8XBIU+i8PlwhAdwOxqNWZwogCXK7zaX4LXMe50OtKXBFBKdIzKopKkl\nxSXuRsQd98MTvUs41HrExz459kOUv/w6RyW1OOCZhyl+1hFvIATcTdYYy7VWR6ed\nBOyEhdt1trDRK1pwnstRuxBk4KpHuLw1t5N/vnjMCxUQ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEcDCCA1igAwIBAgIRAMHTGdw9yTpb8GTC7eORirkwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDA1MjMwMDAwMDBaFw0xNzA1MjIyMzU5NTlaMD8xITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEaMBgGA1UEAxMRaWRwLmNyb3Vz\nLW5pY2UuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCnQ3RV1nfN\nL8sIsz8lErI6GirN9Gm96VGgQIlFVdE4MQt1zJ8v8VfPeFH++a/N/I56emmGRc/G\nsihTWAXZ8prWUYisSPtuTmnHXFmAEOJZp4/ajdVUUBT+WMGpJx2XUfIUPfa1+TK+\nw+0eqRpCh6IWtPqyPOLs24lKdDcLV55j65LLcBfyejeUsjtyGrimC64Dy1vXTAJf\nyHVk5GeOvAvcdCBZUO5GRjIhlWiH0YLJJ439MzpbEgXYhIFQvPEVBY+he448SQXS\nanD9JJalMmA9/tmWHqo9qCusDxXVzGUhgW2FHKh49AjMaXp/W5n1p50ZLoicEq7k\ns5NtBCw8jCGDAgMBAAGjggFuMIIBajAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3\nV0fqkOO57TAdBgNVHQ4EFgQUs/OdYrZbtOAjgBXRUwXEVH/bhJ0wDgYDVR0PAQH/\nBAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUF\nBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1UdHwQz\nMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0Eu\nY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3Mu\ndGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9v\nY3NwLnRjcy50ZXJlbmEub3JnMBwGA1UdEQQVMBOCEWlkcC5jcm91cy1uaWNlLmZy\nMA0GCSqGSIb3DQEBBQUAA4IBAQA+TVHB9HB1aQF2emZfL4BKmI+ULDlvSPunwG1w\nBYzKcYeg2pH39CFREkXTGXn/VDFGXdMOmVlvTGvNeQwEWQVbqrHEyFSyney0e7ZE\nKsS81CNBYBd7KTWJC4NpYXsrlGT43cKIeWsbbhVRrG8xv3y66AOrzW8HO0kHbkb5\nBDObTK/AxaaDCf754DBSS+C7OHTihGp4Be+8EbQvQb5drVCgrHdbtP7dd31XXCV1\nPK0bgjuS0OSSCCgiqBftO/Ym7RLAoYif9L8mQLCDcms/4wJzjssdLgnuqSk3VxPx\ntYzHJuh0PK935LA6t7Tt2AiGFlmfSUXmGwwHxCMalr3BgJBN"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS de Nice - Personnels"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.crous-nice.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS de Nice - Personnels"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://mailfilter.sunet.se/shibboleth",
    {
      "entity_id": "https://mailfilter.sunet.se/shibboleth",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish University Network (SUNET)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sunet.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SUNET"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mailfilter.sunet.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mailfilter.sunet.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mailfilter.sunet.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mailfilter.sunet.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SUNET Mailfilter Service"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "SUNET Mailfilter Service"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://mailfilter.sunet.se/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://mailfilter.sunet.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "mailfilter.sunet.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJAJ5oV5rQ7B3hMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE21haWxmaWx0ZXIuc3VuZXQuc2UwHhcNMTAwODI2MTk0NDIyWhcNMjAwODIz\nMTk0NDIyWjAeMRwwGgYDVQQDExNtYWlsZmlsdGVyLnN1bmV0LnNlMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuwGz7eWqtVCW3Be28I+IPpODVQDPQIwi\nchEFFSJdlkF7c9XN806yVAaGvsOrnNaFUTM5h/Gc4Hak1A0puoLI1aMkyeA0sMWb\nMi6owbVDrjXGoD4gAoC9AIhqfj0NtE8zGlbGsL0dezM68NJwIt2C30U1rzOfUS53\nrngSTvleQK0lnd8I2Sys+msN6kP+4N64A3IBg6A2AVZtaadB6fJIoxQrQOhU3N1U\nAfaK8TcLaclVC5PfiwuJuiSLM0RgMy68B0Fht0V6lUpdiBoF5nU4sKAVYjZz+ZHo\npi6sntIe+FchSvmDXf7zqqLS/NQiM+bD65T/nvazAbtBIbKmWb817wIDAQABo0Ew\nPzAeBgNVHREEFzAVghNtYWlsZmlsdGVyLnN1bmV0LnNlMB0GA1UdDgQWBBQ+3/bs\nSg4SKO4FCGqYge9BF2au7TANBgkqhkiG9w0BAQUFAAOCAQEAVxV3i2vePzZeSjyy\n/i7KiU62byrG6YVBpUnmuofRuNtrC0pvnEMlGYI93pqOuQOe0sw5CEweIIyeTfQ2\n7AlQPA3kiIyvG1mubSJH421oJWXt1GJD/RRH56uJtGUzOykEC350lwcQ3chnQauO\nTJuwybaXhBX3CiHaq2aUt4rLRCiY4q3i2n0x/K5h3YajaI1I/6kSmA/2i6N7kUM3\nywk5dDSfqTd62MTtqC8hJXQj0pQlQ/9GBeoyE83uTSrPR+Fo3bcGPu6WPs3FeQY5\nEeerFHSYV6H0U7y47ZJcBMX2n4xZXMZbTYTlX1AHOYiU3y7I/ZCvSuZScFBK5Lk/\nKHCx/w=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=mailfilter.sunet.se"
                    },
                    "x509_issuer_serial": {
                      "x509_serial_number": {
                        "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SerialNumber",
                        "text": "11414469578012237281"
                      },
                      "x509_issuer_name": {
                        "__class__": "http://www.w3.org/2000/09/xmldsig#&X509IssuerName",
                        "text": "CN=mailfilter.sunet.se"
                      },
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509IssuerSerial"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "mailfilter.sunet.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJAJ5oV5rQ7B3hMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE21haWxmaWx0ZXIuc3VuZXQuc2UwHhcNMTAwODI2MTk0NDIyWhcNMjAwODIz\nMTk0NDIyWjAeMRwwGgYDVQQDExNtYWlsZmlsdGVyLnN1bmV0LnNlMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuwGz7eWqtVCW3Be28I+IPpODVQDPQIwi\nchEFFSJdlkF7c9XN806yVAaGvsOrnNaFUTM5h/Gc4Hak1A0puoLI1aMkyeA0sMWb\nMi6owbVDrjXGoD4gAoC9AIhqfj0NtE8zGlbGsL0dezM68NJwIt2C30U1rzOfUS53\nrngSTvleQK0lnd8I2Sys+msN6kP+4N64A3IBg6A2AVZtaadB6fJIoxQrQOhU3N1U\nAfaK8TcLaclVC5PfiwuJuiSLM0RgMy68B0Fht0V6lUpdiBoF5nU4sKAVYjZz+ZHo\npi6sntIe+FchSvmDXf7zqqLS/NQiM+bD65T/nvazAbtBIbKmWb817wIDAQABo0Ew\nPzAeBgNVHREEFzAVghNtYWlsZmlsdGVyLnN1bmV0LnNlMB0GA1UdDgQWBBQ+3/bs\nSg4SKO4FCGqYge9BF2au7TANBgkqhkiG9w0BAQUFAAOCAQEAVxV3i2vePzZeSjyy\n/i7KiU62byrG6YVBpUnmuofRuNtrC0pvnEMlGYI93pqOuQOe0sw5CEweIIyeTfQ2\n7AlQPA3kiIyvG1mubSJH421oJWXt1GJD/RRH56uJtGUzOykEC350lwcQ3chnQauO\nTJuwybaXhBX3CiHaq2aUt4rLRCiY4q3i2n0x/K5h3YajaI1I/6kSmA/2i6N7kUM3\nywk5dDSfqTd62MTtqC8hJXQj0pQlQ/9GBeoyE83uTSrPR+Fo3bcGPu6WPs3FeQY5\nEeerFHSYV6H0U7y47ZJcBMX2n4xZXMZbTYTlX1AHOYiU3y7I/ZCvSuZScFBK5Lk/\nKHCx/w=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=mailfilter.sunet.se"
                    },
                    "x509_issuer_serial": {
                      "x509_serial_number": {
                        "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SerialNumber",
                        "text": "11414469578012237281"
                      },
                      "x509_issuer_name": {
                        "__class__": "http://www.w3.org/2000/09/xmldsig#&X509IssuerName",
                        "text": "CN=mailfilter.sunet.se"
                      },
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509IssuerSerial"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mailfilter.sunet.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mailfilter.sunet.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mailfilter.sunet.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mailfilter.sunet.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mailfilter.sunet.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://mailfilter.sunet.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mailfilter.sunet.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://mailfilter.sunet.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://mailfilter.sunet.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://mailfilter.sunet.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://se.timeedit.net/lu-student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@evolvera.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TimeEdit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://se.timeedit.net/lu-student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://se.timeedit.net/web/lu/db1/timeedit/ssoLogout/lu_stud_saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TimeEdit, utvecklat av Evolvera AB"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TimeEdit, developed by Evolvera AB"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TimeEdit f\u00f6r studenter vid Lunds universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TimeEdit for students at Lund University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAggCCQDSfJxeKVOg3jANBgkqhkiG9w0BAQUFADBSMQswCQYDVQQGEwJTRTESMBAGA1UE\nBxQJR8O2dGVib3JnMRQwEgYDVQQKEwtUaW1lRWRpdCBBQjEZMBcGA1UEAxMQYXV0aC50aW1lZWRp\ndC5zZTAeFw0xMzA2MTQwNzE0MTlaFw0xNTA2MTQwNzE0MTlaMFIxCzAJBgNVBAYTAlNFMRIwEAYD\nVQQHFAlHw7Z0ZWJvcmcxFDASBgNVBAoTC1RpbWVFZGl0IEFCMRkwFwYDVQQDExBhdXRoLnRpbWVl\nZGl0LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoL+lyBleTM0UGwGPLXPcfBMr\nomnPqP8+qlE+rOs0mEbvNyXdEWT0Z5P/XoMVfERJQQ6v5DAJF4c3o1BiPshZL8cj6QdLuJXLfVNG\nu5mzq/lKpB/n38Y4cWYxIyNtBcV9vcKDIRUbQP/27nEPMsbs2IaCXf6V3l3yQqbymZTyd8nBfZZF\nG95zDKBTSD5UQ3XW+LbvjKSZY4qDjyFkeOfj8kVyltWTHRMvKTKGLeNrGyCFiaMY/vfyA22gOyz4\nO2cY/oqFs8+82AOs3Si4+eGkFAq3CdEWSE4c69oDrzEWk+bKgxw5qyhWQ/13eh8AiZMDeqhT7q32\nRthqEp8GfwPM1QIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCRsLvMI4OJ076STPIyxnwk6bXRG5RL\nMR1pJ3umMNCa1LR1RnH1feuvm9dxerUTow7bPIsarJarh0iEIj2kLtu/prPm+ZcAKeEjh27pSM7m\n1F0XBkDqeP1msR+7g0aHlt0MzrKm/Esb1JX9YCO3MHl1XFc8xSnv2bxKWvER+tmDWkFrC0y1u2+H\nB/CfyES8ntBP6F7aZ6UQ4GTrqF0MZNGBoWFyXecGe5XEwWJwP4otSrJ2q7cbQU33xEcri0dHiMMl\nTiN/6f25dSm5UFCxqWGGAQndGfn/tE5FSqJlrHnbF2M6x4eH3MEIbHebI+nJlk6ASPdgIssvsDcd\nGImnaeS4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://se.timeedit.net/web/lu/db1/timeedit/ssoResponse/lu_stud_saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "false"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://sso.eur.nl/opensso",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.eur.nl/opensso",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-06-30T13:30:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/80e917885da2dd2624b1408b6b69fa2a",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eur.nl"
              },
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Erasmus Universiteit Rotterdam"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Erasmus University Rotterdam"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/eur.png",
                    "height": "25",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Erasmus Universiteit Rotterdam"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Erasmus University Rotterdam"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Erasmus University Rotterdam"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eur.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Erasmus University Rotterdam"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:mlml.calstate.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "iamadmin@calstate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marcus M. Mizushima"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pklepac@mlml.calstate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul Klepac"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jarlt@mlml.calstate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeff Arlt"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "iamadmin@calstate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Eli Pham"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:mlml.calstate.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-mlml.calstate.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-mlml.calstate.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFZDCCBEygAwIBAgIJANHtJiw8sqZ3MA0GCSqGSIb3DQEBBQUAMIHRMQswCQYD\nVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMTW9zcyBMYW5k\naW5nMSQwIgYDVQQKExtDYWxpZm9ybmlhIFN0YXRlIFVuaXZlcnNpdHkxKTAnBgNV\nBAsTIE1vc3MgTGFuZGluZyBNYXJpbmUgTGFib3JhdG9yaWVzMR4wHAYDVQQDExVp\nZHAtbWxtbC5jYWxzdGF0ZS5lZHUxJTAjBgkqhkiG9w0BCQEWFml0c3VwcG9ydEBj\nYWxzdGF0ZS5lZHUwHhcNMTIwNzE3MTYyMTE3WhcNMjIwNzE1MTYyMTE3WjCB0TEL\nMAkGA1UEBhMCVVMxEzARBgNVBAgTCkNhbGlmb3JuaWExFTATBgNVBAcTDE1vc3Mg\nTGFuZGluZzEkMCIGA1UEChMbQ2FsaWZvcm5pYSBTdGF0ZSBVbml2ZXJzaXR5MSkw\nJwYDVQQLEyBNb3NzIExhbmRpbmcgTWFyaW5lIExhYm9yYXRvcmllczEeMBwGA1UE\nAxMVaWRwLW1sbWwuY2Fsc3RhdGUuZWR1MSUwIwYJKoZIhvcNAQkBFhZpdHN1cHBv\ncnRAY2Fsc3RhdGUuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\nyk/L4w1fUSkaLroiQI/rfYME0l9KvWLFSc6c4UGsI0Zkp/t5gelAOvxtkB76k/B0\n+n2oxKpX/9U3wjmgd8NzKyv4hYbcOdgbQtl672iiR+xf2aEuMvT3JQdcqYse4yXv\njim9nxdmbtemJhNZvCgKdb9URseNnB3BVfQL1dr9iaByDsKErMa5Cy375D+4DSWY\n0tC24rJMLKjNygCOu9htKoZI/A2opKbVF80mH3Ujv5SeqGfj06MHO4Az3emztsc/\nykwN6MG0LB4Et/7d/dySW34zAyQG9M6t17NjB4IW8uzq1YjmWo81DXsDdjyKNRgk\nJytvT4mhnV4Iqm7kcS37kQIDAQABo4IBOzCCATcwHQYDVR0OBBYEFMshsF41jQre\nmlkl8hPrvquQAlBHMIIBBgYDVR0jBIH+MIH7gBTLIbBeNY0K3ppZJfIT676rkAJQ\nR6GB16SB1DCB0TELMAkGA1UEBhMCVVMxEzARBgNVBAgTCkNhbGlmb3JuaWExFTAT\nBgNVBAcTDE1vc3MgTGFuZGluZzEkMCIGA1UEChMbQ2FsaWZvcm5pYSBTdGF0ZSBV\nbml2ZXJzaXR5MSkwJwYDVQQLEyBNb3NzIExhbmRpbmcgTWFyaW5lIExhYm9yYXRv\ncmllczEeMBwGA1UEAxMVaWRwLW1sbWwuY2Fsc3RhdGUuZWR1MSUwIwYJKoZIhvcN\nAQkBFhZpdHN1cHBvcnRAY2Fsc3RhdGUuZWR1ggkA0e0mLDyypncwDAYDVR0TBAUw\nAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAPgiqzlbPXyjP29dhlOIvATne68IbTEEv\nBEOOshvQYna/SlbmhzVFp2+mqJILXjBu3b7+MhydoxQSFDiK7yWmvU02Ownk0tYL\niL54lUeZs8ADRZYipvzdsJ0E7E6LxC4JOsFREigFafDwk1lSBKSJ+JsEhmuNzEhz\n+0cck/yTzDrnBvJuqrVWsv9Po6nJN6lgpf7P+H4fzPRLgRN4IymUuKTl+av9C8Nh\n0PKULq364ZYjX+pa5f2au9lPWj1nwmV9lc9envcbiU7hg6LXZeh5fD5dzsad5YCn\nrDOZv9+tMo8RM/TCwSdro/wDgMKNegtJQb3Wny5phuSnRENGn+sr4w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mlml.calstate.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-mlml.calstate.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-mlml.calstate.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-mlml.calstate.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-mlml.calstate.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-mlml.calstate.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-mlml.calstate.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mlml.calstate.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Moss Landing Marine Laboratories"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFZDCCBEygAwIBAgIJANHtJiw8sqZ3MA0GCSqGSIb3DQEBBQUAMIHRMQswCQYD\nVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMTW9zcyBMYW5k\naW5nMSQwIgYDVQQKExtDYWxpZm9ybmlhIFN0YXRlIFVuaXZlcnNpdHkxKTAnBgNV\nBAsTIE1vc3MgTGFuZGluZyBNYXJpbmUgTGFib3JhdG9yaWVzMR4wHAYDVQQDExVp\nZHAtbWxtbC5jYWxzdGF0ZS5lZHUxJTAjBgkqhkiG9w0BCQEWFml0c3VwcG9ydEBj\nYWxzdGF0ZS5lZHUwHhcNMTIwNzE3MTYyMTE3WhcNMjIwNzE1MTYyMTE3WjCB0TEL\nMAkGA1UEBhMCVVMxEzARBgNVBAgTCkNhbGlmb3JuaWExFTATBgNVBAcTDE1vc3Mg\nTGFuZGluZzEkMCIGA1UEChMbQ2FsaWZvcm5pYSBTdGF0ZSBVbml2ZXJzaXR5MSkw\nJwYDVQQLEyBNb3NzIExhbmRpbmcgTWFyaW5lIExhYm9yYXRvcmllczEeMBwGA1UE\nAxMVaWRwLW1sbWwuY2Fsc3RhdGUuZWR1MSUwIwYJKoZIhvcNAQkBFhZpdHN1cHBv\ncnRAY2Fsc3RhdGUuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\nyk/L4w1fUSkaLroiQI/rfYME0l9KvWLFSc6c4UGsI0Zkp/t5gelAOvxtkB76k/B0\n+n2oxKpX/9U3wjmgd8NzKyv4hYbcOdgbQtl672iiR+xf2aEuMvT3JQdcqYse4yXv\njim9nxdmbtemJhNZvCgKdb9URseNnB3BVfQL1dr9iaByDsKErMa5Cy375D+4DSWY\n0tC24rJMLKjNygCOu9htKoZI/A2opKbVF80mH3Ujv5SeqGfj06MHO4Az3emztsc/\nykwN6MG0LB4Et/7d/dySW34zAyQG9M6t17NjB4IW8uzq1YjmWo81DXsDdjyKNRgk\nJytvT4mhnV4Iqm7kcS37kQIDAQABo4IBOzCCATcwHQYDVR0OBBYEFMshsF41jQre\nmlkl8hPrvquQAlBHMIIBBgYDVR0jBIH+MIH7gBTLIbBeNY0K3ppZJfIT676rkAJQ\nR6GB16SB1DCB0TELMAkGA1UEBhMCVVMxEzARBgNVBAgTCkNhbGlmb3JuaWExFTAT\nBgNVBAcTDE1vc3MgTGFuZGluZzEkMCIGA1UEChMbQ2FsaWZvcm5pYSBTdGF0ZSBV\nbml2ZXJzaXR5MSkwJwYDVQQLEyBNb3NzIExhbmRpbmcgTWFyaW5lIExhYm9yYXRv\ncmllczEeMBwGA1UEAxMVaWRwLW1sbWwuY2Fsc3RhdGUuZWR1MSUwIwYJKoZIhvcN\nAQkBFhZpdHN1cHBvcnRAY2Fsc3RhdGUuZWR1ggkA0e0mLDyypncwDAYDVR0TBAUw\nAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAPgiqzlbPXyjP29dhlOIvATne68IbTEEv\nBEOOshvQYna/SlbmhzVFp2+mqJILXjBu3b7+MhydoxQSFDiK7yWmvU02Ownk0tYL\niL54lUeZs8ADRZYipvzdsJ0E7E6LxC4JOsFREigFafDwk1lSBKSJ+JsEhmuNzEhz\n+0cck/yTzDrnBvJuqrVWsv9Po6nJN6lgpf7P+H4fzPRLgRN4IymUuKTl+av9C8Nh\n0PKULq364ZYjX+pa5f2au9lPWj1nwmV9lc9envcbiU7hg6LXZeh5fD5dzsad5YCn\nrDOZv9+tMo8RM/TCwSdro/wDgMKNegtJQb3Wny5phuSnRENGn+sr4w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Moss Landing Marine Laboratories"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mlml.calstate.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Moss Landing Marine Laboratories"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.uwyo.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "thomas.wilson@uwyo.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tom Wilson"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Robert.Morrison@uwyo.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert Morrison"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mkelly@uwyo.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matt Kelly"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "thomas.wilson@uwyo.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tom Wilson"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.uwyo.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.uwyo.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.uwyo.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.uwyo.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.uwyo.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.uwyo.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.uwyo.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uwyo.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Production IdP for UWYO domain"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.uwyo.edu/_files/images/logo.png",
                    "lang": "en",
                    "height": "253",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "88"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Wyoming"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVANo3Z4/Uxn2PVJs0WudES8wCVuyuMA0GCSqGSIb3DQEB\nBQUAMB4xHDAaBgNVBAMTE3NoaWJib2xldGgudXd5by5lZHUwHhcNMTIwMjE1MjE1\nMTMwWhcNMzIwMjE1MjE1MTMwWjAeMRwwGgYDVQQDExNzaGliYm9sZXRoLnV3eW8u\nZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAhs08G8iQTjb2XzJ2\n5O6QqeYfvXWiELJyGXYQzx3Wmk86vTciI2xZ7Jty+ltBtWVwo7L9y9/d1oLLVjZ+\n/lpQiwyOrL0mjg5XmUAZlvUkgPYFdrUUQRGFFxn+23U47hx7QuXyLDNkaJp9rZXb\nDpieXuKpg5eqCKBFUWKIlFeUKUIKJStSHck2dTiIX2fFc/MkkCW4ThNUpZxbz+3w\na/qamV9bu81/MBXze8ZYIWe/vw/9IN6BHq6rgH+W7DZVMrVdkwSHDGuVnrIkoO23\nigi2EJZ3rkW3C8mkZW98TL3kLVJtmhUxrHE3ET+y9qibujXINGiaZbfMjJqVm8Yh\npeNqnwIDAQABo20wazBKBgNVHREEQzBBghNzaGliYm9sZXRoLnV3eW8uZWR1hipo\ndHRwczovL3NoaWJib2xldGgudXd5by5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0O\nBBYEFOiPv5aGKE0BejOyz/xU627PJMLQMA0GCSqGSIb3DQEBBQUAA4IBAQBlYTmR\nWIs7Z8XFGNMmBpLMhEreQry4EC3mErUaLgH88mAT907dkZYmUBnQh2+ckFdzJtaX\njGu4xCad6HFgCW/6OwmvfqaLEmCmu1ePX/05opEZS/dbbGN4qnbe7hxetC7mm8FW\nZpdD0gf3Agw5wNueGv7cubwYGYEdG4yQGcq59Z1WwW9mD92tI7KfnxX4Ew0vO1pg\n35OqYyFafhnIhBGVi3SyxNSCuy2et9euMTwnmg/Q1DJvWup1US8Ny3GJEFytX72T\nvvzAEN1ksmkE84dyB8aObIrU3F7zmXG3LhS93xrPKNiXtB48BM6ovBkUQr+DGlRZ\nsAnxXYy7lSDqYZTx"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Wyoming"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uwyo.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Wyoming"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-p03.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-p03.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p03.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p03.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p03.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p03.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p03.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-p03.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-p03.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-p03.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-p03.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIJALlFagI0Uwl6MA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2xhZG9rMy1wMDMubGFkb2sudW11LnNlMB4XDTE0MDEyNDEzNTMxN1oXDTI0\nMDEyMjEzNTMxN1owIjEgMB4GA1UEAxMXbGFkb2szLXAwMy5sYWRvay51bXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC2WRXxwfEiKVZs2lT22FnK\njP3pzSrMxwC+7em7IAqvUYDAp4h7Cgmx4ip8m6Hv7H5pnfd1BGZzjeX5dErIG9OG\nv+6vZ0/H2jZzWoliBdTH7hpkfmJQldBgu19f6twEfAwrdulCyUR6WIsEYdANsfnw\ngCQ5Tu7gNg/EjzV2Co9wO/0EeaWd9G85PFfqX3U0oOIPU8u6TR7yRbFcoTH1AhCW\njCqulJm6VD0RXkKtx/K4GcuNfkjwRiKcYZci6Hw4Pzj/iZpDeCmKQED0p8uzRbhQ\nLI/dLIYCN8HMrLkr71KVTgbJOTZU221P5Ikql8ApezzAEy0vIsFdCXymuiCoKVFf\nAgMBAAGjbTBrMEoGA1UdEQRDMEGCF2xhZG9rMy1wMDMubGFkb2sudW11LnNlhiZo\ndHRwczovL2xhZG9rMy1wMDMubGFkb2sudW11LnNlL2d1aS1zcDAdBgNVHQ4EFgQU\nA9R98B+FMizzUlovAXJA01jKOuIwDQYJKoZIhvcNAQEFBQADggEBAAfQ+mZxoMnJ\nEfHAHHiRf7v7HX3MSSRKmvp4lnS/o1y4uWeCGTCH9sQfKO6M9v+nLDjhIATo8ZjH\n1ygw+O/6jyXe1KHR5nbnYk2gHjLFGMhjk8B8+FeYaLH0ToHc3BMvtQk3m9527IBj\n6W9CPtsWTho4WXHVldfPRa9qZuE/ShTRijfJBuZsDl4f4jNACu8W4ftpc7FXkhR6\n27tJTACV6SprvPMO9tPiTPs4tK3kRGlvFg7LYv9f5miF7CPx3w5sbBO16ZGiPvtA\n64ROLHRju0HiVT29/waQDjdp8ku+tl1cP9TYHPsHCP1Ngd7o9lxtsXKOMtBJID7w\nX1EbeNi162M="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-p03.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p03.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p03.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p03.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p03.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p03.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p03.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-p03.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-p03.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-p03.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.testa.antagning.se/aws-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al2"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://www.swamid.se/assurance-requirement",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.testa.antagning.se/aws-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.testa.antagning.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.testa.antagning.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.testa.antagning.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.testa.antagning.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.testa.antagning.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.testa.antagning.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.testa.antagning.se/aws-sp/aws-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.testa.antagning.se/aws-sp"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIJALhHdWlTdPORMA0GCSqGSIb3DQEBBQUAMCgxJjAkBgNV\nBAMTHXd3dy50ZXN0YS5hbnRhZ25pbmcuc2UvYXdzLXNwMB4XDTExMTEwMzEzMTQw\nM1oXDTIxMTAzMTEzMTQwM1owKDEmMCQGA1UEAxMdd3d3LnRlc3RhLmFudGFnbmlu\nZy5zZS9hd3Mtc3AwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDvjfZK\nUCha0m0sDBe9pVL/YY9gbWAspd363rlCEaFyY481s2lYX8gXPgC/bFD8WT7XAKxa\ntYjX3ju6q4Jw/ZKdwnd3u3V9uVWSgwmc8BGAdV/WP2y5mSU9EJyTPWWBTqK50wPm\nCnTrLZqoAsWIywR5R9xusYZf8IjeOSv9ojF9yvp5+m6teGLbN8j0/CRg2SCyQkmi\ntW+QZgkwbGz8X6hvMDoOR8ViNBEZFHPDoGJvyl0SowAUvGCQ12YR8wfXBB59juFL\nE+33WgyWEEfFc+skHA0LRsHvzyQ33wRHi7wMTaSu6WlxG7lzgxzfKzJpS6RoGwmP\nsGFRskXDDYavCR4xAgMBAAGjeTB3MFYGA1UdEQRPME2CHXd3dy50ZXN0YS5hbnRh\nZ25pbmcuc2UvYXdzLXNwhixodHRwczovL3d3dy50ZXN0YS5hbnRhZ25pbmcuc2Uv\nYXdzLXNwL2F3cy1zcDAdBgNVHQ4EFgQUZ+hrnqVNJLbnEvnckP4Q9y2XDOUwDQYJ\nKoZIhvcNAQEFBQADggEBAOZaSI+yZF8yJyUuwE+rfxiTPARNAcfvk2aZluLnW77F\nyIutnbUefGHCwizVrZlV5y2TDDbsVsvNDmFpzEYP5l3DzkCtaCS5VhqPYcs24hN6\nCv5mxYMiXcAzvBfeF00N08eZhMHqjTArwSMy0FDI3x+9eykIdiGAk+bVhGTVgODb\nAozy2tOSe3IQkBbEhNMwXG6zd0vk+EvjJOY70mDM1fTstk1RlC5SfKOKedR7OPVx\nXWs22uhZ+dUKGogeaw1c8TIN5IecMckSvoBEKlNnWUUqkRZ+uPXc39UAxSgkbp6k\nNwmwca4vUPP18NPxE6sVgzPFFieSJjeVNXufl0sye1Q="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.testa.antagning.se/aws-sp"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.testa.antagning.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.testa.antagning.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.testa.antagning.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.testa.antagning.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.testa.antagning.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.testa.antagning.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.testa.antagning.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.testa.antagning.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.testa.antagning.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.testa.antagning.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.londonmetsu.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.londonmetsu.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-11-19T15:35:04Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "London Metropolitan University Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.londonmetsu.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.londonmetsu.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.londonmetsu.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.londonmetsu.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.londonmetsu.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.londonmetsu.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.londonmetsu.org.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.londonmetsu.org.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.londonmetsu.org.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.londonmetsu.org.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.londonmetsu.org.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.londonmetsu.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.londonmetsu.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.londonmetsu.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.londonmetsu.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.londonmetsu.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.londonmetsu.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.schoolspeoplenet.nsix.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:schoolapps@norfolk.gov.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "School Apps Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:schoolapps@norfolk.gov.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "School Apps Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.schoolspeoplenet.nsix.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-01-09T10:29:04Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Norfolk Schools Peoplenet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.norfolk.gov.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Norfolk County Council"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.schoolspeoplenet.nsix.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.schoolspeoplenet.nsix.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.schoolspeoplenet.nsix.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.schoolspeoplenet.nsix.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.schoolspeoplenet.nsix.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sp.schoolspeoplenet.nsix.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAN5YKsPXDSWGMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGG5jY3ZtcnAwOC5ub3Jmb2xrLmdvdi51azAeFw0xNDAxMDkwOTI3MzhaFw0y\n\t\t\t\t\t\tNDAxMDcwOTI3MzhaMCMxITAfBgNVBAMTGG5jY3ZtcnAwOC5ub3Jmb2xrLmdvdi51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKY8JugWRi8mTZVkCiD0\n\t\t\t\t\t\tHBPw7+uorNwt6pOfIvtRqs7TJyNYjbKaE5dM/ZSuiD0Zv+YSuOGmZJClcRbX5w5S\n\t\t\t\t\t\t58qNXjqQKSj5FrSxOmlGq0SGcmNVai1fedaMSrUIgJzoGEKwmpGw1+TL7m22h1nZ\n\t\t\t\t\t\tlYl2p47/8hSXixdYYwLH0XpPzLrqQzvj3TRGQOVHYhnUJcDR2gUzmPqXAaKDEd5d\n\t\t\t\t\t\tneeV/s3eko9kJWRpGsXG+epPzrYtakHhireRsoaka+t20T3biRLa4IT9OqQzT4OJ\n\t\t\t\t\t\tXn4ae/LvJ9NLORVDKTgPKxp0shN0OLvOmWKCZIyb2I2dp9JyXVXDdCC4rJXZi23S\n\t\t\t\t\t\tHbMCAwEAAaNGMEQwIwYDVR0RBBwwGoIYbmNjdm1ycDA4Lm5vcmZvbGsuZ292LnVr\n\t\t\t\t\t\tMB0GA1UdDgQWBBSPEDbgPGg9G0Jm+54R4+UEvh/UrzANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEADudrAdcCD/UWqwvZ7+wL+RUK3E5YCIqwLOYVa80vMtR+PzBpHALoAj6cCm60\n\t\t\t\t\t\tt05dwf4wbPYnJaHoTF/m0Lp/Upwx4UWn8eATlg9Ao6Crkblv3z4gkzd744Cxc9Jr\n\t\t\t\t\t\tgOEHnn+YomA2pEe91rWT/vWapAlveMKdbXLw7eYmUfXeC0w2fQ6elnfhLSpUJXCR\n\t\t\t\t\t\t4DTDyww2YdMVDdkW+8e520LdkXROLEyzZjRWJ8ltXFMGqIr7/ulkOh4M6CoMgSO5\n\t\t\t\t\t\tV1RkCcDHXv9gSHsR4sLFl7ihWLiy8cwYh2ZrV+WfrVMPq+apGUNvw/2rr8LGZ7GI\n\t\t\t\t\t\tWRa4qcbZKMNcIe2284SSyOXXLA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.schoolspeoplenet.nsix.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp.schoolspeoplenet.nsix.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.schoolspeoplenet.nsix.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp.schoolspeoplenet.nsix.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp.schoolspeoplenet.nsix.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp.schoolspeoplenet.nsix.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://oa.kluwerlawonline.com/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "van Engelenburg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kirsten.vanengelenburg@wolterskluwer.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kirsten"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "van Engelenburg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kirsten.vanengelenburg@wolterskluwer.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kirsten"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://oa.kluwerlawonline.com/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-03-23T10:48:43Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "KluwerLawOnline"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kluwerlawonline.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Kluwer Law International BV"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "With an online subscription to Kluwer Law Online, \n\t\tyou gain access to the pdfs and bibliographical information of any of the journals and manuals."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "KluwerLawOnline"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDnTCCAoWgAwIBAgIJAJYLHg2fH267MA0GCSqGSIb3DQEBBQUAMD0xGjAYBgNV\n\t\t\tBAoTEUtsdXdlciBMYXcgT25saW5lMR8wHQYDVQQDExZvYS5rbHV3ZXJsYXdvbmxp\n\t\t\tbmUuY29tMB4XDTE1MDczMTE2NDkwNloXDTI1MDcyODE2NDkwNlowPTEaMBgGA1UE\n\t\t\tChMRS2x1d2VyIExhdyBPbmxpbmUxHzAdBgNVBAMTFm9hLmtsdXdlcmxhd29ubGlu\n\t\t\tZS5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCUcpIkgmhzB1g+\n\t\t\t+eTVTnyKWRgs+/mSDUPw7FrYtCPiDYEBmenr609GD6vZYCbvHRLqYY10jEo/Nyq7\n\t\t\tvP1XF6kyoBcFa/dANKGuAq8l0ZB18HiU85BvwRKfpf27A/UOq3cMHBQnZsRs/aT4\n\t\t\tQRgOulKMu5wrPRzH6r5Zs8L0LRo+sGcP0cn4/R6sdCtZ5/VX3KvuDHLTuWkVFmAn\n\t\t\t0fJjFJ+DXkc64llNWbZkbcOHucN9bOkBfwwSL4DQDp6oQCDfMCxD/FnNinvN8CUC\n\t\t\t4JphqnjgYynnTceN9MYZt0AOJamOCaQVAJIP9oKpydgb/FHp+FQAa3ro6lqg5l5C\n\t\t\t69155ppJAgMBAAGjgZ8wgZwwHQYDVR0OBBYEFO67+5bmuAYHPlYPyZyRX6FZs8f/\n\t\t\tMG0GA1UdIwRmMGSAFO67+5bmuAYHPlYPyZyRX6FZs8f/oUGkPzA9MRowGAYDVQQK\n\t\t\tExFLbHV3ZXIgTGF3IE9ubGluZTEfMB0GA1UEAxMWb2Eua2x1d2VybGF3b25saW5l\n\t\t\tLmNvbYIJAJYLHg2fH267MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEB\n\t\t\tADAaSYwEwCQZ4OapKHSIX9p3Ia7/ALFx/p1D6dJjltSNuE114ql4NfouR7DisgIb\n\t\t\tI61dtVM/fzjYeypmkLcbX2bqI+nQNbKPyjkmnW8nKIQuM7fPwy0kQwV9LlOe8aco\n\t\t\tnx4zVpkZST/aJhsbBF/PXVHKLuoTKe+E3pwqlvrtxSWVKYY4V+cFWzDMtZN79AMF\n\t\t\tVwJ5T9KvixVnSnw5UnEUZGtxDBeYnTEIq7uQnObdkSMWWF8SxUNJusb6eK7PFL77\n\t\t\tS4Xmt02YQb+KgWfOlxUJYTdPVwTWgl1mG+bJtMGhm+Fhvbe6XsE9OTkR3JukWM09\n\t\t\tEdleBJR5tYeTchiSmuPV+fU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDnTCCAoWgAwIBAgIJAJYLHg2fH267MA0GCSqGSIb3DQEBBQUAMD0xGjAYBgNV\n\t\t\tBAoTEUtsdXdlciBMYXcgT25saW5lMR8wHQYDVQQDExZvYS5rbHV3ZXJsYXdvbmxp\n\t\t\tbmUuY29tMB4XDTE1MDczMTE2NDkwNloXDTI1MDcyODE2NDkwNlowPTEaMBgGA1UE\n\t\t\tChMRS2x1d2VyIExhdyBPbmxpbmUxHzAdBgNVBAMTFm9hLmtsdXdlcmxhd29ubGlu\n\t\t\tZS5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCUcpIkgmhzB1g+\n\t\t\t+eTVTnyKWRgs+/mSDUPw7FrYtCPiDYEBmenr609GD6vZYCbvHRLqYY10jEo/Nyq7\n\t\t\tvP1XF6kyoBcFa/dANKGuAq8l0ZB18HiU85BvwRKfpf27A/UOq3cMHBQnZsRs/aT4\n\t\t\tQRgOulKMu5wrPRzH6r5Zs8L0LRo+sGcP0cn4/R6sdCtZ5/VX3KvuDHLTuWkVFmAn\n\t\t\t0fJjFJ+DXkc64llNWbZkbcOHucN9bOkBfwwSL4DQDp6oQCDfMCxD/FnNinvN8CUC\n\t\t\t4JphqnjgYynnTceN9MYZt0AOJamOCaQVAJIP9oKpydgb/FHp+FQAa3ro6lqg5l5C\n\t\t\t69155ppJAgMBAAGjgZ8wgZwwHQYDVR0OBBYEFO67+5bmuAYHPlYPyZyRX6FZs8f/\n\t\t\tMG0GA1UdIwRmMGSAFO67+5bmuAYHPlYPyZyRX6FZs8f/oUGkPzA9MRowGAYDVQQK\n\t\t\tExFLbHV3ZXIgTGF3IE9ubGluZTEfMB0GA1UEAxMWb2Eua2x1d2VybGF3b25saW5l\n\t\t\tLmNvbYIJAJYLHg2fH267MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEB\n\t\t\tADAaSYwEwCQZ4OapKHSIX9p3Ia7/ALFx/p1D6dJjltSNuE114ql4NfouR7DisgIb\n\t\t\tI61dtVM/fzjYeypmkLcbX2bqI+nQNbKPyjkmnW8nKIQuM7fPwy0kQwV9LlOe8aco\n\t\t\tnx4zVpkZST/aJhsbBF/PXVHKLuoTKe+E3pwqlvrtxSWVKYY4V+cFWzDMtZN79AMF\n\t\t\tVwJ5T9KvixVnSnw5UnEUZGtxDBeYnTEIq7uQnObdkSMWWF8SxUNJusb6eK7PFL77\n\t\t\tS4Xmt02YQb+KgWfOlxUJYTdPVwTWgl1mG+bJtMGhm+Fhvbe6XsE9OTkR3JukWM09\n\t\t\tEdleBJR5tYeTchiSmuPV+fU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://oa.kluwerlawonline.com/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://oa.kluwerlawonline.com/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.mcgill.ca/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Shibboleth Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:isrdbateam@campus.mcgill.ca"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "McGill"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.mcgill.ca/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.canarie.ca/templates/services/docs/CAF_join_en.pdf"
              }
            ],
            "registration_instant": "2015-07-07T00:00:00Z",
            "registration_authority": "http://www.canarie.ca",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAKFxePPwNhoZCU/fBrDudUYkci5yMA0GCSqGSIb3DQEB\nBQUAMB8xHTAbBgNVBAMTFHNoaWJib2xldGgubWNnaWxsLmNhMB4XDTEwMDkyNzE0\nNTQyMloXDTMwMDkyNzE0NTQyMlowHzEdMBsGA1UEAxMUc2hpYmJvbGV0aC5tY2dp\nbGwuY2EwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCI6PNQptKRhQiG\ntOCyQdN6aUWLKkNZuVmT3poxRUidZpIOb5erxXMO8QJwLkVrhMke8grdcz6Vvf8R\nRMW0HXLvdo/FUCkGh2ZG8Cc4+zoD8fydix48RuVbXFj365KbwwzMnmTJPah79PAY\nYSWTNz7/GQ/Bkc/H+M17ZBTxMgKC2KnfNoQKt/b5q/V8p+4jyS+jOnGmdiTZewj/\n93nF8NHAeVjkJNXar0trJA3FIVXGNBzR9mGJT/yvjNOoh+RYXkAu4cAAyGCaGCyX\nH2LK/bRuNGVZIs7e+pjF6fLkO1eBczWLLh95SlnLPCNqQJEdUALheaMAco/ZPZSy\nPBiA59/PAgMBAAGjbzBtMEwGA1UdEQRFMEOCFHNoaWJib2xldGgubWNnaWxsLmNh\nhitodHRwczovL3NoaWJib2xldGgubWNnaWxsLmNhL2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBR9d78sZf5fuWvwdRUSKNHNOmodyjANBgkqhkiG9w0BAQUFAAOCAQEA\naC9u7Fw8PkXZHYWv7cxBTvWaQWPnG3T9zRFXT9nbaTWKhnvGG/UwklwRUyPv6oKA\nhTZ+J/8xsmR+IlkSkZhT7RCO2qVWJgKLFFR5NncHIwFiztcyiu9kOYNY5h5WtCde\nb5yYM3NYl2Unh9fHE7ZMSYnVUisC0KjQH7yn9z/7tWGAP7/rjXhPVJSGIwLUpdKN\nF7qiMg3a4zpfvypZOGjtkXyJMBanaLc9UiGBGBE/t4b+fbJP1HQn085EvQPW3tin\nf7FLtBGjplM/vCklFh57cHLjew1y1vud5iMVWqVgKdPJH0EZbbnR7Xa2tt8MKWWs\nyiqk26yLVKsf3etilKA7Jw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mcgill.ca"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.mcgill.ca:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.mcgill.ca:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.mcgill.ca/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.mcgill.ca/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.mcgill.ca/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.mcgill.ca/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.mcgill.ca:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.mcgill.ca:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mcgill.ca"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mcgill.ca/"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAKFxePPwNhoZCU/fBrDudUYkci5yMA0GCSqGSIb3DQEB\nBQUAMB8xHTAbBgNVBAMTFHNoaWJib2xldGgubWNnaWxsLmNhMB4XDTEwMDkyNzE0\nNTQyMloXDTMwMDkyNzE0NTQyMlowHzEdMBsGA1UEAxMUc2hpYmJvbGV0aC5tY2dp\nbGwuY2EwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCI6PNQptKRhQiG\ntOCyQdN6aUWLKkNZuVmT3poxRUidZpIOb5erxXMO8QJwLkVrhMke8grdcz6Vvf8R\nRMW0HXLvdo/FUCkGh2ZG8Cc4+zoD8fydix48RuVbXFj365KbwwzMnmTJPah79PAY\nYSWTNz7/GQ/Bkc/H+M17ZBTxMgKC2KnfNoQKt/b5q/V8p+4jyS+jOnGmdiTZewj/\n93nF8NHAeVjkJNXar0trJA3FIVXGNBzR9mGJT/yvjNOoh+RYXkAu4cAAyGCaGCyX\nH2LK/bRuNGVZIs7e+pjF6fLkO1eBczWLLh95SlnLPCNqQJEdUALheaMAco/ZPZSy\nPBiA59/PAgMBAAGjbzBtMEwGA1UdEQRFMEOCFHNoaWJib2xldGgubWNnaWxsLmNh\nhitodHRwczovL3NoaWJib2xldGgubWNnaWxsLmNhL2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBR9d78sZf5fuWvwdRUSKNHNOmodyjANBgkqhkiG9w0BAQUFAAOCAQEA\naC9u7Fw8PkXZHYWv7cxBTvWaQWPnG3T9zRFXT9nbaTWKhnvGG/UwklwRUyPv6oKA\nhTZ+J/8xsmR+IlkSkZhT7RCO2qVWJgKLFFR5NncHIwFiztcyiu9kOYNY5h5WtCde\nb5yYM3NYl2Unh9fHE7ZMSYnVUisC0KjQH7yn9z/7tWGAP7/rjXhPVJSGIwLUpdKN\nF7qiMg3a4zpfvypZOGjtkXyJMBanaLc9UiGBGBE/t4b+fbJP1HQn085EvQPW3tin\nf7FLtBGjplM/vCklFh57cHLjew1y1vud5iMVWqVgKdPJH0EZbbnR7Xa2tt8MKWWs\nyiqk26yLVKsf3etilKA7Jw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "McGill University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mcgill.ca/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "McGill University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://edgehill.idm.oclc.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Support Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Support Desk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://edgehill.idm.oclc.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-03-30T12:39:06Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Edge Hill University Hosted EZProxy"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oclc.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "OCLC (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://login.edgehill.idm.oclc.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.edgehill.idm.oclc.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.edgehill.idm.oclc.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.edgehill.idm.oclc.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIECDCCAvCgAwIBAgIBAjANBgkqhkiG9w0BAQUFADBlMSAwHgYDVQQDFBcqLmVk\n\t\t\t\t\t\tZ2VoaWxsLmlkbS5vY2xjLm9yZzELMAkGA1UEBhMCVUsxDTALBgNVBAoTBE9DTEMx\n\t\t\t\t\t\tJTAjBgkqhkiG9w0BCQEWFmNhcmwucHJlbnRpY2VAb2NsYy5vcmcwHhcNMTUwMzI3\n\t\t\t\t\t\tMTA0MzEyWhcNMjUwMzI2MTA0MzEyWjBlMSAwHgYDVQQDFBcqLmVkZ2VoaWxsLmlk\n\t\t\t\t\t\tbS5vY2xjLm9yZzELMAkGA1UEBhMCVUsxDTALBgNVBAoTBE9DTEMxJTAjBgkqhkiG\n\t\t\t\t\t\t9w0BCQEWFmNhcmwucHJlbnRpY2VAb2NsYy5vcmcwggEiMA0GCSqGSIb3DQEBAQUA\n\t\t\t\t\t\tA4IBDwAwggEKAoIBAQC9XWwlM5l+FA3Szp7cK4n+ITQL+WzqcL3/c0G7RqQ4Tyiz\n\t\t\t\t\t\tMoe/MLZBw/szuz+ZjeydXwfwnzRZSPtEirT2JnsgBWvB4KgzU6CRImOp8D7x3R3f\n\t\t\t\t\t\tzjpH8rkbtAFRVAhUm1Pc3OWqBGem1NZ2nTLjnNKpboe+w4JZK9/8nD7Mlc4MVpsw\n\t\t\t\t\t\tP85Vk25HHlESlHGvLrv4VM8k3TAPuBfRmnnEP5BEnVq1DRaPMjnhfHkdemKXlRhD\n\t\t\t\t\t\tFy5HrcklKT5hF0WZgh9kvBAqzQKm+K4hZEk4b5SvkPB/rxWQn9Ph6+IxyKBhExB8\n\t\t\t\t\t\tm+Mo3NVP6B6JdMVMhQHH85jabI2dCffzuArWr0GjAgMBAAGjgcIwgb8wHQYDVR0O\n\t\t\t\t\t\tBBYEFIDfx+TCvcdb9L8eeMTtMOGzyXTzMIGPBgNVHSMEgYcwgYSAFIDfx+TCvcdb\n\t\t\t\t\t\t9L8eeMTtMOGzyXTzoWmkZzBlMSAwHgYDVQQDFBcqLmVkZ2VoaWxsLmlkbS5vY2xj\n\t\t\t\t\t\tLm9yZzELMAkGA1UEBhMCVUsxDTALBgNVBAoTBE9DTEMxJTAjBgkqhkiG9w0BCQEW\n\t\t\t\t\t\tFmNhcmwucHJlbnRpY2VAb2NsYy5vcmeCAQIwDAYDVR0TBAUwAwEB/zANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEALeqmiNGUZMU3dXyZfwbf6cAsHlFLaaGt/0SOR8HRHj6mWrBZ\n\t\t\t\t\t\tf6wUeeDCqjHca+hzmeYzdfs74sDtN93QJnT7uKTW6d2wILwEALQHFmQg8IttKiE6\n\t\t\t\t\t\tVlYllB4h/Ji80qu9yoNjsKlyKNsf1gvaB0m21DlMCiLH2ko6GjZnXAvTxmaZ3TDy\n\t\t\t\t\t\tcXULLz3O8+6sQGeNDNPqveWCH7LaWcu0Ir86vgbB7kLxq4R6WeOUnrX0Z4O2yjzu\n\t\t\t\t\t\twuNMTpknM93KKLmgUBIgLViCcmLnYd1s/jXGB+67/MRfHZDCTKHXPQ6IeKoMLgtU\n\t\t\t\t\t\tP3oaxQuVKH67V9gN9dXAVYslrL5acjgqie9w/w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://login.edgehill.idm.oclc.org/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://idp.amue.fr/idp/saml2/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "German hurtado"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "German.hurtado@amue.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Didier Denjean"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Didier.denjean@amue.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.amue.fr/idp/saml2/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-11-26T11:26:33Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.amue.fr/idp/saml2/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.amue.fr/idp/saml2/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "amue.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cpu.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "espe.amue.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iuf.cpu.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.amue.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "AMUE - Agence de Mutualisation des Universit\u00e9s et Etablissements"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "AMUE - Agence de Mutualisation des Universit\u00e9s et Etablissements"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDgTCCAmmgAwIBAgIJAJz0e9ITZF9gMA0GCSqGSIb3DQEBBQUAMFcxCzAJBgNV\nBAYTAkZSMRMwEQYDVQQIDApTb21lLVN0YXRlMQ4wDAYDVQQHDAVQYXJpczENMAsG\nA1UECgwEQU1VRTEUMBIGA1UEAwwLaWRwLmFtdWUuZnIwHhcNMTQxMDE1MTQyMjUz\nWhcNMjQxMDE2MTQyMjUzWjBXMQswCQYDVQQGEwJGUjETMBEGA1UECAwKU29tZS1T\ndGF0ZTEOMAwGA1UEBwwFUGFyaXMxDTALBgNVBAoMBEFNVUUxFDASBgNVBAMMC2lk\ncC5hbXVlLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA241uUmwE\n4O95iIpPgHVBmvQsXgqUx6Jz1tKGQn4T2TQntn//Y2P8qRykhQ2YV+qLbJNrYWC9\nUYMlE+/aP4muMF4ChLV7ij3c6gCkxCAigOoHiQZFwLNPDzjiNs/eAxE/RDB9BUcf\nHL+953Q3lL/EEsWkTggPxaqWatyXbtPRaGl4WypVsztziF9D/Kdo5VVP9dElasBO\naBXRy5HZLVHmGpCaaiOydcMyLf2CO0hA6pxDl3aYvyh1BLF5vcbMTg4tpu7Ks33c\n0H8Gdv8i8FYXZzHrHTghsfHp42obl0f7E7hUuHxRdwOgq7szbMeXIh5HPWm1Yz2S\nXPBwe5LjhuZw3wIDAQABo1AwTjAdBgNVHQ4EFgQUtFPL4vJjppV2NlZrKkczRW4j\n1l8wHwYDVR0jBBgwFoAUtFPL4vJjppV2NlZrKkczRW4j1l8wDAYDVR0TBAUwAwEB\n/zANBgkqhkiG9w0BAQUFAAOCAQEAe3jRuNrsDnBpwD2x6Yep61EPOXTjix12k2iy\nU6x6ggpL3hBjfJuEzMViHB/x2tVc/KaM2QiqRqiIsK73Woa1G00IS7AZvzFm1uyo\nI+tTmgFAcNORr5ucYnCdj3BzirEwLhGbczidsBquyvKL4VzT0oMlVND4jD5DFSlG\n/UFZ57goJxGSNK7pG4RsTi+Eha6CQgm7rNeHMr4lnBLjIOMft37/vkSo1Wx2vXTA\nY6g6XMXwo2b6mIgK0y4447ZzOokArx1Jy7yvg7LDXTwUVVevrIy2Gb+sQlpGeKmr\nlO2z79XxgAmGiMTqrh2EIm+X9F53PSRqNjOExud+Ge1XjSYNVg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDgTCCAmmgAwIBAgIJANYhmQZ/PLaYMA0GCSqGSIb3DQEBBQUAMFcxCzAJBgNV\nBAYTAkZSMRMwEQYDVQQIDApTb21lLVN0YXRlMQ4wDAYDVQQHDAVQYXJpczENMAsG\nA1UECgwEQU1VRTEUMBIGA1UEAwwLaWRwLmFtdWUuZnIwHhcNMTMxMTI1MDk0NzM3\nWhcNMTMxMjI1MDk0NzM3WjBXMQswCQYDVQQGEwJGUjETMBEGA1UECAwKU29tZS1T\ndGF0ZTEOMAwGA1UEBwwFUGFyaXMxDTALBgNVBAoMBEFNVUUxFDASBgNVBAMMC2lk\ncC5hbXVlLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA241uUmwE\n4O95iIpPgHVBmvQsXgqUx6Jz1tKGQn4T2TQntn//Y2P8qRykhQ2YV+qLbJNrYWC9\nUYMlE+/aP4muMF4ChLV7ij3c6gCkxCAigOoHiQZFwLNPDzjiNs/eAxE/RDB9BUcf\nHL+953Q3lL/EEsWkTggPxaqWatyXbtPRaGl4WypVsztziF9D/Kdo5VVP9dElasBO\naBXRy5HZLVHmGpCaaiOydcMyLf2CO0hA6pxDl3aYvyh1BLF5vcbMTg4tpu7Ks33c\n0H8Gdv8i8FYXZzHrHTghsfHp42obl0f7E7hUuHxRdwOgq7szbMeXIh5HPWm1Yz2S\nXPBwe5LjhuZw3wIDAQABo1AwTjAdBgNVHQ4EFgQUtFPL4vJjppV2NlZrKkczRW4j\n1l8wHwYDVR0jBBgwFoAUtFPL4vJjppV2NlZrKkczRW4j1l8wDAYDVR0TBAUwAwEB\n/zANBgkqhkiG9w0BAQUFAAOCAQEAtHnVQXFET0Lq3wjCqbbJFe7wMf2L2y+R2soV\nhFmVuJPW6e2We5MFw3uzw0LWgjFX4+cddimjw1tTDbQO1GRWV1XQiSUpd4iFcqSL\nUncJxo6pOMwQMU/pptjSEKvzGMfkCuPbs8P7KA3KveDJj7r0h/SAJL3Lq42u1dWE\nHReuVPebHm8bm731uo491q1LdjCfUAaz14UMGYJL2UfigFa0fp3ONfkoZR2aob1w\nzYcZ/I9oT7x7mBJe4Fb1lUMrI9+0A4XBORW0i374j1hzvMprE3UW777QDK+TorKh\nJwghMs3y4HmiEKEylVhTWipavdzRw41b9jbFKmgB7MqdBiCfhQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "AMUE - Agence de Mutualisation des Universit\u00e9s et Etablissements"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.amue.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "AMUE - Agence de Mutualisation des Universit\u00e9s et Etablissements"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.cvt.uppfoljning.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.cvt.uppfoljning.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cvt.uppfoljning.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.cvt.uppfoljning.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cvt.uppfoljning.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cvt.uppfoljning.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cvt.uppfoljning.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.cvt.uppfoljning.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.cvt.uppfoljning.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.env.uppfoljning.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.env.uppfoljning.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.env.uppfoljning.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.cvt.uppfoljning.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.cvt.uppfoljning.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIJAJiQ6Y4LQA2rMA0GCSqGSIb3DQEBBQUAMCcxJTAjBgNV\nBAMTHHd3dy5jdnQudXBwZm9sam5pbmcubGFkb2suc2UwHhcNMTUxMDIyMTMyODM1\nWhcNMjUxMDE5MTMyODM1WjAnMSUwIwYDVQQDExx3d3cuY3Z0LnVwcGZvbGpuaW5n\nLmxhZG9rLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1HEGTRbi\ngDbH0FVYPs6k4lKZ5MxM3nxAoSXcRDVizojNNzlsiy9VhqpUZyhJS3PWTd4ORII+\nPZxvApKOGMuIV4HElXfeX7YGm/v4KdXro2Sk5U5KVNzfg43Snb7oRS3pq9km2Uzr\nBmxiMwVxbzROnSfePal1wRyXqQwQJOXTLqLm9XBFC1Z3autwVLvn1YQ8t/c21QK8\nHeoxGGQAlf5IlsetiXNoJH714+ovpsbnlpZB9ZEU8gF+E2j/igGA1YxfcKNbusBi\nKs6olO37lwb0kmULooqEwVIQRXfncOzx/O8QJI9FJWrHQlFmzFre6TAQ/iSVByb6\nrSPw0PXKNzyKYwIDAQABo3cwdTBUBgNVHREETTBLghx3d3cuY3Z0LnVwcGZvbGpu\naW5nLmxhZG9rLnNlhitodHRwczovL3d3dy5jdnQudXBwZm9sam5pbmcubGFkb2su\nc2UvZ3VpLXNwMB0GA1UdDgQWBBRqHw1wOSeUjkz37X5oJtxCZwq3MDANBgkqhkiG\n9w0BAQUFAAOCAQEAVCyTPqAjAYrbO0t9nj/Vma1hbF2Y2rgBpjQDuSOIPuiFNjgw\nl6QVMhxbroL5FcWnYQ5eJAHGMgs7THDKvEs7lLo8hReyA/gyhtv+wnWw75Zdf7G3\nW5EKt6m0g4T0I6vLykleVx5iGcGGWWUKqBcqOEdEtVSnThPo6+qfGNa0+wAU+wYk\ndcRieDbdpuiP1i98Q6xHyHdufBFWypbxd7ay7/978uHhrMt06zgvBqcN0c6vDAEn\nJN8DBjzaLWDIVRmzVzcl/0rdt5hrTbdsWzWr06BNOXjapzJ+YlQ7efSLJDGlyeek\nAmc24v5TLThVrOsV13FA5SIl4sa5rwDvh3WoSw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.cvt.uppfoljning.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cvt.uppfoljning.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.cvt.uppfoljning.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cvt.uppfoljning.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cvt.uppfoljning.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cvt.uppfoljning.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cvt.uppfoljning.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.cvt.uppfoljning.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.cvt.uppfoljning.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.cvt.uppfoljning.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://pera.cs.lth.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://pera.cs.lth.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://pera.cs.lth.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://pera.cs.lth.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pera.cs.lth.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://pera.cs.lth.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://pera.cs.lth.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://pera.cs.lth.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Student Achievement Manager - a system for managing student achievements in courses (labs, assignments et.c.)"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Student Achievement Manager - ett system f\u00f6r att lagra students prestationer p\u00e5 kurser (labbar, inl\u00e4mningsuppgifter et.c.)"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SAM"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SAM"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "pera.cs.lth.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJAPm+5sYdxcHcMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDnBlcmEuY3MubHRoLnNlMB4XDTE1MDQxNzE0NDYyNloXDTI1MDQxNDE0NDYy\nNlowGTEXMBUGA1UEAxMOcGVyYS5jcy5sdGguc2UwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDnul878AQtH03tKJOsn48aTXG4SG/LKA9J8XDmxboZAQLy\nBckIzvahZ7FBH7MZWvJggUmaq9xIaGHS9l5LWtglrxBVsl5ANacyNRe9MJdASIOp\nincSKZ0pIIX3XbJwT7g6dqH9RtRSfVDztvfYCmvrUjpw8x497z45JWVZdAl+bMJI\nmtyyR1yNmWW1ykRIxMkFteQCFI72mumckFC+sLTYwd4DEkZzOaiIcqDeIX4kDJ5p\ncuUCwf69ff7RIrIlQLcsFVz55ZDdoOXU4lzcGoPMl1OCyubOKZSD6AMxIa4JUcHp\ncRNHuiv4AXDLppNsCbo3GyQ8tEZ6WCzgAd545f4nAgMBAAGjPDA6MBkGA1UdEQQS\nMBCCDnBlcmEuY3MubHRoLnNlMB0GA1UdDgQWBBQ39doGEDrBQn9EnuNPwHWXkPdX\nETANBgkqhkiG9w0BAQUFAAOCAQEAfejsXBSZjCLFSkNE7CZV6X4GiaVUQQBjLg4M\nWYbV0DlpFySTJVgGGraEFfIKLpCs95ia8PnQDKKmQ6W4LqVfTxE3CcRaroM3M1O8\nIqacVYr3ZhbrOrQ+6Ldo+TC7LJRxYsJP3BwSUoz76SYvKTZb57xPXMMDlAa+z/oD\nebqJSvnu/O0R6xh5ZGmELyxh8I7toabcaPNHOvM2wlrdh0WXEnZ1zrSZ73tHSV9N\n8w2PsZdwObljCNyShMWZnm+SguQXyG41xD7ZxWddo6KBnb6yyFkaXqKGeZm6fl1i\nLeMlo5NMwFMrOjn5nFCm7yN2pibn2Ttd7O7G9w42rLCsalVNHw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=pera.cs.lth.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pera.cs.lth.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://pera.cs.lth.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://pera.cs.lth.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://pera.cs.lth.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://pera.cs.lth.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://iamlearning.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wilkinson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:michael@i-ed.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wilkinson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:michael@i-ed.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://iamlearning.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "I am learning: Games based revision and assessment for KS1, KS2, KS3, GCSE, Diplomas"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iamlearning.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "I Education Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://iamlearning.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://iamlearning.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://iamlearning.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://iamlearning.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "1",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://iamlearning.co.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC2TCCAcGgAwIBAgIJAMokAyU3GHytMA0GCSqGSIb3DQEBBQUAMBExDzANBgNV\n\t\t\t\t\t\tBAMTBmlkNjMxOTAeFw0xMDAxMTkwOTU0MDZaFw0yMDAxMTcwOTU0MDZaMBExDzAN\n\t\t\t\t\t\tBgNVBAMTBmlkNjMxOTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMYE\n\t\t\t\t\t\toDy4UOTnFc4+FU/zVYM1/+TpqI2+7paafYg6wwacMkMbEGHqp4F/uvM8UnPZcPGO\n\t\t\t\t\t\t4s4BJO30ltKsCqexIxnTvg66V6aw5Gq/PooUCxXGP6rnUyDyTrSm9WWF17WVuLpH\n\t\t\t\t\t\tpzMo5Ki8zlBWPxD2gd1uJuy+Lf8BJJ9aa9cYzx+glEARMXepiDaKpJFfkeSKemh5\n\t\t\t\t\t\tBGVfH38NvBfN+lzaqhkjfyc9IuDPbFoNS5FNCiEN4zgvKxzGXVCZ6kdOgIuJ5Y0G\n\t\t\t\t\t\txENR6oRTJuXQqSSXyaVg1Vk4Z4a5IRIZaM/bOEFwDQGMKFWFIALybFncKQu5/wW1\n\t\t\t\t\t\t4x5aIyLLxHmCnbobTsUCAwEAAaM0MDIwEQYDVR0RBAowCIIGaWQ2MzE5MB0GA1Ud\n\t\t\t\t\t\tDgQWBBSbQnqKj1RxIHMszD6H3Yutb3tlkzANBgkqhkiG9w0BAQUFAAOCAQEAeEED\n\t\t\t\t\t\tN2aGD0CE1PGcyPhARqR6RiXouYrXPhLmHz17SRn0VWBIDMSdZz7OKV8aoq08/qcA\n\t\t\t\t\t\tV9ZnxpUBa6fFOOdMhWcMpHT6Wuroiv2Ny5NQBXT7Xpuswqnv+MuNgOqpKBTQCmU5\n\t\t\t\t\t\tILxIOviUIcAGZgNej3nHfgsT4NzydsiHVgFALirWLXH1J/NmB34+phUtMtaBa9T9\n\t\t\t\t\t\tGrFRWzfWm+K5BCsK7pee4B0GXvbvmDO2BQ7WfIhuZ++8b3uIR+0Z0Giri+waZNPp\n\t\t\t\t\t\tQdYt8st5T7TLnAVqn9pXqrKSHdHjrxfyfCgJOzSPQklYcPeTsnD5M5saEQhIo7WD\n\t\t\t\t\t\tPIDUzYqlDKOVDtrCmA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC2TCCAcGgAwIBAgIJAMokAyU3GHytMA0GCSqGSIb3DQEBBQUAMBExDzANBgNV\n\t\t\t\t\t\tBAMTBmlkNjMxOTAeFw0xMDAxMTkwOTU0MDZaFw0yMDAxMTcwOTU0MDZaMBExDzAN\n\t\t\t\t\t\tBgNVBAMTBmlkNjMxOTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMYE\n\t\t\t\t\t\toDy4UOTnFc4+FU/zVYM1/+TpqI2+7paafYg6wwacMkMbEGHqp4F/uvM8UnPZcPGO\n\t\t\t\t\t\t4s4BJO30ltKsCqexIxnTvg66V6aw5Gq/PooUCxXGP6rnUyDyTrSm9WWF17WVuLpH\n\t\t\t\t\t\tpzMo5Ki8zlBWPxD2gd1uJuy+Lf8BJJ9aa9cYzx+glEARMXepiDaKpJFfkeSKemh5\n\t\t\t\t\t\tBGVfH38NvBfN+lzaqhkjfyc9IuDPbFoNS5FNCiEN4zgvKxzGXVCZ6kdOgIuJ5Y0G\n\t\t\t\t\t\txENR6oRTJuXQqSSXyaVg1Vk4Z4a5IRIZaM/bOEFwDQGMKFWFIALybFncKQu5/wW1\n\t\t\t\t\t\t4x5aIyLLxHmCnbobTsUCAwEAAaM0MDIwEQYDVR0RBAowCIIGaWQ2MzE5MB0GA1Ud\n\t\t\t\t\t\tDgQWBBSbQnqKj1RxIHMszD6H3Yutb3tlkzANBgkqhkiG9w0BAQUFAAOCAQEAeEED\n\t\t\t\t\t\tN2aGD0CE1PGcyPhARqR6RiXouYrXPhLmHz17SRn0VWBIDMSdZz7OKV8aoq08/qcA\n\t\t\t\t\t\tV9ZnxpUBa6fFOOdMhWcMpHT6Wuroiv2Ny5NQBXT7Xpuswqnv+MuNgOqpKBTQCmU5\n\t\t\t\t\t\tILxIOviUIcAGZgNej3nHfgsT4NzydsiHVgFALirWLXH1J/NmB34+phUtMtaBa9T9\n\t\t\t\t\t\tGrFRWzfWm+K5BCsK7pee4B0GXvbvmDO2BQ7WfIhuZ++8b3uIR+0Z0Giri+waZNPp\n\t\t\t\t\t\tQdYt8st5T7TLnAVqn9pXqrKSHdHjrxfyfCgJOzSPQklYcPeTsnD5M5saEQhIo7WD\n\t\t\t\t\t\tPIDUzYqlDKOVDtrCmA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://iamlearning.co.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://iamlearning.co.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://iamlearning.co.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://iamlearning.co.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://iamlearning.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://iamlearning.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://iamlearning.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://iamlearning.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://iamlearning.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://iamlearning.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://dlib-jiscidp.edina.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:edina@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EDINA Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:edina.infrastructure@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EDINA Infrastructure"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ukfed.infrastructure@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UK federation infrastructure"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dlib-jiscidp.edina.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSzCCAjOgAwIBAgIUZooYXtDuohUPtXHr8p6BHj6IAsEwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwIzEhMB8GA1UEAxMYZGxpYi1qaXNjaWRwLmVkaW5hLmFjLnVrMB4XDTEwMDIy\n\t\t\t\t\t\tNjEwMDM1OVoXDTMwMDIyNjEwMDM1OVowIzEhMB8GA1UEAxMYZGxpYi1qaXNjaWRw\n\t\t\t\t\t\tLmVkaW5hLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA479P\n\t\t\t\t\t\tsZNAGnDd+wlw7o+isg+M++16qHhHNzFPKQBhdA+ojQ0nUjQZZT5SgAVt6WeVE4P3\n\t\t\t\t\t\tuwG/fWt3cdQ0xYz4pLneqyzve9uuLd0q4J/oqSGKsb9rfIw+Uw7I6K40WySukfpJ\n\t\t\t\t\t\t7IPREX6z+ymubn7FQOsK9zQ8y6P3Gl67bnnS4CIkot2BKdsX882OoEsDcZGnmXaN\n\t\t\t\t\t\t12L70pN5vQN3PJzNvc8/sz6u9DgDL8OlXY2fn6ASJ2y2etuHCLkAUSsB14pntgyA\n\t\t\t\t\t\tWOL0fr7SETJq5y2bCz8SLyoEXqBNe32be2S1prWB5Ioq3gxA9vF1e2WRq/j6AL0U\n\t\t\t\t\t\tq0s8dAFizK4WjN6nVQIDAQABo3cwdTBUBgNVHREETTBLghhkbGliLWppc2NpZHAu\n\t\t\t\t\t\tZWRpbmEuYWMudWuGL2h0dHBzOi8vZGxpYi1qaXNjaWRwLmVkaW5hLmFjLnVrL2lk\n\t\t\t\t\t\tcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRFE/N5nUQ7MQ/bdOJ1S5cFrY39wTANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAIzqOynQb9fyfwh4A+r94vl+OvVxg1FPtcZtTYx+6S3L1\n\t\t\t\t\t\tlLZV6V3urshRREuwOwVvF7a6vEk/G8cw8UCLUIuvbSa/kSFZokRhfkSaoBeeO8s3\n\t\t\t\t\t\t75RIq10OY7S/GFtLI9yMb9Okm7O/CxVi4+0HWWk/59FDkKbnSgdqJ7vDZTMcErWo\n\t\t\t\t\t\tYQuoeO3mFnbXMgpryJF95isXdiKSJMor9MhrnPkRaJ1KY8iX1PpYNCuvJKM/TrRM\n\t\t\t\t\t\tlES1uOmAEuYzRJ7ih5DMjY9bdIiPHr/P6ACfsfx5GmjO1NMeLgtIHWG0lKwg9KkP\n\t\t\t\t\t\t/qwJiPguX3f69bdizxAelZA/3dsl2Tmp9LLuliVkeg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "jisc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "collections.jisc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "jiscadvance.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edina.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://dlib-jiscidp.edina.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-jiscidp.edina.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://dlib-jiscidp.edina.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dlib-jiscidp.edina.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dlib-jiscidp.edina.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dlib-jiscidp.edina.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://dlib-jiscidp.edina.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-jiscidp.edina.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "jisc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "collections.jisc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "jiscadvance.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edina.ac.uk"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "JISC IdP (maintained by EDINA)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://dlib-jiscidp.edina.ac.uk/img/jisc.gif",
                    "height": "39",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "52"
                  },
                  {
                    "text": "https://dlib-jiscidp.edina.ac.uk/img/jiscicon.gif",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "JISC Executive New"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSzCCAjOgAwIBAgIUZooYXtDuohUPtXHr8p6BHj6IAsEwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwIzEhMB8GA1UEAxMYZGxpYi1qaXNjaWRwLmVkaW5hLmFjLnVrMB4XDTEwMDIy\n\t\t\t\t\t\tNjEwMDM1OVoXDTMwMDIyNjEwMDM1OVowIzEhMB8GA1UEAxMYZGxpYi1qaXNjaWRw\n\t\t\t\t\t\tLmVkaW5hLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA479P\n\t\t\t\t\t\tsZNAGnDd+wlw7o+isg+M++16qHhHNzFPKQBhdA+ojQ0nUjQZZT5SgAVt6WeVE4P3\n\t\t\t\t\t\tuwG/fWt3cdQ0xYz4pLneqyzve9uuLd0q4J/oqSGKsb9rfIw+Uw7I6K40WySukfpJ\n\t\t\t\t\t\t7IPREX6z+ymubn7FQOsK9zQ8y6P3Gl67bnnS4CIkot2BKdsX882OoEsDcZGnmXaN\n\t\t\t\t\t\t12L70pN5vQN3PJzNvc8/sz6u9DgDL8OlXY2fn6ASJ2y2etuHCLkAUSsB14pntgyA\n\t\t\t\t\t\tWOL0fr7SETJq5y2bCz8SLyoEXqBNe32be2S1prWB5Ioq3gxA9vF1e2WRq/j6AL0U\n\t\t\t\t\t\tq0s8dAFizK4WjN6nVQIDAQABo3cwdTBUBgNVHREETTBLghhkbGliLWppc2NpZHAu\n\t\t\t\t\t\tZWRpbmEuYWMudWuGL2h0dHBzOi8vZGxpYi1qaXNjaWRwLmVkaW5hLmFjLnVrL2lk\n\t\t\t\t\t\tcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRFE/N5nUQ7MQ/bdOJ1S5cFrY39wTANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAIzqOynQb9fyfwh4A+r94vl+OvVxg1FPtcZtTYx+6S3L1\n\t\t\t\t\t\tlLZV6V3urshRREuwOwVvF7a6vEk/G8cw8UCLUIuvbSa/kSFZokRhfkSaoBeeO8s3\n\t\t\t\t\t\t75RIq10OY7S/GFtLI9yMb9Okm7O/CxVi4+0HWWk/59FDkKbnSgdqJ7vDZTMcErWo\n\t\t\t\t\t\tYQuoeO3mFnbXMgpryJF95isXdiKSJMor9MhrnPkRaJ1KY8iX1PpYNCuvJKM/TrRM\n\t\t\t\t\t\tlES1uOmAEuYzRJ7ih5DMjY9bdIiPHr/P6ACfsfx5GmjO1NMeLgtIHWG0lKwg9KkP\n\t\t\t\t\t\t/qwJiPguX3f69bdizxAelZA/3dsl2Tmp9LLuliVkeg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "JISC Executive New"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://edina.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibidptest.york.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@york.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "User Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@york.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibidptest.york.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-05-07T16:13:09Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID/DCCAuSgAwIBAgIJAOgs+vZkeVN+MA0GCSqGSIb3DQEBBQUAMH8xCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMQ0wCwYDVQQIEwRZb3JrMQ0wCwYDVQQHEwRZb3JrMRswGQYDVQQKExJV\n\t\t\t\t\t\tbml2ZXJzaXR5IG9mIFlvcmsxFDASBgNVBAsTC0lUIFNlcnZpY2VzMR8wHQYDVQQD\n\t\t\t\t\t\tExZzaGliaWRwdGVzdC55b3JrLmFjLnVrMB4XDTEzMDUwNzEzMTIwOFoXDTIzMDUw\n\t\t\t\t\t\tNTEzMTIwOFowfzELMAkGA1UEBhMCR0IxDTALBgNVBAgTBFlvcmsxDTALBgNVBAcT\n\t\t\t\t\t\tBFlvcmsxGzAZBgNVBAoTElVuaXZlcnNpdHkgb2YgWW9yazEUMBIGA1UECxMLSVQg\n\t\t\t\t\t\tU2VydmljZXMxHzAdBgNVBAMTFnNoaWJpZHB0ZXN0LnlvcmsuYWMudWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDMUmL9nDPjCZvZ8+dOTqAqJ7nskqlp\n\t\t\t\t\t\tYXb94lrlj299DJ6vQaUm4/dR8S3lW1o4mImOJoRW1KWq57vnhKZc7XX8KjxLPRlB\n\t\t\t\t\t\tLJ5RMSFnqkOZKMNxvESu03eFljawaedz6I9hgDV75EB8AQOXq5guFYx7gmFEmV01\n\t\t\t\t\t\t68qtDZzfahsgTQaMmyvXDFtQjPFtyPFM7gXAZ7hN7IqG4/nfNXoGuL8ACGHsr7c9\n\t\t\t\t\t\tB1loWgc7SHzM7Dg8Wx8I+cDvieJi2O6m7k39IX2SXcx4ddwNpsD07v0GmvwUckia\n\t\t\t\t\t\toqiV/ZwqCNIn5mNW9DIKVy7Tf845BlaQEQPeGwbYnG0tNi0VbxxEaXm/AgMBAAGj\n\t\t\t\t\t\tezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVk\n\t\t\t\t\t\tIENlcnRpZmljYXRlMB0GA1UdDgQWBBRxs5ICZ+pK/8qFe1SVvLDCXUUI5TAfBgNV\n\t\t\t\t\t\tHSMEGDAWgBRxs5ICZ+pK/8qFe1SVvLDCXUUI5TANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tPVQMh/w0BlmmO1IBojykKwkxfs5Q7dbUSbumoFPFfb/RzZ+qTNW7EKDtU84GULGR\n\t\t\t\t\t\tHiFvbC7CxnXSzRtwt9v+RMyUcw3K9Rsm66zWWqebfm/apNvRgBLpB6z9AK2wQQiJ\n\t\t\t\t\t\tXMxmlAoM41ZeENbLYI0MoUKTFPg9FnAsyDZe5MEk831VbuY7engJkezFtKQ1TuW3\n\t\t\t\t\t\t/6bXFnodg3tFTgEcl9ZNZVahH/KRDlxlOR9umHIRKgd7BX/mZsAewsyt4BGs58yL\n\t\t\t\t\t\tmjybiHzAx77eG8wAb0J52d2t64ppwtOjauky+ppRFmP9Nu+J4WVwlnJsqQZTcQYt\n\t\t\t\t\t\tRKXBwZEOA6Bf4YjcgUtkWQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "york.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidptest.york.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidptest.york.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidptest.york.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidptest.york.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibidptest.york.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidptest.york.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidptest.york.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidptest.york.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "york.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID/DCCAuSgAwIBAgIJAOgs+vZkeVN+MA0GCSqGSIb3DQEBBQUAMH8xCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMQ0wCwYDVQQIEwRZb3JrMQ0wCwYDVQQHEwRZb3JrMRswGQYDVQQKExJV\n\t\t\t\t\t\tbml2ZXJzaXR5IG9mIFlvcmsxFDASBgNVBAsTC0lUIFNlcnZpY2VzMR8wHQYDVQQD\n\t\t\t\t\t\tExZzaGliaWRwdGVzdC55b3JrLmFjLnVrMB4XDTEzMDUwNzEzMTIwOFoXDTIzMDUw\n\t\t\t\t\t\tNTEzMTIwOFowfzELMAkGA1UEBhMCR0IxDTALBgNVBAgTBFlvcmsxDTALBgNVBAcT\n\t\t\t\t\t\tBFlvcmsxGzAZBgNVBAoTElVuaXZlcnNpdHkgb2YgWW9yazEUMBIGA1UECxMLSVQg\n\t\t\t\t\t\tU2VydmljZXMxHzAdBgNVBAMTFnNoaWJpZHB0ZXN0LnlvcmsuYWMudWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDMUmL9nDPjCZvZ8+dOTqAqJ7nskqlp\n\t\t\t\t\t\tYXb94lrlj299DJ6vQaUm4/dR8S3lW1o4mImOJoRW1KWq57vnhKZc7XX8KjxLPRlB\n\t\t\t\t\t\tLJ5RMSFnqkOZKMNxvESu03eFljawaedz6I9hgDV75EB8AQOXq5guFYx7gmFEmV01\n\t\t\t\t\t\t68qtDZzfahsgTQaMmyvXDFtQjPFtyPFM7gXAZ7hN7IqG4/nfNXoGuL8ACGHsr7c9\n\t\t\t\t\t\tB1loWgc7SHzM7Dg8Wx8I+cDvieJi2O6m7k39IX2SXcx4ddwNpsD07v0GmvwUckia\n\t\t\t\t\t\toqiV/ZwqCNIn5mNW9DIKVy7Tf845BlaQEQPeGwbYnG0tNi0VbxxEaXm/AgMBAAGj\n\t\t\t\t\t\tezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVk\n\t\t\t\t\t\tIENlcnRpZmljYXRlMB0GA1UdDgQWBBRxs5ICZ+pK/8qFe1SVvLDCXUUI5TAfBgNV\n\t\t\t\t\t\tHSMEGDAWgBRxs5ICZ+pK/8qFe1SVvLDCXUUI5TANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tPVQMh/w0BlmmO1IBojykKwkxfs5Q7dbUSbumoFPFfb/RzZ+qTNW7EKDtU84GULGR\n\t\t\t\t\t\tHiFvbC7CxnXSzRtwt9v+RMyUcw3K9Rsm66zWWqebfm/apNvRgBLpB6z9AK2wQQiJ\n\t\t\t\t\t\tXMxmlAoM41ZeENbLYI0MoUKTFPg9FnAsyDZe5MEk831VbuY7engJkezFtKQ1TuW3\n\t\t\t\t\t\t/6bXFnodg3tFTgEcl9ZNZVahH/KRDlxlOR9umHIRKgd7BX/mZsAewsyt4BGs58yL\n\t\t\t\t\t\tmjybiHzAx77eG8wAb0J52d2t64ppwtOjauky+ppRFmP9Nu+J4WVwlnJsqQZTcQYt\n\t\t\t\t\t\tRKXBwZEOA6Bf4YjcgUtkWQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of York test service"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.york.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of York"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://appdb-dev.marie.hellasgrid.gr/edugain-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chatziangelou"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mhaggel@iasa.gr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marios"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chatziangelou"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "appdb-support@iasa.gr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marios"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://appdb-dev.marie.hellasgrid.gr/edugain-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Accelerating Systems and Applications - Greek Research and Technology Network"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u0399\u03bd\u03c3\u03c4\u03b9\u03c4\u03bf\u03cd\u03c4\u03bf \u0395\u03c0\u03b9\u03c4\u03b1\u03c7\u03c5\u03bd\u03c4\u03b9\u03ba\u03ce\u03bd \u03a3\u03c5\u03c3\u03c4\u03b7\u03bc\u03ac\u03c4\u03c9\u03bd \u03ba\u03b1\u03b9 \u0395\u03c6\u03b1\u03c1\u03bc\u03bf\u03b3\u03ce\u03bd - \u0395\u03b8\u03bd\u03b9\u03ba\u03cc \u0394\u03af\u03ba\u03c4\u03c5\u03bf \u0388\u03c1\u03b5\u03c5\u03bd\u03b1\u03c2 \u03ba\u03b1\u03b9 \u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03af\u03b1\u03c2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iasa.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iasa.gr/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.grnet.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.grnet.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IASA - GRNET"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u0399\u0395\u03a3\u0395 - \u0395\u0394\u0395\u03a4"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://appdb-dev.marie.hellasgrid.gr/auth/module.php/saml/sp/saml2-logout.php/edugain-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://appdb-dev.marie.hellasgrid.gr/auth/module.php/saml/sp/saml2-logout.php/edugain-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://wiki.appdb.egi.eu/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EGI Applications Database (DEV)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "EGI Software & Cloud Marketplace (Development Instance)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://appdb-dev.marie.hellasgrid.gr/images/appdblogo.png",
                    "height": "128",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "120"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://wiki.appdb.egi.eu/main:about:terms"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://wiki.appdb.egi.eu/main:about:terms"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://appdb-dev.marie.hellasgrid.gr/auth/module.php/saml/sp/saml2-acs.php/edugain-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://appdb-dev.marie.hellasgrid.gr/auth/module.php/saml/sp/saml1-acs.php/edugain-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://appdb-dev.marie.hellasgrid.gr/auth/module.php/saml/sp/saml2-acs.php/edugain-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://appdb-dev.marie.hellasgrid.gr/auth/module.php/saml/sp/saml1-acs.php/edugain-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "EGI Applications Database (DEV)"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "EGI Software & Cloud Marketplace (Development Instance)"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "http://sts.zadkine.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://sts.zadkine.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-04-29T12:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/16af967ce379fb1cc54bbe2e8ad5d565",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Zadkine (nieuw)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Zadkine (nieuw)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/zadkine.gif",
                    "height": "86",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "86"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Zadkine"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Zadkine"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.zadkine.nl"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.zadkine.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Zadkine"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Zadkine"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp-vaas-stage.asknet.de/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:customerservice@asknet.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Customer Service"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-adm@asknet.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth-adm"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp-vaas-stage.asknet.de/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-03-09T14:39:35Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Asknet Verification Services for Student Discounts (TEST)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.asknet.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "asknet AG"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Asknet Verification Services for Student Discounts (TEST)"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Asknet Verification Services for Student Discounts (TEST)"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:sn",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:givenName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:mail",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "1",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Asknet Verification Services for Student Discounts (TEST)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://verify-service.com/fileadmin/templates/images/logo_70.png",
                    "height": "70",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "134"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Asknet Verification Services for Student Discounts (TEST)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/DFN-DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/DFN-DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/SWITCH-DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/SWITCH-DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/UKfederation-DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/UKfederation-DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIJAOLeXLHoXOOiMA0GCSqGSIb3DQEBCwUAMCIxIDAeBgNV\n\t\t\t\t\t\tBAMMF3NwLXZhYXMtc3RhZ2UuYXNrbmV0LmRlMB4XDTE1MDcyMjEzMDczOVoXDTE2\n\t\t\t\t\t\tMDcyMTEzMDczOVowIjEgMB4GA1UEAwwXc3AtdmFhcy1zdGFnZS5hc2tuZXQuZGUw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC5gqGWJhwGXHgsbs4IdDlr\n\t\t\t\t\t\tkxi9GMG+1he06TDlL/1p1944Eh4o4Wt2wWeF7fF7FcKFHcgkA6eRYcohxmEQ1AMW\n\t\t\t\t\t\tGpYFg1mNoUVAPQ5U8T+jkcR7DCIawhYPOg+amHiRW6Yp12bzx9XXED7eunGCy9Cx\n\t\t\t\t\t\trEaOFSPphFwByglnuygflQaYbzIZodLpqgHg7nzQ/SxqLXUqFu0hEeH6kQlUN7H5\n\t\t\t\t\t\t+uIaXENAWPKrtVpX03nD6RDz1Lt+qIUwJVHbmZPaduMIKNBDWWIIco866UvUAPB/\n\t\t\t\t\t\trxw8MV+CQ11TzcggtiyBw+DZ2TJdd8jbu9G8D1vqZi4UZTCbi6ue1ONonljbdAzF\n\t\t\t\t\t\tAgMBAAGjcTBvMB0GA1UdDgQWBBTfYwuPt4s+LqFQmmgJZv1s9S7iXTBOBgNVHREE\n\t\t\t\t\t\tRzBFghdzcC12YWFzLXN0YWdlLmFza25ldC5kZYYqaHR0cHM6Ly9zcC12YWFzLXN0\n\t\t\t\t\t\tYWdlLmFza25ldC5kZS9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQB7FWT4\n\t\t\t\t\t\tSgwaAefiqvIq0Roj3V37//xxxnkk7/sT3osaCHN+IVyS675/aycle7LwtDPPJF7y\n\t\t\t\t\t\t7LkwKtBdOj9d58EENS7sYARnyHiPX7m00Noditu4aTv6bnY84e9xqjaJFN8wPQeM\n\t\t\t\t\t\tUOV6D8DAJMaZy7/gdgynxG7i154XpsdVKjot4FCqvB14Lzo6bGDp4YOcFoYI6Lfi\n\t\t\t\t\t\tEAkReSU9CsQe3mDyNpHnxazMiUuf6iZuK05bwgo0ySKwI7v8RtSHrIvu4WtDSnIE\n\t\t\t\t\t\t0QioQKnSaAN78iwuNCB+geZyn+pUAVmtEIwSW6iDZ5PfA1b3Gs+qa6OR77czMUYu\n\t\t\t\t\t\tdfRSQz6T7P1oJNSr"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp-vaas-stage.asknet.de/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-p04.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-p04.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p04.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p04.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p04.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p04.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p04.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-p04.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-p04.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;p04"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;p04"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-p04.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-p04.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQTCCAimgAwIBAgIJAMpb1u8wOCflMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2xhZG9rMy1wMDQubGFkb2sudW11LnNlMB4XDTE0MTAwNzE0NDU0NloXDTI0\nMTAwNDE0NDU0NlowIjEgMB4GA1UEAxMXbGFkb2szLXAwNC5sYWRvay51bXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDRRsQ6Ran6umULbdel3U3s\n2bSvFaJoJ02PCy97TVXJf4ZFGHEIOz0zz16VBnDZ4KYpJ6UAXhi71gT05lSarMEe\nssptpzEIWu5iJqY6dHVOyVydyzVZNCSJRjPX3SUsTSSQ2GMePK2QvHXlj9BDood4\nU8bt6Bp0D5yzCXg4d3MWj2J4asrKIhtcFY/tLRXwNJRcCfH7p7yX/V+jl7Q3s4yh\nrfiS3F92ftIw8TtvCJrR3r5kgkzGHBVoqQssnvEe8fZc9YrDp+2DhlmJasinopm8\nSN8pIasKMoT2L5DtLbOT63gYOHYDj4JJvFsENcBrTGE9YEgdnbgRHi1flvSSZgud\nAgMBAAGjejB4MFcGA1UdEQRQME6CF2xhZG9rMy1wMDQubGFkb2sudW11LnNlhjNo\ndHRwczovL2xhZG9rMy1wMDQubGFkb2sudW11LnNlL3N0dWRlbnQtZnJvbnRlbmQt\nc3AwHQYDVR0OBBYEFFTIfNmLHlmAW1LdcLDKcQuP4MuDMA0GCSqGSIb3DQEBBQUA\nA4IBAQAWNMu7cdHqcV3Bqww8Hq/1rJq+c7DJEs1WArpq494aji9EsGAp6sj3V3Yg\nMBIqt3ZPsFXJvxIEJ1Bz+uvlmct3izMB9B2wk+hn8FOB9rL62be2eN+0IZ0UODRl\n1xLwwG1jnbI1/JKt/WgyNSxzZZIoeHke6UN+bDF47y6Ci5uC5oxUpyVBPFgO7LWH\nwVB95fM+M156ebpT5oUjiMvr5sprTRouGpNNMdvBhhsMbJ0omBpvD7HdQkAjX8p4\nxtga4e2lfE1bIxn0FHcarq8TGMHyqy0+HiITVNKh/NDO9uG50DHxiu53D6N/9Pgo\nAP3USOeyGONOlpoZbgadSKbbuAKV"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-p04.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p04.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p04.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p04.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p04.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p04.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p04.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-p04.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-p04.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-p04.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.abintegro.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@abintegro.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sunay"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hilmi@abintegro.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hilmi"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.abintegro.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-08-15T15:23:38Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Abintegro Career Centre"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.abintegro.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Abintegro Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.abintegro.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.abintegro.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.abintegro.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.abintegro.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.abintegro.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.abintegro.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "E-learning and employability solutions for careers services and training departments."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.abintegro.com/Images/AbintegroLogo-220-80.png",
                    "height": "80",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "220"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Abintegro Career Centre"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3zCCAcegAwIBAgIJAJ2y3/Ipx0rcMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\n\t\t\t\t\t\tBAMTCGFiaW50YWEyMB4XDTEzMDgxNDIzMTI1NFoXDTIzMDgxMjIzMTI1NFowEzER\n\t\t\t\t\t\tMA8GA1UEAxMIYWJpbnRhYTIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQC9NZvmrSYjcTzr0HKkQTo7sftSQsJ8C24K0H7hv4xa2k3xTRsJ3x1cR3VSohpV\n\t\t\t\t\t\tTh9j6KqpEItOh3kK5nr5yjyTsekWF/vrdtvZzzI95eAtcvFP5dXNdMIUkcbbOnys\n\t\t\t\t\t\tbYKFVzdtKw9ZwejZvkzbzQ7n6kUTyhLlZIUma3rQNhYWmmyVFVSRqbXX5XkgqjKG\n\t\t\t\t\t\t5MIy42nGIfOVF+RdnkA5u+t2zlUdJuyhLJfyrfovnf/Ttdw1lpJ0zzqEvFPHa5Dx\n\t\t\t\t\t\t1W9B2tama+MURTJfO9ZRgckx4qGpL+vuZKDs1gynzzwhqff476UNlYeTDTZzAB8u\n\t\t\t\t\t\tuLObbBZszG/3rM+Kdjfo0sKPAgMBAAGjNjA0MBMGA1UdEQQMMAqCCGFiaW50YWEy\n\t\t\t\t\t\tMB0GA1UdDgQWBBRUIJFi6Zdg8nwr4/rA63aWklFizzANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAqfryYrk6Ha9xkgPbauuJFXGLlcSPnUUJK8wLhTFX3asacroLYVYxMF6bty2I\n\t\t\t\t\t\t8Hm/WerHTYLvdyvR8z+cwar74PqPHsql1kjGikZwWNTeQbt8L5r+MY6R+qVTyIXL\n\t\t\t\t\t\t0QygcVpFA8/07uIV/MO6ldsLu/IXMwFt7VWwlueq744pi9ACDjaLwhZ9QcegFOKa\n\t\t\t\t\t\tk0bU3yG5Uj27MYAxRjBTMH7YFV0RcrBdczeWw4ivNourUbYnhHOpjKBmyLt3haSz\n\t\t\t\t\t\t1QLpZpLaDMTcC5r1tLHfZcEIDo1Zop9cMEJr5+vbYtMi0GxLGZdHVQ8supUNDNgp\n\t\t\t\t\t\t3/OQ0NRj9PRqf24c2oftTWePWQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.abintegro.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.abintegro.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.abintegro.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.abintegro.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.abintegro.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.abintegro.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://safe.epcc.ed.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@epcc.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Booth"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:s.booth@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stephen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://safe.epcc.ed.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-06-17T14:03:08Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EPCC SAFE"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.epcc.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://safe.epcc.ed.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://safe.epcc.ed.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://safe.epcc.ed.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://safe.epcc.ed.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://safe.epcc.ed.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://safe.epcc.ed.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://safe.epcc.ed.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SAFE HPC service administration hosted at EPCC"
                  }
                ],
                "logo": [
                  {
                    "text": "https://safe.epcc.ed.ac.uk/images/safelogo.gif",
                    "height": "65",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "162"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EPCC SAFE"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAM6PYwal8Sr+MA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\n\t\t\t\t\t\tBAMTEnNhZmUuZXBjYy5lZC5hYy51azAeFw0xNDA2MTMxMjI1MjNaFw0yNDA2MTAx\n\t\t\t\t\t\tMjI1MjNaMB0xGzAZBgNVBAMTEnNhZmUuZXBjYy5lZC5hYy51azCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBALyfMo6ccoUJQkWr8s+D+5Pumxqu2bpFc4V7\n\t\t\t\t\t\tRbGGcmMLq5Nigv34AzDcdHSBejB0CbdtLd8rm7trjUx3kF50aZkU2cSYoPjl6qFq\n\t\t\t\t\t\t+Y6FdfdGpSA7s2kRsqEyDB/BTXy8ePUgtFTmzgscI0zYtbeNNjqfoKEprtWys3+W\n\t\t\t\t\t\tDMzHcWoc5ayCQiWzQMKxkuOaBynpaZeePBMHncmtqBOECU6xqVlhbN0C8SSqBHVf\n\t\t\t\t\t\t/AZyaT9Re6F65v0Sstph+Hm1jBTj5zmCoszWiGpTIE392eFuU7UE6oKO2NbX1HGG\n\t\t\t\t\t\t97+Wd1OyIxxSm6MgN1fni0n5gSEJdvfDUrllUvE1RI86kA0GXkUCAwEAAaNAMD4w\n\t\t\t\t\t\tHQYDVR0RBBYwFIISc2FmZS5lcGNjLmVkLmFjLnVrMB0GA1UdDgQWBBQPSH7aENek\n\t\t\t\t\t\tefLSP07GJnhd4Rz83jANBgkqhkiG9w0BAQUFAAOCAQEAWVuBgQop6+C6N61h/mbb\n\t\t\t\t\t\tTs2aW47rBqWb3e1SywL4QNlI6+ktCmycQmuuYxWi8kayicIk01LT8XMABRNRM/Tr\n\t\t\t\t\t\tCmHYn2TXOnA7eWB2Cqb6dSQcKc/DuY43DWnrPNiqdWyyWkbHldf91sLBMERwjGam\n\t\t\t\t\t\ttczJCAEP3dcXxAZQ/jY9wmFmq9hB5wK9N0VJyoR1Fk823uTGxynkdrp36JQ9ye2U\n\t\t\t\t\t\tTbDGOMsMVIOoZaFZSBuZXWOuZZPBR9cZ3w9R2+H7PuQcpA0bbn5Zg5q8jO0EsVrY\n\t\t\t\t\t\txJJwl96Mjvc83n1JFmgn/IFCrv6Rohp9xKa3AOFpMI/SEbh5kEqKhAPfpFcNVp4c\n\t\t\t\t\t\tPg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://safe.epcc.ed.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://safe.epcc.ed.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://safe.epcc.ed.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://safe.epcc.ed.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://safe.epcc.ed.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://safe.epcc.ed.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://medlem.studentkareniboras.se/saml/simplesamlwww/module.php/saml/sp/metadata.php/AgeraMedlem",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "S\u00f6lve"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "johan@montania.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Johan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://medlem.studentkareniboras.se/saml/simplesamlwww/module.php/saml/sp/metadata.php/AgeraMedlem",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://medlem.studentkareniboras.se/saml/simplesamlwww/module.php/saml/sp/saml2-logout.php/AgeraMedlem",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Medlemsportalen f\u00f6r Studentk\u00e5ren i Bor\u00e5s"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Member Portal for Bor\u00e5s Student Union"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Medlemsportalen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Member Portal"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://medlem.studentkareniboras.se/saml/simplesamlwww/module.php/saml/sp/saml2-acs.php/AgeraMedlem",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://medlem.studentkareniboras.se/saml/simplesamlwww/module.php/saml/sp/saml1-acs.php/AgeraMedlem",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://medlem.studentkareniboras.se/saml/simplesamlwww/module.php/saml/sp/saml2-acs.php/AgeraMedlem",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://medlem.studentkareniboras.se/saml/simplesamlwww/module.php/saml/sp/saml1-acs.php/AgeraMedlem/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:profiles:holder-of-key:SSO:browser",
              "location": "https://medlem.studentkareniboras.se/saml/simplesamlwww/module.php/saml/sp/saml2-acs.php/AgeraMedlem",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.cambria.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Brandish"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mark.brandish@cambria.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Brandish"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mark.brandish@cambria.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cambria.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-03-26T16:07:40Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://oa.idp.cambria.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://oa.idp.cambria.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cambria.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIISzyK9gZorNowDQYJKoZIhvcNAQEFBQAwNzEWMBQGA1UE\n\t\t\t\t\t\tCgwNQ29sZWcgQ2FtYnJpYTEdMBsGA1UEAwwUb2EuaWRwLmNhbWJyaWEuYWMudWsw\n\t\t\t\t\t\tHhcNMTYwMzA3MTQzOTM2WhcNMjYwMzA3MTQzOTM2WjA3MRYwFAYDVQQKDA1Db2xl\n\t\t\t\t\t\tZyBDYW1icmlhMR0wGwYDVQQDDBRvYS5pZHAuY2FtYnJpYS5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ7P2M9Vcopthk3oh2pIdPigljmuQcft\n\t\t\t\t\t\t5mIyQS24tblGhMu9E22rNPusoAmj8KbJgtqjJuEnzemc8qogtZHoRJTHs+3uI7zU\n\t\t\t\t\t\t6bXisC7FwCdJ8TlvTttT2kVcS6fA/Bcnhr0o9rBntpION+giElLEEb5vGvohXlD+\n\t\t\t\t\t\t2oLt6Lh+jLSXWQZsqnxEnxQrlZxD7bLzf0IDZCCNx0ZHa+CBczXAtAUyn3sXqhgN\n\t\t\t\t\t\ton1VrsREazWE2CTzDiNXPyKW2fsTKp1at0pQngajFcIjTvci3C1bTGD2f+bcXLSu\n\t\t\t\t\t\tdTdwsQ+UpsIIWdl4F5BLvdVPaMSU1Tb0OjWsds1kXZOD/oU0DatsbX8CAwEAAaNQ\n\t\t\t\t\t\tME4wHQYDVR0OBBYEFORbFc1mosQDoF1bAVW1uCJGlZDqMB8GA1UdIwQYMBaAFORb\n\t\t\t\t\t\tFc1mosQDoF1bAVW1uCJGlZDqMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAAzweLub0NeuD2pPzjYreA46SsXHRG5eocon9ESrzQzA2yihFEU6LyFzmi0W\n\t\t\t\t\t\tmMZslKjNGoYcYi/EkPMXCv5IxIZrWGqSEAz//5DGZ72nv7nC+iOhIiAWQJRUSg3R\n\t\t\t\t\t\tPaKoJe7kM4Kn2gOsQHAJh5knMSMkqNNovojQJRSDq8uhrmjXluL3FA9/dpZNX6J1\n\t\t\t\t\t\tD/GnngxdSMqk6TfZuBaMNV5W/XkOzStxu3uy+WXAHxCQU7juZWSWdQeA3l57lL0b\n\t\t\t\t\t\tmq6VF0PEksJJGubKZwWUAXgoPGrPu9fhSr9uj3qjXn9uD5NnyRl9QHyWc99pYTIr\n\t\t\t\t\t\t9nYZ5vIuX2yxGi/sM8qmpiVCL9s="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIISzyK9gZorNowDQYJKoZIhvcNAQEFBQAwNzEWMBQGA1UE\n\t\t\t\t\t\tCgwNQ29sZWcgQ2FtYnJpYTEdMBsGA1UEAwwUb2EuaWRwLmNhbWJyaWEuYWMudWsw\n\t\t\t\t\t\tHhcNMTYwMzA3MTQzOTM2WhcNMjYwMzA3MTQzOTM2WjA3MRYwFAYDVQQKDA1Db2xl\n\t\t\t\t\t\tZyBDYW1icmlhMR0wGwYDVQQDDBRvYS5pZHAuY2FtYnJpYS5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ7P2M9Vcopthk3oh2pIdPigljmuQcft\n\t\t\t\t\t\t5mIyQS24tblGhMu9E22rNPusoAmj8KbJgtqjJuEnzemc8qogtZHoRJTHs+3uI7zU\n\t\t\t\t\t\t6bXisC7FwCdJ8TlvTttT2kVcS6fA/Bcnhr0o9rBntpION+giElLEEb5vGvohXlD+\n\t\t\t\t\t\t2oLt6Lh+jLSXWQZsqnxEnxQrlZxD7bLzf0IDZCCNx0ZHa+CBczXAtAUyn3sXqhgN\n\t\t\t\t\t\ton1VrsREazWE2CTzDiNXPyKW2fsTKp1at0pQngajFcIjTvci3C1bTGD2f+bcXLSu\n\t\t\t\t\t\tdTdwsQ+UpsIIWdl4F5BLvdVPaMSU1Tb0OjWsds1kXZOD/oU0DatsbX8CAwEAAaNQ\n\t\t\t\t\t\tME4wHQYDVR0OBBYEFORbFc1mosQDoF1bAVW1uCJGlZDqMB8GA1UdIwQYMBaAFORb\n\t\t\t\t\t\tFc1mosQDoF1bAVW1uCJGlZDqMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAAzweLub0NeuD2pPzjYreA46SsXHRG5eocon9ESrzQzA2yihFEU6LyFzmi0W\n\t\t\t\t\t\tmMZslKjNGoYcYi/EkPMXCv5IxIZrWGqSEAz//5DGZ72nv7nC+iOhIiAWQJRUSg3R\n\t\t\t\t\t\tPaKoJe7kM4Kn2gOsQHAJh5knMSMkqNNovojQJRSDq8uhrmjXluL3FA9/dpZNX6J1\n\t\t\t\t\t\tD/GnngxdSMqk6TfZuBaMNV5W/XkOzStxu3uy+WXAHxCQU7juZWSWdQeA3l57lL0b\n\t\t\t\t\t\tmq6VF0PEksJJGubKZwWUAXgoPGrPu9fhSr9uj3qjXn9uD5NnyRl9QHyWc99pYTIr\n\t\t\t\t\t\t9nYZ5vIuX2yxGi/sM8qmpiVCL9s="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Coleg Cambria"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cambria.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Coleg Cambria"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://play.mah.se",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "saml_admin@kaltura.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://play.mah.se",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MAH (PROD)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://play.mah.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "MAH (PROD)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://play.mah.se/user/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is the Malm\u00f6 University streaming service"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Detta \u00e4r Malm\u00f6 h\u00f6gskolas play tj\u00e4nst"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Malm\u00f6 University Play service"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Malm\u00f6 h\u00f6gskolas Play tj\u00e4nst"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.mah.se/user/authenticate",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shu-shib.hosted.exlibrisgroup.com/shib",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shu-shib.hosted.exlibrisgroup.com/shib",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-06-08T13:43:20Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "This is a Shibboleth SP for Sheffield Hallam University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://exlibrisgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ex Libris (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is an Ex Libris Primo Hosted SP on behalf of Sheffield Hallam University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sheffield Hallam University - Primo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAMbLNjH7IdN7MA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB2FpbzAwMjgwHhcNMTUwNDAyMTkyMjE5WhcNMjUwMzMwMTkyMjE5WjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdhaW8wMDI4MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tlmjeE3y9jL60+iV+qcDYc6/nOs5YIyeLpkSYmQmIyhxDdHWNowH71qEO5esUrvAU\n\t\t\t\t\t\tGt2Fz1fp4ZNc5IRDXhqEG5w/5RHVRdtVTWYQBrZKKtgVrwwC76mAl7sHCvexFep6\n\t\t\t\t\t\tFvWE7jhIi/ybRDKO9Ajqow4oPFk5YPOaRj7qy2Rk92b6SSz8YMVU3U8Mn9WdSKNk\n\t\t\t\t\t\tEyhjwqM9TnTPLGttjZGOmXc5o2lbvt9NjJU3BeG8Sr1dx6JHEBXfuXPUns15Ry27\n\t\t\t\t\t\tbAtbWslGKxpgt9ubJE6FICGslRPxpXJTpMYW7D+jFHqPSimSb4GUzhDJULSMyZpe\n\t\t\t\t\t\tmooKno/Lsu3lFQ1el9IevwIDAQABozUwMzASBgNVHREECzAJggdhaW8wMDI4MB0G\n\t\t\t\t\t\tA1UdDgQWBBThYVZfmqu4Vlq+kYervlubORuF5TANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tQjAAP63C1Letp+5hXqZCGCyV47Xox+HhKfsM4jq2IC8/2CwvuoDyvnWL6AHtDRxw\n\t\t\t\t\t\t1hlM5MP13AIrRzhN0oLsJVnfshgXRs0WvpyzlARIZECnMqXDNq4amdLp/ydRgWOE\n\t\t\t\t\t\txXnlvEqdbbnZ0gJueeiWrO6TeCvIoiUpv9LqjnqYnPUbFMfD7M63B1y2f6FeCwMK\n\t\t\t\t\t\t3EcRGV15x15BRqn20jupvVsGr7FkRN49LV8qu6U+Ff3E88SOmqLAP9ELvCAZ2MM0\n\t\t\t\t\t\tfd+fRWW+0dWqB9jA2+UE1R4V+6NiJVESYmnc+pfeVOtt8kinJ3fXa3kjFgwN7gZt\n\t\t\t\t\t\t616nxaRmxDQmzhRhAYD2LA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shu-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cambro-utv1.umdc.umu.se/shibboleth",
    {
      "entity_id": "https://cambro-utv1.umdc.umu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cambro-utv1.umdc.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cambro-utv1.umdc.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cambro-utv1.umdc.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cambro-utv1.umdc.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://cambro-utv1.umdc.umu.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "cambro-utv1.umdc.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEtTCCA52gAwIBAgILAQAAAAABH9HgmtcwDQYJKoZIhvcNAQEFBQAwXzELMAkG\nA1UEBhMCQkUxEzARBgNVBAoTCkN5YmVydHJ1c3QxFzAVBgNVBAsTDkVkdWNhdGlv\nbmFsIENBMSIwIAYDVQQDExlDeWJlcnRydXN0IEVkdWNhdGlvbmFsIENBMB4XDTA5\nMDMwNDEzMjcxMVoXDTEyMDMwNDEzMjcxMVowWTELMAkGA1UEBhMCU0UxDTALBgNV\nBAcTBFVtZWExGTAXBgNVBAoTEFVtZWEgdW5pdmVyc2l0ZXQxIDAeBgNVBAMTF2Nh\nbWJyby11dHYxLnVtZGMudW11LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\nCgKCAQEA5TaLPTlLKk0TeGGRD4LP2f/PrRrFpKunsr++6ui9EsRGwRlla2lNVqsW\nAEpNFFUfQzOrrtMgbBZeCRdzWjaF5v+RDD5y7TGt+V2hqneIzCP0UlRCsYfDynVK\n3MMtIOziTGbX+W1yoSRO4U+t5kS0Ezyq3kly2sp0HRdpJOkRekaq0wOPO7b4I7M3\nw72Xa9cKsGEpqC4BVKhwLpPNvEg8Q2yQWHVEGBADRpxq8c+37w3UCpsW5lXZSTIX\ne5Bup0DzpEAofaYXYR7+xozWA5np/DttV0XES8OPySTKz4uJF12TdXtQDO71jriy\njb1p4PzwRDWKyeV01NuAKB+pOgUpwQIDAQABo4IBdjCCAXIwUAYDVR0gBEkwRzBF\nBgcqhkixPgEAMDowOAYIKwYBBQUHAgEWLGh0dHA6Ly93d3cuZ2xvYmFsc2lnbi5u\nZXQvcmVwb3NpdG9yeS9jcHMuY2ZtMA4GA1UdDwEB/wQEAwIFoDAfBgNVHSMEGDAW\ngBRlZaM91zsRowoHJTfJQkpbdndQ4TAdBgNVHQ4EFgQUWekEey2KnDs/ydaenF3j\nDgQDzxswOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC5nbG9iYWxzaWduLm5l\ndC9lZHVjYXRpb25hbC5jcmwwTwYIKwYBBQUHAQEEQzBBMD8GCCsGAQUFBzAChjNo\ndHRwOi8vc2VjdXJlLmdsb2JhbHNpZ24ubmV0L2NhY2VydC9lZHVjYXRpb25hbC5j\ncnQwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMCIGA1UdEQQbMBmCF2Nh\nbWJyby11dHYxLnVtZGMudW11LnNlMA0GCSqGSIb3DQEBBQUAA4IBAQB0Tg84TC+P\nedgi+MJHZw9giLhPuaw1G7YeNsPelp7BdaGG5mj6NtnObxJxpX/Ac1XFmOWrs/d8\ndIW9cdRoomW9d9fgm4asKmUwj6riLT3KcZoaxqnQrI5RqINs1SGKcRNc4OnK/4WE\nIIODbCqQMNc97u8i++Cxi1DU09qE4awAs7hEz5twv3CPaDSBy/TiQbNs8PuPIZP9\n9wef0YIBiLfnHJpjtlzM4Nm0Gmmj7Q3ikrtd0Y9xH4GLHA4M/aWDgOHT8uQcVw8A\n74ghwcgLAYhaGLgvvisof0SMPG8Fp3A3cQ735bUbCFl1+MQDSHRZOJAPB/5t+Jlu\ngZWpy/ZEPcE5"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=cambro-utv1.umdc.umu.se,O=Umea universitet,L=Umea,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "cambro-utv1.umdc.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEtTCCA52gAwIBAgILAQAAAAABH9HgmtcwDQYJKoZIhvcNAQEFBQAwXzELMAkG\nA1UEBhMCQkUxEzARBgNVBAoTCkN5YmVydHJ1c3QxFzAVBgNVBAsTDkVkdWNhdGlv\nbmFsIENBMSIwIAYDVQQDExlDeWJlcnRydXN0IEVkdWNhdGlvbmFsIENBMB4XDTA5\nMDMwNDEzMjcxMVoXDTEyMDMwNDEzMjcxMVowWTELMAkGA1UEBhMCU0UxDTALBgNV\nBAcTBFVtZWExGTAXBgNVBAoTEFVtZWEgdW5pdmVyc2l0ZXQxIDAeBgNVBAMTF2Nh\nbWJyby11dHYxLnVtZGMudW11LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\nCgKCAQEA5TaLPTlLKk0TeGGRD4LP2f/PrRrFpKunsr++6ui9EsRGwRlla2lNVqsW\nAEpNFFUfQzOrrtMgbBZeCRdzWjaF5v+RDD5y7TGt+V2hqneIzCP0UlRCsYfDynVK\n3MMtIOziTGbX+W1yoSRO4U+t5kS0Ezyq3kly2sp0HRdpJOkRekaq0wOPO7b4I7M3\nw72Xa9cKsGEpqC4BVKhwLpPNvEg8Q2yQWHVEGBADRpxq8c+37w3UCpsW5lXZSTIX\ne5Bup0DzpEAofaYXYR7+xozWA5np/DttV0XES8OPySTKz4uJF12TdXtQDO71jriy\njb1p4PzwRDWKyeV01NuAKB+pOgUpwQIDAQABo4IBdjCCAXIwUAYDVR0gBEkwRzBF\nBgcqhkixPgEAMDowOAYIKwYBBQUHAgEWLGh0dHA6Ly93d3cuZ2xvYmFsc2lnbi5u\nZXQvcmVwb3NpdG9yeS9jcHMuY2ZtMA4GA1UdDwEB/wQEAwIFoDAfBgNVHSMEGDAW\ngBRlZaM91zsRowoHJTfJQkpbdndQ4TAdBgNVHQ4EFgQUWekEey2KnDs/ydaenF3j\nDgQDzxswOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC5nbG9iYWxzaWduLm5l\ndC9lZHVjYXRpb25hbC5jcmwwTwYIKwYBBQUHAQEEQzBBMD8GCCsGAQUFBzAChjNo\ndHRwOi8vc2VjdXJlLmdsb2JhbHNpZ24ubmV0L2NhY2VydC9lZHVjYXRpb25hbC5j\ncnQwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMCIGA1UdEQQbMBmCF2Nh\nbWJyby11dHYxLnVtZGMudW11LnNlMA0GCSqGSIb3DQEBBQUAA4IBAQB0Tg84TC+P\nedgi+MJHZw9giLhPuaw1G7YeNsPelp7BdaGG5mj6NtnObxJxpX/Ac1XFmOWrs/d8\ndIW9cdRoomW9d9fgm4asKmUwj6riLT3KcZoaxqnQrI5RqINs1SGKcRNc4OnK/4WE\nIIODbCqQMNc97u8i++Cxi1DU09qE4awAs7hEz5twv3CPaDSBy/TiQbNs8PuPIZP9\n9wef0YIBiLfnHJpjtlzM4Nm0Gmmj7Q3ikrtd0Y9xH4GLHA4M/aWDgOHT8uQcVw8A\n74ghwcgLAYhaGLgvvisof0SMPG8Fp3A3cQ735bUbCFl1+MQDSHRZOJAPB/5t+Jlu\ngZWpy/ZEPcE5"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=cambro-utv1.umdc.umu.se,O=Umea universitet,L=Umea,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cambro-utv1.umdc.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cambro-utv1.umdc.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cambro-utv1.umdc.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cambro-utv1.umdc.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cambro-utv1.umdc.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cambro-utv1.umdc.umu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cambro-utv1.umdc.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://cambro-utv1.umdc.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://cambro-utv1.umdc.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://cambro-utv1.umdc.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.citybathcoll.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Elliott"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:naomi.elliott@bathcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Naomi"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Haskins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:haskinsj@bathcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Justin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.citybathcoll.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-07-04T18:17:54Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.citybathcoll.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.citybathcoll.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "citybathcoll.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUjCCAjqgAwIBAgIIfbSOFSC/ASkwDQYJKoZIhvcNAQEFBQAwQDEdMBsGA1UE\n\t\t\t\t\t\tCgwUQ2l0eSBvZiBCYXRoIENvbGxlZ2UxHzAdBgNVBAMMFmlkcC5jaXR5YmF0aGNv\n\t\t\t\t\t\tbGwuYWMudWswHhcNMTMwNDE4MTMyMTUzWhcNMjMwNDE4MTMyMTUzWjBAMR0wGwYD\n\t\t\t\t\t\tVQQKDBRDaXR5IG9mIEJhdGggQ29sbGVnZTEfMB0GA1UEAwwWaWRwLmNpdHliYXRo\n\t\t\t\t\t\tY29sbC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIpNwR6K\n\t\t\t\t\t\tqvXHyj9FgnJ49oM25jOaqYfwXfc4EIq/1wEmuulwRVz0YdizYN0nQZNyujfFi7Wn\n\t\t\t\t\t\tV+1r14vOg6Zke+VT6u4jlL9H+reg8gieN/ybVIMNqzfddY7a82N/ZABoEQ1Wckol\n\t\t\t\t\t\tGAjcYrxO2hW71AKIixUT0S0sw8zpCCTntvqIhw+SB7fDT1v5oN0snLPplTdfwEk2\n\t\t\t\t\t\tlLLEECZnf0IP/+5o76K/7KYO/+LrKS0eSrFQwQxz1IX6Vh413lMwa597gAXT2IKn\n\t\t\t\t\t\taYPAStni01WUFPuAs5eVWoXtAEx7sbhmPoxmhFGo4xVwhTVzJLo19QdagBb9jSRa\n\t\t\t\t\t\tQaX+wKN6Ykp2RQsCAwEAAaNQME4wHQYDVR0OBBYEFHCktVxixSE9H7lUY6M2eMtN\n\t\t\t\t\t\tKdKjMB8GA1UdIwQYMBaAFHCktVxixSE9H7lUY6M2eMtNKdKjMAwGA1UdEwQFMAMB\n\t\t\t\t\t\tAf8wDQYJKoZIhvcNAQEFBQADggEBAEVLIzBFQ9u2sQ6esQMyWGZ74U5lgWqKOrLy\n\t\t\t\t\t\thjRFKFlEmL14S3w9b/Lj/KOGQ7QyH4P8bc7pnApftQSFTpCtLIjRRgSyuvoTUYXX\n\t\t\t\t\t\t9mnEB4xpMDZfoHd+CP3Ipcfg08KTh1G9BEFJEeQW4zVxXp1YHd32/XBvT6vfxrKE\n\t\t\t\t\t\t7zQPX/4mWDTmOTOs+7LmxhioeAeSgPbRh8waA0O3YRJCZ4Sw/Fel8wfmnu9X6DAH\n\t\t\t\t\t\t4hLCRi7w+XmEl47/Lc7uJfuwoBl7h01Tdw4y8gPPLBoXKbg0MdYxbUbEONaFfNc/\n\t\t\t\t\t\t3Lx/vmCft7bkCTFeY/m+j8a6an5M5PxQXyB3QaHDcuITralR0bQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUjCCAjqgAwIBAgIIfbSOFSC/ASkwDQYJKoZIhvcNAQEFBQAwQDEdMBsGA1UE\n\t\t\t\t\t\tCgwUQ2l0eSBvZiBCYXRoIENvbGxlZ2UxHzAdBgNVBAMMFmlkcC5jaXR5YmF0aGNv\n\t\t\t\t\t\tbGwuYWMudWswHhcNMTMwNDE4MTMyMTUzWhcNMjMwNDE4MTMyMTUzWjBAMR0wGwYD\n\t\t\t\t\t\tVQQKDBRDaXR5IG9mIEJhdGggQ29sbGVnZTEfMB0GA1UEAwwWaWRwLmNpdHliYXRo\n\t\t\t\t\t\tY29sbC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIpNwR6K\n\t\t\t\t\t\tqvXHyj9FgnJ49oM25jOaqYfwXfc4EIq/1wEmuulwRVz0YdizYN0nQZNyujfFi7Wn\n\t\t\t\t\t\tV+1r14vOg6Zke+VT6u4jlL9H+reg8gieN/ybVIMNqzfddY7a82N/ZABoEQ1Wckol\n\t\t\t\t\t\tGAjcYrxO2hW71AKIixUT0S0sw8zpCCTntvqIhw+SB7fDT1v5oN0snLPplTdfwEk2\n\t\t\t\t\t\tlLLEECZnf0IP/+5o76K/7KYO/+LrKS0eSrFQwQxz1IX6Vh413lMwa597gAXT2IKn\n\t\t\t\t\t\taYPAStni01WUFPuAs5eVWoXtAEx7sbhmPoxmhFGo4xVwhTVzJLo19QdagBb9jSRa\n\t\t\t\t\t\tQaX+wKN6Ykp2RQsCAwEAAaNQME4wHQYDVR0OBBYEFHCktVxixSE9H7lUY6M2eMtN\n\t\t\t\t\t\tKdKjMB8GA1UdIwQYMBaAFHCktVxixSE9H7lUY6M2eMtNKdKjMAwGA1UdEwQFMAMB\n\t\t\t\t\t\tAf8wDQYJKoZIhvcNAQEFBQADggEBAEVLIzBFQ9u2sQ6esQMyWGZ74U5lgWqKOrLy\n\t\t\t\t\t\thjRFKFlEmL14S3w9b/Lj/KOGQ7QyH4P8bc7pnApftQSFTpCtLIjRRgSyuvoTUYXX\n\t\t\t\t\t\t9mnEB4xpMDZfoHd+CP3Ipcfg08KTh1G9BEFJEeQW4zVxXp1YHd32/XBvT6vfxrKE\n\t\t\t\t\t\t7zQPX/4mWDTmOTOs+7LmxhioeAeSgPbRh8waA0O3YRJCZ4Sw/Fel8wfmnu9X6DAH\n\t\t\t\t\t\t4hLCRi7w+XmEl47/Lc7uJfuwoBl7h01Tdw4y8gPPLBoXKbg0MdYxbUbEONaFfNc/\n\t\t\t\t\t\t3Lx/vmCft7bkCTFeY/m+j8a6an5M5PxQXyB3QaHDcuITralR0bQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bath College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.citybathcoll.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Bath College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idpshib01.ifma.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Christophe DUMONET"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "christophe.dumonet@ifma.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fr\u00e9d\u00e9ric DEDIEU"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "frederic.dedieu@ifma.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idpshib01.ifma.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2011-02-16T15:38:32Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idpshib01.ifma.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idpshib01.ifma.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idpshib01.ifma.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ifma.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifma.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFMA Clermont-Ferrand - Institut Francais de Mecanique Avancee"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFMA Clermont-Ferrand - Institut Francais de Mecanique Avancee"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4DCCAkmgAwIBAgIJAMWigPxuLL5RMA0GCSqGSIb3DQEBBQUAMIGHMQswCQYD\nVQQGEwJGUjERMA8GA1UECAwIQXV2ZXJnbmUxEDAOBgNVBAcMB0FVQklFUkUxDTAL\nBgNVBAoMBElGTUExDDAKBgNVBAsMA0NSSTEaMBgGA1UEAwwRaWRwc2hpYjAxLmlm\nbWEuZnIxGjAYBgkqhkiG9w0BCQEWC2NyaUBpZm1hLmZyMCAXDTE1MDUxOTEwMTYy\nMVoYDzIwNTUwNTA5MTAxNjIxWjCBhzELMAkGA1UEBhMCRlIxETAPBgNVBAgMCEF1\ndmVyZ25lMRAwDgYDVQQHDAdBVUJJRVJFMQ0wCwYDVQQKDARJRk1BMQwwCgYDVQQL\nDANDUkkxGjAYBgNVBAMMEWlkcHNoaWIwMS5pZm1hLmZyMRowGAYJKoZIhvcNAQkB\nFgtjcmlAaWZtYS5mcjCBnzANBgkqhkiG9w0BAQEFAAOBjQAwgYkCgYEAs17WhzJT\nsQF4vCk1dEkDqWrgzuSXce32mqY31tSu2L6xlGaIn2XpxxUQMSiKdJY4tGOmTqks\n07dvNnDfrNo71wJcJqSGHULr1LDagyggWP0iq9MCABFr0q1hbPGO9xLvR7A8gJa7\nwLci0nzgD7p47LitEO8HTILOHGeOsJUSWQUCAwEAAaNQME4wHQYDVR0OBBYEFIkZ\no+plAQVTkGYW+5u15h5uIIiZMB8GA1UdIwQYMBaAFIkZo+plAQVTkGYW+5u15h5u\nIIiZMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADgYEApkkmKWKEOj7oKVhi\nd4yuQHjMIVdzNOOmIaEBhiD6DJtUd3PzRkLygxXCgEjsqsXKPvI/SAaEHm3v3YTK\nj1sOHmXiHYkOuZiqSkP+Foyrenc96ZRSq1T4y8HdwRwvMnG6Y9sJ5P87XmeupUyL\nU60eCzyytFHcDjlnz1S/qeEMni0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEcDCCA1igAwIBAgIQeWTtozL+4yMlqLCyZXkkqjANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTExMTIyMDAwMDAwMFoXDTEzMDEwODIzNTk1OVowUjELMAkGA1UE\nBhMCRlIxLzAtBgNVBAoTJkluc3RpdHV0IEZyYW5jYWlzIGRlIE1lY2FuaXF1ZSBB\ndmFuY2VlMRIwEAYDVQQDFAkqLmlmbWEuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQDT0T6oBcfYbOMw1YVxmnJSN4p4OHVERMf0c9fX8euMywkzeC7E\n53ijhMu2qLR9dXpyqz3ZBr9aL+/XeyjiF/FAbq8y3ebUywfA9IN0F3wYtjhD8KEa\nYxEvt//JDgg20KGX23WEdr3SZjvMTZgHClfwwRNBvmZtslgsUPChxn+buphf4ZrO\nBdI4gwW4yW4cOM5gBDnj7cpxXL/5ClfvE+Gf9YOJhI9Ou90oySma441KewXyzCvz\naiffk0Paxcrh8nzP7s531366gm6T5D6syFPmOKrT49r8eyYOKHiwO/0iX250AN+3\nU6xb90aM/q2iAU6kSVznC4LsUkdK7b0aWxgtAgMBAAGjggFcMIIBWDAfBgNVHSME\nGDAWgBQMvZNoDPPeq6NJays3V0fqkOO57TAdBgNVHQ4EFgQUmcSMqeTuutpp0yVl\nGuv4BnmpyUQwDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYw\nFAYIKwYBBQUHAwEGCCsGAQUFBwMCMBgGA1UdIAQRMA8wDQYLKwYBBAGyMQECAh0w\nOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJF\nTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8v\nY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYa\naHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwFAYDVR0RBA0wC4IJKi5pZm1hLmZy\nMA0GCSqGSIb3DQEBBQUAA4IBAQA4WLst0L7sOZ95kiql+s0F759dOaAX3Cl7ZmHZ\nzSG5JVd7yiEbW1vYSweXgBvoX9r/CAhbD8jnbPYdst6c25ux8gMlSLIbfELKsvfK\nsiwJ96dtRbGaZW5/pupYJEQlnZR91oFgv+iZqefxVQw44TD7MbDqkYzVVMamT+ZM\nl4Qpi4VdqnK4Tt47CqosYm5Y/NwMsE20yw4IbQSFJyhWthhVJ62lyekh+SnRRUNn\ns50/E8fZWkQetEbw3KpZy2H/eL7loEb6/mJdDFmXd1onNu+4U366Rw3501o7NGbF\n1disNesj8I3wk+psj7WYU56fxmDDdj/F/XB66PmkewkLZL5p"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFMA Clermont-Ferrand - Institut Francais de Mecanique Avancee"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifma.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFMA Clermont-Ferrand - Institut Francais de Mecanique Avancee"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://notify.ncl.ac.uk/shibboleth/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Franks"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chris.franks@ncl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Franks"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chris.franks@ncl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://notify.ncl.ac.uk/shibboleth/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-01-05T11:05:54Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Newcastle University Notification SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ncl.ac.uk/itservice/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Newcastle upon Tyne"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://notify.ncl.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://notify.ncl.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://notify.ncl.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://notify.ncl.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://notify.ncl.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://notify.ncl.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJAMJRPlnJoPNzMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\n\t\t\t\t\t\tBAMTG2x0c2FsZXJ0MDEuY2FtcHVzLm5jbC5hYy51azAeFw0xNjAxMDQxMDA0MjJa\n\t\t\t\t\t\tFw0yNjAxMDExMDA0MjJaMCYxJDAiBgNVBAMTG2x0c2FsZXJ0MDEuY2FtcHVzLm5j\n\t\t\t\t\t\tbC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKRHwhBL0wfZ\n\t\t\t\t\t\t1yjQoNKnYDLyoCFDlwNGNjLMKwjWnMYQI9LUUzkMXKniU+8Ca4q169iIgttKsIXs\n\t\t\t\t\t\tlayTWSx7JjMuW3WjVS9ZJariLlNEwlMrLWjXBBgTG6sbTZaF8zhuFXdaJ8jSM3q6\n\t\t\t\t\t\tnjQWuZuacUWtT9zGkBdno+x4ZKUsr/PmpZiFCl83FmqyR4aFOrZWJf2mxaOwToL6\n\t\t\t\t\t\twtgyJeYcuB6270ITQmII3xWMlLT/bMfCFvtP77gbpcySglVHDkne8aNtlL1vs//k\n\t\t\t\t\t\tmQcE5m98rkWQN3sHLv/+r6ALR3cKuBnHucyALx6Gv2aSu7HciGCZE/oaHHb/HPdK\n\t\t\t\t\t\tO/pvBohDzQ8CAwEAAaNJMEcwJgYDVR0RBB8wHYIbbHRzYWxlcnQwMS5jYW1wdXMu\n\t\t\t\t\t\tbmNsLmFjLnVrMB0GA1UdDgQWBBRb76oLxarnCkg04gf5vs7NKJL4PjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAFP+BtC7xocTjILUNlwUU+toDsaDs7BNjq6yvxsADHKV71RcL\n\t\t\t\t\t\tPE2zzQKU3ULa4oVjU/yGCZydPw8RtCumnoWJlybduoml9XJamtsWma/9xZq7gmx0\n\t\t\t\t\t\tcacCOtpx5QV1YZdJU3Lb71x+5+s90MaC1LecNfEyuqM+kQCXVcSwKD3XOw0qpSwB\n\t\t\t\t\t\tWlq4Soq4QUkxlYFXP0JNXJy62uRk8Zkkk/cdQzd4dobo3wmnng+Vj8NmPJo7L7pB\n\t\t\t\t\t\tp8EpFlUZK2rYtwRforxMLa4QiMeeW9C7tFO9K5C7cRbUpDiZKUiDQlAUzBEWg8kR\n\t\t\t\t\t\thwibfza/3X5Qgg0cxnSxzS1NtJOl0ORjRjfMyA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://notify.ncl.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://notify.ncl.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://notify.ncl.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://notify.ncl.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://notify.ncl.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://notify.ncl.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://jira-test.its.umu.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://jira-test.its.umu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jira-test.its.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://jira-test.its.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jira-test.its.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://jira-test.its.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jira-test.its.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://jira-test.its.umu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://jira-test.its.umu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://jira-test.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Test-instansen av Jira f\u00f6r ITS, Ume\u00e5 universitet."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Test-instance of Jira for ITS, Ume\u00e5 universitet"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ITS Jira-instans f\u00f6r test"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ITS Jira-instans f\u00f6r test"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jira-test.its.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://jira-test.its.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jira-test.its.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://jira-test.its.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jira-test.its.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://jira-test.its.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://jira-test.its.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://jira-test.its.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://jira-test.its.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://usertest.sciquest.com",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Monroe"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:MMonroe@SciQuest.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Monroe"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:MMonroe@SciQuest.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://usertest.sciquest.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-12-13T16:37:27Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SciQuest, Inc. (test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sciquest.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SciQuest Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAl2gAwIBAgIITH47WRLwirIwDQYJKoZIhvcNAQEEBQAwXzELMAkGA1UEBhMCVVMxETAP\n\t\t\t\t\t\tBgNVBAoTCFNjaVF1ZXN0MRQwEgYDVQQLEwtEZXZlbG9wbWVudDEnMCUGA1UEAxMeU2NpUXVlc3Qg\n\t\t\t\t\t\tQ2VydGlmaWNhdGUgQXV0aG9yaXR5MB4XDTEzMDkwOTIwMjkzMVoXDTMzMDMzMTIwMjkzMVowYDEV\n\t\t\t\t\t\tMBMGA1UEAxMMc2NpcXVlc3QuY29tMRQwEgYDVQQLEwtEZXZlbG9wbWVudDEXMBUGA1UEChMOU2Np\n\t\t\t\t\t\tUXVlc3QsIEluYy4xCzAJBgNVBAgTAk5DMQswCQYDVQQGEwJVUzCCASIwDQYJKoZIhvcNAQEBBQAD\n\t\t\t\t\t\tggEPADCCAQoCggEBAJAwZSK6e1O56akTZTxBKIuDkuUZDyJzSl4xaqPa8C6XWP7I+G6sFUbtHb3I\n\t\t\t\t\t\tfY7FVmYkeS7Rx2hZA+AbNMGA3JdectjGfJoc2DYZ5ZW/Pk/hslSWJ/PGnJmJDomM90NNRYa0NPSK\n\t\t\t\t\t\tXSl9KLEsBj+S5YGrC7NZR6L0NCrLiqRGXCwdqMSl2TORG3DjdVFnyp933vxjhnaJW7ihpIc4Ga0H\n\t\t\t\t\t\tORjj6zk2npzGhq71qmRwfxHFsRivFR1CBH3EVsqLCm3AXhVmqCuwJYmXjo26aZYOV61gvMht0oWq\n\t\t\t\t\t\thPI3LQXZ6nWwpPOCiyMBJAuhckZQQu0n81tJyII0J+fXJXzObJ9OJxUCAwEAAaM0MDIwDgYDVR0P\n\t\t\t\t\t\tAQH/BAQDAgWgMCAGA1UdJQEB/wQWMBQGCCsGAQUFBwMEBggrBgEFBQcDAjANBgkqhkiG9w0BAQQF\n\t\t\t\t\t\tAAOBgQAj3d6pxxPMxzet05eEemxV0wgP9L0F27/sTPsGioynIclNxKoAC5hoeiHAOVKw+8RTL3D/\n\t\t\t\t\t\tUJxYoO9+3wRbtkiHnfP2W8SP7GoxvZhaJyblGX5PS+xLtCBhwfVbUQC9dNGy/yTOggYvF6oQIXn2\n\t\t\t\t\t\tU7mXMJZfSVNp1vexAK1dV+TJVQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://usertest.sciquest.com/apps/Router/ExternalAuth/SAML/Login/Edinburgh",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://usertest.sciquest.com/apps/Router/ExternalAuth/SAML/Login/Warwick",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://shibboleth.wmintelligence.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Revuri"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:bharadwaj.revuri@digitalinsightresearch.in"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bharadwaj"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Revuri"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:bharadwaj.revuri@digitalinsightresearch.in"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bharadwaj"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.wmintelligence.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-04-03T12:00:44Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "World Market Intelligence"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.worldmarketintelligence.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "World Market Intelligence Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.wmintelligence.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.wmintelligence.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.wmintelligence.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.wmintelligence.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.wmintelligence.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.wmintelligence.com/Shibboleth.sso/SAML2/POST",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth.wmintelligence.com/Shibboleth.sso/SAML2/POST",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The world's markets quantified, qualified and expertly evaluated"
                  }
                ],
                "logo": [
                  {
                    "text": "https://s3-eu-west-1.amazonaws.com/www.worldmarketintelligence.com/world_market_intelligence_logo.png",
                    "height": "67",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "201"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "World Market Intelligence"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTzCCAjegAwIBAgIJAOR5X3M97uKJMA0GCSqGSIb3DQEBBQUAMCgxJjAkBgNV\n\t\t\t\t\t\tBAMTHXNoaWJib2xldGgud21pbnRlbGxpZ2VuY2UuY29tMB4XDTE0MDMyMjA0MDAy\n\t\t\t\t\t\tOVoXDTE3MDMyMTA0MDAyOVowKDEmMCQGA1UEAxMdc2hpYmJvbGV0aC53bWludGVs\n\t\t\t\t\t\tbGlnZW5jZS5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCiRNxg\n\t\t\t\t\t\tCe6zMPijvEumDw+cb4Y/DUR8GPLV9HqiAN+0n0QKE/lZIa+kC3TxldgMrIkFjtle\n\t\t\t\t\t\tgZ4iG7MCBvoAb8w2DPjrH5KwoyhLRRXKVEq8axmdeXU0CUJw+N6518vzKmQGv1GU\n\t\t\t\t\t\tRs8If5ctvvZi6LcZIUI09/fHPt1PehNUFzoCDN7RCE3xztWCIbFaDptDLrJ1oMqW\n\t\t\t\t\t\tvbNbOnn07uyEtNYjAtI7mkR/A1fbYNTez0t+6GawtGmexwHCOT3UefOhRfGqBh+5\n\t\t\t\t\t\tRM2VvZQH+vGxzqzg4qdDahF7FYi9r2OpxgTeebSmrZ7vjfRRt9TQ29oN1NyxgjJr\n\t\t\t\t\t\tW5S+LhdfiIWqMOL3AgMBAAGjfDB6MFkGA1UdEQRSMFCCHXNoaWJib2xldGgud21p\n\t\t\t\t\t\tbnRlbGxpZ2VuY2UuY29thi9odHRwOi8vc2hpYmJvbGV0aC53bWludGVsbGlnZW5j\n\t\t\t\t\t\tZS5jb20vc2hpYmJvbGV0aDAdBgNVHQ4EFgQU6LfyT/3Hb1BITfsUmAwnzz3jX+0w\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAGVK1LxrSZw5uwP6rjgaFGtFFjvdlPoyS3S7CTsj\n\t\t\t\t\t\t9wpg7zs/gEoO+ptXeAcPkENgU7InUxfn3RVhB1sIit5UWRYCtNFBih4WZXCbmL0G\n\t\t\t\t\t\t/9YOOmSGbEGpDrPCLmxYc8oVNFe5ks5+lOBqUZK15lPpgwQwlAX/c1Jn//BMte7c\n\t\t\t\t\t\tgP556YvRParYU9E1zN+npL4c7pbLXPpkkpDTqJjplvCcnMbkD9e5LmexaRwy5CQa\n\t\t\t\t\t\tiuc28kLhBX8fCLSx4fnkb7l9g6ogFqNJEGf3PG1EDahl9oX6r51bBVYHYBJM6+Zr\n\t\t\t\t\t\thTLk6uX2iiqI9onok/cihw18QDh106Ws9cafIukWyVpHbt4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.wmintelligence.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.wmintelligence.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.wmintelligence.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.wmintelligence.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.wmintelligence.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.wmintelligence.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.wmintelligence.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth.wmintelligence.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.wmintelligence.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.wmintelligence.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.wiltshire.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@wiltshire.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Grenfell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:john.grenfell@wiltshire.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.wiltshire.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-06-05T16:44:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEoTCCA4mgAwIBAgIRAOiGbysj0iOdFzhBHusteqMwDQYJKoZIhvcNAQELBQAw\n\t\t\t\t\t\tZDELMAkGA1UEBhMCTkwxFjAUBgNVBAgTDU5vb3JkLUhvbGxhbmQxEjAQBgNVBAcT\n\t\t\t\t\t\tCUFtc3RlcmRhbTEPMA0GA1UEChMGVEVSRU5BMRgwFgYDVQQDEw9URVJFTkEgU1NM\n\t\t\t\t\t\tIENBIDIwHhcNMTUwMjI0MDAwMDAwWhcNMTgwMjIzMjM1OTU5WjBBMSEwHwYDVQQL\n\t\t\t\t\t\tExhEb21haW4gQ29udHJvbCBWYWxpZGF0ZWQxHDAaBgNVBAMTE2lkcC53aWx0c2hp\n\t\t\t\t\t\tcmUuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC8WXQAsa7l\n\t\t\t\t\t\tjeJ86YSF0jAyrqyaSeIjwQgFnUXFCPw/k/H9vzNDF/cZM8faRfx+14b9HMlXLdLD\n\t\t\t\t\t\tbKcl/4dPQY6oxqt+3IGTLPATva2aMbssTbICswVz7VOVjHMPnssha9HYDFgoUVTV\n\t\t\t\t\t\t7C0f8nKGzzQiT6FIspIjWALBU7DAOonvz0MernDWpVQ5vpW/TSMbd1wBHgMmdTmu\n\t\t\t\t\t\th/XgffOYolhgBS5asilC3O6BCqxbYdH76MEeZcVcXCf0y4lQ41pUNagAtLdCNOZu\n\t\t\t\t\t\tA5IUbqrao6BACiKFzv/mpguYNXEtZHSGyCLrC2qu2nnQ2udqfnmBYtgsX8FWAUQt\n\t\t\t\t\t\tz2LNvW0OSrwHAgMBAAGjggFvMIIBazAfBgNVHSMEGDAWgBRb0IocmjJb4LXdllQb\n\t\t\t\t\t\t4YYosP22vTAdBgNVHQ4EFgQUWT26a/YMEDwjsLN+InUujXgi+PEwDgYDVR0PAQH/\n\t\t\t\t\t\tBAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUF\n\t\t\t\t\t\tBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1UdHwQz\n\t\t\t\t\t\tMDEwL6AtoCuGKWh0dHA6Ly9jcmwudXNlcnRydXN0LmNvbS9URVJFTkFTU0xDQTIu\n\t\t\t\t\t\tY3JsMGwGCCsGAQUFBwEBBGAwXjA1BggrBgEFBQcwAoYpaHR0cDovL2NydC51c2Vy\n\t\t\t\t\t\tdHJ1c3QuY29tL1RFUkVOQVNTTENBMi5jcnQwJQYIKwYBBQUHMAGGGWh0dHA6Ly9v\n\t\t\t\t\t\tY3NwLnVzZXJ0cnVzdC5jb20wHgYDVR0RBBcwFYITaWRwLndpbHRzaGlyZS5hYy51\n\t\t\t\t\t\tazANBgkqhkiG9w0BAQsFAAOCAQEAjrPlaXZ/IvJnllBGlHgfkiCtEDgmT5X9vWhK\n\t\t\t\t\t\tMkCs5n1N22WAiP232Yk1TffU+jTBhoKgP8uxb9LPu7c2AwVXiuJ1EJGJpYkvwQvm\n\t\t\t\t\t\tagbyy/B/4O36SwjhG+arqD6B3sDWB4tAQJuoFQ3OP/eOccZ6yG8HGVbqCf39kjpK\n\t\t\t\t\t\thv8PqQ8vCp/jLuK4LX1zPdB0NoESOm9KmW4CsQA/4QJCaJrnRI/Lm0/9T/1yT62d\n\t\t\t\t\t\t0ME9TV8PlhWKNsAHrbaqyii4dqlSpsrP6rCad4pqlp5m1bRIZC7Met5RQ6qyIUjC\n\t\t\t\t\t\tqwqpVTvyqjl0xrmHHCWfxY8GEVajGv7HzlQwukJFT2uSFdJl/g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wiltshire.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.wiltshire.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.wiltshire.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.wiltshire.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.wiltshire.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.wiltshire.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.wiltshire.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.wiltshire.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.wiltshire.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wiltshire.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEoTCCA4mgAwIBAgIRAOiGbysj0iOdFzhBHusteqMwDQYJKoZIhvcNAQELBQAw\n\t\t\t\t\t\tZDELMAkGA1UEBhMCTkwxFjAUBgNVBAgTDU5vb3JkLUhvbGxhbmQxEjAQBgNVBAcT\n\t\t\t\t\t\tCUFtc3RlcmRhbTEPMA0GA1UEChMGVEVSRU5BMRgwFgYDVQQDEw9URVJFTkEgU1NM\n\t\t\t\t\t\tIENBIDIwHhcNMTUwMjI0MDAwMDAwWhcNMTgwMjIzMjM1OTU5WjBBMSEwHwYDVQQL\n\t\t\t\t\t\tExhEb21haW4gQ29udHJvbCBWYWxpZGF0ZWQxHDAaBgNVBAMTE2lkcC53aWx0c2hp\n\t\t\t\t\t\tcmUuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC8WXQAsa7l\n\t\t\t\t\t\tjeJ86YSF0jAyrqyaSeIjwQgFnUXFCPw/k/H9vzNDF/cZM8faRfx+14b9HMlXLdLD\n\t\t\t\t\t\tbKcl/4dPQY6oxqt+3IGTLPATva2aMbssTbICswVz7VOVjHMPnssha9HYDFgoUVTV\n\t\t\t\t\t\t7C0f8nKGzzQiT6FIspIjWALBU7DAOonvz0MernDWpVQ5vpW/TSMbd1wBHgMmdTmu\n\t\t\t\t\t\th/XgffOYolhgBS5asilC3O6BCqxbYdH76MEeZcVcXCf0y4lQ41pUNagAtLdCNOZu\n\t\t\t\t\t\tA5IUbqrao6BACiKFzv/mpguYNXEtZHSGyCLrC2qu2nnQ2udqfnmBYtgsX8FWAUQt\n\t\t\t\t\t\tz2LNvW0OSrwHAgMBAAGjggFvMIIBazAfBgNVHSMEGDAWgBRb0IocmjJb4LXdllQb\n\t\t\t\t\t\t4YYosP22vTAdBgNVHQ4EFgQUWT26a/YMEDwjsLN+InUujXgi+PEwDgYDVR0PAQH/\n\t\t\t\t\t\tBAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUF\n\t\t\t\t\t\tBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1UdHwQz\n\t\t\t\t\t\tMDEwL6AtoCuGKWh0dHA6Ly9jcmwudXNlcnRydXN0LmNvbS9URVJFTkFTU0xDQTIu\n\t\t\t\t\t\tY3JsMGwGCCsGAQUFBwEBBGAwXjA1BggrBgEFBQcwAoYpaHR0cDovL2NydC51c2Vy\n\t\t\t\t\t\tdHJ1c3QuY29tL1RFUkVOQVNTTENBMi5jcnQwJQYIKwYBBQUHMAGGGWh0dHA6Ly9v\n\t\t\t\t\t\tY3NwLnVzZXJ0cnVzdC5jb20wHgYDVR0RBBcwFYITaWRwLndpbHRzaGlyZS5hYy51\n\t\t\t\t\t\tazANBgkqhkiG9w0BAQsFAAOCAQEAjrPlaXZ/IvJnllBGlHgfkiCtEDgmT5X9vWhK\n\t\t\t\t\t\tMkCs5n1N22WAiP232Yk1TffU+jTBhoKgP8uxb9LPu7c2AwVXiuJ1EJGJpYkvwQvm\n\t\t\t\t\t\tagbyy/B/4O36SwjhG+arqD6B3sDWB4tAQJuoFQ3OP/eOccZ6yG8HGVbqCf39kjpK\n\t\t\t\t\t\thv8PqQ8vCp/jLuK4LX1zPdB0NoESOm9KmW4CsQA/4QJCaJrnRI/Lm0/9T/1yT62d\n\t\t\t\t\t\t0ME9TV8PlhWKNsAHrbaqyii4dqlSpsrP6rCad4pqlp5m1bRIZC7Met5RQ6qyIUjC\n\t\t\t\t\t\tqwqpVTvyqjl0xrmHHCWfxY8GEVajGv7HzlQwukJFT2uSFdJl/g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Wiltshire College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wiltshire.ac.uk/external/about_us/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Wiltshire College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idpv3.rnp.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Laerte F Belotto"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "laerte.belotto@terceiro.rnp.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idpv3.rnp.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID7jCCAtYCAQAwDQYJKoZIhvcNAQEFBQAwgbwxMTAvBgNVBAoTKFJOUCAtIFJl\nZGUgTmFjaW9uYWwgZGUgRW5zaW5vIGUgUGVzcXVpc2ExDDAKBgNVBAsTA0dUSTEt\nMCsGCSqGSIb3DQEJARYebGFlcnRlLmJlbG90dG9AdGVyY2Vpcm8ucm5wLmJyMREw\nDwYDVQQHEwhDYW1waW5hczETMBEGA1UECBQKU8OjbyBQYXVsbzELMAkGA1UEBhMC\nQlIxFTATBgNVBAMTDGlkcHYzLnJucC5icjAeFw0xNjA0MDQxNTAxMzRaFw0xOTA0\nMDQxNTAxMzRaMIG8MTEwLwYDVQQKEyhSTlAgLSBSZWRlIE5hY2lvbmFsIGRlIEVu\nc2lubyBlIFBlc3F1aXNhMQwwCgYDVQQLEwNHVEkxLTArBgkqhkiG9w0BCQEWHmxh\nZXJ0ZS5iZWxvdHRvQHRlcmNlaXJvLnJucC5icjERMA8GA1UEBxMIQ2FtcGluYXMx\nEzARBgNVBAgUClPDo28gUGF1bG8xCzAJBgNVBAYTAkJSMRUwEwYDVQQDEwxpZHB2\nMy5ybnAuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDSw9chEqxg\njyWEbzMawJRqOCSxW6L747AD4Cd2PBDP0kAdUTpLvUds10stn7LJVoe9BGqRbo3i\nFXuD8WgmMS03ADjsdXtQuQcOLPdfdjUpswRMbmrzhwygTqBrwmESpbABz6FsxcLI\nLJYkJIWj03ay0nPSCphwqd/FBbensTqeKyy6f7BMudReOPj93oL6ZOEvadrRx/Ln\nAIa446yMgo4b/BZpxKEwE2taJ+F122ytNW5s5UQVdXcg6t/PU8yqpvt6PUN/IeVy\nZoQE+1/4a6KglA5HMlL+0RW1pVnF7AnEjuS6DXHlPyqO8FqGRB+Dl0P3yAF2XwTP\n3sXegg/OgoxhAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAGwYS5Kaft8IZE1p2sPT\nd1MDRJtkBhonCNoc1HgD4bESl6EaSLLcwH40Ued7eXaoXeurhTFNHqY0dpZcZ1qX\n8z9z1ecqN1J2g5jz3z/g+/Pvc/TGxnHANf5ZyTArGcvCDM6mMFlDa440k/UucwFV\nuH84HDKhKM7WB2d2Lsx+Ok9ae3AtE+Jfs7POvQ8OCCg2K/a+MgD0vIPkrjt0Rvqq\nCu0TgwLPpqMwaxEqdFhISrmKiQDCUrgSFYa5LdeHeNqYzB6cQAN7LWF1eutgaxyv\nrwzjZkFiGeBWPDwP+z0ujfn5lrTAghRDc3f51qSgar/SybqN6bZxjOZF8EzcMqOI\nBLw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rnp.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idpv3.rnp.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idpv3.rnp.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idpv3.rnp.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idpv3.rnp.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idpv3.rnp.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idpv3.rnp.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idpv3.rnp.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idpv3.rnp.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rnp.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.rnp.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.rnp.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IDP V3 - Laerte  RNP Campinas"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IDP V3 - Laerte  RNP Campinas"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IDP V3 - Laerte  RNP Campinas"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IDP V3 - Laerte  RNP Campinas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID7jCCAtYCAQAwDQYJKoZIhvcNAQEFBQAwgbwxMTAvBgNVBAoTKFJOUCAtIFJl\nZGUgTmFjaW9uYWwgZGUgRW5zaW5vIGUgUGVzcXVpc2ExDDAKBgNVBAsTA0dUSTEt\nMCsGCSqGSIb3DQEJARYebGFlcnRlLmJlbG90dG9AdGVyY2Vpcm8ucm5wLmJyMREw\nDwYDVQQHEwhDYW1waW5hczETMBEGA1UECBQKU8OjbyBQYXVsbzELMAkGA1UEBhMC\nQlIxFTATBgNVBAMTDGlkcHYzLnJucC5icjAeFw0xNjA0MDQxNTAxMzRaFw0xOTA0\nMDQxNTAxMzRaMIG8MTEwLwYDVQQKEyhSTlAgLSBSZWRlIE5hY2lvbmFsIGRlIEVu\nc2lubyBlIFBlc3F1aXNhMQwwCgYDVQQLEwNHVEkxLTArBgkqhkiG9w0BCQEWHmxh\nZXJ0ZS5iZWxvdHRvQHRlcmNlaXJvLnJucC5icjERMA8GA1UEBxMIQ2FtcGluYXMx\nEzARBgNVBAgUClPDo28gUGF1bG8xCzAJBgNVBAYTAkJSMRUwEwYDVQQDEwxpZHB2\nMy5ybnAuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDSw9chEqxg\njyWEbzMawJRqOCSxW6L747AD4Cd2PBDP0kAdUTpLvUds10stn7LJVoe9BGqRbo3i\nFXuD8WgmMS03ADjsdXtQuQcOLPdfdjUpswRMbmrzhwygTqBrwmESpbABz6FsxcLI\nLJYkJIWj03ay0nPSCphwqd/FBbensTqeKyy6f7BMudReOPj93oL6ZOEvadrRx/Ln\nAIa446yMgo4b/BZpxKEwE2taJ+F122ytNW5s5UQVdXcg6t/PU8yqpvt6PUN/IeVy\nZoQE+1/4a6KglA5HMlL+0RW1pVnF7AnEjuS6DXHlPyqO8FqGRB+Dl0P3yAF2XwTP\n3sXegg/OgoxhAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAGwYS5Kaft8IZE1p2sPT\nd1MDRJtkBhonCNoc1HgD4bESl6EaSLLcwH40Ued7eXaoXeurhTFNHqY0dpZcZ1qX\n8z9z1ecqN1J2g5jz3z/g+/Pvc/TGxnHANf5ZyTArGcvCDM6mMFlDa440k/UucwFV\nuH84HDKhKM7WB2d2Lsx+Ok9ae3AtE+Jfs7POvQ8OCCg2K/a+MgD0vIPkrjt0Rvqq\nCu0TgwLPpqMwaxEqdFhISrmKiQDCUrgSFYa5LdeHeNqYzB6cQAN7LWF1eutgaxyv\nrwzjZkFiGeBWPDwP+z0ujfn5lrTAghRDc3f51qSgar/SybqN6bZxjOZF8EzcMqOI\nBLw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IDP V3 - Laerte  RNP Campinas"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IDP V3 - Laerte  RNP Campinas"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rnp.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rnp.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IDP V3 - Laerte  RNP Campinas"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IDP V3 - Laerte  RNP Campinas"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ijs.si/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lenar\u010di\u010d"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jadran.lenarcic@ijs.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jadran"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@ijs.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Martinec"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mark.martinec@ijs.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jona Javor\u0161ek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jona.javorsek@ijs.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jona Javor\u0161ek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jona.javorsek@ijs.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ijs.si/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_general.pdf"
              },
              {
                "lang": "sl",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_splosni_pogoji.pdf"
              }
            ],
            "registration_instant": "2015-02-10T13:02:29Z",
            "registration_authority": "http://aai.arnes.si",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ijs.si/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ijs.si/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ijs.si"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ijs.si/ijsw/JSI"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ijs.si/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Jo\u017eef Stefan Institute"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ponudnik identitet za Institut \"Jo\u017eef Stefan\""
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "300",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "300"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Jo\u017eef Stefan Institute"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institut \"Jo\u017eef Stefan\""
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "In\u0161titut Jo\u017eef Stefan (IJS)"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "In\u0161titut Jo\u017eef Stefan (IJS)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ijs.si/ijsw/JSI"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ijs.si/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "In\u0161titut Jo\u017eef Stefan (IJS)"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "In\u0161titut Jo\u017eef Stefan (IJS)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.jove.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Robinson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dan.robinson@jove.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Robinson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dan.robinson@jove.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.jove.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-09-03T19:35:36Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Journal of Visualized Experiments"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jove.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "MYJOVE Corporation"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.jove.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.jove.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.jove.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.jove.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.jove.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.jove.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4jCCAcqgAwIBAgIJAMmZMgpgR98FMA0GCSqGSIb3DQEBBQUAMBQxEjAQBgNV\n\t\t\t\t\t\tBAMTCWpvdmUtc2l0ZTAeFw0xNDA4MjYxOTI5NDVaFw0yNDA4MjMxOTI5NDVaMBQx\n\t\t\t\t\t\tEjAQBgNVBAMTCWpvdmUtc2l0ZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAJpYESYD4dYzXNtXUSDK3W59M7Mr5MdCZxbr8I508aQkXIDwjBNqtr6a7Hat\n\t\t\t\t\t\tHer5Zr7FU8jaddsO5hgFaOwdN/5EZfqpSDdS6YCop7Y7b5MuKW2IXQqyl3Uf6NVB\n\t\t\t\t\t\tuFb24x8Jq9PzmpWXE0O+qiRubp9kVR2DsIv5QJcAmMJn46jAyJefqOTTtoeOT9PH\n\t\t\t\t\t\tHOuOd21k8zRmeFQq2hYgL+8pkVN6KvJMSR8+a7V0xL4TinO2NLgU+REPkh8dZwKk\n\t\t\t\t\t\tv3YiX5Zy4NHsn8BkdNwlTkB2Opd90ociYnvvWjsLcM0jHLDs+Kg1BBqbtFFE2Aiv\n\t\t\t\t\t\tWioIclBIAGURdZnHyn5bviGp8E0CAwEAAaM3MDUwFAYDVR0RBA0wC4IJam92ZS1z\n\t\t\t\t\t\taXRlMB0GA1UdDgQWBBQJINSSKzlDshwkhXdHrjR2mNn+zjANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAhrtgkBsbRvQLDtyhGbtMPbTTlGDHrnOXUFx5TqqyGCqYgp86n7awj2kU\n\t\t\t\t\t\typRW27QZr6a7LnyznASyXWWak0JXb90ZvPMR8bpvPEYR1HbGVQ94/+KlOtsR3SjP\n\t\t\t\t\t\t0swPElIYm9Ff3oNaM0uh3YAi9qhB/ZrTJmXcTDLZDgC3jOApjNV2nvtjb2Bu0ysN\n\t\t\t\t\t\tyKyJd48ZF72SR5zQKq4S7OcbHtttrk0/xeEHomt+Xw0PzB265Vr14OZoAO91jEvP\n\t\t\t\t\t\tdU4byrEQ+k+7huxTc6arI5cagwL8GnpH6I0M6Ouj8T4RTmXHKWseJDXYCc9WNlN/\n\t\t\t\t\t\tqa6mttqxIIeSvf7w0qq4buQC7/jHWQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.jove.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.jove.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.jove.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.jove.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.jove.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.jove.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp1.uwaterloo.ca/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mason"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "watiam@uwaterloo.ca"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sean"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp1.uwaterloo.ca/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.canarie.ca/templates/services/docs/CAF_join_en.pdf"
              },
              {
                "lang": "fr",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.canarie.ca/templates/services/docs/CAF_join_fr.pdf"
              }
            ],
            "registration_instant": "2014-06-19T00:00:00Z",
            "registration_authority": "http://www.canarie.ca",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUbKz7iorE+LiL1mldU1jseivAaTkwDQYJKoZIhvcNAQEF\nBQAwHDEaMBgGA1UEAxMRaWRwMS51d2F0ZXJsb28uY2EwHhcNMTQwNjE4MTMxMTQ5\nWhcNMzQwNjE4MTMxMTQ5WjAcMRowGAYDVQQDExFpZHAxLnV3YXRlcmxvby5jYTCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJLtTKyNTqUzgIoJaZs1s3UJ\n0jPSIy18S8yVyOEhGaa2MT6kd3ik1tZ3O3iFNm59oNU/IU7km+O8Lq364GME0lCD\nKEobEaH2Tcs55Hk2a9rSmpZ/9+MAW9W/UJVb7Y/T1+jpQxVB4KTVULGqleO4wwJZ\nnhRbzNFuQgSW12msKV4d0ClKct5ui2UlkCXLrC6MFOEsKoGawpm5StKSnbTzLD4K\n3B6LdSc3WQWzX8zSHwSbe0PLbH2MD1Ns37YNNFv5uDhiYeh7E9zYfqd1LmUufmK2\n3daof43rjDRi+3Ybzx44GDMp1bMp7c7Q9W2HmnrZDY0fiyeLTXURDPGbsUgENFMC\nAwEAAaNpMGcwRgYDVR0RBD8wPYIRaWRwMS51d2F0ZXJsb28uY2GGKGh0dHBzOi8v\naWRwMS51d2F0ZXJsb28uY2EvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFHQQAyUs\nuhk9N8P6qen7W7J4k4itMA0GCSqGSIb3DQEBBQUAA4IBAQCMwr7R/xOhdI8OQlc8\ntp6gnIsUSBD6uwcXGVfjg07i/NTtfWTRG3cn8SvV5KcmxqNTQxkkhXyE92RMw88O\nOQM220jmY4fQx63af0OjtXTUYxIOK0Cg0FXMylloHdRyVqp2wbJqbclYL3IWoNRN\nnbyTdmEBxrUjKsAgJl9F4mS06iuOyBUMmcLxqPRQCNuPm7CJECTmYfUiaEKh5Keo\n4f7W4J1Jx1wcvieUsbcMRx258MXiQ+tqYvPVTAuNsFOZ3YcOUHjXTTueSLyzDVb8\nYXl9jLkki1wDKTSv8RDcUDjBWf0rITaf13Q08dKsI2gUp786n2QO9fXaKKgxSM+n\n7zvx"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uwaterloo.ca"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Students, employees and other University of Waterloo account holders"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Waterloo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.uwaterloo.ca/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.uwaterloo.ca/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp1.uwaterloo.ca/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp1.uwaterloo.ca/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.uwaterloo.ca/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp1.uwaterloo.ca/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp1.uwaterloo.ca/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp1.uwaterloo.ca/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp1.uwaterloo.ca/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.uwaterloo.ca/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.uwaterloo.ca/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uwaterloo.ca"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Students, employees and other University of Waterloo account holders"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Waterloo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUbKz7iorE+LiL1mldU1jseivAaTkwDQYJKoZIhvcNAQEF\nBQAwHDEaMBgGA1UEAxMRaWRwMS51d2F0ZXJsb28uY2EwHhcNMTQwNjE4MTMxMTQ5\nWhcNMzQwNjE4MTMxMTQ5WjAcMRowGAYDVQQDExFpZHAxLnV3YXRlcmxvby5jYTCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJLtTKyNTqUzgIoJaZs1s3UJ\n0jPSIy18S8yVyOEhGaa2MT6kd3ik1tZ3O3iFNm59oNU/IU7km+O8Lq364GME0lCD\nKEobEaH2Tcs55Hk2a9rSmpZ/9+MAW9W/UJVb7Y/T1+jpQxVB4KTVULGqleO4wwJZ\nnhRbzNFuQgSW12msKV4d0ClKct5ui2UlkCXLrC6MFOEsKoGawpm5StKSnbTzLD4K\n3B6LdSc3WQWzX8zSHwSbe0PLbH2MD1Ns37YNNFv5uDhiYeh7E9zYfqd1LmUufmK2\n3daof43rjDRi+3Ybzx44GDMp1bMp7c7Q9W2HmnrZDY0fiyeLTXURDPGbsUgENFMC\nAwEAAaNpMGcwRgYDVR0RBD8wPYIRaWRwMS51d2F0ZXJsb28uY2GGKGh0dHBzOi8v\naWRwMS51d2F0ZXJsb28uY2EvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFHQQAyUs\nuhk9N8P6qen7W7J4k4itMA0GCSqGSIb3DQEBBQUAA4IBAQCMwr7R/xOhdI8OQlc8\ntp6gnIsUSBD6uwcXGVfjg07i/NTtfWTRG3cn8SvV5KcmxqNTQxkkhXyE92RMw88O\nOQM220jmY4fQx63af0OjtXTUYxIOK0Cg0FXMylloHdRyVqp2wbJqbclYL3IWoNRN\nnbyTdmEBxrUjKsAgJl9F4mS06iuOyBUMmcLxqPRQCNuPm7CJECTmYfUiaEKh5Keo\n4f7W4J1Jx1wcvieUsbcMRx258MXiQ+tqYvPVTAuNsFOZ3YcOUHjXTTueSLyzDVb8\nYXl9jLkki1wDKTSv8RDcUDjBWf0rITaf13Q08dKsI2gUp786n2QO9fXaKKgxSM+n\n7zvx"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Waterloo"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uwaterloo.ca"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Waterloo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.univ-psl.fr/idp/saml2/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support.informatique@univ-psl.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.univ-psl.fr/idp/saml2/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-03-19T10:06:01Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univ-psl.fr/idp/saml2/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univ-psl.fr/idp/saml2/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.univ-psl.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-psl.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-psl.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The populations covered are students, teachers and staff of the universities"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Les populations couvertes sont les \u00e9tudiants, les enseignants et les personnels de l'universit\u00e9s"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PSL Research University"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PSL - Universit\u00e9 de Recherche Paris Sciences & Lettres"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+TCCAeGgAwIBAgIJANcuXKnq7Ew5MA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\nBAMMCHdob2NhcmVzMB4XDTE1MDMxMTE2NDAxMFoXDTI1MDMwODE2NDAxMFowEzER\nMA8GA1UEAwwId2hvY2FyZXMwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQDQ7HX5jtzHtkKu0RUvTlnxG04v8dfmnkMr0PVb6bFZpBSxG+E5ORXqMKQ9qXiq\no+W5XYkZ8M2Njn7ndHqovFoEfFjTqTi0hL2LXmYOPJbWIw6Xhs6GLUZ2USnoHPbg\nIHiMFKqHFEi7EejOzlmskDwCOc6gcsiL9UqShi/QsZO8JQtc/G6ZkEuQ8eFlZZ4M\nn8Oxi5P8ivDPv1U9kq4dMfYRNEnQoZWPwsrRxpVYCyvBo4V3sfhTb1tA41Wycqs4\nO8nTH/pZkFxXLBPrKmzFHxN/y9vik7OAMczGQs1m0+j7e9084Xh6tLPvJMrOhVAO\nMtoc333WbfR9Rceaq5fXC1UXAgMBAAGjUDBOMB0GA1UdDgQWBBRLEg3XwdkF74fg\npGhKRxpShFKrjTAfBgNVHSMEGDAWgBRLEg3XwdkF74fgpGhKRxpShFKrjTAMBgNV\nHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQB//rAaAaEoP0tlnuXyiV3nDvXo\n/D4eaLS84BPm9kmdicjVg2+BniDd2P05ecY8OJpd4usXmbaeVH/gHBZ+9QmA9p3F\nO02qh3wA/FykOaZ8wWG4x9bTiFn2gR2+tet5DxWECWtVim4KJXTPP76k0S1anf9v\nTR+9MZ+wgSmw6FzzmLb/rLPqGDTjJty/3j4A3/dpoYoDsthfzPHF0IVSWZ6AOXq7\n4NVa4plDX3kopSpDWpn0AR9JL6d76t1TZqXPACtoO3JOLvWujgNmZxmOwBdFcMe6\nm4NQPTEkvbbry7PxzsLnEPJZu80pEM8viNvuNNKAnyJZLIH17t8JkEW5Nr/E"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PSL - Universit\u00e9 de Recherche Paris Sciences & Lettres"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-psl.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "PSL - Universit\u00e9 de Recherche Paris Sciences & Lettres"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://auth.asiaportal.info",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:bib@nias.ku.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Administrator"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://auth.asiaportal.info",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.asiaportal.info/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://guide.asiaportal.info"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Provides access to databases and other resources for Nias Nordic Council Member institutions"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://guide.asiaportal.info/privacypolicy/V1"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "AsiaPortal: Databases and other resources provided by the Nordic Institute of Asian Studies"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.asiaportal.info/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://auth.asiaportal.info/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://auth.asiaportal.info/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://auth.asiaportal.info/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "AsiaPortal Resources by Nordic Institute of Asian Studies"
                }
              ],
              "requested_attribute": [
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://pp-test-admin.it.su.se/Shibboleth.sso",
    {
      "entity_id": "https://pp-test-admin.it.su.se/Shibboleth.sso",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://pp-test-admin.it.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://pp-test-admin.it.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pp-test-admin.it.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://pp-test-admin.it.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://pp-test-admin.it.su.se/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://pp-test-admin.it.su.se/Shibboleth.sso/WAYF/wavelan",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "pp9-test-admin1.it.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJANQ5Gk+rX2cMMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\nBAMTGHBwOS10ZXN0LWFkbWluMS5pdC5zdS5zZTAeFw0xMDA1MjAwNzMxMDRaFw0y\nMDA1MTcwNzMxMDRaMCMxITAfBgNVBAMTGHBwOS10ZXN0LWFkbWluMS5pdC5zdS5z\nZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALL6MQHP8faLRkxQb7jZ\nzGFPlqPyLONhaRH7MhayH6fjp28pPQj65KvoqR8KMEujdYtkugpXd03ZbLOzYcty\n9RXWf29K0BTmb1AcQjqcv4Ciq8Cix4tA6jD3nnuztrrELOmJ5U3pM0ebQystAyoz\nrYZhpdjIynlCcHACoG5dZPS36mhiPYVpAfIcUY2K/zPmLIgwZrsvAl8hRltuClxF\n8ZzWeY04RoXMpOLw6W8l/Yz6d+ioRZxifFt9t3ZvXnI9X6SZQ9rmQi5ii0gF1+xp\nrbrBfmhUTItFLmI1aDUiPWGTLQtwXJcqZdygyCYCSQBVKWT2hX2lW8T7WkXBM6+i\nxdUCAwEAAaNGMEQwIwYDVR0RBBwwGoIYcHA5LXRlc3QtYWRtaW4xLml0LnN1LnNl\nMB0GA1UdDgQWBBTyDEsz2V7ggY9hxIDkjnnlf26n4TANBgkqhkiG9w0BAQUFAAOC\nAQEAGL1UqHFcCT2hJXpot4U8mw6UZjTZdX9tuaMPrl8UrkWG+EJZFUo8nrpH8Pbk\nuwdugFiMmSOwXQoAEB7wKvgQJ/Tbkdw+OIIT62FYXPdEquDuOTeuM8reXN49ZVfO\nbz4duBx6ui5e0o9XdMyxjJpML1kNzrNRJJ9KeKptFfA9Zw0KGjkwTyGDdDlpvd6Z\nSQQJB5ysqsYR9Eq3kkRn7H5hO02Xu+J1EDgC/c0XBSXT9OerLozjUgGuGDI6bsCi\nq1cJ9OonqjbI45FgVw8ubcuDl1SCfN2zVNjZ27ZvRqyzxAl4xa5Bkh6QDhNqbaMd\nHXJSWiUzSKMrriekzJ2y2Pkqng=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=pp9-test-admin1.it.su.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "pp9-test-admin1.it.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJANQ5Gk+rX2cMMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\nBAMTGHBwOS10ZXN0LWFkbWluMS5pdC5zdS5zZTAeFw0xMDA1MjAwNzMxMDRaFw0y\nMDA1MTcwNzMxMDRaMCMxITAfBgNVBAMTGHBwOS10ZXN0LWFkbWluMS5pdC5zdS5z\nZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALL6MQHP8faLRkxQb7jZ\nzGFPlqPyLONhaRH7MhayH6fjp28pPQj65KvoqR8KMEujdYtkugpXd03ZbLOzYcty\n9RXWf29K0BTmb1AcQjqcv4Ciq8Cix4tA6jD3nnuztrrELOmJ5U3pM0ebQystAyoz\nrYZhpdjIynlCcHACoG5dZPS36mhiPYVpAfIcUY2K/zPmLIgwZrsvAl8hRltuClxF\n8ZzWeY04RoXMpOLw6W8l/Yz6d+ioRZxifFt9t3ZvXnI9X6SZQ9rmQi5ii0gF1+xp\nrbrBfmhUTItFLmI1aDUiPWGTLQtwXJcqZdygyCYCSQBVKWT2hX2lW8T7WkXBM6+i\nxdUCAwEAAaNGMEQwIwYDVR0RBBwwGoIYcHA5LXRlc3QtYWRtaW4xLml0LnN1LnNl\nMB0GA1UdDgQWBBTyDEsz2V7ggY9hxIDkjnnlf26n4TANBgkqhkiG9w0BAQUFAAOC\nAQEAGL1UqHFcCT2hJXpot4U8mw6UZjTZdX9tuaMPrl8UrkWG+EJZFUo8nrpH8Pbk\nuwdugFiMmSOwXQoAEB7wKvgQJ/Tbkdw+OIIT62FYXPdEquDuOTeuM8reXN49ZVfO\nbz4duBx6ui5e0o9XdMyxjJpML1kNzrNRJJ9KeKptFfA9Zw0KGjkwTyGDdDlpvd6Z\nSQQJB5ysqsYR9Eq3kkRn7H5hO02Xu+J1EDgC/c0XBSXT9OerLozjUgGuGDI6bsCi\nq1cJ9OonqjbI45FgVw8ubcuDl1SCfN2zVNjZ27ZvRqyzxAl4xa5Bkh6QDhNqbaMd\nHXJSWiUzSKMrriekzJ2y2Pkqng=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=pp9-test-admin1.it.su.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://pp-test-admin.it.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://pp-test-admin.it.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pp-test-admin.it.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://pp-test-admin.it.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://pp-test-admin.it.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://pp-test-admin.it.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pp-test-admin.it.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://pp-test-admin.it.su.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://pp-test-admin.it.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://pp-test-admin.it.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://app-ca.tophat.com/sso/shibboleth/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@tophat.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Green"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:brennen@tophat.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brennan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jones"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:josh@tophat.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Josh"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://app-ca.tophat.com/sso/shibboleth/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-03-22T12:47:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Top Hat"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tophat.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Top Hat Monocle"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://app-ca.tophat.com/sso/shibboleth/slo",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Top Hat Classroom Response System"
                  }
                ],
                "logo": [
                  {
                    "text": "https://s3.amazonaws.com/thm-corporate/tophat-logo-blue.png",
                    "height": "30",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "110"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Top Hat"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBTCCAe2gAwIBAgIJAJBdLHPlzYOPMA0GCSqGSIb3DQEBBQUAMBUxEzARBgNV\n\t\t\t\t\t\tBAMTCnRvcGhhdC5jb20wHhcNMTQxMDE2MTg0OTU4WhcNMjQxMDEzMTg0OTU4WjAV\n\t\t\t\t\t\tMRMwEQYDVQQDEwp0b3BoYXQuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAtJvhoZ3zRb7UbxCE+NNCxTtUMwunQPa06R+JmvuYZdSOGwPW6W5ff3NE\n\t\t\t\t\t\tJm7S/EzcnXNeQLEdSombqATN5gOIo4vFfTpwBW/P5syvc0EBphXvoqkLeJcPrMm3\n\t\t\t\t\t\tCR0QMerSe7i8xMXc/2o80aKHw5Cl99/ujvamrF6B+n4LbSi/Eo78G9JGIEFhOYYz\n\t\t\t\t\t\t3UsGrm3b+pS9tn9NQXoCAL/YfUc70LV+CdKrxtW/psQMGjmbvR3saSnVoimyEcUq\n\t\t\t\t\t\tdOhpyfYnVjNZsIANE/PoG4TYYU0zetTao5PD47mRIQ81FNxlXz2fg2LCzb8h06CU\n\t\t\t\t\t\tRi4NFAI7hBlZpQe+WhptkBa+gt5qgwIDAQABo1gwVjA1BgNVHREELjAsggp0b3Bo\n\t\t\t\t\t\tYXQuY29thh51cm46bWFjZTp1bXUuc2U6c2FtbDp0b3BoYXQ6c3AwHQYDVR0OBBYE\n\t\t\t\t\t\tFEN/h+ezcP/7CqNsqgpTxRWvbwTNMA0GCSqGSIb3DQEBBQUAA4IBAQCQmBmsKvMr\n\t\t\t\t\t\t/PZVvszcGM9Ea/PulcPp0BbAHAdjaiFiw0SQkyaEY9fLi8yWOb/Gy0TVAGLxwBY7\n\t\t\t\t\t\tdm6VZnVPxhvxL0RBswpJxs1XK4LYL0oj0ZHCHdQRktOBmuZ/rfkVheEBv8ek0sy5\n\t\t\t\t\t\tshomaKJuTBEQd06ZeRZl71IUn6ytyUAp1ZCw3+bKh0cYYNzEYsd5PEq7yaG0tNTR\n\t\t\t\t\t\tZ1eDZ10E6yP+f7eCFegs9qutMyxLhvefdGt2t4GvK4kbhjBRDAQwrAnXMixVkUkr\n\t\t\t\t\t\tDsQPDtPsT1ONS2VZMmtQir8qUybJV5BfREoepLCOMIAbCRrRM0dQKK9C0HVXsNe3\n\t\t\t\t\t\tF3yzDCsg02aQ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBTCCAe2gAwIBAgIJAJBdLHPlzYOPMA0GCSqGSIb3DQEBBQUAMBUxEzARBgNV\n\t\t\t\t\t\tBAMTCnRvcGhhdC5jb20wHhcNMTQxMDE2MTg0OTU4WhcNMjQxMDEzMTg0OTU4WjAV\n\t\t\t\t\t\tMRMwEQYDVQQDEwp0b3BoYXQuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAtJvhoZ3zRb7UbxCE+NNCxTtUMwunQPa06R+JmvuYZdSOGwPW6W5ff3NE\n\t\t\t\t\t\tJm7S/EzcnXNeQLEdSombqATN5gOIo4vFfTpwBW/P5syvc0EBphXvoqkLeJcPrMm3\n\t\t\t\t\t\tCR0QMerSe7i8xMXc/2o80aKHw5Cl99/ujvamrF6B+n4LbSi/Eo78G9JGIEFhOYYz\n\t\t\t\t\t\t3UsGrm3b+pS9tn9NQXoCAL/YfUc70LV+CdKrxtW/psQMGjmbvR3saSnVoimyEcUq\n\t\t\t\t\t\tdOhpyfYnVjNZsIANE/PoG4TYYU0zetTao5PD47mRIQ81FNxlXz2fg2LCzb8h06CU\n\t\t\t\t\t\tRi4NFAI7hBlZpQe+WhptkBa+gt5qgwIDAQABo1gwVjA1BgNVHREELjAsggp0b3Bo\n\t\t\t\t\t\tYXQuY29thh51cm46bWFjZTp1bXUuc2U6c2FtbDp0b3BoYXQ6c3AwHQYDVR0OBBYE\n\t\t\t\t\t\tFEN/h+ezcP/7CqNsqgpTxRWvbwTNMA0GCSqGSIb3DQEBBQUAA4IBAQCQmBmsKvMr\n\t\t\t\t\t\t/PZVvszcGM9Ea/PulcPp0BbAHAdjaiFiw0SQkyaEY9fLi8yWOb/Gy0TVAGLxwBY7\n\t\t\t\t\t\tdm6VZnVPxhvxL0RBswpJxs1XK4LYL0oj0ZHCHdQRktOBmuZ/rfkVheEBv8ek0sy5\n\t\t\t\t\t\tshomaKJuTBEQd06ZeRZl71IUn6ytyUAp1ZCw3+bKh0cYYNzEYsd5PEq7yaG0tNTR\n\t\t\t\t\t\tZ1eDZ10E6yP+f7eCFegs9qutMyxLhvefdGt2t4GvK4kbhjBRDAQwrAnXMixVkUkr\n\t\t\t\t\t\tDsQPDtPsT1ONS2VZMmtQir8qUybJV5BfREoepLCOMIAbCRrRM0dQKK9C0HVXsNe3\n\t\t\t\t\t\tF3yzDCsg02aQ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://app-ca.tophat.com/sso/shibboleth/acs",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Top Hat"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:ac.uk:sdss.ac.uk:provider:identity:shibboleth-i.sgul.ac.uk",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Carr"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kecarr@sgul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Keith"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Carr"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kecarr@sgul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Keith"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:ac.uk:sdss.ac.uk:provider:identity:shibboleth-i.sgul.ac.uk",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUAnlMK5UZoNDOL9nbtSWzA8/XR4cwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHDEaMBgGA1UEAxMRc2dzYTAxLnNndWwuYWMudWswHhcNMTMwNjExMDkyMTAy\n\t\t\t\t\t\tWhcNMzMwNjExMDkyMTAyWjAcMRowGAYDVQQDExFzZ3NhMDEuc2d1bC5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIp65woT8aiIkKpFnRy8WNIk\n\t\t\t\t\t\tGbO/EL0wJnYI7/AuGoCCPbvnxwAXoIqyNjSnzy82dTn82rZGlKQFL7pfZ/vq3Pxl\n\t\t\t\t\t\tPDn5mwF5VQYW17LunIhrj9JgnRuTxNW/XpsL74/hmeZwj859NmHA0HXQ+3T/kkS1\n\t\t\t\t\t\tBHD3V1uQBYTAHGpjJHe8E0p3sDRNjldx2negX7mhmde1D1CeSEcpaDpod4DTrc3W\n\t\t\t\t\t\tQ56/5tXTl6OrUYlHGyjzDlknrLNS8NyGRuY1vPXjaWJFesru3uRHI1FduWXgtY1F\n\t\t\t\t\t\ta0A5FBy4btrIixxPgSfrJehzkjLdF7eYAd+efJTuoRoLOeWA+kHGJof6+vqtQ4kC\n\t\t\t\t\t\tAwEAAaNpMGcwRgYDVR0RBD8wPYIRc2dzYTAxLnNndWwuYWMudWuGKGh0dHBzOi8v\n\t\t\t\t\t\tc2dzYTAxLnNndWwuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFMBNSmc4\n\t\t\t\t\t\t4s/YiTVkVD7VJ4AP/nlQMA0GCSqGSIb3DQEBBQUAA4IBAQAk/Ys37rY68WWcw9uj\n\t\t\t\t\t\tFNcSiG0jetWek4UHPajBN/CKwEqgIizvpjFNQdWp/BsMg1SF9ItzvsyhN6S+HoaD\n\t\t\t\t\t\tr6ndXU5h9vJTnOlbnE0aPMU0SC7Q5AZKjqtSx/OvyZ/sPG+OW08C70fsSQ5F7pj5\n\t\t\t\t\t\tZiEtvU8EPPeQo0XAekQjmZyoUpDqM+NfTCmaBSIXEgI1oUJrzrMFmY0cYzz3JDtD\n\t\t\t\t\t\tT8Ji+J5vBVFGESak+uKDq7dDV9ERia7sy5CxS15L9dxc3SPTBGkTyDjTEAEKsXa/\n\t\t\t\t\t\tAiV0PWB9+hLQl9kShgPPGnw7vMGXS9NXetdVS32t0K7XQm7BUuje9FqF+IWwGTDI\n\t\t\t\t\t\tqCZw"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sgul.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sgsa01.sgul.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sgsa01.sgul.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sgsa01.sgul.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sgsa01.sgul.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sgsa01.sgul.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sgsa01.sgul.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sgsa01.sgul.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sgsa01.sgul.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sgul.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://sgsa01.sgul.ac.uk/idp/images/sgul_logo_standard.png",
                    "height": "150",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "200"
                  },
                  {
                    "text": "https://sgsa01.sgul.ac.uk/idp/images/sgul_logo_small.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://sgsa01.sgul.ac.uk/idp/images/favicon.ico",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "St George's, University of London"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUAnlMK5UZoNDOL9nbtSWzA8/XR4cwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHDEaMBgGA1UEAxMRc2dzYTAxLnNndWwuYWMudWswHhcNMTMwNjExMDkyMTAy\n\t\t\t\t\t\tWhcNMzMwNjExMDkyMTAyWjAcMRowGAYDVQQDExFzZ3NhMDEuc2d1bC5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIp65woT8aiIkKpFnRy8WNIk\n\t\t\t\t\t\tGbO/EL0wJnYI7/AuGoCCPbvnxwAXoIqyNjSnzy82dTn82rZGlKQFL7pfZ/vq3Pxl\n\t\t\t\t\t\tPDn5mwF5VQYW17LunIhrj9JgnRuTxNW/XpsL74/hmeZwj859NmHA0HXQ+3T/kkS1\n\t\t\t\t\t\tBHD3V1uQBYTAHGpjJHe8E0p3sDRNjldx2negX7mhmde1D1CeSEcpaDpod4DTrc3W\n\t\t\t\t\t\tQ56/5tXTl6OrUYlHGyjzDlknrLNS8NyGRuY1vPXjaWJFesru3uRHI1FduWXgtY1F\n\t\t\t\t\t\ta0A5FBy4btrIixxPgSfrJehzkjLdF7eYAd+efJTuoRoLOeWA+kHGJof6+vqtQ4kC\n\t\t\t\t\t\tAwEAAaNpMGcwRgYDVR0RBD8wPYIRc2dzYTAxLnNndWwuYWMudWuGKGh0dHBzOi8v\n\t\t\t\t\t\tc2dzYTAxLnNndWwuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFMBNSmc4\n\t\t\t\t\t\t4s/YiTVkVD7VJ4AP/nlQMA0GCSqGSIb3DQEBBQUAA4IBAQAk/Ys37rY68WWcw9uj\n\t\t\t\t\t\tFNcSiG0jetWek4UHPajBN/CKwEqgIizvpjFNQdWp/BsMg1SF9ItzvsyhN6S+HoaD\n\t\t\t\t\t\tr6ndXU5h9vJTnOlbnE0aPMU0SC7Q5AZKjqtSx/OvyZ/sPG+OW08C70fsSQ5F7pj5\n\t\t\t\t\t\tZiEtvU8EPPeQo0XAekQjmZyoUpDqM+NfTCmaBSIXEgI1oUJrzrMFmY0cYzz3JDtD\n\t\t\t\t\t\tT8Ji+J5vBVFGESak+uKDq7dDV9ERia7sy5CxS15L9dxc3SPTBGkTyDjTEAEKsXa/\n\t\t\t\t\t\tAiV0PWB9+hLQl9kShgPPGnw7vMGXS9NXetdVS32t0K7XQm7BUuje9FqF+IWwGTDI\n\t\t\t\t\t\tqCZw"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "St George's, University of London"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sgul.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "St George's Hospital Medical School"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://se.timeedit.net/chalmers-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@evolvera.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TimeEdit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://se.timeedit.net/chalmers-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://se.timeedit.net/web/chalmers/db1/timeedit/ssoLogout/saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TimeEdit, utvecklat av Evolvera AB"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TimeEdit, developed by Evolvera AB"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TimeEdit f\u00f6r anst\u00e4llda och studenter vid Chalmers"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TimeEdit for employees and students Chalmers"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAggCCQDSfJxeKVOg3jANBgkqhkiG9w0BAQUFADBSMQswCQYDVQQGEwJTRTESMBAGA1UE\nBxQJR8O2dGVib3JnMRQwEgYDVQQKEwtUaW1lRWRpdCBBQjEZMBcGA1UEAxMQYXV0aC50aW1lZWRp\ndC5zZTAeFw0xMzA2MTQwNzE0MTlaFw0xNTA2MTQwNzE0MTlaMFIxCzAJBgNVBAYTAlNFMRIwEAYD\nVQQHFAlHw7Z0ZWJvcmcxFDASBgNVBAoTC1RpbWVFZGl0IEFCMRkwFwYDVQQDExBhdXRoLnRpbWVl\nZGl0LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoL+lyBleTM0UGwGPLXPcfBMr\nomnPqP8+qlE+rOs0mEbvNyXdEWT0Z5P/XoMVfERJQQ6v5DAJF4c3o1BiPshZL8cj6QdLuJXLfVNG\nu5mzq/lKpB/n38Y4cWYxIyNtBcV9vcKDIRUbQP/27nEPMsbs2IaCXf6V3l3yQqbymZTyd8nBfZZF\nG95zDKBTSD5UQ3XW+LbvjKSZY4qDjyFkeOfj8kVyltWTHRMvKTKGLeNrGyCFiaMY/vfyA22gOyz4\nO2cY/oqFs8+82AOs3Si4+eGkFAq3CdEWSE4c69oDrzEWk+bKgxw5qyhWQ/13eh8AiZMDeqhT7q32\nRthqEp8GfwPM1QIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCRsLvMI4OJ076STPIyxnwk6bXRG5RL\nMR1pJ3umMNCa1LR1RnH1feuvm9dxerUTow7bPIsarJarh0iEIj2kLtu/prPm+ZcAKeEjh27pSM7m\n1F0XBkDqeP1msR+7g0aHlt0MzrKm/Esb1JX9YCO3MHl1XFc8xSnv2bxKWvER+tmDWkFrC0y1u2+H\nB/CfyES8ntBP6F7aZ6UQ4GTrqF0MZNGBoWFyXecGe5XEwWJwP4otSrJ2q7cbQU33xEcri0dHiMMl\nTiN/6f25dSm5UFCxqWGGAQndGfn/tE5FSqJlrHnbF2M6x4eH3MEIbHebI+nJlk6ASPdgIssvsDcd\nGImnaeS4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://se.timeedit.net/web/chalmers/db1/timeedit/ssoResponse/saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "false"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://cafe-idp.ufc.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Federacao CAFe"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "federacao_cafe@sti.ufc.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe-idp.ufc.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFVjCCBD6gAwIBAgISESGwx2jv72u5M30bUGytllkYMA0GCSqGSIb3DQEBCwUA\nMIGpMQswCQYDVQQGEwJCUjEXMBUGA1UECBMOUmlvIGRlIEphbmVpcm8xFzAVBgNV\nBAcTDlJpbyBkZSBKYW5laXJvMSQwIgYDVQQLExtHZXJlbmNpYSBkZSBTZXJ2aWNv\ncyAoR1NlcikxMTAvBgNVBAoTKFJlZGUgTmFjaW9uYWwgZGUgRW5zaW5vIGUgUGVz\ncXVpc2EgLSBSTlAxDzANBgNVBAMTBklDUEVkdTAeFw0xNTAxMjkxODU2MDNaFw0x\nODAxMjkxODU2MDNaMHAxCzAJBgNVBAYTAkJSMQswCQYDVQQIEwJDRTESMBAGA1UE\nBxMJRm9ydGFsZXphMSYwJAYDVQQKEx1VTklWRVJTSURBREUgRkVERVJBTCBETyBD\nRUFSQTEYMBYGA1UEAxMPY2FmZS1pZHAudWZjLmJyMIIBIjANBgkqhkiG9w0BAQEF\nAAOCAQ8AMIIBCgKCAQEA5mmwq3ScV2FZL+AbZxcuOALuAp0dnETymHyJeXQ4OStE\nmRrdINtjjDRiSPMYVWAY10rllQw73sjmZ64Hlf/ER4RhqZIhBFIu4XKEvglKO5dP\nMI0uCVvz1RIx6zz4Zny9GmxCzVQF5gCI81vksduFdVrqsZ0sIqd0MUyx9D/57O3c\nYhvJh/KMctF+53NH+OkXwUH7CvhluRUFI9IjtKISSsMPlnZIpVhIolHmqW834Bfe\nL4m80VOT1oUwg5JjNL/BWRyM9enzwSP0wT+rZnlmgqo3udBoO2g7LcLQ2GabxPID\ndLANiQv60Vw58RD7dVyzT/73M2JHIsOuzmpCOnVdiwIDAQABo4IBrjCCAaowDgYD\nVR0PAQH/BAQDAgWgMEkGA1UdIARCMEAwPgYGZ4EMAQICMDQwMgYIKwYBBQUHAgEW\nJmh0dHBzOi8vd3d3Lmdsb2JhbHNpZ24uY29tL3JlcG9zaXRvcnkvMBoGA1UdEQQT\nMBGCD2NhZmUtaWRwLnVmYy5icjAJBgNVHRMEAjAAMB0GA1UdJQQWMBQGCCsGAQUF\nBwMBBggrBgEFBQcDAjA+BgNVHR8ENzA1MDOgMaAvhi1odHRwOi8vY3JsLmdsb2Jh\nbHNpZ24uY29tL2dzL2ljcGVkdXNoYTJnMi5jcmwwgYYGCCsGAQUFBwEBBHoweDBA\nBggrBgEFBQcwAoY0aHR0cDovL3NlY3VyZS5nbG9iYWxzaWduLmNvbS9jYWNlcnQv\naWNwZWR1c2hhMmcyLmNydDA0BggrBgEFBQcwAYYoaHR0cDovL29jc3AyLmdsb2Jh\nbHNpZ24uY29tL2ljcGVkdXNoYTJnMjAdBgNVHQ4EFgQUEcKIonX/zpNFnXfdkUYP\nMRdG7mEwHwYDVR0jBBgwFoAUlfCkhBqnXCA2psUI12VCAuV3aOMwDQYJKoZIhvcN\nAQELBQADggEBAEyWJQd7Q20jRhjUM3Ue+ySclvHDETUhgnEYcnnJAUeBtNlF/e2l\nTmV/jfzWDX1tkHkyJbDUZyCOvsmPyGgre5n8ZR42Jf9iJkeEqm3LDnvHrEO2LIDV\ndHyNFUeaVBvn3hvA/tvwdRvaSEzxUtVUQ2X+J/4z/38VUXYtufumZekm8D+L6Koe\n5bIDnlUKqHjO/25ph8xm7K5S3BjkL0fQwrEZImgTIEBhWPLnwVUaOPahMwUGeWf8\naGkhxUVPyqMyuAr0p2iujFM0X8kGWL9nJCAARH4f9rnJs2gOhphoSHpbAKZdtq4Z\n//f+GmXi7h7Buz4+dG0ibmbq8NCOoHJDdys="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufc.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe-idp.ufc.br/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe-idp.ufc.br/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe-idp.ufc.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe-idp.ufc.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe-idp.ufc.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe-idp.ufc.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe-idp.ufc.br/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe-idp.ufc.br/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufc.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufc.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufc.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFC - Universidade Federal do Ceara"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFC - Universidade Federal do Ceara"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFC - Universidade Federal do Ceara"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFC - Universidade Federal do Ceara"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFVjCCBD6gAwIBAgISESGwx2jv72u5M30bUGytllkYMA0GCSqGSIb3DQEBCwUA\nMIGpMQswCQYDVQQGEwJCUjEXMBUGA1UECBMOUmlvIGRlIEphbmVpcm8xFzAVBgNV\nBAcTDlJpbyBkZSBKYW5laXJvMSQwIgYDVQQLExtHZXJlbmNpYSBkZSBTZXJ2aWNv\ncyAoR1NlcikxMTAvBgNVBAoTKFJlZGUgTmFjaW9uYWwgZGUgRW5zaW5vIGUgUGVz\ncXVpc2EgLSBSTlAxDzANBgNVBAMTBklDUEVkdTAeFw0xNTAxMjkxODU2MDNaFw0x\nODAxMjkxODU2MDNaMHAxCzAJBgNVBAYTAkJSMQswCQYDVQQIEwJDRTESMBAGA1UE\nBxMJRm9ydGFsZXphMSYwJAYDVQQKEx1VTklWRVJTSURBREUgRkVERVJBTCBETyBD\nRUFSQTEYMBYGA1UEAxMPY2FmZS1pZHAudWZjLmJyMIIBIjANBgkqhkiG9w0BAQEF\nAAOCAQ8AMIIBCgKCAQEA5mmwq3ScV2FZL+AbZxcuOALuAp0dnETymHyJeXQ4OStE\nmRrdINtjjDRiSPMYVWAY10rllQw73sjmZ64Hlf/ER4RhqZIhBFIu4XKEvglKO5dP\nMI0uCVvz1RIx6zz4Zny9GmxCzVQF5gCI81vksduFdVrqsZ0sIqd0MUyx9D/57O3c\nYhvJh/KMctF+53NH+OkXwUH7CvhluRUFI9IjtKISSsMPlnZIpVhIolHmqW834Bfe\nL4m80VOT1oUwg5JjNL/BWRyM9enzwSP0wT+rZnlmgqo3udBoO2g7LcLQ2GabxPID\ndLANiQv60Vw58RD7dVyzT/73M2JHIsOuzmpCOnVdiwIDAQABo4IBrjCCAaowDgYD\nVR0PAQH/BAQDAgWgMEkGA1UdIARCMEAwPgYGZ4EMAQICMDQwMgYIKwYBBQUHAgEW\nJmh0dHBzOi8vd3d3Lmdsb2JhbHNpZ24uY29tL3JlcG9zaXRvcnkvMBoGA1UdEQQT\nMBGCD2NhZmUtaWRwLnVmYy5icjAJBgNVHRMEAjAAMB0GA1UdJQQWMBQGCCsGAQUF\nBwMBBggrBgEFBQcDAjA+BgNVHR8ENzA1MDOgMaAvhi1odHRwOi8vY3JsLmdsb2Jh\nbHNpZ24uY29tL2dzL2ljcGVkdXNoYTJnMi5jcmwwgYYGCCsGAQUFBwEBBHoweDBA\nBggrBgEFBQcwAoY0aHR0cDovL3NlY3VyZS5nbG9iYWxzaWduLmNvbS9jYWNlcnQv\naWNwZWR1c2hhMmcyLmNydDA0BggrBgEFBQcwAYYoaHR0cDovL29jc3AyLmdsb2Jh\nbHNpZ24uY29tL2ljcGVkdXNoYTJnMjAdBgNVHQ4EFgQUEcKIonX/zpNFnXfdkUYP\nMRdG7mEwHwYDVR0jBBgwFoAUlfCkhBqnXCA2psUI12VCAuV3aOMwDQYJKoZIhvcN\nAQELBQADggEBAEyWJQd7Q20jRhjUM3Ue+ySclvHDETUhgnEYcnnJAUeBtNlF/e2l\nTmV/jfzWDX1tkHkyJbDUZyCOvsmPyGgre5n8ZR42Jf9iJkeEqm3LDnvHrEO2LIDV\ndHyNFUeaVBvn3hvA/tvwdRvaSEzxUtVUQ2X+J/4z/38VUXYtufumZekm8D+L6Koe\n5bIDnlUKqHjO/25ph8xm7K5S3BjkL0fQwrEZImgTIEBhWPLnwVUaOPahMwUGeWf8\naGkhxUVPyqMyuAr0p2iujFM0X8kGWL9nJCAARH4f9rnJs2gOhphoSHpbAKZdtq4Z\n//f+GmXi7h7Buz4+dG0ibmbq8NCOoHJDdys="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFC - Universidade Federal do Ceara"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFC - Universidade Federal do Ceara"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufc.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufc.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFC - Universidade Federal do Ceara"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFC - Universidade Federal do Ceara"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://agenda.ct.infn.it/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fargetta"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:credentials-admin@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marco"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barbera"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:credentials-admin@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roberto"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://agenda.ct.infn.it/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2015-06-12T06:20:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Agenda erogata da INFN Catania"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Agenda provided by INFN Catania"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ct.infn.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ct.infn.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INFN Catania"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INFN Catania"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://agenda.ct.infn.it/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://agenda.ct.infn.it/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://agenda.ct.infn.it/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://agenda.ct.infn.it/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://agenda.ct.infn.it/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://agenda.ct.infn.it/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://agenda.ct.infn.it/service"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The service allows users to create and manage events, from single lectures to small meetings to project workshops to complex multi-session many-day conferences, including the registration of participants, the submission of abstracts/papers and the evaluation of contributions."
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Il servizio permette agli utenti di creare e gestire eventi come seminari, meeting, workshop e conferenze con sessioni multiple distribuite su pi\u00f9 giorni. Include moduli per la registrazione dei partecipanti, la sottomissione di abstract/articoli e la valutazione dei contributi"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://agenda.ct.infn.it/privacy-policy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Agenda provided by INFN Catania"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Agenda erogata da INFN Catania"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEbzCCA1egAwIBAgIQcBeCzWBBCds83fLXgAuSAjANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMTIxNzAwMDAwMFoXDTE2MTIxNjIzNTk1OVowPzEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRowGAYDVQQDExFhZ2VuZGEuY3Qu\naW5mbi5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALMFJxLvoJwG\nOFLjLpxlthfZUaqSC3+qQcwOaPrfFm++/H8of+Tx4NsjgVZjerEFVlhopy82VTRU\nvXRFrvwFh0rMngAVm91v3LhunrxxUel/w6PgTS3BhZ20SZCVCkwKNPz9RhXff0hq\nPQrny6w9wYyxyj3q13yePE9ko+mwl+C11nZB09P2RvvXbPoNcvUl6LvWtKQbRMWC\nB7HXTNxddLztQLQnh1yhp0ZflLmiGEEykFWghqzijIucWSZxKugd/DmHhxJQhHkd\nBF43+CzFcfdUubFLrU2BZ9/pSuvpayo43qHP0EJmIhZkpCqjIYkQJovWrmZ+n3rf\nJ2ve3EoK1T0CAwEAAaOCAW4wggFqMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdX\nR+qQ47ntMB0GA1UdDgQWBBTZMyBGdI6hJlZf/sNiL/domOmiMDAOBgNVHQ8BAf8E\nBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUH\nAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0fBDMw\nMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5j\ncmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50\nZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29j\nc3AudGNzLnRlcmVuYS5vcmcwHAYDVR0RBBUwE4IRYWdlbmRhLmN0LmluZm4uaXQw\nDQYJKoZIhvcNAQEFBQADggEBAATfPKKhvVoL2B0ce5BouD9hErF4MC2XxlJdrLJP\nXlOeFNWBBwxBM7FIM2fSTLpNTnc7OA0BPLXbadICSmfY5HdikNPvns9/aNrizr+j\npex1lYCY0uAwwsEauUxpJpPAe5+t9xD4URog0pIw21W95XTmSTyQoTtOhI506oqy\noJ8AUmOGoqwOg8ivuuVT2h7O8p4DQ6L8wczZW/W/IoCL+5aC/X7Y78j5Sq9/VQln\nzzDg3oMFoud4+0zxptfHSro23+L0uN2miOChuTyMmoNA5kVoh02h2irRHwJccJbK\nkJY22vXsTzKEv4WUZ/LwCqp5QrPy41LCTCsEsP8TVL/ktPc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEbzCCA1egAwIBAgIQcBeCzWBBCds83fLXgAuSAjANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMTIxNzAwMDAwMFoXDTE2MTIxNjIzNTk1OVowPzEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRowGAYDVQQDExFhZ2VuZGEuY3Qu\naW5mbi5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALMFJxLvoJwG\nOFLjLpxlthfZUaqSC3+qQcwOaPrfFm++/H8of+Tx4NsjgVZjerEFVlhopy82VTRU\nvXRFrvwFh0rMngAVm91v3LhunrxxUel/w6PgTS3BhZ20SZCVCkwKNPz9RhXff0hq\nPQrny6w9wYyxyj3q13yePE9ko+mwl+C11nZB09P2RvvXbPoNcvUl6LvWtKQbRMWC\nB7HXTNxddLztQLQnh1yhp0ZflLmiGEEykFWghqzijIucWSZxKugd/DmHhxJQhHkd\nBF43+CzFcfdUubFLrU2BZ9/pSuvpayo43qHP0EJmIhZkpCqjIYkQJovWrmZ+n3rf\nJ2ve3EoK1T0CAwEAAaOCAW4wggFqMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdX\nR+qQ47ntMB0GA1UdDgQWBBTZMyBGdI6hJlZf/sNiL/domOmiMDAOBgNVHQ8BAf8E\nBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUH\nAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0fBDMw\nMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5j\ncmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50\nZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29j\nc3AudGNzLnRlcmVuYS5vcmcwHAYDVR0RBBUwE4IRYWdlbmRhLmN0LmluZm4uaXQw\nDQYJKoZIhvcNAQEFBQADggEBAATfPKKhvVoL2B0ce5BouD9hErF4MC2XxlJdrLJP\nXlOeFNWBBwxBM7FIM2fSTLpNTnc7OA0BPLXbadICSmfY5HdikNPvns9/aNrizr+j\npex1lYCY0uAwwsEauUxpJpPAe5+t9xD4URog0pIw21W95XTmSTyQoTtOhI506oqy\noJ8AUmOGoqwOg8ivuuVT2h7O8p4DQ6L8wczZW/W/IoCL+5aC/X7Y78j5Sq9/VQln\nzzDg3oMFoud4+0zxptfHSro23+L0uN2miOChuTyMmoNA5kVoh02h2irRHwJccJbK\nkJY22vXsTzKEv4WUZ/LwCqp5QrPy41LCTCsEsP8TVL/ktPc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://agenda.ct.infn.it/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://agenda.ct.infn.it/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://agenda.ct.infn.it/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://agenda.ct.infn.it/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://agenda.ct.infn.it/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://agenda.ct.infn.it/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Agenda provided by INFN Catania"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Agenda erogata da INFN Catania"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The service allows users to create and manage events, from single lectures to small meetings to project workshops to complex multi-session many-day conferences, including the registration of participants, the submission of abstracts/papers and the evaluation of contributions."
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Il servizio permette agli utenti di creare e gestire eventi come seminari, meeting, workshop e conferenze con sessioni multiple distribuite su pi\u00f9 giorni. Include moduli per la registrazione dei partecipanti, la sottomissione di abstract/articoli e la valutazione dei contributi"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.iadt.ie/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Syed"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:arif.syed@iadt.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Arif"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hennessy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:colm.hennessy@iadt.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Colm"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Coen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:maurice.coen@iadt.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Maurice"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.iadt.ie/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2011-10-18T00:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.iadt.ie/idp/logout.jsp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.iadt.ie/idp/logout.jsp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.iadt.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.iadt.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.iadt.ie/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iadt.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.iadt.ie"
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/iadt.png",
                    "height": "101",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "151"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Dun Laoghaire Institute of Art Design and Technology"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.2802499,-6.1539366"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVALmq0aeEnY2koINV+tGCDu0kV09pMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2lkcC5pYWR0LmllMB4XDTA5MDQwODE0NDAyMFoXDTI5\nMDQwODE0NDAyMFowFjEUMBIGA1UEAxMLaWRwLmlhZHQuaWUwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCPkswyC6jeXgUJzMGhx7QlixYHq4Rqh4KBPlxH\nIpv4bd3/GfkoZs2avpxD75ksEzNsAbTlq7QyiqVaPB4MXo85NqV5e2xt2NexCmxn\nlEYjtqTkgU83lOPSmu4dQDKhXfoK5ZSoSd9d8BgfmRKQNgr3UdIs0pcVTcRbG+Yz\nJPLyTgewKNdRD1BvimaxbDvjBXxTpGo3KEtv4tEWuVqlo+yqQkFawF11xnNtmLzH\nhub9/GxMdLEySuJIsvfLmawpsoV7Kp6mr9onMPSl/k9x+7dG2b2FSc8blPN6NiPO\nIMs5Dig4OXW6O9N5WsOXNVa7MtpK02t69FlKOm1BjZo6ytIvAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2lkcC5pYWR0LmllhiJodHRwczovL2lkcC5pYWR0LmllL2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBS1GPf9ZZNOFL9/cO4deMgQC/hoXTANBgkqhkiG\n9w0BAQUFAAOCAQEAZEfSyT4N9goj8oSV8NL0B8pXIKyVBZBoE6id+B47VVv7u1vC\naDHKArulvZPR43lzFx2q6lHclHj2PeNzUgx10ZUrrsXxOd+2FUG8ExaKiMv/F3/w\nApcMs8kQehlArgcwqVTzGqqZ1+FtMfVDyGS5AX/tZHo4frzFJlcqyKYgnrKTueEi\n2Ytjlo3VTd3RMwTBG2D2PmhoO/Q461J3WYD5IuFZ8a83HZOIXE5mXYx3vBJCxD5s\n6IJk9cDYR07yL/pz7pOLDYcKoo1/lNVMA4IXVzCnXOOrE29pL249ewOlHBX3meoy\nQrq4WvN81X5uUTN6qJPlL6wd+mT+LsrZPH+zyw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Dun Laoghaire Institute of Art Design and Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iadt.ie"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Dun Laoghaire Institute of Art Design and Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.uco.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lucas Joachim"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "joachim.lucas@uco.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Zoundi Patrick"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "patrick.zoundi@uco.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.uco.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2010-07-09T14:39:03Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.uco.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.uco.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://www.uco.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uco.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uco.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 Catholique de l'Ouest - Angers"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 Catholique de l'Ouest - Angers"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAPhF6Z+pMtMAffPTgC8LNS+CPPoMMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCnd3dy51Y28uZnIwHhcNMTEwNzIwMTQyMzUwWhcNMzEw\nNzIwMTQyMzUwWjAVMRMwEQYDVQQDEwp3d3cudWNvLmZyMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA0mhB2HdGNn2tfVrT9ciREesIHvTSoXnI6AQpqD9K\nLlB7bIjUX9EyfVXlg2fvcJYyfGeuQL1mbK0bXuM0AUX4aO3kf5vrtVLO0npQSuE4\nreAThATYtCsor30uTOb8YcCANJ0OcnN8jm+GgZmroUIakyl2RRPMtuc+RBx8lnh4\nN+Tac1OssR1Zdx8peAtV0MvXoC6hy5/Rp1i1/QiKX4QHQh85GMPG5wANRpag4U+9\nFPhRikDdwMH+gYyTY2zcAYxdyRJNK1dKtYVSSlW+JoX0JgL8vOcC+H5lHsDpHjK1\ny0k39zeVSURgOxu7U04ZPNclt4qYo6MHi7Gc+LLtyoO7zwIDAQABo1swWTA4BgNV\nHREEMTAvggp3d3cudWNvLmZyhiFodHRwczovL3d3dy51Y28uZnIvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFD9XAALJ3NCu1Z7q/lcamqo6vefAMA0GCSqGSIb3DQEB\nBQUAA4IBAQCKoc/CFYtJwGptZuJYo9da4NQ2jk2FvqX5o0AyT7cmimU8tj1B41m9\nDkVjwq2HPeTbcDUoECZJFoisIaQOuoxXxSvA8yYTtgBYUQEvqMOwLG+9cCjkT7V9\nhw9qQmD0JVSknJslFuLoqn88bodKPJE1u7Sgfk/huMEZItLBG/6EMKCINuN+nLt3\nMk7/mIJoHFhYEh81ZVlwKHPGmZ/ST8Y0GXeH95nO3BuuFp6cWgE7Eu4u9XiF5Ice\nN4chOWs7G4bomBuESzkGeydsJjWl7WmhuoKqfTV5V6W+hsBnkXGG4cpfB9R3Du+v\n0m1zBj8dwon9dDvWHf2On3KrRYbYl2Ff"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 Catholique de l'Ouest - Angers"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uco.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 Catholique de l'Ouest - Angers"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://janus.cnrs.fr/idp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dsichangement@dsi.cnrs.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://janus.cnrs.fr/idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-10-02T14:55:56Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://janus.cnrs.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://janus.cnrs.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://janus.cnrs.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cnrs.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.dsi.cnrs.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CNRS IDP server"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Serveur IDP du CNRS"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CNRS"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CNRS"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUcyCcvrPE6sFdJyVsCKfKmZg0/70wDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNamFudXMuY25ycy5mcjAeFw0xNDA2MTYyMTA1MDZaFw0y\nNDA2MTYyMTA1MDZaMBgxFjAUBgNVBAMTDWphbnVzLmNucnMuZnIwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCAQ7NtsTYjE/tTo9LM8y7AUlqejU6lpiph\ndW2yR2Ii7Xcm+niy+F4sjy3OoSt83Osuu1SXb/Cp2BZ8Spw3EMzSAKI0T9sIq4/F\nePspMLRThXW6cQLgUYekICh4H9ZQBU/luTS6ekTB3IgUPAFiiwFw8idC7KBc3OR8\nIDng0iOZSWejKahELmPWh6KeXj6SShPwdYiRMHZgCS2Sijzsv53tlQPm88nO0aQf\n6aEe5wXZqoAF1pkL6VhNo1R9pf7Wl4uiRvyiojflr09Pg3GsEOZg342J8PSIBQzJ\n+do/BNT7bWRsX2yEyX0PoieFpTMNz/Y6+IVMUrhZn2+n1X2iEtOxAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDWphbnVzLmNucnMuZnKGJGh0dHBzOi8vamFudXMuY25ycy5m\nci9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUy/9dd6btq/teyttwa2YjbrSnQ/ow\nDQYJKoZIhvcNAQEFBQADggEBAGWm6W+fJ6dQ0cHFcg1S8haiBQnGTcdWF17YXyYG\nWuiFFBX4RXuhoRyu0aWxcw7THdHP19/K3+lAueFPBCG6K7qz9gtvf4ZWJWWLq0jQ\nz9uNdB09xLWTleRe7c4ptCaQ/nU07ZibFHVXIGT2zZOODBXIiWsiXchH56D4TN0Z\nbKQsdICU4/Q+thqPKtYHL5T3leyJKCoEQC0o7jZ2q7T2SF6j7d7kwoa58qopcMTz\nJ9FdzyFEdepofr6Cj3sQu4nA28iAc91t0ZYvTbbrFu1KBby90rPH1p4+xLV42/Fy\nwPrS8Iosd99N9HZcyPWEuGXeoFyLRK8VArJPtD6f2ZHusXQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CNRS"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dsi.cnrs.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CNRS"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://pp-prod-admin.it.su.se/Shibboleth.sso",
    {
      "entity_id": "https://pp-prod-admin.it.su.se/Shibboleth.sso",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://pp-prod-admin.it.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://pp-prod-admin.it.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pp-prod-admin.it.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://pp-prod-admin.it.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://pp-prod-admin.it.su.se/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://pp-prod-admin.it.su.se/Shibboleth.sso/WAYF/wavelan",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "pp9-prod-admin1.it.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAP8sLfGcmOsKMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\nBAMTGHBwOS1wcm9kLWFkbWluMS5pdC5zdS5zZTAeFw0xMDAzMjQxNDI3NDZaFw0y\nMDAzMjExNDI3NDZaMCMxITAfBgNVBAMTGHBwOS1wcm9kLWFkbWluMS5pdC5zdS5z\nZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN46VBP4Q6f64DXTcKyC\nFIiKOP8CoTJy20kwZiizykrePVnSyZfAms8Zgksy2NlzLfpvDSD+wk37BbDPn1jA\n8suMqozWIFXLb+/DtT+MLmpaHOVE8vPKTHUPNh6dT4F8eOU4fBX5Ug+QYgmbWBUg\nUPuAyjyRIuV26kN0goFV7DQvuDzUoaOUEpGKu8Tt7pHOd7XFUB1ygN8cuozrCq7O\n/JLzOC2rPJR2UGmll+1f7AcJj43/ZTc05iNZQzKBZQRFUNlUElZHwDcmBZv8LNNx\nBC7tq5wzsFX51r6sW43hV7VFs9RYkWvO7lQ8lLaHa/kunM/FkmDkJEUi9TkdQJXl\nZMUCAwEAAaNGMEQwIwYDVR0RBBwwGoIYcHA5LXByb2QtYWRtaW4xLml0LnN1LnNl\nMB0GA1UdDgQWBBR/UfLUcj9RRmh5gSsPauIy0Ytn5zANBgkqhkiG9w0BAQUFAAOC\nAQEAU07b1XSnv4SfdqKprvAqpP/4zCArsdJyOy+nBI03r9KRBxu1eU2zuVgg9DJ6\nu/nc+176NUFRta9BwOJ53ioffGkVep/8P4g3HLp/EtpxJpycgIweJ62Ydo8JOAzO\nMJXHSjF8CqVQse22yntqU43cQuDwQB3VF5+un2gvJ34al942iqz1CnRTRsSFF6Dg\nGkfLyE/a/WBCcaQYdjI3ZSOyDrH8qDqVx9zzgYdILFHC3/9Ed+0mkV7VqvAeSsFb\nyogOGjGfiq+FxU4S3pDLXKObqfMiGTnVF6HgKD1a/F6yk6iypZjpO1hG7cfQP2bC\n3kwqqXGjzwCQvYBoTqQwTDdO3A=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=pp9-prod-admin1.it.su.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "pp9-prod-admin1.it.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAP8sLfGcmOsKMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\nBAMTGHBwOS1wcm9kLWFkbWluMS5pdC5zdS5zZTAeFw0xMDAzMjQxNDI3NDZaFw0y\nMDAzMjExNDI3NDZaMCMxITAfBgNVBAMTGHBwOS1wcm9kLWFkbWluMS5pdC5zdS5z\nZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN46VBP4Q6f64DXTcKyC\nFIiKOP8CoTJy20kwZiizykrePVnSyZfAms8Zgksy2NlzLfpvDSD+wk37BbDPn1jA\n8suMqozWIFXLb+/DtT+MLmpaHOVE8vPKTHUPNh6dT4F8eOU4fBX5Ug+QYgmbWBUg\nUPuAyjyRIuV26kN0goFV7DQvuDzUoaOUEpGKu8Tt7pHOd7XFUB1ygN8cuozrCq7O\n/JLzOC2rPJR2UGmll+1f7AcJj43/ZTc05iNZQzKBZQRFUNlUElZHwDcmBZv8LNNx\nBC7tq5wzsFX51r6sW43hV7VFs9RYkWvO7lQ8lLaHa/kunM/FkmDkJEUi9TkdQJXl\nZMUCAwEAAaNGMEQwIwYDVR0RBBwwGoIYcHA5LXByb2QtYWRtaW4xLml0LnN1LnNl\nMB0GA1UdDgQWBBR/UfLUcj9RRmh5gSsPauIy0Ytn5zANBgkqhkiG9w0BAQUFAAOC\nAQEAU07b1XSnv4SfdqKprvAqpP/4zCArsdJyOy+nBI03r9KRBxu1eU2zuVgg9DJ6\nu/nc+176NUFRta9BwOJ53ioffGkVep/8P4g3HLp/EtpxJpycgIweJ62Ydo8JOAzO\nMJXHSjF8CqVQse22yntqU43cQuDwQB3VF5+un2gvJ34al942iqz1CnRTRsSFF6Dg\nGkfLyE/a/WBCcaQYdjI3ZSOyDrH8qDqVx9zzgYdILFHC3/9Ed+0mkV7VqvAeSsFb\nyogOGjGfiq+FxU4S3pDLXKObqfMiGTnVF6HgKD1a/F6yk6iypZjpO1hG7cfQP2bC\n3kwqqXGjzwCQvYBoTqQwTDdO3A=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=pp9-prod-admin1.it.su.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://pp-prod-admin.it.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://pp-prod-admin.it.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pp-prod-admin.it.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://pp-prod-admin.it.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://pp-prod-admin.it.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://pp-prod-admin.it.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pp-prod-admin.it.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://pp-prod-admin.it.su.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://pp-prod-admin.it.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://pp-prod-admin.it.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.bca.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ricketts"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cricketts@bca.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Prior"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:NCPrior@bca.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Neil"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.bca.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-03-07T14:59:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDfjCCAmYCCQDx7t/Xm+vk2jANBgkqhkiG9w0BAQsFADCBgDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEjAQBgNVBAgMCUJlcmtzaGlyZTETMBEGA1UEBwwKTWFpZGVuaGVhZDEpMCcG\n\t\t\t\t\t\tA1UECgwgQmVya3NoaXJlIENvbGxlZ2Ugb2YgQWdyaWN1bHR1cmUxHTAbBgNVBAMM\n\t\t\t\t\t\tFHNoaWJib2xldGguYmNhLmFjLnVrMB4XDTE1MDExNTEwMjA1OVoXDTM1MDExMDEw\n\t\t\t\t\t\tMjA1OVowgYAxCzAJBgNVBAYTAkdCMRIwEAYDVQQIDAlCZXJrc2hpcmUxEzARBgNV\n\t\t\t\t\t\tBAcMCk1haWRlbmhlYWQxKTAnBgNVBAoMIEJlcmtzaGlyZSBDb2xsZWdlIG9mIEFn\n\t\t\t\t\t\tcmljdWx0dXJlMR0wGwYDVQQDDBRzaGliYm9sZXRoLmJjYS5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBALmriTHAnzTh0koWNhcZeqWl1VkHR+wi\n\t\t\t\t\t\t0w6zWxI3961lmUJbfu9md/HZT6wTzoTxiIUPq1CS11zgkUuDybtNc3JHUojHtArw\n\t\t\t\t\t\tLHw/PgRaDZaPZMpqEf7zsRR7ouytPw9XqhVD4XJLWSQMYpHlvHB7rE1sLVb6j9dA\n\t\t\t\t\t\th5niM+6kmd3iozcDcVENptYeNxwuZwKk6BfMT9PgpWCYB0SvfgYdMPGC3VJ0VgPw\n\t\t\t\t\t\tNrNeI0IKRyl7Lj0g6h8HUfl0C4sVcf+PXnzD0iLzaEmra1fBWV3Yy7E+E7N7NqwW\n\t\t\t\t\t\tTCNTNiRO2lBbddVjtaRYVcj4RyxsESJ3dwAT8iojFTYYW8/ZH7l4JWcCAwEAATAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQsFAAOCAQEABU3bhbpaCtOrumoaBklKmVhZTrpuo1T9SGHMA6yO\n\t\t\t\t\t\tGjd+E5ZFgNQp3CYO0nDikmQX5QFIxnW+tVpC/fsC/zaNxj4WqYSP4+Ufv6vg2wiY\n\t\t\t\t\t\tKX4rkZ8a6kRvTprxFwrrXySL4l9b7Y/3gNco5Pqm38x3QUp/D4jfI5kzTyxnQjaR\n\t\t\t\t\t\tX7DQsNjtE8jJQMzY4q+fazQ0xcgVtYP8Hyr5zw6Pm83IbTUjHSsQt8DKA6N4lHKY\n\t\t\t\t\t\tg6jq1rxI6gl+gQh+D35UoNrGcjo2xdS0xqcKLNLdlHJe/WmVvr5lZORTj5rQxKr6\n\t\t\t\t\t\t85G9KyAB1Ly2q4Vohbob+kcEb/5qtjq2hjgfMZbOGKj1ZA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bca.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.bca.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.bca.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.bca.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.bca.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.bca.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.bca.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.bca.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.bca.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bca.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDfjCCAmYCCQDx7t/Xm+vk2jANBgkqhkiG9w0BAQsFADCBgDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEjAQBgNVBAgMCUJlcmtzaGlyZTETMBEGA1UEBwwKTWFpZGVuaGVhZDEpMCcG\n\t\t\t\t\t\tA1UECgwgQmVya3NoaXJlIENvbGxlZ2Ugb2YgQWdyaWN1bHR1cmUxHTAbBgNVBAMM\n\t\t\t\t\t\tFHNoaWJib2xldGguYmNhLmFjLnVrMB4XDTE1MDExNTEwMjA1OVoXDTM1MDExMDEw\n\t\t\t\t\t\tMjA1OVowgYAxCzAJBgNVBAYTAkdCMRIwEAYDVQQIDAlCZXJrc2hpcmUxEzARBgNV\n\t\t\t\t\t\tBAcMCk1haWRlbmhlYWQxKTAnBgNVBAoMIEJlcmtzaGlyZSBDb2xsZWdlIG9mIEFn\n\t\t\t\t\t\tcmljdWx0dXJlMR0wGwYDVQQDDBRzaGliYm9sZXRoLmJjYS5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBALmriTHAnzTh0koWNhcZeqWl1VkHR+wi\n\t\t\t\t\t\t0w6zWxI3961lmUJbfu9md/HZT6wTzoTxiIUPq1CS11zgkUuDybtNc3JHUojHtArw\n\t\t\t\t\t\tLHw/PgRaDZaPZMpqEf7zsRR7ouytPw9XqhVD4XJLWSQMYpHlvHB7rE1sLVb6j9dA\n\t\t\t\t\t\th5niM+6kmd3iozcDcVENptYeNxwuZwKk6BfMT9PgpWCYB0SvfgYdMPGC3VJ0VgPw\n\t\t\t\t\t\tNrNeI0IKRyl7Lj0g6h8HUfl0C4sVcf+PXnzD0iLzaEmra1fBWV3Yy7E+E7N7NqwW\n\t\t\t\t\t\tTCNTNiRO2lBbddVjtaRYVcj4RyxsESJ3dwAT8iojFTYYW8/ZH7l4JWcCAwEAATAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQsFAAOCAQEABU3bhbpaCtOrumoaBklKmVhZTrpuo1T9SGHMA6yO\n\t\t\t\t\t\tGjd+E5ZFgNQp3CYO0nDikmQX5QFIxnW+tVpC/fsC/zaNxj4WqYSP4+Ufv6vg2wiY\n\t\t\t\t\t\tKX4rkZ8a6kRvTprxFwrrXySL4l9b7Y/3gNco5Pqm38x3QUp/D4jfI5kzTyxnQjaR\n\t\t\t\t\t\tX7DQsNjtE8jJQMzY4q+fazQ0xcgVtYP8Hyr5zw6Pm83IbTUjHSsQt8DKA6N4lHKY\n\t\t\t\t\t\tg6jq1rxI6gl+gQh+D35UoNrGcjo2xdS0xqcKLNLdlHJe/WmVvr5lZORTj5rQxKr6\n\t\t\t\t\t\t85G9KyAB1Ly2q4Vohbob+kcEb/5qtjq2hjgfMZbOGKj1ZA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Berkshire College of Agriculture"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bca.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Berkshire College of Agriculture"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.cced.cranfield.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cced.cranfield.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-07-04T15:41:49Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/cced.cranfield.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/cced.cranfield.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cced.cranfield.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cranfield University SoM Executive Development"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cranfield.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://involvio.com/saml",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ari@involvio.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ari Winkleman"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ari@involvio.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ari Winkleman"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ari@involvio.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ari Winkleman"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ari@involvio.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ari Winkleman"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://involvio.com/saml",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Involvio"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://involvio.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Involvio"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://involvio.com/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://involvio.com"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Involvio"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Involvio is a student engagement platform"
                  }
                ],
                "logo": [
                  {
                    "text": "https://s3.amazonaws.com/involvio-production/involvio.png",
                    "lang": "en",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "319"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://involvio.com/privacy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFUDCCBDigAwIBAgIQCC0M0Kc2/YNjE4dQDyg+EzANBgkqhkiG9w0BAQsFADCB\nkDELMAkGA1UEBhMCR0IxGzAZBgNVBAgTEkdyZWF0ZXIgTWFuY2hlc3RlcjEQMA4G\nA1UEBxMHU2FsZm9yZDEaMBgGA1UEChMRQ09NT0RPIENBIExpbWl0ZWQxNjA0BgNV\nBAMTLUNPTU9ETyBSU0EgRG9tYWluIFZhbGlkYXRpb24gU2VjdXJlIFNlcnZlciBD\nQTAeFw0xNTExMTcwMDAwMDBaFw0xODAyMTQyMzU5NTlaMFoxITAfBgNVBAsTGERv\nbWFpbiBDb250cm9sIFZhbGlkYXRlZDEcMBoGA1UECxMTQ09NT0RPIFNTTCBXaWxk\nY2FyZDEXMBUGA1UEAwwOKi5pbnZvbHZpby5jb20wggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDjzjTs8dOiIjzEvl98qBzWE/ppFyPDHV1SAmIkb9xitP0t\nxr6hsuZ+UM+m2Q+L2EdD/0dbombUDUtDuqK1Zq5jYDb+y6pk1A4w0JdaJQTBPjBu\nojk0AECw+l/+0zC9LzXdBnTyEpd4gYtzYZyKNukIiDbySOEgN/vpi5M0Ssh23Iyd\nzz72P4JoWSTCF9Rdncp+iksGFzwYRknKCoiZZNjjMoPs8oW5p6IkSp9SwDCOM+7s\nsRPhPOxOgtXiq/6hlCIa1fpRKhUoS7qqiN58wCa3P9KQNZ7uLiZz+z946KrpnLbl\nkcqi+CXXVtH4zjxfPpCGlB+pNq3lX+0+DGmS8j1JAgMBAAGjggHZMIIB1TAfBgNV\nHSMEGDAWgBSQr2o6lFoL2JDqElZz30O0Oija5zAdBgNVHQ4EFgQUPyRkwXM3rarn\nYCqtwjuAjLZtNXgwDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0l\nBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCME8GA1UdIARIMEYwOgYLKwYBBAGyMQEC\nAgcwKzApBggrBgEFBQcCARYdaHR0cHM6Ly9zZWN1cmUuY29tb2RvLmNvbS9DUFMw\nCAYGZ4EMAQIBMFQGA1UdHwRNMEswSaBHoEWGQ2h0dHA6Ly9jcmwuY29tb2RvY2Eu\nY29tL0NPTU9ET1JTQURvbWFpblZhbGlkYXRpb25TZWN1cmVTZXJ2ZXJDQS5jcmww\ngYUGCCsGAQUFBwEBBHkwdzBPBggrBgEFBQcwAoZDaHR0cDovL2NydC5jb21vZG9j\nYS5jb20vQ09NT0RPUlNBRG9tYWluVmFsaWRhdGlvblNlY3VyZVNlcnZlckNBLmNy\ndDAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AuY29tb2RvY2EuY29tMCcGA1UdEQQg\nMB6CDiouaW52b2x2aW8uY29tggxpbnZvbHZpby5jb20wDQYJKoZIhvcNAQELBQAD\nggEBAAjlGQXfaBd54KeICKV1LTcsoMlC35yAyPPTaRFAQdGuOZKYjYjPzdY8wc84\nPvi2Il8beElLRbj26mth9jxvMDSr4F7kGVoQJ1ZN8xOh+zzNUYBECXxIX7G9DdWm\nMY5fYqAf+oHuuIhbvnjdG0A1xrQIP3X1yk577aYjTYti9hD0reN3ZDrp4JzYe+YG\njP/CprjIL/d7DaruZFiSmnfUa1FeOryhuKzbqcm6GpV0tzfsNT47kpngsTtTK1Cy\n4+OA7UVWic/3LCX+lQkFzRWGgvOikUp1phZ18NFpS3ak/c7H3teur2CFfpWTKdxz\nGF977KpzHlIAUY/y8JmOWhaTjR0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://involvio.com/saml/acs",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Involvio"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Involvio is a student engagement platform"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "o",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:incommon:virginia.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ehc@Virginia.EDU"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hamp Carruth"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "systems@virginia.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ITC Unix Systems"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "systems@virginia.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Systems Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "incommon-admin@virginia.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UVa InCommon Admin"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:virginia.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.its.virginia.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.its.virginia.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIVALIs8V8u06NEcoiPKqBdTWQ5F3WdMA0GCSqGSIb3DQEB\nBQUAMCMxITAfBgNVBAMTGHNoaWJpZHAuaXRzLnZpcmdpbmlhLmVkdTAeFw0xMjAz\nMDIxNTI2MDNaFw0zMjAzMDIxNTI2MDNaMCMxITAfBgNVBAMTGHNoaWJpZHAuaXRz\nLnZpcmdpbmlhLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMz9\n8k0PGFjm33ceTUVhpw4fWO+oknxcOTL8o+nsnD3jiaF7KIBWs70+M9Ddkl8ih/os\nrXCPzBhmB/ttNgaKGczqGKCq+o1+cjBgrHzxfUOQAr6ne6ZyZgN0VbRNvkNDB9Te\nGf9BAlByFcLbrM9xYfu5z79deO9m/M5q6FbD5QMY1qN8A5oJhi1IPZo5GuFCoUJz\nmWGRXSujZQHBFr5T+euyMxnC3Gr+yJhP5plm9tET5VEf/tCWmeeWam84e1u9LP2n\nbFYpusfGZ9lA/JgoYOdYTb5gcHb53yIzLxUF/KaUQACMqbIXZxpvg+7qpLZkBJIX\nG/Qipg5ProkW7GqyzrcCAwEAAaNmMGQwQwYDVR0RBDwwOoIYc2hpYmlkcC5pdHMu\ndmlyZ2luaWEuZWR1hh51cm46bWFjZTppbmNvbW1vbjp2aXJnaW5pYS5lZHUwHQYD\nVR0OBBYEFJe4yrDCKYu70HZV9azIdbPqM9KHMA0GCSqGSIb3DQEBBQUAA4IBAQB8\nG07ktM6zaMsydtat8FUHbQsDqMu51vJAg8DTHD63SoJSG/NFar8BNZH0DDb33Zyy\n4KXfVGzE5Jtg5cb/5eRLah42FtkfvXnSMKgn8jAx77jG3kD/okm0iCKP6RRS7L7Q\nl3CESXZORAXC50pPjoacANRdAl729CszcW65zUhoKBV37plZq5uRc7FTtjJujEOL\n0wsZTq9SmdmHtH3E+XabESqWp43vuMTNS2XPBQPIQUyuCldZN+N6jLkOGQI104P3\n3FljH7rKPo43+7MT2XZGS2J+PcALgUfSxewXei0RQNXWXN3l0qXupwsWM8kO6mSA\nzZQUr9YEODP0DFBKKGSo"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "virginia.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.its.virginia.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.its.virginia.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibidp.its.virginia.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.its.virginia.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.its.virginia.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.its.virginia.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "virginia.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Virginia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIVALIs8V8u06NEcoiPKqBdTWQ5F3WdMA0GCSqGSIb3DQEB\nBQUAMCMxITAfBgNVBAMTGHNoaWJpZHAuaXRzLnZpcmdpbmlhLmVkdTAeFw0xMjAz\nMDIxNTI2MDNaFw0zMjAzMDIxNTI2MDNaMCMxITAfBgNVBAMTGHNoaWJpZHAuaXRz\nLnZpcmdpbmlhLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMz9\n8k0PGFjm33ceTUVhpw4fWO+oknxcOTL8o+nsnD3jiaF7KIBWs70+M9Ddkl8ih/os\nrXCPzBhmB/ttNgaKGczqGKCq+o1+cjBgrHzxfUOQAr6ne6ZyZgN0VbRNvkNDB9Te\nGf9BAlByFcLbrM9xYfu5z79deO9m/M5q6FbD5QMY1qN8A5oJhi1IPZo5GuFCoUJz\nmWGRXSujZQHBFr5T+euyMxnC3Gr+yJhP5plm9tET5VEf/tCWmeeWam84e1u9LP2n\nbFYpusfGZ9lA/JgoYOdYTb5gcHb53yIzLxUF/KaUQACMqbIXZxpvg+7qpLZkBJIX\nG/Qipg5ProkW7GqyzrcCAwEAAaNmMGQwQwYDVR0RBDwwOoIYc2hpYmlkcC5pdHMu\ndmlyZ2luaWEuZWR1hh51cm46bWFjZTppbmNvbW1vbjp2aXJnaW5pYS5lZHUwHQYD\nVR0OBBYEFJe4yrDCKYu70HZV9azIdbPqM9KHMA0GCSqGSIb3DQEBBQUAA4IBAQB8\nG07ktM6zaMsydtat8FUHbQsDqMu51vJAg8DTHD63SoJSG/NFar8BNZH0DDb33Zyy\n4KXfVGzE5Jtg5cb/5eRLah42FtkfvXnSMKgn8jAx77jG3kD/okm0iCKP6RRS7L7Q\nl3CESXZORAXC50pPjoacANRdAl729CszcW65zUhoKBV37plZq5uRc7FTtjJujEOL\n0wsZTq9SmdmHtH3E+XabESqWp43vuMTNS2XPBQPIQUyuCldZN+N6jLkOGQI104P3\n3FljH7rKPo43+7MT2XZGS2J+PcALgUfSxewXei0RQNXWXN3l0qXupwsWM8kO6mSA\nzZQUr9YEODP0DFBKKGSo"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://shibidp.its.virginia.edu/shiberror.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Virginia"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.virginia.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Virginia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://play.hig.se",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "saml_admin@kaltura.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://play.hig.se",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "H\u00f6gskolan i G\u00e4vle"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://play.hig.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "H\u00f6gskolan i G\u00e4vle"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://play.hig.se/user/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service is for presentation of videos from University of G\u00e4vle."
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Denna tj\u00e4nst anv\u00e4nds f\u00f6r presentationer av video fr\u00e5n H\u00f6gskolan i G\u00e4vle."
                  }
                ],
                "logo": [
                  {
                    "text": "https://webkonto.student.hig.se/head/loggaengelska.png",
                    "height": "94",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "83"
                  },
                  {
                    "text": "https://webkonto.student.hig.se/head/logga3.png",
                    "lang": "sv",
                    "height": "94",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "83"
                  },
                  {
                    "text": "https://webkonto.student.hig.se/head/loggaengelska.png",
                    "lang": "en",
                    "height": "94",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "83"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of G\u00e4vle Play service"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "H\u00f6gskolan i G\u00e4vle Playtj\u00e4nst"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.hig.se/user/authenticate",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://gcu.idm.oclc.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Support Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Support Desk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://gcu.idm.oclc.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-04-09T14:33:01Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Glasgow Caledonian University Hosted EZProxy"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oclc.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "OCLC (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://login.gcu.idm.oclc.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.gcu.idm.oclc.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.gcu.idm.oclc.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.gcu.idm.oclc.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEAjCCAuqgAwIBAgIBAjANBgkqhkiG9w0BAQUFADBjMRswGQYDVQQDFBIqLmdj\n\t\t\t\t\t\tdS5pZG0ub2NsYy5vcmcxCzAJBgNVBAYTAlVLMQ0wCwYDVQQKEwRPQ0xDMSgwJgYJ\n\t\t\t\t\t\tKoZIhvcNAQkBFhlqYW1lcy5odXRjaGluc29uQG9jbGMub3JnMB4XDTE0MDQwODA5\n\t\t\t\t\t\tMjMwNFoXDTI0MDQwNzA5MjMwNFowYzEbMBkGA1UEAxQSKi5nY3UuaWRtLm9jbGMu\n\t\t\t\t\t\tb3JnMQswCQYDVQQGEwJVSzENMAsGA1UEChMET0NMQzEoMCYGCSqGSIb3DQEJARYZ\n\t\t\t\t\t\tamFtZXMuaHV0Y2hpbnNvbkBvY2xjLm9yZzCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBAMT0xloPYpMr8p6BWPrrVfiOCy/o3FUyA5TshNxjVayC0Y+jHlwf\n\t\t\t\t\t\tjlqZoseU0tFUkRPll5wioukxcvR1O1fgBRM1hdNAbiHg6y2T677ji4GO+/Ya8Lt6\n\t\t\t\t\t\t7OdgDtoliP7wUaBq7rHiQgpzWDh82tEKQ95m+qEIBtOG2lGEeAoy0D01+p2W5grm\n\t\t\t\t\t\tFZyoN/YA68Cd5xtloOwRNaOZ63imjXi9mjxrHaLrlRCEHnvRGm6HWW1niCeu7EDY\n\t\t\t\t\t\tS9g4fVQY0rMIMd/Q9ISzqzhF1akZERG2GsjJctSVtbq1MIN6aC4Eh2kdbEytfEbD\n\t\t\t\t\t\tdlK/4kvT9ycYMm0kOk/LdmOtTN11t15jzE0CAwEAAaOBwDCBvTAdBgNVHQ4EFgQU\n\t\t\t\t\t\tenw01HVcsPIbyZ8kLsB/u2a6BS8wgY0GA1UdIwSBhTCBgoAUenw01HVcsPIbyZ8k\n\t\t\t\t\t\tLsB/u2a6BS+hZ6RlMGMxGzAZBgNVBAMUEiouZ2N1LmlkbS5vY2xjLm9yZzELMAkG\n\t\t\t\t\t\tA1UEBhMCVUsxDTALBgNVBAoTBE9DTEMxKDAmBgkqhkiG9w0BCQEWGWphbWVzLmh1\n\t\t\t\t\t\tdGNoaW5zb25Ab2NsYy5vcmeCAQIwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAeEfQ8o/m5HDO/5H5Hk2KFUVB7eh6eLGrT8cO4uj6ajWvx2DMkjiI7Xfg\n\t\t\t\t\t\tgYmIbLsbSR3iryoxoTsiakLB1Cvt3reVagah1sAkVqQl9yLw56q8V4AbfJN4OdTH\n\t\t\t\t\t\t6u49A/SY7quj8eDrUDqTVP9arCWu153U/h+KFzjTuEVTxxYuMGXMzElf32lYMjrO\n\t\t\t\t\t\t4FFpcyVbHiLfkGed+1e9c9tVQm6gNj34Yim0xTEQIW+TD3PV9OxZvTZ5wKxYAZuP\n\t\t\t\t\t\tNn3NCKYoSTvPu2dJGROCnlm3bnkTz4fW5hwlFImzA4tv+tsjZtnsQp/XfJ+5h7le\n\t\t\t\t\t\tdfzIYdf+lychhwisBoYuI4TC5BOFBQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://login.gcu.idm.oclc.org/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://vip.espci.fr/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Emmanuel Dreyfus"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Emmanuel.Dreyfus@espci.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jean-Jacques Puig"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Jean-Jacques.Puig@espci.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://vip.espci.fr/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2010-05-31T18:03:42Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vip.espci.fr/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vip.espci.fr/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://vip.espci.fr/shib13/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "espci.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.espci.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ESPCI ParisTech"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ESPCI ParisTech"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFdjCCBF6gAwIBAgIQINOwQe4k09iKRAogjYscZDANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQwODAwMDAwMFoXDTE3MDQwNzIzNTk1OVowOjEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRUwEwYDVQQDEwx2aXAuZXNwY2ku\nZnIwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQDG4kQF844cPIa0EonJ\nNOgAx1MC8skufPLiqMFNu9moOTuq7GBVYPgyjPt46xhWm6VvAMTwZHTSPS4NYQwy\nPwU8S6XRYLh+K5hJmeWras/UJFxsNMqwtA/5KRGYRDPKv6kA2oF7dWu9uA8e78L2\nYCGPcY3YVmURl0Hcsa4EN2fU2c3a00NDJjJKuk1QF/M4lh+SG8lzQJHDrVtkl4tg\ndO74GOq1hhY3wq4037Ybi7TnBDQ47MUtANpPmmOhnbUR8nXaNGpBfLX515qoyksr\ntlk7YeoyguEqWIoEHmxNzwuNqh2cVBJQassPzIYYQfabbO6SH/PQxri3kyzVs7eF\nIIxQ4a7ueI6sGDeuuMhLFGG6tvJOPw2K/9fsHGYdGtnUAF7PVmNCUkRC9P667baz\ncJL5wGkAS6yczTXAS14WwL+OPQldB15Etv9odQ8cp/xJWL+fkrx3GzG4lyzRPo2f\nw84G1YQt1PJ5VJ+gT+ZzUDAkTnYpV7Hw2DUm2EIUAMXRL2d/B17GyxKh+YvtWRsl\nr+MkLWjdb2RglF1EtKV8YvXiGk26gDc3J8ZkseOq8RkvYHqFfZl346I4ve1dwB++\nHwc2AvVCkCWxczQs6kFkgx9kw+GrrFB3OLUB+/EOh39iB5FyC+EKt1TGPhE1r41F\nyjfR4oLG0niAJvbTYtDPZ6AN4wIDAQABo4IBejCCAXYwHwYDVR0jBBgwFoAUDL2T\naAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFGqL9qiZrqTzr2sVmqknWvntrCtV\nMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUF\nBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAEC\nATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RF\nUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6\nLy9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzAB\nhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAoBgNVHREEITAfggx2aXAuZXNw\nY2kuZnKCD29wZW5pZC5lc3BjaS5mcjANBgkqhkiG9w0BAQUFAAOCAQEAJ3M5NRTg\nXfOhpzRIyBfNgEMV/D9n2h9vD4YqJI05bYhbELOD1wkmLcpFWSsDc0V1WxCHl9Dz\ny2YdRaq51NbeBlnh/Q8ulKqx//O+29R52AHD3p7Be4lynIHDRgOWWu9pzZTDd0yw\nMthAhzQKI6LenYb3jIJqy8OKgEAZB/kQcWfmVlXws7CyxFk6XJS7tIm52d9ywMGe\n/4Wpe4W1jHEWn4ngfgHIOZ33NHsze0p+A3lhQLQxQc2yYk2pfhwMq2a++veSqnrs\nM3PXyfI7EheNPXVG8+6JL5disJ3pvtZwIrzh3ApWc4NDE2BISXejQZxpl5wVtCt+\naWaLoR3kbEdTYA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFdjCCBF6gAwIBAgIQINOwQe4k09iKRAogjYscZDANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQwODAwMDAwMFoXDTE3MDQwNzIzNTk1OVowOjEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRUwEwYDVQQDEwx2aXAuZXNwY2ku\nZnIwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQDG4kQF844cPIa0EonJ\nNOgAx1MC8skufPLiqMFNu9moOTuq7GBVYPgyjPt46xhWm6VvAMTwZHTSPS4NYQwy\nPwU8S6XRYLh+K5hJmeWras/UJFxsNMqwtA/5KRGYRDPKv6kA2oF7dWu9uA8e78L2\nYCGPcY3YVmURl0Hcsa4EN2fU2c3a00NDJjJKuk1QF/M4lh+SG8lzQJHDrVtkl4tg\ndO74GOq1hhY3wq4037Ybi7TnBDQ47MUtANpPmmOhnbUR8nXaNGpBfLX515qoyksr\ntlk7YeoyguEqWIoEHmxNzwuNqh2cVBJQassPzIYYQfabbO6SH/PQxri3kyzVs7eF\nIIxQ4a7ueI6sGDeuuMhLFGG6tvJOPw2K/9fsHGYdGtnUAF7PVmNCUkRC9P667baz\ncJL5wGkAS6yczTXAS14WwL+OPQldB15Etv9odQ8cp/xJWL+fkrx3GzG4lyzRPo2f\nw84G1YQt1PJ5VJ+gT+ZzUDAkTnYpV7Hw2DUm2EIUAMXRL2d/B17GyxKh+YvtWRsl\nr+MkLWjdb2RglF1EtKV8YvXiGk26gDc3J8ZkseOq8RkvYHqFfZl346I4ve1dwB++\nHwc2AvVCkCWxczQs6kFkgx9kw+GrrFB3OLUB+/EOh39iB5FyC+EKt1TGPhE1r41F\nyjfR4oLG0niAJvbTYtDPZ6AN4wIDAQABo4IBejCCAXYwHwYDVR0jBBgwFoAUDL2T\naAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFGqL9qiZrqTzr2sVmqknWvntrCtV\nMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUF\nBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAEC\nATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RF\nUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6\nLy9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzAB\nhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAoBgNVHREEITAfggx2aXAuZXNw\nY2kuZnKCD29wZW5pZC5lc3BjaS5mcjANBgkqhkiG9w0BAQUFAAOCAQEAJ3M5NRTg\nXfOhpzRIyBfNgEMV/D9n2h9vD4YqJI05bYhbELOD1wkmLcpFWSsDc0V1WxCHl9Dz\ny2YdRaq51NbeBlnh/Q8ulKqx//O+29R52AHD3p7Be4lynIHDRgOWWu9pzZTDd0yw\nMthAhzQKI6LenYb3jIJqy8OKgEAZB/kQcWfmVlXws7CyxFk6XJS7tIm52d9ywMGe\n/4Wpe4W1jHEWn4ngfgHIOZ33NHsze0p+A3lhQLQxQc2yYk2pfhwMq2a++veSqnrs\nM3PXyfI7EheNPXVG8+6JL5disJ3pvtZwIrzh3ApWc4NDE2BISXejQZxpl5wVtCt+\naWaLoR3kbEdTYA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ESPCI ParisTech"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.espci.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ESPCI ParisTech"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.uni.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "aaron.thompson@uni.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Aaron Thompson"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "steve.moon@uni.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve Moon"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.uni.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.uni.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.uni.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.uni.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.uni.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.uni.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uni.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uni.edu/its/success/federated-identity-based-authentication-and-authorization"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Northern Iowa"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Northern Iowa"
                  }
                ],
                "logo": [
                  {
                    "text": "https://shib.uni.edu/uni_shib_logo.jpg",
                    "lang": "en",
                    "height": "151",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "150"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.uni.edu/policies/web-privacy-statement"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUCu4IcZbPLmOuHB1lfiwiMS3C3awwDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMc2hpYi51bmkuZWR1MB4XDTEwMTEwODIyMTYwN1oXDTMw\nMTEwODIyMTYwN1owFzEVMBMGA1UEAxMMc2hpYi51bmkuZWR1MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsB2tsghTo0KUgABFUMSxsDrozS1W08ZsYtXw\n2G1BMnXDsbQbPmvXlQ46qML3I78xErOMkr1oZ+ni3rlUD3G+GtLNVhO9cq5oqANJ\nsbrF99bs6cxYbuYx8vriijSCgEPaV3rPkqmLE0TIzFyDnaDp2U56tCN41CxA2g4Y\nxFYwk2PTs0QPDfdbtNqmyFcGaNnYsJEmxVjKc+zMQQd2dBikOeKwrhzGYO980BmK\nDOiFk7eTXpyW+hBOaiKveUwS81cORvlCcLIf6dm0tPPGlOjH8L3WqZve0nqmOxqi\nmPzf+Fps77DOPaRZxtn2N7YCEK7UMsj0DBxFBQJVtUH8F9eL1wIDAQABo18wXTA8\nBgNVHREENTAzggxzaGliLnVuaS5lZHWGI2h0dHBzOi8vc2hpYi51bmkuZWR1L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBReKCQUpF/hHZGp8UEdgJIXFLrP5zANBgkq\nhkiG9w0BAQUFAAOCAQEANsWWgW8We+gkawvvf3WXgBPieqOqYGi/6FWyjIyIHnfk\nUViTJ6wIvEJ1Cn1jKaVafrvEEPTo4T0QwSJnySEuGQYsqoo4o2JG/w74+6+As4ka\nmzr9bFrxFHn7PWGqaW1cYVQ/u8JKBb9fCBbkSrCB97zEuunpW7N2ZJw1UHyrSBS3\nr+MGykM/8VJU9Qql88dSUZ/kJru02gNQaqFpjAL3fk+R901tdP4+B4LYQlb+jHg5\n3p5sK3Hiue0026r9kZw9D7u+fPecPUxnjZLBo7WgI5fPZ+lKhXTPNzeFqP+rAdDe\nkCdWJpucLkkmoLQQ21pIXNh5PSelhthswpCAnAkulA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Northern Iowa"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Northern Iowa"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:ucsf.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kevin.dale@ucsf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kevin Dale"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "susil.rayamajhi@ucsf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Susil Rayamajhi"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "nathan.sheldon@ucsf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nathan Sheldon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mukesh.yadav@ucsf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mukesh Yadav"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:ucsf.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://dp.ucsf.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dp.ucsf.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dp.ucsf.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dp.ucsf.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://dp.ucsf.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dp.ucsf.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucsf.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of California, San Francisco"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUW2hLRYSTq6yflHpRZ5ZBXty14rYwDQYJKoZIhvcNAQEF\nBQAwFjEUMBIGA1UEAxMLZHAudWNzZi5lZHUwHhcNMDkwODI5MDQwMzU5WhcNMjkw\nODI5MDQwMzU5WjAWMRQwEgYDVQQDEwtkcC51Y3NmLmVkdTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAK+WY9j/fuMEQ2u4mKKeU5LXO+mi7BKKkJP3PUN0\nIz4whL/M9uTR+C7x6DCVbi4CXNia8hmoNbWIKCKto9UJT/e+Y4y+dZjC4TLcIvdU\nog7x4/3qlcwI76jkomyL5uy2/7Ow+l/pmX99wph+K4/d8EpwE3NTXcFOVv1D8M3p\nUrVEfT1aoAm7p4SXS3uohM7KDXTljqtxImt/Q+cRFBImNyp7YTFp37024eMwtNfL\nJxEajodIFOCCYP6DmN5I1RWTF808BPPbkt7agjuz50pCdXHxfgnCfUmHeeUz4yLI\n6cgOWkB9JISN567vAH68IInM9with782aIsVLf2Fs5pQqxECAwEAAaNdMFswOgYD\nVR0RBDMwMYILZHAudWNzZi5lZHWGImh0dHBzOi8vZHAudWNzZi5lZHUvaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFDfsmZZFJeq4xHogyRDy+1N69EEKMA0GCSqGSIb3\nDQEBBQUAA4IBAQBiK5W3RyQc/LL+FOy9mQIFzmobtJCGYUHwn/jMzZ+FdiV688MO\nA94AHGnxlvjjlVE7sjI83XgUK80IpLWz1QtCN9Pcwo5M0tNCxOFAkIe1xRadZmN4\nLpFOenH8vd5TF7DjrozFivFC4+l/mTTW4hfl+RaR34zgrzBAv+fUNrq7cNrid11w\n0h17HNqD964TR4QphmFyIrFR9skSs+41ScRMa4c7Svel8p4f+ptoATHSlSm0OZay\njktgJp4o+Ld8xiH8Q5oLQ/qNG0hx9IRMaum9h0HCnxwHKsrxcJW2/A/CVhaVlj4J\np/B3Zs13i2Wc6VGZGK1rfVetLqSnvfVPnT+h"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://dp.ucsf.edu/idp/profile/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of California, San Francisco"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ucsf.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of California, San Francisco"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.turnitinuk.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibadmin@turnitin.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth admin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibadmin@turnitin.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth admin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.turnitinuk.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-12-18T10:58:40Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "iParadigms: TurnitinUK"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.turnitinuk.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "iParadigms Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.turnitinuk.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.turnitinuk.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.turnitinuk.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.turnitinuk.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "TurnitinUK"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonTargetedID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:mail",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ],
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.turnitinuk.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "authn_requests_signed": "1",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.turnitinuk.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth.turnitinuk.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.turnitinuk.com/Shibboleth.sso/WAYF/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEJDCCAwygAwIBAgIJANNCqdS5T/uTMA0GCSqGSIb3DQEBBQUAMIGSMQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECAwKQ2FsaWZvcm5pYTEQMA4GA1UEBwwHT2FrbGFuZDET\n\t\t\t\t\t\tMBEGA1UECgwKaVBhcmFkaWdtczEgMB4GA1UEAwwXc2hpYmJvbGV0aC5zdWJtaXQu\n\t\t\t\t\t\tYWMudWsxJTAjBgkqhkiG9w0BCQEWFnNoaWJhZG1pbkB0dXJuaXRpbi5jb20wHhcN\n\t\t\t\t\t\tMTMwODIzMDAzMjM4WhcNMjMwODIxMDAzMjM4WjCBkjELMAkGA1UEBhMCVVMxEzAR\n\t\t\t\t\t\tBgNVBAgMCkNhbGlmb3JuaWExEDAOBgNVBAcMB09ha2xhbmQxEzARBgNVBAoMCmlQ\n\t\t\t\t\t\tYXJhZGlnbXMxIDAeBgNVBAMMF3NoaWJib2xldGguc3VibWl0LmFjLnVrMSUwIwYJ\n\t\t\t\t\t\tKoZIhvcNAQkBFhZzaGliYWRtaW5AdHVybml0aW4uY29tMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAwP4A/JGVAR4/MLEn2/YgG+8RqWnJqi/Pxuux6AR8\n\t\t\t\t\t\tYJouaq6OIN7FtmFTze4aOVji3u0QoxDU559gl72VA3c4J+DYV/6sKz4LCGrN7NTM\n\t\t\t\t\t\tRdtHrHJkPtj1ktIkBaCSYPADoTsrlQnRqZ5sSc8Q1vQNFQCfhf61mkKE3VX+EwTK\n\t\t\t\t\t\tnjx6NhyhpPSfctUdPR/QADZZCWazldENSuH7yyUjTlxhBLLQD9Yyahn2e11Afqvc\n\t\t\t\t\t\tiJvyZMVtfQ0ezKVQlinXTtPKROuVHPybKcCcvu0WLncrW1M1kbhkmUNbCjPWspxp\n\t\t\t\t\t\ty91ggvdRePbOdZZwmUIxkEMeGiXDA8YvmF2gk6wptRv/7wIDAQABo3sweTAJBgNV\n\t\t\t\t\t\tHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZp\n\t\t\t\t\t\tY2F0ZTAdBgNVHQ4EFgQUvcJOH3FW/nHHBg7gjXPFvTUg0EkwHwYDVR0jBBgwFoAU\n\t\t\t\t\t\tvcJOH3FW/nHHBg7gjXPFvTUg0EkwDQYJKoZIhvcNAQEFBQADggEBAJteiRc11ZQe\n\t\t\t\t\t\tmm2idBi0wnpXTsXq7Boo2tFBB1QhJ4c/XkkBb1gzBaGe2dH4jZ0NbpN8+JXifplz\n\t\t\t\t\t\tZokKNVILqvi7xnR3aAs2lFRqN3mpZ2a3Kkn5liLtiOeuVx37o/n6RxpTKS/KHufz\n\t\t\t\t\t\tebYCs8ORGrdWHuiGHPX6LNy9ITONdFr7ma57aQ7Xr47hxgT/XRk48OcDGhTFAlmt\n\t\t\t\t\t\tXCnhD1dwMqXgkfULzheeg/j2BDCBfWjfG+4D6FzQlbFbyfOK03w8Yjxmy397OYbC\n\t\t\t\t\t\tQ/KYFVKd7S68jRoJ05AH/RvuEL7Fr8hSYJHhs26lgTM9MFU79jjzfhH4OvYyjoK5\n\t\t\t\t\t\tBqox791QdCs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.turnitinuk.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.turnitinuk.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.turnitinuk.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth.turnitinuk.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.turnitinuk.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.turnitinuk.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol"
        }
      ]
    }
  ],
  [
    "urn:mace:incommon:duke.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idmstech@duke.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shilen Patel"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idmstech@duke.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shilen Patel"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:duke.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.oit.duke.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.oit.duke.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEWjCCA0KgAwIBAgIJAP1rB/FjRgy6MA0GCSqGSIb3DQEBBQUAMHsxCzAJBgNV\nBAYTAlVTMRcwFQYDVQQIEw5Ob3J0aCBDYXJvbGluYTEPMA0GA1UEBxMGRHVyaGFt\nMRgwFgYDVQQKEw9EdWtlIFVuaXZlcnNpdHkxDDAKBgNVBAsTA09JVDEaMBgGA1UE\nAxMRc2hpYi5vaXQuZHVrZS5lZHUwHhcNMTAwOTA5MTI0NDU1WhcNMjgwOTA0MTI0\nNDU1WjB7MQswCQYDVQQGEwJVUzEXMBUGA1UECBMOTm9ydGggQ2Fyb2xpbmExDzAN\nBgNVBAcTBkR1cmhhbTEYMBYGA1UEChMPRHVrZSBVbml2ZXJzaXR5MQwwCgYDVQQL\nEwNPSVQxGjAYBgNVBAMTEXNoaWIub2l0LmR1a2UuZWR1MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAt+hnl6gSRi0Y8VuNl6PCPYejj7VfVs/y8bRa5zAY\nRHwb75+vBSs2j1yeUcSore9Ba5Ni7v947V34afRMGRPOqr4TEDZxU+1Bg0zAvSrR\nn4Y8B+zyJuhtOpmOZzTwE9o/Oc+CB4kYV/K0woKZdcoxHJm8TbqBqdxU4fFYUlNU\no4Dr5jRdCSr9MHBOqGWXtQMg16qYNB7StNk4twY29FNnpZwkVTfsE76uVsRMkG8i\n6/RiHpXZ/ioOOqndptbEGdsOIE3ivAJOZdvYwnDe5NnTH06P01HsxH3OOnYqhuG2\nJ6qdhqoelGeHRG+jfl8YkYXCcKQvja2tJ5G+6iqSN7DP6QIDAQABo4HgMIHdMB0G\nA1UdDgQWBBQHYXwB6otkfyMOmUI59j8823hFRDCBrQYDVR0jBIGlMIGigBQHYXwB\n6otkfyMOmUI59j8823hFRKF/pH0wezELMAkGA1UEBhMCVVMxFzAVBgNVBAgTDk5v\ncnRoIENhcm9saW5hMQ8wDQYDVQQHEwZEdXJoYW0xGDAWBgNVBAoTD0R1a2UgVW5p\ndmVyc2l0eTEMMAoGA1UECxMDT0lUMRowGAYDVQQDExFzaGliLm9pdC5kdWtlLmVk\ndYIJAP1rB/FjRgy6MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAG7q\nwJpiSLJbx2gj/cGDYeuBW/CeRGNghjQ/mb076P3WXsRNPAimcXulSUbQkS6eDH4t\nIfvsa0jf4FRsEOwH/x8354/0wyv4RwuavX25kjpmoFn3O+eKokyzsc7/Q2gsm0mv\nV8XQo+5b+4we8AFYlAVp26nLeIqAiJM8xZJ9yHuzVL1O4yxIWIKECWHLqY5+1nas\nXNiLURrHhsK5pZUPLuhzJFgZuJT62TtnrjJXlrRhJ389VSkh6R64C6ncjNkg6/Cu\ntA6SX0infqNRyPRNJK+bnQd1yOP4++tjD/lAPE+5tiD/waI3fArt43ZE/qp7pYMS\n9TEfyQ5QpfRYAUFWXBc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "duke.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.oit.duke.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.oit.duke.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.oit.duke.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.oit.duke.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEWjCCA0KgAwIBAgIJAP1rB/FjRgy6MA0GCSqGSIb3DQEBBQUAMHsxCzAJBgNV\nBAYTAlVTMRcwFQYDVQQIEw5Ob3J0aCBDYXJvbGluYTEPMA0GA1UEBxMGRHVyaGFt\nMRgwFgYDVQQKEw9EdWtlIFVuaXZlcnNpdHkxDDAKBgNVBAsTA09JVDEaMBgGA1UE\nAxMRc2hpYi5vaXQuZHVrZS5lZHUwHhcNMTAwOTA5MTI0NDU1WhcNMjgwOTA0MTI0\nNDU1WjB7MQswCQYDVQQGEwJVUzEXMBUGA1UECBMOTm9ydGggQ2Fyb2xpbmExDzAN\nBgNVBAcTBkR1cmhhbTEYMBYGA1UEChMPRHVrZSBVbml2ZXJzaXR5MQwwCgYDVQQL\nEwNPSVQxGjAYBgNVBAMTEXNoaWIub2l0LmR1a2UuZWR1MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAt+hnl6gSRi0Y8VuNl6PCPYejj7VfVs/y8bRa5zAY\nRHwb75+vBSs2j1yeUcSore9Ba5Ni7v947V34afRMGRPOqr4TEDZxU+1Bg0zAvSrR\nn4Y8B+zyJuhtOpmOZzTwE9o/Oc+CB4kYV/K0woKZdcoxHJm8TbqBqdxU4fFYUlNU\no4Dr5jRdCSr9MHBOqGWXtQMg16qYNB7StNk4twY29FNnpZwkVTfsE76uVsRMkG8i\n6/RiHpXZ/ioOOqndptbEGdsOIE3ivAJOZdvYwnDe5NnTH06P01HsxH3OOnYqhuG2\nJ6qdhqoelGeHRG+jfl8YkYXCcKQvja2tJ5G+6iqSN7DP6QIDAQABo4HgMIHdMB0G\nA1UdDgQWBBQHYXwB6otkfyMOmUI59j8823hFRDCBrQYDVR0jBIGlMIGigBQHYXwB\n6otkfyMOmUI59j8823hFRKF/pH0wezELMAkGA1UEBhMCVVMxFzAVBgNVBAgTDk5v\ncnRoIENhcm9saW5hMQ8wDQYDVQQHEwZEdXJoYW0xGDAWBgNVBAoTD0R1a2UgVW5p\ndmVyc2l0eTEMMAoGA1UECxMDT0lUMRowGAYDVQQDExFzaGliLm9pdC5kdWtlLmVk\ndYIJAP1rB/FjRgy6MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAG7q\nwJpiSLJbx2gj/cGDYeuBW/CeRGNghjQ/mb076P3WXsRNPAimcXulSUbQkS6eDH4t\nIfvsa0jf4FRsEOwH/x8354/0wyv4RwuavX25kjpmoFn3O+eKokyzsc7/Q2gsm0mv\nV8XQo+5b+4we8AFYlAVp26nLeIqAiJM8xZJ9yHuzVL1O4yxIWIKECWHLqY5+1nas\nXNiLURrHhsK5pZUPLuhzJFgZuJT62TtnrjJXlrRhJ389VSkh6R64C6ncjNkg6/Cu\ntA6SX0infqNRyPRNJK+bnQd1yOP4++tjD/lAPE+5tiD/waI3fArt43ZE/qp7pYMS\n9TEfyQ5QpfRYAUFWXBc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "duke.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Duke University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Duke University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.duke.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Duke University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp-v2.konstfack.se/adfs/services/trust",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46-8-4504100"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pettersson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "netsupport@konstfack.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "H\u00e5kan"
          }
        }
      ],
      "entity_id": "https://idp-v2.konstfack.se/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "regexp": "false",
            "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
            "text": "konstfack.se"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-v2.konstfack.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-v2.konstfack.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-v2.konstfack.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-v2.konstfack.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-v2.konstfack.se/adfs/services/trust/artifactresolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "konstfack.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.konstfack.se/sv/Om-Konstfack"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.konstfack.se/en/About-Konstfack"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Konstfack"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Konstfack"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University College of Arts, Crafts and Design"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University College of Arts, Crafts and Design"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp-v2.konstfack.se/adfs/portal/logo/logo.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.konstfack.se/sv/Om-Konstfack/Om-webbplatsen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.konstfack.se/en/About-Konstfack/About-this-site"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute": [
            {
              "friendly_name": "E-Mail Address",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/emailaddress",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Given Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/givenname",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/name",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "UPN",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/upn",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Common Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/CommonName",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "AD FS 1.x E-Mail Address",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/EmailAddress",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Group",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/Group",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "AD FS 1.x UPN",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/claims/UPN",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Role",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/role",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Surname",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/surname",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "PPID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/privatepersonalidentifier",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Name ID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/nameidentifier",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Authentication time stamp",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/authenticationinstant",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Authentication method",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/authenticationmethod",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Deny only group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/denyonlysid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Deny only primary SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/denyonlyprimarysid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Deny only primary group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/denyonlyprimarygroupsid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/groupsid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Primary group SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/primarygroupsid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Primary SID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/primarysid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Windows account name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/windowsaccountname",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Is Registered User",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/devicecontext/claims/isregistereduser",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Device Identifier",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/devicecontext/claims/identifier",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Device Registration Identifier",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/devicecontext/claims/registrationid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Device Registration DisplayName",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/devicecontext/claims/displayname",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Device OS type",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/devicecontext/claims/ostype",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Device OS Version",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/devicecontext/claims/osversion",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Is Managed Device",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/devicecontext/claims/ismanaged",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Forwarded Client IP",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/requestcontext/claims/x-ms-forwarded-client-ip",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Client Application",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/requestcontext/claims/x-ms-client-application",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Client User Agent",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/requestcontext/claims/x-ms-client-user-agent",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Client IP",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/requestcontext/claims/x-ms-client-ip",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Endpoint Path",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/requestcontext/claims/x-ms-endpoint-absolute-path",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Proxy",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/requestcontext/claims/x-ms-proxy",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Application Identifier",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/requestcontext/claims/relyingpartytrustid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Application policies",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/applicationpolicy",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Authority Key Identifier",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/authoritykeyidentifier",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Basic Constraint",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/basicconstraints",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Enhanced Key Usage",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/eku",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Issuer",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/field/issuer",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Issuer Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/field/issuername",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Key Usage",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/keyusage",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Not After",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/field/notafter",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Not Before",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/field/notbefore",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Certificate Policies",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/certificatepolicy",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Public Key",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/rsa",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Certificate Raw Data",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/field/rawdata",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Subject Alternative Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/san",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Serial Number",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2008/06/identity/claims/serialnumber",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Signature Algorithm",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/field/signaturealgorithm",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Subject",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/field/subject",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Subject Key Identifier",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/subjectkeyidentifier",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Subject Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/field/subjectname",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "V2 Template Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/certificatetemplateinformation",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "V1 Template Name",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/extension/certificatetemplatename",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Thumbprint",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/thumbprint",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "X.509 Version",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/12/certificatecontext/field/x509version",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Inside Corporate Network",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2012/01/insidecorporatenetwork",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Password Expiration Time",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2012/01/passwordexpirationtime",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Password Expiration Days",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2012/01/passwordexpirationdays",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Update Password URL",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2012/01/passwordchangeurl",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Authentication Methods References",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/claims/authnmethodsreferences",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Client Request ID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/2012/01/requestcontext/claims/client-request-id",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "Alternate Login ID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.microsoft.com/ws/2013/11/alternateloginid",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "employeeID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/employeeID",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            }
          ],
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Konstfack"
          }
        ],
        "organization_url": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.konstfack.se/"
          }
        ],
        "organization_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Konstfack"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-v2.konstfack.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-v2.konstfack.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://idp-v2.konstfack.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://idp-v2.konstfack.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-v2.konstfack.se/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ni.nordu.net/saml2/metadata/",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lundberg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lundberg@nordu.net"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "NORDUnet A/S"
          },
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Johan"
          }
        }
      ],
      "entity_id": "https://ni.nordu.net/saml2/metadata/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ni.nordu.net/saml2/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6zCCAdOgAwIBAgIJAI32hx6m/IFWMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDG5pLm5vcmR1Lm5ldDAeFw0xMjA4MzAxMjAyMTFaFw0yMjA4MjgxMjAyMTFa\nMBcxFTATBgNVBAMTDG5pLm5vcmR1Lm5ldDCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAKIsfzWwYgW2y9+K58VQi35/weisNzGlYYJbpYY8+AqGhtkSpB8D\nz46HVvyZ1L6lgShGQ5fNUzB/zT9GuYnR1BbJMmz0t/XU1eLz1btyD11/DtL9FMm2\nc/FYPe9Srn9x0n6mtncZofWVeD+a8cdRoOOrLwjL25QGCfAPynSf0OdUraUM6qKt\nu4KGAK8FMDss8uLDaJjJVc1saeDg6NpvYralAY+CnyiuskLYhilmLb0tMu63+ma8\nXVtZV9bWPMyB1RnT9aRYXPL3GjiH/Pun1r74SsNP9M77RS7j3PD5Jf1wmPpIBZL0\nDk6l3RnuVzK6D9zwTiAEDu3a+trzu5BzNMcCAwEAAaM6MDgwFwYDVR0RBBAwDoIM\nbmkubm9yZHUubmV0MB0GA1UdDgQWBBTPG/xsbxF7Q8OHyhUIktltkneGJTANBgkq\nhkiG9w0BAQUFAAOCAQEAI+gTmUEi7+iXxLJwhhnTm2w07fI8r/Rx3HXVQJ7fk0k9\nZX+yVo16pG7uxzWu88w9urMpjlRMBV9xT7oE+7xuOppeSJbQpjxfYCArq/VD+Qr/\nWjzMRZMjN4LkL+s6m0f4ASItLF5MBXmStmxl5ZE0UajyR08i87sg9QcTVXBpyirr\niRfdxDA4R+g0xwEZhpg2HbKRHeP8Uy/8SrOLYMFsblex5vc/96eZCOc88FlH1ydk\nzj16pWsjoYc1j+cnJBREpOJCeotrkBKte+OL1J5ku6e3qoQ+4Oyrsu4qhU/8geIo\nGtDqiUnI4ewwuxmNcK7kU1vUmBsiKlS5lyo8c+hpTA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ni.nordu.net/saml2/acs/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "NOCLook"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://birk.wayf.dk/birk.php/fs.dskd.dk/adfs/services/trust",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://birk.wayf.dk/birk.php/fs.dskd.dk/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2015-05-27T15:12:32Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/fs.dskd.dk/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dskd.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Designskolen Kolding"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Design School Kolding"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "dskd.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC1DCCAbwCAQcwDQYJKoZIhvcNAQELBQAwMDEuMCwGA1UEAwwlaHR0cDovL2Zz\nLmRza2QuZGsvYWRmcy9zZXJ2aWNlcy90cnVzdDAeFw0xNTAxMDEwMDAwMDBaFw0y\nNTEyMzEyMzU5NTlaMDAxLjAsBgNVBAMMJWh0dHA6Ly9mcy5kc2tkLmRrL2FkZnMv\nc2VydmljZXMvdHJ1c3QwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDH\niAwKahBTuI4Z+IJ1rgOeEiCCy3bR9QIe3BpCsejFCU5rSzkWANqVuc1PDfp0JdIZ\nhrPXsmDJQMmidPCGPIDQKo+bk+af3+EUFS/I/+35sSBX2vf+h1DHvZV9jsznmpSV\njp7HZ/WoPWBykWBJO0AOVmzB5zlaqkS36J76+wxerwdpuExVnYSNd73S+AyT/EZ+\ntXAO+6lQ8FL/YMlJnUkSaSqLSHFy01D2qBNmYRwBpCS6/dUZyxi0t5j8ghKUD4BH\nOZVavn65J62cJdXiOcMRyUAIp57GXQrL63KtrjIcXddq+CZyZ5t37EdUOIz42joF\ncy73MFOntynlKEvOw1BJAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAAi+Kah5zSB6\nKbsrjzAP15Lemsnnlfm01DTYdSnq0DvR8xtuZqg1OrU7jEQuD4aYAK8nyoLtPxmk\n6jPI6CCNAa/MvSgwxivD2hFR7ynKJrbI65DPP7Wo/6GRSr4vMD3xhKFNGS2061M1\n8majtXtIhwqhbEgmq5EAKeTQiUZM9GcJh86+r7Td9aJxiAa2jdn3UnTEfc5pDr71\nWks1+XvQCZCvDytO08HrCK+2n42p5qVxKX2amKpWDuseBmpuTC9uTFbP2pJuJssN\nVOvL3ykvu7uuZW0/HdBtWE/eVi8dAKE/eV5SDo6p0QUF2GK2fT7a6Mlwl5tyYAoU\ndPcr9FHbXBQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Designskolen Kolding"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Design School Kolding"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.designskolenkolding.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.designskolenkolding.dk/en"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Designskolen Kolding"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Design School Kolding"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://admin.vpp.midlands3cities.ac.uk/simplesaml/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itservicedesk@nottingham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Betts"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Craig.Betts@nottingham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Craig"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://admin.vpp.midlands3cities.ac.uk/simplesaml/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-09-17T10:17:54Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "M3C Administration"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.midlands3cities.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Nottingham"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://admin.vpp.midlands3cities.ac.uk/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://admin.vpp.midlands3cities.ac.uk/simplesaml/module.php/saml/sp/discoresp.php",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Virtual Postgraduate Platform administration console"
                  }
                ],
                "logo": [
                  {
                    "text": "https://vpp.midlands3cities.ac.uk/shibboleth-ds/logo_transparent.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "143"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "M3C Administration"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFnzCCBIegAwIBAgIJAJo8nGGZ+AUAMA0GCSqGSIb3DQEBBQUAMIHkMQswCQYD\n\t\t\t\t\t\tVQQGEwJVSzEYMBYGA1UECBMPTm90dGluZ2hhbXNoaXJlMRMwEQYDVQQHEwpOb3Rp\n\t\t\t\t\t\tdG5naGFtMSEwHwYDVQQKExhVbml2ZXJzaXR5IG9mIE5vdHRpbmdoYW0xHTAbBgNV\n\t\t\t\t\t\tBAsTFEluZm9ybWF0aW9uIFNlcnZpY2VzMSgwJgYDVQQDEx9hZG1pbi52cHAubWlk\n\t\t\t\t\t\tbGFuZHMzY2l0aWVzLmFjLnVrMTowOAYJKoZIhvcNAQkBFit1aS1hcHBsaWNhdGlv\n\t\t\t\t\t\tbi1kZXZlbG9wbWVudEBub3R0aW5naGFtLmFjLnVrMB4XDTE1MDgyNzA3MzA1N1oX\n\t\t\t\t\t\tDTI1MDgyNjA3MzA1N1owgeQxCzAJBgNVBAYTAlVLMRgwFgYDVQQIEw9Ob3R0aW5n\n\t\t\t\t\t\taGFtc2hpcmUxEzARBgNVBAcTCk5vdGl0bmdoYW0xITAfBgNVBAoTGFVuaXZlcnNp\n\t\t\t\t\t\tdHkgb2YgTm90dGluZ2hhbTEdMBsGA1UECxMUSW5mb3JtYXRpb24gU2VydmljZXMx\n\t\t\t\t\t\tKDAmBgNVBAMTH2FkbWluLnZwcC5taWRsYW5kczNjaXRpZXMuYWMudWsxOjA4Bgkq\n\t\t\t\t\t\thkiG9w0BCQEWK3VpLWFwcGxpY2F0aW9uLWRldmVsb3BtZW50QG5vdHRpbmdoYW0u\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCZfHcd5M8ywt10\n\t\t\t\t\t\tr1IGXI041IBcZkrf92pLr3tNki3WeDFcMc0fYgTM3bQURnQX4vPwHxGg688/KNg/\n\t\t\t\t\t\t0tTAiqdKH1z59OXbKEeRUga4iV+iS3cMJh4wdTM2j7Ii1nWkOXwucJOsYM/1Ctxk\n\t\t\t\t\t\tPsWxLbbeROEPHKDcetcItpKcgGA9L3gJmgIGW/XhNViOCw/eXsK32JY3V8rgsZnN\n\t\t\t\t\t\tLJs31ecTZrE6Xii03FgmY2CwIbclqGOcpJujOYy2IdiAkg+g0IhQQfUjJflk2487\n\t\t\t\t\t\tg9LMMr6Gs2AB80fCpbNBifxHZjiLvjVDvIOqbBRE4Dwj6QX4ATGz6MV1L8+dXb12\n\t\t\t\t\t\tRnr1JzNjAgMBAAGjggFQMIIBTDAdBgNVHQ4EFgQU0KQ+wxVQfSjnHvZStfyP7kEf\n\t\t\t\t\t\tOqUwggEbBgNVHSMEggESMIIBDoAU0KQ+wxVQfSjnHvZStfyP7kEfOqWhgeqkgecw\n\t\t\t\t\t\tgeQxCzAJBgNVBAYTAlVLMRgwFgYDVQQIEw9Ob3R0aW5naGFtc2hpcmUxEzARBgNV\n\t\t\t\t\t\tBAcTCk5vdGl0bmdoYW0xITAfBgNVBAoTGFVuaXZlcnNpdHkgb2YgTm90dGluZ2hh\n\t\t\t\t\t\tbTEdMBsGA1UECxMUSW5mb3JtYXRpb24gU2VydmljZXMxKDAmBgNVBAMTH2FkbWlu\n\t\t\t\t\t\tLnZwcC5taWRsYW5kczNjaXRpZXMuYWMudWsxOjA4BgkqhkiG9w0BCQEWK3VpLWFw\n\t\t\t\t\t\tcGxpY2F0aW9uLWRldmVsb3BtZW50QG5vdHRpbmdoYW0uYWMudWuCCQCaPJxhmfgF\n\t\t\t\t\t\tADAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAbX/FnL9VG4/wFGObq\n\t\t\t\t\t\tuHUJBbxyauoDL0EsZfC5n77GQ1y6I2S0QONYoHo73jjZChgTh4ehs7T4jEH44jIB\n\t\t\t\t\t\t9+Mk+PINIuuqAFr/O2bT3W5095QhfsSwUrflJ6EiyzbBLkwzR7lXdI+NX49Ac8t9\n\t\t\t\t\t\tix6jdDSFuFkk0mflSWK/CWbh9yg+WJSeZAMVeZouZFG5LwJc9I//Bd2QARkXDniL\n\t\t\t\t\t\tEQE0sXwP+xYb9jSS6rjHhXYbpOdp8Di6R1/WuqlytpKCZ0BSk2R/jhBdjE0eFrba\n\t\t\t\t\t\tVhBFdDAYO44lUzzsyNRuoEMSvhHWhUBp2369nuoAl0Y0qST19KxMB6UWU6GhnKa8\n\t\t\t\t\t\tMhTV"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFnzCCBIegAwIBAgIJAJo8nGGZ+AUAMA0GCSqGSIb3DQEBBQUAMIHkMQswCQYD\n\t\t\t\t\t\tVQQGEwJVSzEYMBYGA1UECBMPTm90dGluZ2hhbXNoaXJlMRMwEQYDVQQHEwpOb3Rp\n\t\t\t\t\t\tdG5naGFtMSEwHwYDVQQKExhVbml2ZXJzaXR5IG9mIE5vdHRpbmdoYW0xHTAbBgNV\n\t\t\t\t\t\tBAsTFEluZm9ybWF0aW9uIFNlcnZpY2VzMSgwJgYDVQQDEx9hZG1pbi52cHAubWlk\n\t\t\t\t\t\tbGFuZHMzY2l0aWVzLmFjLnVrMTowOAYJKoZIhvcNAQkBFit1aS1hcHBsaWNhdGlv\n\t\t\t\t\t\tbi1kZXZlbG9wbWVudEBub3R0aW5naGFtLmFjLnVrMB4XDTE1MDgyNzA3MzA1N1oX\n\t\t\t\t\t\tDTI1MDgyNjA3MzA1N1owgeQxCzAJBgNVBAYTAlVLMRgwFgYDVQQIEw9Ob3R0aW5n\n\t\t\t\t\t\taGFtc2hpcmUxEzARBgNVBAcTCk5vdGl0bmdoYW0xITAfBgNVBAoTGFVuaXZlcnNp\n\t\t\t\t\t\tdHkgb2YgTm90dGluZ2hhbTEdMBsGA1UECxMUSW5mb3JtYXRpb24gU2VydmljZXMx\n\t\t\t\t\t\tKDAmBgNVBAMTH2FkbWluLnZwcC5taWRsYW5kczNjaXRpZXMuYWMudWsxOjA4Bgkq\n\t\t\t\t\t\thkiG9w0BCQEWK3VpLWFwcGxpY2F0aW9uLWRldmVsb3BtZW50QG5vdHRpbmdoYW0u\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCZfHcd5M8ywt10\n\t\t\t\t\t\tr1IGXI041IBcZkrf92pLr3tNki3WeDFcMc0fYgTM3bQURnQX4vPwHxGg688/KNg/\n\t\t\t\t\t\t0tTAiqdKH1z59OXbKEeRUga4iV+iS3cMJh4wdTM2j7Ii1nWkOXwucJOsYM/1Ctxk\n\t\t\t\t\t\tPsWxLbbeROEPHKDcetcItpKcgGA9L3gJmgIGW/XhNViOCw/eXsK32JY3V8rgsZnN\n\t\t\t\t\t\tLJs31ecTZrE6Xii03FgmY2CwIbclqGOcpJujOYy2IdiAkg+g0IhQQfUjJflk2487\n\t\t\t\t\t\tg9LMMr6Gs2AB80fCpbNBifxHZjiLvjVDvIOqbBRE4Dwj6QX4ATGz6MV1L8+dXb12\n\t\t\t\t\t\tRnr1JzNjAgMBAAGjggFQMIIBTDAdBgNVHQ4EFgQU0KQ+wxVQfSjnHvZStfyP7kEf\n\t\t\t\t\t\tOqUwggEbBgNVHSMEggESMIIBDoAU0KQ+wxVQfSjnHvZStfyP7kEfOqWhgeqkgecw\n\t\t\t\t\t\tgeQxCzAJBgNVBAYTAlVLMRgwFgYDVQQIEw9Ob3R0aW5naGFtc2hpcmUxEzARBgNV\n\t\t\t\t\t\tBAcTCk5vdGl0bmdoYW0xITAfBgNVBAoTGFVuaXZlcnNpdHkgb2YgTm90dGluZ2hh\n\t\t\t\t\t\tbTEdMBsGA1UECxMUSW5mb3JtYXRpb24gU2VydmljZXMxKDAmBgNVBAMTH2FkbWlu\n\t\t\t\t\t\tLnZwcC5taWRsYW5kczNjaXRpZXMuYWMudWsxOjA4BgkqhkiG9w0BCQEWK3VpLWFw\n\t\t\t\t\t\tcGxpY2F0aW9uLWRldmVsb3BtZW50QG5vdHRpbmdoYW0uYWMudWuCCQCaPJxhmfgF\n\t\t\t\t\t\tADAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAbX/FnL9VG4/wFGObq\n\t\t\t\t\t\tuHUJBbxyauoDL0EsZfC5n77GQ1y6I2S0QONYoHo73jjZChgTh4ehs7T4jEH44jIB\n\t\t\t\t\t\t9+Mk+PINIuuqAFr/O2bT3W5095QhfsSwUrflJ6EiyzbBLkwzR7lXdI+NX49Ac8t9\n\t\t\t\t\t\tix6jdDSFuFkk0mflSWK/CWbh9yg+WJSeZAMVeZouZFG5LwJc9I//Bd2QARkXDniL\n\t\t\t\t\t\tEQE0sXwP+xYb9jSS6rjHhXYbpOdp8Di6R1/WuqlytpKCZ0BSk2R/jhBdjE0eFrba\n\t\t\t\t\t\tVhBFdDAYO44lUzzsyNRuoEMSvhHWhUBp2369nuoAl0Y0qST19KxMB6UWU6GhnKa8\n\t\t\t\t\t\tMhTV"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://admin.vpp.midlands3cities.ac.uk/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://admin.vpp.midlands3cities.ac.uk/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://admin.vpp.midlands3cities.ac.uk/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://admin.vpp.midlands3cities.ac.uk/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.nurseryworld.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pollard"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tom.pollard@markallengroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tom"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dixon"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul@liblynx.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.nurseryworld.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-07-15T09:25:05Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Nursery World"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.markallengroup.com/ma-education/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LibLynx LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nurseryworld-mag-shib.liblynx.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nurseryworld-mag-shib.liblynx.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nurseryworld-mag-shib.liblynx.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nurseryworld-mag-shib.liblynx.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nurseryworld-mag-shib.liblynx.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://nurseryworld-mag-shib.liblynx.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Nursery World is a magazine for practitioners across the early years of education and childcare"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Nursery World"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6DCCAdCgAwIBAgIJAKKEvzTa1baZMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\n\t\t\t\t\t\tBAMTC2xpYmx5bnguY29tMB4XDTE1MDcwMTE0MzA1OFoXDTI1MDYyODE0MzA1OFow\n\t\t\t\t\t\tFjEUMBIGA1UEAxMLbGlibHlueC5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQC/tN/ehV2IQ8427sENebb+6ij+VoiIirTDNTOtvOa9ff3Yk5L+8VaS\n\t\t\t\t\t\tn5AUPJ7X4JHXl6rMIz0Vy8aaP+jeWy+oTUnNfNAXJz3CGqz3+GYST4qCbUfi071y\n\t\t\t\t\t\taZEiw/zD3PG2XjCI1iB4jojVEMOZvUNMXw2Fp2hAdeR1E4Jct6wHiPioDzKXCm5o\n\t\t\t\t\t\tEpR0EhYRDBQ5KD1pNulD219uFxmeq4sg4Yhw3e87dN0Mf+DYIm32ApXQfCj37lQm\n\t\t\t\t\t\tY3E5U/fDBaM1Du54+hWrRi4NzzHpCCmA6AfeMcyoUUmL67wc4vXePh+b1ZPtM1Dn\n\t\t\t\t\t\trsjH86EUcCZVBNp1c9nb6KO5uWfw3a7hAgMBAAGjOTA3MBYGA1UdEQQPMA2CC2xp\n\t\t\t\t\t\tYmx5bnguY29tMB0GA1UdDgQWBBRhxZ/MN/oyiZyi9iRBE2VmvDGllDANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAM1eUF5GIiZPHhmhN7mWhiNmM9cC9q+hR+BZjfBjOFyvHmUry\n\t\t\t\t\t\tXKWaq+5GVG/yZBtD8hnQAanLCBFT7iPXyPDeMkkf3CYwEScRZglVJqffn2v7rpO/\n\t\t\t\t\t\tgqam0j1tzRAgvYbZXBe/u71qFVN57b5w6XPq0rONkq1HlFPLz1kZ/RPeDPxsy1m1\n\t\t\t\t\t\tBD9Air6XaXKVUCuozkcpnDIQqDfrx+VdsHqi03T4H4UgQrqjx/C+eASsFH9qQsBz\n\t\t\t\t\t\t7wGBxTNZk8z8Ob/CFJI79t38xZnP8cBEr4vlE27ld7HGu1mzBZPi6d4pAhpOcIvG\n\t\t\t\t\t\ttkJW/9JlQ93sBxUk0E1HbTlYxtXFbNCVwqEWcg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nurseryworld-mag-shib.liblynx.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://nurseryworld-mag-shib.liblynx.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nurseryworld-mag-shib.liblynx.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://nurseryworld-mag-shib.liblynx.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://nurseryworld-mag-shib.liblynx.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://nurseryworld-mag-shib.liblynx.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://qa.dawsonera.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:daw-shibboleth-support@semantico.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:daw-shibboleth-support@semantico.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://qa.dawsonera.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-04-12T13:17:34Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Dawson Shibboleth 2 SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dawsonbooks.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Semantico Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://qa.dawsonera.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://qa.dawsonera.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://qa.dawsonera.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://qa.dawsonera.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://qa.dawsonera.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://qa.dawsonera.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://qa.dawsonera.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiQCCQC0Ky/bIMuQajANBgkqhkiG9w0BAQUFADBgMQswCQYDVQQGEwJV\n\t\t\t\t\t\tSzEPMA0GA1UECBMGU3Vzc2V4MREwDwYDVQQHEwhCcmlnaHRvbjESMBAGA1UEChMJ\n\t\t\t\t\t\tc2VtYW50aWNvMRkwFwYDVQQDExBxYS5kYXdzb25lcmEuY29tMB4XDTEzMDQxMDA5\n\t\t\t\t\t\tNTMzMVoXDTE1MDQxMDA5NTMzMVowYDELMAkGA1UEBhMCVUsxDzANBgNVBAgTBlN1\n\t\t\t\t\t\tc3NleDERMA8GA1UEBxMIQnJpZ2h0b24xEjAQBgNVBAoTCXNlbWFudGljbzEZMBcG\n\t\t\t\t\t\tA1UEAxMQcWEuZGF3c29uZXJhLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\n\t\t\t\t\t\tAQoCggEBAMk2vJiHzuv5fLpisAaVQFFIQVgcxiLnq1IUgsDD2b2dZwbJ+jnc9L0W\n\t\t\t\t\t\tlRUVg7UczlTX6yFDMHXexbLr2ZK5kzamWSwPyi5VEvxrFTJk6RYHoV+OCLdqBugX\n\t\t\t\t\t\tb7nb3k3tvtdY4M1tvNiepfxeEGvB/j2+vThdG8ziwxk9o4OoRfW5EcXI7LJiJkIx\n\t\t\t\t\t\tlVtxQHyZ4ZzFsNx+pgaJcGuf6BXRSJ3AOUezkPGaBOLKyBeMTgwvANubCzQy6GXI\n\t\t\t\t\t\tSVdOM5qCMMEpsjp9Bob242iJo07deEv9um7bBI4pGlE2y85PNYnIXqhnFKlqN+wP\n\t\t\t\t\t\tn4/JgFJ4f/uiz3MNULKFd7dT6zvNhRkCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tt3FU0AH1Cg/vyOcNtqk2UW67h0M8TXzya9QlYBjNPeeD2b2FxWYOWckYyxp73QUE\n\t\t\t\t\t\tMDm/lzz9Vnt3uUR53DuidNfSwoh1xoDZWxCa04wFq41+dv+K+KTpMtbCx3LEWkm4\n\t\t\t\t\t\tfE/AIcvD/5i0IR0UYvgyElJC8ZA5gINZQGs7GUHOWl+WSJATVZ04NMkSu81ecgPR\n\t\t\t\t\t\tuAgAlVn4CIs6BK7w+GYmGIMPh+TOwuBeA9RXPVtYV1/DOi8J488bu1t1BRSzgFAZ\n\t\t\t\t\t\t0LfHeCvTazIS97MK6v6zLztr5TE2Up0bGuY40AQ7os+Cve3PiPyZvwj/sh0bYWzY\n\t\t\t\t\t\taghk88mgQ85rliDI3J2b+A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://qa.dawsonera.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://qa.dawsonera.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://qa.dawsonera.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://qa.dawsonera.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://qa.dawsonera.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://qa.dawsonera.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://qa.dawsonera.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://qa.dawsonera.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://qa.dawsonera.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://qa.dawsonera.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://data.houseoffinance.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Palombo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Carmine.Palombo@hhs.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Carmine"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://data.houseoffinance.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://data.houseoffinance.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://data.houseoffinance.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://data.houseoffinance.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://data.houseoffinance.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://data.houseoffinance.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://data.houseoffinance.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://data.houseoffinance.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Swedish House of Finance"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Swedish House of Finance"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "data.houseoffinance.se"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://data.houseoffinance.se/shibboleth"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIJAK6AAcNNJjCuMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmRhdGEuaG91c2VvZmZpbmFuY2Uuc2UwHhcNMTYwMzA4MTQ0NDA4WhcNMjYw\nMzA2MTQ0NDA4WjAhMR8wHQYDVQQDExZkYXRhLmhvdXNlb2ZmaW5hbmNlLnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArPSJOxt5DXZw813HFzlM/0c/\nU6DOZsICjNSMPzNCRYT2jDXdt4WkublVvcgFVZ0p0ZIJThGy+rTe/S1m9vW5Kxr7\nA+nC2hB1k4bEWJgTbU2xNsZbRwVTSkfctDlvSYgHaZg/mm7y4ZEbS8qhD0GpiIMB\nZ5B6OM4CT7gehdjw3TUGDyPiL569SpBj4usCkMME4Vs/jdQje96AXOv67ARfTDTC\nScGum48q+Em7bI++P2XPqpaSc4PfEh7x/K/ZP29FN+Hb2nmCPaWWCCX12IaHqwr+\ng6mLlY4cpBbg69aAmDVlchEIHcttL0LR3BbhdWDieysJsxAriDKDxct92P1CvwID\nAQABo28wbTBMBgNVHREERTBDghZkYXRhLmhvdXNlb2ZmaW5hbmNlLnNlhilodHRw\nczovL2RhdGEuaG91c2VvZmZpbmFuY2Uuc2Uvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\nAAZRAurfsXSsARjq6KTFryG1y0gwDQYJKoZIhvcNAQEFBQADggEBAFxU/bQoQTvF\nRecwpsLhwannPUVhxmW8+w4RyXGFaKiveT/4O/wJ5iszliY8/12BSRoh99jUaiKi\nqDpm0+hWbZ1BcFeK+gp4d2n3xyMzt5RrrnxmdXN8ygAETvd48JR4uIU5gumHz6v+\nkaD7h06doeo/UNKCaTDf+Dn32jXXmzuX+pPO++cWmFuU51sx+ipDV3zEYTR/WBuf\n9ZwzASroyK/ophVGVZO6u/hk2z4voVjJ43WCkOc5BeWBGM0wyybaHbcNC0mD0xdF\nvIKmtAthocLF3GRtKL/ft5Ncl85OzrHGQjxFfqlQL46cZL3X/Xqu3ilgHNw8xTrX\nbi+i8GP0b/0="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=data.houseoffinance.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://data.houseoffinance.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://collectionsmanager.is.ed.ac.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:information.systems@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Information Systems"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lddt@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Library Digital Development Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://collectionsmanager.is.ed.ac.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-08-15T13:43:53Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Edinburgh Collections Manager"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://collectionsmanager.is.ed.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://collectionsmanager.is.ed.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "DSpace installation for managing the University\n\t\t\t\tof Edinburgh collection level descriptions and collection items."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Edinburgh Collections Manager Test"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJALy03M7u1gVPMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\n\t\t\t\t\t\tBAMTG2xhYy1yZXBvLWxpdmUxMS5pcy5lZC5hYy51azAeFw0xNDA4MTExNjE2MDVa\n\t\t\t\t\t\tFw0yNDA4MDgxNjE2MDVaMCYxJDAiBgNVBAMTG2xhYy1yZXBvLWxpdmUxMS5pcy5l\n\t\t\t\t\t\tZC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALxmqAyAZJll\n\t\t\t\t\t\tNsHWH/yK4hSEiqk/Ln1dF9FktB5rzP7FaUWIYL/Q9Igqr8UDqRBi+KTTFePHhi8k\n\t\t\t\t\t\tH3E8Yh473ej0a1d2s2DtMIzVNjXMMaQxEksZGADtPp00L6SrvYZAtb5gIT71nATb\n\t\t\t\t\t\tSIaoZWH2hyO9Ods6zhwU6uv4xogyHiL1Kmxz9jecJ/xIwXmn2twFgrLpRtjrHhzl\n\t\t\t\t\t\tXYrDlSRX49rVsB4Ey8dBPGTgkfbJbk4ZkxFnKMOw9Lw0GBoVWtY7Vn9RPWbISPD/\n\t\t\t\t\t\t+4y3CTwJbnljeJpZey0KTrOkHXQ8GqRBswEYJCHWBVrH6cmgdnGnciDnN1TttSOF\n\t\t\t\t\t\tJM9XR+AgFfMCAwEAAaNJMEcwJgYDVR0RBB8wHYIbbGFjLXJlcG8tbGl2ZTExLmlz\n\t\t\t\t\t\tLmVkLmFjLnVrMB0GA1UdDgQWBBQ1Ofx7Y4foN2eFktuJ0I1n+WcNJzANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAjuI/UTy4EX8iQHPxVWxioob3+ORavEe+FX3sAEsfPeTNaFt2\n\t\t\t\t\t\tbf1iFA90DwZBDLPAhUgGiMegR/qb6Uh+m7y4GznSK3esxyjssxuDSPpO2yipw2Pb\n\t\t\t\t\t\t5M0dhW7gGi6CK0jWi/91WMNytDCW4RbTGDEXLBGO344Mhmbu163V0a656/Gub1hz\n\t\t\t\t\t\tXlShSl3z0t8E32ipwG2X9d8JTAaqHtcdW001sfyAibFQh2y8a7ozLCQHmSXUcFde\n\t\t\t\t\t\tNOR1PCznRoAlRPp4Wd8nBVPDNbHIzHT7QkYmx3iKPYKZXRMR7icUh6vyzUxskdjr\n\t\t\t\t\t\tp1m+/fC5uLdMuu57gH/cV696hZae6vVbcI2R2g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://collectionsmanager.is.ed.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ibp.cas.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Van\u00ed\u010dek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vanicekp@utia.cas.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ibp.cas.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2014-07-25T15:25:07Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/avcr"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAKW2EZM9liIS9zxSJj2keamQoSWxMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC5pYnAuY2FzLmN6MB4XDTE0MDcyNDA5NDU1MFoX\nDTM0MDcyNDA5NDU1MFowGTEXMBUGA1UEAxMOaWRwLmlicC5jYXMuY3owggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDCcjIT8YIRLlcj3VCCeqa2qSwK2Ugb\nohvyVmx4dldYsP2NpqFM8Hvzmor0Sq+h0CTDAnvsDhpnHTSNC+bWh4nCKahiBZ0b\nGqMMiatHYsq6DawZCRRzI7bKiGmGIxsG5YaqmqBTjvHhsePzkedn5qIp5PEYi+MG\naL/oQ1UVBsVW0dZGzMpockzxJAbut+kNlC99OsSWoQ/MyDVcPqu36QUaebahQUzF\nhDAB5ZvS+6PylulTmbWHPG5RRtgwNyfGxqpJupbeckt8BN3k5t9ydxNZsI4zyjbn\nySbdYYhka/8/qOSvGoyg7RAvoqqR2PK417kHc2Ien96u7Q+lMwGKmKOpAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC5pYnAuY2FzLmN6hiVodHRwczovL2lkcC5pYnAu\nY2FzLmN6L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRtafM3sXw4M6AoCL8uynsW\n7CQJQzANBgkqhkiG9w0BAQUFAAOCAQEAlujcijW6c8cVu5QpYIxE2g2AiM9MEf7q\ngBHtO2oSuseSHv6h1ZWNA/9qGg2LPWc1T+QWBQZbT16VyGig5Moxb1J8VPxfv+A0\neQHoLsBTLVP06npY3NztVm3xogPnpwUcjUagECmar/HKkQ8hMeVatK/o3MR05XRC\nssOxXuhGNkdEqrBAYJ+ABQSCw0yK9qkA0URqksCGHN4jpmflwa4e+PY/DBlHzn1w\nu9Mna/iP3SHv09aTqAt9DjGGf+3oQRVkybSpdpdgRbXotUyhoGgCazhsWLCSvZke\nzaDcul2ivMCAW6N+57bhddfKSw9fgoTN5yhdbE17rpMTCk3OMSjfNQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ibp.cas.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ibp.cas.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ibp.cas.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ibp.cas.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ibp.cas.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ibp.cas.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ibp.cas.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ibp.cas.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ibp.cas.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ibp.cas.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ibp.cas.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ibp.cas.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ibp.cas.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ibp.cz/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ibp.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider IBP AV CR employees."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance BF\u00da AV \u010cR"
                  }
                ],
                "logo": [
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-ibp-44.png",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "81"
                  },
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-ibp-65.png",
                    "height": "65",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "120"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Biophysics AS CR"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Biofyzik\u00e1ln\u00ed \u00fastav AV \u010cR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAKW2EZM9liIS9zxSJj2keamQoSWxMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC5pYnAuY2FzLmN6MB4XDTE0MDcyNDA5NDU1MFoX\nDTM0MDcyNDA5NDU1MFowGTEXMBUGA1UEAxMOaWRwLmlicC5jYXMuY3owggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDCcjIT8YIRLlcj3VCCeqa2qSwK2Ugb\nohvyVmx4dldYsP2NpqFM8Hvzmor0Sq+h0CTDAnvsDhpnHTSNC+bWh4nCKahiBZ0b\nGqMMiatHYsq6DawZCRRzI7bKiGmGIxsG5YaqmqBTjvHhsePzkedn5qIp5PEYi+MG\naL/oQ1UVBsVW0dZGzMpockzxJAbut+kNlC99OsSWoQ/MyDVcPqu36QUaebahQUzF\nhDAB5ZvS+6PylulTmbWHPG5RRtgwNyfGxqpJupbeckt8BN3k5t9ydxNZsI4zyjbn\nySbdYYhka/8/qOSvGoyg7RAvoqqR2PK417kHc2Ien96u7Q+lMwGKmKOpAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC5pYnAuY2FzLmN6hiVodHRwczovL2lkcC5pYnAu\nY2FzLmN6L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRtafM3sXw4M6AoCL8uynsW\n7CQJQzANBgkqhkiG9w0BAQUFAAOCAQEAlujcijW6c8cVu5QpYIxE2g2AiM9MEf7q\ngBHtO2oSuseSHv6h1ZWNA/9qGg2LPWc1T+QWBQZbT16VyGig5Moxb1J8VPxfv+A0\neQHoLsBTLVP06npY3NztVm3xogPnpwUcjUagECmar/HKkQ8hMeVatK/o3MR05XRC\nssOxXuhGNkdEqrBAYJ+ABQSCw0yK9qkA0URqksCGHN4jpmflwa4e+PY/DBlHzn1w\nu9Mna/iP3SHv09aTqAt9DjGGf+3oQRVkybSpdpdgRbXotUyhoGgCazhsWLCSvZke\nzaDcul2ivMCAW6N+57bhddfKSw9fgoTN5yhdbE17rpMTCk3OMSjfNQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Biophysics AS CR, v.v.i."
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Biofyzik\u00e1ln\u00ed \u00fastav AV \u010cR, v.v.i."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ibp.cz/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ibp.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Biophysics AS CR"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Biofyzik\u00e1ln\u00ed \u00fastav AV \u010cR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://srmo.sagepub.com/oa/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:onlinesupport@sagepub.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sage Online Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smith"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rob.smith@sagepub.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rob"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://srmo.sagepub.com/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-05-19T09:13:02Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SAGE Research Methods"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sagepublications.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SAGE Publications Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://srmo.sagepub.com/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://srmo.sagepub.com/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://srmo.sagepub.com/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://srmo.sagepub.com/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8jCCAdqgAwIBAgIEU3YWujANBgkqhkiG9w0BAQUFADA7MR4wHAYDVQQKExVT\n\t\t\t\t\t\tQUdFIFJlc2VhcmNoIE1ldGhvZHMxGTAXBgNVBAMTEHNybW8uc2FnZXB1Yi5jb20w\n\t\t\t\t\t\tHhcNMTQwNTE2MTM0NjM0WhcNMjQwNTEzMTM0NjM0WjA7MR4wHAYDVQQKExVTQUdF\n\t\t\t\t\t\tIFJlc2VhcmNoIE1ldGhvZHMxGTAXBgNVBAMTEHNybW8uc2FnZXB1Yi5jb20wggEi\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCAj7S6njJm0RnWWITsCrEtFaXe\n\t\t\t\t\t\tfOL5sO/jeFs1OdsMOdJvrF2W1ogslAV1Dg7SnF/aVeOkybQbE1iA8astIPLf1qv/\n\t\t\t\t\t\tFcv6a8lSlGBk3hMFX6ye3431lqw1nsF53S/TUzEflixBjxO7j9QcM2l4wRLwuo9M\n\t\t\t\t\t\tW2qYrOw2AfxE7vca3fDICdhtfcQIkHFnkLi67bhR6rFqTjwz1cj38RXXz2c2TSPA\n\t\t\t\t\t\tfTjRZoePMNqDaucNcBVrT9KqXxWJBr8zqMrC5CUYGCuYiqNB8MbHdW/o14ah4uVl\n\t\t\t\t\t\tZB0B9iJ2eGmA5tzs+dTKzcspDpF11LS0i3RMBysfFB+Grj3mu5GgFGDnVW5nAgMB\n\t\t\t\t\t\tAAEwDQYJKoZIhvcNAQEFBQADggEBAEV8fmC0KbKrXDKBq5ZDrvRRoFZMynTWnkMs\n\t\t\t\t\t\tKT2ImrfxpIbv+XO06lWAh5j8XIgV5tqTTam9IpcudEOxjmd6imwQ4qTdc2MbFzRR\n\t\t\t\t\t\tX4HG+J+GOuvH6ZhCSfWEoZRqRkw6c/PCokyWeYkXPPL24d8zVDWcVKQBngMPtopE\n\t\t\t\t\t\tyJpPVcRPu71eZ5KOarxT9nawAzAhuVrMLrhlg8yqEWa66y1AZwtasasFZXqlkVI+\n\t\t\t\t\t\tdxiaed8zkkHD2w69AjFwKA1RnhTTbrC2bKzUdcqOHonpyPPUap0inRbmqUjKzQCl\n\t\t\t\t\t\t55ck9QM2cw42xmEUlINH1J6X6dML/U+SLIf6kozvqhrPqJTWnAA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8jCCAdqgAwIBAgIEU3YWujANBgkqhkiG9w0BAQUFADA7MR4wHAYDVQQKExVT\n\t\t\t\t\t\tQUdFIFJlc2VhcmNoIE1ldGhvZHMxGTAXBgNVBAMTEHNybW8uc2FnZXB1Yi5jb20w\n\t\t\t\t\t\tHhcNMTQwNTE2MTM0NjM0WhcNMjQwNTEzMTM0NjM0WjA7MR4wHAYDVQQKExVTQUdF\n\t\t\t\t\t\tIFJlc2VhcmNoIE1ldGhvZHMxGTAXBgNVBAMTEHNybW8uc2FnZXB1Yi5jb20wggEi\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCAj7S6njJm0RnWWITsCrEtFaXe\n\t\t\t\t\t\tfOL5sO/jeFs1OdsMOdJvrF2W1ogslAV1Dg7SnF/aVeOkybQbE1iA8astIPLf1qv/\n\t\t\t\t\t\tFcv6a8lSlGBk3hMFX6ye3431lqw1nsF53S/TUzEflixBjxO7j9QcM2l4wRLwuo9M\n\t\t\t\t\t\tW2qYrOw2AfxE7vca3fDICdhtfcQIkHFnkLi67bhR6rFqTjwz1cj38RXXz2c2TSPA\n\t\t\t\t\t\tfTjRZoePMNqDaucNcBVrT9KqXxWJBr8zqMrC5CUYGCuYiqNB8MbHdW/o14ah4uVl\n\t\t\t\t\t\tZB0B9iJ2eGmA5tzs+dTKzcspDpF11LS0i3RMBysfFB+Grj3mu5GgFGDnVW5nAgMB\n\t\t\t\t\t\tAAEwDQYJKoZIhvcNAQEFBQADggEBAEV8fmC0KbKrXDKBq5ZDrvRRoFZMynTWnkMs\n\t\t\t\t\t\tKT2ImrfxpIbv+XO06lWAh5j8XIgV5tqTTam9IpcudEOxjmd6imwQ4qTdc2MbFzRR\n\t\t\t\t\t\tX4HG+J+GOuvH6ZhCSfWEoZRqRkw6c/PCokyWeYkXPPL24d8zVDWcVKQBngMPtopE\n\t\t\t\t\t\tyJpPVcRPu71eZ5KOarxT9nawAzAhuVrMLrhlg8yqEWa66y1AZwtasasFZXqlkVI+\n\t\t\t\t\t\tdxiaed8zkkHD2w69AjFwKA1RnhTTbrC2bKzUdcqOHonpyPPUap0inRbmqUjKzQCl\n\t\t\t\t\t\t55ck9QM2cw42xmEUlINH1J6X6dML/U+SLIf6kozvqhrPqJTWnAA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SAGE Research Methods"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://www.cardiffstudents.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.cardiffstudents.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-10-11T15:15:02Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cardiff University Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cardiffstudents.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cardiffstudents.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cardiffstudents.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.cardiffstudents.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cardiffstudents.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cardiffstudents.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.cardiffstudents.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.cardiffstudents.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cardiffstudents.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.cardiffstudents.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cardiffstudents.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.cardiffstudents.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.cardiffstudents.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.cardiffstudents.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.tower.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.tower.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/tower.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/tower.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tower.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Tower Hamlets College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tower.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://mailfilter.nordu.net/shibboleth",
    {
      "entity_id": "https://mailfilter.nordu.net/shibboleth",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mailfilter.nordu.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mailfilter.nordu.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mailfilter.nordu.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mailfilter.nordu.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SUNET Mailfilter Service"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "SUNET Mailfilter Service"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mailfilter.nordu.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://mailfilter.nordu.net/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://mailfilter.nordu.net/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "mailfilter.sunet.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJAJ5oV5rQ7B3hMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE21haWxmaWx0ZXIuc3VuZXQuc2UwHhcNMTAwODI2MTk0NDIyWhcNMjAwODIz\nMTk0NDIyWjAeMRwwGgYDVQQDExNtYWlsZmlsdGVyLnN1bmV0LnNlMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuwGz7eWqtVCW3Be28I+IPpODVQDPQIwi\nchEFFSJdlkF7c9XN806yVAaGvsOrnNaFUTM5h/Gc4Hak1A0puoLI1aMkyeA0sMWb\nMi6owbVDrjXGoD4gAoC9AIhqfj0NtE8zGlbGsL0dezM68NJwIt2C30U1rzOfUS53\nrngSTvleQK0lnd8I2Sys+msN6kP+4N64A3IBg6A2AVZtaadB6fJIoxQrQOhU3N1U\nAfaK8TcLaclVC5PfiwuJuiSLM0RgMy68B0Fht0V6lUpdiBoF5nU4sKAVYjZz+ZHo\npi6sntIe+FchSvmDXf7zqqLS/NQiM+bD65T/nvazAbtBIbKmWb817wIDAQABo0Ew\nPzAeBgNVHREEFzAVghNtYWlsZmlsdGVyLnN1bmV0LnNlMB0GA1UdDgQWBBQ+3/bs\nSg4SKO4FCGqYge9BF2au7TANBgkqhkiG9w0BAQUFAAOCAQEAVxV3i2vePzZeSjyy\n/i7KiU62byrG6YVBpUnmuofRuNtrC0pvnEMlGYI93pqOuQOe0sw5CEweIIyeTfQ2\n7AlQPA3kiIyvG1mubSJH421oJWXt1GJD/RRH56uJtGUzOykEC350lwcQ3chnQauO\nTJuwybaXhBX3CiHaq2aUt4rLRCiY4q3i2n0x/K5h3YajaI1I/6kSmA/2i6N7kUM3\nywk5dDSfqTd62MTtqC8hJXQj0pQlQ/9GBeoyE83uTSrPR+Fo3bcGPu6WPs3FeQY5\nEeerFHSYV6H0U7y47ZJcBMX2n4xZXMZbTYTlX1AHOYiU3y7I/ZCvSuZScFBK5Lk/\nKHCx/w=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=mailfilter.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "mailfilter.sunet.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJAJ5oV5rQ7B3hMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE21haWxmaWx0ZXIuc3VuZXQuc2UwHhcNMTAwODI2MTk0NDIyWhcNMjAwODIz\nMTk0NDIyWjAeMRwwGgYDVQQDExNtYWlsZmlsdGVyLnN1bmV0LnNlMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuwGz7eWqtVCW3Be28I+IPpODVQDPQIwi\nchEFFSJdlkF7c9XN806yVAaGvsOrnNaFUTM5h/Gc4Hak1A0puoLI1aMkyeA0sMWb\nMi6owbVDrjXGoD4gAoC9AIhqfj0NtE8zGlbGsL0dezM68NJwIt2C30U1rzOfUS53\nrngSTvleQK0lnd8I2Sys+msN6kP+4N64A3IBg6A2AVZtaadB6fJIoxQrQOhU3N1U\nAfaK8TcLaclVC5PfiwuJuiSLM0RgMy68B0Fht0V6lUpdiBoF5nU4sKAVYjZz+ZHo\npi6sntIe+FchSvmDXf7zqqLS/NQiM+bD65T/nvazAbtBIbKmWb817wIDAQABo0Ew\nPzAeBgNVHREEFzAVghNtYWlsZmlsdGVyLnN1bmV0LnNlMB0GA1UdDgQWBBQ+3/bs\nSg4SKO4FCGqYge9BF2au7TANBgkqhkiG9w0BAQUFAAOCAQEAVxV3i2vePzZeSjyy\n/i7KiU62byrG6YVBpUnmuofRuNtrC0pvnEMlGYI93pqOuQOe0sw5CEweIIyeTfQ2\n7AlQPA3kiIyvG1mubSJH421oJWXt1GJD/RRH56uJtGUzOykEC350lwcQ3chnQauO\nTJuwybaXhBX3CiHaq2aUt4rLRCiY4q3i2n0x/K5h3YajaI1I/6kSmA/2i6N7kUM3\nywk5dDSfqTd62MTtqC8hJXQj0pQlQ/9GBeoyE83uTSrPR+Fo3bcGPu6WPs3FeQY5\nEeerFHSYV6H0U7y47ZJcBMX2n4xZXMZbTYTlX1AHOYiU3y7I/ZCvSuZScFBK5Lk/\nKHCx/w=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=mailfilter.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mailfilter.nordu.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mailfilter.nordu.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mailfilter.nordu.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mailfilter.nordu.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mailfilter.nordu.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://mailfilter.nordu.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mailfilter.nordu.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://mailfilter.nordu.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://mailfilter.nordu.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://mailfilter.nordu.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://adfs.fom.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs.fom.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-04-29T12:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/11b0d7eaaf1673ff0728ec7b46331c27",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Stichting voor Fundamenteel Onderzoek der Materie - bureau"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Foundation for Fundamental Research on Matter - bureau"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/fom.png",
                    "height": "300",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "500"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FOM-bureau"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FOM-bureau"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "FOM-bureau"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "FOM-bureau"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fom.nl"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fom.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "FOM-bureau"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "FOM-bureau"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.newbold.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.newbold.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/newbold.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/newbold.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "newbold.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Newbold College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.newbold.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.aua.gr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lekatsas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "alex@aua.gr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alexandros"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lekatsas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "alex@aua.gr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alexandros"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.aua.gr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEYTCCA0mgAwIBAgIQLao5DrjKl4jtinW5yqZdmDANBgkqhkiG9w0BAQUFADA2\n                            MQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n                            U1NMIENBMB4XDTEzMDcxNTAwMDAwMFoXDTE2MDcxNDIzNTk1OVowODEhMB8GA1UE\n                            CxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRMwEQYDVQQDEwppZHAuYXVhLmdy\n                            MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAudMiLYCnGTOdy3cDiHPh\n                            4YtBdPR5g9XEXhVD8bCLlYY64H8RGiZlkBlfEYOKc8JR20/hbHlGotP9wcibK8GP\n                            ZJ1w7qll1oiE8OAU+9KzpzZYzLJ8pwuCOpiqfy4SztBK0JUq9Nd0tCjQ4B+v9gnm\n                            cBzqiE+1vQ/5CBnEhGg+Oy5jzyHQVSnQ241CT3VsjIRs1ZzBtI/EODNnnamV/d1x\n                            zZwqybklD3jOMzRzvcAOV3aaTJrFma2rt3tWpdAykO4EMNQRu6DFmZv7TcbVElIy\n                            T9PiA9Bvjaj99V/8oP2vcYEMf7Le0Zg0KGSegNRXmkDe2j/ltzq7dMKfeIz9zLOu\n                            3QIDAQABo4IBZzCCAWMwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH6pDjue0w\n                            HQYDVR0OBBYEFEJL3TxlxKi8XGNZygQlIqZA9dmjMA4GA1UdDwEB/wQEAwIFoDAM\n                            BgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNV\n                            HSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAxMC+gLaAr\n                            hilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNybDBtBggr\n                            BgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5v\n                            cmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8vb2NzcC50Y3Mu\n                            dGVyZW5hLm9yZzAVBgNVHREEDjAMggppZHAuYXVhLmdyMA0GCSqGSIb3DQEBBQUA\n                            A4IBAQAIQM5R4k0UvejW0sGjN8BjY3SI9NCqGpWqa2KvahG0S7hKseCLRhasrORa\n                            rBlW2Fc4ANdbt2ixp9GBFq+0Jr8uI8Gk4yuQsPEJ4TBp3rywC43QFE2MXyhzgCso\n                            wgA5AjFA+5k8ceZN6PK0O6bWcNyNdgFsIF4KgW/+SelgxT8AnJYG0GRUBAf3DIrQ\n                            Nuw5bEgQ0r45EPQALqs2qKANJDWNiC4Ad5WB5QkVbw/eODpQXGbOVyV6vbb++0df\n                            mQptmsByxpJOAuAuzFRgct/YD2rGwiP2/iuL/QX2wSvWZpABTSAPaynG10ScZl55\n                            HWQrDaq4qyBzo7Flcck4QDjBirDo"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aua.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.aua.gr:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.aua.gr:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.aua.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.aua.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.aua.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.aua.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.aua.gr:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.aua.gr:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aua.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEYTCCA0mgAwIBAgIQLao5DrjKl4jtinW5yqZdmDANBgkqhkiG9w0BAQUFADA2\n                            MQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n                            U1NMIENBMB4XDTEzMDcxNTAwMDAwMFoXDTE2MDcxNDIzNTk1OVowODEhMB8GA1UE\n                            CxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRMwEQYDVQQDEwppZHAuYXVhLmdy\n                            MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAudMiLYCnGTOdy3cDiHPh\n                            4YtBdPR5g9XEXhVD8bCLlYY64H8RGiZlkBlfEYOKc8JR20/hbHlGotP9wcibK8GP\n                            ZJ1w7qll1oiE8OAU+9KzpzZYzLJ8pwuCOpiqfy4SztBK0JUq9Nd0tCjQ4B+v9gnm\n                            cBzqiE+1vQ/5CBnEhGg+Oy5jzyHQVSnQ241CT3VsjIRs1ZzBtI/EODNnnamV/d1x\n                            zZwqybklD3jOMzRzvcAOV3aaTJrFma2rt3tWpdAykO4EMNQRu6DFmZv7TcbVElIy\n                            T9PiA9Bvjaj99V/8oP2vcYEMf7Le0Zg0KGSegNRXmkDe2j/ltzq7dMKfeIz9zLOu\n                            3QIDAQABo4IBZzCCAWMwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH6pDjue0w\n                            HQYDVR0OBBYEFEJL3TxlxKi8XGNZygQlIqZA9dmjMA4GA1UdDwEB/wQEAwIFoDAM\n                            BgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNV\n                            HSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAxMC+gLaAr\n                            hilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNybDBtBggr\n                            BgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5v\n                            cmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8vb2NzcC50Y3Mu\n                            dGVyZW5hLm9yZzAVBgNVHREEDjAMggppZHAuYXVhLmdyMA0GCSqGSIb3DQEBBQUA\n                            A4IBAQAIQM5R4k0UvejW0sGjN8BjY3SI9NCqGpWqa2KvahG0S7hKseCLRhasrORa\n                            rBlW2Fc4ANdbt2ixp9GBFq+0Jr8uI8Gk4yuQsPEJ4TBp3rywC43QFE2MXyhzgCso\n                            wgA5AjFA+5k8ceZN6PK0O6bWcNyNdgFsIF4KgW/+SelgxT8AnJYG0GRUBAf3DIrQ\n                            Nuw5bEgQ0r45EPQALqs2qKANJDWNiC4Ad5WB5QkVbw/eODpQXGbOVyV6vbb++0df\n                            mQptmsByxpJOAuAuzFRgct/YD2rGwiP2/iuL/QX2wSvWZpABTSAPaynG10ScZl55\n                            HWQrDaq4qyBzo7Flcck4QDjBirDo"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Agricultural University of Athens"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u0393\u03b5\u03c9\u03c0\u03bf\u03bd\u03b9\u03ba\u03cc \u03a0\u03b1\u03bd\u03b5\u03c0\u03b9\u03c3\u03c4\u03ae\u03bc\u03b9\u03bf \u0391\u03b8\u03b7\u03bd\u03ce\u03bd"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aua.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aua.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Agricultural University of Athens"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u0393\u03b5\u03c9\u03c0\u03bf\u03bd\u03b9\u03ba\u03cc \u03a0\u03b1\u03bd\u03b5\u03c0\u03b9\u03c3\u03c4\u03ae\u03bc\u03b9\u03bf \u0391\u03b8\u03b7\u03bd\u03ce\u03bd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://federatie.umcn.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://federatie.umcn.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-12-11T14:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/6e54255933dcf152086180366e8bf0d4",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Radboudumc"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Radboudumc"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/Radboudumc.jpg",
                    "height": "300",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "500"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Radboudumc"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Radboudumc"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Radboudumc"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.umcn.nl/Pages/default.aspx"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Radboudumc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.millersville.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Keith.Wenz@millersville.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Keith Wenz"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Christopher.Medalis@millersville.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Christopher Medalis"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Veronica.Longenecker@millersville.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Veronica Longenecker"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.millersville.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.millersville.edu:9443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.millersville.edu:9443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqYCCQCad9weHImjfTANBgkqhkiG9w0BAQUFADCBoDELMAkGA1UEBhMC\nVVMxFTATBgNVBAgMDFBlbm5zeWx2YW5pYTEVMBMGA1UEBwwMTWlsbGVyc3ZpbGxl\nMQswCQYDVQQKDAJNVTELMAkGA1UECwwCSVQxHTAbBgNVBAMMFGlkcC5taWxsZXJz\ndmlsbGUuZWR1MSowKAYJKoZIhvcNAQkBFhtrZWl0aC53ZW56QG1pbGxlcnN2aWxs\nZS5lZHUwHhcNMTQwMjEyMjAzNDU2WhcNMjQwMjEyMjAzNDU2WjCBoDELMAkGA1UE\nBhMCVVMxFTATBgNVBAgMDFBlbm5zeWx2YW5pYTEVMBMGA1UEBwwMTWlsbGVyc3Zp\nbGxlMQswCQYDVQQKDAJNVTELMAkGA1UECwwCSVQxHTAbBgNVBAMMFGlkcC5taWxs\nZXJzdmlsbGUuZWR1MSowKAYJKoZIhvcNAQkBFhtrZWl0aC53ZW56QG1pbGxlcnN2\naWxsZS5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDcxo3XJyJ4\nXFEbcFxi2tLbeYkgTpkCa5SkJ5iRXJ1nzY3QxtLdUlDPSDZ8yL0/aHmOrNYyblTu\nyS+7AWGONpUcO4TC+o/wXRX2bA351wqP2jB+epZmJeT+sGRwdwD4Zz8LsELlcI79\nKwzefVPE99q0lyeWr8AXK6uW3vV5y8akHmVcrjBxlh36inCwOgTQSlvYtbXHciVP\nB0/tSMGG8pNhKaCDhO9g8GCwJaZOGlA9Xyz42Nl+a+azjLznVMpgWbwY3YEZ3ju+\njxnImQhKULjT+aY0PNk6+z+7NDeFEFfA/B/Q2QXUR64sVcP5lRNzIcV+56mJAbkM\nvwS7CF5l9FJxAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAJZYFahiDe2dzQIRA1jS\njinR70bTzkiOnQNnGQeLi1soMsix+5+tlUNx51/kHevjEmIXaF/1ExdJMA7WgIrb\nWTkuZZ4Vavfj2R6JoNWu2FRW/2M1DrXJqpbwUGcXjdHQ2rbBYmVwSCatNFTsSHip\nlL2HPQZGvht42iAEbk/V/1yrk3oL2gMCQNE72LZsR+NsBwxqICq8VMA4MhRlmKj9\nW9f49ZEtPeCsIRlBj5+g8bp0Kp/01+ZBsUH3sz4Il7xdKP5SDmSliwsdtFdtGtG3\nB1Hr85xtqTtI/mbxmfcdcmmfrY5MeMsi3FWn25+n9vouDArR9CPBswnaC7QQv8Q5\nXaY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDmDCCAoACCQDPokmAeSlZezANBgkqhkiG9w0BAQUFADCBjTEdMBsGA1UEAwwU\naWRwLm1pbGxlcnN2aWxsZS5lZHUxMTAvBgNVBAoMKE1pbGxlcnN2aWxsZSBVbml2\nZXJzaXR5IG9mIFBlbm5zeWx2YW5pYSAxCzAJBgNVBAYTAlVTMRUwEwYDVQQIDAxQ\nZW5uc3lsdmFuaWExFTATBgNVBAcMDE1pbGxlcnN2aWxsZTAeFw0xMzAyMjAwMTEx\nMTFaFw0xNDAyMjAwMTExMTFaMIGNMR0wGwYDVQQDDBRpZHAubWlsbGVyc3ZpbGxl\nLmVkdTExMC8GA1UECgwoTWlsbGVyc3ZpbGxlIFVuaXZlcnNpdHkgb2YgUGVubnN5\nbHZhbmlhIDELMAkGA1UEBhMCVVMxFTATBgNVBAgMDFBlbm5zeWx2YW5pYTEVMBMG\nA1UEBwwMTWlsbGVyc3ZpbGxlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAsk4pBIiHNa6xPAgluBgTro53X6UHITXz8nrMd2vE1q0+e5dBVcFMxtcKgXC9\nHqeb5h4BCetgMVBjQcUqGVTvkVEc+U0oHYgA30QRknT64cY3fNobabbgDuw/BBM0\n1cvGVh//lg3p9hDfGPSvXDyJLh1+D0vcj+4UgaCYiHLBMvSjaJtzKI12ppvryNG8\nTx5yVSLJGCFuuq5aeEH8h6i5n46RabRea0+g/Y1AEabToFf+4sJdQ55a96S7O1RR\nmFmFmCpv7DCFI96yaIRUUylGq0wTt0g/NGEbKDBdc1RVdJS0VVvQ12fXgakWtb8U\nYeoQtJyO11UhiY84GF1VB5O4PQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQAB8bN2\nEdf1s1dmx3OtrgrhWP+GTPwBXZEkPd89/aauVNF23sgYUYwd1FIJQUF3oxFxf6R4\nYVnaVTHw/6Lgzgkua+Vyq7cNsjmrWSqadFiBsT3lOw6CmTFwpJp1cbA17oEh6MzN\n5pKtg5vkF66uNK48G8McryCcP9jrX3n1ldDV33qITE9JgY9yGOcm5dmhU+tBNmzI\nzMjjr6ZldRn41oqKMVdr6Wsv7FXecCOwbFPzItMINzDJ5GAP8Fm2H02JBkai8jX8\nWAWsqXPCafwwasFkMDtUQbBIB70JqFTLFdb8xbP6ESn8cBr2nbB8qcvWPM8MBvX5\nrkHfGo7YiJzuzWRw"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "millersville.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.millersville.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.millersville.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.millersville.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.millersville.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.millersville.edu:9443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.millersville.edu:9443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "millersville.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Millersville University Shibboleth Identity Provider"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.millersville.edu/registrar/faculty/ferpa.php"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Millersville University of Pennsylvania"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqYCCQCad9weHImjfTANBgkqhkiG9w0BAQUFADCBoDELMAkGA1UEBhMC\nVVMxFTATBgNVBAgMDFBlbm5zeWx2YW5pYTEVMBMGA1UEBwwMTWlsbGVyc3ZpbGxl\nMQswCQYDVQQKDAJNVTELMAkGA1UECwwCSVQxHTAbBgNVBAMMFGlkcC5taWxsZXJz\ndmlsbGUuZWR1MSowKAYJKoZIhvcNAQkBFhtrZWl0aC53ZW56QG1pbGxlcnN2aWxs\nZS5lZHUwHhcNMTQwMjEyMjAzNDU2WhcNMjQwMjEyMjAzNDU2WjCBoDELMAkGA1UE\nBhMCVVMxFTATBgNVBAgMDFBlbm5zeWx2YW5pYTEVMBMGA1UEBwwMTWlsbGVyc3Zp\nbGxlMQswCQYDVQQKDAJNVTELMAkGA1UECwwCSVQxHTAbBgNVBAMMFGlkcC5taWxs\nZXJzdmlsbGUuZWR1MSowKAYJKoZIhvcNAQkBFhtrZWl0aC53ZW56QG1pbGxlcnN2\naWxsZS5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDcxo3XJyJ4\nXFEbcFxi2tLbeYkgTpkCa5SkJ5iRXJ1nzY3QxtLdUlDPSDZ8yL0/aHmOrNYyblTu\nyS+7AWGONpUcO4TC+o/wXRX2bA351wqP2jB+epZmJeT+sGRwdwD4Zz8LsELlcI79\nKwzefVPE99q0lyeWr8AXK6uW3vV5y8akHmVcrjBxlh36inCwOgTQSlvYtbXHciVP\nB0/tSMGG8pNhKaCDhO9g8GCwJaZOGlA9Xyz42Nl+a+azjLznVMpgWbwY3YEZ3ju+\njxnImQhKULjT+aY0PNk6+z+7NDeFEFfA/B/Q2QXUR64sVcP5lRNzIcV+56mJAbkM\nvwS7CF5l9FJxAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAJZYFahiDe2dzQIRA1jS\njinR70bTzkiOnQNnGQeLi1soMsix+5+tlUNx51/kHevjEmIXaF/1ExdJMA7WgIrb\nWTkuZZ4Vavfj2R6JoNWu2FRW/2M1DrXJqpbwUGcXjdHQ2rbBYmVwSCatNFTsSHip\nlL2HPQZGvht42iAEbk/V/1yrk3oL2gMCQNE72LZsR+NsBwxqICq8VMA4MhRlmKj9\nW9f49ZEtPeCsIRlBj5+g8bp0Kp/01+ZBsUH3sz4Il7xdKP5SDmSliwsdtFdtGtG3\nB1Hr85xtqTtI/mbxmfcdcmmfrY5MeMsi3FWn25+n9vouDArR9CPBswnaC7QQv8Q5\nXaY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDmDCCAoACCQDPokmAeSlZezANBgkqhkiG9w0BAQUFADCBjTEdMBsGA1UEAwwU\naWRwLm1pbGxlcnN2aWxsZS5lZHUxMTAvBgNVBAoMKE1pbGxlcnN2aWxsZSBVbml2\nZXJzaXR5IG9mIFBlbm5zeWx2YW5pYSAxCzAJBgNVBAYTAlVTMRUwEwYDVQQIDAxQ\nZW5uc3lsdmFuaWExFTATBgNVBAcMDE1pbGxlcnN2aWxsZTAeFw0xMzAyMjAwMTEx\nMTFaFw0xNDAyMjAwMTExMTFaMIGNMR0wGwYDVQQDDBRpZHAubWlsbGVyc3ZpbGxl\nLmVkdTExMC8GA1UECgwoTWlsbGVyc3ZpbGxlIFVuaXZlcnNpdHkgb2YgUGVubnN5\nbHZhbmlhIDELMAkGA1UEBhMCVVMxFTATBgNVBAgMDFBlbm5zeWx2YW5pYTEVMBMG\nA1UEBwwMTWlsbGVyc3ZpbGxlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAsk4pBIiHNa6xPAgluBgTro53X6UHITXz8nrMd2vE1q0+e5dBVcFMxtcKgXC9\nHqeb5h4BCetgMVBjQcUqGVTvkVEc+U0oHYgA30QRknT64cY3fNobabbgDuw/BBM0\n1cvGVh//lg3p9hDfGPSvXDyJLh1+D0vcj+4UgaCYiHLBMvSjaJtzKI12ppvryNG8\nTx5yVSLJGCFuuq5aeEH8h6i5n46RabRea0+g/Y1AEabToFf+4sJdQ55a96S7O1RR\nmFmFmCpv7DCFI96yaIRUUylGq0wTt0g/NGEbKDBdc1RVdJS0VVvQ12fXgakWtb8U\nYeoQtJyO11UhiY84GF1VB5O4PQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQAB8bN2\nEdf1s1dmx3OtrgrhWP+GTPwBXZEkPd89/aauVNF23sgYUYwd1FIJQUF3oxFxf6R4\nYVnaVTHw/6Lgzgkua+Vyq7cNsjmrWSqadFiBsT3lOw6CmTFwpJp1cbA17oEh6MzN\n5pKtg5vkF66uNK48G8McryCcP9jrX3n1ldDV33qITE9JgY9yGOcm5dmhU+tBNmzI\nzMjjr6ZldRn41oqKMVdr6Wsv7FXecCOwbFPzItMINzDJ5GAP8Fm2H02JBkai8jX8\nWAWsqXPCafwwasFkMDtUQbBIB70JqFTLFdb8xbP6ESn8cBr2nbB8qcvWPM8MBvX5\nrkHfGo7YiJzuzWRw"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Millersville University of Pennsylvania"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.millersville.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Millersville University of Pennsylvania"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.fh-joanneum.at/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@fh-joanneum.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ZIT"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@fh-joanneum.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ZIT"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.fh-joanneum.at/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://eduid.at/policy/mdrps-20140606"
              }
            ],
            "registration_instant": "2015-02-16T10:29:20Z",
            "registration_authority": "http://eduid.at",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIULPWP1POqPuJKTnkDdlx69nSwI/owDQYJKoZIhvcNAQEF\nBQAwHTEbMBkGA1UEAwwSaWRwLmZoLWpvYW5uZXVtLmF0MB4XDTE0MTEwNjA4MjY0\nOVoXDTM0MTEwNjA4MjY0OVowHTEbMBkGA1UEAwwSaWRwLmZoLWpvYW5uZXVtLmF0\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1F56hDJn3Wak6ykkjmqB\nVc7KfehBvDV/7Zr08IkW0PmbSCRNao0MOT5NvmJWuvRguc9gPgPJC+hodomIdBXb\nNlECN5k+6WG/8lEr2roC9SGtbjz4GjU/hVDbB3v5kNs0ovV4DHwn6pGzArY0Wqv3\nurzaSEPXdB6j9/tWNMch2UY1nQE8BPJmt8bXNKJjgNBx1YkdOK/YUlGr5wNEwYBU\nyR5W409Yj1/+KZrhXcsXEEQRcWh3slasDh/P3dcWzqIoNWHDuvO2n/casdaplASY\nMha6cZyiIlAmzjCb/EBH+ET3lbLUqaa9QAB/gpQA+GJ8sqRyV46OtgJWH7r1XhXo\n9QIDAQABo2swaTAdBgNVHQ4EFgQU7sDCk08y2FydgwEKMrw9hyaC1BIwSAYDVR0R\nBEEwP4ISaWRwLmZoLWpvYW5uZXVtLmF0hilodHRwczovL2lkcC5maC1qb2FubmV1\nbS5hdC9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAbgEklICx1nWj\nBOLoNsIxfLStKrZ/OGQPZA4qs8SnKrn5ZHWwGkYQVOUjdlj9Ujx5G7jT29m1fG9Z\n5iwDDHtYcgqzJBZo4nVdwnexbZcIB05+/L3xgbbIcnXOu3WlaleTYH9sef8/ExT2\nKT1bQbbDmXXzzvxnkEUcWIs/r3GRE45GnSVUAcZQqvheF9ELKUFzd8C36glQ98D4\nCpiRk275uQjBfzjFS7xpOuNR8tqe+sx7bxNoFL6aHHr8zJ8RWLmXc8S3xLtDTpgT\nFaM76TBX0JxWOxqWce24DPI/3UTL/iGk+WE61+ar5rD+jAdtgHFhc9UMvxdZYJmz\n8zYGzVn2IQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fh-joanneum.at"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.fh-joanneum.at:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.fh-joanneum.at:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.fh-joanneum.at/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.fh-joanneum.at/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.fh-joanneum.at:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.fh-joanneum.at/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.fh-joanneum.at/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.fh-joanneum.at/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.fh-joanneum.at/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.fh-joanneum.at:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.fh-joanneum.at:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fh-joanneum.at"
              },
              {
                "logo": [
                  {
                    "text": "https://www.fh-joanneum.at/custom/images/logo_1001.png",
                    "height": "47",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "218"
                  },
                  {
                    "text": "https://www.fh-joanneum.at/favicon.ico",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FH Joanneum"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FH Joanneum"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "fh-joanneum.at"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.06931,15.40799"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.45431,15.33112"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:46.87544,15.90241"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIULPWP1POqPuJKTnkDdlx69nSwI/owDQYJKoZIhvcNAQEF\nBQAwHTEbMBkGA1UEAwwSaWRwLmZoLWpvYW5uZXVtLmF0MB4XDTE0MTEwNjA4MjY0\nOVoXDTM0MTEwNjA4MjY0OVowHTEbMBkGA1UEAwwSaWRwLmZoLWpvYW5uZXVtLmF0\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1F56hDJn3Wak6ykkjmqB\nVc7KfehBvDV/7Zr08IkW0PmbSCRNao0MOT5NvmJWuvRguc9gPgPJC+hodomIdBXb\nNlECN5k+6WG/8lEr2roC9SGtbjz4GjU/hVDbB3v5kNs0ovV4DHwn6pGzArY0Wqv3\nurzaSEPXdB6j9/tWNMch2UY1nQE8BPJmt8bXNKJjgNBx1YkdOK/YUlGr5wNEwYBU\nyR5W409Yj1/+KZrhXcsXEEQRcWh3slasDh/P3dcWzqIoNWHDuvO2n/casdaplASY\nMha6cZyiIlAmzjCb/EBH+ET3lbLUqaa9QAB/gpQA+GJ8sqRyV46OtgJWH7r1XhXo\n9QIDAQABo2swaTAdBgNVHQ4EFgQU7sDCk08y2FydgwEKMrw9hyaC1BIwSAYDVR0R\nBEEwP4ISaWRwLmZoLWpvYW5uZXVtLmF0hilodHRwczovL2lkcC5maC1qb2FubmV1\nbS5hdC9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAbgEklICx1nWj\nBOLoNsIxfLStKrZ/OGQPZA4qs8SnKrn5ZHWwGkYQVOUjdlj9Ujx5G7jT29m1fG9Z\n5iwDDHtYcgqzJBZo4nVdwnexbZcIB05+/L3xgbbIcnXOu3WlaleTYH9sef8/ExT2\nKT1bQbbDmXXzzvxnkEUcWIs/r3GRE45GnSVUAcZQqvheF9ELKUFzd8C36glQ98D4\nCpiRk275uQjBfzjFS7xpOuNR8tqe+sx7bxNoFL6aHHr8zJ8RWLmXc8S3xLtDTpgT\nFaM76TBX0JxWOxqWce24DPI/3UTL/iGk+WE61+ar5rD+jAdtgHFhc9UMvxdZYJmz\n8zYGzVn2IQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "FH Joanneum"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "FH Joanneum"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fh-joanneum.at/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fh-joanneum.at/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "FH Joanneum Ges.m.b.H"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "FH Joanneum Ges.m.b.H"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:psu.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "max@psu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark Miller"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "identity@psu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Penn State Identity Services"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "avh3@psu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrea Harrington"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mrg30@psu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael Gettes"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:psu.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://as1.fim.psu.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://as1.fim.psu.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE+jCCA+KgAwIBAgIJAL8NZFMAw3T+MA0GCSqGSIb3DQEBBQUAMIGuMQswCQYD\nVQQGEwJVUzEVMBMGA1UECBMMUGVubnN5bHZhbmlhMRgwFgYDVQQHEw9Vbml2ZXJz\naXR5IFBhcmsxKjAoBgNVBAoTIVRoZSBQZW5uc3lsdmFuaWEgU3RhdGUgVW5pdmVy\nc2l0eTEoMCYGA1UECxMfSW5mb3JtYXRpb24gVGVjaG5vbG9neSBTZXJ2aWNlczEY\nMBYGA1UEAxMPYXMxLmZpbS5wc3UuZWR1MB4XDTEyMDQxMTE5MjMzNFoXDTMyMDQw\nNjE5MjMzNFowga4xCzAJBgNVBAYTAlVTMRUwEwYDVQQIEwxQZW5uc3lsdmFuaWEx\nGDAWBgNVBAcTD1VuaXZlcnNpdHkgUGFyazEqMCgGA1UEChMhVGhlIFBlbm5zeWx2\nYW5pYSBTdGF0ZSBVbml2ZXJzaXR5MSgwJgYDVQQLEx9JbmZvcm1hdGlvbiBUZWNo\nbm9sb2d5IFNlcnZpY2VzMRgwFgYDVQQDEw9hczEuZmltLnBzdS5lZHUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDgDw/HyxwqLZGLR1s6ewzwji0fx1dq\nY4GoNycD8brxxnA11BgL0cSIM0WYyfOJBUxBhmkrlWccZDPPOmAC5qlPfLO8GjIS\nyFQrMFyhCynYKlP0Clm/59FkM/Jw2GPFmVXgM+dczk75f0sOaQzmay8pZdnOX3SX\nCX4aiOU+PFUqSuF94Ug/DkSeVHf9x6aV6A/e2iWHsigHTXNL5T5n29iNPRjdQ7NT\nJBnMGMpzjoZkFvmlVsplt6bTT7v81khDQItvTXVz1l9b3P3scYU2a3tRHFuyHRr8\nAHaqRDwIeDP4EaQcMHkD5EktM8RkOiPFYZQwSSrhM5F7gk/rFOXg+ZOvAgMBAAGj\nggEXMIIBEzAdBgNVHQ4EFgQU5I99+kOGxYuGIeGYPeB8BdbR0GUwgeMGA1UdIwSB\n2zCB2IAU5I99+kOGxYuGIeGYPeB8BdbR0GWhgbSkgbEwga4xCzAJBgNVBAYTAlVT\nMRUwEwYDVQQIEwxQZW5uc3lsdmFuaWExGDAWBgNVBAcTD1VuaXZlcnNpdHkgUGFy\nazEqMCgGA1UEChMhVGhlIFBlbm5zeWx2YW5pYSBTdGF0ZSBVbml2ZXJzaXR5MSgw\nJgYDVQQLEx9JbmZvcm1hdGlvbiBUZWNobm9sb2d5IFNlcnZpY2VzMRgwFgYDVQQD\nEw9hczEuZmltLnBzdS5lZHWCCQC/DWRTAMN0/jAMBgNVHRMEBTADAQH/MA0GCSqG\nSIb3DQEBBQUAA4IBAQCE5rt7hCbcrtwqaR6e9Z4nRfWdkQYtGTWi9UaBFhS7MLJB\nt4FyP+ohfRshQGAwJjekQW28GhuoDWngcdZFhE0ktYwct2zKhUDe8ggPWJWPLnlD\nUMiSX6BIn6tgpkpqpwduCoceQqLD2XnT33X7Fur0qohGW2EFPKxKHEVHXtfcHEsZ\nsBGSEC21XV/796AI8JQ4rb8ASWaLSjoGGwlZjsDogIzUJAuMdBPuG/CkbTJDjsii\nu9cF1oLJGzUEXx6B1ugWfWxVeUumOE0PGX3uPijrOd3Ak1gRevg//iyMw+zvL9xL\n4e+XA3Dtyu/I5Riwwv3AF7MFfNpiFhs0ay1ARC8y"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "psu.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://as1.fim.psu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://as1.fim.psu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://as1.fim.psu.edu/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://as1.fim.psu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://as1.fim.psu.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://as1.fim.psu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://as1.fim.psu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "psu.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.psu.edu/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.dept.psu.edu/ids/public/psulogoforincommon.png",
                    "lang": "en",
                    "height": "70",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "130"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.psu.edu/web-privacy-statement"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Penn State"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE+jCCA+KgAwIBAgIJAL8NZFMAw3T+MA0GCSqGSIb3DQEBBQUAMIGuMQswCQYD\nVQQGEwJVUzEVMBMGA1UECBMMUGVubnN5bHZhbmlhMRgwFgYDVQQHEw9Vbml2ZXJz\naXR5IFBhcmsxKjAoBgNVBAoTIVRoZSBQZW5uc3lsdmFuaWEgU3RhdGUgVW5pdmVy\nc2l0eTEoMCYGA1UECxMfSW5mb3JtYXRpb24gVGVjaG5vbG9neSBTZXJ2aWNlczEY\nMBYGA1UEAxMPYXMxLmZpbS5wc3UuZWR1MB4XDTEyMDQxMTE5MjMzNFoXDTMyMDQw\nNjE5MjMzNFowga4xCzAJBgNVBAYTAlVTMRUwEwYDVQQIEwxQZW5uc3lsdmFuaWEx\nGDAWBgNVBAcTD1VuaXZlcnNpdHkgUGFyazEqMCgGA1UEChMhVGhlIFBlbm5zeWx2\nYW5pYSBTdGF0ZSBVbml2ZXJzaXR5MSgwJgYDVQQLEx9JbmZvcm1hdGlvbiBUZWNo\nbm9sb2d5IFNlcnZpY2VzMRgwFgYDVQQDEw9hczEuZmltLnBzdS5lZHUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDgDw/HyxwqLZGLR1s6ewzwji0fx1dq\nY4GoNycD8brxxnA11BgL0cSIM0WYyfOJBUxBhmkrlWccZDPPOmAC5qlPfLO8GjIS\nyFQrMFyhCynYKlP0Clm/59FkM/Jw2GPFmVXgM+dczk75f0sOaQzmay8pZdnOX3SX\nCX4aiOU+PFUqSuF94Ug/DkSeVHf9x6aV6A/e2iWHsigHTXNL5T5n29iNPRjdQ7NT\nJBnMGMpzjoZkFvmlVsplt6bTT7v81khDQItvTXVz1l9b3P3scYU2a3tRHFuyHRr8\nAHaqRDwIeDP4EaQcMHkD5EktM8RkOiPFYZQwSSrhM5F7gk/rFOXg+ZOvAgMBAAGj\nggEXMIIBEzAdBgNVHQ4EFgQU5I99+kOGxYuGIeGYPeB8BdbR0GUwgeMGA1UdIwSB\n2zCB2IAU5I99+kOGxYuGIeGYPeB8BdbR0GWhgbSkgbEwga4xCzAJBgNVBAYTAlVT\nMRUwEwYDVQQIEwxQZW5uc3lsdmFuaWExGDAWBgNVBAcTD1VuaXZlcnNpdHkgUGFy\nazEqMCgGA1UEChMhVGhlIFBlbm5zeWx2YW5pYSBTdGF0ZSBVbml2ZXJzaXR5MSgw\nJgYDVQQLEx9JbmZvcm1hdGlvbiBUZWNobm9sb2d5IFNlcnZpY2VzMRgwFgYDVQQD\nEw9hczEuZmltLnBzdS5lZHWCCQC/DWRTAMN0/jAMBgNVHRMEBTADAQH/MA0GCSqG\nSIb3DQEBBQUAA4IBAQCE5rt7hCbcrtwqaR6e9Z4nRfWdkQYtGTWi9UaBFhS7MLJB\nt4FyP+ohfRshQGAwJjekQW28GhuoDWngcdZFhE0ktYwct2zKhUDe8ggPWJWPLnlD\nUMiSX6BIn6tgpkpqpwduCoceQqLD2XnT33X7Fur0qohGW2EFPKxKHEVHXtfcHEsZ\nsBGSEC21XV/796AI8JQ4rb8ASWaLSjoGGwlZjsDogIzUJAuMdBPuG/CkbTJDjsii\nu9cF1oLJGzUEXx6B1ugWfWxVeUumOE0PGX3uPijrOd3Ak1gRevg//iyMw+zvL9xL\n4e+XA3Dtyu/I5Riwwv3AF7MFfNpiFhs0ay1ARC8y"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Penn State"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.psu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Pennsylvania State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-14.ladok.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-14.ladok.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-14.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-14.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-14.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-14.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-14.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-14.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-14.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;14"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;14"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-14.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-14.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJANz1RZ6LJaI4MA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0xNC5sYWRvay51bXUuc2UwHhcNMTUwMTIwMTEwMjM4WhcNMjUw\nMTE3MTEwMjM4WjAhMR8wHQYDVQQDExZsYWRvazMtMTQubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArdcdcCAAmnzDM5X3jagmHXQM\nQnQxP6LpWcOlSxFhju4XXB83Jh+DHY8fbP9XHh6ZL1Bol/ireyEI79KpPL3Ics8o\ntP0dxoxG2uwQ7sdWiRifHUOWL+gU3F1jzHPOr8F10oBBkxPFXdsmt90zWyZlFDhU\na8NPCb4ZJQBL7kTMSioYmxy2aKvRL69CfsaWglqNZ/oXy6lOCwjJwch0n3iVQDER\ntQvIEuBpXZCYd721/f/bPjoigvFweYYWGJUeWNum8tnO2mrWVGQysncHNjcrIoiq\nWcT05wIqZm0IwytPDT8Y2Zmw6G3ua1eBlApD0OqAP8VlVin3DRy7ZJoOsRSmuQID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMTQubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0xNC5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUUsL/gU0NPNjVc5M5G58QF+UY6+gwDQYJKoZIhvcNAQEFBQADggEB\nAFz+OT3s1pvFxVBvwkb06eMP9NJKlWnJgwSOb9FibhS0x88ya5smmLun2AnXRcGB\ncLrYRsCNJiIh3h5Gll21X8rk0ynrwxs1k9xjb2LTPXkC9YF5NtknO1ZR4Jl+LIrZ\nNef4RSum18/sUhncWfYaypL8N/xPO8BNhU8D8qwI88WNEjyQrMrsqz5HUxFJgmb3\nNIGsLbCCym0gapILXCVwumUBtuuKqhqwMzurysCg6mRrGaKTn5QDdLU4od+K+KEB\nfad56LiMqe2XQBdVmuC0G6vTwrUGifrgKl1ijK1OxgYk709aHsu8Chtr2iGENcv1\n8zGN8ILH+bDTU9H6P9PXk0E="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-14.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-14.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-14.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-14.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-14.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-14.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-14.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-14.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-14.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-14.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://passportprod.lu.se/activateaccount/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://passportprod.lu.se/activateaccount/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://passportprod.lu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://passportprod.lu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://passportprod.lu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://passportprod.lu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://passportprod.lu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://passportprod.lu.se/Shibboleth.sso/Login-antagning",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://passportprod.lu.se/Shibboleth.sso/Login-eduid",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://passportprod.lu.se/Shibboleth.sso/Login-lu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://passportprod.lu.se"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://passportprod.lu.se"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration and activating accounts"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration och aktivering av konton"
                  }
                ],
                "logo": [
                  {
                    "text": "http://www.lunduniversity.lu.se/sites/www.lunduniversity.lu.se/files/lund_university_logotype.png",
                    "height": "78",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  },
                  {
                    "text": "http://www.lu.se/sites/www.lu.se/files/logo.png",
                    "lang": "sv",
                    "height": "78",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Password portal for Lund University"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "L\u00f6senordsportal f\u00f6r Lunds universitet"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "uwws13.uw.lu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAPAD4VpPdKCMMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD3V3d3MxMy51dy5sdS5zZTAeFw0xNTA4MzExMjU5MzhaFw0yNTA4MjgxMjU5\nMzhaMBoxGDAWBgNVBAMTD3V3d3MxMy51dy5sdS5zZTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAL41aRiC3QY3GqS2UNPnJdwOd/vT1yC8kogU8tznToJ2\nXcRPjgYxdB0ycgin/npyIlmb/+OpZa+fkiN7o8rJ6T9cjpGyCcggIPavTYpG/IeC\nmenBjIwid+mLno5asuaXX5NwMIfjSCmnO4NQ23PnooIPtmMuEo1xxze+nBDt39v+\nLcC2SJc3mkMoKWDYTEwFejfljhsPBopdkr3/s4iQuHiRHXwQtMuWzmxWVtdEQjP4\nJexnYMegKii+bLmPCpRl1u5xg+Uj/MNeF/RP2Hf8UQ8d/VWSzEx6tM5K8055/XOi\nWO/vn46fqecUirZI8KCi2b5Y3YJmW52AaRRS1PnAJDcCAwEAAaM9MDswGgYDVR0R\nBBMwEYIPdXd3czEzLnV3Lmx1LnNlMB0GA1UdDgQWBBQN4D+sxH8TNpdqHr1myCjn\nczQXVTANBgkqhkiG9w0BAQUFAAOCAQEAmXkKKSjw0imbaKmMdqYFOLHoDGp4c6wi\n5fUBtVLt9ATcXBNcRZ/YGWv84YqxztifpE0muL9wdlFEhDdPATBgATPjjHkddNOW\ngVsd3XlY7NqXicukF6IRg4r7/jdo2yeUU7Z5/piAQmH/GNH37rNhjYXLCRu4i2Mx\n0ecfB1zt/F/alqrL7sx78i+BhTSKI/OURkr+ifjXHdZAp5z1lpLn+YxL3VL6aEke\nbK7+H+UyCLeQ4gkfKPEkbHdeDsdcIJxtKjur6L2PS3Mr+tPtVNPLEXOZNLwKicuU\nlQd6YWu02Yr4FawRDeUp8PI+VMYf1WapfZ0FFE2Od+FUc/i+8TMudA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=uwws13.uw.lu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://passportprod.lu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://passportprod.lu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://passportprod.lu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://passportprod.lu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://passportprod.lu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://passportprod.lu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://passportprod.lu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://passportprod.lu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://passportprod.lu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://its-utv03.ad.umu.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://its-utv03.ad.umu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/MIUN",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/KTH",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/SU",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/UMU",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/HH",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/HHTEST",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Serviceprovider, anv\u00e4nds prim\u00e4rt f\u00f6r utveckling"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Serviceprovider, primarily used for development"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ITS, Ume\u00e5 universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ITS, Umea University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "its-utv03.ad.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKzCCAxOgAwIBAgIJAMZSkH53CntAMA0GCSqGSIb3DQEBBQUAMIGrMQswCQYD\nVQQGEwJTRTEVMBMGA1UECAwMVmFzdGVyYm90dGVuMQ0wCwYDVQQHDARVbWVhMQww\nCgYDVQQKDANJVFMxJTAjBgNVBAsMHE9yZ2FuaXphdGlvbmFsIFVuaXQgTmFtZTpJ\nVFMxHDAaBgNVBAMME2l0cy11dHYwMy5hZC51bXUuc2UxIzAhBgkqhkiG9w0BCQEW\nFGFrZS5hbmRlcnNzb25AdW11LnNlMB4XDTE0MDkyMzA4MzQxMloXDTE3MDgwNjA4\nMzQxMlowgasxCzAJBgNVBAYTAlNFMRUwEwYDVQQIDAxWYXN0ZXJib3R0ZW4xDTAL\nBgNVBAcMBFVtZWExDDAKBgNVBAoMA0lUUzElMCMGA1UECwwcT3JnYW5pemF0aW9u\nYWwgVW5pdCBOYW1lOklUUzEcMBoGA1UEAwwTaXRzLXV0djAzLmFkLnVtdS5zZTEj\nMCEGCSqGSIb3DQEJARYUYWtlLmFuZGVyc3NvbkB1bXUuc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQC6WjbxUU6Sy8YeZIeQ11E2eH66YG/CcAy3nd2g\n0ai2Dzu03wCD+GNdWPuZslLlkvK4AE6iR2+ZQgkqzBoI7ifpxSbnPMfPDMjNK5Yx\nIx7EHE1kgD7D1iCz30H2O9/oNSVjykMXnjLMlLBYaDjxZoj+L3pwKKTW6Yzg6T7o\nz90xke1qpcVOD0+e2vgLoYbIq7QTzF/VkPyRrDwsbw3f4WiJiRAI9dNLPdt6fh6F\nePKKPv6xUEOO1uDjVmwL7HUYfh6br5G6jR642rnbJhqd5HJiD1Sn+BMv2ilVFHOr\nKclBHavS9aKvj++IVdjTMk0/APsSi8uV2RF1UEeUVh2afi2pAgMBAAGjUDBOMB0G\nA1UdDgQWBBS/yT6QYUoPUWKDcpJe52kqdgRKXzAfBgNVHSMEGDAWgBS/yT6QYUoP\nUWKDcpJe52kqdgRKXzAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCa\n53ROhR17tvRIoeBhUZ3WICcNsrN88LcQX6iiD9beWr4bLYn0hX+vgs/EoznuLZPL\n9yBPk5XlVfRJA6XGQ2mrcWeVPapduIOeRX5MpBaOhOULMahTC9VztR+0/h5lUiVF\nMgYw/UX/wMJheDvEqt31DrwfGPH7cFnZZnNiDBNzpe7RTx5r6W9lXROzyl0BJ+l/\nN1edCRg4D+SjXviDNKli19pL82ONv0x607sCLGKEDR3qhQxd7wcGcNGwlg32MFNQ\nvk7XtvHnrAqG1Nn1WrK5npXCw9Tx8omdql4W0fhtdHDffSxO7iNVswPS8/fYIYHc\nxjIf5blaR7shDIsqWMix"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=ake.andersson@umu.se,CN=its-utv03.ad.umu.se,OU=Organizational Unit Name:ITS,O=ITS,L=Umea,ST=Vasterbotten,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://its-utv03.ad.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://synnefo.sky.deic.dk/astakos/ui/login/shibboleth/",
    {
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2013-09-11T16:04:28Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute_value": [
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "kalmar"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "denmark"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "iceland"
              }
            ],
            "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
            "name": "tags",
            "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+45 40142359"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bernath"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "isbe@adm.dtu.dk"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "DeIC"
          },
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Istvan"
          }
        }
      ],
      "entity_id": "https://synnefo.sky.deic.dk/astakos/ui/login/shibboleth/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://synnefo.sky.deic.dk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Form\u00e5let er at stille virtuelle maskiner og lagerplads til r\u00e5dighed for personale og studerende ved de h\u00f8jere l\u00e6reanstalter."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The purpose is to put virtual machines and storage at the disposal of people affiliated with any Danish higher educational institution."
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Synnefo DeIC"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Synnefo DeIC"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://synnefo.sky.deic.dk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://synnefo.sky.deic.dk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Form\u00e5let er at stille virtuelle maskiner og lagerplads til r\u00e5dighed for personale og studerende ved de h\u00f8jere l\u00e6reanstalter."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The purpose is to put virtual machines and storage at the disposal of people affiliated with any Danish higher educational institution."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Synnefo DeIC"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Synnefo DeIC"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "gn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://wikispaces.psu.edu/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pmd@psu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Phil Devan"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rac@psu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rich Cropp"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cjh@psu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Christopher Hubing"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://wikispaces.psu.edu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Penn State"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.psu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Pennsylvania State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://wikispaces.psu.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://wikispaces.psu.edu/dashboard.action"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.dept.psu.edu/ids/public/psulogoforincommon.png",
                    "lang": "en",
                    "height": "70",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "130"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.psu.edu/web-privacy-statement"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Penn State WikiSpaces"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDzDCCArQCCQDCI8d9i9pvjzANBgkqhkiG9w0BAQUFADCBpzELMAkGA1UEBhMC\nVVMxFTATBgNVBAgMDFBlbm5zeWx2YW5pYTEYMBYGA1UEBwwPVW5pdmVyc2l0eSBQ\nYXJrMSowKAYDVQQKDCFUaGUgUGVubnN5bHZhbmlhIFN0YXRlIFVuaXZlcnNpdHkx\nHjAcBgNVBAsMFUVtZXJnaW5nIFRlY2hub2xvZ2llczEbMBkGA1UEAwwSd2lraXNw\nYWNlcy5wc3UuZWR1MB4XDTE0MDQwOTE1Mzc0MFoXDTM0MDQwNDE1Mzc0MFowgacx\nCzAJBgNVBAYTAlVTMRUwEwYDVQQIDAxQZW5uc3lsdmFuaWExGDAWBgNVBAcMD1Vu\naXZlcnNpdHkgUGFyazEqMCgGA1UECgwhVGhlIFBlbm5zeWx2YW5pYSBTdGF0ZSBV\nbml2ZXJzaXR5MR4wHAYDVQQLDBVFbWVyZ2luZyBUZWNobm9sb2dpZXMxGzAZBgNV\nBAMMEndpa2lzcGFjZXMucHN1LmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBALoiOXQkq6k5kNcpwdUjyDNsO2ssYK8kt59DyTM8c4YOr+VBHf4YdU3H\nqHOeXMCP8fIsD9OgcqQFAhojUGvGA9z0mjEQv9/Je8SCGgDjXOdcF+yCo1b50ppY\njDlDP2wvyKowmXlrxMSZELqR1lRf1SUFA4j1XDiQpV2RtNixmqKPUWXsPFAZTFz/\nwwwFkdA1h/6l7qrdeDtN0Fe83dd88EDjF2Q1QMk2H1rGGdeiz1mTNu4vj8P+KbiO\nhO/D/S59kpJ8jKldbTpkckpnNZHFLJhUl0RlwyTlFGOG25Qwytj/asWxOajSq73h\nHML1ilm7AqPst0Ifk0xvOpg8cbm2p78CAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\nuZ8ibmbbqYzefrwgrti0kPcixsMpke79L54WcF7X45APwvtUGw27t0N6mEt5ntT3\nyscYdrIzhTl7hCjUJKmjJ55R3a5U4oDgkxRKo9LnGutVyrRTGBnDoZfY8d3zCWPf\nth9ZAPsvojAxSWpkwLIv5ZteTks99bAUsYE81dPx8hNIqSLDxsOROawCnrhTEowy\n1BXL7qYVuWw2cJiTFaL+IVCpltBYmmYUsPTIFSxhQGOljuwx6zY1l61TAivFp3Km\n+Yv+iYmBO0r1b3xOFejbmcyGKJzOgu8rje7pSASVviqwvjxAtAZ3iIlZZSQ8Tk/o\nYB840Gg/4ow3pdRVwzYL/g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wikispaces.psu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://wikispaces.psu.edu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wikispaces.psu.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://wikispaces.psu.edu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://wikispaces.psu.edu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Penn State WikiSpaces"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://login.proxy.kib.ki.se/shibboleth",
    {
      "entity_id": "https://login.proxy.kib.ki.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://login.proxy.kib.ki.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.proxy.kib.ki.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.proxy.kib.ki.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.proxy.kib.ki.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEcDCCA1igAwIBAgIBCzANBgkqhkiG9w0BAQUFADCBhjEYMBYGA1UEAxMPcHJv\neHkua2liLmtpLnNlMQswCQYDVQQGEwJTRTEeMBwGA1UEChMVS2Fyb2xpbnNrYSBJ\nbnN0aXR1dGV0MRswGQYDVQQLExJVTklWRVJTSVRZIExJQlJBUlkxIDAeBgkqhkiG\n9w0BCQEWEXViaXRkb3NAa2liLmtpLnNlMB4XDTEwMDIyNjEzMjE1NloXDTIwMDIy\nNjEzMjE1NlowgYYxGDAWBgNVBAMTD3Byb3h5LmtpYi5raS5zZTELMAkGA1UEBhMC\nU0UxHjAcBgNVBAoTFUthcm9saW5za2EgSW5zdGl0dXRldDEbMBkGA1UECxMSVU5J\nVkVSU0lUWSBMSUJSQVJZMSAwHgYJKoZIhvcNAQkBFhF1Yml0ZG9zQGtpYi5raS5z\nZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK5QKiARTF50XEK/89+t\ntr8k7WH5Xrsq+3enTBngK7IQeCN7kHIR2OSFlanC2MOi8NiRVlKol0qH/1q+RRR9\nKHd/PGZbsLWZ1LroOgR488MKOkkF0LblnMVDt1V5kLReQSl6H2sKNayFnE22A37G\nmgtgyZ7B0BKYK3zCgNRvTfwuhkQHeNmJtpLyoa6YeSyYEMjQ+PBwvU4MhmsatBgG\nXu/h/JL7N++BeY7aPPvLm1e0IUum+kqnnJgCdXYwVyw6Wb9wvNwyBsTwYLgiwhS+\nMINIvBjulW4qqpKp0xAdYwju9C9AJRik/7PLCnI5qpXXS62+MmwAW3jz6ryBIt/7\nx+ECAwEAAaOB5jCB4zAdBgNVHQ4EFgQUQkgS+CkU30Ybml3lbFXnt5o1OdkwgbMG\nA1UdIwSBqzCBqIAUQkgS+CkU30Ybml3lbFXnt5o1OdmhgYykgYkwgYYxGDAWBgNV\nBAMTD3Byb3h5LmtpYi5raS5zZTELMAkGA1UEBhMCU0UxHjAcBgNVBAoTFUthcm9s\naW5za2EgSW5zdGl0dXRldDEbMBkGA1UECxMSVU5JVkVSU0lUWSBMSUJSQVJZMSAw\nHgYJKoZIhvcNAQkBFhF1Yml0ZG9zQGtpYi5raS5zZYIBCzAMBgNVHRMEBTADAQH/\nMA0GCSqGSIb3DQEBBQUAA4IBAQBBAZDVdk+gbcH0g5221e6O9krMykXfcnO2Eoe6\n8tRxS43/9VQFLFu+YERrT/au5qvvPxEhWaG8YVXMJcKyN8nywdnov2swu73TjmnC\n0Rq9COqTAbCli5zkpi8A09cUuzshoPAnfbP+zCAGC2Bibfpn26OWwwYZ5Hi+mvUK\n83R4KeTZ1XsjqA80mq2IJTCZ4SivI/EUXR2c/lx9K2FcUgL0SU7hQdkxDuCQSlER\n+z254HQ3Bsu/dQR61LpUyKeKnYUvR6Z3eriDI6aaBElRFkmgxjBAmL/esl5lmeg7\ndOkAplPQyOj+P+Uy42rzO3amgl1r/DvYexsSitOdJLqbVOrz"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "urn:oasis:names:tc:SAML:2.0:protocol urn:oasis:names:tc:SAML:1.1:protocol http://schemas.xmlsoap.org/ws/2003/07/secext",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://idp.abingdon-witney.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itservices@abingdon-witney.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT services"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itservices@abingdon-witney.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT services"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.abingdon-witney.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-02-02T15:50:56Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.abingdon-witney.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.abingdon-witney.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.abingdon-witney.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.abingdon-witney.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.abingdon-witney.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.abingdon-witney.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "abingdon-witney.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://idp.abingdon-witney.ac.uk/idp/images/awcicon16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.abingdon-witney.ac.uk/idp/images/awclogored80x60.png",
                    "height": "80",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  },
                  {
                    "text": "https://idp.abingdon-witney.ac.uk/idp/images/awclogored350x170.png",
                    "height": "350",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "170"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Abingdon and Witney College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTzCCAjegAwIBAgIUfiVxgSRDxCzABDMLiAjqfpU+PuMwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwJDEiMCAGA1UEAwwZaWRwLmFiaW5nZG9uLXdpdG5leS5hYy51azAeFw0xNTEw\n\t\t\t\t\t\tMzAxMDI4MzlaFw0zNTEwMzAxMDI4MzlaMCQxIjAgBgNVBAMMGWlkcC5hYmluZ2Rv\n\t\t\t\t\t\tbi13aXRuZXkuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDE\n\t\t\t\t\t\t5+Ga0Ez064Yi3cnMFh4gYXJEcALYJXGUxUuT7kd4Po3JVVtGLw9bXvZD+0JlUfac\n\t\t\t\t\t\t3LOg1erBo43Neav8xHPGjvlIbDSJr0xwxSpU6epxbb+kRY/iuEPn0nN/hSWvMJTV\n\t\t\t\t\t\tGP7Nbuqbw5By1mhlQGQYUXiioDl7PMzJzqT/Gq766AjLDoLMmJroWvPHHkxZ5MK+\n\t\t\t\t\t\tOytm9QQw/9CXdWhgj+WB1KarAwwmWCZH39wiA/NUHRqiSW86tlZSRhk5y2LbRP5l\n\t\t\t\t\t\twQaU4UiuMXCEzcyLXyssPsV85H+yIlEmEaoNgbEiNA/CUnOrxpsRy0wUUIB48/5V\n\t\t\t\t\t\tSi0974dTHn/Hh8erV/UtAgMBAAGjeTB3MB0GA1UdDgQWBBTkF099+qcKWGi4cP55\n\t\t\t\t\t\tkqdWPhj8DzBWBgNVHREETzBNghlpZHAuYWJpbmdkb24td2l0bmV5LmFjLnVrhjBo\n\t\t\t\t\t\tdHRwczovL2lkcC5hYmluZ2Rvbi13aXRuZXkuYWMudWsvaWRwL3NoaWJib2xldGgw\n\t\t\t\t\t\tDQYJKoZIhvcNAQELBQADggEBAGJj6+R4nrxc8Fd2fLflEMGvI2XREWPNArMfwkUo\n\t\t\t\t\t\tv4q4miUqsOldJmmTDn9IfBRN6IfwmY4udAQmMbNKnVe97y1X2iLp/bjbIjebln6M\n\t\t\t\t\t\tL2SNM2RwupVRDyUhVGSB8Y1oR6KXptKnNsceqpGgWOPUIPQhRN0anlm8Bokd5+Ty\n\t\t\t\t\t\thttuagrntS9WLIseHe0HmAMwfZqnIBX9uofB1dr6+nibLNxTp8sU1cKvm/qSKii0\n\t\t\t\t\t\tktEDvpbOHC8IJyp4vTGgiIy+G08diHDDGRjVx/2NCNGhO8OkYqijFKBFw1sH02N/\n\t\t\t\t\t\tYCK7eydlkPufBd4mL2wfQ9HGBEq9bbc8w407g/NrkJb/KT8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTzCCAjegAwIBAgIUPdKuMgQHT3w/Ux+Tj8Vneskj30owDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwJDEiMCAGA1UEAwwZaWRwLmFiaW5nZG9uLXdpdG5leS5hYy51azAeFw0xNTEw\n\t\t\t\t\t\tMzAxMDI4MzRaFw0zNTEwMzAxMDI4MzRaMCQxIjAgBgNVBAMMGWlkcC5hYmluZ2Rv\n\t\t\t\t\t\tbi13aXRuZXkuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCf\n\t\t\t\t\t\tqKxQIKszUVA4rjh+y7WYlbVtJxD2XtNEtMpfauulelxFx47GVAozNSJE3Yot5FA6\n\t\t\t\t\t\tWYIGWM8SXe1a/9wrLkWvSbHm09cChSWvdvHpOS5SCqNYoekw72W2Wct/cdyhlwwt\n\t\t\t\t\t\t4w6QSJJedyEm2wjUuKJGdkw9CBo1xcL3gvb+39fiialCSx4zZFQacMDHhVOtcrDO\n\t\t\t\t\t\tsOT1akP7jIxaQng0PGHp48MrsVzcRT3t7KMuPiWlF8d/BTcs10EbqFyaV1VrEBJ8\n\t\t\t\t\t\tsUZk6dlqEBEtdC67V1F4PA9ybCALEtpUfKc1JynjYlkhtuAWVWem4rHgbYew5CRz\n\t\t\t\t\t\tT+seuy7W1jJHG4/WNR+xAgMBAAGjeTB3MB0GA1UdDgQWBBR0vwEhtdD3PhB7+f7Z\n\t\t\t\t\t\tcI8O7pfYfjBWBgNVHREETzBNghlpZHAuYWJpbmdkb24td2l0bmV5LmFjLnVrhjBo\n\t\t\t\t\t\tdHRwczovL2lkcC5hYmluZ2Rvbi13aXRuZXkuYWMudWsvaWRwL3NoaWJib2xldGgw\n\t\t\t\t\t\tDQYJKoZIhvcNAQELBQADggEBAJFMU/i/7sVsL/3q2Cjpl4xGphIqw/xA5wy2xp0Y\n\t\t\t\t\t\tmXEPK5mSeZQTmYfQhH8SJeba/CapeXoXzdFwveF0jLgpjB1k4JIsFjeav4IQqO6+\n\t\t\t\t\t\tjAF8AqOZHF3meSxlyQgoqJGwdrGSIvh4gy+muMh/D5k2TofqIHIxxTm2feb4PuMR\n\t\t\t\t\t\tcuboNR5MDxzEiHgGBKvFPpea2AENpjgBuRBxogi6LU2jsaB8MjweyZZJLeMYuRrl\n\t\t\t\t\t\t+0jolUo6/0w181pG0tK3jSqRRG3UAvxp7v/oMkdH+0fNmhbwIEUfAb2wdc2cNLko\n\t\t\t\t\t\tz/nsVV3bjy7BvANR9zBR2P2kSUigfb8XlBN+FrVImqdtIj8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTzCCAjegAwIBAgIUASRtwxa77nvzG1pY8eQRuAM5HGcwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwJDEiMCAGA1UEAwwZaWRwLmFiaW5nZG9uLXdpdG5leS5hYy51azAeFw0xNTEw\n\t\t\t\t\t\tMzAxMDI4MzdaFw0zNTEwMzAxMDI4MzdaMCQxIjAgBgNVBAMMGWlkcC5hYmluZ2Rv\n\t\t\t\t\t\tbi13aXRuZXkuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDM\n\t\t\t\t\t\tzNX2/zEDgoRs6AgceOSWEZREYiIaFzC3kkK8iIQRfn8GLhk0P9qzTeFNlfgewMri\n\t\t\t\t\t\tT3vbeTPyrgSHIgHpjK0/o9ir3PJMzfove5oywzJomvO7+6EbIuWCmZHoIsbYVhVP\n\t\t\t\t\t\td6xR7vpuo2iSpsqsUnNJfSL1eSb7HGgZtuqwUKBnYFQokw/lxBukD5vj94sZowlU\n\t\t\t\t\t\tpMbSMGdFolws8KSjCJworK61wFwexVwL18X+h47GnAx/zqTDXQOIgLscbPmxHCB9\n\t\t\t\t\t\td/HrdXjt9w+nnF/UvhGI/9rypKTL8IgEQpB1gBwwE2ktcGipUXqMBXncZmvzVOS6\n\t\t\t\t\t\tudqWX73azf7CjZLzQNy1AgMBAAGjeTB3MB0GA1UdDgQWBBSZLe0Cy8n6uaEE8UYu\n\t\t\t\t\t\t9bYxqg/afzBWBgNVHREETzBNghlpZHAuYWJpbmdkb24td2l0bmV5LmFjLnVrhjBo\n\t\t\t\t\t\tdHRwczovL2lkcC5hYmluZ2Rvbi13aXRuZXkuYWMudWsvaWRwL3NoaWJib2xldGgw\n\t\t\t\t\t\tDQYJKoZIhvcNAQELBQADggEBAMKn76gfCQqUoYWVfCHm+nVIjQrFuf7F7rNPCJN4\n\t\t\t\t\t\tJa1bp8nmhnWuJj4oW7T6iyX2+ttXVd0vMzrqBM0qETG1rzTYJjuLvTjKwRAsIrlJ\n\t\t\t\t\t\t/Cc5iY6Xa5jfUoSMTAnuLZ9h/UIkPIMkeFfxG9qK5pE7s7piGPO7tUccAU0DQVCY\n\t\t\t\t\t\tduE2wbUYZNfHwieygpg0Kn8n34Qjpddp4KNN5gwBoKll/x6fIczePfg37VQcrq44\n\t\t\t\t\t\tObrTbjOI4EheoS793EIihLWUkN1/1P2rZI+KhAgXqOtnpaUKdga6z8BjQExpJMzr\n\t\t\t\t\t\tWrt0e8XJ7W1dmFHPHsp9LRKIPSbXP+gDI+GHEQGxXxAmUYk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Abingdon and Witney College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.abingdon-witney.ac.uk"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Abingdon and Witney College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.hawaii.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "its-iam-help@lists.hawaii.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UH ITS Identity and Access Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mhodges@hawaii.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael Hodges"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.hawaii.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.hawaii.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.hawaii.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUbG6AsWJKVFL4BChkxcf2t9iBajMwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOaWRwLmhhd2FpaS5lZHUwHhcNMTAwNjA4MDE0ODI4WhcN\nMzAwNjA4MDE0ODI4WjAZMRcwFQYDVQQDEw5pZHAuaGF3YWlpLmVkdTCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBANw36Y5YP/lArq7ctP14ghwuWEUeMUUl\n5Nkd7TpKa4aeHyj+UoCTQQHfy+arJO1itCPHz98Uhaw4G4XQnxQhfuw6L6mz2//A\neOdlpt5GkJMQIy5pE4pLOXOhHBYJmBLsTPWB8I0QizAAb3xXTeUB++ww0IO9bOR0\nVA8tI6kWSCWlxDAQQ4Thn/Jz0XEX1R2YJQR8b5oo+FIuV9In+qJ3j4NbUqfeKMzL\nvK+fNeH/XhyT20dkp8g3gXfEX0zVwFSjiYeYDulD/HTnjoy6ZBheXPJOSAW8ywAC\n0xd4hmFpsGjmPNHL+17suRCKXcDkwUsmwcZ9/RWvo/iJLE1Ol763OhUCAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOaWRwLmhhd2FpaS5lZHWGJWh0dHBzOi8vaWRwLmhhd2Fp\naS5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFH/WD1Sn9/gtumFPjrjPJaeN\nzMYVMA0GCSqGSIb3DQEBBQUAA4IBAQAuNKVRhisKC2eBievJQzGjMV7WAsAnRrR6\n6bMHDqIp3xfi+/H0b9dVm8SqBj/p4mHp/aL8156Swm02souRvqg6WaKsV4q3BDKk\naXeO5QDC+tC6HB7NSofJV7IcJLs5cZjqSRf3grbSWMugafBVbIvJuhs7uTYVZJby\n6h/kbkMY4Y7Fgg7Vg9yLtmyDMJs7eUz5pY4vPHzxwMVC6amJSMmMVhjsRWnmaAq+\n+jxLLXON7aWQGK5hhCLuzDL0zq6pX6THeEoNssY75ZTX0mWIaMwDQnvnA+5E2ca3\nlcsojI5PrsQEZo8UhgHFafO6bTiv+g2a2j0mVhWU1YJGOscK2Awq"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hawaii.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UH Web Login Service"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.hawaii.edu/UH_System_Logo.png",
                    "lang": "en",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Hawaii"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Hawaii"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hawaii.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Hawaii"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.solentsu.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.solentsu.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-10-24T10:30:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Solent Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.solentsu.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.solentsu.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.solentsu.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.solentsu.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.solentsu.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.solentsu.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.solentsu.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.solentsu.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.solentsu.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.solentsu.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.solentsu.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.solentsu.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.solentsu.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.solentsu.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.eki.ee/simplesamlphp/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "eenet@eenet.ee"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TAAT"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.eki.ee/simplesamlphp/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://taat.edu.ee/main/documents/?lang=en"
              }
            ],
            "registration_authority": "http://taat.edu.ee",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.eki.ee/simplesamlphp/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "want_authn_requests_signed": "true",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.eki.ee/simplesamlphp/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eki.ee"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "et",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Eesti keele instituut"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of the Estonian Language"
          }
        ],
        "organization_url": [
          {
            "lang": "et",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eki.ee"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eki.ee"
          }
        ],
        "organization_name": [
          {
            "lang": "et",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eesti keele instituut"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of the Estonian Language"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.ifpr.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jefferson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cinfra@ifpr.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.ifpr.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID2DCCAsACAQAwDQYJKoZIhvcNAQEFBQAwgbExKzApBgNVBAoTIklGUFIgLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkbyBQYXJhbmExDTALBgNVBAsTBERUSUMxITAfBgkq\nhkiG9w0BCQEWEmNpbmZyYUBpZnByLmVkdS5icjERMA8GA1UEBxMIQ3VyaXRpYmEx\nDzANBgNVBAgTBlBhcmFuYTELMAkGA1UEBhMCQlIxHzAdBgNVBAMTFnNoaWJib2xl\ndGguaWZwci5lZHUuYnIwHhcNMTQwNDIyMTgyMTAyWhcNMTcwNDIxMTgyMTAyWjCB\nsTErMCkGA1UEChMiSUZQUiAtIEluc3RpdHV0byBGZWRlcmFsIGRvIFBhcmFuYTEN\nMAsGA1UECxMERFRJQzEhMB8GCSqGSIb3DQEJARYSY2luZnJhQGlmcHIuZWR1LmJy\nMREwDwYDVQQHEwhDdXJpdGliYTEPMA0GA1UECBMGUGFyYW5hMQswCQYDVQQGEwJC\nUjEfMB0GA1UEAxMWc2hpYmJvbGV0aC5pZnByLmVkdS5icjCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAL+QMvkPnIAOTQOZTKrQeyHwl1GsqdR5m7+7XhQl\n7GKYJbNwcszmZ755m7uOtz7lmBiI0ZGe77tvcExGPh9lbQiu2IGNLfA2hEtJ4FOA\nRfAATUN6HNtLEEGFxBoG94+E46FdhNVOWUUIlaPVuu9rWbEnY4+rleHEFQ4qveY6\nl1lan5To0CEd4AZEox20EDvtASKR0V+rsgGTGfX7PRnmLFLmbaOj8DkAaYrLdsvC\nl4cA/KspTuSeFO/JSGaZMwZzUlw9znB7KK1oBIas4HQq4JdgqN02mP32E1zYJwm8\n0i/jqijkPrq8vNh97L8itIKB3Z+MEMUc2mimLfbBHu/BrP8CAwEAATANBgkqhkiG\n9w0BAQUFAAOCAQEAUE5Wp5u744Ur0FMDBRSKpsG0mfgBhneFPE5BnLyjKaNKe9wL\noWvmERcRMKMfXCthEdL7xRjg3PyaCHanuR2KtqiGrKNMtLtBewhqLBoygasNUfeE\nCIjCG+f57fEsd+cqTidaq5uJn3mcKIy/f3cBEesjRvGsTEQQIjrd6pxKqqKNdMPc\n0s9J+ykM0ZPdWusS+IIStc5WEuS3ZrvkwqgInZxvpAobYBxfFIdZeW1pAudK8YHw\nkHoWX9q1+fm3k/1z+W3MvDdC6+WAqEJKWHyMqVQwnzHbwk6Q2jlzQOH9D9n31L6H\naNQDToC/YZpWymJvQafzCi1CmvvqS5M497IndQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.ifpr.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.ifpr.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.ifpr.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.ifpr.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.ifpr.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.ifpr.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.ifpr.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.ifpr.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifpr.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifpr.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFPR - Instituto Federal do Parana"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFPR - Instituto Federal do Parana"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFPR - Instituto Federal do Parana"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFPR - Instituto Federal do Parana"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID2DCCAsACAQAwDQYJKoZIhvcNAQEFBQAwgbExKzApBgNVBAoTIklGUFIgLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkbyBQYXJhbmExDTALBgNVBAsTBERUSUMxITAfBgkq\nhkiG9w0BCQEWEmNpbmZyYUBpZnByLmVkdS5icjERMA8GA1UEBxMIQ3VyaXRpYmEx\nDzANBgNVBAgTBlBhcmFuYTELMAkGA1UEBhMCQlIxHzAdBgNVBAMTFnNoaWJib2xl\ndGguaWZwci5lZHUuYnIwHhcNMTQwNDIyMTgyMTAyWhcNMTcwNDIxMTgyMTAyWjCB\nsTErMCkGA1UEChMiSUZQUiAtIEluc3RpdHV0byBGZWRlcmFsIGRvIFBhcmFuYTEN\nMAsGA1UECxMERFRJQzEhMB8GCSqGSIb3DQEJARYSY2luZnJhQGlmcHIuZWR1LmJy\nMREwDwYDVQQHEwhDdXJpdGliYTEPMA0GA1UECBMGUGFyYW5hMQswCQYDVQQGEwJC\nUjEfMB0GA1UEAxMWc2hpYmJvbGV0aC5pZnByLmVkdS5icjCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAL+QMvkPnIAOTQOZTKrQeyHwl1GsqdR5m7+7XhQl\n7GKYJbNwcszmZ755m7uOtz7lmBiI0ZGe77tvcExGPh9lbQiu2IGNLfA2hEtJ4FOA\nRfAATUN6HNtLEEGFxBoG94+E46FdhNVOWUUIlaPVuu9rWbEnY4+rleHEFQ4qveY6\nl1lan5To0CEd4AZEox20EDvtASKR0V+rsgGTGfX7PRnmLFLmbaOj8DkAaYrLdsvC\nl4cA/KspTuSeFO/JSGaZMwZzUlw9znB7KK1oBIas4HQq4JdgqN02mP32E1zYJwm8\n0i/jqijkPrq8vNh97L8itIKB3Z+MEMUc2mimLfbBHu/BrP8CAwEAATANBgkqhkiG\n9w0BAQUFAAOCAQEAUE5Wp5u744Ur0FMDBRSKpsG0mfgBhneFPE5BnLyjKaNKe9wL\noWvmERcRMKMfXCthEdL7xRjg3PyaCHanuR2KtqiGrKNMtLtBewhqLBoygasNUfeE\nCIjCG+f57fEsd+cqTidaq5uJn3mcKIy/f3cBEesjRvGsTEQQIjrd6pxKqqKNdMPc\n0s9J+ykM0ZPdWusS+IIStc5WEuS3ZrvkwqgInZxvpAobYBxfFIdZeW1pAudK8YHw\nkHoWX9q1+fm3k/1z+W3MvDdC6+WAqEJKWHyMqVQwnzHbwk6Q2jlzQOH9D9n31L6H\naNQDToC/YZpWymJvQafzCi1CmvvqS5M497IndQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFPR - Instituto Federal do Parana"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFPR - Instituto Federal do Parana"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifpr.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifpr.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFPR - Instituto Federal do Parana"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFPR - Instituto Federal do Parana"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.uclouvain.be/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Delcourt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "olivier.delcourt@uclouvain.be"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olivier"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uclouvain.be/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://federation.belnet.be/files/Belnet-metadata-registration-practice-statement.txt"
              }
            ],
            "registration_instant": "2012-03-27T12:00:00Z",
            "registration_authority": "http://federation.belnet.be/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uclouvain.be:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uclouvain.be:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIULsoRND5rnR86uR/01PHcK0n+pmkwDQYJKoZIhvcNAQEL\nBQAwGzEZMBcGA1UEAwwQaWRwLnVjbG91dmFpbi5iZTAeFw0xNTA2MjMxMjQzNDla\nFw0zNTA2MjMxMjQzNDlaMBsxGTAXBgNVBAMMEGlkcC51Y2xvdXZhaW4uYmUwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCTMboR5U7bjJx+kyifcb531Z/f\nQdgE8RTc3x4RlKe48OpVnBnmqmWsWQLLa42a+DvnKfZv7gqYo/51x6Zc4YsQHL/w\nueOUAabNgNbXkyrEnD7yoHuS9jTCvGV+HK+J3sNf6HVx5MZnxk6mui0r8IhzRfDl\nPq9kM+W2OPKkbYCoIBjBH1S3BsPifz0D2pFpiQ1Fjc19u4818xvP4r12ALcWcDxP\n8eI+rKH8dxAld+DeQAwkwvtzDh+6fgvv8ktBEVfMd793mCIjoP4HS+WJqgLX4ttD\nj63/cQ3oYSN20CFLuhbd3d6yfHx8c9Ea6F/beNloGGDatZYJ4mk2NBATXbhdAgMB\nAAGjZzBlMB0GA1UdDgQWBBQc/p554yCIxGlazuaJK8sT3Jv6JzBEBgNVHREEPTA7\nghBpZHAudWNsb3V2YWluLmJlhidodHRwczovL2lkcC51Y2xvdXZhaW4uYmUvaWRw\nL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAAQJmepDebdFihTF+DoqBM2n\nCMG5Qrdw5RIh4syzeFhzJBJPzsRvGCPQUP78exFjYD9D5eg0SqXFzN2ip507QeVu\nbvZj2W0Sg69XRSAljXiE9iqK5i3+4lV+lYgjT34A5pDmwr22M8C/QUSfPNqc5TJS\n61Ua0VOxuhRRljSIufX/lZd4PHL1/IQ6TnoHRvTJ/O3EomN75JNczHD+GCFxfrZk\nBIyJrdYr392Pi2qT9hndEWKEGsJFyhcTicd3lf0EShcXm2KbpEvNz8k+S4Twn8q4\ngoNAmKsfT41JZjV09SqBnNHg/0fYtAHaNH0QOyRhS4kVhUkmdrdnbhuzWwLL+Y4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUL59ORSvxP+AJwSsPyJpZlpDdWjowDQYJKoZIhvcNAQEL\nBQAwGzEZMBcGA1UEAwwQaWRwLnVjbG91dmFpbi5iZTAeFw0xNTA2MjMxMjQzNDda\nFw0zNTA2MjMxMjQzNDdaMBsxGTAXBgNVBAMMEGlkcC51Y2xvdXZhaW4uYmUwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCRNp3NBgCosZPYfQLAKigckH5a\nyTybh/Nw2jRUo2WuBk4DYzsiVbjdfylcj/vt6ZO7TDk3oTRkUwlSwMqujRnSpOv7\nNSJdqemJPfKG77JIomnSXLhlF3Ti1l1MEAM3rm+BhFUiCLOyzpgCejEo5jRc7ioJ\nbrOWBBU6ixxlreyHN8HJv6oNfGbF+0+RfEzntGzhVRW/TWIbXOjJikDxH9GTKqo/\nOBtcPW4r13EiE0SaPibr4IDGkZ31e9k1thWfQf8oVQlloqX8TqW4Qfa2fIbBCihP\nHwivY0x6R7u7OAZYa9rbZutwD4K4ANYHl246f9LKGIDj1fT3sx7mNd8qymTpAgMB\nAAGjZzBlMB0GA1UdDgQWBBQbRFM5+fd31sppff2cCm3rNXwDpDBEBgNVHREEPTA7\nghBpZHAudWNsb3V2YWluLmJlhidodHRwczovL2lkcC51Y2xvdXZhaW4uYmUvaWRw\nL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAGO0F2vutWO9OSP6/RIE7a8Y\nkboJpQaIQSafbr201WeLNvrOVvbVZg317Z9bx7TvURdHVhGYhCfQpDyDLBRISC1R\nugHbCmBDf72I5mF9XXNgoZcclOEprcxrFo8HHb4Y3LCzx+tny1NnBiQ7qOmOp69R\noPCTgFYIFRUgpQX//LI3O3Mvri5VTyBEuZi3xNb3nfOgO7Nm1j5WafWkY/Ez7SLc\n+Eq9MovDNNSNM+tHunfAL+gpMXqnNqgoX/rdf1zCh4iFADNcVIlIWm08teLueerC\nzw6rVzahF34aPaCK0oBPRTHGG43EyKpYvq6WVoVGKPO02ZnUC0znXfiQft47ImE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUW9CW/lDKLYeNR9Qf3Shw0wzP7/8wDQYJKoZIhvcNAQEL\nBQAwGzEZMBcGA1UEAwwQaWRwLnVjbG91dmFpbi5iZTAeFw0xNTA2MjMxMjQzNDha\nFw0zNTA2MjMxMjQzNDhaMBsxGTAXBgNVBAMMEGlkcC51Y2xvdXZhaW4uYmUwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDQ6bNbNeyP/geUyaLvd0FWwDia\nEhIpYSWs7MoG7f4eQxuY1d3rwCzrIXNYZqNsjUsR7owKkLGCFXMi9UC/gVoTKNcf\n8bba6d/2LXajX0mjww+0CnsbWlEMBMYu3I/jxnyOf4XVhdYxmgk7Yf/J/r1weOI6\np8a/FNHp1tYwhwdUZGPJPKPnH5cFd1qdLtRVadk6uDYzk3N6R/rAMNBszsWnP3jK\nN7Q6ydzsyelEcIzEjkrs65ONW5wpVj2XTjNPdzGOief6OmaRUBA+3dBc6IamSRNO\ny6/I183KsrWOn4nycVI/YzjzOF1zpC8il4C4QdlXz/auqfFyyaBdMftBiK6/AgMB\nAAGjZzBlMB0GA1UdDgQWBBR866jbr+1nZyWWyqTmX1a02AEHwTBEBgNVHREEPTA7\nghBpZHAudWNsb3V2YWluLmJlhidodHRwczovL2lkcC51Y2xvdXZhaW4uYmUvaWRw\nL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBABmis53jaA3iQihgzcnFaJL1\n0kUrsuXhZ9AsCdVHtszqkh7aKSag81jGFUmxKPGRM9/gP+wW8T4R62gEhcgdfkaB\nm1JNt0AQKzr64b3nehsxVEHGWyJxgQdV+sWAYv8p7BQmx2dGy9Gf9d7r0f2BVxLh\nXDBjy1GOfQe9Y8f918KdHX9ekfVZzVJu4Ukoz66rOWlDenbOZb///Ih1kE20Yh+L\njB2eA8lGhLRdfBI2Z7gkLxL6eDCa9QzxZnrX8Pd8a5yGlSe51IyfRFeY5B8inl0p\nRQ04bxgiI77gAJH7GDHsFbX71Gmfurj7pJ3R5F25y6KUWELAmhAPm4Kb0WyV0Us="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uclouvain.be"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.uclouvain.be/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uclouvain.be/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.uclouvain.be/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uclouvain.be/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uclouvain.be:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uclouvain.be:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uclouvain.be"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.uclouvain.be/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.uclouvain.be/en-index.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universite Catholique de Louvain"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Catholic University of Louvain"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "L'Universite Catholique de Louvain est une universite pluridisciplinaire au coeur de l'Europe (Belgique)."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Catholic University of Louvain is an pluridisciplinary university at the heart of Europe (Belgium)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.uclouvain.be/favicon.ico",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.uclouvain.be/idp/images/UCL-bandeau.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "540"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.uclouvain.be/10547.html"
                  }
                ]
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "uclouvain.be"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:50.669920,4.615240"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.104.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:6a8:3080::/44"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIULsoRND5rnR86uR/01PHcK0n+pmkwDQYJKoZIhvcNAQEL\nBQAwGzEZMBcGA1UEAwwQaWRwLnVjbG91dmFpbi5iZTAeFw0xNTA2MjMxMjQzNDla\nFw0zNTA2MjMxMjQzNDlaMBsxGTAXBgNVBAMMEGlkcC51Y2xvdXZhaW4uYmUwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCTMboR5U7bjJx+kyifcb531Z/f\nQdgE8RTc3x4RlKe48OpVnBnmqmWsWQLLa42a+DvnKfZv7gqYo/51x6Zc4YsQHL/w\nueOUAabNgNbXkyrEnD7yoHuS9jTCvGV+HK+J3sNf6HVx5MZnxk6mui0r8IhzRfDl\nPq9kM+W2OPKkbYCoIBjBH1S3BsPifz0D2pFpiQ1Fjc19u4818xvP4r12ALcWcDxP\n8eI+rKH8dxAld+DeQAwkwvtzDh+6fgvv8ktBEVfMd793mCIjoP4HS+WJqgLX4ttD\nj63/cQ3oYSN20CFLuhbd3d6yfHx8c9Ea6F/beNloGGDatZYJ4mk2NBATXbhdAgMB\nAAGjZzBlMB0GA1UdDgQWBBQc/p554yCIxGlazuaJK8sT3Jv6JzBEBgNVHREEPTA7\nghBpZHAudWNsb3V2YWluLmJlhidodHRwczovL2lkcC51Y2xvdXZhaW4uYmUvaWRw\nL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAAQJmepDebdFihTF+DoqBM2n\nCMG5Qrdw5RIh4syzeFhzJBJPzsRvGCPQUP78exFjYD9D5eg0SqXFzN2ip507QeVu\nbvZj2W0Sg69XRSAljXiE9iqK5i3+4lV+lYgjT34A5pDmwr22M8C/QUSfPNqc5TJS\n61Ua0VOxuhRRljSIufX/lZd4PHL1/IQ6TnoHRvTJ/O3EomN75JNczHD+GCFxfrZk\nBIyJrdYr392Pi2qT9hndEWKEGsJFyhcTicd3lf0EShcXm2KbpEvNz8k+S4Twn8q4\ngoNAmKsfT41JZjV09SqBnNHg/0fYtAHaNH0QOyRhS4kVhUkmdrdnbhuzWwLL+Y4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUL59ORSvxP+AJwSsPyJpZlpDdWjowDQYJKoZIhvcNAQEL\nBQAwGzEZMBcGA1UEAwwQaWRwLnVjbG91dmFpbi5iZTAeFw0xNTA2MjMxMjQzNDda\nFw0zNTA2MjMxMjQzNDdaMBsxGTAXBgNVBAMMEGlkcC51Y2xvdXZhaW4uYmUwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCRNp3NBgCosZPYfQLAKigckH5a\nyTybh/Nw2jRUo2WuBk4DYzsiVbjdfylcj/vt6ZO7TDk3oTRkUwlSwMqujRnSpOv7\nNSJdqemJPfKG77JIomnSXLhlF3Ti1l1MEAM3rm+BhFUiCLOyzpgCejEo5jRc7ioJ\nbrOWBBU6ixxlreyHN8HJv6oNfGbF+0+RfEzntGzhVRW/TWIbXOjJikDxH9GTKqo/\nOBtcPW4r13EiE0SaPibr4IDGkZ31e9k1thWfQf8oVQlloqX8TqW4Qfa2fIbBCihP\nHwivY0x6R7u7OAZYa9rbZutwD4K4ANYHl246f9LKGIDj1fT3sx7mNd8qymTpAgMB\nAAGjZzBlMB0GA1UdDgQWBBQbRFM5+fd31sppff2cCm3rNXwDpDBEBgNVHREEPTA7\nghBpZHAudWNsb3V2YWluLmJlhidodHRwczovL2lkcC51Y2xvdXZhaW4uYmUvaWRw\nL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAGO0F2vutWO9OSP6/RIE7a8Y\nkboJpQaIQSafbr201WeLNvrOVvbVZg317Z9bx7TvURdHVhGYhCfQpDyDLBRISC1R\nugHbCmBDf72I5mF9XXNgoZcclOEprcxrFo8HHb4Y3LCzx+tny1NnBiQ7qOmOp69R\noPCTgFYIFRUgpQX//LI3O3Mvri5VTyBEuZi3xNb3nfOgO7Nm1j5WafWkY/Ez7SLc\n+Eq9MovDNNSNM+tHunfAL+gpMXqnNqgoX/rdf1zCh4iFADNcVIlIWm08teLueerC\nzw6rVzahF34aPaCK0oBPRTHGG43EyKpYvq6WVoVGKPO02ZnUC0znXfiQft47ImE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUW9CW/lDKLYeNR9Qf3Shw0wzP7/8wDQYJKoZIhvcNAQEL\nBQAwGzEZMBcGA1UEAwwQaWRwLnVjbG91dmFpbi5iZTAeFw0xNTA2MjMxMjQzNDha\nFw0zNTA2MjMxMjQzNDhaMBsxGTAXBgNVBAMMEGlkcC51Y2xvdXZhaW4uYmUwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDQ6bNbNeyP/geUyaLvd0FWwDia\nEhIpYSWs7MoG7f4eQxuY1d3rwCzrIXNYZqNsjUsR7owKkLGCFXMi9UC/gVoTKNcf\n8bba6d/2LXajX0mjww+0CnsbWlEMBMYu3I/jxnyOf4XVhdYxmgk7Yf/J/r1weOI6\np8a/FNHp1tYwhwdUZGPJPKPnH5cFd1qdLtRVadk6uDYzk3N6R/rAMNBszsWnP3jK\nN7Q6ydzsyelEcIzEjkrs65ONW5wpVj2XTjNPdzGOief6OmaRUBA+3dBc6IamSRNO\ny6/I183KsrWOn4nycVI/YzjzOF1zpC8il4C4QdlXz/auqfFyyaBdMftBiK6/AgMB\nAAGjZzBlMB0GA1UdDgQWBBR866jbr+1nZyWWyqTmX1a02AEHwTBEBgNVHREEPTA7\nghBpZHAudWNsb3V2YWluLmJlhidodHRwczovL2lkcC51Y2xvdXZhaW4uYmUvaWRw\nL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBABmis53jaA3iQihgzcnFaJL1\n0kUrsuXhZ9AsCdVHtszqkh7aKSag81jGFUmxKPGRM9/gP+wW8T4R62gEhcgdfkaB\nm1JNt0AQKzr64b3nehsxVEHGWyJxgQdV+sWAYv8p7BQmx2dGy9Gf9d7r0f2BVxLh\nXDBjy1GOfQe9Y8f918KdHX9ekfVZzVJu4Ukoz66rOWlDenbOZb///Ih1kE20Yh+L\njB2eA8lGhLRdfBI2Z7gkLxL6eDCa9QzxZnrX8Pd8a5yGlSe51IyfRFeY5B8inl0p\nRQ04bxgiI77gAJH7GDHsFbX71Gmfurj7pJ3R5F25y6KUWELAmhAPm4Kb0WyV0Us="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universite Catholique de Louvain"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uclouvain.be/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universite Catholique de Louvain"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://birk.wayf.dk/birk.php/auth.msk.dk/adfs/services/trust",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://birk.wayf.dk/birk.php/auth.msk.dk/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2015-06-26T11:11:53Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/auth.msk.dk/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "msk.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Maskinmesterskolen K\u00f8benhavn"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Copenhagen School of Marine Engineering and Technology Management"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "msk.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC1jCCAb4CAQcwDQYJKoZIhvcNAQELBQAwMTEvMC0GA1UEAwwmaHR0cDovL2F1\ndGgubXNrLmRrL2FkZnMvc2VydmljZXMvdHJ1c3QwHhcNMTUwMTAxMDAwMDAwWhcN\nMjUxMjMxMjM1OTU5WjAxMS8wLQYDVQQDDCZodHRwOi8vYXV0aC5tc2suZGsvYWRm\ncy9zZXJ2aWNlcy90cnVzdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAMeIDApqEFO4jhn4gnWuA54SIILLdtH1Ah7cGkKx6MUJTmtLORYA2pW5zU8N+nQl\n0hmGs9eyYMlAyaJ08IY8gNAqj5uT5p/f4RQVL8j/7fmxIFfa9/6HUMe9lX2OzOea\nlJWOnsdn9ag9YHKRYEk7QA5WbMHnOVqqRLfonvr7DF6vB2m4TFWdhI13vdL4DJP8\nRn61cA77qVDwUv9gyUmdSRJpKotIcXLTUPaoE2ZhHAGkJLr91RnLGLS3mPyCEpQP\ngEc5lVq+frknrZwl1eI5wxHJQAinnsZdCsvrcq2uMhxd12r4JnJnm3fsR1Q4jPja\nOgVzLvcwU6e3KeUoS87DUEkCAwEAATANBgkqhkiG9w0BAQsFAAOCAQEASUaHBtxa\nUS3uTB3ULRH9GaZ/G418Tk1/0MMG/3KGDkI0boi7AFgr+t+/J2gmSd6nPpu5UCgd\nE4jpj1zX6+nU+xI/XQrRghCTqyakwG9JDzZsMDG78kLp4EBVfZbeJ/4vIm1i46Bx\noDZPgIrNPa3NOCnsuRABVBf1obHzsy1pBNAVs4lRFoy/+cad9KYbHOLu4r0DteLA\nzUsbQupz63gLqkFj4t+lcOV743aWzX4Z0RVZ3JfqfqBW5weKbqShMmFBBLnxqBzc\nY0vFLNNUbts2J7AXDQK28bn0u2mnK6aC2eFqEgcTU6xg+qQbj81PxKigfSJRsh+R\n5pHBv+YlEDNmzQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Maskinmesterskolen K\u00f8benhavn"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Copenhagen School of Marine Engineering and Technology Management"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.msk.dk/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.msk.dk/om-skolen/english"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Maskinmesterskolen K\u00f8benhavn"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Copenhagen School of Marine Engineering and Technology Management"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://portofranco.ufma.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Diego Figueiredo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "diego.luis@ufma.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://portofranco.ufma.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID3jCCAsYCAQAwDQYJKoZIhvcNAQEFBQAwgbQxMDAuBgNVBAoTJ1VGTUEgLSBV\nbml2ZXJzaWRhZGUgRmVkZXJhbCBkbyBNYXJhbmhhbzEMMAoGA1UECxMDTlRJMSEw\nHwYJKoZIhvcNAQkBFhJkaWVnby5sdWlzQHVmbWEuYnIxETAPBgNVBAcTCFNhbyBM\ndWlzMREwDwYDVQQIEwhNYXJhbmhhbzELMAkGA1UEBhMCQlIxHDAaBgNVBAMTE3Bv\ncnRvZnJhbmNvLnVmbWEuYnIwHhcNMTUxMTA5MjA0MTAyWhcNMTgxMTA4MjA0MTAy\nWjCBtDEwMC4GA1UEChMnVUZNQSAtIFVuaXZlcnNpZGFkZSBGZWRlcmFsIGRvIE1h\ncmFuaGFvMQwwCgYDVQQLEwNOVEkxITAfBgkqhkiG9w0BCQEWEmRpZWdvLmx1aXNA\ndWZtYS5icjERMA8GA1UEBxMIU2FvIEx1aXMxETAPBgNVBAgTCE1hcmFuaGFvMQsw\nCQYDVQQGEwJCUjEcMBoGA1UEAxMTcG9ydG9mcmFuY28udWZtYS5icjCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ8qhiylWVK+Op8tJPWa5HtGHUwgdTCk\nihewKun6bvySKb+9A4iMXgYehtIty9lV23IaHlxDKbgGRcXjWInEwextjGToXyZB\nwRz+e4Y2joCVKw/iLOt6r5lKPEENlbYczz0+XfK3egibfibt1EbLr8Yyj/QW/6zY\ny1prsXNwGYe2vFDEMHwcrBr3Z7IpFsJGJ/9xw9UmobmwQhdny2xVq+tmYgWtFDDY\nbkc8FYk/I628ObZuKCOvaakJJkNvoFJkyZDwvOcs0tFL4560nztuRsdglbqjSl8N\nWzQ5JTM/vtIshIkYMBAjuCT5QxGDG3DwnVB0dj85dTibudQlZarD53sCAwEAATAN\nBgkqhkiG9w0BAQUFAAOCAQEATOK9hSMoC68PEsh4oeG81ZLpp97dwe9yNeuGq4Ly\nlYF2ikH0SIRCnj9GQ2+MyoEzbonA/ludt7ZAJfkKz0Kt+V0OL4NIF1z3D25PDlDb\neSvL3M2EC8Dn2s7dr+cFvt2KACbRa3yRz3TmBoSHBlX1nUB33jVMIOHyKpLAKyVz\nWskJDJaGkQHHnzgWFBByR/hnx2+78lh0b65fN71yNvIurLmyCU5pPktvBpCIGB6e\nq75Pgfria4aDAF9QLVPkjsGH9v67hyUm6UVG3wWVQIPDr8yPJuyjpBQMsQjh0joV\nKppwAy5eNWAi4mWRFM4cGIz4BEG+BogTKBTVyF1/sNjC6Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufma.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://portofranco.ufma.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://portofranco.ufma.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://portofranco.ufma.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://portofranco.ufma.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://portofranco.ufma.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://portofranco.ufma.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://portofranco.ufma.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://portofranco.ufma.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufma.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufma.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufma.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFMA - Universidade Federal do Maranhao"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFMA - Universidade Federal do Maranhao"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFMA - Universidade Federal do Maranhao"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFMA - Universidade Federal do Maranhao"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID3jCCAsYCAQAwDQYJKoZIhvcNAQEFBQAwgbQxMDAuBgNVBAoTJ1VGTUEgLSBV\nbml2ZXJzaWRhZGUgRmVkZXJhbCBkbyBNYXJhbmhhbzEMMAoGA1UECxMDTlRJMSEw\nHwYJKoZIhvcNAQkBFhJkaWVnby5sdWlzQHVmbWEuYnIxETAPBgNVBAcTCFNhbyBM\ndWlzMREwDwYDVQQIEwhNYXJhbmhhbzELMAkGA1UEBhMCQlIxHDAaBgNVBAMTE3Bv\ncnRvZnJhbmNvLnVmbWEuYnIwHhcNMTUxMTA5MjA0MTAyWhcNMTgxMTA4MjA0MTAy\nWjCBtDEwMC4GA1UEChMnVUZNQSAtIFVuaXZlcnNpZGFkZSBGZWRlcmFsIGRvIE1h\ncmFuaGFvMQwwCgYDVQQLEwNOVEkxITAfBgkqhkiG9w0BCQEWEmRpZWdvLmx1aXNA\ndWZtYS5icjERMA8GA1UEBxMIU2FvIEx1aXMxETAPBgNVBAgTCE1hcmFuaGFvMQsw\nCQYDVQQGEwJCUjEcMBoGA1UEAxMTcG9ydG9mcmFuY28udWZtYS5icjCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ8qhiylWVK+Op8tJPWa5HtGHUwgdTCk\nihewKun6bvySKb+9A4iMXgYehtIty9lV23IaHlxDKbgGRcXjWInEwextjGToXyZB\nwRz+e4Y2joCVKw/iLOt6r5lKPEENlbYczz0+XfK3egibfibt1EbLr8Yyj/QW/6zY\ny1prsXNwGYe2vFDEMHwcrBr3Z7IpFsJGJ/9xw9UmobmwQhdny2xVq+tmYgWtFDDY\nbkc8FYk/I628ObZuKCOvaakJJkNvoFJkyZDwvOcs0tFL4560nztuRsdglbqjSl8N\nWzQ5JTM/vtIshIkYMBAjuCT5QxGDG3DwnVB0dj85dTibudQlZarD53sCAwEAATAN\nBgkqhkiG9w0BAQUFAAOCAQEATOK9hSMoC68PEsh4oeG81ZLpp97dwe9yNeuGq4Ly\nlYF2ikH0SIRCnj9GQ2+MyoEzbonA/ludt7ZAJfkKz0Kt+V0OL4NIF1z3D25PDlDb\neSvL3M2EC8Dn2s7dr+cFvt2KACbRa3yRz3TmBoSHBlX1nUB33jVMIOHyKpLAKyVz\nWskJDJaGkQHHnzgWFBByR/hnx2+78lh0b65fN71yNvIurLmyCU5pPktvBpCIGB6e\nq75Pgfria4aDAF9QLVPkjsGH9v67hyUm6UVG3wWVQIPDr8yPJuyjpBQMsQjh0joV\nKppwAy5eNWAi4mWRFM4cGIz4BEG+BogTKBTVyF1/sNjC6Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFMA - Universidade Federal do Maranhao"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFMA - Universidade Federal do Maranhao"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufma.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufma.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFMA - Universidade Federal do Maranhao"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFMA - Universidade Federal do Maranhao"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayf.frhavn-gym.dk/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayf.frhavn-gym.dk/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2012-11-15T14:53:18Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayf.frhavn-gym.dk/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "frhavn-gym.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Frederikshavn Gymnasium & HF-kursus"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Frederikshavn upper secondary school and HF-Course"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "frhavn-gym.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAjCCAeoCAQcwDQYJKoZIhvcNAQELBQAwRzFFMEMGA1UEAww8aHR0cHM6Ly93\nYXlmLmZyaGF2bi1neW0uZGsvc2ltcGxlc2FtbC9zYW1sMi9pZHAvbWV0YWRhdGEu\ncGhwMB4XDTE1MDEwMTAwMDAwMFoXDTI1MTIzMTIzNTk1OVowRzFFMEMGA1UEAww8\naHR0cHM6Ly93YXlmLmZyaGF2bi1neW0uZGsvc2ltcGxlc2FtbC9zYW1sMi9pZHAv\nbWV0YWRhdGEucGhwMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAx4gM\nCmoQU7iOGfiCda4DnhIggst20fUCHtwaQrHoxQlOa0s5FgDalbnNTw36dCXSGYaz\n17JgyUDJonTwhjyA0CqPm5Pmn9/hFBUvyP/t+bEgV9r3/odQx72VfY7M55qUlY6e\nx2f1qD1gcpFgSTtADlZswec5WqpEt+ie+vsMXq8HabhMVZ2EjXe90vgMk/xGfrVw\nDvupUPBS/2DJSZ1JEmkqi0hxctNQ9qgTZmEcAaQkuv3VGcsYtLeY/IISlA+ARzmV\nWr5+uSetnCXV4jnDEclACKeexl0Ky+tyra4yHF3Xavgmcmebd+xHVDiM+No6BXMu\n9zBTp7cp5ShLzsNQSQIDAQABMA0GCSqGSIb3DQEBCwUAA4IBAQDEe2XDhPjDzgE9\nzLsGWFD/ZnxJRzVrAJqF3ix9To7XcPxlJXnmIFxkSpM7R7hJvxAWFBN8A7Lsits+\nMFweCoLCOnIeDdIIlM5fVXF0aRX3d8hPI6esnRDMQvtSM4fc/tGux4TGyqm9xNUL\nXE73vx0ig4cN/S+LB+aqvb29JWcL4UJEjF0KmDvoJImY812XYe53M5R/I44gpn+M\nVpnqVuENeOV3seRgxzxpfbA/TIjPtZLuNxeHR7dcGTvU631VfV7E/uxlSTZlxhCV\nCIASt2ITWU50Fzl2O8YDrRF6S0XehWsyr1uWfsDwZiZe9L5rHJSoEZMhPVWdnrtS\nDoLyd1u8"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Frederikshavn Gymnasium & HF-kursus"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Frederikshavn upper secondary school and HF-Course"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://frhavn-gym.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.frhavn-gym.dk/english/"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Frederikshavn Gymnasium & HF-kursus"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Frederikshavn upper secondary school and HF-Course"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.telecom-paristech.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@enst.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.telecom-paristech.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2010-09-06T11:36:26Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.telecom-paristech.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.telecom-paristech.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.telecom-paristech.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mines-telecom.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "telecom-paristech.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.telecom-paristech.fr/"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "T\u00e9l\u00e9com ParisTech"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "T\u00e9l\u00e9com ParisTech"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSzCCAjOgAwIBAgIUOdyX2dtbQ38bYSsIYvHC27pbOf4wDQYJKoZIhvcNAQEF\nBQAwIzEhMB8GA1UEAxMYaWRwLnRlbGVjb20tcGFyaXN0ZWNoLmZyMB4XDTEwMDEy\nODE3MDA0MVoXDTMwMDEyODE3MDA0MVowIzEhMB8GA1UEAxMYaWRwLnRlbGVjb20t\ncGFyaXN0ZWNoLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAiVSP\nMWN9NGSu79LJ5CEhhDAWfKTaaXQRrk26/3axPDtaDJVO9KhJ9oie3SZjlogVvmuE\nUHiONGqWhO4H1eKXfPKQIpq5e+JpR9Nxr8WMsjhXnToCcMZsSes6E44S3YXWVblv\nEmWKE3JFUYWO/cpVGZWjdnWierXziUPo8UcRI8BPBqoCgMQzDkVtJngqNPWim0/M\nS7LbyZmrYbDlwqM74CNFFRK+cknv221xr36sSTVAf9QdbL+zfvxCOxR4vmUxSTG5\nFKD89Js9ELMZoadpJYWEkdIJuvZ0R12dtlXn+rYKpqpOuP/X/kjtJM40WpchSWn7\no2z0KwtUVkkugtUN/QIDAQABo3cwdTBUBgNVHREETTBLghhpZHAudGVsZWNvbS1w\nYXJpc3RlY2guZnKGL2h0dHBzOi8vaWRwLnRlbGVjb20tcGFyaXN0ZWNoLmZyL2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBSzcODCJpeqAD7OPTNA7Uf6rJ/73DANBgkq\nhkiG9w0BAQUFAAOCAQEAPkpw2TRt9SQdGPslqaoEq+/Y+3qdoPAFEipXUxEsexVU\nRZiHCQm90wLhAV4+IGmk5XuVVKN5M+3kQVDq/iql3W9IoShV71mQhDEqNQJkztGK\n1XPWYZu2Qgzui0YessRn7F8/Ts3cRm6L43oAKWJvSR0Zad9L4Eeli/ymCZ+3VO86\nhx8qX90cpGu6iYMPfbu+Dl+dFRxJkNY5SGbNGHvv9ZH3FF7f5cN7R8BtWVgo0rTR\nDmlnOFBrEU8tBkHNwNS0wwdZkOuQjoafB1QOZ39oH7koG+DICom7vxCLTWxcAMj+\n4QsS7+VwhxDRJdfBoQvr3mrm+hxwrCDEGlU3qCaenA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "T\u00e9l\u00e9com ParisTech"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.telecom-paristech.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "T\u00e9l\u00e9com ParisTech"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:cru.fr:federation:univ-st-etienne.fr",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Murgue Thierry"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "thierry.murgue@univ-st-etienne.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Valeille Jean-Fran\u00e7ois"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jean.francois.valeille@univ-st-etienne.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:cru.fr:federation:univ-st-etienne.fr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-07-17T14:19:31Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univ-st-etienne.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univ-st-etienne.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.univ-st-etienne.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-st-etienne.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-st-etienne.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Saint-Etienne - Jean Monnet"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Saint-Etienne - Jean Monnet"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIJAKRhyHl9TUy1MA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmlkcC51bml2LXN0LWV0aWVubmUuZnIwHhcNMTQxMjExMDkwODE5WhcNMTcx\nMjEwMDkwODE5WjAhMR8wHQYDVQQDExZpZHAudW5pdi1zdC1ldGllbm5lLmZyMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA4eKLfLM95OgfT/AudFYKlqnL\nC+ByQ2Kij4dnWoRnHiY3aInQzpkEQSg4gQxm8vNLLV+L3NlNHKEBkMY51aAicrRp\nAwwkiPgNOpSwNf6sE12FFvSqvDy3xsoVgAxbgXbUGP6sCqmbXSlEOQ/ubY3Ss+UT\nzWewDUbMDNm89D6ihHlafuFI21OOOT6qAgvhyvATMK0qJDbobZjDNMAdTBhxdEaN\ngv2QidHj1ITj7GHWRZ0z64yrhMu4ti/ooUJB5yP81AaKJonk4Fut+ljCuMZA6ARY\nA8GgJLuV62ou+03SH5RJb+JaK5qBzZ1Y2fxo++hwutOzNdKbMPoawNg8GIRbRwID\nAQABo3MwcTBQBgNVHREESTBHghZpZHAudW5pdi1zdC1ldGllbm5lLmZyhi11cm46\nbWFjZTpjcnUuZnI6ZmVkZXJhdGlvbjp1bml2LXN0LWV0aWVubmUuZnIwHQYDVR0O\nBBYEFF70lFwBQN8lPT449YrrNS0gch1nMA0GCSqGSIb3DQEBBQUAA4IBAQAD4/dl\nZmjnh27+8G/0U4yVM9UHvrFdCZjHBWwaWm3l+ON1E+JuouxqSf2WI3P6iJUnv/++\nMD1iMaS0MI/mL2atsYgw2QBUE3kgLBNQLulefkdguZh/MziT6TDf7dtcjMza0quA\ngSjSFxAP1DpnOX9YzLoNHfg7rWhlzjZmgtBWq/TDVTMIKHMn+xrptyNB2nzeiQPQ\ny+sDX87f4KU2fKpVjS1OOZv1a9f+U9wRnOXjuTVVr50lj4YdjzVq5g9TGxF3n8Qk\n3My8dpA9BiKR9vHvNPiGJPfruPZnK6WpjX+Q35KHrKNCquj5L09GW3OviRgRkUlu\n8CBvzFGfIhN9GDZ3"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkCgAwIBAgIVAM60eJPNg42CHzM+jgGiPUF8XxVEMA0GCSqGSIb3DQEB\nBQUAMCYxJDAiBgNVBAMTG2lwZC10ZXN0LnVuaXYtc3QtZXRpZW5uZS5mcjAeFw0x\nMDAxMjcxMzMzMTNaFw0zMDAxMjcxMzMzMTNaMCYxJDAiBgNVBAMTG2lwZC10ZXN0\nLnVuaXYtc3QtZXRpZW5uZS5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\nggEBAL/9p3g2bat/dj9BdEBKhJMfh6ruQAb/WENj8VDd69vd0qlg7gBFdcUAlrWu\nlWbGxIGSike4JKk/BflJvJsOw56tqdVOgX574nhz74t7wq3bb4oy4+z6QBU4D4fi\ns81DGmDlYLM+99wTXEeXu6U7MYUoHve76yRLP3tJ/JupT4JVmfWLbmfWpWdaIXTu\nGIMhPPuZ+tlZyVMUy4Yisj1+hxJkC0XbZ/Tt0k/U6ibmFw2RgMZ4e9I/F5XAAuIL\nntj94ucDfkak5IjzdazgL2hyPhRs5HCl8fM02xH3Hiy54o6/ol4Bht3KUotnQ7hf\ndYDxIxHdAkHqDx7rQuSpyTSZckECAwEAAaN9MHswWgYDVR0RBFMwUYIbaXBkLXRl\nc3QudW5pdi1zdC1ldGllbm5lLmZyhjJodHRwczovL2lwZC10ZXN0LnVuaXYtc3Qt\nZXRpZW5uZS5mci9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU71M58iX9SWskgRx3\niaqLJvvFm+swDQYJKoZIhvcNAQEFBQADggEBAKcebag8459paefinfIIkTj5eZPx\n7PMt8G3Qn2wdSOCdUqi+wB/ouR9R005RJe2MEZgixUNc2umwTZuO3MR5Rc4+TjyI\nXzRKyPJ2OmxEL3ly8pKUd0a3fXJZTOikICLLYezOdV2V/QLheIvMfZlhZ1uUhVGB\n0uoJRHu/zdhfGClj4eYML47y5EanadjY3nQ91GcDYxFeEFIGtcy+xp+CbEeFeqEH\nJ/tcRGvcPSvO9TGVGz+0YVsDmcGrfiHcokztEZ6Z7ADLep/iXMTpS331wYizQ7Oc\nI5j1CmAlzfvcYGPy6fOMCjINmd75Sez4RvGbVAQE/tRIM+6ButzQ6Lymrk4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Saint-Etienne - Jean Monnet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-st-etienne.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Saint-Etienne - Jean Monnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dlib-brewdog.ucs.ed.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Stuart"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alex.stuart@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Stuart"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alex.stuart@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dlib-brewdog.ucs.ed.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-01-31T14:00:45Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTzCCAjegAwIBAgIUZZAevsduZb+ksg12hWJz0it6obcwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJDEiMCAGA1UEAxMZZGxpYi1icmV3ZG9nLnVjcy5lZC5hYy51azAeFw0xNTEx\n\t\t\t\t\t\tMjUxMzUyNTdaFw0zNTExMjUxMzUyNTdaMCQxIjAgBgNVBAMTGWRsaWItYnJld2Rv\n\t\t\t\t\t\tZy51Y3MuZWQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCT\n\t\t\t\t\t\tlxvyZDrQk4NmB/8eCqgu+4rOJp6JW7bPXMkmmnibVbGDuGzyeD66GKuN/p4ev/nS\n\t\t\t\t\t\tXz9uUgX/5Z/30hNEANLIMFRW2Ds3zytISLnZ9plSOWJ456CEb1ne84H7B9N/VAHB\n\t\t\t\t\t\t/eM+7zbNnzL4BhkYC64Zu2KzJvZzdsCe6mEUr6is6imn82YLyy3jzKWyuEsTxesN\n\t\t\t\t\t\t3XZqdPfehjy39jcgkG8DQJGgwqCxP4hyLhMCjo6lgZ7GO08wdTMHEkjP9Wf/WXPw\n\t\t\t\t\t\tTP/VN3DBZmgHQ9XgCa45WYxab93+HnL258UscDOwYBeOuXLWnlNT2wfWqFU0lUD3\n\t\t\t\t\t\t+2WH/tE3wjkCejiAXeaPAgMBAAGjeTB3MFYGA1UdEQRPME2CGWRsaWItYnJld2Rv\n\t\t\t\t\t\tZy51Y3MuZWQuYWMudWuGMGh0dHBzOi8vZGxpYi1icmV3ZG9nLnVjcy5lZC5hYy51\n\t\t\t\t\t\tay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUHlvSVqIZuSLPEnkuljdJiy7YlzEw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAGV7em8jposBaytzgw3CYyCSLmAOkqaVMrUFVyQ1\n\t\t\t\t\t\tKPA84EAS+K7/7d4hg1VMO3KQVB6oTUfzoMmz1AagDU8qeZbaD3zN/dPS1aNnEfPg\n\t\t\t\t\t\tjizWl9pQeeiIYiLyVOY2+T2FYX+Kzf4w2tlIpM+1C2znVVJQcPTIIIwc3gQFgV3F\n\t\t\t\t\t\t5MLKXUMlpo3O4npIUXzR61O8EfjScnIaE/D3+rjbNStxfMebuyUi9G5THXZOOrbd\n\t\t\t\t\t\tAPu5rR/r9x/dJ3F3YTXGx2Mw3NfYYX7XP3UxvKKSCwCb5aQ/kEIJjE9hUIEIEdma\n\t\t\t\t\t\toobJ79OhVG+IPVW5qutgYavQ5qKeSCCa5Pe6/7Yww8L9Lks="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brewdog.edina.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://dlib-brewdog.ucs.ed.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-brewdog.ucs.ed.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://dlib-brewdog.ucs.ed.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dlib-brewdog.ucs.ed.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dlib-brewdog.ucs.ed.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dlib-brewdog.ucs.ed.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://dlib-brewdog.ucs.ed.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-brewdog.ucs.ed.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brewdog.edina.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://dlib-brewdog.ucs.ed.ac.uk/idp/images/brewdog.28x28.png",
                    "height": "28",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "28"
                  },
                  {
                    "text": "https://dlib-brewdog.ucs.ed.ac.uk/idp/images/brewdog.128x128.png",
                    "height": "128",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "128"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "dlib-brewdog test IdP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTzCCAjegAwIBAgIUZZAevsduZb+ksg12hWJz0it6obcwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJDEiMCAGA1UEAxMZZGxpYi1icmV3ZG9nLnVjcy5lZC5hYy51azAeFw0xNTEx\n\t\t\t\t\t\tMjUxMzUyNTdaFw0zNTExMjUxMzUyNTdaMCQxIjAgBgNVBAMTGWRsaWItYnJld2Rv\n\t\t\t\t\t\tZy51Y3MuZWQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCT\n\t\t\t\t\t\tlxvyZDrQk4NmB/8eCqgu+4rOJp6JW7bPXMkmmnibVbGDuGzyeD66GKuN/p4ev/nS\n\t\t\t\t\t\tXz9uUgX/5Z/30hNEANLIMFRW2Ds3zytISLnZ9plSOWJ456CEb1ne84H7B9N/VAHB\n\t\t\t\t\t\t/eM+7zbNnzL4BhkYC64Zu2KzJvZzdsCe6mEUr6is6imn82YLyy3jzKWyuEsTxesN\n\t\t\t\t\t\t3XZqdPfehjy39jcgkG8DQJGgwqCxP4hyLhMCjo6lgZ7GO08wdTMHEkjP9Wf/WXPw\n\t\t\t\t\t\tTP/VN3DBZmgHQ9XgCa45WYxab93+HnL258UscDOwYBeOuXLWnlNT2wfWqFU0lUD3\n\t\t\t\t\t\t+2WH/tE3wjkCejiAXeaPAgMBAAGjeTB3MFYGA1UdEQRPME2CGWRsaWItYnJld2Rv\n\t\t\t\t\t\tZy51Y3MuZWQuYWMudWuGMGh0dHBzOi8vZGxpYi1icmV3ZG9nLnVjcy5lZC5hYy51\n\t\t\t\t\t\tay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUHlvSVqIZuSLPEnkuljdJiy7YlzEw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAGV7em8jposBaytzgw3CYyCSLmAOkqaVMrUFVyQ1\n\t\t\t\t\t\tKPA84EAS+K7/7d4hg1VMO3KQVB6oTUfzoMmz1AagDU8qeZbaD3zN/dPS1aNnEfPg\n\t\t\t\t\t\tjizWl9pQeeiIYiLyVOY2+T2FYX+Kzf4w2tlIpM+1C2znVVJQcPTIIIwc3gQFgV3F\n\t\t\t\t\t\t5MLKXUMlpo3O4npIUXzR61O8EfjScnIaE/D3+rjbNStxfMebuyUi9G5THXZOOrbd\n\t\t\t\t\t\tAPu5rR/r9x/dJ3F3YTXGx2Mw3NfYYX7XP3UxvKKSCwCb5aQ/kEIJjE9hUIEIEdma\n\t\t\t\t\t\toobJ79OhVG+IPVW5qutgYavQ5qKeSCCa5Pe6/7Yww8L9Lks="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "dlib-brewdog test IdP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ucs.cirqahosting.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Orchard"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lee@isoxford.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lee"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@isoxford.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Oxford Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Salvesen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:david@isoxford.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@isoxford.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Oxford Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ucs.cirqahosting.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-01-29T11:03:25Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University Campus Suffolk Heritage Online"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.isoxford.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IS Oxford Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ucs.cirqahosting.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ucs.cirqahosting.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ucs.cirqahosting.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ucs.cirqahosting.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ucs.cirqahosting.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ucs.cirqahosting.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHjCCAgagAwIBAgIJAJgpdfh1+YmvMA0GCSqGSIb3DQEBBQUAMCgxJjAkBgNV\n\t\t\t\t\t\tBAMTHWNhbXN1Zi5pc294Zm9yZC1ob3N0aW5nLmxvY2FsMB4XDTE1MDEyNjIyNDIy\n\t\t\t\t\t\tOVoXDTI1MDEyMzIyNDIyOVowKDEmMCQGA1UEAxMdY2Ftc3VmLmlzb3hmb3JkLWhv\n\t\t\t\t\t\tc3RpbmcubG9jYWwwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDZ5jC5\n\t\t\t\t\t\tHNdlXT+XHl10MnAnG/1HHiqEUCEHPZlNP/4vgEZcS1odaZwnbgzb6p9uZZIvG/15\n\t\t\t\t\t\t1ZichCYob2AOUOYVKn6tcafdQYxEDSqnmBuuH/6NMDZqVCQAvCDkt9Tm2E+hBfzz\n\t\t\t\t\t\txCW0Bgl0EYY5ttzz8cI4EmNdvmjwDMksvNFxXvDwsoGeawPegCSfgYyW2cfrbDlL\n\t\t\t\t\t\trgcWjuO3+5e0HXW/k982iElL8yb5fXyTHBj+RBvjUVxTdCuFeLEiQwDgSEJwQNNx\n\t\t\t\t\t\tiMMcO67dRbaydylxFk9+GvVkRd3JFGO+UJxn5ZyN2dSbuP2bbLpdYEiWqhuxNSNb\n\t\t\t\t\t\tbVg2H694UeApZWQBAgMBAAGjSzBJMCgGA1UdEQQhMB+CHWNhbXN1Zi5pc294Zm9y\n\t\t\t\t\t\tZC1ob3N0aW5nLmxvY2FsMB0GA1UdDgQWBBTRQN1mn2+jFE6f5U1fyWVWhLhxYzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEALb+vfdXhr5lXgudzXI+Fhnp1lGmHCdrVdut8E/pw\n\t\t\t\t\t\tQrRqVxEZ1T4rVoHLcVG3jsKb7voknZMfTriayogl2b7F95nV0dfL6+7e13tsB0DE\n\t\t\t\t\t\tCRuo3jPUm3lvdxkacsgC9SNSJASa3lo5lsq7rUpvfCsF4lxjyE5gkYLuYWIpjC2L\n\t\t\t\t\t\tzfyCpYrSVsQpFGe4NcdkEGIxfMIN3/odMgwzWR5LxU3/UFjIb/smfYYJcpEgDA8z\n\t\t\t\t\t\tflxTIg3hb5c3mlLYpLTboH9Nd5xwUba9OuWaS0mNfYBc5jjzHv3wc17LUR3+3c0y\n\t\t\t\t\t\tPKzomY9nI7c5Kk93SmbYuuBY76D/kZE+baaoDSELEYNXtA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ucs.cirqahosting.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ucs.cirqahosting.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ucs.cirqahosting.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ucs.cirqahosting.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ucs.cirqahosting.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ucs.cirqahosting.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.its.utexas.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@utlists.utexas.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "U.T. Austin Shibboleth Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@utlists.utexas.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "U.T. Austin Shibboleth Team"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@utlists.utexas.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "U.T. Austin Shibboleth Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.its.utexas.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.its.utexas.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.its.utexas.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAKPStYoZAbTw2rzx/dJ9wcFl/s2ZMA0GCSqGSIb3DQEB\nBQUAMB0xGzAZBgNVBAMTEmlkcC5pdHMudXRleGFzLmVkdTAeFw0xNDA0MTYxMjA1\nMThaFw0zNDA0MTYxMjA1MThaMB0xGzAZBgNVBAMTEmlkcC5pdHMudXRleGFzLmVk\ndTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKbHfWtWfUKtVpY5WTie\n4JNr+K4oqXWgEDMzNTY3eRQt5NzkJ9aW6XNMwGCXDjREoFJYvj1NddqHTMu5Ka/c\n/IWPBQ6wk/yOJiqn5pc7r3gxeab8waUXQ7b5lu0gv5OLUUP/FeYfQlYaegFCFkte\nRKq1JzWBKAFmsc4Sp90/R2n4C2cMASAxUQ+HrnCOhebbEBokk9mlo8K+zdxpwKsG\nFuL8SC8VbUtRWDj+l/Z9JiUvvGqLbED8iIrHWl2zGP7omJt2AsRM4YsSHKE0e6w8\nHp0qRvxGo4e+BW2Ws1KI7NCRKtjPmMGxLt62j4W6Dx9VjcorpRgoqz+qZjOJnxmS\nve8CAwEAAaNrMGkwSAYDVR0RBEEwP4ISaWRwLml0cy51dGV4YXMuZWR1hilodHRw\nczovL2lkcC5pdHMudXRleGFzLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\ncKXw6nHvAlzIGDoqsK23wic7dr8wDQYJKoZIhvcNAQEFBQADggEBAHn5gSpEAA5z\nBictD4hXayvmjf47zsh6FnsnJ9+B6+K/mEI5eR3+gjnrnwl68rgj9VHxI53xg1Nl\n6z2r3lqOJ7dwvV1SUis9NH0euSnJdQnCpPaxWu4s06QAaM2zZOHnux3Csug4eHrs\nSi3ZsZwCjhY3ivtdtEHGFYV9fRi2udTfcEcF1fBZsON+5c29W1PmsThYOtF5aldN\ncINu0ZcgPH9q4l8yWDrzRECYbhqEUJdhiOaTlPDMh6/lK/QIttKxhqH+Nx0z3N6F\nVZWH/+OpywKUCeg5c5S6/oGEzmcGSJHH27DJdGPoLefO8/gscFtanxC3aOp6O1Zl\nwy0ZZr9AXLI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utexas.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.its.utexas.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.its.utexas.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.its.utexas.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.its.utexas.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.its.utexas.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.its.utexas.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utexas.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.utexas.edu/its/help/shibboleth"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Texas at Austin"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Logon service for The University of Texas at Austin"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.utexas.edu/includes/core/images/wordmark-stacked-2012.png",
                    "lang": "en",
                    "height": "150",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "344"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.utexas.edu/cio/policies/web-privacy/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAKPStYoZAbTw2rzx/dJ9wcFl/s2ZMA0GCSqGSIb3DQEB\nBQUAMB0xGzAZBgNVBAMTEmlkcC5pdHMudXRleGFzLmVkdTAeFw0xNDA0MTYxMjA1\nMThaFw0zNDA0MTYxMjA1MThaMB0xGzAZBgNVBAMTEmlkcC5pdHMudXRleGFzLmVk\ndTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKbHfWtWfUKtVpY5WTie\n4JNr+K4oqXWgEDMzNTY3eRQt5NzkJ9aW6XNMwGCXDjREoFJYvj1NddqHTMu5Ka/c\n/IWPBQ6wk/yOJiqn5pc7r3gxeab8waUXQ7b5lu0gv5OLUUP/FeYfQlYaegFCFkte\nRKq1JzWBKAFmsc4Sp90/R2n4C2cMASAxUQ+HrnCOhebbEBokk9mlo8K+zdxpwKsG\nFuL8SC8VbUtRWDj+l/Z9JiUvvGqLbED8iIrHWl2zGP7omJt2AsRM4YsSHKE0e6w8\nHp0qRvxGo4e+BW2Ws1KI7NCRKtjPmMGxLt62j4W6Dx9VjcorpRgoqz+qZjOJnxmS\nve8CAwEAAaNrMGkwSAYDVR0RBEEwP4ISaWRwLml0cy51dGV4YXMuZWR1hilodHRw\nczovL2lkcC5pdHMudXRleGFzLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\ncKXw6nHvAlzIGDoqsK23wic7dr8wDQYJKoZIhvcNAQEFBQADggEBAHn5gSpEAA5z\nBictD4hXayvmjf47zsh6FnsnJ9+B6+K/mEI5eR3+gjnrnwl68rgj9VHxI53xg1Nl\n6z2r3lqOJ7dwvV1SUis9NH0euSnJdQnCpPaxWu4s06QAaM2zZOHnux3Csug4eHrs\nSi3ZsZwCjhY3ivtdtEHGFYV9fRi2udTfcEcF1fBZsON+5c29W1PmsThYOtF5aldN\ncINu0ZcgPH9q4l8yWDrzRECYbhqEUJdhiOaTlPDMh6/lK/QIttKxhqH+Nx0z3N6F\nVZWH/+OpywKUCeg5c5S6/oGEzmcGSJHH27DJdGPoLefO8/gscFtanxC3aOp6O1Zl\nwy0ZZr9AXLI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "http://www.utexas.edu/its/helpdesk/"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Texas at Austin"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utexas.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Texas at Austin"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.nelson.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.nelson.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/nelson.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/nelson.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nelson.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Nelson College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nelson.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.cnwl.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Overt Software"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Overt Software"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cnwl.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-02-22T16:13:14Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUEJciO46aX1zd30VubLZW8mTbPWcwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGTEXMBUGA1UEAxMOaWRwLmNud2wuYWMudWswHhcNMTMwMjIyMTM0MTQ2WhcN\n\t\t\t\t\t\tMzMwMjIyMTM0MTQ2WjAZMRcwFQYDVQQDEw5pZHAuY253bC5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKw5eKNDVnIjYE4C57t/K2+u+4c/tirp\n\t\t\t\t\t\trk9ozEGO0JCSnCq+GcxJm5Mfxs5sM6u919g7BOZZU5zm5sykEvhM1YonMcjzcBsd\n\t\t\t\t\t\tEHVs78c9Nlv6ZueO5923ArCYybTPTpqZWr9px0XdltBkLafFOWPUt3mUVUglv6X6\n\t\t\t\t\t\tesMQaiDPAbrG+Nvdo0ZbnlA5tBy7WMNEk6SyB0VhxIN3KDWsTi39tRpNVaroO+VG\n\t\t\t\t\t\tpdrC31S4g5aropb/27kOTIltrxVokJDLHjo0PMO2o2eKLZvtgYRnL8/XTTXexZyy\n\t\t\t\t\t\tU85U3G5zPw2jptUHHx1W9Ojs/9rUsp61znAJEXfgMS5iQLl2JwA9EsUCAwEAAaNj\n\t\t\t\t\t\tMGEwQAYDVR0RBDkwN4IOaWRwLmNud2wuYWMudWuGJWh0dHBzOi8vaWRwLmNud2wu\n\t\t\t\t\t\tYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFBWW2Q/zTBI5/JWM/SHx/Kg2\n\t\t\t\t\t\tYRleMA0GCSqGSIb3DQEBBQUAA4IBAQAFcWzf6iOnJGNSlIOCJjj6aOoM3wNqLZ7s\n\t\t\t\t\t\tWAtBhxVb+w2vs5w2mTrgpj24wbfpyQVhCrQjUFLdVmOqyUlpF9A/kJOgUYuq5JZa\n\t\t\t\t\t\tGeJy1cwl1CdVtzsZ7UZPz6ToC97uVuhKiVevPoAmaJ+zDiFdVPBiTmkOz7nMZnCt\n\t\t\t\t\t\t5PqDYeRNAlFDTx0nQ1WjaPuwWBhdii3EaHLQWrFPN6dfoxX6YPtboQKZk9b3/r7N\n\t\t\t\t\t\tWzPw4pujvskfh9Hw6/3ghnooiV9ZYq3SrpCB8m+xj78CoSz6FPXKvFoQGEKPbOQn\n\t\t\t\t\t\t8Ava86ENk3hQjKbGmaS8RNl6EtCrQNiAaBNYx1xlAoP3IZ+nO1h9"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cnwl.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cnwl.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cnwl.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.cnwl.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cnwl.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.cnwl.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cnwl.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cnwl.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cnwl.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cnwl.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUEJciO46aX1zd30VubLZW8mTbPWcwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGTEXMBUGA1UEAxMOaWRwLmNud2wuYWMudWswHhcNMTMwMjIyMTM0MTQ2WhcN\n\t\t\t\t\t\tMzMwMjIyMTM0MTQ2WjAZMRcwFQYDVQQDEw5pZHAuY253bC5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKw5eKNDVnIjYE4C57t/K2+u+4c/tirp\n\t\t\t\t\t\trk9ozEGO0JCSnCq+GcxJm5Mfxs5sM6u919g7BOZZU5zm5sykEvhM1YonMcjzcBsd\n\t\t\t\t\t\tEHVs78c9Nlv6ZueO5923ArCYybTPTpqZWr9px0XdltBkLafFOWPUt3mUVUglv6X6\n\t\t\t\t\t\tesMQaiDPAbrG+Nvdo0ZbnlA5tBy7WMNEk6SyB0VhxIN3KDWsTi39tRpNVaroO+VG\n\t\t\t\t\t\tpdrC31S4g5aropb/27kOTIltrxVokJDLHjo0PMO2o2eKLZvtgYRnL8/XTTXexZyy\n\t\t\t\t\t\tU85U3G5zPw2jptUHHx1W9Ojs/9rUsp61znAJEXfgMS5iQLl2JwA9EsUCAwEAAaNj\n\t\t\t\t\t\tMGEwQAYDVR0RBDkwN4IOaWRwLmNud2wuYWMudWuGJWh0dHBzOi8vaWRwLmNud2wu\n\t\t\t\t\t\tYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFBWW2Q/zTBI5/JWM/SHx/Kg2\n\t\t\t\t\t\tYRleMA0GCSqGSIb3DQEBBQUAA4IBAQAFcWzf6iOnJGNSlIOCJjj6aOoM3wNqLZ7s\n\t\t\t\t\t\tWAtBhxVb+w2vs5w2mTrgpj24wbfpyQVhCrQjUFLdVmOqyUlpF9A/kJOgUYuq5JZa\n\t\t\t\t\t\tGeJy1cwl1CdVtzsZ7UZPz6ToC97uVuhKiVevPoAmaJ+zDiFdVPBiTmkOz7nMZnCt\n\t\t\t\t\t\t5PqDYeRNAlFDTx0nQ1WjaPuwWBhdii3EaHLQWrFPN6dfoxX6YPtboQKZk9b3/r7N\n\t\t\t\t\t\tWzPw4pujvskfh9Hw6/3ghnooiV9ZYq3SrpCB8m+xj78CoSz6FPXKvFoQGEKPbOQn\n\t\t\t\t\t\t8Ava86ENk3hQjKbGmaS8RNl6EtCrQNiAaBNYx1xlAoP3IZ+nO1h9"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "College North West London"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cnwl.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "College of North West London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ait.ie/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Donohue"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:colindonohue@ait.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "COlin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hallissy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ihallissy@ait.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Coleman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rcoleman@ait.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rossa"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ait.ie/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2011-01-20T00:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ait.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ait.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ait.ie/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ait.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ait.ie/informationforcurrentstudents/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/ait.png",
                    "lang": "en",
                    "height": "73",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "211"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "lang": "en",
                    "height": "73",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "211"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Athlone Institute of Technology"
                  },
                  {
                    "lang": "ga",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Instit\u00faid Teicneola\u00edochta Bhaile \u00c1tha Luain"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.4108177,-7.8923645"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAKw7msQ/Rhb4chwEi3azizevjePPMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC5haXQuaWUwHhcNMTEwMzIxMTUyMjUyWhcNMzEw\nMzIxMTUyMjUyWjAVMRMwEQYDVQQDEwppZHAuYWl0LmllMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAn2HDYEWizKKegiu4xpCgnEqZ9NEa9UV2Yau/py7b\nnNyxI9Y4xyihPx7CqGZEsBdk4buJpVhwMiNk4p0BXtgpUV937E4fsKl1XyHSnFAa\nXQyx6Fw+UtA1/Y74k+WHJ3aOReSL4Jr5PC8NFi//XgaV/uKiXXk7jkwKMrngBZk/\ny+DHZHNPuw3XSED7e6/v+EKWqQ8jpr2GvU+S1+IqVApZ/32XqdidXwJUAc2v1Sw8\nyLrWWtAnYOjSOr0fw9jPGtpJRsCnHa44pDL7zOoS6o3S9+GQxUO0Eqoe9ySq+UEE\nrSxAhaBqQmHODeoeyzGmIF1Y7/JWfOu0PXkgcunGUKQaLQIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAuYWl0LmllhiFodHRwczovL2lkcC5haXQuaWUvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFL/kQjcyF+wSC4KxLfM1LwK9gzp4MA0GCSqGSIb3DQEB\nBQUAA4IBAQCVn5uKkeelZcbCFenjwTSlcv/Ej8IPF3CqN25Eeva1C4PUdwWyo/NS\nmgvDgICYJDo70kxvK5/SBkBlFtlAQ8BVIhRWZIWEXR1z3UJpuUsxKXmN3ESTLI+d\nqJdIBfPThCK9QJgj1/RA/ZAnSMRR/ZWP3Ys/Gse+KhkPKx0Lj6RTO/R32KXPBM+V\nxSS9WVQ7qm9/LoId9C1bBTSgSoE/3190gEO1Rox09dNKh2qZBlxqzg9VWaGodw1+\nS9AlbrF9+Pfu2lmvqmVUw6OQW0Usf6ANTb0pXim274/efX34EVz63en/hFbP97eQ\nGe5BNlqT3Xh9wwnHhhgTKZivKII/N7hZ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Athlone Institute of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ait.ie/informationforcurrentstudents/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Athlone Institute of Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://naming.ja.net/dns-test/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:naming@ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "JANET NAMING"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:naming@ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "JANET NAMING"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://naming.ja.net/dns-test/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-12-16T16:13:54Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Janet Naming Service (test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ja.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "JISC Collections and Janet Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://naming-test.ja.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://naming-test.ja.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://naming-test.ja.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://naming-test.ja.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://naming-test.ja.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "JISC Domain Registration Service"
                  }
                ],
                "logo": [
                  {
                    "text": "https://domainregistry-test.jisc.ac.uk/dns-test/Images/federation-sp-logo.png",
                    "height": "72",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "JISC Domain Registration Service"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://naming-test.ja.net/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://naming-test.ja.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://domainregistry-test.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://naming-test.ja.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://domainregistry-test.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4jCCAcqgAwIBAgIJAKyF+vahRReuMA0GCSqGSIb3DQEBBQUAMBQxEjAQBgNV\n\t\t\t\t\t\tBAMTCWhhcjAwMzkxODAeFw0wOTExMjAwODM4MTVaFw0xOTExMTgwODM4MTVaMBQx\n\t\t\t\t\t\tEjAQBgNVBAMTCWhhcjAwMzkxODCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAKyGnAXQpTnriKaVLhBxB2V01KEV7JFljb6JyCUgmPzhjozQV78Lt6wnrlVE\n\t\t\t\t\t\tPMJUFzx6MhVOOFdmoud9f4uEt3eLeNNBkXy6F1hLsK93MmEq7NycC9f+RTGkXuI9\n\t\t\t\t\t\tZZ6bHpCQg4cgLlo+e+oSmyFrqdwHkKXRxhx7sLDpmrBRt4WS1Yom/sf1roaj/HYJ\n\t\t\t\t\t\tI09jwKfl5mlFhWqHoprT6zHYZ/q4HIgo8CYFzRPTBYP2WoakD87P3UPpVZj6uLAz\n\t\t\t\t\t\td8LCuv1ZX2HJTHYrUyEM4tbqA2cv/CN8W6cgTkm5puZAMvPmFeNnoQlkBnUpH/oc\n\t\t\t\t\t\toGDmT026FyBGQ6yXva1uZVOX0xMCAwEAAaM3MDUwFAYDVR0RBA0wC4IJaGFyMDAz\n\t\t\t\t\t\tOTE4MB0GA1UdDgQWBBQST9Pog/haMAhYi8W9rY0cKz3XfjANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAERDcKAB+oNKMF14ys3MjR7NgPZzAnxNjyDizDMsPug9ZqfXKTfU1NFZx\n\t\t\t\t\t\tnx1ihIXHOBZgLU4RKLJSopHZ57V+HlOebXCckx/je1y4a30B0sIg3yk9ZZlMNcVI\n\t\t\t\t\t\tJWEIEGc6kkIhgQBMAtTaae+Yd1gqk4MQBQG08iDy9M3E4jp3BmgZbJL2lBYwCoRc\n\t\t\t\t\t\tU2soIdQNoQS5WDuqwDVXqOljUfijVZU9YRpjPDsXqDQDVO+7v/EbPxVtRThQChxY\n\t\t\t\t\t\tLwXeoQe6wBNtmeBEdm16Ik+PCxkgQlTCLythjkwmB+AjmqoW6Kp9bNfh7/Tlv/lM\n\t\t\t\t\t\tbYW9q2/JzwJW2LhAXTV1ev8D9e3peg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://naming-test.ja.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://naming-test.ja.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://naming-test.ja.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://naming-test.ja.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://domainregistry-test.jisc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://domainregistry-test.jisc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://domainregistry-test.jisc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://domainregistry-test.jisc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://domainregistry-test.jisc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://domainregistry-test.jisc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://naming-test.ja.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://naming-test.ja.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://naming-test.ja.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://naming-test.ja.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://naming-test.ja.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://naming-test.ja.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://devsso.educause.edu/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ITHelpdesk@educause.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "achaux@educause.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex Chaux"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ITinfo@educause.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Administrative Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://devsso.educause.edu/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EDUCAUSE"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.educause.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "EDUCAUSE"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.educause.edu/about/incommon"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EDUCAUSE DEVSSO"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "EDUCAUSE development environment for Single Sign On supporting InCommon.  EDUCAUSE is a nonprofit association and the foremost community of IT leaders and professionals committed to advancing higher education.  This service provides access to collaborative and informative services for faculty and staff if the form of curated content, publications, IT benchmarking data and research, list servers, blogs, wikis, and events."
                  }
                ],
                "logo": [
                  {
                    "text": "https://devsso.educause.edu/assets/images/logo.png",
                    "lang": "en",
                    "height": "42",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "188"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.educause.edu/privacy-policy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+jCCAeKgAwIBAgIGAVKap2yFMA0GCSqGSIb3DQEBCwUAMD4xCzAJBgNVBAYTAlVTMREwDwYD\nVQQKEwhlZHVjYXVzZTEcMBoGA1UEAxMTc3NvLWRzLmVkdWNhdXNlLmVkdTAeFw0xNjAyMDEwMjI2\nNDlaFw0xODAxMzEwMjI2NDlaMD4xCzAJBgNVBAYTAlVTMREwDwYDVQQKEwhlZHVjYXVzZTEcMBoG\nA1UEAxMTc3NvLWRzLmVkdWNhdXNlLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAMiYhZkpBh5pZ5bJs+LbqWN4DRNOwqq2mfNl6jJHlvBiv5cUnCVMdVdE+wCF5ZDaY0dolYeln3Xz\n7jQBEfgfxgP4LJgSgd4nuwAYpR3Bz6V4wVWodlwHgzPXOBoPymt40NV8wWi+7lANu2KJVyvAV+ln\n2ikGKjJF8LX8y+jgEx43CDfHHtFTqnG831ayXEVMiodDzIwGV4+eBLJSnpK0x7f6PD5imIJzzqgY\nvvkYuLIIMhyaw2CJ793JIQO4ZcCkZIHmuEaQOuFkZTp/J/v4JAOBRacTyW4Y+05hJLXPc94aW07O\nPfG5l7py3P0DZ+vlc3azboo2RHPeChG75fQOEekCAwEAATANBgkqhkiG9w0BAQsFAAOCAQEAFQ1E\nLRbfn5jeGhbruKZMv4+ieFnn1AeDGKwy7QfX3KcDHjNCA1P2JTVQWIkqFrQvxCiLYHKEg91Rt6qH\nVTuYygTmNKRCr9AQZQfpl1PAfAm8yCyIagCS6Y4b4qhGYLhbh7WB2yN8mRJihC2S1I6YRwjmccy3\nwIYcfJLdh1HhzGUEwzLOEyjWJmZBKq3PLRD+8ikpL0FXry9i4Jp0OE5UrnvNRn77WAtXAQEu7hsO\nNdqWxNaWjSX5B9mtseJPAPCRU1LJjqMO8LSVbe3HlfKqqZ0pcRwqWFobiKuDe6UeG4AZy+iI3hH1\nDjG7U+yjWFViwzT+zlX+3ZOrtEj4J1/vLw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://devsso.educause.edu/sp/ACS.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "EDUCAUSE DEVSSO"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "EDUCAUSE development environment for Single Sign On supporting InCommon.  EDUCAUSE is a nonprofit association and the foremost community of IT leaders and professionals committed to advancing higher education.  This service provides access to collaborative and informative services for faculty and staff if the form of curated content, publications, IT benchmarking data and research, list servers, blogs, wikis, and events."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.hallamstudentsunion.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.hallamstudentsunion.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-07-25T14:09:20Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Sheffield Hallam Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hallamstudentsunion.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.hallamstudentsunion.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.hallamstudentsunion.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.hallamstudentsunion.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.hallamstudentsunion.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.hallamstudentsunion.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.hallamstudentsunion.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.hallamstudentsunion.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.hallamstudentsunion.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.hallamstudentsunion.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.hallamstudentsunion.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.hallamstudentsunion.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.hallamstudentsunion.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.hallamstudentsunion.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-00.ladok.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-00.ladok.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-00.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-00.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-00.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-00.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-00.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-00.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-00.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;00"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;00"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-00.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-00.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJALaiCJSP55zsMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wMC5sYWRvay51bXUuc2UwHhcNMTQwOTI1MDk1NjA1WhcNMjQw\nOTIyMDk1NjA1WjAhMR8wHQYDVQQDExZsYWRvazMtMDAubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAv7pXel9V/9/sPCh3YGFGK09G\nL6Rc5jCccGNqjWKOr7bPuPfami/UltfcDmKR24ka5540N1F1vMoRa5Jy2SpSw+fl\naSTRZgI1i4CwVFEbblwirdS2VTnuv04VVnuXI46mW6p6Purr41z8d6W6fUo5Q0Ev\nN6KtTnl6EoIQoAMh8Fe5WuZOkggYtvaJAWWaVtYaqxw4duhhNHRbOmxVA6G7VfH5\nIPzt+C6W2F42QoOXcNQPnz7xkQHa22vxPk0rAiOI166YeA/ytUs7/svY7P3OnUus\ns7nUYGOPe9sa5Y11vVD95D42zSbewLFda0aSPSCr7FUkYdOUIZcWGDPJG/o5OQID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMDAubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0wMC5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUVikKoyndXo08xCDD2jx853IrnhcwDQYJKoZIhvcNAQEFBQADggEB\nAAdVurbu0mBd3/p5QBPuYP+pTOQ3ABr6yakpfVbSybGpaKfyf2MZlOHu2LMprbNv\ntvzzAXzrOj0C21pz1dnQEOFNRGtCg+bHdWpgP0NzJl+kwNyztSWoxGmpVziSPI3s\nz+Kc0rAVF4588jsHJ4JMqeEwaHSBrX5lEYFIa/V/aInyF1N69RCNffSwYajhpX0X\n5Q7G3gNErTdpY7VyESfIjKrDNoyNva5oBZBu/Q0OUPLRbgcir3TuauHwdjtzJVIY\nNsnYXbWq6x+lyyXytITJnpDmB0/1iWgykJDFXR6D/AzjVNW3/43F4DSbK+/JFuqX\nXtg7VBxaqt1Fm/Me7/+LxiQ="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-00.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-00.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-00.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-00.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-00.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-00.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-00.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-00.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-00.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-00.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-12.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-12.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-12.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-12.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-12.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-12.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-12.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-12.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-12.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;12"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;12"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-12.its.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-12.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLjCCAhagAwIBAgIJAPnC+peLfHVhMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0xMi5sYWRvay51bXUuc2UwHhcNMTQwMTI0MTM0OTU3WhcNMjQw\nMTIyMTM0OTU3WjAhMR8wHQYDVQQDExZsYWRvazMtMTIubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA6tsIiVZ360dMYzGUItQ2Qn8l\nExo/iteiejZ1rFePFuh1R6cJbvlteQPt/cGiFm1OGsNANgyeWg2zWfUNscXtOO5a\nDoEgvYIwmx86bl9T5FVqIfAwfRpdqjFasYBPrE4SZGg1cQ9vkXWI9HFL803qDdvO\nirAEMpxH+Rej0ba84/uzDLNE5jP0bWk5QRKjC5Q8p1Xb+VDIzwGXAeW2hkh84X6J\nhggcWx9GhfIHVjXOZJQHz6mX89KskWiMIAyf0b+9I/rN0xXXzp+HgtpzTyKOvNy9\ny6gcArtDwya1Nx67Vz2zWQtvhshT3cWGSyXZafckcWhOKa1K/Z1CJBCKlFBouQID\nAQABo2kwZzBGBgNVHREEPzA9ghZsYWRvazMtMTIubGFkb2sudW11LnNlhiNodHRw\nczovL2xhZG9rMy0xMi5pdHMudW11LnNlL2d1aS1zcDAdBgNVHQ4EFgQUTbevuoCn\nJQLYErC4b+Ppng9nv1IwDQYJKoZIhvcNAQEFBQADggEBAIgqICMEKpo42IILnM0a\nn5/vwO0IbvJt55xS/O2C3xMxE84CLHIDVT8MnT2Fb0pFCpXhOGKXqLwSgr0eNmKr\nBLncmhUslSoGCuUelCtCmMoqaGXxvDs4MEHq6ivYjXAr8gEunlIC9d2/wtt35s5S\njw+O2kgZ38R8TRWf7F0Bu6Q3+ukdC8e6lcCEY9SpfLdPQdBEg/rvnH2FridZoD9K\nMEraXUrzmKXaqNkD95DUxHeGB8gA9eacFfcuLKdHSxFQ57h3WekbNgtSgRpMeK4o\nsSWjeK+ZudD5JSHb+STFDRSWC7oyQNiQuddlj0hF5L7GnePnetK4TIQbcEHgNb9M\n9mE="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-12.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-12.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-12.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-12.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-12.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-12.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-12.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-12.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-12.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-12.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.sdsu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mjeffers@mail.sdsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marcus Jeffers"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mjeffers@mail.sdsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marcus Jeffers"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "etshelpdesk@mail.sdsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ETS Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.sdsu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sdsu.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sdsu.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAMWWto0I48RmvkuXkJ+lKemaw/hrMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDGlkcC5zZHN1LmVkdTAeFw0xMTA1MjAxODU0MTJaFw0z\nMTA1MjAxODU0MTJaMBcxFTATBgNVBAMTDGlkcC5zZHN1LmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAJbJtnmu55QH0hhGveJ4/H9uDPjkLYNYDi5Y\nlxwv0O0rtlaOQXCTqgtS2OF/uymX/o282lruA8XmZ11GEWpf65yopwCRrUpXkQes\nKYqKCv8ukyD3FLkfeCuMKGbCFgDVn4UgJXihKaqpbl4akgp538FNVvH0uKCgf1yH\n89wtugU4QdbglAgiRnxk6VLSg+YTOjfqfcWinTwRr5yIzxwdMnHfUXfSuJj6QhtO\nnWj9HiKKHSzMNioAhQPTitFV+pJLVz/3wHIchSDVdxYPYxDW4+t56Ca9mAEgojKY\ns3Hhb1flxnCB1WdhzWHlWvlLmxrx9qje36G61ZVEXhlF3nF6G6sCAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMaWRwLnNkc3UuZWR1hiNodHRwczovL2lkcC5zZHN1LmVkdS9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUUUOlgbFxNZPDpAJv1l1BSGZ0G60wDQYJ\nKoZIhvcNAQEFBQADggEBAGLeQcITD841MUUfBlRcreQtdvrecxcDvIpRU7zxPEi2\nbmhbhKEiLb5tcLb3UYCZUyYKS8aLGwmDXnfBbXSpuqSe+pun897ojH1/MRcikei7\nPsdo34PGlaVp5ZO6YsaB7myXkvVSCB9W+g36Ko2hb639dEo3jamHf3IO9iec3/T6\ngrlHPK6YpLkl/yFUyG674xclGFYbO5e1oSTo2RI8Prq5SFMm+ZTM8RpJE4S8N2KK\n/xmDUZex0G3l2kQXG453HGvKmtyfatFO0EQsKSXR7TDUA5DlKaTR7TTqJIoQK0th\nH0EQISNFETzOPvigNzdVOpw9ywvLIgC4MAevthLo5ek="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sdsu.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.sdsu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sdsu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sdsu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAMWWto0I48RmvkuXkJ+lKemaw/hrMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDGlkcC5zZHN1LmVkdTAeFw0xMTA1MjAxODU0MTJaFw0z\nMTA1MjAxODU0MTJaMBcxFTATBgNVBAMTDGlkcC5zZHN1LmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAJbJtnmu55QH0hhGveJ4/H9uDPjkLYNYDi5Y\nlxwv0O0rtlaOQXCTqgtS2OF/uymX/o282lruA8XmZ11GEWpf65yopwCRrUpXkQes\nKYqKCv8ukyD3FLkfeCuMKGbCFgDVn4UgJXihKaqpbl4akgp538FNVvH0uKCgf1yH\n89wtugU4QdbglAgiRnxk6VLSg+YTOjfqfcWinTwRr5yIzxwdMnHfUXfSuJj6QhtO\nnWj9HiKKHSzMNioAhQPTitFV+pJLVz/3wHIchSDVdxYPYxDW4+t56Ca9mAEgojKY\ns3Hhb1flxnCB1WdhzWHlWvlLmxrx9qje36G61ZVEXhlF3nF6G6sCAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMaWRwLnNkc3UuZWR1hiNodHRwczovL2lkcC5zZHN1LmVkdS9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUUUOlgbFxNZPDpAJv1l1BSGZ0G60wDQYJ\nKoZIhvcNAQEFBQADggEBAGLeQcITD841MUUfBlRcreQtdvrecxcDvIpRU7zxPEi2\nbmhbhKEiLb5tcLb3UYCZUyYKS8aLGwmDXnfBbXSpuqSe+pun897ojH1/MRcikei7\nPsdo34PGlaVp5ZO6YsaB7myXkvVSCB9W+g36Ko2hb639dEo3jamHf3IO9iec3/T6\ngrlHPK6YpLkl/yFUyG674xclGFYbO5e1oSTo2RI8Prq5SFMm+ZTM8RpJE4S8N2KK\n/xmDUZex0G3l2kQXG453HGvKmtyfatFO0EQsKSXR7TDUA5DlKaTR7TTqJIoQK0th\nH0EQISNFETzOPvigNzdVOpw9ywvLIgC4MAevthLo5ek="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sdsu.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://newscenter.sdsu.edu/brand/images/primary3color.gif",
                    "lang": "en",
                    "height": "162",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "235"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "San Diego State University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "San Diego State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sdsu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "San Diego State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.nejm.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.nejm.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-08-06T15:48:45Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Atypon Systems: New England Journal of Medicine"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nejm.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAIBpEkq6FhlUMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\n\t\t\t\t\t\tBAMTDHd3dy5uZWptLm9yZzAeFw0xMzA3MTAyMTA3MDJaFw0yMzA3MDgyMTA3MDJa\n\t\t\t\t\t\tMBcxFTATBgNVBAMTDHd3dy5uZWptLm9yZzCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBANK1qbc1ivsRyR7Lch3ED1VC9eB76M93xlw4cNo/dvOZIxKDXj08\n\t\t\t\t\t\tiKA0m6Ku3/iyiXHvCpVlwTgI4Ip/Xt6lFFWBpY4+jd+ava+E9+ANCWOQJf9G62qo\n\t\t\t\t\t\tbvaz8PQRxXKEck+rWLDnWja5GgXHzTiPZpdNeiN3HxbDXbqzZyiOBESwEeMXuMuB\n\t\t\t\t\t\tCOs+iDVh4BhrhL0hD9976og0YyFlpZNnN0wkHJuhCVdWgwscK4sheTM/Hl4FCxb6\n\t\t\t\t\t\tHogoNWsnURLZCIvd9QfHJ+K33LN3zUbjJFBcN4LjhE9mt13gwliiXDwNl0RdYxvB\n\t\t\t\t\t\tepOKacojBJlV2kJdhe3G9olGYgX1GDTEA3UCAwEAAaNbMFkwOAYDVR0RBDEwL4IM\n\t\t\t\t\t\td3d3Lm5lam0ub3Jnhh9odHRwczovL3d3dy5uZWptLm9yZy9zaGliYm9sZXRoMB0G\n\t\t\t\t\t\tA1UdDgQWBBTWPgvv+5CtphKIteQIzAPkFdbZ8jANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tA5NpngLVi9/1vHPrbLVhXwkrVlBfGvirUNgLlfp29pO2EXHhPcpyMZXRM9hkttGu\n\t\t\t\t\t\tlEJetzEXKVMaNyhoqnvnQ1JqCt4rFp/PV+MQO1ZPxJ4nPcXU3kdAJG3VuSu7jRRZ\n\t\t\t\t\t\tiyS7KYql93SEwfOyIuPB/lPnOQ3uHV94bRGgfYnTq8S1NAdEXp/rMWM4yWPF+8nq\n\t\t\t\t\t\tkBkgu74s1BfumuoQbNNatX/yAxy8kSiPLOWQpotcA1JR6qQ02PlphNp33+T6asTn\n\t\t\t\t\t\t3y2fAMI1ef+C1XDMkJBYSS/o9AiY5VF+TSmsgpN4Etlr2BCk2aOvfEsi0cQMuThu\n\t\t\t\t\t\tZN3XBFLXsiMX/MLD9bpLrA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.nejm.org/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.nejm.org/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.nejm.org/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://uk.practicallaw.com/cs/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Parker"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Christopher.Parker@thomsonreuters.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Christopher"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lukiwebops@thomsonreuters.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Web Operations Group"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wilson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alan.wilson@thomsonreuters.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lukiwebops@thomsonreuters.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Web Operations Group"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://uk.practicallaw.com/cs/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-07-07T09:24:06Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Practical Law"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://uk.practicallaw.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Thomson Reuters (Professional) UK Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://uk.practicallaw.com/cs/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://uk.practicallaw.com/cs/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uk.practicallaw.com/cs/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uk.practicallaw.com/cs/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://global.practicallaw.com/cs/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://global.practicallaw.com/cs/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://global.practicallaw.com/cs/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://global.practicallaw.com/cs/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            }
          ],
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6DCCAdCgAwIBAgIEU1pN/TANBgkqhkiG9w0BAQUFADA2MRYwFAYDVQQKEw1Q\n\t\t\t\t\t\tcmFjdGljYWwgTGF3MRwwGgYDVQQDExN1ay5wcmFjdGljYWxsYXcuY29tMB4XDTE0\n\t\t\t\t\t\tMDQyNTExNTg1M1oXDTI0MDQyMjExNTg1M1owNjEWMBQGA1UEChMNUHJhY3RpY2Fs\n\t\t\t\t\t\tIExhdzEcMBoGA1UEAxMTdWsucHJhY3RpY2FsbGF3LmNvbTCCASIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEBBQADggEPADCCAQoCggEBAJBGaaaJYyVzFc48ThFdkzUVkcPFQLgdZGSuQYPe\n\t\t\t\t\t\t6hps6CmWGKKxGF5Wra1PlYMrgxu8dOMtMgzBTGEySJnjm5SUUemHehN+xL9AyCs2\n\t\t\t\t\t\tUgHJooNsqdu6PbxVJMOhFuVCGhiIysSFA/xBinxRBgPcl+4aLIXdE8Lha2CWYxdd\n\t\t\t\t\t\t4BfeOtx7X92vqpmBmMI/68/7BZWiJAmmko1D+OgH/DupwmdkasFisVcdFzWUQEgp\n\t\t\t\t\t\tOY65dB7FxZpOY3zXrC7Af3OUxw9RnnlsgD2boRU48ddGBh4txXBU5Ft7RaGuRM+K\n\t\t\t\t\t\tBfh24nSjIXd1YDOjhTOPnD5Ty6/lO+tT+4Zlsww85LQKEwcCAwEAATANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAGlqkedupw+BYF0ae7nLgesJ2VBdGTabqg+vB/G16ZAGKeBoj\n\t\t\t\t\t\tvmd0w4Aii9sNnyb6BIQvXnlqvi7sNRXcBovlaQARTpTcCm9jHqWPvZzK9hxdm2/o\n\t\t\t\t\t\tkbHBKjHnTL7YBxPwMfHkaOmQhx2tTPgGhOK34eUzhXlLSPYrtGcde/pCFsyuhCUT\n\t\t\t\t\t\tNJ0vqLTB/w2YDJ0jC7xTCx+X6N+NulCteQosnKxtZ/blaHMwwX+j96LGHPtpOmN7\n\t\t\t\t\t\tf1v1bBVmrjy6E1aWTdH7G4cEhMIyfPeZRZvuThhKDGjBVRy1EjI+FSxWPxM1WnsD\n\t\t\t\t\t\ty8wft8UJXsBOJlHjpkjdcaR+DS88edmhvJNRbQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6DCCAdCgAwIBAgIEU1pN/TANBgkqhkiG9w0BAQUFADA2MRYwFAYDVQQKEw1Q\n\t\t\t\t\t\tcmFjdGljYWwgTGF3MRwwGgYDVQQDExN1ay5wcmFjdGljYWxsYXcuY29tMB4XDTE0\n\t\t\t\t\t\tMDQyNTExNTg1M1oXDTI0MDQyMjExNTg1M1owNjEWMBQGA1UEChMNUHJhY3RpY2Fs\n\t\t\t\t\t\tIExhdzEcMBoGA1UEAxMTdWsucHJhY3RpY2FsbGF3LmNvbTCCASIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEBBQADggEPADCCAQoCggEBAJBGaaaJYyVzFc48ThFdkzUVkcPFQLgdZGSuQYPe\n\t\t\t\t\t\t6hps6CmWGKKxGF5Wra1PlYMrgxu8dOMtMgzBTGEySJnjm5SUUemHehN+xL9AyCs2\n\t\t\t\t\t\tUgHJooNsqdu6PbxVJMOhFuVCGhiIysSFA/xBinxRBgPcl+4aLIXdE8Lha2CWYxdd\n\t\t\t\t\t\t4BfeOtx7X92vqpmBmMI/68/7BZWiJAmmko1D+OgH/DupwmdkasFisVcdFzWUQEgp\n\t\t\t\t\t\tOY65dB7FxZpOY3zXrC7Af3OUxw9RnnlsgD2boRU48ddGBh4txXBU5Ft7RaGuRM+K\n\t\t\t\t\t\tBfh24nSjIXd1YDOjhTOPnD5Ty6/lO+tT+4Zlsww85LQKEwcCAwEAATANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAGlqkedupw+BYF0ae7nLgesJ2VBdGTabqg+vB/G16ZAGKeBoj\n\t\t\t\t\t\tvmd0w4Aii9sNnyb6BIQvXnlqvi7sNRXcBovlaQARTpTcCm9jHqWPvZzK9hxdm2/o\n\t\t\t\t\t\tkbHBKjHnTL7YBxPwMfHkaOmQhx2tTPgGhOK34eUzhXlLSPYrtGcde/pCFsyuhCUT\n\t\t\t\t\t\tNJ0vqLTB/w2YDJ0jC7xTCx+X6N+NulCteQosnKxtZ/blaHMwwX+j96LGHPtpOmN7\n\t\t\t\t\t\tf1v1bBVmrjy6E1aWTdH7G4cEhMIyfPeZRZvuThhKDGjBVRy1EjI+FSxWPxM1WnsD\n\t\t\t\t\t\ty8wft8UJXsBOJlHjpkjdcaR+DS88edmhvJNRbQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "A legal solution from Thomson Reuters providing practical know how (including practice notes, precedents and checklists) to help lawyers work smarter and more efficiently. Practical Law know how is created and maintained by a team of 300 lawyer-editors."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Practical Law"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://lu.exigus.com/simplesaml/module.php/saml/sp/metadata.php/lu",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Uggla"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pontus@exigus.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pontus"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://lu.exigus.com/simplesaml/module.php/saml/sp/metadata.php/lu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lu.exigus.com/simplesaml/module.php/saml/sp/saml2-logout.php/lu",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Exigus, bildbank f\u00f6r Lunds universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Exigus, image bank for Lund University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lunds universitets bildbank"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lund University's image bank"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lu.exigus.com/simplesaml/module.php/saml/sp/saml2-acs.php/lu",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://lu.exigus.com/simplesaml/module.php/saml/sp/saml1-acs.php/lu",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lu.exigus.com/simplesaml/module.php/saml/sp/saml2-acs.php/lu",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://lu.exigus.com/simplesaml/module.php/saml/sp/saml1-acs.php/lu/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.cypnow.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pollard"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tom.pollard@markallengroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tom"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dixon"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul@liblynx.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.cypnow.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-07-15T07:45:37Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Children and Young People Now"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.markallengroup.com/ma-education/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LibLynx LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cypnow-mag-shib.liblynx.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cypnow-mag-shib.liblynx.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cypnow-mag-shib.liblynx.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cypnow-mag-shib.liblynx.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cypnow-mag-shib.liblynx.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://cypnow-mag-shib.liblynx.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Children & Young People Now is a magazine for professionals working with children and young people"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Children and Young People Now"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6DCCAdCgAwIBAgIJAKKEvzTa1baZMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\n\t\t\t\t\t\tBAMTC2xpYmx5bnguY29tMB4XDTE1MDcwMTE0MzA1OFoXDTI1MDYyODE0MzA1OFow\n\t\t\t\t\t\tFjEUMBIGA1UEAxMLbGlibHlueC5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQC/tN/ehV2IQ8427sENebb+6ij+VoiIirTDNTOtvOa9ff3Yk5L+8VaS\n\t\t\t\t\t\tn5AUPJ7X4JHXl6rMIz0Vy8aaP+jeWy+oTUnNfNAXJz3CGqz3+GYST4qCbUfi071y\n\t\t\t\t\t\taZEiw/zD3PG2XjCI1iB4jojVEMOZvUNMXw2Fp2hAdeR1E4Jct6wHiPioDzKXCm5o\n\t\t\t\t\t\tEpR0EhYRDBQ5KD1pNulD219uFxmeq4sg4Yhw3e87dN0Mf+DYIm32ApXQfCj37lQm\n\t\t\t\t\t\tY3E5U/fDBaM1Du54+hWrRi4NzzHpCCmA6AfeMcyoUUmL67wc4vXePh+b1ZPtM1Dn\n\t\t\t\t\t\trsjH86EUcCZVBNp1c9nb6KO5uWfw3a7hAgMBAAGjOTA3MBYGA1UdEQQPMA2CC2xp\n\t\t\t\t\t\tYmx5bnguY29tMB0GA1UdDgQWBBRhxZ/MN/oyiZyi9iRBE2VmvDGllDANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAM1eUF5GIiZPHhmhN7mWhiNmM9cC9q+hR+BZjfBjOFyvHmUry\n\t\t\t\t\t\tXKWaq+5GVG/yZBtD8hnQAanLCBFT7iPXyPDeMkkf3CYwEScRZglVJqffn2v7rpO/\n\t\t\t\t\t\tgqam0j1tzRAgvYbZXBe/u71qFVN57b5w6XPq0rONkq1HlFPLz1kZ/RPeDPxsy1m1\n\t\t\t\t\t\tBD9Air6XaXKVUCuozkcpnDIQqDfrx+VdsHqi03T4H4UgQrqjx/C+eASsFH9qQsBz\n\t\t\t\t\t\t7wGBxTNZk8z8Ob/CFJI79t38xZnP8cBEr4vlE27ld7HGu1mzBZPi6d4pAhpOcIvG\n\t\t\t\t\t\ttkJW/9JlQ93sBxUk0E1HbTlYxtXFbNCVwqEWcg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cypnow-mag-shib.liblynx.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cypnow-mag-shib.liblynx.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cypnow-mag-shib.liblynx.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://cypnow-mag-shib.liblynx.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://cypnow-mag-shib.liblynx.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://cypnow-mag-shib.liblynx.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://imodrhubarb.imodules.com/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jwicoff@imodules.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Josh Wicoff"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://imodrhubarb.imodules.com/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Imodules Software, Inc."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.imodules.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Imodules Software, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://secure4.imodules.com/controls/login/AssertionConsumerService.aspx?sid=1232&gid=1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://secure4.imodules.com/controls/login/AssertionConsumerService.aspx?sid=1232&gid=2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://secure4.imodules.com/controls/login/AssertionConsumerService.aspx?sid=1232&gid=3",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBDCCAeygAwIBAgIQzEDukSw9R5BHpxVmr1UwFjANBgkqhkiG9w0BAQQFADAX\nMRUwEwYDVQQDEwxpbW9kdWxlcy5jb20wHhcNMTQwNjEwMjExODU3WhcNMzQwNjEw\nMjExODU2WjAXMRUwEwYDVQQDEwxpbW9kdWxlcy5jb20wggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQDC5hlDfEQ7RoqQgtcZjOxN2FdUOMu4MI8hIeydiFDy\n1fT1t1jJHmFF5V4JDGpITIapK2caenljBcGl7CGC+Z6EXID8i0lxc7lLWOOrYkJb\n8PeuVOpbxTZfOxfkC3jf4IfLZPtBfDvWjYtVUPwDCpwLLE/GQzz6HySoMIcWAkQ9\nbPoAIITTRnDpo1f4J6nO81DKx0XjBVIbz6aTsF60pcXQzLJ69KGI5Jkh3DjmNbeq\nEXH6ENtq823q4JGXRrKvCPrTlt+79EI1p+ECSaRUx006raAYHktUTT2KY1oUlsuk\nqVA+LMmhX/+jF1fgOehHEurOiKQp2aGmeV4PnJ8pXKM9AgMBAAGjTDBKMEgGA1Ud\nAQRBMD+AEG94Y5yfOU4e+OzhpzVt1UyhGTAXMRUwEwYDVQQDEwxpbW9kdWxlcy5j\nb22CEMxA7pEsPUeQR6cVZq9VMBYwDQYJKoZIhvcNAQEEBQADggEBAFDDvIjK8eJO\nYjDqnY9DfzUEN6Vp80w3ZLhT/K49/McNbbGkt0bgg45MeJ78IxLdclTIhOEeHACN\nF71+XLb9PjRfISiB37V157w0nKF5MsMYU1dathFrVOzCIxvhERgoD4lMNtwZiKKH\nJ/xYeczpnHz5iFpoiCvsvPTP5sZqAKvf5ovpermVcLyqEPJJHvLHe+TbwdwTuGMS\npF2w1WQGpSgdbcxWWwmwpbeiF5ADI6UTS5txOfG0p8L2RTxgRJ6Nb7lNrelIEcup\n6nWHUla/60ENe+AN9qsqYh1vnknLi7kSMHwvtyzFQDHnXhwhLa9mkpsZVkeLEGsR\nMJlfQnuceWY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "iModules Preload: rhubarb"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "http://ccidfederation.clusius.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://ccidfederation.clusius.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-04-23T12:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/df9b663261436f0d31a332a5e17161b1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Clusius College"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Clusius College"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/clusius_college.gif",
                    "height": "160",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "200"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Clusius College"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Clusius College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Clusius College"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Clusius College"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.clusius.nl"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.clusius.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Clusius College"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Clusius College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.ingramdigital.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Masales"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dmasales@myilibrary.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Deron"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Masales"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dmasales@myilibrary.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Deron"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.ingramdigital.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-03-02T16:54:25Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MyiLibrary.com"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.myilibrary.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ingram Digital"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.ingramdigital.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.ingramdigital.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.ingramdigital.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.ingramdigital.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.ingramdigital.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib.ingramdigital.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shib.ingramdigital.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFxDCCBKygAwIBAgIQOpCD+8UZ84TwSedea43aUDANBgkqhkiG9w0BAQUFADCB\n\t\t\t\t\t\ttTELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMR8wHQYDVQQL\n\t\t\t\t\t\tExZWZXJpU2lnbiBUcnVzdCBOZXR3b3JrMTswOQYDVQQLEzJUZXJtcyBvZiB1c2Ug\n\t\t\t\t\t\tYXQgaHR0cHM6Ly93d3cudmVyaXNpZ24uY29tL3JwYSAoYykxMDEvMC0GA1UEAxMm\n\t\t\t\t\t\tVmVyaVNpZ24gQ2xhc3MgMyBTZWN1cmUgU2VydmVyIENBIC0gRzMwHhcNMTIwMzMw\n\t\t\t\t\t\tMDAwMDAwWhcNMTgwMzMxMjM1OTU5WjCBsDELMAkGA1UEBhMCVVMxEjAQBgNVBAgT\n\t\t\t\t\t\tCVRlbm5lc3NlZTERMA8GA1UEBxQITGFWZXJnbmUxFzAVBgNVBAoUDkluZ3JhbSBE\n\t\t\t\t\t\taWdpdGFsMQswCQYDVQQLFAJJVDEzMDEGA1UECxQqVGVybXMgb2YgdXNlIGF0IHd3\n\t\t\t\t\t\tdy52ZXJpc2lnbi5jb20vcnBhIChjKTA1MR8wHQYDVQQDFBZzaGliLmluZ3JhbWRp\n\t\t\t\t\t\tZ2l0YWwuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtR7bJj0G\n\t\t\t\t\t\t944b3VEsUv+lB9czHTMCVsjQxKL9gj39e5kwh0pv1d2dNgcVTiMxjeX+ytziakLw\n\t\t\t\t\t\tjvNugfmWRqV5P2TAcyforAVFjknUGIY33vfqqn8EhxE8ydpcf1e2soYb8SnqBW84\n\t\t\t\t\t\tAKkcuy9sOvsmjH2mP5wxzdHfbUG+2iJqhXPzEdZZp+3OjA0MKpJgoo0LDxmiGbKL\n\t\t\t\t\t\t6u+DOLsi0sqvh8c/M0fq3vA+BQQOL+9vWL2Yf1jbV0hpdoTUMxixLlf9thItPh6h\n\t\t\t\t\t\tUcok8f6OhWSK5slTXO3IVoki9uRAzEOckkyzRqthuNOgQgXSzDVxzaygeGSfmvSL\n\t\t\t\t\t\twJ59DW3pYFhLIwIDAQABo4IB0TCCAc0wCQYDVR0TBAIwADALBgNVHQ8EBAMCBaAw\n\t\t\t\t\t\tRQYDVR0fBD4wPDA6oDigNoY0aHR0cDovL1NWUlNlY3VyZS1HMy1jcmwudmVyaXNp\n\t\t\t\t\t\tZ24uY29tL1NWUlNlY3VyZUczLmNybDBEBgNVHSAEPTA7MDkGC2CGSAGG+EUBBxcD\n\t\t\t\t\t\tMCowKAYIKwYBBQUHAgEWHGh0dHBzOi8vd3d3LnZlcmlzaWduLmNvbS9ycGEwHQYD\n\t\t\t\t\t\tVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMB8GA1UdIwQYMBaAFA1EXBZTRMGC\n\t\t\t\t\t\tfh0gqyX0AWPYvnmlMHYGCCsGAQUFBwEBBGowaDAkBggrBgEFBQcwAYYYaHR0cDov\n\t\t\t\t\t\tL29jc3AudmVyaXNpZ24uY29tMEAGCCsGAQUFBzAChjRodHRwOi8vU1ZSU2VjdXJl\n\t\t\t\t\t\tLUczLWFpYS52ZXJpc2lnbi5jb20vU1ZSU2VjdXJlRzMuY2VyMG4GCCsGAQUFBwEM\n\t\t\t\t\t\tBGIwYKFeoFwwWjBYMFYWCWltYWdlL2dpZjAhMB8wBwYFKw4DAhoEFEtruSiWBgy7\n\t\t\t\t\t\t0FI4mymsSweLIQUYMCYWJGh0dHA6Ly9sb2dvLnZlcmlzaWduLmNvbS92c2xvZ28x\n\t\t\t\t\t\tLmdpZjANBgkqhkiG9w0BAQUFAAOCAQEApLyZmCn4L1QNZ2xg1zbqv07Jfvo4WllF\n\t\t\t\t\t\tkWOxaWWOBLoWi73/BNwcPsUgbnDGxRFLWKeMbdVPiS2ezI4ckTPShxw6Vq7wkRWQ\n\t\t\t\t\t\twRkQAE8AOfv5ZqMc3T2RSEJQu+FRSfYh4W6CTbDd0YXf6kPC5X/tStgFWlFr3hNY\n\t\t\t\t\t\tahkl80i8Ykgw14NIuW0AFTSQc+9Wl/B46rQ2wyOhM51XOQe9yvfKllef3npk8NTw\n\t\t\t\t\t\tmMUY52JZtyVONCAvb8UlR67nIEfo1gKWsLqajHh3T39WaAzlqN7wJm+ugOx9WD/S\n\t\t\t\t\t\to8jyra7+kME1GlD/W7OIckTkwxoAkB3J8jOgmlzVfOtITlgjTn/iHA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.ingramdigital.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.ingramdigital.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.ingramdigital.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shib.ingramdigital.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shib.ingramdigital.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shib.ingramdigital.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://shibboleth.metapress.com/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@metapress.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MetaPress Support Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@metapress.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MetaPress Support Desk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://shibboleth.metapress.com/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MetaPress"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.metapress.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "EBSCO Industries, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.metapress.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.metapress.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.metapress.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.metapress.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPjCCAiagAwIBAgIJAKTDQvdm67vhMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHNoaWJib2xldGgubWV0YXByZXNzLmNvbTAeFw0xMjA2MjUxNTI5NDFaFw0y\n\t\t\t\t\t\tMjA2MjMxNTI5NDFaMCMxITAfBgNVBAMTGHNoaWJib2xldGgubWV0YXByZXNzLmNv\n\t\t\t\t\t\tbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANCgbbfHnyWZP//SKjok\n\t\t\t\t\t\toNxy7YAFDxFysMjUBJnoeSN0J/nD8XvggcO10PpL+g1RnUAnc9L/2Zp0A6DpQSbN\n\t\t\t\t\t\t9RUX3o+lG4X9bQGBntImQcRx37joWq6bEKuMNxJzf42gqUCGYbUyXIRfPpjAgqEE\n\t\t\t\t\t\t5MEmjt7qK3j1NsE7NPoLpXtgNGSl9TM2dClruZiSGVPeYjA1GFW6cAk6CWy17KyB\n\t\t\t\t\t\tCZMF0d+FLEu5RQnJZOYz4fCSdhdn4lOw1gjNRI02zhMtfwgJt4Haq5H/qtsJyaPW\n\t\t\t\t\t\t9kcz1EqeX88QpJKB/eDYwQ5cLcQXuNex3eaPuzF4lwS+Ybh3CDCBg3k+VPCNVgx5\n\t\t\t\t\t\t0zECAwEAAaN1MHMwUgYDVR0RBEswSYIYc2hpYmJvbGV0aC5tZXRhcHJlc3MuY29t\n\t\t\t\t\t\thi1odHRwOi8vc2hpYmJvbGV0aC5tZXRhcHJlc3MuY29tL3NoaWJib2xldGgtc3Aw\n\t\t\t\t\t\tHQYDVR0OBBYEFPmH00sX6+2+UJXx2FEPf008kLDjMA0GCSqGSIb3DQEBBQUAA4IB\n\t\t\t\t\t\tAQAu+UyC9yMgDkfRYmLOzgIu6lUExX7JNN1tAjU6mXUb59cSs0nnk6s6lHab2DD4\n\t\t\t\t\t\ttc4i9aWS0e5q4UXnzV04+tr2Cr6AYDBS05d1trKAb3QZLBxeC9h+DGw23nLRwKTg\n\t\t\t\t\t\tYCELf07nXYSUr6KfLpNCH3d+ws+urhZtpFeElipKJQXdUnV1oe7be4ZveCaqqLm4\n\t\t\t\t\t\tyAJJ+ag8LeAszHnxACtNDd7cMvM0vgEc9WosMsBoMhY02dXSniM/9aMeKUNx6vLO\n\t\t\t\t\t\tw4MgU2zatZCHJjjn+lIwK4I5nJ36/jGx9bMJS7j0LxkEu1ITvZkaNre256n8JQKB\n\t\t\t\t\t\tZO4eKkKd2NI2Sm3qkNxfiLv6"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPjCCAiagAwIBAgIJAKTDQvdm67vhMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHNoaWJib2xldGgubWV0YXByZXNzLmNvbTAeFw0xMjA2MjUxNTI5NDFaFw0y\n\t\t\t\t\t\tMjA2MjMxNTI5NDFaMCMxITAfBgNVBAMTGHNoaWJib2xldGgubWV0YXByZXNzLmNv\n\t\t\t\t\t\tbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANCgbbfHnyWZP//SKjok\n\t\t\t\t\t\toNxy7YAFDxFysMjUBJnoeSN0J/nD8XvggcO10PpL+g1RnUAnc9L/2Zp0A6DpQSbN\n\t\t\t\t\t\t9RUX3o+lG4X9bQGBntImQcRx37joWq6bEKuMNxJzf42gqUCGYbUyXIRfPpjAgqEE\n\t\t\t\t\t\t5MEmjt7qK3j1NsE7NPoLpXtgNGSl9TM2dClruZiSGVPeYjA1GFW6cAk6CWy17KyB\n\t\t\t\t\t\tCZMF0d+FLEu5RQnJZOYz4fCSdhdn4lOw1gjNRI02zhMtfwgJt4Haq5H/qtsJyaPW\n\t\t\t\t\t\t9kcz1EqeX88QpJKB/eDYwQ5cLcQXuNex3eaPuzF4lwS+Ybh3CDCBg3k+VPCNVgx5\n\t\t\t\t\t\t0zECAwEAAaN1MHMwUgYDVR0RBEswSYIYc2hpYmJvbGV0aC5tZXRhcHJlc3MuY29t\n\t\t\t\t\t\thi1odHRwOi8vc2hpYmJvbGV0aC5tZXRhcHJlc3MuY29tL3NoaWJib2xldGgtc3Aw\n\t\t\t\t\t\tHQYDVR0OBBYEFPmH00sX6+2+UJXx2FEPf008kLDjMA0GCSqGSIb3DQEBBQUAA4IB\n\t\t\t\t\t\tAQAu+UyC9yMgDkfRYmLOzgIu6lUExX7JNN1tAjU6mXUb59cSs0nnk6s6lHab2DD4\n\t\t\t\t\t\ttc4i9aWS0e5q4UXnzV04+tr2Cr6AYDBS05d1trKAb3QZLBxeC9h+DGw23nLRwKTg\n\t\t\t\t\t\tYCELf07nXYSUr6KfLpNCH3d+ws+urhZtpFeElipKJQXdUnV1oe7be4ZveCaqqLm4\n\t\t\t\t\t\tyAJJ+ag8LeAszHnxACtNDd7cMvM0vgEc9WosMsBoMhY02dXSniM/9aMeKUNx6vLO\n\t\t\t\t\t\tw4MgU2zatZCHJjjn+lIwK4I5nJ36/jGx9bMJS7j0LxkEu1ITvZkaNre256n8JQKB\n\t\t\t\t\t\tZO4eKkKd2NI2Sm3qkNxfiLv6"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.metapress.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.metapress.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.metapress.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.metapress.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.metapress.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.metapress.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.metapress.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth.metapress.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.metapress.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.metapress.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://lists.geant.org",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "David Verdin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "david.verdin@renater.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Michael Haller"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "michael.haller@dante.net"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://lists.geant.org",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-04-29T09:35:00Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/collaboratif"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/community"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GIP RENATER"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.renater.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GIP RENATER"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://lists.geant.org/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "GN4 project collaborative tools (mailing lists and wikis)."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ce service fournit des outils de travail collaboratif aux membres du projet GN4, notamment des lists de diffusion et des wikis"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://lists.geant.org/coc.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Geant Groupware service"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Geant Groupware service"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJAKXf1V/KCXwLMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFnRlc3QtbGlzdHMwMS5nZWFudC5uZXQwHhcNMTUwNDAxMTM1MTQ1WhcNMjUw\nMzI5MTM1MTQ1WjAhMR8wHQYDVQQDExZ0ZXN0LWxpc3RzMDEuZ2VhbnQubmV0MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA7XdG9N0LSlfi87WDu0/fctSU\nh65Rm9tm+JzQxuK9NyfQeXKhBaQMK+uelrk66mgjxAiuuYDGkJ1Ity99SVYCjFsF\nZCUk2QV68KDewsX8dQhS4mgx7YzQS0j7mKQ4gligmoYiZ8RmA01aOKgG3t0Pbfty\nhHYrNx72tgoONyuvGNXaDpJe7bvb3flEiPe6zBqcCxarYvviiPrUuGFN01BLiuJ/\nrOkeimuvS6uDgPcJjPHYIY08GOypiFBVPKD9BFzNMYNzLubKQhZlYxQ2DwZr9A6B\n4PgK/hr0KFtMv8dwQFiJeZlNkL1M0uCLZvwYdp7R1LcmhYtLfBw9LPyYavAwAwID\nAQABo0QwQjAhBgNVHREEGjAYghZ0ZXN0LWxpc3RzMDEuZ2VhbnQubmV0MB0GA1Ud\nDgQWBBQQF9uaxqwZHMPdBAUqwbbJKZ+azjANBgkqhkiG9w0BAQUFAAOCAQEA26hO\nSxEnEo0+dGefyelpepLK88yLUTCqLKkf/ueh/bRYTxYnvhuXnKG8SEnj31hsBlrg\n0rRBJk1dcEonIjxAx/SU6pwfJ5meocEUmr8JhTrC3GfJD+N2fSifaKmFXJ+eDG4H\nLtwhiMq61U4VkTW/vMIHNHoKm9gkDxStp1ci6MFdLtUaIiffYBOPtuqRwDz2IErX\nbkeBfYrxyNLXpg3EbMJ5c7lQ7UJxEcUk7RyqX7whVwIEChIlnSb1i1GSdw+eZafE\ncFHyCkGxqfrSPB381C4XX43hNs4gH/w0gXZ9k9bopeuBQc5lJG+isAotHjHQwQ5r\nlLRJvk9cfZmZAyHc8w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJAKXf1V/KCXwLMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFnRlc3QtbGlzdHMwMS5nZWFudC5uZXQwHhcNMTUwNDAxMTM1MTQ1WhcNMjUw\nMzI5MTM1MTQ1WjAhMR8wHQYDVQQDExZ0ZXN0LWxpc3RzMDEuZ2VhbnQubmV0MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA7XdG9N0LSlfi87WDu0/fctSU\nh65Rm9tm+JzQxuK9NyfQeXKhBaQMK+uelrk66mgjxAiuuYDGkJ1Ity99SVYCjFsF\nZCUk2QV68KDewsX8dQhS4mgx7YzQS0j7mKQ4gligmoYiZ8RmA01aOKgG3t0Pbfty\nhHYrNx72tgoONyuvGNXaDpJe7bvb3flEiPe6zBqcCxarYvviiPrUuGFN01BLiuJ/\nrOkeimuvS6uDgPcJjPHYIY08GOypiFBVPKD9BFzNMYNzLubKQhZlYxQ2DwZr9A6B\n4PgK/hr0KFtMv8dwQFiJeZlNkL1M0uCLZvwYdp7R1LcmhYtLfBw9LPyYavAwAwID\nAQABo0QwQjAhBgNVHREEGjAYghZ0ZXN0LWxpc3RzMDEuZ2VhbnQubmV0MB0GA1Ud\nDgQWBBQQF9uaxqwZHMPdBAUqwbbJKZ+azjANBgkqhkiG9w0BAQUFAAOCAQEA26hO\nSxEnEo0+dGefyelpepLK88yLUTCqLKkf/ueh/bRYTxYnvhuXnKG8SEnj31hsBlrg\n0rRBJk1dcEonIjxAx/SU6pwfJ5meocEUmr8JhTrC3GfJD+N2fSifaKmFXJ+eDG4H\nLtwhiMq61U4VkTW/vMIHNHoKm9gkDxStp1ci6MFdLtUaIiffYBOPtuqRwDz2IErX\nbkeBfYrxyNLXpg3EbMJ5c7lQ7UJxEcUk7RyqX7whVwIEChIlnSb1i1GSdw+eZafE\ncFHyCkGxqfrSPB381C4XX43hNs4gH/w0gXZ9k9bopeuBQc5lJG+isAotHjHQwQ5r\nlLRJvk9cfZmZAyHc8w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://lists.geant.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lists.geant.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Geant Groupware service"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Geant Groupware service"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Ce service fournit des outils de travail collaboratif aux membres du projet GN4, notamment des lists de diffusion et des wikis"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "GN4 project collaborative tools (mailing lists and wikis)."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:incommon:lbl.gov",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "gahaverkamp@lbl.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Greg Haverkamp"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idm@lbl.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Identity Management Team"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@lb.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "security@lbl.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LBL Cybersecurity"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "urn:mace:incommon:lbl.gov",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.lbl.gov/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.lbl.gov/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.lbl.gov/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.lbl.gov/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUWaUNclZjoQfm4ab+ttJmW3Oqs7swDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNbG9naW4ubGJsLmdvdjAeFw0wODEwMzEyMzM2MjVaFw0y\nODEwMzEyMzM2MjVaMBgxFjAUBgNVBAMTDWxvZ2luLmxibC5nb3YwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCUWmS996rDiCDoR0+O6MM5ufJlH6JYK9vv\n1AHR29TrZXIv4xkddf8KdTEgXfS7nimbrqKO+rNnt4dvYGfG/BH2jyFhZH48EZMA\n7xzBqp9OTr4uG0J1b286ychnlZAkgqtich4FCQOkhSKWbt9XSudcsWNqSG/VRN9r\nWfqI16q74IFLm8ATUJDkTn+sG29rJcDTqADDlbA8gP3qBHXrPypfmEZChCnEpoUJ\n82w8KjwbyrRIUtOnFBkZsj8XD1Hlv6vASHXxgc7nAYP9zxXSlBFfg1oSMuyWZSXC\nvRmXb32H9I8wO+/8KvzmndzZzU1yw+KZcaMhxfTFUAwxfCDfHyZjAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDWxvZ2luLmxibC5nb3aGJGh0dHBzOi8vbG9naW4ubGJsLmdv\ndi9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUm7bprLeALfsJXQkGskKJIbn7o00w\nDQYJKoZIhvcNAQEFBQADggEBAC7pPx/biv1uaWXHd77M0HS03VP5oazpjD8yt9TO\nkFST/Q3Jtsg3anxCfqaP/R2vcad8H722vFDZwGflImbZg3DNhF6Mj/pt3CuGpnIg\n7+6mXRTDNzaTKya4wX8RZdNMZ129n4LO+IVgjXZBBpGyNkPbu5D1dXuvsOdWH81B\n//GRSpTRrm0DB2rN6refGeRfHB7ZMVeWQVJFwr+51X+6OitKHLG6/xPqURI+x3mA\njMIMRq4HkXJG3HRnSAxxmy5CPoslaIvJEXvV1WGUe/1jSqCKfdVSf1SeN2KqfQyj\nXHl1TMy82/4cFm7JOZXiJx32LIlICdpcBIGU7dFwHmiVYJc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lbl.gov"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://commons.lbl.gov/display/IDMgmt/Web+Single+Sign+On+at+LBNL"
                  }
                ],
                "logo": [
                  {
                    "text": "https://commons.lbl.gov/download/attachments/58393603/lbl-logo-scaled.png",
                    "lang": "en",
                    "height": "111",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "130"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.lbl.gov/Disclaimers.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lawrence Berkeley National Laboratory"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lawrence Berkeley National Laboratory"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lbl.gov/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Lawrence Berkeley National Laboratory"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.unipg.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servizio.idem@unipg.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Supporto IDEM"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.unipg.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2014-09-09T12:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUbtCA5KDFFzAdtSTGPwrF8RKSWf8wDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMaWRwLnVuaXBnLml0MB4XDTEzMTEyOTEwNDgyN1oXDTMz\nMTEyOTEwNDgyN1owFzEVMBMGA1UEAxMMaWRwLnVuaXBnLml0MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEArcWMYBTfLliKg2yiUOuJphQVPDuzFh8iAzmB\nN5rs+B9Y841AvxgC2K12IogTLt2oeX5qv2hvyoip2q3XBY8aHo4xwjTW0UmgZ4Td\ndTA1ImOUq61mUYucYemfng+wO2rKpDOaOuwjOOJ4ZwYly0f4MenKDkGxmv/X5vFQ\nmNc5EeC4Zllkvoss95OuE8oQ/xxA+3xsAT6zhjadsHlTrxHfkWBDTbeNhupAbqD0\nJB84CfVNaOrmD/haNzn5lfktKb+aDwac+wSpl/P2wxa2F5ZkTLJeRF6WK0z4S6Wb\nIaaLbrwIXCWnZnQoWY6mFKBaK2hAB8P3emlpsve6cl5QC7TnqwIDAQABo18wXTA8\nBgNVHREENTAzggxpZHAudW5pcGcuaXSGI2h0dHBzOi8vaWRwLnVuaXBnLml0L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBRlnQD+3BGocWcSXr2HfL3Pm+HSjTANBgkq\nhkiG9w0BAQUFAAOCAQEAF8seek5DbzQnVsPhRzkzsl367Q6gnCiUWJR4x+KwgDLb\nyC/1F9x62DxiM1HqN21K2IhhJuiBEgEH2vfBBL9XS4U12gCnjOeOrVq4Sn1n0y0n\nMtr1n/F38kdTww7elicK1c5VfJzNW92SPZ0WDeqx6dsHtCLr0cEbe2m37ObmbP7m\ni+4ZUJg7ph20zCfmZuqz9U7rd2Cextu267R6HGTb7j44QyqyR/HLmGcisZuA8F14\nNESI9h/L+O7VkKo6jKvBZhUuOxNrc/NvUToO5BaKJjtdP0kHDKKgKHpuE5FHSeGr\na3btFASB68LjOF7z6SBM9h7F+NMDYLzCDuf6qHqMkg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unipg.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unipg.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unipg.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unipg.it/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unipg.it/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unipg.it:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.unipg.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unipg.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.unipg.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unipg.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unipg.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unipg.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unipg.it/en/idem-federation"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unipg.it/il-portale/servizi-on-line/federazione-idem"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for the University of Perugia"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider per gli utenti dell'Universit\u00e0 degli studi di Perugia"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.unipg.it/en/idem-federation/idem-privacy"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.unipg.it/il-portale/servizi-on-line/federazione-idem/informativa-idem"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Perugia"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 degli studi di Perugia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unipg.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUbtCA5KDFFzAdtSTGPwrF8RKSWf8wDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMaWRwLnVuaXBnLml0MB4XDTEzMTEyOTEwNDgyN1oXDTMz\nMTEyOTEwNDgyN1owFzEVMBMGA1UEAxMMaWRwLnVuaXBnLml0MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEArcWMYBTfLliKg2yiUOuJphQVPDuzFh8iAzmB\nN5rs+B9Y841AvxgC2K12IogTLt2oeX5qv2hvyoip2q3XBY8aHo4xwjTW0UmgZ4Td\ndTA1ImOUq61mUYucYemfng+wO2rKpDOaOuwjOOJ4ZwYly0f4MenKDkGxmv/X5vFQ\nmNc5EeC4Zllkvoss95OuE8oQ/xxA+3xsAT6zhjadsHlTrxHfkWBDTbeNhupAbqD0\nJB84CfVNaOrmD/haNzn5lfktKb+aDwac+wSpl/P2wxa2F5ZkTLJeRF6WK0z4S6Wb\nIaaLbrwIXCWnZnQoWY6mFKBaK2hAB8P3emlpsve6cl5QC7TnqwIDAQABo18wXTA8\nBgNVHREENTAzggxpZHAudW5pcGcuaXSGI2h0dHBzOi8vaWRwLnVuaXBnLml0L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBRlnQD+3BGocWcSXr2HfL3Pm+HSjTANBgkq\nhkiG9w0BAQUFAAOCAQEAF8seek5DbzQnVsPhRzkzsl367Q6gnCiUWJR4x+KwgDLb\nyC/1F9x62DxiM1HqN21K2IhhJuiBEgEH2vfBBL9XS4U12gCnjOeOrVq4Sn1n0y0n\nMtr1n/F38kdTww7elicK1c5VfJzNW92SPZ0WDeqx6dsHtCLr0cEbe2m37ObmbP7m\ni+4ZUJg7ph20zCfmZuqz9U7rd2Cextu267R6HGTb7j44QyqyR/HLmGcisZuA8F14\nNESI9h/L+O7VkKo6jKvBZhUuOxNrc/NvUToO5BaKJjtdP0kHDKKgKHpuE5FHSeGr\na3btFASB68LjOF7z6SBM9h7F+NMDYLzCDuf6qHqMkg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 degli studi di Perugia"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Perugia"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unipg.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unipg.it/en"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli studi di Perugia"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Perugia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.burycollege.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Minta"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:louise.minta@burycollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Louise"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Garner"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dominic.garner@burycollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dominic"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.burycollege.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-07-21T15:13:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWjCCAkICCQC8tl6skoCc8zANBgkqhkiG9w0BAQUFADBvMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjETMBEGA1UECBMKTWFuY2hlc3RlcjENMAsGA1UEBxMEQnVyeTEVMBMGA1UEChMM\n\t\t\t\t\t\tQnVyeSBDb2xsZWdlMSUwIwYDVQQDExxzaGliYm9sZXRoLmJ1cnljb2xsZWdlLmFj\n\t\t\t\t\t\tLnVrMB4XDTE0MDcwOTE0Mjk1OFoXDTM0MDcwNDE0Mjk1OFowbzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEzARBgNVBAgTCk1hbmNoZXN0ZXIxDTALBgNVBAcTBEJ1cnkxFTATBgNVBAoT\n\t\t\t\t\t\tDEJ1cnkgQ29sbGVnZTElMCMGA1UEAxMcc2hpYmJvbGV0aC5idXJ5Y29sbGVnZS5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAND/tL2yS5omqRAg\n\t\t\t\t\t\tMRXvoOL7sdII0Bl3pe6mSPebwAIk252444CXXnPyYxNjjwTc4EKRNsI2KYAVgqRf\n\t\t\t\t\t\tng9+2bie34Qfb/xvgHN6wrh/oJRQCXaTt1fFLdOIVNKRNVEE5/Gij9ItT9RAWCgZ\n\t\t\t\t\t\toQsu6e5wIfxmkPARwDrhw99UfIlZG5vsrlISaxE+EWUZCjaJdBPwAEKbm9HF3/Zm\n\t\t\t\t\t\tBQ2fldxbMSG0uBm17UNg606BmWlRthXlSG2mbvwEPTRnQ4n0vvOWIl6fFUD1iNUE\n\t\t\t\t\t\ttX3Ay3ab3/FagvJ8jiwDXPZT6boXNYdd1zLwHsuHcAvphi+AxIW7xZ3kBAHHWQ6z\n\t\t\t\t\t\tyIUdNQkCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAcU/my3lp/CHxZE45dOmGmex2\n\t\t\t\t\t\tSmuni9Wzh9U01OHUiBzY7FTET4pdpitboZ/f7xRobnbHecFJfzHt3bVJDBDAPs/+\n\t\t\t\t\t\tVHwRJP40SvrSDtq5fHA4L41sMZcHVfxFHmzQblgpBjuwUqcfsoEmg3/lCrk8zhef\n\t\t\t\t\t\twllZha3ZbPbLaTMqhttUtOhgZ+x3tJEvnoJJem9gXu6yAdQQooEtOvSebLbnxjL5\n\t\t\t\t\t\tefQCQP3Hn4/00dV32OSfv/ZME7C+XyNGP9fCVV1tl44Po/3FhPEmhu0SmmF5DIIx\n\t\t\t\t\t\tAMJshMgl/n/2lWhtoezBSuHSoLRtboKXS54Jqzf9Z7PcuPbOLsYMymfdR1vsqg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "burycollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.burycollege.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.burycollege.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.burycollege.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.burycollege.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.burycollege.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.burycollege.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.burycollege.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.burycollege.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "burycollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWjCCAkICCQC8tl6skoCc8zANBgkqhkiG9w0BAQUFADBvMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjETMBEGA1UECBMKTWFuY2hlc3RlcjENMAsGA1UEBxMEQnVyeTEVMBMGA1UEChMM\n\t\t\t\t\t\tQnVyeSBDb2xsZWdlMSUwIwYDVQQDExxzaGliYm9sZXRoLmJ1cnljb2xsZWdlLmFj\n\t\t\t\t\t\tLnVrMB4XDTE0MDcwOTE0Mjk1OFoXDTM0MDcwNDE0Mjk1OFowbzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEzARBgNVBAgTCk1hbmNoZXN0ZXIxDTALBgNVBAcTBEJ1cnkxFTATBgNVBAoT\n\t\t\t\t\t\tDEJ1cnkgQ29sbGVnZTElMCMGA1UEAxMcc2hpYmJvbGV0aC5idXJ5Y29sbGVnZS5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAND/tL2yS5omqRAg\n\t\t\t\t\t\tMRXvoOL7sdII0Bl3pe6mSPebwAIk252444CXXnPyYxNjjwTc4EKRNsI2KYAVgqRf\n\t\t\t\t\t\tng9+2bie34Qfb/xvgHN6wrh/oJRQCXaTt1fFLdOIVNKRNVEE5/Gij9ItT9RAWCgZ\n\t\t\t\t\t\toQsu6e5wIfxmkPARwDrhw99UfIlZG5vsrlISaxE+EWUZCjaJdBPwAEKbm9HF3/Zm\n\t\t\t\t\t\tBQ2fldxbMSG0uBm17UNg606BmWlRthXlSG2mbvwEPTRnQ4n0vvOWIl6fFUD1iNUE\n\t\t\t\t\t\ttX3Ay3ab3/FagvJ8jiwDXPZT6boXNYdd1zLwHsuHcAvphi+AxIW7xZ3kBAHHWQ6z\n\t\t\t\t\t\tyIUdNQkCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAcU/my3lp/CHxZE45dOmGmex2\n\t\t\t\t\t\tSmuni9Wzh9U01OHUiBzY7FTET4pdpitboZ/f7xRobnbHecFJfzHt3bVJDBDAPs/+\n\t\t\t\t\t\tVHwRJP40SvrSDtq5fHA4L41sMZcHVfxFHmzQblgpBjuwUqcfsoEmg3/lCrk8zhef\n\t\t\t\t\t\twllZha3ZbPbLaTMqhttUtOhgZ+x3tJEvnoJJem9gXu6yAdQQooEtOvSebLbnxjL5\n\t\t\t\t\t\tefQCQP3Hn4/00dV32OSfv/ZME7C+XyNGP9fCVV1tl44Po/3FhPEmhu0SmmF5DIIx\n\t\t\t\t\t\tAMJshMgl/n/2lWhtoezBSuHSoLRtboKXS54Jqzf9Z7PcuPbOLsYMymfdR1vsqg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bury College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.burycollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Bury College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://test.napier.unidesk.ac.uk/tas/secure/login/verify",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:is.helpline@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-certs@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Apps Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test.napier.unidesk.ac.uk/tas/secure/login/verify",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-05T09:19:47Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Test Unidesk - Napier"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID5jCCAs6gAwIBAgIJALDwEI9HqzwmMA0GCSqGSIb3DQEBCwUAMFUxIjAgBgNV\n\t\t\t\t\t\tBAMTGXRlc3QubmFwaWVyLnVuaWRlc2suYWMudWsxIjAgBgNVBAoTGXRlc3QubmFw\n\t\t\t\t\t\taWVyLnVuaWRlc2suYWMudWsxCzAJBgNVBAYTAlVLMB4XDTE2MDMyNTE0NDUyNloX\n\t\t\t\t\t\tDTI2MDMyMzE0NDUyNlowVTEiMCAGA1UEAxMZdGVzdC5uYXBpZXIudW5pZGVzay5h\n\t\t\t\t\t\tYy51azEiMCAGA1UEChMZdGVzdC5uYXBpZXIudW5pZGVzay5hYy51azELMAkGA1UE\n\t\t\t\t\t\tBhMCVUswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC9CZdoVgdpI5GH\n\t\t\t\t\t\ttLbxPGK7YsiaciujrnLSwBIDoiBiC9Ktg0v4aqUmXUO3qUpXRiQZ27zkPLBqWN2t\n\t\t\t\t\t\tnI91lBMKB8pcsHVTAE9CGyZqDxrcA8qjVtSVogAaN9OAhZ246Rf9vcD6bD23kZ8b\n\t\t\t\t\t\tp5VU+DKO4c630i7WpjYlTjiT1lBjMPaK8eIJa/cHdOGyV0ZsIE9mkXjOGz77nzQQ\n\t\t\t\t\t\tb/XgSQBURFscEszUMvsDR6aiJD8tGhC1B04bfnZBTGlfod5P7LHb66DOYGHbobxZ\n\t\t\t\t\t\t6ySBktMpBwAR5GjfxfZesKSfRYSJ7HH9AxeCfsMcl5IoxEHRm1rBRaZipGlrMjnE\n\t\t\t\t\t\ta+fwHI/pAgMBAAGjgbgwgbUwHQYDVR0OBBYEFFRjbf5Cssg5VmJSaMbtUcecnSOo\n\t\t\t\t\t\tMIGFBgNVHSMEfjB8gBRUY23+QrLIOVZiUmjG7VHHnJ0jqKFZpFcwVTEiMCAGA1UE\n\t\t\t\t\t\tAxMZdGVzdC5uYXBpZXIudW5pZGVzay5hYy51azEiMCAGA1UEChMZdGVzdC5uYXBp\n\t\t\t\t\t\tZXIudW5pZGVzay5hYy51azELMAkGA1UEBhMCVUuCCQCw8BCPR6s8JjAMBgNVHRME\n\t\t\t\t\t\tBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQBlYjCA1NO5uEvVIKnZ9Pp8fgtrlvCR\n\t\t\t\t\t\tmWmTRJiB6UIwCxvulHPMSk3Yf8YInG0Uu85xImYF40pjI77t/Vxp0w9Dnr5AccO4\n\t\t\t\t\t\tpOoB0aloZqW+iyNICvNhI4IEzoDbttPbRvb2HRcpahbySUQTrwVSni8cE9flBpBg\n\t\t\t\t\t\t7LI1pZcPt5mnO3/9Pkod2/wCUE27hPLJG8IvzAZ8mHsFYSPWijiKkvmM4BoEDRJk\n\t\t\t\t\t\t1YdtL5xTLOLE8C8NnNHOwyHC0S7NGnYiV+L6JPkP6DzZAILb3DYLEgXNGzjCnpNn\n\t\t\t\t\t\tOEXG4w6V9oQj82r4pWPQ4RS99T86clSzjEPzlrUJO6cPMntuH3yuLHKA"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID5jCCAs6gAwIBAgIJALDwEI9HqzwmMA0GCSqGSIb3DQEBCwUAMFUxIjAgBgNV\n\t\t\t\t\t\tBAMTGXRlc3QubmFwaWVyLnVuaWRlc2suYWMudWsxIjAgBgNVBAoTGXRlc3QubmFw\n\t\t\t\t\t\taWVyLnVuaWRlc2suYWMudWsxCzAJBgNVBAYTAlVLMB4XDTE2MDMyNTE0NDUyNloX\n\t\t\t\t\t\tDTI2MDMyMzE0NDUyNlowVTEiMCAGA1UEAxMZdGVzdC5uYXBpZXIudW5pZGVzay5h\n\t\t\t\t\t\tYy51azEiMCAGA1UEChMZdGVzdC5uYXBpZXIudW5pZGVzay5hYy51azELMAkGA1UE\n\t\t\t\t\t\tBhMCVUswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC9CZdoVgdpI5GH\n\t\t\t\t\t\ttLbxPGK7YsiaciujrnLSwBIDoiBiC9Ktg0v4aqUmXUO3qUpXRiQZ27zkPLBqWN2t\n\t\t\t\t\t\tnI91lBMKB8pcsHVTAE9CGyZqDxrcA8qjVtSVogAaN9OAhZ246Rf9vcD6bD23kZ8b\n\t\t\t\t\t\tp5VU+DKO4c630i7WpjYlTjiT1lBjMPaK8eIJa/cHdOGyV0ZsIE9mkXjOGz77nzQQ\n\t\t\t\t\t\tb/XgSQBURFscEszUMvsDR6aiJD8tGhC1B04bfnZBTGlfod5P7LHb66DOYGHbobxZ\n\t\t\t\t\t\t6ySBktMpBwAR5GjfxfZesKSfRYSJ7HH9AxeCfsMcl5IoxEHRm1rBRaZipGlrMjnE\n\t\t\t\t\t\ta+fwHI/pAgMBAAGjgbgwgbUwHQYDVR0OBBYEFFRjbf5Cssg5VmJSaMbtUcecnSOo\n\t\t\t\t\t\tMIGFBgNVHSMEfjB8gBRUY23+QrLIOVZiUmjG7VHHnJ0jqKFZpFcwVTEiMCAGA1UE\n\t\t\t\t\t\tAxMZdGVzdC5uYXBpZXIudW5pZGVzay5hYy51azEiMCAGA1UEChMZdGVzdC5uYXBp\n\t\t\t\t\t\tZXIudW5pZGVzay5hYy51azELMAkGA1UEBhMCVUuCCQCw8BCPR6s8JjAMBgNVHRME\n\t\t\t\t\t\tBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQBlYjCA1NO5uEvVIKnZ9Pp8fgtrlvCR\n\t\t\t\t\t\tmWmTRJiB6UIwCxvulHPMSk3Yf8YInG0Uu85xImYF40pjI77t/Vxp0w9Dnr5AccO4\n\t\t\t\t\t\tpOoB0aloZqW+iyNICvNhI4IEzoDbttPbRvb2HRcpahbySUQTrwVSni8cE9flBpBg\n\t\t\t\t\t\t7LI1pZcPt5mnO3/9Pkod2/wCUE27hPLJG8IvzAZ8mHsFYSPWijiKkvmM4BoEDRJk\n\t\t\t\t\t\t1YdtL5xTLOLE8C8NnNHOwyHC0S7NGnYiV+L6JPkP6DzZAILb3DYLEgXNGzjCnpNn\n\t\t\t\t\t\tOEXG4w6V9oQj82r4pWPQ4RS99T86clSzjEPzlrUJO6cPMntuH3yuLHKA"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.napier.unidesk.ac.uk/tas/secure/login/verify",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://daisy.ict.kth.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Olofsson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pelle@dsv.su.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Per"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://daisy.ict.kth.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://daisy.ict.kth.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://daisy.ict.kth.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://daisy.ict.kth.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://daisy.ict.kth.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://daisy.ict.kth.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://daisy.ict.kth.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://daisy.ict.kth.se/Shibboleth.sso/Login/SU",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://daisy.ict.kth.se/Shibboleth.sso/DS/DSV",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://daisy.ict.kth.se/Shibboleth.sso/DS/DSV",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://daisy.ict.kth.se/Shibboleth.sso/DS/SU",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://daisy.ict.kth.se/Shibboleth.sso/DS/SU",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://daisy.ict.kth.se/Shibboleth.sso/DS/SWAMID",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://daisy.ict.kth.se/Shibboleth.sso/DS/SWAMID",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt system f\u00f6r data- och systemvetenskap vid Stockholms universitet och ICT-skolan vid KTH."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administrative system for education used by the Department of Computer and Systems Sciences (DSV) at Stockholm University and the School of Information and Communication Technology (ICT) at KTH."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Daisy"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Daisy"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "daisy.dsv.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJANH4LV/rSc9DMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2RhaXN5LmRzdi5zdS5zZTAeFw0xNDA5MDIxMTM0MzdaFw0yNDA4MzAxMTM0\nMzdaMBoxGDAWBgNVBAMTD2RhaXN5LmRzdi5zdS5zZTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAMYxuWKcPXDRuanmNtBs0LlEdh8z5Dx/x1w6ZxmlfI7n\nEd8pZbNwQXh8Ve8oa+zE5h5ucUQaH4IXn/dggbhnX6YbtI6uY5nti7gcFCivDxJ0\n5QM4BkRJlpCDX9neSehXJD/qXEhClSVMbr97nW0tG9MZcQf/PpnMqpfEOFTdzewX\n0JrNTUQWqseTYgJ4FIyjXL1juz6UwmBI+0Dmm7qQbg9dqqTLE9eImUPgATr+HIeY\nRPhIMFAyDxHDTsRaots8zx8KqjEUxmpI1dwCflPEJRxTe1dy+o/A00qUKrBWNdVN\nV0jahE0vSuHnpxskB5f9ZcMiUgwf84/qyKTGefoiomkCAwEAAaM9MDswGgYDVR0R\nBBMwEYIPZGFpc3kuZHN2LnN1LnNlMB0GA1UdDgQWBBS9Ss3+oqLHzza+tYncMvHI\nDfBVUzANBgkqhkiG9w0BAQUFAAOCAQEAHSqZjB17aP2sDkSEfqSbui2yMXwPcZSW\n2kKR6hZv1r7HnHDoGJYRmj7/qjVnaWJxSwZkeUvDykZpl1Vn42Ik0UgtipZ245Si\nSHhrmDQo9lpms1YwVFyHXamSU/6zbG0W/sTpcM5FB3hqUgWOLkO+bRutZZKE8T9N\n+T0zv7S1FTWBttLA6iYOd/ODVe+Px2UMbadlk4iGZHZUI/4T4aRcNUInNhEdYXDK\nAA4QdpJkL9NWpra1nc5H/Z+Xs+KwciCDhmuu+QGwuynKuoJwSxRnlsGBar9K/5ra\nQhkStwIG6VXQAVJpMKGblsSIk+TqRD1okkUSY5BHAob80RAoOCmbhw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=daisy.dsv.su.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://daisy.ict.kth.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://daisy.ict.kth.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://daisy.ict.kth.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://daisy.ict.kth.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://daisy.ict.kth.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://daisy.ict.kth.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://daisy.ict.kth.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://daisy.ict.kth.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://daisy.ict.kth.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.utb.grayzone.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.utb.grayzone.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.utb.grayzone.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.utb.grayzone.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.utb.grayzone.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.utb.grayzone.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.utb.grayzone.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.utb.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.utb.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.utb.grayzone.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.utb.grayzone.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.utb.grayzone.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.utb.grayzone.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.utb.grayzone.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIJAJPZjxg5+NvsMA0GCSqGSIb3DQEBCwUAMCQxIjAgBgNV\nBAMTGXd3dy51dGIuZ3JheXpvbmUubGFkb2suc2UwHhcNMTYwMzE0MTEzNTAwWhcN\nMjYwMzEyMTEzNTAwWjAkMSIwIAYDVQQDExl3d3cudXRiLmdyYXl6b25lLmxhZG9r\nLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAyrtmI0m3IVrZcnzO\n+WFroBzzRtKcBRS3T+jrdamvtpcIWGuJVBuk9dRpDGwIaIxscdg67mye0ZOJZ6YS\nLqBxqz41/pD5PPc7skomgQO5zuTYJK3bV8DQpWVJqcZS2ulFtihCunAIryifab0x\nYFdqV1BMpgYlnW0W4ijNNyEiXTmTzgaaNuEU5p3jJV3csXI7nR4PDvK7+3p1HInv\ncvLpgwGAb5hHulY+VrkQ0ahuCtcXnjDrPi7zrz9YhCNvHHTrEj5gSldQNMA4vP+F\ngtD9mzoewXF6ohZ5SKY4O75adzOMG3KC49KO2iStqVns17W3G/77Ur8lBox/LpRa\nJHZHGwIDAQABo3EwbzBOBgNVHREERzBFghl3d3cudXRiLmdyYXl6b25lLmxhZG9r\nLnNlhihodHRwczovL3d3dy51dGIuZ3JheXpvbmUubGFkb2suc2UvZ3VpLXNwMB0G\nA1UdDgQWBBSJ4KTf8+bflcMvJIakk+0CeJ1PGTANBgkqhkiG9w0BAQsFAAOCAQEA\nAOd9wK2YEAzyMSLLtiYH7LREWEbV/ZBJpUdEK1Lz9tM3jSIcZs/4cM2L5uTiJ3GL\nMW/lRZGA2UZuOy87eiN61PUXHF6P2cGtbNJiR3xwCUlsFpt3qtAW1ymI234hTbHD\n8VjClW1t4yrjtb9OY86EsyWlidl5TVFKA5lpA6gUhLb3esommGRobpTl7sjswwO9\nwpcYuvyt6attK8W6TOzPRnV+4jUjGCG+YIoZPx6/avKmzgbzVBP8MDjIgaFO9cWz\n2UEGOUva3jtbUucaTmwcoqTtGDrJHawS4Vx+/PuAFIyUwGgMsp88D7OpjzfOA48p\ndzE8INr6mv2sLjkxoHRQ1w=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.utb.grayzone.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.utb.grayzone.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.utb.grayzone.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.utb.grayzone.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.utb.grayzone.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.utb.grayzone.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.utb.grayzone.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.utb.grayzone.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.utb.grayzone.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.utb.grayzone.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.crous-nantes.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dsi.exploitation@crous-nantes.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.crous-nantes.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-01-28T09:50:19Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.crous-nantes.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.crous-nantes.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.crous-nantes.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "crous-nantes.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.crous-nantes.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Employees from CROUS of Nantes"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administratifs CROUS Nantes"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS of Nantes"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS de Nantes"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAMI83efvzywvxHitZXX4VZlwTMCTMA0GCSqGSIb3DQEB\nBQUAMB4xHDAaBgNVBAMTE2lkcC5jcm91cy1uYW50ZXMuZnIwHhcNMTQwNDEwMTI1\nNzAyWhcNMzQwNDEwMTI1NzAyWjAeMRwwGgYDVQQDExNpZHAuY3JvdXMtbmFudGVz\nLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqNwp1Kemrmrbq+EJ\nAjqE4/C9R90pS4T5FShT/qCBlZUysiApI0/F1rcYqDfccHINp0Z6wsKAVcM10eOv\n1JokHOc1CKiPRMDTy1GLCjELj7JyLacZeEkg4Tja/6ILXcnWMOe/WrddVCvuOjxN\nnekRqxkrTMsOI44zV2Z5grnGReyhAYmV38VphFBYFn5IFZAbJNcip82rJsJAr6rS\nyN+NtX1u70UyJ9jlZlH0pu796AQX8CnsG7DBrRzSO2bttQySFrvqf1MkQJknDIuC\nrWcCGBNmCgSs5GusevCbRMvJxhLhE2F/19pyKawjM6/2QaG5LhYprQRXWLnBnJY3\nvXzmOQIDAQABo20wazBKBgNVHREEQzBBghNpZHAuY3JvdXMtbmFudGVzLmZyhipo\ndHRwczovL2lkcC5jcm91cy1uYW50ZXMuZnIvaWRwL3NoaWJib2xldGgwHQYDVR0O\nBBYEFA0ym8iOuZOL8OiKnoyrOXIteMCPMA0GCSqGSIb3DQEBBQUAA4IBAQBOElqO\nepb/E6K9bXwf7GFHqGWr4W7qEpqjJWvwbYLD8CUFKQaiEIQnWDywPpOTaVqwY548\n+4vNNu/xab3U8INNmnRf26TD2CuknF2GUqDy5FBPkwwrTHoQbsNp7c1nCABpH3gF\npM9wqeKv332VzQPVFERNYY2ZtngdmvALe7EGyMntjtYm6J1NFQGAl0w5dx7KRU59\n/NV3jddW4fqkuqKKCNEzWx+mOcunNLWoJMnZwixbLczf1qw5bA3uEdL4qEepqyUe\nb4Va7oIyoH9QLAUtV8dUZNqUOwYBWmRcNKnI4tYCuL3HuIaQulLE9SUGPCotx3mQ\nWtPzHc/Z3g9j7+76"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEdDCCA1ygAwIBAgIRALmCI9KfSplaBaEw3OkzCqswDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xMzEyMDQwMDAwMDBaFw0xNjEyMDMyMzU5NTlaMEExITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEcMBoGA1UEAxMTaWRwLmNyb3Vz\nLW5hbnRlcy5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN7dNk66\n6Q8SjuXbyYGRJDmUcZzfrQbZo2tm93Q6UW0OwyidY+HQ2kwjnfFtAO8k9nYJbUR7\nsbffjlJ6cE7UqvzCCLhdQ+ljv0qMQIUFCdQyq7Qc1JtJ5wDppK7gFFxHi0JkZKzc\neI5a8MGJ9QmBa9dqeD6bR116TkiF8zBpuUvTz64E9OIb0RuO/auFn0T0fpOh3WlS\nGl2viccrsMKLBYqYNVESBlKbO2KvfcgYJJF5FcwBL+UWoCms5wo/R4jr4CfyOZ7D\n1S4Em8Id62+3iIVybn17BF0iO1zhuExh8NHGT4HpfZbqfwZh+3i7X1CflXRoZ/bi\nb3xYhYGmkkphqg0CAwEAAaOCAXAwggFsMB8GA1UdIwQYMBaAFAy9k2gM896ro0lr\nKzdXR+qQ47ntMB0GA1UdDgQWBBQ48HcJP0W24khejtyhRVxcWxIkgTAOBgNVHQ8B\nAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYB\nBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0f\nBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xD\nQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRj\ncy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDov\nL29jc3AudGNzLnRlcmVuYS5vcmcwHgYDVR0RBBcwFYITaWRwLmNyb3VzLW5hbnRl\ncy5mcjANBgkqhkiG9w0BAQUFAAOCAQEABJnxgwEeQraM3Xe7rLl95ex0B+QUrBVY\nGCjumdLmvDf8i26sr8V1S/Y7pnFvwOwJutrf4P23tYEcFlMRjxkSZqGhfkzws+A4\noGEtdmL2SZwX4kkhczWk2VboqCaywOPKhLrZBlsezqwpNODU5MSEs7DHZB4RV1kx\nY4Lshyv0lVcFjSQyQnYTAPJ9nfZDAAV82/IUlbGEZwO+KcX7DsY7LIfxlMwesRLV\nd3kCluVSx+IUBZZixpFu9/bCBlpuEzHrmXsU/by0WO0w49ICNX3lUCLUkWvMuSlN\nri7ETEJpUukv03GWujd49DIGtCfo6+64k5DS9OpUUvAbsMfYlvudjQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS de Nantes"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.crous-nantes.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS de Nantes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp02.ifc.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Marcos Malfatti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cirt@ifc.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp02.ifc.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID1jCCAr4CAQAwDQYJKoZIhvcNAQEFBQAwgbAxLDAqBgNVBAoTI0lGQyAtIElu\nc3RpdHV0byBGZWRlcmFsIENhdGFyaW5lbnNlMQwwCgYDVQQLEwNEVEkxHjAcBgkq\nhkiG9w0BCQEWD2NpcnRAaWZjLmVkdS5icjERMA8GA1UEBxMIQmx1bWVuYXUxFzAV\nBgNVBAgTDlNhbnRhIENhdGFyaW5hMQswCQYDVQQGEwJCUjEZMBcGA1UEAxMQaWRw\nMDIuaWZjLmVkdS5icjAeFw0xNTA5MDQxMjQyNTdaFw0xODA5MDMxMjQyNTdaMIGw\nMSwwKgYDVQQKEyNJRkMgLSBJbnN0aXR1dG8gRmVkZXJhbCBDYXRhcmluZW5zZTEM\nMAoGA1UECxMDRFRJMR4wHAYJKoZIhvcNAQkBFg9jaXJ0QGlmYy5lZHUuYnIxETAP\nBgNVBAcTCEJsdW1lbmF1MRcwFQYDVQQIEw5TYW50YSBDYXRhcmluYTELMAkGA1UE\nBhMCQlIxGTAXBgNVBAMTEGlkcDAyLmlmYy5lZHUuYnIwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQC8FP6O2mSRACAJf66lHBAuk29vYyrwlFR4ixQLS8tn\nbSm+f2U1156R9wwUEV3gpSGvECuWpHAKoGxW18FgtkOYVducNXVipT29kKHXngj3\nZuij8MJ6byNSQsrM9noxQVVKHaLHzE9OlS/GfHCa0ZUz0L1mVZtpKEWn1v6Krq4M\njxoyY9Yb8ftHCWNx1Ahya8hrt/WexX9/dfK2wRkqPTUsGdU8Ey0lD6/3aXVDFYjQ\nwMATh5VeHKMdICj7z3+2qR11Syz4xEuIB5tvEdweVUzWrfl36WGGOu/hZGAS3pbg\nQRjdbl7aFc3ZoKJj8yA9hzVIg66OsCUC6Nw8CA5btSjXAgMBAAEwDQYJKoZIhvcN\nAQEFBQADggEBAAJ9GCV4KUP+lD25i/aqkqCPZ1fax3+KxExMGW/OVgl+50CVu80w\nsp2+PpQm9IBTO0gGq2kmqPMsYn9DSGRVYcjmAwBLR9mgN3l5pJ5Jq0dQnzQiAEeJ\n7ZLlejVj/jRVzinyAyrZPivzA8lJ4liPdkID6qtgVuaBW9Xr4YR7z2Jr9d1ppt+1\nzguX/6l7wtLQBVd/WJghECX7cLt1JzhmiKDLn/ib4/44BRf5TfVGHNmdikee7xYZ\nyywikHxhzaAW7q+tPCGAMCJWIjPX3fGDSGQIsGXSF87WTdg5S8+Eudlsh1Q/NQN3\nMbzxH0b+Clvd+lg7zzt4d6FadoYsR3FYh0A="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp02.ifc.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp02.ifc.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp02.ifc.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp02.ifc.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp02.ifc.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp02.ifc.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp02.ifc.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp02.ifc.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifc.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifc.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFC - Instituto Federal Catarinense"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFC - Instituto Federal Catarinense"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFC - Instituto Federal Catarinense"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFC - Instituto Federal Catarinense"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID1jCCAr4CAQAwDQYJKoZIhvcNAQEFBQAwgbAxLDAqBgNVBAoTI0lGQyAtIElu\nc3RpdHV0byBGZWRlcmFsIENhdGFyaW5lbnNlMQwwCgYDVQQLEwNEVEkxHjAcBgkq\nhkiG9w0BCQEWD2NpcnRAaWZjLmVkdS5icjERMA8GA1UEBxMIQmx1bWVuYXUxFzAV\nBgNVBAgTDlNhbnRhIENhdGFyaW5hMQswCQYDVQQGEwJCUjEZMBcGA1UEAxMQaWRw\nMDIuaWZjLmVkdS5icjAeFw0xNTA5MDQxMjQyNTdaFw0xODA5MDMxMjQyNTdaMIGw\nMSwwKgYDVQQKEyNJRkMgLSBJbnN0aXR1dG8gRmVkZXJhbCBDYXRhcmluZW5zZTEM\nMAoGA1UECxMDRFRJMR4wHAYJKoZIhvcNAQkBFg9jaXJ0QGlmYy5lZHUuYnIxETAP\nBgNVBAcTCEJsdW1lbmF1MRcwFQYDVQQIEw5TYW50YSBDYXRhcmluYTELMAkGA1UE\nBhMCQlIxGTAXBgNVBAMTEGlkcDAyLmlmYy5lZHUuYnIwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQC8FP6O2mSRACAJf66lHBAuk29vYyrwlFR4ixQLS8tn\nbSm+f2U1156R9wwUEV3gpSGvECuWpHAKoGxW18FgtkOYVducNXVipT29kKHXngj3\nZuij8MJ6byNSQsrM9noxQVVKHaLHzE9OlS/GfHCa0ZUz0L1mVZtpKEWn1v6Krq4M\njxoyY9Yb8ftHCWNx1Ahya8hrt/WexX9/dfK2wRkqPTUsGdU8Ey0lD6/3aXVDFYjQ\nwMATh5VeHKMdICj7z3+2qR11Syz4xEuIB5tvEdweVUzWrfl36WGGOu/hZGAS3pbg\nQRjdbl7aFc3ZoKJj8yA9hzVIg66OsCUC6Nw8CA5btSjXAgMBAAEwDQYJKoZIhvcN\nAQEFBQADggEBAAJ9GCV4KUP+lD25i/aqkqCPZ1fax3+KxExMGW/OVgl+50CVu80w\nsp2+PpQm9IBTO0gGq2kmqPMsYn9DSGRVYcjmAwBLR9mgN3l5pJ5Jq0dQnzQiAEeJ\n7ZLlejVj/jRVzinyAyrZPivzA8lJ4liPdkID6qtgVuaBW9Xr4YR7z2Jr9d1ppt+1\nzguX/6l7wtLQBVd/WJghECX7cLt1JzhmiKDLn/ib4/44BRf5TfVGHNmdikee7xYZ\nyywikHxhzaAW7q+tPCGAMCJWIjPX3fGDSGQIsGXSF87WTdg5S8+Eudlsh1Q/NQN3\nMbzxH0b+Clvd+lg7zzt4d6FadoYsR3FYh0A="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFC - Instituto Federal Catarinense"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFC - Instituto Federal Catarinense"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifc.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifc.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFC - Instituto Federal Catarinense"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFC - Instituto Federal Catarinense"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://daisy.dsv.su.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Olofsson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pelle@dsv.su.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Per"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://daisy.dsv.su.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://daisy.dsv.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://daisy.dsv.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://daisy.dsv.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://daisy.dsv.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://daisy.dsv.su.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://daisy.dsv.su.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://daisy.dsv.su.se/Shibboleth.sso/Login/SU",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://daisy.dsv.su.se/Shibboleth.sso/DS/DSV",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://daisy.dsv.su.se/Shibboleth.sso/DS/DSV",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://daisy.dsv.su.se/Shibboleth.sso/DS/SU",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://daisy.dsv.su.se/Shibboleth.sso/DS/SU",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://daisy.dsv.su.se/Shibboleth.sso/DS/SWAMID",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://daisy.dsv.su.se/Shibboleth.sso/DS/SWAMID",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt system f\u00f6r data- och systemvetenskap vid Stockholms universitet och ICT-skolan vid KTH."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administrative system for education used by the Department of Computer and Systems Sciences (DSV) at Stockholm University and the School of Information and Communication Technology (ICT) at KTH."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Daisy"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Daisy"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "daisy.dsv.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJANH4LV/rSc9DMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2RhaXN5LmRzdi5zdS5zZTAeFw0xNDA5MDIxMTM0MzdaFw0yNDA4MzAxMTM0\nMzdaMBoxGDAWBgNVBAMTD2RhaXN5LmRzdi5zdS5zZTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAMYxuWKcPXDRuanmNtBs0LlEdh8z5Dx/x1w6ZxmlfI7n\nEd8pZbNwQXh8Ve8oa+zE5h5ucUQaH4IXn/dggbhnX6YbtI6uY5nti7gcFCivDxJ0\n5QM4BkRJlpCDX9neSehXJD/qXEhClSVMbr97nW0tG9MZcQf/PpnMqpfEOFTdzewX\n0JrNTUQWqseTYgJ4FIyjXL1juz6UwmBI+0Dmm7qQbg9dqqTLE9eImUPgATr+HIeY\nRPhIMFAyDxHDTsRaots8zx8KqjEUxmpI1dwCflPEJRxTe1dy+o/A00qUKrBWNdVN\nV0jahE0vSuHnpxskB5f9ZcMiUgwf84/qyKTGefoiomkCAwEAAaM9MDswGgYDVR0R\nBBMwEYIPZGFpc3kuZHN2LnN1LnNlMB0GA1UdDgQWBBS9Ss3+oqLHzza+tYncMvHI\nDfBVUzANBgkqhkiG9w0BAQUFAAOCAQEAHSqZjB17aP2sDkSEfqSbui2yMXwPcZSW\n2kKR6hZv1r7HnHDoGJYRmj7/qjVnaWJxSwZkeUvDykZpl1Vn42Ik0UgtipZ245Si\nSHhrmDQo9lpms1YwVFyHXamSU/6zbG0W/sTpcM5FB3hqUgWOLkO+bRutZZKE8T9N\n+T0zv7S1FTWBttLA6iYOd/ODVe+Px2UMbadlk4iGZHZUI/4T4aRcNUInNhEdYXDK\nAA4QdpJkL9NWpra1nc5H/Z+Xs+KwciCDhmuu+QGwuynKuoJwSxRnlsGBar9K/5ra\nQhkStwIG6VXQAVJpMKGblsSIk+TqRD1okkUSY5BHAob80RAoOCmbhw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=daisy.dsv.su.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://daisy.dsv.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://daisy.dsv.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://daisy.dsv.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://daisy.dsv.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://daisy.dsv.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://daisy.dsv.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://daisy.dsv.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://daisy.dsv.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://daisy.dsv.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://library.qub.ac.uk/shibboleth/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:eresources@qub.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "E-Resouces Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Goodall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.goodall@qub.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://library.qub.ac.uk/shibboleth/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-05-31T09:25:24Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Queen's University SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qub.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Queen's University of Belfast"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://raptor.qub.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://raptor.qub.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://raptor.qub.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://raptor.qub.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://raptor.qub.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://raptor.qub.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Queen's University SP for special access Library E-Resources"
                  }
                ],
                "logo": [
                  {
                    "text": "https://ezproxy1.qub.ac.uk:8443/icons/Q.gif",
                    "height": "95",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Queen's University SP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC2TCCAcGgAwIBAgIJANx6SVUginfkMA0GCSqGSIb3DQEBBQUAMBExDzANBgNV\n\t\t\t\t\t\tBAMTBnJhcHRvcjAeFw0xMzA0MjQwODU0MTdaFw0yMzA0MjIwODU0MTdaMBExDzAN\n\t\t\t\t\t\tBgNVBAMTBnJhcHRvcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKB3\n\t\t\t\t\t\tk6ymJAJTxp7t77CFWoRJKYBCfNxiXaE5BcT76ZcWIohzpsiHyTpPlKU0uZe1rjNh\n\t\t\t\t\t\tgOEVjcdNI3n6AAaIT3CvawtbczAIHi5XflQ//S9qdn+W1+kgcSFvgINSIhHIW66F\n\t\t\t\t\t\tOXSa7oHCHNxmb3LYE7EZj1pEpFAgYvNG4V6UW8lgDmB4fS4DPdO+BPj6AIYVb6PF\n\t\t\t\t\t\t50FzrMiDPdRkr/aXZ7evxWmD7ruojrJRLuFI7bZoNlaEGpKRQ/krZPZz1VddUy/d\n\t\t\t\t\t\ttFznDa328ytxn9fGq5ZWPoiaA/1zaEJ9yVdAwKi/M5KQRTgZZ/Yae/zu8rTlTjZB\n\t\t\t\t\t\tob5AJgSgOW5RoAyKG+cCAwEAAaM0MDIwEQYDVR0RBAowCIIGcmFwdG9yMB0GA1Ud\n\t\t\t\t\t\tDgQWBBTsdKLXymwLx7MoCSzQZgdEcVhc2zANBgkqhkiG9w0BAQUFAAOCAQEANfHO\n\t\t\t\t\t\t1TeImBAPHOsgGuGedT9q45nkmtJDXSGI7a68chsPvaOzQfAlVeFFBDyQ7YfoHmLb\n\t\t\t\t\t\tyuBjU5OCRfpJ3PyQAnVO8l/aEMUT1qe4HKbOWLV3jdM/HxumqkEDraZe3mAceelj\n\t\t\t\t\t\t7Xs+Fpncf80Iie3I4LEvgjSkqryciRQFFESA8dLMkuKoMKMmiswVwKVErw/nMClb\n\t\t\t\t\t\tARNvuh8GT+MqNqACjO9Dstixdcr2A5WapXIs5G+is7RnGVtxwQBp4Q0ULqbqSJiD\n\t\t\t\t\t\t7dODX4wncRad73U0SAmqFt9fpftB4rOuHloEKkkoGGKSvqlWUGkiT5GWw/BH0o1n\n\t\t\t\t\t\teZkMlsZjMmrX7Nk0/A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://raptor.qub.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://raptor.qub.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://raptor.qub.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://raptor.qub.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://raptor.qub.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://raptor.qub.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://account.uat.turningtechnologies.com/account/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dhalladay@turningtechnologies.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dylan Halladay"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://account.uat.turningtechnologies.com/account/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Turning Technologies"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.turningtechnologies.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Turning Technologies"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://account.uat.turningtechnologies.com/account/shibboleth/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Turning Technologies UAT"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFUjCCBDqgAwIBAgIJAMo4GjnD2cuBMA0GCSqGSIb3DQEBBQUAMIHLMQswCQYD\nVQQGEwJVUzENMAsGA1UECBMET2hpbzETMBEGA1UEBxMKWW91bmdzdG93bjEdMBsG\nA1UEChMUVHVybmluZyBUZWNobm9sb2dpZXMxGTAXBgNVBAsTEEFjY291bnQgU1NP\nIFRlYW0xLDAqBgNVBAMTI2FjY291bnQudWF0LnR1cm5pbmd0ZWNobm9sb2dpZXMu\nY29tMTAwLgYJKoZIhvcNAQkBFiFkaGFsbGFkYXlAdHVybmluZ3RlY2hub2xvZ2ll\ncy5jb20wHhcNMTUwNzAxMTU0NzQyWhcNMjUwNjI4MTU0NzQyWjCByzELMAkGA1UE\nBhMCVVMxDTALBgNVBAgTBE9oaW8xEzARBgNVBAcTCllvdW5nc3Rvd24xHTAbBgNV\nBAoTFFR1cm5pbmcgVGVjaG5vbG9naWVzMRkwFwYDVQQLExBBY2NvdW50IFNTTyBU\nZWFtMSwwKgYDVQQDEyNhY2NvdW50LnVhdC50dXJuaW5ndGVjaG5vbG9naWVzLmNv\nbTEwMC4GCSqGSIb3DQEJARYhZGhhbGxhZGF5QHR1cm5pbmd0ZWNobm9sb2dpZXMu\nY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAswjq0ZuGa0j/insB\nJptRZya11BByqU6/cfkQcPkF6MpDRJ+iPvRLdq/10BjMkgBmE6eWke/kSjNvMDCz\nZQ9VLqK35588pTyUlz61l5bea0LEw/DQGZbnF6kkiZmOB9X65Zvq2qdi50jJjsPw\ngvwmjctPjl7tzUdNCwElp9Ws8b2VLNPdgJ/RgQcBXA00wtbkHNAa4ug481NLhBHN\nyNDlZPAaaXjTRFFkS1znkJbroU6kfPIVeVBXjTgkPxBKvVwergW9+z902TlVAkUz\nJY5PKsPocaiBhXMNR5MHedVy/Q0YVpy8z/o3t1s/8kxTCospNefnhiO8zSuq6SJh\nbka96QIDAQABo4IBNTCCATEwHQYDVR0OBBYEFIAiZITkEsHtrkY2Fy0f1HYZXzhf\nMIIBAAYDVR0jBIH4MIH1gBSAImSE5BLB7a5GNhctH9R2GV84X6GB0aSBzjCByzEL\nMAkGA1UEBhMCVVMxDTALBgNVBAgTBE9oaW8xEzARBgNVBAcTCllvdW5nc3Rvd24x\nHTAbBgNVBAoTFFR1cm5pbmcgVGVjaG5vbG9naWVzMRkwFwYDVQQLExBBY2NvdW50\nIFNTTyBUZWFtMSwwKgYDVQQDEyNhY2NvdW50LnVhdC50dXJuaW5ndGVjaG5vbG9n\naWVzLmNvbTEwMC4GCSqGSIb3DQEJARYhZGhhbGxhZGF5QHR1cm5pbmd0ZWNobm9s\nb2dpZXMuY29tggkAyjgaOcPZy4EwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUF\nAAOCAQEANWMFaMjzwh+wAqx7dTZpEzEdQMgEu+LmFTH8vf3qS9XBG84TO87QZC6a\njGSnJlG8PYB9z2CwjXRXx+ViSdbX9d+pjLz2Y92koQtLqVz9vEDE0zjbc6YsljLq\n/KdHwEeGpf8lyOftx2GQog4vAhaI/bGWmTkK0n+lSz01ObPwtTmi7oc2LjRFF0nj\nVtht8dQ8R3StjVM6lyzXjRbin4VrTT0NXQgsezxCfUp2FkonhL1kVywptWBUEga1\ns+aZGcabVSj16x5Y2VD+HIdHIjLUO5iQOvuaa2nR1+r8hh9RkLnmLkaXWIA5PPZH\nFRbDalYxxNiLLA0IlrVRk20iCT6vLg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://account.uat.turningtechnologies.com/account/shibboleth/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://account.uat.turningtechnologies.com/account/shibboleth/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://account.uat.turningtechnologies.com/account/shibboleth/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://account.uat.turningtechnologies.com/account/shibboleth/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://account.uat.turningtechnologies.com/account/shibboleth/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://account.uat.turningtechnologies.com/account/shibboleth/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Turning Technologies UAT"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-p00.ladok.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-p00.ladok.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;p00"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;p00"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-p00.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-p00.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQTCCAimgAwIBAgIJALxPd7mRqLHWMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2xhZG9rMy1wMDAubGFkb2sudW11LnNlMB4XDTE0MTAwNzE0NDUwN1oXDTI0\nMTAwNDE0NDUwN1owIjEgMB4GA1UEAxMXbGFkb2szLXAwMC5sYWRvay51bXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC5eQWoo0jvq5ezBDlf44cN\nsbWxAK+OkxeRrIgazZz3BgFO7F+RTuEFyWbVCuwjltGqhugKwXWG+Sw6hK1HCJh7\n7EhxlXiiFZjsl0UYIvh4fk2YDSHnFX1gvF/8SvUJ6y3XXfq+NFcm79wbw7JCcHon\nimO50gTfcX+f8vOEmx7T39vdCMJinwZFfgwdSAgKI2u99hF7Fh6MoREL69rWtOn5\nSMKu6aOMz61fxI0+mQw0YPpdix0z8q6qTgfgWa6q1TXo7a5hEvooCXbfvG0EcBt9\nWe59FKDHqOco4q8O7W/+CfTh3chrqvIgd1ySno4PUofrQpZx43U6jPUwIppDlmq3\nAgMBAAGjejB4MFcGA1UdEQRQME6CF2xhZG9rMy1wMDAubGFkb2sudW11LnNlhjNo\ndHRwczovL2xhZG9rMy1wMDAubGFkb2sudW11LnNlL3N0dWRlbnQtZnJvbnRlbmQt\nc3AwHQYDVR0OBBYEFPYqHe1zEaIMRzs3f0sxAtAwo7lwMA0GCSqGSIb3DQEBBQUA\nA4IBAQCvy0qQ/FqDy6C1g5ECxZViC8/VPRBKnlnVXzmUWSjbF7KMTbfsM/LXKs2z\nyqtu4vOZ3HjUyL8ZB0MUhvBRZZKJEU+ybkNRll71Lmi7G7pjF0lppFRNt0DIxQ4t\nB3ZmRqC36gtRXx9Sw3utpX3EPkUDh2ahit3dqXBF2befvQRgXLo6Bdcy0+2t1vzm\noIn5DFz+1jZCpTHuVuRKNJPVuks8RWzBV0QUgeiO9vzg8JMbyDJx0DU3azGuNrBH\nrJDif3ojo11aT4Nrn7xehC+cV0yIqTFPNiAuZ/MWyDUBH5MIw3blavnllojr8+PG\nUEpDZ+oqJxcdV7QpvC9PesO5oSvH"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-p00.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-p00.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.jisc-collections.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:vlem@kidderminster.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kidderminster"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Williams"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.williams@jisc-collections.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.jisc-collections.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-02-01T16:22:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "JISC Collections"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jisc-collections.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "JISC Collections and Janet Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.jisc-collections.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.jisc-collections.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.jisc-collections.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.jisc-collections.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.jisc-collections.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.jisc-collections.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.jisc-collections.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.jisc-collections.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Jisc Collections supports the procurement of digital content for education and research in the UK"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.jisc-collections.ac.uk/Documents/Jisc%20logo/Jisc_Logo_64x64px.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Jisc Collections"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUjCCAjoCCQDzQJpygfVTxjANBgkqhkiG9w0BAQUFADBrMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEPMA0GA1UECBMGTG9uZG9uMQ8wDQYDVQQHEwZMb25kb24xGTAXBgNVBAoTEEpJ\n\t\t\t\t\t\tU0MgQ29sbGVjdGlvbnMxHzAdBgNVBAMTFmppc2MtY29sbGVjdGlvbnMuYWMudWsw\n\t\t\t\t\t\tHhcNMTEwMTI4MTU1ODE2WhcNMjEwMTI1MTU1ODE2WjBrMQswCQYDVQQGEwJHQjEP\n\t\t\t\t\t\tMA0GA1UECBMGTG9uZG9uMQ8wDQYDVQQHEwZMb25kb24xGTAXBgNVBAoTEEpJU0Mg\n\t\t\t\t\t\tQ29sbGVjdGlvbnMxHzAdBgNVBAMTFmppc2MtY29sbGVjdGlvbnMuYWMudWswggEi\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDOi5rCHkxIFijmIutmjK46cxws\n\t\t\t\t\t\trCD8GwR12njggDuiMp51xoIjsZPvjLUam1NC1ik9JTQKNdGUnJDi9Mg0EJ0di06i\n\t\t\t\t\t\ttuoKle7qO526zB6/V7mTDYp+VHuipEr1w55f4UTxcgjxyzAM64P0Nth+4tmYY9dF\n\t\t\t\t\t\t0eNNkSozotaCyqdh8WuTNsE4m2A5AlYD5pMLWpJcKLJqbBIx+XH23k4nBQceuYk8\n\t\t\t\t\t\tiiKN4alJ8pFQcuzh8Bxxby9lKYjavSamjBi/MhhMMWwMd5O7PJHCj0Voyem9PGZG\n\t\t\t\t\t\tHbQYAjjqYHzVQXHYlLWAYeyYrq6r1mB9VhLofOcSTxgn7GniD/lNAi607DTLAgMB\n\t\t\t\t\t\tAAEwDQYJKoZIhvcNAQEFBQADggEBADSgmIvVUoZs5T/sk04+xC6hij0xQouwi0+O\n\t\t\t\t\t\tW8b4SGdMRrgn9nZ+8XRlhaGu9Nk4Vr9HU1djNbvaVw9DiJJ8j24Aggl1TP3THG6l\n\t\t\t\t\t\tLvzeK6zmwGqxWKPJH5Fr4t3jKqNauFEDxlbA30Qj8VzFO/KSN6aRvrkeuPnJOmcf\n\t\t\t\t\t\ttRjvWI+4CWEugY71OJjukJ8dNT3DOZLuLfHqzIDjAbrpFKeq+ktbAkR+CIdx59Go\n\t\t\t\t\t\t/D9NN+plf4NJOs37pk8YfnyyVsR6Gz/eSjK2XgJVZ/7Xa6VIqcPwbvhaBfRpc8Zx\n\t\t\t\t\t\t9tU+F6+/Gl/SQn9byiovbhO+UIGqktvx26oEnpbrV0suXvB8TvQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.jisc-collections.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.jisc-collections.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.jisc-collections.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.jisc-collections.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.jisc-collections.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.jisc-collections.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.jisc-collections.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.jisc-collections.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.jisc-collections.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.jisc-collections.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "box.net",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "business-support@box.com"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Box.net"
          },
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Box"
          }
        }
      ],
      "entity_id": "box.net",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.services.box.net/sp/SLO.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.services.box.net/sp/SLO.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sso.services.box.net/sp/SLO.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.services.box.net/sp/SLO.ssaml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "index": "0",
              "location": "https://sso.services.box.net/sp/ARS.ssaml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "is_default": "true"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://sso.services.box.net/sp/ACS.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sso.services.box.net/sp/ACS.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sso.services.box.net/sp/ACS.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://events.ucl.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barker"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:systems@ucl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adrian"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jomaron"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cmj@candjsoftware.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barker"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:systems@ucl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adrian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jomaron"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cmj@candjsoftware.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://events.ucl.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-01-12T18:45:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University College London: Events Calendar"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ucl.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University College London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://events.ucl.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://events.ucl.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://events.ucl.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://events.ucl.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://events.ucl.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://events.ucl.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIJAMhx5buX5u6lMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEGV2ZW50cy51Y2wuYWMudWswHhcNMTMwODE1MjAwMjMzWhcNMjgwODExMjAw\n\t\t\t\t\t\tMjMzWjAbMRkwFwYDVQQDExBldmVudHMudWNsLmFjLnVrMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAvMZJYxOssGkpBVd67l0fLZwUUZYrI96V+LYxRETF\n\t\t\t\t\t\tCOiwY4F9qZakjGLeSu6grE0/IfXqVQmRJrBnD7ZylFgZNwUymZutBAKf+MUvZ4tg\n\t\t\t\t\t\ttbjmCRNjp1YXMMNuacZKafM8pXOGf6JVnao02m8KojOqHXWH8/iZ6Q8ZICp7HyUf\n\t\t\t\t\t\t6FSfbSjIcfEWJETqMOjll7//X/xevT6tLqOYM6mGvkL8+v59yiylL6dmubuc0eku\n\t\t\t\t\t\toI+qx4oEcOZQG7Kh8Ma338Ir+K4r3GRyBmeDAf6bf73DgCsm9LYzbZJAfBj2k17e\n\t\t\t\t\t\tvEHZklAMEC61C0kZ+uw97JsnbuKwg5Lr1x2O23uRe+Uu+wIDAQABo2MwYTBABgNV\n\t\t\t\t\t\tHREEOTA3ghBldmVudHMudWNsLmFjLnVrhiNodHRwczovL2V2ZW50cy51Y2wuYWMu\n\t\t\t\t\t\tdWsvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUtVIfzTtfXXYgsLzHKV+nlYpC0YkwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBAAuzenNPDyESW0NGiFOujy4iN1sUci5R971Q52J5vRI6\n\t\t\t\t\t\tVAOkcorPF1pQZQG+0ysy8IO7z8pMrcjnPnihMoEieWhevuQ3rH0GQTIsZp2R44QT\n\t\t\t\t\t\t8Ef85tFNRNtBl4N+wzR8YsimKuO6yF5LzYv4qmny7VTb2Vgy5D7cRbrdkPDunseV\n\t\t\t\t\t\tgcWtiFfrJ88ZfwGpzLxu3+NciV2dCWpydaJOm9UbnhPCQBJpOeISLFnWyVsd+aHt\n\t\t\t\t\t\tS4692p+l8NLdLIr36qthKjOIlrARIpG/vcpJKBlrq+YecfaICiUCCHH0DvMHb4Ev\n\t\t\t\t\t\tfKI+L2d7dTFS5x6olfRCjRqlj5p4sXouizdqc0Ak10M="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://events.ucl.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://events.ucl.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://events.ucl.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://events.ucl.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://events.ucl.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://events.ucl.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://events.ucl.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://events.ucl.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://events.ucl.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://events.ucl.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:cru.fr:federation:univ-reunion.fr",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dsi-si@listes.univ-reunion.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:cru.fr:federation:univ-reunion.fr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-04-10T15:52:09Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univ-reunion.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univ-reunion.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.univ-reunion.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-reunion.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-reunion.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Reunion Island"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de la R\u00e9union"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAL8dyCz520Rx/kdyqcI4TXpOUd79MA0GCSqGSIb3DQEB\nBQUAMB4xHDAaBgNVBAMTE2lkcC51bml2LXJldW5pb24uZnIwHhcNMDkwMzE2MTQz\nOTQ5WhcNMjkwMzE2MTQzOTQ5WjAeMRwwGgYDVQQDExNpZHAudW5pdi1yZXVuaW9u\nLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqWm8P30Q7FaWJ7EX\nQBT412i9UZUVcab0hEu7aVY5y7Oz8SH4Pmnku33as+c1mMb/VC502aU/znQY3neO\n1uI/b/4w1FCPLbB3ZVz9klXGuj6/HSxWqYwCLbQQBlwpGACXsrTBfu8b3tK+MSYD\nK77TXECDQA2U4PFIKnpuBZB6cgJpBORthkKb3tg+oBeWj14CgMz5+2w1ouuRsQ6K\nGiZXf2z1RiqyODnsDst2ml4RrmQzbDFURJ0gdL6qsaUB+SGJqaabo7iYZZKgK/EA\n9+jzXCzG97jAyTyse00LliLMOc5/fAY5GLhkpVV5/9rt0W9mXbbRV4TGA6iaJGKZ\n9Y6CtQIDAQABo20wazBKBgNVHREEQzBBghNpZHAudW5pdi1yZXVuaW9uLmZyhipo\ndHRwczovL2lkcC51bml2LXJldW5pb24uZnIvaWRwL3NoaWJib2xldGgwHQYDVR0O\nBBYEFBbec4spkaLKldRGAyIDjSfMSJzNMA0GCSqGSIb3DQEBBQUAA4IBAQBSjuGF\nqqn1aEmcSAArdDkgvmAZbCnvUeZuHUEdXufrZ6JMYGS742f3A6onSAK0WZmyg0Tf\nbS7YQhEdR3NwlFNhkoCCY0IewEp1pRuKxE+u8VD1372JLCOtIRWTgxvc/VPDdw0C\nUjQmucMfyAn+/mNiR4XRPqOYm1BXvM4RDwTTmYKvaWhUAjnFgr4LTckjS4z6nMfx\nhYC3u9/xmqRAR2bDXeRB4poDfLVXfGKureDZPWw72aPvzjJ4XGf/aaHI3AmL5zmR\ngBZQE0UE++9BzuSgkbANei54g+uo5zgXNgeJT15B9waWhUpo8AMbzOKpXgmCAp51\nFChXMMiPA+POOLIC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de la R\u00e9union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-reunion.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de la R\u00e9union"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ecam.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sysadmin@ecam.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ecam.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-04-30T18:14:43Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ecam.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ecam.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ecam.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ecam.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ecam.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Utilisateurs ECAM"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Utilisateurs ECAM"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ECAM Lyon"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ECAM Lyon"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUXFGDVnYfC4TCE7Lq/bUOsxSKIrswDQYJKoZIhvcNAQEF\nBQAwFjEUMBIGA1UEAxMLaWRwLmVjYW0uZnIwHhcNMTQwNDI4MTMxMTQ4WhcNMzQw\nNDI4MTMxMTQ4WjAWMRQwEgYDVQQDEwtpZHAuZWNhbS5mcjCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAIIMTqPcyJZJxgn7lOirdEZMejGbdNX/90ZcBGYa\n6Ks1nT8smP+xyctNKS2vP7kZ59N+Ml7LB0Mne/teKkH1Qx/IEftRsTeuW70kFU6B\nRUEyHMnAyz5rZAozonbbaxKcLf383RvztwifOfcx04haXs3Du9KFGsIz2D8bYUuQ\n7yoBQy/00lTOhn+C92NSZP2iTWwNVfPAh3cEXj1VZQ47y0fkGUd/dBQIT4p4mii/\n4w3PLI4wnU44JlWcsDJllGZjBa/MQY4dRBeKibxDz8oMHxZj4nqc/ZIQ1MIIKd9v\nT24bBwL+RSa6/kGnk5M0hGwHliXGnsiM4/+4TnFJL0wWAfkCAwEAAaNdMFswOgYD\nVR0RBDMwMYILaWRwLmVjYW0uZnKGImh0dHBzOi8vaWRwLmVjYW0uZnIvaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFOtnyyDaZuvbEOS/oJjhfM9qSbeBMA0GCSqGSIb3\nDQEBBQUAA4IBAQAeDlQG75QPvtH7RH4XgFjbtuK0Vx+C+RG+JjelVwtcUz6+P2jx\n/t16CRXS6GYSuKlL8X9hWzfxdMxcSSpdynEeh1s99w/9f19tJEPEsJNQ0AdLB80Q\nbXG9s8yhrIeO8Z7fHM6/23ay0uqXSw/DtAMFQ1dBKpKJ129nhuhELdDyw3IU3lwX\nj64hF1f32hVfNw1lfF3WwUPD7+ePFAsDZ5X0Z6rTlK0pRm/MKfzU+ASmYyJMbbwc\n7o8Ug2yRh/zIA5hfS5mxYt/1anKXSXxB6DIozsy5rWBZdGKTTFiqVZmFPQjOAOQn\nwuRoN+B/HWXuO2OFERHORHrZqV90QV5Sciud"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ECAM Lyon"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ecam.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ECAM Lyon"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://uobhive.sisoshibboleth.co.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Info"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Oates"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://uobhive.sisoshibboleth.co.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-08-28T14:25:23Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SiSo University of Bedfordshire, Online Resource Booking"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sisoshibboleth.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "TechEthika Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uob-hive.siso.co/sso/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://uob-hive.siso.co/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://uob-hive.siso.co/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SiSo University of Bedfordshire, Online Resource Booking"
                  }
                ],
                "logo": [
                  {
                    "text": "https://uob-hive.siso.co/images/layout/siso-logo.jpg",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SiSo University of Bedfordshire, Online Resource Booking"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAOSUhyDXVj7AMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB3Npc28uY28wHhcNMTMwMTA3MTYzMTIxWhcNMjMwMTA1MTYzMTIxWjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdzaXNvLmNvMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\txDnj9YFJVXclawo/8rs1aWYAgk6rKi8A/Cyycq0mW5yOKLLh8MUIgDeOGL7bLl7p\n\t\t\t\t\t\tMBeZM4ILlNaeJhICWm1tuLB6SYzREnXwpO7+lvx13xsRHW2TjCPGV3yUgz55vRYj\n\t\t\t\t\t\tbseFrwFHJ8IrL24UTLcpX/R//9cMkZpSqM+77Hn22dxbYvGUOQCHOQzL78AO91qz\n\t\t\t\t\t\tdUaxKzYWyWM7w2U4APP41Zvd0flyUtRZXp8W+WwlUDffFoNndsjR4L/9wuXvOcrH\n\t\t\t\t\t\t+VZtMLy60+cB9bpvVlaQVlt+1stEABdMVvuGNkJ9wIjRjP2b9OLUI76QmgwIDtdE\n\t\t\t\t\t\t5BS0Bv0Puz66L96r2MunRQIDAQABozUwMzASBgNVHREECzAJggdzaXNvLmNvMB0G\n\t\t\t\t\t\tA1UdDgQWBBRRosxNbUQXXwtWDl/kYMScRImh5TANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tgrfjza9Btcz+9WvzcjDTZ+KSrWWvrthA3zc6Q+C/MIBG8CCuxMO+uwFBnXIopGlX\n\t\t\t\t\t\tbLa/QtVLjOugsnizFxjaEFTG4jGndtPJ8+9V8Eja5RlOazuM2LT738+Um8/1Frhr\n\t\t\t\t\t\tGXa0Hdv9ZWEbIhil65fFqZNOmOteja6xxAQ9NgGG/XUnTVTbr7msihEAYTTcS40/\n\t\t\t\t\t\tGSYpT9nQwiryfSWDNJ17Zyl44389kSw+FCUsu8Ns9VSDEDWr/R+97ZMcjN6hAfJL\n\t\t\t\t\t\tdji3X1aaAC/JbnJl/v+yR1TH/sdHyObVaM7FToUGKiyjX9VpfOe64d0hjogzEr0x\n\t\t\t\t\t\tfirJubLNu96jbGctasqcpQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uob-hive.siso.co/sso/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://uob-hive.siso.co/sso/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uob-hive.siso.co/sso/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://uob-hive.siso.co/sso/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://uob-hive.siso.co/sso/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://uob-hive.siso.co/sso/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.fh-rosenheim.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Meier"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:robert.meier@fh-rosenheim.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Meier"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idm-support@fh-rosenheim.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.fh-rosenheim.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2013-10-17T07:15:42Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.fh-rosenheim.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFyjCCBLKgAwIBAgIHGdmQDevy+jANBgkqhkiG9w0BAQsFADBhMQswCQYDVQQG\nEwJERTEhMB8GA1UEChMYRmFjaGhvY2hzY2h1bGUgUm9zZW5oZWltMRYwFAYDVQQL\nEw1SZWNoZW56ZW50cnVtMRcwFQYDVQQDEw5GSC1STyBDQSAtIEcwMjAeFw0xNTA3\nMzAxMjAzMTBaFw0xODEwMjYxMjAzMTBaMIGHMQswCQYDVQQGEwJERTEPMA0GA1UE\nCAwGQmF5ZXJuMRIwEAYDVQQHDAlSb3NlbmhlaW0xHTAbBgNVBAoMFEhvY2hzY2h1\nbGUgUm9zZW5oZWltMRYwFAYDVQQLDA1SZWNoZW56ZW50cnVtMRwwGgYDVQQDDBNp\nZHAuZmgtcm9zZW5oZWltLmRlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAt++hJd5t48KJPKqUqz6zzYQYp6JAvxAioSYcTMoWlPwpfEnBHXMdYe9X+Yka\nG4mdn6vrrm60mFPi+IIIHUYYnSB0Q2VV12gOzOfcu+oveGb4Jd0PnR0beud5ns2q\ncfZ/AD8pn2Y2uHYw7Y/yIzAtejhO7waBt6gSthv2Kw/LtvMjCMG0bXhOobOQ1Kqb\nXw8r3yN8o5DD43SoKHX1HN5krEYqnKu2M/KcO9FJgYlk8RrwWWffXgfTO55ISysX\ndW4B55mDvCxCqQmzKDSbwZBTKoG8RXHtnonmedtm2egVwxH8HPfWj84Fpk2eCVQj\n78fkh+neUWGL/lOCdr3nDy6i6wIDAQABo4ICXjCCAlowTwYDVR0gBEgwRjARBg8r\nBgEEAYGtIYIsAQEEAwMwEQYPKwYBBAGBrSGCLAIBBAMBMA8GDSsGAQQBga0hgiwB\nAQQwDQYLKwYBBAGBrSGCLB4wCQYDVR0TBAIwADALBgNVHQ8EBAMCBeAwHQYDVR0l\nBBYwFAYIKwYBBQUHAwIGCCsGAQUFBwMBMB0GA1UdDgQWBBR6kwflRNnIjgBvGKaO\n+Jz7PAY2OTAfBgNVHSMEGDAWgBQgZm4lL6ljTaLgJ7qJf8sVuj+ukTAeBgNVHREE\nFzAVghNpZHAuZmgtcm9zZW5oZWltLmRlMIGPBgNVHR8EgYcwgYQwQKA+oDyGOmh0\ndHA6Ly9jZHAxLnBjYS5kZm4uZGUvZmgtcm9zZW5oZWltLWNhL3B1Yi9jcmwvZ19j\nYWNybC5jcmwwQKA+oDyGOmh0dHA6Ly9jZHAyLnBjYS5kZm4uZGUvZmgtcm9zZW5o\nZWltLWNhL3B1Yi9jcmwvZ19jYWNybC5jcmwwgd0GCCsGAQUFBwEBBIHQMIHNMDMG\nCCsGAQUFBzABhidodHRwOi8vb2NzcC5wY2EuZGZuLmRlL09DU1AtU2VydmVyL09D\nU1AwSgYIKwYBBQUHMAKGPmh0dHA6Ly9jZHAxLnBjYS5kZm4uZGUvZmgtcm9zZW5o\nZWltLWNhL3B1Yi9jYWNlcnQvZ19jYWNlcnQuY3J0MEoGCCsGAQUFBzAChj5odHRw\nOi8vY2RwMi5wY2EuZGZuLmRlL2ZoLXJvc2VuaGVpbS1jYS9wdWIvY2FjZXJ0L2df\nY2FjZXJ0LmNydDANBgkqhkiG9w0BAQsFAAOCAQEAT0veIj3G+Z2c+lWdFmHjl1MY\nvGLdqSz/kOBTP0TQmaR0F3XfwAeq2vzjLrIKzq2dLta7B8XM2z6SQP076+bDitwn\nPyjzjBHhcH0+9qbW7NyuAqGJ7QLDNgHdTp6Vy9NL3n3DWQcyl5+IJF0/AaOTcGpv\nTzuebWBhhABPYYHBzqwFL1PQho8hY3k/HgYbKe0LZT1qskSuGwaKwUgxS4nj6TB0\nRjabz+0qMj6nOvfzyxRHCmD2F58f/vRXQ5GjDK9BJDs7m9a7X0HFydFA1ICzXy3h\n9ByxH89P1vaG3uoL/8eUitiZIHEjnbRywqTb4ymRNc25zHssb3nB9JElcjpesQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.fh-rosenheim.de,OU=Rechenzentrum,O=Hochschule Rosenheim,L=Rosenheim,ST=Bayern,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.fh-rosenheim.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFyjCCBLKgAwIBAgIHGdmQDevy+jANBgkqhkiG9w0BAQsFADBhMQswCQYDVQQG\nEwJERTEhMB8GA1UEChMYRmFjaGhvY2hzY2h1bGUgUm9zZW5oZWltMRYwFAYDVQQL\nEw1SZWNoZW56ZW50cnVtMRcwFQYDVQQDEw5GSC1STyBDQSAtIEcwMjAeFw0xNTA3\nMzAxMjAzMTBaFw0xODEwMjYxMjAzMTBaMIGHMQswCQYDVQQGEwJERTEPMA0GA1UE\nCAwGQmF5ZXJuMRIwEAYDVQQHDAlSb3NlbmhlaW0xHTAbBgNVBAoMFEhvY2hzY2h1\nbGUgUm9zZW5oZWltMRYwFAYDVQQLDA1SZWNoZW56ZW50cnVtMRwwGgYDVQQDDBNp\nZHAuZmgtcm9zZW5oZWltLmRlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAt++hJd5t48KJPKqUqz6zzYQYp6JAvxAioSYcTMoWlPwpfEnBHXMdYe9X+Yka\nG4mdn6vrrm60mFPi+IIIHUYYnSB0Q2VV12gOzOfcu+oveGb4Jd0PnR0beud5ns2q\ncfZ/AD8pn2Y2uHYw7Y/yIzAtejhO7waBt6gSthv2Kw/LtvMjCMG0bXhOobOQ1Kqb\nXw8r3yN8o5DD43SoKHX1HN5krEYqnKu2M/KcO9FJgYlk8RrwWWffXgfTO55ISysX\ndW4B55mDvCxCqQmzKDSbwZBTKoG8RXHtnonmedtm2egVwxH8HPfWj84Fpk2eCVQj\n78fkh+neUWGL/lOCdr3nDy6i6wIDAQABo4ICXjCCAlowTwYDVR0gBEgwRjARBg8r\nBgEEAYGtIYIsAQEEAwMwEQYPKwYBBAGBrSGCLAIBBAMBMA8GDSsGAQQBga0hgiwB\nAQQwDQYLKwYBBAGBrSGCLB4wCQYDVR0TBAIwADALBgNVHQ8EBAMCBeAwHQYDVR0l\nBBYwFAYIKwYBBQUHAwIGCCsGAQUFBwMBMB0GA1UdDgQWBBR6kwflRNnIjgBvGKaO\n+Jz7PAY2OTAfBgNVHSMEGDAWgBQgZm4lL6ljTaLgJ7qJf8sVuj+ukTAeBgNVHREE\nFzAVghNpZHAuZmgtcm9zZW5oZWltLmRlMIGPBgNVHR8EgYcwgYQwQKA+oDyGOmh0\ndHA6Ly9jZHAxLnBjYS5kZm4uZGUvZmgtcm9zZW5oZWltLWNhL3B1Yi9jcmwvZ19j\nYWNybC5jcmwwQKA+oDyGOmh0dHA6Ly9jZHAyLnBjYS5kZm4uZGUvZmgtcm9zZW5o\nZWltLWNhL3B1Yi9jcmwvZ19jYWNybC5jcmwwgd0GCCsGAQUFBwEBBIHQMIHNMDMG\nCCsGAQUFBzABhidodHRwOi8vb2NzcC5wY2EuZGZuLmRlL09DU1AtU2VydmVyL09D\nU1AwSgYIKwYBBQUHMAKGPmh0dHA6Ly9jZHAxLnBjYS5kZm4uZGUvZmgtcm9zZW5o\nZWltLWNhL3B1Yi9jYWNlcnQvZ19jYWNlcnQuY3J0MEoGCCsGAQUFBzAChj5odHRw\nOi8vY2RwMi5wY2EuZGZuLmRlL2ZoLXJvc2VuaGVpbS1jYS9wdWIvY2FjZXJ0L2df\nY2FjZXJ0LmNydDANBgkqhkiG9w0BAQsFAAOCAQEAT0veIj3G+Z2c+lWdFmHjl1MY\nvGLdqSz/kOBTP0TQmaR0F3XfwAeq2vzjLrIKzq2dLta7B8XM2z6SQP076+bDitwn\nPyjzjBHhcH0+9qbW7NyuAqGJ7QLDNgHdTp6Vy9NL3n3DWQcyl5+IJF0/AaOTcGpv\nTzuebWBhhABPYYHBzqwFL1PQho8hY3k/HgYbKe0LZT1qskSuGwaKwUgxS4nj6TB0\nRjabz+0qMj6nOvfzyxRHCmD2F58f/vRXQ5GjDK9BJDs7m9a7X0HFydFA1ICzXy3h\n9ByxH89P1vaG3uoL/8eUitiZIHEjnbRywqTb4ymRNc25zHssb3nB9JElcjpesQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.fh-rosenheim.de,OU=Rechenzentrum,O=Hochschule Rosenheim,L=Rosenheim,ST=Bayern,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fh-rosenheim.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.fh-rosenheim.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.fh-rosenheim.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.fh-rosenheim.de/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.fh-rosenheim.de/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.fh-rosenheim.de:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.fh-rosenheim.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.fh-rosenheim.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.fh-rosenheim.de/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.fh-rosenheim.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.fh-rosenheim.de/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.fh-rosenheim.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.fh-rosenheim.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fh-rosenheim.de"
              },
              {
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider der Hochschule Rosenheim"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider of the University of Applied Sciences Rosenheim"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.fh-rosenheim.de/fileadmin/user_upload/Fakultaeten_und_Abteilungen/Rechenzentrum/Icons/fh_rosenheim_logo_klein.jpg",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "40"
                  },
                  {
                    "text": "https://www.fh-rosenheim.de/fileadmin/user_upload/Fakultaeten_und_Abteilungen/Rechenzentrum/Icons/fh_rosenheim_logo.jpg",
                    "height": "75",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "75"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hochschule Rosenheim"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Applied Sciences Rosenheim"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.fh-rosenheim.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFyjCCBLKgAwIBAgIHGdmQDevy+jANBgkqhkiG9w0BAQsFADBhMQswCQYDVQQG\nEwJERTEhMB8GA1UEChMYRmFjaGhvY2hzY2h1bGUgUm9zZW5oZWltMRYwFAYDVQQL\nEw1SZWNoZW56ZW50cnVtMRcwFQYDVQQDEw5GSC1STyBDQSAtIEcwMjAeFw0xNTA3\nMzAxMjAzMTBaFw0xODEwMjYxMjAzMTBaMIGHMQswCQYDVQQGEwJERTEPMA0GA1UE\nCAwGQmF5ZXJuMRIwEAYDVQQHDAlSb3NlbmhlaW0xHTAbBgNVBAoMFEhvY2hzY2h1\nbGUgUm9zZW5oZWltMRYwFAYDVQQLDA1SZWNoZW56ZW50cnVtMRwwGgYDVQQDDBNp\nZHAuZmgtcm9zZW5oZWltLmRlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAt++hJd5t48KJPKqUqz6zzYQYp6JAvxAioSYcTMoWlPwpfEnBHXMdYe9X+Yka\nG4mdn6vrrm60mFPi+IIIHUYYnSB0Q2VV12gOzOfcu+oveGb4Jd0PnR0beud5ns2q\ncfZ/AD8pn2Y2uHYw7Y/yIzAtejhO7waBt6gSthv2Kw/LtvMjCMG0bXhOobOQ1Kqb\nXw8r3yN8o5DD43SoKHX1HN5krEYqnKu2M/KcO9FJgYlk8RrwWWffXgfTO55ISysX\ndW4B55mDvCxCqQmzKDSbwZBTKoG8RXHtnonmedtm2egVwxH8HPfWj84Fpk2eCVQj\n78fkh+neUWGL/lOCdr3nDy6i6wIDAQABo4ICXjCCAlowTwYDVR0gBEgwRjARBg8r\nBgEEAYGtIYIsAQEEAwMwEQYPKwYBBAGBrSGCLAIBBAMBMA8GDSsGAQQBga0hgiwB\nAQQwDQYLKwYBBAGBrSGCLB4wCQYDVR0TBAIwADALBgNVHQ8EBAMCBeAwHQYDVR0l\nBBYwFAYIKwYBBQUHAwIGCCsGAQUFBwMBMB0GA1UdDgQWBBR6kwflRNnIjgBvGKaO\n+Jz7PAY2OTAfBgNVHSMEGDAWgBQgZm4lL6ljTaLgJ7qJf8sVuj+ukTAeBgNVHREE\nFzAVghNpZHAuZmgtcm9zZW5oZWltLmRlMIGPBgNVHR8EgYcwgYQwQKA+oDyGOmh0\ndHA6Ly9jZHAxLnBjYS5kZm4uZGUvZmgtcm9zZW5oZWltLWNhL3B1Yi9jcmwvZ19j\nYWNybC5jcmwwQKA+oDyGOmh0dHA6Ly9jZHAyLnBjYS5kZm4uZGUvZmgtcm9zZW5o\nZWltLWNhL3B1Yi9jcmwvZ19jYWNybC5jcmwwgd0GCCsGAQUFBwEBBIHQMIHNMDMG\nCCsGAQUFBzABhidodHRwOi8vb2NzcC5wY2EuZGZuLmRlL09DU1AtU2VydmVyL09D\nU1AwSgYIKwYBBQUHMAKGPmh0dHA6Ly9jZHAxLnBjYS5kZm4uZGUvZmgtcm9zZW5o\nZWltLWNhL3B1Yi9jYWNlcnQvZ19jYWNlcnQuY3J0MEoGCCsGAQUFBzAChj5odHRw\nOi8vY2RwMi5wY2EuZGZuLmRlL2ZoLXJvc2VuaGVpbS1jYS9wdWIvY2FjZXJ0L2df\nY2FjZXJ0LmNydDANBgkqhkiG9w0BAQsFAAOCAQEAT0veIj3G+Z2c+lWdFmHjl1MY\nvGLdqSz/kOBTP0TQmaR0F3XfwAeq2vzjLrIKzq2dLta7B8XM2z6SQP076+bDitwn\nPyjzjBHhcH0+9qbW7NyuAqGJ7QLDNgHdTp6Vy9NL3n3DWQcyl5+IJF0/AaOTcGpv\nTzuebWBhhABPYYHBzqwFL1PQho8hY3k/HgYbKe0LZT1qskSuGwaKwUgxS4nj6TB0\nRjabz+0qMj6nOvfzyxRHCmD2F58f/vRXQ5GjDK9BJDs7m9a7X0HFydFA1ICzXy3h\n9ByxH89P1vaG3uoL/8eUitiZIHEjnbRywqTb4ymRNc25zHssb3nB9JElcjpesQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.fh-rosenheim.de,OU=Rechenzentrum,O=Hochschule Rosenheim,L=Rosenheim,ST=Bayern,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.fh-rosenheim.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFyjCCBLKgAwIBAgIHGdmQDevy+jANBgkqhkiG9w0BAQsFADBhMQswCQYDVQQG\nEwJERTEhMB8GA1UEChMYRmFjaGhvY2hzY2h1bGUgUm9zZW5oZWltMRYwFAYDVQQL\nEw1SZWNoZW56ZW50cnVtMRcwFQYDVQQDEw5GSC1STyBDQSAtIEcwMjAeFw0xNTA3\nMzAxMjAzMTBaFw0xODEwMjYxMjAzMTBaMIGHMQswCQYDVQQGEwJERTEPMA0GA1UE\nCAwGQmF5ZXJuMRIwEAYDVQQHDAlSb3NlbmhlaW0xHTAbBgNVBAoMFEhvY2hzY2h1\nbGUgUm9zZW5oZWltMRYwFAYDVQQLDA1SZWNoZW56ZW50cnVtMRwwGgYDVQQDDBNp\nZHAuZmgtcm9zZW5oZWltLmRlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAt++hJd5t48KJPKqUqz6zzYQYp6JAvxAioSYcTMoWlPwpfEnBHXMdYe9X+Yka\nG4mdn6vrrm60mFPi+IIIHUYYnSB0Q2VV12gOzOfcu+oveGb4Jd0PnR0beud5ns2q\ncfZ/AD8pn2Y2uHYw7Y/yIzAtejhO7waBt6gSthv2Kw/LtvMjCMG0bXhOobOQ1Kqb\nXw8r3yN8o5DD43SoKHX1HN5krEYqnKu2M/KcO9FJgYlk8RrwWWffXgfTO55ISysX\ndW4B55mDvCxCqQmzKDSbwZBTKoG8RXHtnonmedtm2egVwxH8HPfWj84Fpk2eCVQj\n78fkh+neUWGL/lOCdr3nDy6i6wIDAQABo4ICXjCCAlowTwYDVR0gBEgwRjARBg8r\nBgEEAYGtIYIsAQEEAwMwEQYPKwYBBAGBrSGCLAIBBAMBMA8GDSsGAQQBga0hgiwB\nAQQwDQYLKwYBBAGBrSGCLB4wCQYDVR0TBAIwADALBgNVHQ8EBAMCBeAwHQYDVR0l\nBBYwFAYIKwYBBQUHAwIGCCsGAQUFBwMBMB0GA1UdDgQWBBR6kwflRNnIjgBvGKaO\n+Jz7PAY2OTAfBgNVHSMEGDAWgBQgZm4lL6ljTaLgJ7qJf8sVuj+ukTAeBgNVHREE\nFzAVghNpZHAuZmgtcm9zZW5oZWltLmRlMIGPBgNVHR8EgYcwgYQwQKA+oDyGOmh0\ndHA6Ly9jZHAxLnBjYS5kZm4uZGUvZmgtcm9zZW5oZWltLWNhL3B1Yi9jcmwvZ19j\nYWNybC5jcmwwQKA+oDyGOmh0dHA6Ly9jZHAyLnBjYS5kZm4uZGUvZmgtcm9zZW5o\nZWltLWNhL3B1Yi9jcmwvZ19jYWNybC5jcmwwgd0GCCsGAQUFBwEBBIHQMIHNMDMG\nCCsGAQUFBzABhidodHRwOi8vb2NzcC5wY2EuZGZuLmRlL09DU1AtU2VydmVyL09D\nU1AwSgYIKwYBBQUHMAKGPmh0dHA6Ly9jZHAxLnBjYS5kZm4uZGUvZmgtcm9zZW5o\nZWltLWNhL3B1Yi9jYWNlcnQvZ19jYWNlcnQuY3J0MEoGCCsGAQUFBzAChj5odHRw\nOi8vY2RwMi5wY2EuZGZuLmRlL2ZoLXJvc2VuaGVpbS1jYS9wdWIvY2FjZXJ0L2df\nY2FjZXJ0LmNydDANBgkqhkiG9w0BAQsFAAOCAQEAT0veIj3G+Z2c+lWdFmHjl1MY\nvGLdqSz/kOBTP0TQmaR0F3XfwAeq2vzjLrIKzq2dLta7B8XM2z6SQP076+bDitwn\nPyjzjBHhcH0+9qbW7NyuAqGJ7QLDNgHdTp6Vy9NL3n3DWQcyl5+IJF0/AaOTcGpv\nTzuebWBhhABPYYHBzqwFL1PQho8hY3k/HgYbKe0LZT1qskSuGwaKwUgxS4nj6TB0\nRjabz+0qMj6nOvfzyxRHCmD2F58f/vRXQ5GjDK9BJDs7m9a7X0HFydFA1ICzXy3h\n9ByxH89P1vaG3uoL/8eUitiZIHEjnbRywqTb4ymRNc25zHssb3nB9JElcjpesQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.fh-rosenheim.de,OU=Rechenzentrum,O=Hochschule Rosenheim,L=Rosenheim,ST=Bayern,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hochschule Rosenheim"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Applied Sciences Rosenheim"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fh-rosenheim.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fh-rosenheim.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e360"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e360"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.uolia.london.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Thomas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Jonathon.Thomas@london.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jonathon"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Thomas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Jonathon.Thomas@london.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jonathon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uolia.london.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEYTCCA0mgAwIBAgIBADANBgkqhkiG9w0BAQQFADCBgTELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tDzANBgNVBAcTBkxvbmRvbjEdMBsGA1UEChMUVW5pdmVyc2l0eSBvZiBMb25kb24x\n\t\t\t\t\t\tITAfBgNVBAsTGEludGVybmF0aW9uYWwgUHJvZ3JhbW1lczEfMB0GA1UEAxMWaWRw\n\t\t\t\t\t\tLnVvbGlhLmxvbmRvbi5hYy51azAeFw0xMjAyMTYxNDQ4MDhaFw0yMjAyMTUxNDQ4\n\t\t\t\t\t\tMDhaMIGBMQswCQYDVQQGEwJHQjEPMA0GA1UEBxMGTG9uZG9uMR0wGwYDVQQKExRV\n\t\t\t\t\t\tbml2ZXJzaXR5IG9mIExvbmRvbjEhMB8GA1UECxMYSW50ZXJuYXRpb25hbCBQcm9n\n\t\t\t\t\t\tcmFtbWVzMR8wHQYDVQQDExZpZHAudW9saWEubG9uZG9uLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAn5qfRa40+d5zS+HjcdhMRsk2upuvwyZE\n\t\t\t\t\t\tlycpoQCDzoZDuibi4gqhG4BK2eiHlBJcGjKSnwXatm0PGQcqao4NaE+mq0amh9yp\n\t\t\t\t\t\t+MdVAgXiZx0VgofBF5oexfd73YAEDUS71uja4n39CfQHBZZldy7afj+ycKntEaw5\n\t\t\t\t\t\t8J8e+zrIpEXIxssVf5Mn8zdM1N6YmL7OpR3obQ/CacdsL9OVS2zVT4zYdFEuLiTo\n\t\t\t\t\t\tcz8deEoeA4MoHbS0QbEqcY8J8efkasIGxJ4hlrQr3dvKNIa+VB+I61jxTxyP0SsD\n\t\t\t\t\t\tq06VhHShAlNVwv7GAeTkMFSO7qnLFTQ4kGhqOZVH1NdUQf2NMfrnYwIDAQABo4Hh\n\t\t\t\t\t\tMIHeMB0GA1UdDgQWBBQsPgm9wW+1E/XPmWY90pp4oU6cqjCBrgYDVR0jBIGmMIGj\n\t\t\t\t\t\tgBQsPgm9wW+1E/XPmWY90pp4oU6cqqGBh6SBhDCBgTELMAkGA1UEBhMCR0IxDzAN\n\t\t\t\t\t\tBgNVBAcTBkxvbmRvbjEdMBsGA1UEChMUVW5pdmVyc2l0eSBvZiBMb25kb24xITAf\n\t\t\t\t\t\tBgNVBAsTGEludGVybmF0aW9uYWwgUHJvZ3JhbW1lczEfMB0GA1UEAxMWaWRwLnVv\n\t\t\t\t\t\tbGlhLmxvbmRvbi5hYy51a4IBADAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBAUA\n\t\t\t\t\t\tA4IBAQBToW390/2NKxG7JN+6aW6BMxSLTZOYtF1GwRA3Sc0I0i2mpYx9rpHOBm0K\n\t\t\t\t\t\tDlc1gH9+u1uTS/ZaSDCjXZXW30P4qAWL0cIkcLLbcmxCVlahIPQ2ooM5UPMARy63\n\t\t\t\t\t\thIAoYKJKzpKz9gDboaw2kGiDCaWyObwApygAtfchYjQ5FPrMoRADdXf4ePUfCPBY\n\t\t\t\t\t\tGk5gc/76YD31gApIdoI0RprtU2rOv85PrkyFLmJzirv7RUuG4b55e7RC9bGBMqU5\n\t\t\t\t\t\tcvEAR//kD0TVMXReoDar12mz+r9lCgEcnonTTmzrdEUPR/L0fBPgE/a6FAfbM3Wq\n\t\t\t\t\t\t+KvBFfLg8j/G26W22Ne/6XFgucDY"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "londonexternal.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uolia.london.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uolia.london.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.uolia.london.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uolia.london.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.uolia.london.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uolia.london.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uolia.london.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uolia.london.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "londonexternal.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEYTCCA0mgAwIBAgIBADANBgkqhkiG9w0BAQQFADCBgTELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tDzANBgNVBAcTBkxvbmRvbjEdMBsGA1UEChMUVW5pdmVyc2l0eSBvZiBMb25kb24x\n\t\t\t\t\t\tITAfBgNVBAsTGEludGVybmF0aW9uYWwgUHJvZ3JhbW1lczEfMB0GA1UEAxMWaWRw\n\t\t\t\t\t\tLnVvbGlhLmxvbmRvbi5hYy51azAeFw0xMjAyMTYxNDQ4MDhaFw0yMjAyMTUxNDQ4\n\t\t\t\t\t\tMDhaMIGBMQswCQYDVQQGEwJHQjEPMA0GA1UEBxMGTG9uZG9uMR0wGwYDVQQKExRV\n\t\t\t\t\t\tbml2ZXJzaXR5IG9mIExvbmRvbjEhMB8GA1UECxMYSW50ZXJuYXRpb25hbCBQcm9n\n\t\t\t\t\t\tcmFtbWVzMR8wHQYDVQQDExZpZHAudW9saWEubG9uZG9uLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAn5qfRa40+d5zS+HjcdhMRsk2upuvwyZE\n\t\t\t\t\t\tlycpoQCDzoZDuibi4gqhG4BK2eiHlBJcGjKSnwXatm0PGQcqao4NaE+mq0amh9yp\n\t\t\t\t\t\t+MdVAgXiZx0VgofBF5oexfd73YAEDUS71uja4n39CfQHBZZldy7afj+ycKntEaw5\n\t\t\t\t\t\t8J8e+zrIpEXIxssVf5Mn8zdM1N6YmL7OpR3obQ/CacdsL9OVS2zVT4zYdFEuLiTo\n\t\t\t\t\t\tcz8deEoeA4MoHbS0QbEqcY8J8efkasIGxJ4hlrQr3dvKNIa+VB+I61jxTxyP0SsD\n\t\t\t\t\t\tq06VhHShAlNVwv7GAeTkMFSO7qnLFTQ4kGhqOZVH1NdUQf2NMfrnYwIDAQABo4Hh\n\t\t\t\t\t\tMIHeMB0GA1UdDgQWBBQsPgm9wW+1E/XPmWY90pp4oU6cqjCBrgYDVR0jBIGmMIGj\n\t\t\t\t\t\tgBQsPgm9wW+1E/XPmWY90pp4oU6cqqGBh6SBhDCBgTELMAkGA1UEBhMCR0IxDzAN\n\t\t\t\t\t\tBgNVBAcTBkxvbmRvbjEdMBsGA1UEChMUVW5pdmVyc2l0eSBvZiBMb25kb24xITAf\n\t\t\t\t\t\tBgNVBAsTGEludGVybmF0aW9uYWwgUHJvZ3JhbW1lczEfMB0GA1UEAxMWaWRwLnVv\n\t\t\t\t\t\tbGlhLmxvbmRvbi5hYy51a4IBADAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBAUA\n\t\t\t\t\t\tA4IBAQBToW390/2NKxG7JN+6aW6BMxSLTZOYtF1GwRA3Sc0I0i2mpYx9rpHOBm0K\n\t\t\t\t\t\tDlc1gH9+u1uTS/ZaSDCjXZXW30P4qAWL0cIkcLLbcmxCVlahIPQ2ooM5UPMARy63\n\t\t\t\t\t\thIAoYKJKzpKz9gDboaw2kGiDCaWyObwApygAtfchYjQ5FPrMoRADdXf4ePUfCPBY\n\t\t\t\t\t\tGk5gc/76YD31gApIdoI0RprtU2rOv85PrkyFLmJzirv7RUuG4b55e7RC9bGBMqU5\n\t\t\t\t\t\tcvEAR//kD0TVMXReoDar12mz+r9lCgEcnonTTmzrdEUPR/L0fBPgE/a6FAfbM3Wq\n\t\t\t\t\t\t+KvBFfLg8j/G26W22Ne/6XFgucDY"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of London: Online Library"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.londoninternational.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.chesterfield.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@chesterfield.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@chesterfield.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.chesterfield.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-10-14T16:43:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEIDCCAwigAwIBAgIJAI1fOA60F77hMA0GCSqGSIb3DQEBBQUAMIGQMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjETMBEGA1UECAwKRGVyYnlzaGlyZTEVMBMGA1UEBwwMQ2hlc3RlcmZp\n\t\t\t\t\t\tZWxkMR0wGwYDVQQKDBRDaGVzdGVyZmllbGQgQ29sbGVnZTEVMBMGA1UECwwMSUNU\n\t\t\t\t\t\tIFNlcnZpY2VzMR8wHQYDVQQDDBZpZHAuY2hlc3RlcmZpZWxkLmFjLnVrMB4XDTE0\n\t\t\t\t\t\tMDkwMzA3MzI1MFoXDTI0MDgzMTA3MzI1MFowgZAxCzAJBgNVBAYTAkdCMRMwEQYD\n\t\t\t\t\t\tVQQIDApEZXJieXNoaXJlMRUwEwYDVQQHDAxDaGVzdGVyZmllbGQxHTAbBgNVBAoM\n\t\t\t\t\t\tFENoZXN0ZXJmaWVsZCBDb2xsZWdlMRUwEwYDVQQLDAxJQ1QgU2VydmljZXMxHzAd\n\t\t\t\t\t\tBgNVBAMMFmlkcC5jaGVzdGVyZmllbGQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUA\n\t\t\t\t\t\tA4IBDwAwggEKAoIBAQDQ4RgYUZeGBKe+Fhgtg9h00S6vTVBeD8923xUfwF53XKbu\n\t\t\t\t\t\tNvfQq3331N0ELndolFPFknRdJt0tfUxlpqa9GospV+JJ3tIv6MrpVbkOZyxPI5Fd\n\t\t\t\t\t\tJa1lc+5gkw/1S7k8dWJVlN1pcXrV9XBxIcANKsVZG0smM1H8cuenopMfCWC9PdNE\n\t\t\t\t\t\tTJzU/NvNthQizV4dEC5SP2/MVBUTvltN2JUq0/SjVl0GyKe4lHO6FVsKo5SlIEx/\n\t\t\t\t\t\tpUVCiyTufkaCf+PhULsOlgdGYd0NIT5pmnL58LRVbF9EqDKHeTcqJeSkfKTedwVN\n\t\t\t\t\t\twzvU3wtdh8c7Ub5oODs50Ec5ast+oyksmhCc5f0fAgMBAAGjezB5MAkGA1UdEwQC\n\t\t\t\t\t\tMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRl\n\t\t\t\t\t\tMB0GA1UdDgQWBBRwFnwr6pO2a5pd2/7uh8/ktJxREDAfBgNVHSMEGDAWgBRwFnwr\n\t\t\t\t\t\t6pO2a5pd2/7uh8/ktJxREDANBgkqhkiG9w0BAQUFAAOCAQEANhffi0UUOoXQPaPg\n\t\t\t\t\t\tayl8ylOUKb6ne6GyeE0qPiQG21JR+ndijGw9WkyVc62cvDJBrU9tXUhmxjdsd+Ro\n\t\t\t\t\t\tzyZvVHL+pQaym/nPu6XoNHdjed68b5vVc0d7ImDP2Pre3VgGdpfCxWCHVmC6kCG7\n\t\t\t\t\t\twRwnF/Le1YKLChloc++jgu0mSFozmws0xT8jHZC/Dl6+vERzgcVWY4raB6Z4qY19\n\t\t\t\t\t\t2GwOn1AMDj0vpiTWn7fvv9hivJLcJ45DLMG9ItiAQqaXsgmLGUrLsQPV/waJBcWn\n\t\t\t\t\t\tf78RSU1/IrqCyKLhCu0MpaqsNBW6vettZXLYfwS32SQXnLKdPRCsOpC/paeyfkpB\n\t\t\t\t\t\tTDscwQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "chesterfield.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.chesterfield.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.chesterfield.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.chesterfield.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.chesterfield.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.chesterfield.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.chesterfield.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.chesterfield.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.chesterfield.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "chesterfield.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEIDCCAwigAwIBAgIJAI1fOA60F77hMA0GCSqGSIb3DQEBBQUAMIGQMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjETMBEGA1UECAwKRGVyYnlzaGlyZTEVMBMGA1UEBwwMQ2hlc3RlcmZp\n\t\t\t\t\t\tZWxkMR0wGwYDVQQKDBRDaGVzdGVyZmllbGQgQ29sbGVnZTEVMBMGA1UECwwMSUNU\n\t\t\t\t\t\tIFNlcnZpY2VzMR8wHQYDVQQDDBZpZHAuY2hlc3RlcmZpZWxkLmFjLnVrMB4XDTE0\n\t\t\t\t\t\tMDkwMzA3MzI1MFoXDTI0MDgzMTA3MzI1MFowgZAxCzAJBgNVBAYTAkdCMRMwEQYD\n\t\t\t\t\t\tVQQIDApEZXJieXNoaXJlMRUwEwYDVQQHDAxDaGVzdGVyZmllbGQxHTAbBgNVBAoM\n\t\t\t\t\t\tFENoZXN0ZXJmaWVsZCBDb2xsZWdlMRUwEwYDVQQLDAxJQ1QgU2VydmljZXMxHzAd\n\t\t\t\t\t\tBgNVBAMMFmlkcC5jaGVzdGVyZmllbGQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUA\n\t\t\t\t\t\tA4IBDwAwggEKAoIBAQDQ4RgYUZeGBKe+Fhgtg9h00S6vTVBeD8923xUfwF53XKbu\n\t\t\t\t\t\tNvfQq3331N0ELndolFPFknRdJt0tfUxlpqa9GospV+JJ3tIv6MrpVbkOZyxPI5Fd\n\t\t\t\t\t\tJa1lc+5gkw/1S7k8dWJVlN1pcXrV9XBxIcANKsVZG0smM1H8cuenopMfCWC9PdNE\n\t\t\t\t\t\tTJzU/NvNthQizV4dEC5SP2/MVBUTvltN2JUq0/SjVl0GyKe4lHO6FVsKo5SlIEx/\n\t\t\t\t\t\tpUVCiyTufkaCf+PhULsOlgdGYd0NIT5pmnL58LRVbF9EqDKHeTcqJeSkfKTedwVN\n\t\t\t\t\t\twzvU3wtdh8c7Ub5oODs50Ec5ast+oyksmhCc5f0fAgMBAAGjezB5MAkGA1UdEwQC\n\t\t\t\t\t\tMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRl\n\t\t\t\t\t\tMB0GA1UdDgQWBBRwFnwr6pO2a5pd2/7uh8/ktJxREDAfBgNVHSMEGDAWgBRwFnwr\n\t\t\t\t\t\t6pO2a5pd2/7uh8/ktJxREDANBgkqhkiG9w0BAQUFAAOCAQEANhffi0UUOoXQPaPg\n\t\t\t\t\t\tayl8ylOUKb6ne6GyeE0qPiQG21JR+ndijGw9WkyVc62cvDJBrU9tXUhmxjdsd+Ro\n\t\t\t\t\t\tzyZvVHL+pQaym/nPu6XoNHdjed68b5vVc0d7ImDP2Pre3VgGdpfCxWCHVmC6kCG7\n\t\t\t\t\t\twRwnF/Le1YKLChloc++jgu0mSFozmws0xT8jHZC/Dl6+vERzgcVWY4raB6Z4qY19\n\t\t\t\t\t\t2GwOn1AMDj0vpiTWn7fvv9hivJLcJ45DLMG9ItiAQqaXsgmLGUrLsQPV/waJBcWn\n\t\t\t\t\t\tf78RSU1/IrqCyKLhCu0MpaqsNBW6vettZXLYfwS32SQXnLKdPRCsOpC/paeyfkpB\n\t\t\t\t\t\tTDscwQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Chesterfield College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.chesterfield.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Chesterfield College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://vmidgw3.miun.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 771 975 000"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "SystemDrift, IT-avdelningen, Mittuniversitetet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SystemDriftIT@miun.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Mid Sweden University"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 63 165787"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ove Olander"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Ove.Olander@miun.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Mid Sweden University"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 771 976130"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@miun.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Mid Sweden University"
          }
        }
      ],
      "entity_id": "https://vmidgw3.miun.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oasis:names:tc:SAML:attribute:assurance-certification",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUREnpvBXjmkHQJD0xn6joE9UTMyMwDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPdm1pZGd3My5taXVuLnNlMB4XDTExMTIzMDEwMjMyNVoX\nDTMxMTIzMDEwMjMyNVowGjEYMBYGA1UEAxMPdm1pZGd3My5taXVuLnNlMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAiJkrr5rb4DLITBdU0e/8/lBAnoQq\nBx/coeuJzCNP2EtRKCqTHB+v77geB+zzUZz2xDVmVjqMiO2/yCtZtI1hsK9nuPbV\nEZe1AuyQph31ud3r2ZkT/eS+xbmTyxAkMYSqrj55OC1Dfk0AYHGpS46q3JURD0A8\nOYOQb74IB1iC2+da3VKKjkbVlymdULN+o5Fg+zAzFymClSbPP3+Vu6D/65L2r1Bg\nDDgq9qtFGXdopNHnDU2eY+rTQEipa0EpVG7gv77Q1GFA2f5BCNTuW9AQOKnXTkbO\nhb1bXylESEvNL57+l8/8qdDEJmcvwJRHttVpSlWpTYQKMXK9J5kB3YIhUQIDAQAB\no2UwYzBCBgNVHREEOzA5gg92bWlkZ3czLm1pdW4uc2WGJmh0dHBzOi8vdm1pZGd3\nMy5taXVuLnNlL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRpUIa+z1bDfa7o0lKm\npwa034YZhTANBgkqhkiG9w0BAQUFAAOCAQEAfgyLe7dVQXULh4wAVhCVeUNv40En\nhW929W1K+Zgtz+77nG5lnck88G2yrs15inPABkoGm6SYSYkycYeI7SY1rPy0aSMF\nDWSZLLppL5N1mLxsK+vbF8h3zHWJza8SrxmLoWN6FvM+bYcQb/Peg6MVFpAm3xSp\nEyV0GjP3wM/Qt05Pf26yvZRVXDingJ1RWIOwtNlCag8X/9yG+ktTdSaG+ecqXlq4\nA+ZqGs14HCp2XO5VLdsp8g1i9cUEKgWjMdX8t8GNsYbEjLjAG/CtmNNgUDrEJ4qM\nI7yfePa+lbSSpUv1l32U1dXAI6n54O9jK+ZVGubhDe0PT1Y23j/HHPbZoQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "miun.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://vmidgw3.miun.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vmidgw3.miun.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://vmidgw3.miun.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vmidgw3.miun.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vmidgw3.miun.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vmidgw3.miun.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://vmidgw3.miun.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vmidgw3.miun.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "miun.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.miun.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.miun.se/en/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mittuniversitetet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mid Sweden University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r anst\u00e4llda och studenter hos Mittuniversitetet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Mid Sweden University Identity Provider, used by employees and students at Mid Sweden University"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.miun.se/imagevault/publishedmedia/x4bl7padufcm1j4td3d7/logo.png",
                    "lang": "sv",
                    "height": "111",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "225"
                  },
                  {
                    "text": "https://www.miun.se/imagevault/publishedmedia/x4bl7padufcm1j4td3d7/logo.png",
                    "lang": "en",
                    "height": "111",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "225"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.miun.se/sv/Helpdesk/Student/MittNets-regler/"
                  }
                ]
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "miun.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:63.176762,14.651352"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:62.394626,17.284259"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:62.630989,17.946473"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUREnpvBXjmkHQJD0xn6joE9UTMyMwDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPdm1pZGd3My5taXVuLnNlMB4XDTExMTIzMDEwMjMyNVoX\nDTMxMTIzMDEwMjMyNVowGjEYMBYGA1UEAxMPdm1pZGd3My5taXVuLnNlMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAiJkrr5rb4DLITBdU0e/8/lBAnoQq\nBx/coeuJzCNP2EtRKCqTHB+v77geB+zzUZz2xDVmVjqMiO2/yCtZtI1hsK9nuPbV\nEZe1AuyQph31ud3r2ZkT/eS+xbmTyxAkMYSqrj55OC1Dfk0AYHGpS46q3JURD0A8\nOYOQb74IB1iC2+da3VKKjkbVlymdULN+o5Fg+zAzFymClSbPP3+Vu6D/65L2r1Bg\nDDgq9qtFGXdopNHnDU2eY+rTQEipa0EpVG7gv77Q1GFA2f5BCNTuW9AQOKnXTkbO\nhb1bXylESEvNL57+l8/8qdDEJmcvwJRHttVpSlWpTYQKMXK9J5kB3YIhUQIDAQAB\no2UwYzBCBgNVHREEOzA5gg92bWlkZ3czLm1pdW4uc2WGJmh0dHBzOi8vdm1pZGd3\nMy5taXVuLnNlL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRpUIa+z1bDfa7o0lKm\npwa034YZhTANBgkqhkiG9w0BAQUFAAOCAQEAfgyLe7dVQXULh4wAVhCVeUNv40En\nhW929W1K+Zgtz+77nG5lnck88G2yrs15inPABkoGm6SYSYkycYeI7SY1rPy0aSMF\nDWSZLLppL5N1mLxsK+vbF8h3zHWJza8SrxmLoWN6FvM+bYcQb/Peg6MVFpAm3xSp\nEyV0GjP3wM/Qt05Pf26yvZRVXDingJ1RWIOwtNlCag8X/9yG+ktTdSaG+ecqXlq4\nA+ZqGs14HCp2XO5VLdsp8g1i9cUEKgWjMdX8t8GNsYbEjLjAG/CtmNNgUDrEJ4qM\nI7yfePa+lbSSpUv1l32U1dXAI6n54O9jK+ZVGubhDe0PT1Y23j/HHPbZoQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mittuniversitetet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mid Sweden University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.miun.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "MIUN"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://stg.reachoutcpd.com/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Munn"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dmunn@twig-world.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Munn"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dmunn@twig-world.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://stg.reachoutcpd.com/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-05T07:38:45Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ReachOutCPD"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://stg.reachoutcpd.com/about/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Twig World Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://stg.reachoutcpd.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://stg.reachoutcpd.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://stg.reachoutcpd.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://stg.reachoutcpd.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://stg.reachoutcpd.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://stg.reachoutcpd.com/Shibboleth.sso/Glow",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://stg.reachoutcpd.com/Shibboleth.sso/shibtest",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://stg.reachoutcpd.com/Shibboleth.sso/RMUnify",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://stg.reachoutcpd.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Online access to ReachOutCPD"
                  }
                ],
                "logo": [
                  {
                    "text": "https://stg.reachoutcpd.com/mdui-reachoutcpd-logo.png",
                    "height": "153",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "202"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ReachOutCPD"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIJAL30gKs3VPdtMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\n\t\t\t\t\t\tBAMTE3N0Zy5yZWFjaG91dGNwZC5jb20wHhcNMTUwNDI0MTQ1MTQzWhcNMjUwNDIx\n\t\t\t\t\t\tMTQ1MTQzWjAeMRwwGgYDVQQDExNzdGcucmVhY2hvdXRjcGQuY29tMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvj0x2RzQTuZLCehdtorr/NSEJRVIk1zu\n\t\t\t\t\t\t216Db++oC6OqUj2QY9Gk7DFxudlEfA2rtBn9qTAANKFCQTE7dlfB9HSFLIVPRq9O\n\t\t\t\t\t\t/XIIW2mBJbGBnEU76ihOm1K7MoR8YE335AGBX6aMGznjDtyejkmKtjUd0cfNMP4n\n\t\t\t\t\t\tpVfZruw4lfYsOuTyWNNciY0EeW7KWb48HPr+aPpPaCj3BULuJWz5/4MXJEv3+AHU\n\t\t\t\t\t\tCeaTSdqgK6GxvdSd0FZCx8uE/jY00/ao86Khlpo96lqyjPy3DTk2pXoZkyVRnRGe\n\t\t\t\t\t\tUuqTyki5JmwaiubzvJ9i/5A+sNmzsQ1GxIV+YNtIaJrYoI3fenfihQIDAQABo2ww\n\t\t\t\t\t\tajBJBgNVHREEQjBAghNzdGcucmVhY2hvdXRjcGQuY29thilodHRwczovL3N0Zy5y\n\t\t\t\t\t\tZWFjaG91dGNwZC5jb20vc2hpYmJvbGV0aC1zcDAdBgNVHQ4EFgQURlhEJi5fy+T6\n\t\t\t\t\t\tqLvKlrVDydUExfMwDQYJKoZIhvcNAQEFBQADggEBAHC2zHHbCiRpKFo6qW4iOR72\n\t\t\t\t\t\thriKJVKFAn2R6FjvPHiOX94DtigugA7fnJsiJFuV0k1dGmR49V+IvKHOGksEAR2S\n\t\t\t\t\t\teY1OJBIDTEHmqfkEIJMDv7/4VNYgfYkAoFARJMZKtSyKkbSK4LnAcqHsO3JPQObq\n\t\t\t\t\t\tRnGtYBkA5ueuPlBlZSOFpalruwW5a+xJfPX8ywpGNCR7x2Rg9+y2tIou0HMWSNnU\n\t\t\t\t\t\ttMZ4fmJjde6k1L39lWxloxotW2pn7EdExhBXSSHB7ZLxSh2Sw+jzVC3wVJExCDd9\n\t\t\t\t\t\tP4qiW5N5wrp2gPuwfYg5+XLezOQ9qGVeNKKJrCZu24pR6d/y/6D/5m/XsEXIxfU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://stg.reachoutcpd.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://stg.reachoutcpd.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://stg.reachoutcpd.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://stg.reachoutcpd.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://stg.reachoutcpd.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://stg.reachoutcpd.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://stg.reachoutcpd.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://stg.reachoutcpd.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://stg.reachoutcpd.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://stg.reachoutcpd.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth-idp.uni-goettingen.de/uni/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Adler"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dadler1@gwdg.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Daniel"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pohl"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cpohl@gwdg.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Christof"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth-idp.uni-goettingen.de/uni/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2014-02-14T07:54:13Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shibboleth-idp.uni-goettingen.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGMjCCBRqgAwIBAgIHGcwhSXcahzANBgkqhkiG9w0BAQsFADCBrjELMAkGA1UE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\nwDkP23Ru"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=shibboleth-idp.uni-goettingen.de,O=Georg-August-Universitaet Goettingen,L=Goettingen,ST=Niedersachsen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uni-goettingen.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth-idp.uni-goettingen.de:8443/uni/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-idp.uni-goettingen.de:8443/uni/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth-idp.uni-goettingen.de/uni/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth-idp.uni-goettingen.de/uni/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-idp.uni-goettingen.de:8443/uni/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth-idp.uni-goettingen.de/uni/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth-idp.uni-goettingen.de/uni/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth-idp.uni-goettingen.de/uni/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth-idp.uni-goettingen.de/uni/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth-idp.uni-goettingen.de:8443/uni/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-idp.uni-goettingen.de:8443/uni/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uni-goettingen.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uni-goettingen.de/de/1.html"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uni-goettingen.de/en/1.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Georg-August Universit\u00e4t G\u00f6ttingen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Georg-August University G\u00f6ttingen"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Georg-August Universit\u00e4t G\u00f6ttingen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Georg-August University G\u00f6ttingen"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.uni-goettingen.de/favicon.ico",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "19"
                  },
                  {
                    "text": "https://www.uni-goettingen.de/img/logo_druck.png",
                    "height": "98",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "126"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.uni-goettingen.de/de/439479.html"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.uni-goettingen.de/en/439479.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shibboleth-idp.uni-goettingen.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGMjCCBRqgAwIBAgIHGcwhSXcahzANBgkqhkiG9w0BAQsFADCBrjELMAkGA1UE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\nwDkP23Ru"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=shibboleth-idp.uni-goettingen.de,O=Georg-August-Universitaet Goettingen,L=Goettingen,ST=Niedersachsen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Georg-August-Universit\u00e4t G\u00f6ttingen"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Georg-August-Universit\u00e4t G\u00f6ttingen"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-goettingen.de/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-goettingen.de/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e281"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e281"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth-idp.ics.forth.gr/idp/shibboleth/",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@ics.forth.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Foundation for Research and Technology - Hellas"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@ics.forth.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Foundation for Research and Technology - Hellas"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+30-2810-391647"
            }
          ]
        }
      ],
      "entity_id": "https://shibboleth-idp.ics.forth.gr/idp/shibboleth/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIECTCCAvGgAwIBAgIJAIAFFNmTM96cMA0GCSqGSIb3DQEBBQUAMIGaMQswCQYD\n                            VQQGEwJHUjEOMAwGA1UECAwFQ3JldGUxEjAQBgNVBAcMCUhlcmFrbGlvbjEOMAwG\n                            A1UECgwFRk9SVEgxDDAKBgNVBAsMA0lDUzEkMCIGA1UEAwwbc2hpYmJvbGV0aC1p\n                            ZHAuaWNzLmZvcnRoLmdyMSMwIQYJKoZIhvcNAQkBFhRzdXBwb3J0QGljcy5mb3J0\n                            aC5ncjAeFw0xNTEwMDgxMDM5MjBaFw00MDEwMDExMDM5MjBaMIGaMQswCQYDVQQG\n                            EwJHUjEOMAwGA1UECAwFQ3JldGUxEjAQBgNVBAcMCUhlcmFrbGlvbjEOMAwGA1UE\n                            CgwFRk9SVEgxDDAKBgNVBAsMA0lDUzEkMCIGA1UEAwwbc2hpYmJvbGV0aC1pZHAu\n                            aWNzLmZvcnRoLmdyMSMwIQYJKoZIhvcNAQkBFhRzdXBwb3J0QGljcy5mb3J0aC5n\n                            cjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK44C09K73i6drwcyTYY\n                            yfUHRdNoecBGCKiEW4Nv3XPROKyJEpZeXcqNIjX9Ay5tCgXLI7pwVyD2zvmrw9J+\n                            Bh2zJUSez5icumO3kwoQd+5kt9vqusHCs168ttlcSQ7ulWReSU0geS+uQ7uY2MOw\n                            m1dCSZJ8lBX3l13AZ/KIm2+Q/zt6FDy42ZliosWoi+HBns7W3PzpjSWtfpq+scyd\n                            7jAu8y/pyYoWUK6FCp2CuRSHl4DPzMKcUXdbmN0WsjZVPmnRCedXqXpfu21DRJRK\n                            aI47OJ2E29XqqqiLozbwSsex9sOy8rDyqkwXF5jxfRsTBZTCuT3pOiFnfUJQCeI9\n                            0PUCAwEAAaNQME4wHQYDVR0OBBYEFB0BaUQoT2qrSl67KfbiuzComuW2MB8GA1Ud\n                            IwQYMBaAFB0BaUQoT2qrSl67KfbiuzComuW2MAwGA1UdEwQFMAMBAf8wDQYJKoZI\n                            hvcNAQEFBQADggEBAIQfZ8sg/vT2r3FBaF79wUN5Y0IzvsAhBGcswiljzOJDxOn/\n                            xFLgUjhmpwW7Mo8siDR5RVg0ANRw5nMdvG05SkhJsuzKgQkweQin3NflNR5U5ZOe\n                            3oOM7gMvSP0OR6e1o7PdTU9QnDiWrB760lwUf1ny86dUooNZ0VZNo/CU+2IB6dnQ\n                            K3H7c0cMoWoMFolzhsAxg/HZvv0igIMAJ83Nj0ktzpxJR4s9vSTL+RTVHL3vRVjG\n                            mXvUT48DDF48hmWDN9rh1aApoBf+OvrVGfeaazdMrK/ho6xts+kbJdCumfGx5cyP\n                            AXf1z42E/mE/ELURJf75+xO8AShPK4Ua/5qsbnM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "forth.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ics.forth.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iesl.forth.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "imbb.forth.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iacm.forth.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iceht.forth.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "admin.forth.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pek.forth.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ims.forth.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth-idp.ics.forth.gr:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-idp.ics.forth.gr:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth-idp.ics.forth.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth-idp.ics.forth.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth-idp.ics.forth.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth-idp.ics.forth.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth-idp.ics.forth.gr:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-idp.ics.forth.gr:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "forth.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ics.forth.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iesl.forth.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "imbb.forth.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iacm.forth.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iceht.forth.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "admin.forth.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pek.forth.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ims.forth.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIECTCCAvGgAwIBAgIJAIAFFNmTM96cMA0GCSqGSIb3DQEBBQUAMIGaMQswCQYD\n                            VQQGEwJHUjEOMAwGA1UECAwFQ3JldGUxEjAQBgNVBAcMCUhlcmFrbGlvbjEOMAwG\n                            A1UECgwFRk9SVEgxDDAKBgNVBAsMA0lDUzEkMCIGA1UEAwwbc2hpYmJvbGV0aC1p\n                            ZHAuaWNzLmZvcnRoLmdyMSMwIQYJKoZIhvcNAQkBFhRzdXBwb3J0QGljcy5mb3J0\n                            aC5ncjAeFw0xNTEwMDgxMDM5MjBaFw00MDEwMDExMDM5MjBaMIGaMQswCQYDVQQG\n                            EwJHUjEOMAwGA1UECAwFQ3JldGUxEjAQBgNVBAcMCUhlcmFrbGlvbjEOMAwGA1UE\n                            CgwFRk9SVEgxDDAKBgNVBAsMA0lDUzEkMCIGA1UEAwwbc2hpYmJvbGV0aC1pZHAu\n                            aWNzLmZvcnRoLmdyMSMwIQYJKoZIhvcNAQkBFhRzdXBwb3J0QGljcy5mb3J0aC5n\n                            cjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK44C09K73i6drwcyTYY\n                            yfUHRdNoecBGCKiEW4Nv3XPROKyJEpZeXcqNIjX9Ay5tCgXLI7pwVyD2zvmrw9J+\n                            Bh2zJUSez5icumO3kwoQd+5kt9vqusHCs168ttlcSQ7ulWReSU0geS+uQ7uY2MOw\n                            m1dCSZJ8lBX3l13AZ/KIm2+Q/zt6FDy42ZliosWoi+HBns7W3PzpjSWtfpq+scyd\n                            7jAu8y/pyYoWUK6FCp2CuRSHl4DPzMKcUXdbmN0WsjZVPmnRCedXqXpfu21DRJRK\n                            aI47OJ2E29XqqqiLozbwSsex9sOy8rDyqkwXF5jxfRsTBZTCuT3pOiFnfUJQCeI9\n                            0PUCAwEAAaNQME4wHQYDVR0OBBYEFB0BaUQoT2qrSl67KfbiuzComuW2MB8GA1Ud\n                            IwQYMBaAFB0BaUQoT2qrSl67KfbiuzComuW2MAwGA1UdEwQFMAMBAf8wDQYJKoZI\n                            hvcNAQEFBQADggEBAIQfZ8sg/vT2r3FBaF79wUN5Y0IzvsAhBGcswiljzOJDxOn/\n                            xFLgUjhmpwW7Mo8siDR5RVg0ANRw5nMdvG05SkhJsuzKgQkweQin3NflNR5U5ZOe\n                            3oOM7gMvSP0OR6e1o7PdTU9QnDiWrB760lwUf1ny86dUooNZ0VZNo/CU+2IB6dnQ\n                            K3H7c0cMoWoMFolzhsAxg/HZvv0igIMAJ83Nj0ktzpxJR4s9vSTL+RTVHL3vRVjG\n                            mXvUT48DDF48hmWDN9rh1aApoBf+OvrVGfeaazdMrK/ho6xts+kbJdCumfGx5cyP\n                            AXf1z42E/mE/ELURJf75+xO8AShPK4Ua/5qsbnM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Foundation for Research and Technology - Hellas"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u038a\u03b4\u03c1\u03c5\u03bc\u03b1 \u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03af\u03b1\u03c2 \u03ba\u03b1\u03b9 \u0388\u03c1\u03b5\u03c5\u03bd\u03b1\u03c2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.forth.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.forth.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Foundation for Research and Technology - Hellas"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u038a\u03b4\u03c1\u03c5\u03bc\u03b1 \u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03af\u03b1\u03c2 \u03ba\u03b1\u03b9 \u0388\u03c1\u03b5\u03c5\u03bd\u03b1\u03c2"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://uat.v-scene.ja.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:vidconf@jvcs.ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "v-scene Service Management Centre"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:vidconf@jvcs.ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "v-scene Service Management Centre"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://uat.v-scene.ja.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-05-26T10:19:59Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "v-scene"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.ja.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "JISC Collections and Janet Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://v-scene.ja.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "authn_requests_signed": "1",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://v-scene.ja.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://v-scene.ja.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEbjCCA1agAwIBAgIRAPLs2fw5NrHY6vHiBUWhWeIwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xNDA1MTYwMDAwMDBaFw0xNzA1MTUyMzU5NTlaMD4xITAfBgNV\n\t\t\t\t\t\tBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEZMBcGA1UEAxQQKi52LXNjZW5l\n\t\t\t\t\t\tLmphLm5ldDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMimqOow4OSM\n\t\t\t\t\t\tcGivrxkXeSBOTQOp/jxDWV/Fgm9Q+jXCsHuLRzsi9luGrpglU/avF+HM55AuFb5z\n\t\t\t\t\t\tI8O+H6k/+tMNoeJvcz8J8OiMo4Qul3CL61TjfyFElDwXY2ROJNAkS6vv5w92BTqx\n\t\t\t\t\t\th/u7UH6szFdUVK9ld980v5Sht4+YLlk0csTmtTJWAojm/kHVyM6uddr5rQrlfu9Y\n\t\t\t\t\t\tomKaSVw8DGaQjfQ2x+FXHLOWQZ/NAHJiIRQ40D4UNxCw/dYxPUsfEToBZ/JShf+o\n\t\t\t\t\t\tDXz2pMB4H0QzycPFLOICRISka0gO1wNWsGakAUn4uM6s1yfzDlyT5YM6+ycUo1jx\n\t\t\t\t\t\t9NfQi1GaqjMCAwEAAaOCAW0wggFpMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdX\n\t\t\t\t\t\tR+qQ47ntMB0GA1UdDgQWBBRISYDi3KrE1GaRx9MSCk+rgDVAcTAOBgNVHQ8BAf8E\n\t\t\t\t\t\tBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUH\n\t\t\t\t\t\tAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0fBDMw\n\t\t\t\t\t\tMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5j\n\t\t\t\t\t\tcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50\n\t\t\t\t\t\tZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29j\n\t\t\t\t\t\tc3AudGNzLnRlcmVuYS5vcmcwGwYDVR0RBBQwEoIQKi52LXNjZW5lLmphLm5ldDAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAcYIsGziwQ3v/twTh1kk3+Dhs1+kFvsZeTlQS4GTk\n\t\t\t\t\t\tpkaE8RM8ELEx82PgQjuX2uUTxpfmopxst8FQ2eT/TAyh224EAoRkY2ODUru6Twzb\n\t\t\t\t\t\tNmsBnIJtA0QWikK7P7i9sf1OGZJHCeKOxHHSsg6Z/mw1DGc420vUbA5KeZwRlVnk\n\t\t\t\t\t\tX8Y8QEbGX7Ee0pvRVCURIBEuioQLUkMW1uJu4wwjBnGjRScSzgOXPQDY2q0+gYRt\n\t\t\t\t\t\t3U0pLrCAHTghWhbyfXiqeijWivQ/0Jz5aiRX8738f5L/LN/fqGe0xFQaZoCeeSc/\n\t\t\t\t\t\t8dBRNpkZmtznEg7VKwGKeYuntpvomaA18BEpsQZjgZMHNA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://v-scene.ja.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol"
        }
      ]
    }
  ],
  [
    "https://registration.dariah.eu/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Haase"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:martin.haase@daasi.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Haase"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:martin.haase@daasi.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Haase"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:martin.haase@daasi.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://registration.dariah.eu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2014-05-15T11:08:13Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Gesellschaft f\u00fcr wissenschaftliche Datenverarbeitung mbH"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Gesellschaft f\u00fcr wissenschaftliche Datenverarbeitung mbH"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gwdg.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gwdg.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e112"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e112"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ldap-dariah.esc.rzg.mpg.de/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ldap-dariah.esc.rzg.mpg.de/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ldap-dariah.esc.rzg.mpg.de/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ldap-dariah.esc.rzg.mpg.de/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ldap-dariah.esc.rzg.mpg.de/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://dariah.eu/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://dariah.eu/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DARIAH Registration"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DARIAH Registration"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Service zum Registrieren fremder Accounts in der DARIAH Attribute Authority zum Zweck der Autorisierung an Dariah Services"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Service for Registration of Campus Accounts in the DARIAH Attribute Authority in order to enable Authorization for DARIAH Services"
                  }
                ],
                "logo": [
                  {
                    "text": "https://ldap-dariah.esc.rzg.mpg.de/images/DARIAH_flower_icon.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://ldap-dariah.esc.rzg.mpg.de/images/DARIAH_flower.png",
                    "height": "154",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "160"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://de.dariah.eu/ServicePrivacyPolicy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ldap-dariah.esc.rzg.mpg.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFEDCCA/igAwIBAgIHEy5eQihwbDANBgkqhkiG9w0BAQUFADBeMQswCQYDVQQG\nEwJERTEgMB4GA1UEChMXTWF4LVBsYW5jay1HZXNlbGxzY2hhZnQxDzANBgNVBAMT\nBk1QRyBDQTEcMBoGCSqGSIb3DQEJARYNbXBnLWNhQG1wZy5kZTAeFw0xMjAxMTIx\nMzMxMzFaFw0xNzAxMTAxMzMxMzFaMHsxCzAJBgNVBAYTAkRFMSAwHgYDVQQKExdN\nYXgtUGxhbmNrLUdlc2VsbHNjaGFmdDElMCMGA1UECxMcUmVjaGVuemVudHJ1bSBH\nYXJjaGluZyAoUlpHKTEjMCEGA1UEAxMabGRhcC1kYXJpYWguZXNjLnJ6Zy5tcGcu\nZGUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDbyc9BVBglxQEt8MmI\ncbf3GKqCdQADGnnNXAwx9gjq5mQI2+VNGcBk8aq24p5a++hlemue+6P6RQONiv5z\nsAXlIZb6MuGOcF6gOUqRijMuWW1OueysiO4F5ODOJ8TaGSjWytCSQ28cpJbc7wWo\nmnlZxL6NvVyRiDCJuUfDyIW8ICgk7Aw1K0UdpJXeVzFUiBtTIM7Ira80o3yeLDhi\nDDPc+swDZA9syWvn8/W57kN0/vtUYKzGs6Ae+uRxahSfNg/kx1Rnv0sUln1hgUHh\nVuiKqu1MlAIcckNt00Ck/v7LQV98KJJx+rWWPV1F09a6vPEAesEY+GnJQkwAzh/O\nxiTjAgMBAAGjggG0MIIBsDAJBgNVHRMEAjAAMAsGA1UdDwQEAwIF4DAdBgNVHSUE\nFjAUBggrBgEFBQcDAgYIKwYBBQUHAwEwHQYDVR0OBBYEFEnnIPu9e2M7ABKF66CA\nuTWv1Jf8MB8GA1UdIwQYMBaAFALWHm4Jq79YZacKPEgzYdHOfcNbMCkGA1UdEQQi\nMCCBHnNlcnZlci1jZXJ0aWZpY2F0ZXNAcnpnLm1wZy5kZTB3BgNVHR8EcDBuMDWg\nM6Axhi9odHRwOi8vY2RwMS5wY2EuZGZuLmRlL21wZy1jYS9wdWIvY3JsL2NhY3Js\nLmNybDA1oDOgMYYvaHR0cDovL2NkcDIucGNhLmRmbi5kZS9tcGctY2EvcHViL2Ny\nbC9jYWNybC5jcmwwgZIGCCsGAQUFBwEBBIGFMIGCMD8GCCsGAQUFBzAChjNodHRw\nOi8vY2RwMS5wY2EuZGZuLmRlL21wZy1jYS9wdWIvY2FjZXJ0L2NhY2VydC5jcnQw\nPwYIKwYBBQUHMAKGM2h0dHA6Ly9jZHAyLnBjYS5kZm4uZGUvbXBnLWNhL3B1Yi9j\nYWNlcnQvY2FjZXJ0LmNydDANBgkqhkiG9w0BAQUFAAOCAQEAxDSpJ7Mn2hmiyDzK\nVVtARi1U9EvfTcSIWZFanc1xn9DaFI8s3c6vnEB7+BL/HMbAwnDauWjUPoNzc5I2\nTeH5IjX8MGDjEh7TyNyycWRNJ88ah0LtQoaCgXc0vpTtXZzGelh0A25Hw80sHKa1\nxY4iDAPYwaPY+kFxxAGyeAL9M4q9Z39t6ZIoze+lQm0sxQ3eTvQUPwukAeI9xOzb\nKsbO/Q7VBdzaH75dVrc+dSQqXy1bOQUAext9foXlso8ECt0b1vQVdspe5tQ1+y3u\naDG4T0gWjN5P3enk6TN3v4V9UaBA4J1DkBCxC/RNFnNZc22GqQ1Bbf9rKXjyXECp\nq1AZvg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ldap-dariah.esc.rzg.mpg.de,OU=Rechenzentrum Garching (RZG),O=Max-Planck-Gesellschaft,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ldap-dariah.esc.rzg.mpg.de/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ldap-dariah.esc.rzg.mpg.de/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ldap-dariah.esc.rzg.mpg.de/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ldap-dariah.esc.rzg.mpg.de/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ldap-dariah.esc.rzg.mpg.de/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ldap-dariah.esc.rzg.mpg.de/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "DARIAH Registration"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "DARIAH Registration"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Service zum Registrieren fremder Accounts in der DARIAH Attribute Authority zum Zweck der Autorisierung an Dariah Services"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Service for Registration of Campus Accounts in the DARIAH Attribute Authority in order to enable Authorization for DARIAH Services"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "o",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://webanno.sfs.uni-tuebingen.de",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hinrichs"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:wladmin@sfs.uni-tuebingen.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marie"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hinrichs"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:wladmin@sfs.uni-tuebingen.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marie"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hinrichs"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:wladmin@sfs.uni-tuebingen.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marie"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://webanno.sfs.uni-tuebingen.de",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2016-03-22T22:32:44Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://clarin.eu/category/clarin-member"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://webanno.sfs.uni-tuebingen.de/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://webanno.sfs.uni-tuebingen.de/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webanno.sfs.uni-tuebingen.de/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://webanno.sfs.uni-tuebingen.de/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://webanno.sfs.uni-tuebingen.de/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://webanno.sfs.uni-tuebingen.de/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CLARIN WebAnno"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CLARIN WebAnno"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "WebAnno ist ein webbasiertes Allzweck-Werkzeug f\u00fcr linguistische Anmerkungen."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "WebAnno is a general purpose web-based linguistic annotation tool."
                  }
                ],
                "logo": [
                  {
                    "text": "https://webanno.github.io/webanno/assets/img/logo.png",
                    "height": "128",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "128"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://weblicht.sfs.uni-tuebingen.de/weblichtwiki/index.php/WebLicht_Privacy_Policy_Document"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "weblicht.sfs.uni-tuebingen.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGKzCCBROgAwIBAgIHF3iUXPRQADANBgkqhkiG9w0BAQUFADB3MQswCQYDVQQG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"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=wladmin@sfs.uni-tuebingen.de,CN=weblicht.sfs.uni-tuebingen.de,OU=SfS,O=Universitaet Tuebingen,L=Tuebingen,ST=Baden-Wuerttemberg,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webanno.sfs.uni-tuebingen.de/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://webanno.sfs.uni-tuebingen.de/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CLARIN WebAnno"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CLARIN WebAnno"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "WebAnno ist ein webbasiertes Allzweck-Werkzeug f\u00fcr linguistische Anmerkungen."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "WebAnno is a general purpose web-based linguistic annotation tool."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://krad.cityplym.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@cityplym.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itservices@cityplym.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Services"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://krad.cityplym.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVAMOc1kqMl4mYFgYDAXyXKjoH9obQMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCQxIjAgBgNVBAMTGXNoaWJib2xldGguY2l0eXBseW0uYWMudWswHhcNMTEw\n\t\t\t\t\t\tNjE3MTEzNjUwWhcNMzEwNjE3MTEzNjUwWjAkMSIwIAYDVQQDExlzaGliYm9sZXRo\n\t\t\t\t\t\tLmNpdHlwbHltLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tnET5Mc3Z+5IC8b2KhU2EyWVau8c/sMwNos2wAWwQGJWVq70ZFnPAKWMjmVYx37TC\n\t\t\t\t\t\tDJk0uMtZHBWqNcHRooNqHXy3yVVhve+Sc03YCQ6VwAfJJXFkjgCaL274mLLADIhF\n\t\t\t\t\t\t/UV86AJ48yq7x/4LNtKZA1U86uJvTOT41TkJkPNix1H7IT0ssevZHOgV/jdKJw+T\n\t\t\t\t\t\tFixUsccDdv5+RxRfM24gx7vQ2IGIpYRsISgAtejbtpO/PKNSunqgjjbWE8QB0+UE\n\t\t\t\t\t\tAyGjAEXq1t6HJ6yjLrRR6YAMkfHHpjU1sNBICv5ambVVXX8iS9EzTat9O4cSCU6B\n\t\t\t\t\t\tlklM7JQ0schSt+CQZd9iHwIDAQABo3kwdzBWBgNVHREETzBNghlzaGliYm9sZXRo\n\t\t\t\t\t\tLmNpdHlwbHltLmFjLnVrhjBodHRwczovL3NoaWJib2xldGguY2l0eXBseW0uYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFLwDRVMVjMMG9ZF7cH13znMifPUP\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQCXpJ+3D+ONPxEb/+WhbIHTFFZNYyWK01l4q4Jq\n\t\t\t\t\t\tX3tDpd6vAFvcKr/wqj1UZ6YeXi1MvQpStlNrOnF7ASsQlKIQ167PrcZu6W3mlkiZ\n\t\t\t\t\t\t8WZQ4AGsRuoCxywamNK0tXkdd9Dz1lDwzrkwE/g1GGHg6c/9YFQb2MUjm+6kqvQ8\n\t\t\t\t\t\tiqFQFpdPj9VNUgXt5+3bPeaOluJnAOE9T3IQv8+0MQp+mJ9M+3dChHotIgiXqCuh\n\t\t\t\t\t\tKZ8R8jX4oT44/g+blazA+IP5Jz7/i28JHHdwdq7YXZ13eLezyVV3UI+ldTRvPx8k\n\t\t\t\t\t\t6kGOv0JdsjheocsdY7/KuT0E+oqGEMvnZbXRlF8UKvgxgUgE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cityplym.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.cityplym.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.cityplym.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.cityplym.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.cityplym.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.cityplym.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.cityplym.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.cityplym.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.cityplym.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cityplym.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVAMOc1kqMl4mYFgYDAXyXKjoH9obQMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCQxIjAgBgNVBAMTGXNoaWJib2xldGguY2l0eXBseW0uYWMudWswHhcNMTEw\n\t\t\t\t\t\tNjE3MTEzNjUwWhcNMzEwNjE3MTEzNjUwWjAkMSIwIAYDVQQDExlzaGliYm9sZXRo\n\t\t\t\t\t\tLmNpdHlwbHltLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tnET5Mc3Z+5IC8b2KhU2EyWVau8c/sMwNos2wAWwQGJWVq70ZFnPAKWMjmVYx37TC\n\t\t\t\t\t\tDJk0uMtZHBWqNcHRooNqHXy3yVVhve+Sc03YCQ6VwAfJJXFkjgCaL274mLLADIhF\n\t\t\t\t\t\t/UV86AJ48yq7x/4LNtKZA1U86uJvTOT41TkJkPNix1H7IT0ssevZHOgV/jdKJw+T\n\t\t\t\t\t\tFixUsccDdv5+RxRfM24gx7vQ2IGIpYRsISgAtejbtpO/PKNSunqgjjbWE8QB0+UE\n\t\t\t\t\t\tAyGjAEXq1t6HJ6yjLrRR6YAMkfHHpjU1sNBICv5ambVVXX8iS9EzTat9O4cSCU6B\n\t\t\t\t\t\tlklM7JQ0schSt+CQZd9iHwIDAQABo3kwdzBWBgNVHREETzBNghlzaGliYm9sZXRo\n\t\t\t\t\t\tLmNpdHlwbHltLmFjLnVrhjBodHRwczovL3NoaWJib2xldGguY2l0eXBseW0uYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFLwDRVMVjMMG9ZF7cH13znMifPUP\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQCXpJ+3D+ONPxEb/+WhbIHTFFZNYyWK01l4q4Jq\n\t\t\t\t\t\tX3tDpd6vAFvcKr/wqj1UZ6YeXi1MvQpStlNrOnF7ASsQlKIQ167PrcZu6W3mlkiZ\n\t\t\t\t\t\t8WZQ4AGsRuoCxywamNK0tXkdd9Dz1lDwzrkwE/g1GGHg6c/9YFQb2MUjm+6kqvQ8\n\t\t\t\t\t\tiqFQFpdPj9VNUgXt5+3bPeaOluJnAOE9T3IQv8+0MQp+mJ9M+3dChHotIgiXqCuh\n\t\t\t\t\t\tKZ8R8jX4oT44/g+blazA+IP5Jz7/i28JHHdwdq7YXZ13eLezyVV3UI+ldTRvPx8k\n\t\t\t\t\t\t6kGOv0JdsjheocsdY7/KuT0E+oqGEMvnZbXRlF8UKvgxgUgE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "City College Plymouth"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cityplym.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "City College Plymouth"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://iif.iucc.ac.il/idp/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@iif.iucc.ac.il"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://iif.iucc.ac.il/idp/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://iif.iucc.ac.il/wordpress/wp-content/uploads/2014/06/IIF-Policy.pdf"
              }
            ],
            "registration_instant": "2008-01-17T11:28:03Z",
            "registration_authority": "http://iif.iucc.ac.il",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://iif.iucc.ac.il/idp/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://iif.iucc.ac.il/idp/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Inter University Computation Center"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IUCC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iucc.ac.il"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IUCC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://biggus.nesc.gla.ac.uk/simplesaml/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Watt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:John.Watt@glasgow.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Watt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:John.Watt@glasgow.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://biggus.nesc.gla.ac.uk/simplesaml/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-11-12T11:54:55Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NeSC SimpleSAML Test SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gla.ac.uk/escience/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Glasgow"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://biggus.nesc.gla.ac.uk/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "A test SP running simpleSAMLPHP for federated access to NeSC PHP web applications"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.nesc.gla.ac.uk:8444/nescgla.gif",
                    "height": "168",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "190"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NeSC SimpleSAML Test SP Organisation"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEGDCCAwCgAwIBAgIJAL6/1HPmy0WjMA0GCSqGSIb3DQEBBQUAMIGMMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjERMA8GA1UECBMIU2NvdGxhbmQxEDAOBgNVBAcTB0dsYXNnb3cxHjAc\n\t\t\t\t\t\tBgNVBAoTFVVuaXZlcnNpdHkgb2YgR2xhc2dvdzEYMBYGA1UECxMPVHJ1c3RGYWJy\n\t\t\t\t\t\taWNDZXJ0MR4wHAYDVQQDExViaWdndXMubmVzYy5nbGEuYWMudWswHhcNMTMxMTA0\n\t\t\t\t\t\tMTI1NDM2WhcNMjMxMTAyMTI1NDM2WjCBjDELMAkGA1UEBhMCR0IxETAPBgNVBAgT\n\t\t\t\t\t\tCFNjb3RsYW5kMRAwDgYDVQQHEwdHbGFzZ293MR4wHAYDVQQKExVVbml2ZXJzaXR5\n\t\t\t\t\t\tIG9mIEdsYXNnb3cxGDAWBgNVBAsTD1RydXN0RmFicmljQ2VydDEeMBwGA1UEAxMV\n\t\t\t\t\t\tYmlnZ3VzLm5lc2MuZ2xhLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAqUmwvEs1PilqD3m3tY2ewYnYnLs8M02nXdP0J5SsKsUhvzLnXlpwd3lu\n\t\t\t\t\t\ttUpuwlmw9rPSt25hQYwuZvrmSAgYjevC1theXq+E2zT/VDtXQCPcMRkrfSuj0vj0\n\t\t\t\t\t\twk8M+eWFT5+DLvna24t4BhPYPc9bT00I7LtOg0FNulDxigvtlOfktepG41rQ2czA\n\t\t\t\t\t\t6qtkjtSGuE4BgbH485hQyJCT4JSLuBPT8K0B3rYRe6nqknsm+H+ohCWlzKXKaI6w\n\t\t\t\t\t\t6BuZS91oPne5WczzOk7lkPgPcmzgAhTYujvOkLl7HvX/lX00CvOtRZn6TzY5i5eH\n\t\t\t\t\t\tyvJdqvgmOrcn1aWoYeC5AyHdItOZkQIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCG\n\t\t\t\t\t\tSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4E\n\t\t\t\t\t\tFgQUA8gR9hvw83GQ8eYi0y7ulT0D05MwHwYDVR0jBBgwFoAUA8gR9hvw83GQ8eYi\n\t\t\t\t\t\t0y7ulT0D05MwDQYJKoZIhvcNAQEFBQADggEBAACtN3u83nptnsMlUsA3VwF4huER\n\t\t\t\t\t\tEbn1szPGSdAmVYh9xikyfk6KIav+lUywT3AcyX3Zz2EZu8Sg4cyNut01wbXSLu8E\n\t\t\t\t\t\t69YVmwrjMQC9AxLS73P0vKExPUpNuiDc8RbC4bHz6cGHptSknfSeByXJ59wAday3\n\t\t\t\t\t\tMNA0XQ2qk4zkCDMCU44CT99RBS3rC2HzTXGH2ChZD1LrMontBD2w3wXKxQ1rwAZq\n\t\t\t\t\t\tuj2C2OONhg723em0w0L8zSf9NAg4e+IcWHyJxWeGTldm+20qUTEltukkf72BR6MT\n\t\t\t\t\t\tF8ADSfyH6PnaKgq+jDPKxnTqU8h9Cfw3e/ICV8V+ErNlzXPsA9gkTnGtoPQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEGDCCAwCgAwIBAgIJAL6/1HPmy0WjMA0GCSqGSIb3DQEBBQUAMIGMMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjERMA8GA1UECBMIU2NvdGxhbmQxEDAOBgNVBAcTB0dsYXNnb3cxHjAc\n\t\t\t\t\t\tBgNVBAoTFVVuaXZlcnNpdHkgb2YgR2xhc2dvdzEYMBYGA1UECxMPVHJ1c3RGYWJy\n\t\t\t\t\t\taWNDZXJ0MR4wHAYDVQQDExViaWdndXMubmVzYy5nbGEuYWMudWswHhcNMTMxMTA0\n\t\t\t\t\t\tMTI1NDM2WhcNMjMxMTAyMTI1NDM2WjCBjDELMAkGA1UEBhMCR0IxETAPBgNVBAgT\n\t\t\t\t\t\tCFNjb3RsYW5kMRAwDgYDVQQHEwdHbGFzZ293MR4wHAYDVQQKExVVbml2ZXJzaXR5\n\t\t\t\t\t\tIG9mIEdsYXNnb3cxGDAWBgNVBAsTD1RydXN0RmFicmljQ2VydDEeMBwGA1UEAxMV\n\t\t\t\t\t\tYmlnZ3VzLm5lc2MuZ2xhLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAqUmwvEs1PilqD3m3tY2ewYnYnLs8M02nXdP0J5SsKsUhvzLnXlpwd3lu\n\t\t\t\t\t\ttUpuwlmw9rPSt25hQYwuZvrmSAgYjevC1theXq+E2zT/VDtXQCPcMRkrfSuj0vj0\n\t\t\t\t\t\twk8M+eWFT5+DLvna24t4BhPYPc9bT00I7LtOg0FNulDxigvtlOfktepG41rQ2czA\n\t\t\t\t\t\t6qtkjtSGuE4BgbH485hQyJCT4JSLuBPT8K0B3rYRe6nqknsm+H+ohCWlzKXKaI6w\n\t\t\t\t\t\t6BuZS91oPne5WczzOk7lkPgPcmzgAhTYujvOkLl7HvX/lX00CvOtRZn6TzY5i5eH\n\t\t\t\t\t\tyvJdqvgmOrcn1aWoYeC5AyHdItOZkQIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCG\n\t\t\t\t\t\tSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4E\n\t\t\t\t\t\tFgQUA8gR9hvw83GQ8eYi0y7ulT0D05MwHwYDVR0jBBgwFoAUA8gR9hvw83GQ8eYi\n\t\t\t\t\t\t0y7ulT0D05MwDQYJKoZIhvcNAQEFBQADggEBAACtN3u83nptnsMlUsA3VwF4huER\n\t\t\t\t\t\tEbn1szPGSdAmVYh9xikyfk6KIav+lUywT3AcyX3Zz2EZu8Sg4cyNut01wbXSLu8E\n\t\t\t\t\t\t69YVmwrjMQC9AxLS73P0vKExPUpNuiDc8RbC4bHz6cGHptSknfSeByXJ59wAday3\n\t\t\t\t\t\tMNA0XQ2qk4zkCDMCU44CT99RBS3rC2HzTXGH2ChZD1LrMontBD2w3wXKxQ1rwAZq\n\t\t\t\t\t\tuj2C2OONhg723em0w0L8zSf9NAg4e+IcWHyJxWeGTldm+20qUTEltukkf72BR6MT\n\t\t\t\t\t\tF8ADSfyH6PnaKgq+jDPKxnTqU8h9Cfw3e/ICV8V+ErNlzXPsA9gkTnGtoPQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://biggus.nesc.gla.ac.uk/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://biggus.nesc.gla.ac.uk/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://biggus.nesc.gla.ac.uk/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://biggus.nesc.gla.ac.uk/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.selby.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pilling"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pillingm@selby.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pilling"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pillingm@selby.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.selby.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-01-18T11:19:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFKzCCBBOgAwIBAgIJAIGAdYhCdXOTMA0GCSqGSIb3DQEBBQUAMIGwMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEYMBYGA1UECBMPTm9ydGggWW9ya3NoaXJlMQ4wDAYDVQQHEwVTZWxi\n\t\t\t\t\t\teTEWMBQGA1UEChMNU2VsYnkgQ29sbGVnZTEZMBcGA1UECxMQTmV0d29yayBTZXJ2\n\t\t\t\t\t\taWNlczEfMB0GA1UEAxMWc2hpYmJvbGV0aC5zZWxieS5hYy51azEjMCEGCSqGSIb3\n\t\t\t\t\t\tDQEJARYUcGlsbGluZ21Ac2VsYnkuYWMudWswHhcNMTMxMDI5MDkzNjA4WhcNMjMx\n\t\t\t\t\t\tMDI3MDkzNjA4WjCBsDELMAkGA1UEBhMCR0IxGDAWBgNVBAgTD05vcnRoIFlvcmtz\n\t\t\t\t\t\taGlyZTEOMAwGA1UEBxMFU2VsYnkxFjAUBgNVBAoTDVNlbGJ5IENvbGxlZ2UxGTAX\n\t\t\t\t\t\tBgNVBAsTEE5ldHdvcmsgU2VydmljZXMxHzAdBgNVBAMTFnNoaWJib2xldGguc2Vs\n\t\t\t\t\t\tYnkuYWMudWsxIzAhBgkqhkiG9w0BCQEWFHBpbGxpbmdtQHNlbGJ5LmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0WCeQdUOOwr1zgrswrslHE0L\n\t\t\t\t\t\tUIN97PbpESv/ash874+27SUiJ4xff+OCrmTD/bleiWTwe2gS629blM8ehj7WMI4i\n\t\t\t\t\t\tQvor3Kx13jDsb7rp2TF/G3rFhCwvl6PyDJGUzdKWxKMxyaNRaAI6KmKwFNeUGnTO\n\t\t\t\t\t\tl9f4tXZvuZlvGOmERxmArpIq4R7sMU+ORooIQxDtGriEd/OD9ILPBv7sI0ahY03h\n\t\t\t\t\t\tuLcUpk/INWDdwxS1gxAB7tkpbg7P5ZCczYPEHY0LLSh4G3sQ7dGJULKzj4CwWODS\n\t\t\t\t\t\tNo+XLXpRBg86gE8ijvyMm9znVjoh2jH2izn5pvc61GALEKbDeJnM9dtqG0wrVQID\n\t\t\t\t\t\tAQABo4IBRDCCAUAwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBH\n\t\t\t\t\t\tZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFBe4qAGMntqL06Msf5ZbMHGk\n\t\t\t\t\t\tPpp9MIHlBgNVHSMEgd0wgdqAFBe4qAGMntqL06Msf5ZbMHGkPpp9oYG2pIGzMIGw\n\t\t\t\t\t\tMQswCQYDVQQGEwJHQjEYMBYGA1UECBMPTm9ydGggWW9ya3NoaXJlMQ4wDAYDVQQH\n\t\t\t\t\t\tEwVTZWxieTEWMBQGA1UEChMNU2VsYnkgQ29sbGVnZTEZMBcGA1UECxMQTmV0d29y\n\t\t\t\t\t\tayBTZXJ2aWNlczEfMB0GA1UEAxMWc2hpYmJvbGV0aC5zZWxieS5hYy51azEjMCEG\n\t\t\t\t\t\tCSqGSIb3DQEJARYUcGlsbGluZ21Ac2VsYnkuYWMudWuCCQCBgHWIQnVzkzANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAdFdP+fjhBkK5qfIPqErHOJRlOUq3NNgpbrzpq7P6aGY+\n\t\t\t\t\t\tbCH1vZCV593B3x1avTMWjP/6GEjXxPQOrhC93u3DQsAH+sbpGHIhSnir7egKa0GO\n\t\t\t\t\t\ttCIRBjIuEVrwoLkNudGD+ZXG6rSQBe/8rvKa1PovjeGSWvtMiLdNyI2LqW9gzQog\n\t\t\t\t\t\tYJQRakt5pqHYL0KK+TdZceNVnRyiTTJfl6GZw24ij7zIbTdOTv/vDfNLqHdebkIo\n\t\t\t\t\t\tSgGHbK7rJ0ywnr5qIwrjpfXkyNDUobGdGcrccynBSJoUNwR9dNLFZ8funAukMR4W\n\t\t\t\t\t\t6sm3KNXOyBTi8GzW+r6Ray34zb5DUo1CSfO5fCWRsA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "selby.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.selby.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.selby.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.selby.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.selby.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.selby.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.selby.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.selby.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.selby.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "selby.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFKzCCBBOgAwIBAgIJAIGAdYhCdXOTMA0GCSqGSIb3DQEBBQUAMIGwMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEYMBYGA1UECBMPTm9ydGggWW9ya3NoaXJlMQ4wDAYDVQQHEwVTZWxi\n\t\t\t\t\t\teTEWMBQGA1UEChMNU2VsYnkgQ29sbGVnZTEZMBcGA1UECxMQTmV0d29yayBTZXJ2\n\t\t\t\t\t\taWNlczEfMB0GA1UEAxMWc2hpYmJvbGV0aC5zZWxieS5hYy51azEjMCEGCSqGSIb3\n\t\t\t\t\t\tDQEJARYUcGlsbGluZ21Ac2VsYnkuYWMudWswHhcNMTMxMDI5MDkzNjA4WhcNMjMx\n\t\t\t\t\t\tMDI3MDkzNjA4WjCBsDELMAkGA1UEBhMCR0IxGDAWBgNVBAgTD05vcnRoIFlvcmtz\n\t\t\t\t\t\taGlyZTEOMAwGA1UEBxMFU2VsYnkxFjAUBgNVBAoTDVNlbGJ5IENvbGxlZ2UxGTAX\n\t\t\t\t\t\tBgNVBAsTEE5ldHdvcmsgU2VydmljZXMxHzAdBgNVBAMTFnNoaWJib2xldGguc2Vs\n\t\t\t\t\t\tYnkuYWMudWsxIzAhBgkqhkiG9w0BCQEWFHBpbGxpbmdtQHNlbGJ5LmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0WCeQdUOOwr1zgrswrslHE0L\n\t\t\t\t\t\tUIN97PbpESv/ash874+27SUiJ4xff+OCrmTD/bleiWTwe2gS629blM8ehj7WMI4i\n\t\t\t\t\t\tQvor3Kx13jDsb7rp2TF/G3rFhCwvl6PyDJGUzdKWxKMxyaNRaAI6KmKwFNeUGnTO\n\t\t\t\t\t\tl9f4tXZvuZlvGOmERxmArpIq4R7sMU+ORooIQxDtGriEd/OD9ILPBv7sI0ahY03h\n\t\t\t\t\t\tuLcUpk/INWDdwxS1gxAB7tkpbg7P5ZCczYPEHY0LLSh4G3sQ7dGJULKzj4CwWODS\n\t\t\t\t\t\tNo+XLXpRBg86gE8ijvyMm9znVjoh2jH2izn5pvc61GALEKbDeJnM9dtqG0wrVQID\n\t\t\t\t\t\tAQABo4IBRDCCAUAwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBH\n\t\t\t\t\t\tZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFBe4qAGMntqL06Msf5ZbMHGk\n\t\t\t\t\t\tPpp9MIHlBgNVHSMEgd0wgdqAFBe4qAGMntqL06Msf5ZbMHGkPpp9oYG2pIGzMIGw\n\t\t\t\t\t\tMQswCQYDVQQGEwJHQjEYMBYGA1UECBMPTm9ydGggWW9ya3NoaXJlMQ4wDAYDVQQH\n\t\t\t\t\t\tEwVTZWxieTEWMBQGA1UEChMNU2VsYnkgQ29sbGVnZTEZMBcGA1UECxMQTmV0d29y\n\t\t\t\t\t\tayBTZXJ2aWNlczEfMB0GA1UEAxMWc2hpYmJvbGV0aC5zZWxieS5hYy51azEjMCEG\n\t\t\t\t\t\tCSqGSIb3DQEJARYUcGlsbGluZ21Ac2VsYnkuYWMudWuCCQCBgHWIQnVzkzANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAdFdP+fjhBkK5qfIPqErHOJRlOUq3NNgpbrzpq7P6aGY+\n\t\t\t\t\t\tbCH1vZCV593B3x1avTMWjP/6GEjXxPQOrhC93u3DQsAH+sbpGHIhSnir7egKa0GO\n\t\t\t\t\t\ttCIRBjIuEVrwoLkNudGD+ZXG6rSQBe/8rvKa1PovjeGSWvtMiLdNyI2LqW9gzQog\n\t\t\t\t\t\tYJQRakt5pqHYL0KK+TdZceNVnRyiTTJfl6GZw24ij7zIbTdOTv/vDfNLqHdebkIo\n\t\t\t\t\t\tSgGHbK7rJ0ywnr5qIwrjpfXkyNDUobGdGcrccynBSJoUNwR9dNLFZ8funAukMR4W\n\t\t\t\t\t\t6sm3KNXOyBTi8GzW+r6Ray34zb5DUo1CSfO5fCWRsA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Selby College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.selby.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Selby College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-03.ladok.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-03.ladok.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;03"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;03"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-03.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-03.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAIhCSM/gXPV2MA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wMy5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTIxMzE4WhcNMjQx\nMDA0MTIxMzE4WjAhMR8wHQYDVQQDExZsYWRvazMtMDMubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtQOsQBm/doFi/rO80GvjNJGY\n/hrRllUtBkIgExc/oqEkKEXRH/yp23e5P8aS/u+Z+Ap0e0RCLqQwAi5yVCx4IIp9\nwEu/trbuR75QF9XIGO0cTy0PrcOyZsAjCk42QmdsUWWq/3jv9G+f+Riny0A0yy3y\n5k//tCZPVBQ+6WIhxbSk+yJM5cec4g2exA7M8fWG/i9Wb/7sWEjN0Kz5GTgPLO81\nE4/Ji7oJh4zesuDyFlfCn9wHx7ex7gzmP1H5uTkgfy5GGTZakzVi5dc9oQICY3xA\nDqx95pPNugXlfmZzV6M9aWmPnLvRO17LX9uOD5hDHsqhnqppOVcNf/YEbYxH+QID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMDMubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0wMy5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUbJhrFVcaM2PS/pjQJjhusF3gYRowDQYJKoZIhvcNAQEFBQADggEB\nAJh7UZv2qYzT1FCI0wGEnqPfkxTYFLvjq1zSp1u4WAlvVXPkN/KMbqIgzzTSW3S2\nzyImr52uqUp0IWjbg+iAk5e8n4+08gJMwWcpidfs9U0avIu9YoMz+qjQ5CyMe6xR\n1w1DWjbXQnB75XAtrOYCm7RH9sx0RvpfFnzUT92z2I+68Jl4499eeBzSprJuRjYP\nmiF1AohiHs3zkZAlP4BQWc1utAp/fv5ls2pnepCAJvePieJPalI19r3bd1cLU+A7\ndwvGpzDdwMxXKv+cQUdRnCE3IhzFb8X57J7pQApgGPnzt0H9uwgFPIEE8mOaQM4U\nIlstWICQczAoX1y5Ow2IOEo="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-03.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-03.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.bcot.ac.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.bcot.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/bcot.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/bcot.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bcot.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Basingstoke College of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bcot.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.lcwc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.lcwc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/lcwc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/lcwc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lcwc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lakes College West Cumbria"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lcwc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ujep.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Polacek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pavel.polacek@ujep.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pavel"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ujep.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2010-09-21T15:26:39Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/university"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIELjCCAxYCCQD8WhkthREzrjANBgkqhkiG9w0BAQUFADCB2DELMAkGA1UEBhMC\nQ1oxFzAVBgNVBAgTDkN6ZWNoIFJlcHVibGljMRcwFQYDVQQHEw5Vc3RpIG5hZCBM\nYWJlbTE9MDsGA1UEChM0SmFuIEV2YW5nZWxpc3RhIFB1cmt5bmUgVW5pdmVyc2l0\neSBpbiBVc3RpIG5hZCBMYWJlbTEcMBoGA1UECxMTQ2VudHJ1bSBJbmZvcm1hdGlr\neTEUMBIGA1UEAxMLaWRwLnVqZXAuY3oxJDAiBgkqhkiG9w0BCQEWFXBhdmVsLnBv\nbGFjZWtAdWplcC5jejAeFw0xMzAyMTEwODEzNTJaFw0yMzAyMDkwODEzNTJaMIHY\nMQswCQYDVQQGEwJDWjEXMBUGA1UECBMOQ3plY2ggUmVwdWJsaWMxFzAVBgNVBAcT\nDlVzdGkgbmFkIExhYmVtMT0wOwYDVQQKEzRKYW4gRXZhbmdlbGlzdGEgUHVya3lu\nZSBVbml2ZXJzaXR5IGluIFVzdGkgbmFkIExhYmVtMRwwGgYDVQQLExNDZW50cnVt\nIEluZm9ybWF0aWt5MRQwEgYDVQQDEwtpZHAudWplcC5jejEkMCIGCSqGSIb3DQEJ\nARYVcGF2ZWwucG9sYWNla0B1amVwLmN6MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEAvJIxOavTd0EX9/IM/cpWc/RlFw1wsDiZuN96yFRACjMeY0jxyF80\nKQJbSSUhgnBIXfeLcgOFBYMivtkxpKRw/dqIB7Pq0Reh9sdHvV0Kec7pphHhwiGv\nf5jz9OiqtP8ZfkK8dgZwJfjBhqjt6V5cHI5lGSMek0pH0KcrCo+yAhwtZecuDhTe\nxPHfBJ5UsQ9t/ynCQn6/NckOQrYIkeP9u+wS/XsF8Z5aB35Pjq6RCZCUqrWYomfg\nLpZKAjSikFyA/Er6UiZCXHysYkq1O4kE87ndhkN5ngtH6FBSJQO5QfG8BgrxiOCm\nchPtodxO++n1ZBhMVt4kHAC5txaEhhl9ZwIDAQABMA0GCSqGSIb3DQEBBQUAA4IB\nAQAdNqOKtWjjw2L1YZ7hOxLNyZlAmboyDKeirErCXVK64QVCQvWZTl3BLDmvJzP7\nYbW0NeKq9STOfnxlJOV23NRPLjlaDwMn4B9wF6elNi+FeBplKt8NbXwXPfSSIHN7\nytJJMwPrEBrrXhSKedT/rpGx28Ld4UuC4aKCjhCVor0fGh3B8BPQZoAY3iO+lXJg\n5jSx2xyJS9xVGE4sjeHrPTYNApQUKHboj4d2aswEQg+JvQYqdEU+SCBveo3Qou3Y\n6VLxR/4Su2F6qooWNjensavLeNix6/TurrOgMcIMOsJ1DcWml8HH2yBqEW40QNFQ\nU19RU7sLdrZ60inUFxdxr+AR"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ujep.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ujep.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ujep.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ujep.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ujep.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ujep.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ujep.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ujep.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ujep.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ujep.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ujep.cz/en/welcome.html"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ujep.cz"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for UJEP in Usti nad Labem"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro UJEP v \u00dast\u00ed nad Labem"
                  }
                ],
                "logo": [
                  {
                    "text": "https://trilian.ujep.cz/logo_ujep40.png",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "102"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Jan Evangelista Purkyne University in Usti nad Labem"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Univerzita Jana Evangelisty Purkyn\u011b v \u00dast\u00ed nad Labem"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIELjCCAxYCCQD8WhkthREzrjANBgkqhkiG9w0BAQUFADCB2DELMAkGA1UEBhMC\nQ1oxFzAVBgNVBAgTDkN6ZWNoIFJlcHVibGljMRcwFQYDVQQHEw5Vc3RpIG5hZCBM\nYWJlbTE9MDsGA1UEChM0SmFuIEV2YW5nZWxpc3RhIFB1cmt5bmUgVW5pdmVyc2l0\neSBpbiBVc3RpIG5hZCBMYWJlbTEcMBoGA1UECxMTQ2VudHJ1bSBJbmZvcm1hdGlr\neTEUMBIGA1UEAxMLaWRwLnVqZXAuY3oxJDAiBgkqhkiG9w0BCQEWFXBhdmVsLnBv\nbGFjZWtAdWplcC5jejAeFw0xMzAyMTEwODEzNTJaFw0yMzAyMDkwODEzNTJaMIHY\nMQswCQYDVQQGEwJDWjEXMBUGA1UECBMOQ3plY2ggUmVwdWJsaWMxFzAVBgNVBAcT\nDlVzdGkgbmFkIExhYmVtMT0wOwYDVQQKEzRKYW4gRXZhbmdlbGlzdGEgUHVya3lu\nZSBVbml2ZXJzaXR5IGluIFVzdGkgbmFkIExhYmVtMRwwGgYDVQQLExNDZW50cnVt\nIEluZm9ybWF0aWt5MRQwEgYDVQQDEwtpZHAudWplcC5jejEkMCIGCSqGSIb3DQEJ\nARYVcGF2ZWwucG9sYWNla0B1amVwLmN6MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEAvJIxOavTd0EX9/IM/cpWc/RlFw1wsDiZuN96yFRACjMeY0jxyF80\nKQJbSSUhgnBIXfeLcgOFBYMivtkxpKRw/dqIB7Pq0Reh9sdHvV0Kec7pphHhwiGv\nf5jz9OiqtP8ZfkK8dgZwJfjBhqjt6V5cHI5lGSMek0pH0KcrCo+yAhwtZecuDhTe\nxPHfBJ5UsQ9t/ynCQn6/NckOQrYIkeP9u+wS/XsF8Z5aB35Pjq6RCZCUqrWYomfg\nLpZKAjSikFyA/Er6UiZCXHysYkq1O4kE87ndhkN5ngtH6FBSJQO5QfG8BgrxiOCm\nchPtodxO++n1ZBhMVt4kHAC5txaEhhl9ZwIDAQABMA0GCSqGSIb3DQEBBQUAA4IB\nAQAdNqOKtWjjw2L1YZ7hOxLNyZlAmboyDKeirErCXVK64QVCQvWZTl3BLDmvJzP7\nYbW0NeKq9STOfnxlJOV23NRPLjlaDwMn4B9wF6elNi+FeBplKt8NbXwXPfSSIHN7\nytJJMwPrEBrrXhSKedT/rpGx28Ld4UuC4aKCjhCVor0fGh3B8BPQZoAY3iO+lXJg\n5jSx2xyJS9xVGE4sjeHrPTYNApQUKHboj4d2aswEQg+JvQYqdEU+SCBveo3Qou3Y\n6VLxR/4Su2F6qooWNjensavLeNix6/TurrOgMcIMOsJ1DcWml8HH2yBqEW40QNFQ\nU19RU7sLdrZ60inUFxdxr+AR"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Jan Evangelista Purkyne University in Usti nad Labem"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Univerzita Jana Evangelisty Purkyn\u011b v \u00dast\u00ed nad Labem"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ujep.cz/en/welcome.html"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ujep.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Jan Evangelista Purkyne University in Usti nad Labem"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Univerzita Jana Evangelisty Purkyn\u011b v \u00dast\u00ed nad Labem"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://fam-uat.salford.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:library-systems@salford.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Library Systems Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:library-systems@salford.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Library Systems Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://fam-uat.salford.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-01-27T14:26:50Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://fam-uat.salford.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://fam-uat.salford.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "salford.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYDCCAkigAwIBAgIIdA1q8PHLx00wDQYJKoZIhvcNAQEFBQAwRzElMCMGA1UE\n\t\t\t\t\t\tCgwcVW5pdmVyc2l0eSBvZiBTYWxmb3JkIChUZXN0KTEeMBwGA1UEAwwVZmFtLXVh\n\t\t\t\t\t\tdC5zYWxmb3JkLmFjLnVrMB4XDTEyMDYxMTEyMzAwMVoXDTIyMDYxMTEyMzAwMVow\n\t\t\t\t\t\tRzElMCMGA1UECgwcVW5pdmVyc2l0eSBvZiBTYWxmb3JkIChUZXN0KTEeMBwGA1UE\n\t\t\t\t\t\tAwwVZmFtLXVhdC5zYWxmb3JkLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\n\t\t\t\t\t\tMIIBCgKCAQEAmakhp2Sop9uuZ4/g+ogTc7O6J59oC5jNWSpTSFcKIe8NSIuyfwxh\n\t\t\t\t\t\tIlKW/aQqPKJnFXF14Gxpx1BNppdqQqQRxEL7as4Zxz8/dCp7bYAhfbUqazI9O6eT\n\t\t\t\t\t\tAEXHFdWuF03G6stpD9tgXb/M3C33xIEMbMLrxwecEGptBMXQAGrfP9HjzVSq5sOL\n\t\t\t\t\t\tDRG3XavujhmCwL2mJY8Er0EV89AhGcCMa/gF8LcMsq8lIfAkOOtCIyEyYFxwKhfB\n\t\t\t\t\t\tfPhap5pez1Brb9UclHQS7YPPpbd6sVJbE12ynbp40zFyXI7Gk1VPcGbAOtlmqXN1\n\t\t\t\t\t\tncnRjRD4FFIaze3Hg4psQ45SINODenw0YwIDAQABo1AwTjAdBgNVHQ4EFgQUKP/c\n\t\t\t\t\t\tXhj02302SMPB4YIF+gJPYlgwHwYDVR0jBBgwFoAUKP/cXhj02302SMPB4YIF+gJP\n\t\t\t\t\t\tYlgwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAIQuZ3AkhllWpfZ7w\n\t\t\t\t\t\tNOLbdL9xbbJZBc4fA7INZvVJWDB1PIJUn9Iva943Qym/JEIuVj59S5be0Ctn3XZi\n\t\t\t\t\t\t4I/aRTyi/rPt0px34c3r3yJTtF6OXe1OERoGishcttXgQBQdzuBzr8B0wDYfYL0O\n\t\t\t\t\t\tjrBSqzn19Dhq8+zgINPeKjtwbsPwgAUY/BKZznxpeaqkTvCuPKQVvB/Rhuer4gbg\n\t\t\t\t\t\t9s+2GFpJOEBFGBKGQDrqaN04B5aMGfnVmVuFyFXoKEjwmT2xTyI9ZAqd1IcARhUz\n\t\t\t\t\t\tDo7ZcjE94HyRadvZwOrZEtsZrRDrCGSP3f8oeOO+5+Vrw9R9pG0hgmgRyPi5ms/e\n\t\t\t\t\t\tkjf/HA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYDCCAkigAwIBAgIIdA1q8PHLx00wDQYJKoZIhvcNAQEFBQAwRzElMCMGA1UE\n\t\t\t\t\t\tCgwcVW5pdmVyc2l0eSBvZiBTYWxmb3JkIChUZXN0KTEeMBwGA1UEAwwVZmFtLXVh\n\t\t\t\t\t\tdC5zYWxmb3JkLmFjLnVrMB4XDTEyMDYxMTEyMzAwMVoXDTIyMDYxMTEyMzAwMVow\n\t\t\t\t\t\tRzElMCMGA1UECgwcVW5pdmVyc2l0eSBvZiBTYWxmb3JkIChUZXN0KTEeMBwGA1UE\n\t\t\t\t\t\tAwwVZmFtLXVhdC5zYWxmb3JkLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\n\t\t\t\t\t\tMIIBCgKCAQEAmakhp2Sop9uuZ4/g+ogTc7O6J59oC5jNWSpTSFcKIe8NSIuyfwxh\n\t\t\t\t\t\tIlKW/aQqPKJnFXF14Gxpx1BNppdqQqQRxEL7as4Zxz8/dCp7bYAhfbUqazI9O6eT\n\t\t\t\t\t\tAEXHFdWuF03G6stpD9tgXb/M3C33xIEMbMLrxwecEGptBMXQAGrfP9HjzVSq5sOL\n\t\t\t\t\t\tDRG3XavujhmCwL2mJY8Er0EV89AhGcCMa/gF8LcMsq8lIfAkOOtCIyEyYFxwKhfB\n\t\t\t\t\t\tfPhap5pez1Brb9UclHQS7YPPpbd6sVJbE12ynbp40zFyXI7Gk1VPcGbAOtlmqXN1\n\t\t\t\t\t\tncnRjRD4FFIaze3Hg4psQ45SINODenw0YwIDAQABo1AwTjAdBgNVHQ4EFgQUKP/c\n\t\t\t\t\t\tXhj02302SMPB4YIF+gJPYlgwHwYDVR0jBBgwFoAUKP/cXhj02302SMPB4YIF+gJP\n\t\t\t\t\t\tYlgwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAIQuZ3AkhllWpfZ7w\n\t\t\t\t\t\tNOLbdL9xbbJZBc4fA7INZvVJWDB1PIJUn9Iva943Qym/JEIuVj59S5be0Ctn3XZi\n\t\t\t\t\t\t4I/aRTyi/rPt0px34c3r3yJTtF6OXe1OERoGishcttXgQBQdzuBzr8B0wDYfYL0O\n\t\t\t\t\t\tjrBSqzn19Dhq8+zgINPeKjtwbsPwgAUY/BKZznxpeaqkTvCuPKQVvB/Rhuer4gbg\n\t\t\t\t\t\t9s+2GFpJOEBFGBKGQDrqaN04B5aMGfnVmVuFyFXoKEjwmT2xTyI9ZAqd1IcARhUz\n\t\t\t\t\t\tDo7ZcjE94HyRadvZwOrZEtsZrRDrCGSP3f8oeOO+5+Vrw9R9pG0hgmgRyPi5ms/e\n\t\t\t\t\t\tkjf/HA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Salford TEST"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.salford.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Salford"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.teikav.edu.gr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sotiropoulou"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lsotir@teikav.edu.gr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kalliopi"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.teikav.edu.gr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEbzCCA1egAwIBAgIQFNuyHJki9S+B7LCfm+TiGDANBgkqhkiG9w0BAQUFADA2\n                            MQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n                            U1NMIENBMB4XDTEzMDYyNjAwMDAwMFoXDTE2MDYyNTIzNTk1OVowPzEhMB8GA1UE\n                            CxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRowGAYDVQQDExFpZHAudGVpa2F2\n                            LmVkdS5ncjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN+MrpJsmJnM\n                            T063+RAOnzCcXQ9r5wHym1ZtKoB3FKp2tod++p7YTPk9MoySyffsV0ongHfluMVA\n                            GD2V+TbsbO177yM4t1WIpiuxKT5WlEN+kDkkM5qkYSN+FxD8GH1V2mA/oDf//bDv\n                            EEhRM1Qz3OjMe+Tjt023IETpHQieB3uSiE4vRRro2togvwglTahkNg7Bl4ND7kwu\n                            BXkSsEkshJhZ7hu9zYOX1/fmVA3HCY5MQVm/A8hPoi0vPPU0M75Nrr/gcjayUHCI\n                            bXG2Ihx2dNt6bHIH24JQJQ8NXHJ753oGSX/3/R/umw1fC82cU09ZyXCUh7qU58aQ\n                            AEtoy3zTmUMCAwEAAaOCAW4wggFqMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdX\n                            R+qQ47ntMB0GA1UdDgQWBBTdMGbpA6aMekTpX31WvVX+SYiogzAOBgNVHQ8BAf8E\n                            BAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUH\n                            AwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0fBDMw\n                            MTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5j\n                            cmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50\n                            ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29j\n                            c3AudGNzLnRlcmVuYS5vcmcwHAYDVR0RBBUwE4IRaWRwLnRlaWthdi5lZHUuZ3Iw\n                            DQYJKoZIhvcNAQEFBQADggEBADMm0AmxzrM7mkGHavjT+huoHYy+y+eyOb9/WZ+M\n                            vVoolVQZsbh0AhYBAtDXUg+jJzTIQDZeNg63HqmXJ8uK8If9pjsb6iFUsRYvSGAF\n                            IzcnI11OfTlsEuFGpO1MxBAIlGq2/CtJPy/1Zi2LnK3Ci2kdjCyv5dTbICxa7iuW\n                            XVFBPXrWGtod3YGSwe0qBRCGxAhFX0ea6zM/r6rA4yPFlQkC9UUaN1ITZJyTbXAB\n                            9Gd9S8+S7i0jUNHK6iGX9EvV5VmjpzMY6/vdhoGpc+xuC0bX1Gjsml4HmcIrq25p\n                            VkLGD8nhv01wEmNMTmDawlDlIxUq3l/cK/GuJL/8lVGLOjk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "teikav.edu.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.teikav.edu.gr:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.teikav.edu.gr:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.teikav.edu.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.teikav.edu.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.teikav.edu.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.teikav.edu.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.teikav.edu.gr:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.teikav.edu.gr:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "teikav.edu.gr"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.teiemt.gr/"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.teiemt.gr/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.teikav.edu.gr/logo.png",
                    "height": "83",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "83"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Technological Educational Institute of Eastern Macedonia and Thrace"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03b9\u03ba\u03cc \u0395\u03ba\u03c0\u03b1\u03b9\u03b4\u03b5\u03c5\u03c4\u03b9\u03ba\u03cc \u038a\u03b4\u03c1\u03c5\u03bc\u03b1 \u0391\u03bd\u03b1\u03c4\u03bf\u03bb\u03b9\u03ba\u03ae\u03c2 \u039c\u03b1\u03ba\u03b5\u03b4\u03bf\u03bd\u03af\u03b1\u03c2 \u03ba\u03b1\u03b9 \u0398\u03c1\u03ac\u03ba\u03b7\u03c2"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "noc.teiemt.gr"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "teiemt.gr"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:40.9286958,24.3794714,137"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.130.92.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.130.94.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "83.212.92.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "83.212.94.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEbzCCA1egAwIBAgIQFNuyHJki9S+B7LCfm+TiGDANBgkqhkiG9w0BAQUFADA2\n                            MQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n                            U1NMIENBMB4XDTEzMDYyNjAwMDAwMFoXDTE2MDYyNTIzNTk1OVowPzEhMB8GA1UE\n                            CxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRowGAYDVQQDExFpZHAudGVpa2F2\n                            LmVkdS5ncjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN+MrpJsmJnM\n                            T063+RAOnzCcXQ9r5wHym1ZtKoB3FKp2tod++p7YTPk9MoySyffsV0ongHfluMVA\n                            GD2V+TbsbO177yM4t1WIpiuxKT5WlEN+kDkkM5qkYSN+FxD8GH1V2mA/oDf//bDv\n                            EEhRM1Qz3OjMe+Tjt023IETpHQieB3uSiE4vRRro2togvwglTahkNg7Bl4ND7kwu\n                            BXkSsEkshJhZ7hu9zYOX1/fmVA3HCY5MQVm/A8hPoi0vPPU0M75Nrr/gcjayUHCI\n                            bXG2Ihx2dNt6bHIH24JQJQ8NXHJ753oGSX/3/R/umw1fC82cU09ZyXCUh7qU58aQ\n                            AEtoy3zTmUMCAwEAAaOCAW4wggFqMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdX\n                            R+qQ47ntMB0GA1UdDgQWBBTdMGbpA6aMekTpX31WvVX+SYiogzAOBgNVHQ8BAf8E\n                            BAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUH\n                            AwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0fBDMw\n                            MTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5j\n                            cmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50\n                            ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29j\n                            c3AudGNzLnRlcmVuYS5vcmcwHAYDVR0RBBUwE4IRaWRwLnRlaWthdi5lZHUuZ3Iw\n                            DQYJKoZIhvcNAQEFBQADggEBADMm0AmxzrM7mkGHavjT+huoHYy+y+eyOb9/WZ+M\n                            vVoolVQZsbh0AhYBAtDXUg+jJzTIQDZeNg63HqmXJ8uK8If9pjsb6iFUsRYvSGAF\n                            IzcnI11OfTlsEuFGpO1MxBAIlGq2/CtJPy/1Zi2LnK3Ci2kdjCyv5dTbICxa7iuW\n                            XVFBPXrWGtod3YGSwe0qBRCGxAhFX0ea6zM/r6rA4yPFlQkC9UUaN1ITZJyTbXAB\n                            9Gd9S8+S7i0jUNHK6iGX9EvV5VmjpzMY6/vdhoGpc+xuC0bX1Gjsml4HmcIrq25p\n                            VkLGD8nhv01wEmNMTmDawlDlIxUq3l/cK/GuJL/8lVGLOjk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Eastern Macedonia and Thrace Institute of Technology"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03b9\u03ba\u03cc \u0395\u03ba\u03c0\u03b1\u03b9\u03b4\u03b5\u03c5\u03c4\u03b9\u03ba\u03cc \u038a\u03b4\u03c1\u03c5\u03bc\u03b1 \u0391\u03bd\u03b1\u03c4\u03bf\u03bb\u03b9\u03ba\u03ae\u03c2 \u039c\u03b1\u03ba\u03b5\u03b4\u03bf\u03bd\u03af\u03b1\u03c2 \u03ba\u03b1\u03b9 \u0398\u03c1\u03ac\u03ba\u03b7\u03c2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.teikav.edu.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.teikav.edu.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eastern Macedonia and Thrace Institute of Technology"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03b9\u03ba\u03cc \u0395\u03ba\u03c0\u03b1\u03b9\u03b4\u03b5\u03c5\u03c4\u03b9\u03ba\u03cc \u038a\u03b4\u03c1\u03c5\u03bc\u03b1 \u0391\u03bd\u03b1\u03c4\u03bf\u03bb\u03b9\u03ba\u03ae\u03c2 \u039c\u03b1\u03ba\u03b5\u03b4\u03bf\u03bd\u03af\u03b1\u03c2 \u03ba\u03b1\u03b9 \u0398\u03c1\u03ac\u03ba\u03b7\u03c2"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.oulu.fi/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hakosalo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Jukka.Hakosalo@oulu.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jukka"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hakosalo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Jukka.Hakosalo@oulu.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jukka"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hakosalo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Jukka.Hakosalo@oulu.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jukka"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.oulu.fi/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.csc.fi/english/institutions/haka/instructions/join/eduGAINRegistrationStatement/"
              }
            ],
            "registration_authority": "http://www.csc.fi/haka",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEaDCCA1CgAwIBAgIRAJBo2HnycBTUKKbocEpkkQ4wDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xMzA3MDEwMDAwMDBaFw0xNjA3MTEyMzU5NTlaMDsxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEWMBQGA1UEAxMNbG9naW4ub3Vs\ndS5maTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM2aZafEX/FDrdrz\ntc97CZvxDyEpP8HQXgiZfsUZKVMqFW1+PMojB/d2/u1CZI4zZiiv+MZnSph5eDsM\n5bgoeImLYF+yzc+Jo77Erzg4b4jnLEm/FL+znCHxzZnRCNOAFA4dT0ejZNGuMuiz\ndhNlmyprp1D8ZW6PYIpMhd6poDbvN8r4uttkZRt7nd1TedJ8IZFVz0YbiueFk2Jq\n3/3kcEX651M6cFPQFliJBCZsfm/I4A2Wr3znhpg9ZoKM8XlmFxC5lIueG+xadDn5\nIgDpPMd/4+j6y8GJpjVPen5jQljRlpXi92nGNRHl2JRKssmLzUHoDipF63mcBD3T\nntpoCt0CAwEAAaOCAWowggFmMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdXR+qQ\n47ntMB0GA1UdDgQWBBRUPc90K8NE3LMOwDvaN0iFkxtriDAOBgNVHQ8BAf8EBAMC\nBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIw\nIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0fBDMwMTAv\noC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcmww\nbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50ZXJl\nbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29jc3Au\ndGNzLnRlcmVuYS5vcmcwGAYDVR0RBBEwD4INbG9naW4ub3VsdS5maTANBgkqhkiG\n9w0BAQUFAAOCAQEAS4t/Ojf08h4l9TocXwdsROKo2Fm6yN1F/S8qQR33wDm2W51U\nLDMx9/Zc4NKOZZjPkqtZHOqY0QO54XLEp5YVYJzFy32FCwMc6LFyw5PqXzq2oFKV\ncBJNr+p4XJsh7Ps95ImcAmrubBVxnk9Zk+sGHT7y31cxyuo4D98PA7icD7dMloe/\nbIGXij+jcAi960WSFbNgK5Jm3D4G00fNtg8MOQvpZWNtq8wvF01Iy//WW1tXY/df\nkTHGaVWDNaZW+4SyUjAT5eYB8DUq2v5ntP3E7i5g+X9letuBOzzRglJdrkjfGrrh\nBVDhfQ6xKx1/1Y5/Suthd1U3Tybz1r0WiFoF4Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oulu.fi"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.oulu.fi:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.oulu.fi:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.oulu.fi/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.oulu.fi/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.oulu.fi/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oulu.fi"
              },
              {
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ule\u00e5borgs universitet"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Oulun yliopisto"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Oulu"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEaDCCA1CgAwIBAgIRAJBo2HnycBTUKKbocEpkkQ4wDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xMzA3MDEwMDAwMDBaFw0xNjA3MTEyMzU5NTlaMDsxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEWMBQGA1UEAxMNbG9naW4ub3Vs\ndS5maTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM2aZafEX/FDrdrz\ntc97CZvxDyEpP8HQXgiZfsUZKVMqFW1+PMojB/d2/u1CZI4zZiiv+MZnSph5eDsM\n5bgoeImLYF+yzc+Jo77Erzg4b4jnLEm/FL+znCHxzZnRCNOAFA4dT0ejZNGuMuiz\ndhNlmyprp1D8ZW6PYIpMhd6poDbvN8r4uttkZRt7nd1TedJ8IZFVz0YbiueFk2Jq\n3/3kcEX651M6cFPQFliJBCZsfm/I4A2Wr3znhpg9ZoKM8XlmFxC5lIueG+xadDn5\nIgDpPMd/4+j6y8GJpjVPen5jQljRlpXi92nGNRHl2JRKssmLzUHoDipF63mcBD3T\nntpoCt0CAwEAAaOCAWowggFmMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdXR+qQ\n47ntMB0GA1UdDgQWBBRUPc90K8NE3LMOwDvaN0iFkxtriDAOBgNVHQ8BAf8EBAMC\nBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIw\nIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0fBDMwMTAv\noC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcmww\nbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50ZXJl\nbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29jc3Au\ndGNzLnRlcmVuYS5vcmcwGAYDVR0RBBEwD4INbG9naW4ub3VsdS5maTANBgkqhkiG\n9w0BAQUFAAOCAQEAS4t/Ojf08h4l9TocXwdsROKo2Fm6yN1F/S8qQR33wDm2W51U\nLDMx9/Zc4NKOZZjPkqtZHOqY0QO54XLEp5YVYJzFy32FCwMc6LFyw5PqXzq2oFKV\ncBJNr+p4XJsh7Ps95ImcAmrubBVxnk9Zk+sGHT7y31cxyuo4D98PA7icD7dMloe/\nbIGXij+jcAi960WSFbNgK5Jm3D4G00fNtg8MOQvpZWNtq8wvF01Iy//WW1tXY/df\nkTHGaVWDNaZW+4SyUjAT5eYB8DUq2v5ntP3E7i5g+X9letuBOzzRglJdrkjfGrrh\nBVDhfQ6xKx1/1Y5/Suthd1U3Tybz1r0WiFoF4Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Oulun yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Oulu"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ule\u00e5borgs universitet"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oulu.fi/yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oulu.fi/yliopisto"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oulu.fi/yliopisto"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Oulun yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Oulu"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ule\u00e5borgs universitet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.kedst.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Woolley"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:martin.woolley@kedst.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Woolley"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:martin.woolley@kedst.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.kedst.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIURfg2ZT8NtoYlOeAkg68kLNLvU1IwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGjEYMBYGA1UEAxMPd3d3LmtlZHN0LmFjLnVrMB4XDTA5MDgwNDA4NDg1MVoX\n\t\t\t\t\t\tDTI5MDgwNDA4NDg1MVowGjEYMBYGA1UEAxMPd3d3LmtlZHN0LmFjLnVrMIIBIjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsQ0D7j8KO9M/zkvZ4pYNu88G9i1/\n\t\t\t\t\t\ts8yUlzlusFV8JUoqEczha+XS92o21kwek+iloEjyNMYr1O4cQOXEqwYx3BYlBERP\n\t\t\t\t\t\tPoEmzVnQ+yZ3IGfhrjkUz21KxiSrfui95uoiuJ3mSOv3F8AEFXS4l/FxJ2Pr+37r\n\t\t\t\t\t\tY1/XcyXsk5GlG9DURuTErcd7zWJIiKT6lAQvaLPWCY/uxcQXNQ3nSkyl66r0gcz1\n\t\t\t\t\t\tQFZgX9dEJZ5CFjIUvfKnFUq89UxDPtAFYsSemDCFQs0y4s7vclfnCsPJNErbRz9C\n\t\t\t\t\t\tPvtZyy8O6vLwqeYLGae6TxTWxTudbdle6ZotR4SAhd5lGeGDgz8ENpJ01QIDAQAB\n\t\t\t\t\t\to2UwYzBCBgNVHREEOzA5gg93d3cua2Vkc3QuYWMudWuGJmh0dHBzOi8vd3d3Lmtl\n\t\t\t\t\t\tZHN0LmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTIOI+mXXvpeOykustH\n\t\t\t\t\t\ti52xXKA2PjANBgkqhkiG9w0BAQUFAAOCAQEAgNBCAJj8ik9sqc4Wd9C3s6MV3dsW\n\t\t\t\t\t\t9uxoPtUQx8+mmmwJx6mp4XSqO1Y1il4nQUXe+jvlRG2QE1kftwf/HCIY+CiTiKBz\n\t\t\t\t\t\t+C3fvQDwbGUNO+hu19IEKWaaMAJPQdj1G7Lu7rEfyBq2/kgAAT822KXHGzwLWl3f\n\t\t\t\t\t\tUidggbqOvDH4OS4t0bun2+dZTMq53UlEhd0C7mXI0AoO+LDW58eTv5RToflSAX9O\n\t\t\t\t\t\tVfNZvQZQ7jOmLqxKW5eMU15qdnZR5VzBxaShu21ZLBrmRFrikpO8KbtAvPW98Iz5\n\t\t\t\t\t\tcD/spZeoVpsEQFY1hTmWUlp62t1wTcinHagogSqSVpwe8sPlB2mtRl9wIA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kedst.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://www.kedst.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.kedst.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://www.kedst.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.kedst.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.kedst.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.kedst.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://www.kedst.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.kedst.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kedst.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIURfg2ZT8NtoYlOeAkg68kLNLvU1IwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGjEYMBYGA1UEAxMPd3d3LmtlZHN0LmFjLnVrMB4XDTA5MDgwNDA4NDg1MVoX\n\t\t\t\t\t\tDTI5MDgwNDA4NDg1MVowGjEYMBYGA1UEAxMPd3d3LmtlZHN0LmFjLnVrMIIBIjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsQ0D7j8KO9M/zkvZ4pYNu88G9i1/\n\t\t\t\t\t\ts8yUlzlusFV8JUoqEczha+XS92o21kwek+iloEjyNMYr1O4cQOXEqwYx3BYlBERP\n\t\t\t\t\t\tPoEmzVnQ+yZ3IGfhrjkUz21KxiSrfui95uoiuJ3mSOv3F8AEFXS4l/FxJ2Pr+37r\n\t\t\t\t\t\tY1/XcyXsk5GlG9DURuTErcd7zWJIiKT6lAQvaLPWCY/uxcQXNQ3nSkyl66r0gcz1\n\t\t\t\t\t\tQFZgX9dEJZ5CFjIUvfKnFUq89UxDPtAFYsSemDCFQs0y4s7vclfnCsPJNErbRz9C\n\t\t\t\t\t\tPvtZyy8O6vLwqeYLGae6TxTWxTudbdle6ZotR4SAhd5lGeGDgz8ENpJ01QIDAQAB\n\t\t\t\t\t\to2UwYzBCBgNVHREEOzA5gg93d3cua2Vkc3QuYWMudWuGJmh0dHBzOi8vd3d3Lmtl\n\t\t\t\t\t\tZHN0LmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTIOI+mXXvpeOykustH\n\t\t\t\t\t\ti52xXKA2PjANBgkqhkiG9w0BAQUFAAOCAQEAgNBCAJj8ik9sqc4Wd9C3s6MV3dsW\n\t\t\t\t\t\t9uxoPtUQx8+mmmwJx6mp4XSqO1Y1il4nQUXe+jvlRG2QE1kftwf/HCIY+CiTiKBz\n\t\t\t\t\t\t+C3fvQDwbGUNO+hu19IEKWaaMAJPQdj1G7Lu7rEfyBq2/kgAAT822KXHGzwLWl3f\n\t\t\t\t\t\tUidggbqOvDH4OS4t0bun2+dZTMq53UlEhd0C7mXI0AoO+LDW58eTv5RToflSAX9O\n\t\t\t\t\t\tVfNZvQZQ7jOmLqxKW5eMU15qdnZR5VzBxaShu21ZLBrmRFrikpO8KbtAvPW98Iz5\n\t\t\t\t\t\tcD/spZeoVpsEQFY1hTmWUlp62t1wTcinHagogSqSVpwe8sPlB2mtRl9wIA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "King Edward VI College, Stourbridge"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kedst.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "King Edward VI College, Stourbridge"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://vartuppdrag.se",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Croneborg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:fredrik@learnways.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Fredrik"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://vartuppdrag.se",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vartuppdrag.se/saml2/slo",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://vartuppdrag.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://vartuppdrag.se"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Utbildningsportal f\u00f6r studenter p\u00e5 G\u00f6teborg, Malm\u00f6 and Uppsala Universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Online education portal for university students at G\u00f6teborg, Malm\u00f6 and Uppsala University"
                  }
                ],
                "logo": [
                  {
                    "text": "https://weblogin.uu.se/idp/UUlogin/img/logga-50.png",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "V\u00e5rt uppdrag - Webbutbildning fr\u00e5n Learnways"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "V\u00e5rt uppdrag - Webbutbildning fr\u00e5n Learnways"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/DCCAmWgAwIBAgIJAMcQQq6rmwVQMA0GCSqGSIb3DQEBCwUAMIGVMQswCQYD\n            VQQGEwJTRTESMBAGA1UECAwJU3RvY2tob2xtMRIwEAYDVQQHDAlTdG9ja2hvbG0x\n            EjAQBgNVBAoMCUxlYXJud2F5czELMAkGA1UECwwCSVQxFzAVBgNVBAMMDnZhcnR1\n            cHBkcmFnLnNlMSQwIgYJKoZIhvcNAQkBFhVmcmVkcmlrQGxlYXJud2F5cy5jb20w\n            IBcNMTYwMTEzMDgzMjE4WhgPMjI4OTEwMjgwODMyMThaMIGVMQswCQYDVQQGEwJT\n            RTESMBAGA1UECAwJU3RvY2tob2xtMRIwEAYDVQQHDAlTdG9ja2hvbG0xEjAQBgNV\n            BAoMCUxlYXJud2F5czELMAkGA1UECwwCSVQxFzAVBgNVBAMMDnZhcnR1cHBkcmFn\n            LnNlMSQwIgYJKoZIhvcNAQkBFhVmcmVkcmlrQGxlYXJud2F5cy5jb20wgZ8wDQYJ\n            KoZIhvcNAQEBBQADgY0AMIGJAoGBAN6CRfi7tSIbXTXKbUrtIclwO48aWh4sNMkH\n            qHbc4tBZG3wLUl+UV+mxgIt7rmkOldTrQzhyIfncek8+9L2Oc1Ekc9xg8OPtAqgj\n            2Zb71kL0tK4mheGuHIhRAvMhhyWrTXjmAVdYSiSsUeKiKfFKto/MsCP6pFklyIK1\n            VBgVVQJDAgMBAAGjUDBOMB0GA1UdDgQWBBTdXMeQ0FNPyqyLMt/MoLf689s6BDAf\n            BgNVHSMEGDAWgBTdXMeQ0FNPyqyLMt/MoLf689s6BDAMBgNVHRMEBTADAQH/MA0G\n            CSqGSIb3DQEBCwUAA4GBAJXVENigo8BIrlvDLyhaByEQK+RukwSUh2QqXNVEsA+2\n            vNDD4Soa8JW4kdqtX2VCkYttcSolTNqBbt+ZO3yx6iZPEUPVLvP8taaKU9WeBiTk\n            k3K/qjSaDJC/Pwhxf9fuWZd70hCKDeTFiatSqUCmiCVxMVdJ572aAsCAxWESI3/0"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/DCCAmWgAwIBAgIJAMcQQq6rmwVQMA0GCSqGSIb3DQEBCwUAMIGVMQswCQYD\n            VQQGEwJTRTESMBAGA1UECAwJU3RvY2tob2xtMRIwEAYDVQQHDAlTdG9ja2hvbG0x\n            EjAQBgNVBAoMCUxlYXJud2F5czELMAkGA1UECwwCSVQxFzAVBgNVBAMMDnZhcnR1\n            cHBkcmFnLnNlMSQwIgYJKoZIhvcNAQkBFhVmcmVkcmlrQGxlYXJud2F5cy5jb20w\n            IBcNMTYwMTEzMDgzMjE4WhgPMjI4OTEwMjgwODMyMThaMIGVMQswCQYDVQQGEwJT\n            RTESMBAGA1UECAwJU3RvY2tob2xtMRIwEAYDVQQHDAlTdG9ja2hvbG0xEjAQBgNV\n            BAoMCUxlYXJud2F5czELMAkGA1UECwwCSVQxFzAVBgNVBAMMDnZhcnR1cHBkcmFn\n            LnNlMSQwIgYJKoZIhvcNAQkBFhVmcmVkcmlrQGxlYXJud2F5cy5jb20wgZ8wDQYJ\n            KoZIhvcNAQEBBQADgY0AMIGJAoGBAN6CRfi7tSIbXTXKbUrtIclwO48aWh4sNMkH\n            qHbc4tBZG3wLUl+UV+mxgIt7rmkOldTrQzhyIfncek8+9L2Oc1Ekc9xg8OPtAqgj\n            2Zb71kL0tK4mheGuHIhRAvMhhyWrTXjmAVdYSiSsUeKiKfFKto/MsCP6pFklyIK1\n            VBgVVQJDAgMBAAGjUDBOMB0GA1UdDgQWBBTdXMeQ0FNPyqyLMt/MoLf689s6BDAf\n            BgNVHSMEGDAWgBTdXMeQ0FNPyqyLMt/MoLf689s6BDAMBgNVHRMEBTADAQH/MA0G\n            CSqGSIb3DQEBCwUAA4GBAJXVENigo8BIrlvDLyhaByEQK+RukwSUh2QqXNVEsA+2\n            vNDD4Soa8JW4kdqtX2VCkYttcSolTNqBbt+ZO3yx6iZPEUPVLvP8taaKU9WeBiTk\n            k3K/qjSaDJC/Pwhxf9fuWZd70hCKDeTFiatSqUCmiCVxMVdJ572aAsCAxWESI3/0"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vartuppdrag.se/saml2/acs",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://araripe.uece.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "DI Infra"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "di.infra@uece.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://araripe.uece.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID/DCCAuQCAQAwDQYJKoZIhvcNAQEFBQAwgcMxLzAtBgNVBAoTJlVFQ0UgLSBV\nbml2ZXJzaWRhZGUgRXN0YWRpdWFsIGRvIENlYXJhMSQwIgYDVQQLExtEZXBhcnRh\nbWVudG8gZGUgSW5mb3JtYXRpY2ExHzAdBgkqhkiG9w0BCQEWEGRpLmluZnJhQHVl\nY2UuYnIxEjAQBgNVBAcTCUZvcnRhbGV6YTEOMAwGA1UECBMFQ2VhcmExCzAJBgNV\nBAYTAkJSMRgwFgYDVQQDEw9hcmFyaXBlLnVlY2UuYnIwHhcNMTQwMzIxMTkwNzUy\nWhcNMTcwMzIwMTkwNzUyWjCBwzEvMC0GA1UEChMmVUVDRSAtIFVuaXZlcnNpZGFk\nZSBFc3RhZGl1YWwgZG8gQ2VhcmExJDAiBgNVBAsTG0RlcGFydGFtZW50byBkZSBJ\nbmZvcm1hdGljYTEfMB0GCSqGSIb3DQEJARYQZGkuaW5mcmFAdWVjZS5icjESMBAG\nA1UEBxMJRm9ydGFsZXphMQ4wDAYDVQQIEwVDZWFyYTELMAkGA1UEBhMCQlIxGDAW\nBgNVBAMTD2FyYXJpcGUudWVjZS5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBALXknOC9F11nnTnNa8NuRD4cL/FDS9bzesfl/t/XaDMK32F/JgRxumWz\nSK6r0ejmmufDaIglY5kz2wgBry0jPZjkNoVhmDVpSdeEI3s3qDeWb/Jy6QVIYn71\no25S3p/QTo9DVCjJIYoYD4OmNqU7yJa8sXN5FuvcuTgNXphdbXqMeskw9pGYb1zz\nb+h2jEaWo7wlljOYcwa8F2hJrd9W/ff6vit1cWrXv76afFVK1DjGkuS5H23vEz+Y\n3dRWHaflkxHo7iQ71mLmHGs6lyxf60PmJFyan5J8U1n9xcHlNIWbQsDdpPyxv0To\nPDI8+PywOWhoYYt+zA4Lv9V6CjRqpxMCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\nndu7rtfvY/dTDYWGTdYoTLACJCEsovnY8lzt+kyNIucdgJh//2egd8rKIL8BWUzK\nAhpc0fitAklIDaVNzvJIrqMXLTFbT0deAJeeWN9e3Lke2bEqJPDO4xh1paedwk8b\nK8n//pcvw6uxKq5GEny5MEhVPaBJthThbH023ict7onBkUClgU7pAYh66JDscvXa\njRIAsv0FeZt9c0urK4eU4vpnE7Bk0pNSD7pKqQ/ZXngjZSp6CXWlF2J9PGA2g53r\nJuB1tq80AmWAwgGdW4AxW7LLaxwFK6dl0lMIsWYyMleXuh2KhOGxLKrYa/EDs4Yi\nZ1AZ/tU3s4++vwyfNIfQkg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uece.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://araripe.uece.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://araripe.uece.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://araripe.uece.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://araripe.uece.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://araripe.uece.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://araripe.uece.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://araripe.uece.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://araripe.uece.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uece.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uece.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uece.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UECE - Universidade Estadual do Ceara"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UECE - Universidade Estadual do Ceara"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UECE - Universidade Estadual do Ceara"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UECE - Universidade Estadual do Ceara"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID/DCCAuQCAQAwDQYJKoZIhvcNAQEFBQAwgcMxLzAtBgNVBAoTJlVFQ0UgLSBV\nbml2ZXJzaWRhZGUgRXN0YWRpdWFsIGRvIENlYXJhMSQwIgYDVQQLExtEZXBhcnRh\nbWVudG8gZGUgSW5mb3JtYXRpY2ExHzAdBgkqhkiG9w0BCQEWEGRpLmluZnJhQHVl\nY2UuYnIxEjAQBgNVBAcTCUZvcnRhbGV6YTEOMAwGA1UECBMFQ2VhcmExCzAJBgNV\nBAYTAkJSMRgwFgYDVQQDEw9hcmFyaXBlLnVlY2UuYnIwHhcNMTQwMzIxMTkwNzUy\nWhcNMTcwMzIwMTkwNzUyWjCBwzEvMC0GA1UEChMmVUVDRSAtIFVuaXZlcnNpZGFk\nZSBFc3RhZGl1YWwgZG8gQ2VhcmExJDAiBgNVBAsTG0RlcGFydGFtZW50byBkZSBJ\nbmZvcm1hdGljYTEfMB0GCSqGSIb3DQEJARYQZGkuaW5mcmFAdWVjZS5icjESMBAG\nA1UEBxMJRm9ydGFsZXphMQ4wDAYDVQQIEwVDZWFyYTELMAkGA1UEBhMCQlIxGDAW\nBgNVBAMTD2FyYXJpcGUudWVjZS5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBALXknOC9F11nnTnNa8NuRD4cL/FDS9bzesfl/t/XaDMK32F/JgRxumWz\nSK6r0ejmmufDaIglY5kz2wgBry0jPZjkNoVhmDVpSdeEI3s3qDeWb/Jy6QVIYn71\no25S3p/QTo9DVCjJIYoYD4OmNqU7yJa8sXN5FuvcuTgNXphdbXqMeskw9pGYb1zz\nb+h2jEaWo7wlljOYcwa8F2hJrd9W/ff6vit1cWrXv76afFVK1DjGkuS5H23vEz+Y\n3dRWHaflkxHo7iQ71mLmHGs6lyxf60PmJFyan5J8U1n9xcHlNIWbQsDdpPyxv0To\nPDI8+PywOWhoYYt+zA4Lv9V6CjRqpxMCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\nndu7rtfvY/dTDYWGTdYoTLACJCEsovnY8lzt+kyNIucdgJh//2egd8rKIL8BWUzK\nAhpc0fitAklIDaVNzvJIrqMXLTFbT0deAJeeWN9e3Lke2bEqJPDO4xh1paedwk8b\nK8n//pcvw6uxKq5GEny5MEhVPaBJthThbH023ict7onBkUClgU7pAYh66JDscvXa\njRIAsv0FeZt9c0urK4eU4vpnE7Bk0pNSD7pKqQ/ZXngjZSp6CXWlF2J9PGA2g53r\nJuB1tq80AmWAwgGdW4AxW7LLaxwFK6dl0lMIsWYyMleXuh2KhOGxLKrYa/EDs4Yi\nZ1AZ/tU3s4++vwyfNIfQkg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UECE - Universidade Estadual do Ceara"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UECE - Universidade Estadual do Ceara"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uece.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uece.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UECE - Universidade Estadual do Ceara"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UECE - Universidade Estadual do Ceara"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://aai-logon.uni.li/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@uni.li"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAI"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@uni.li"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAI"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://aai-logon.uni.li/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2014-01-09T10:10:39Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIJALPA8rj6XmsNMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGFhaS1sb2dvbi51bmkubGkwHhcNMTQwMTA5MDY0MTUwWhcNMTcwMTA4MDY0\nMTUwWjAbMRkwFwYDVQQDExBhYWktbG9nb24udW5pLmxpMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA18QaCQt2hS2ln2UCEUZfRP4hnA6hx9VBY1qM0coX\nVawizlgqcaejKFZ3EEi+YlbrI8oqT/XxHfrN97TMMfzbfjpe4yfTO+4qO4kzLquv\nrUBc9Lz9zFn7hwFU6FkOL/ZHfRbztDakuehMi+5l63z8dIkAgS/HC1TsYX1QTnzF\noZfESlJauTysw/ScDNCF9gnN0NNh1wzsWzguHue14kuwbNVpEcSuV7f6y115d+aC\nENcifEX4jXQ02QpRb0aRebPEW1waVrUW1oTOhAzQ8aoQw8oO8zNGYAA36FN98Alt\nkib/Fc8e7geFgIdMwmd7sDMlwJr6hOzdJkDJTAZZaFJGXQIDAQABo2cwZTBEBgNV\nHREEPTA7ghBhYWktbG9nb24udW5pLmxphidodHRwczovL2FhaS1sb2dvbi51bmku\nbGkvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFL0xAMbCNYPb2WYBXyVIKNyIzPd4\nMA0GCSqGSIb3DQEBBQUAA4IBAQAAyrTtR1axJmDFepwN9piRyxwe25UjL7OlSKoN\nqpMUDlkEbdmQUg6UODYXC1mQ/QfuPnTDikj2zhr5ylfFSDYPj2kHUyOTN2koTT++\ng0s3ZNe5ly/e+JH1jPMAWLujlpkwflM/lBhgIA0sQXwJEDxigxuqm34Hd8jZv7h8\na5Sf5EDutKrGtwIfDKSvBynp/cibY7H5Dse/EE4ktFWvMlMDaXPVOWqpzLTb3bIa\nNMeonKCuSuheHvNi2LPf6EyZLALj0VtSW5pxqlhOtcHSlaojESKTL1IrUy5pUmnr\n/LVDLvHUtsJPKNVR2iL2CUFeYjUoh4s2cZPgdMs8Q+XDvVL/"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uni.li"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-logon.uni.li:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-logon.uni.li:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aai-logon.uni.li/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai-logon.uni.li/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai-logon.uni.li/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aai-logon.uni.li/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-logon.uni.li:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-logon.uni.li:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uni.li"
              },
              {
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Universit\u00e4t Liechtenstein"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Liechtenstein"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAAXNSR0IArs4c6QAAACF0RVh0U29mdHdhcmUAR3JhcGhpY0NvbnZlcnRlciAoSW50ZWwpd4f6GQAAACRJREFUeJxiYBgFlINdalL/icG41I4aQKIBo4BGAAAAAP//AwAhn6eucY32zQAAAABJRU5ErkJggg==",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e4t Liechtenstein"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Liechtenstein"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "uni.li"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.149655,9.516456"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.84.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.5.26.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.5.26.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.5.27.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.222.112.0/20"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.222.112.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.222.120.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.222.124.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.80.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.222.126.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.222.127.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIJALPA8rj6XmsNMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGFhaS1sb2dvbi51bmkubGkwHhcNMTQwMTA5MDY0MTUwWhcNMTcwMTA4MDY0\nMTUwWjAbMRkwFwYDVQQDExBhYWktbG9nb24udW5pLmxpMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA18QaCQt2hS2ln2UCEUZfRP4hnA6hx9VBY1qM0coX\nVawizlgqcaejKFZ3EEi+YlbrI8oqT/XxHfrN97TMMfzbfjpe4yfTO+4qO4kzLquv\nrUBc9Lz9zFn7hwFU6FkOL/ZHfRbztDakuehMi+5l63z8dIkAgS/HC1TsYX1QTnzF\noZfESlJauTysw/ScDNCF9gnN0NNh1wzsWzguHue14kuwbNVpEcSuV7f6y115d+aC\nENcifEX4jXQ02QpRb0aRebPEW1waVrUW1oTOhAzQ8aoQw8oO8zNGYAA36FN98Alt\nkib/Fc8e7geFgIdMwmd7sDMlwJr6hOzdJkDJTAZZaFJGXQIDAQABo2cwZTBEBgNV\nHREEPTA7ghBhYWktbG9nb24udW5pLmxphidodHRwczovL2FhaS1sb2dvbi51bmku\nbGkvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFL0xAMbCNYPb2WYBXyVIKNyIzPd4\nMA0GCSqGSIb3DQEBBQUAA4IBAQAAyrTtR1axJmDFepwN9piRyxwe25UjL7OlSKoN\nqpMUDlkEbdmQUg6UODYXC1mQ/QfuPnTDikj2zhr5ylfFSDYPj2kHUyOTN2koTT++\ng0s3ZNe5ly/e+JH1jPMAWLujlpkwflM/lBhgIA0sQXwJEDxigxuqm34Hd8jZv7h8\na5Sf5EDutKrGtwIfDKSvBynp/cibY7H5Dse/EE4ktFWvMlMDaXPVOWqpzLTb3bIa\nNMeonKCuSuheHvNi2LPf6EyZLALj0VtSW5pxqlhOtcHSlaojESKTL1IrUy5pUmnr\n/LVDLvHUtsJPKNVR2iL2CUFeYjUoh4s2cZPgdMs8Q+XDvVL/"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e4t Liechtenstein"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Liechtenstein"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni.li/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni.li/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "uni.li"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://se.timeedit.net/kau-employee-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@evolvera.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TimeEdit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://se.timeedit.net/kau-employee-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://se.timeedit.net/web/kau/db1/timeedit/ssoLogout/personal_saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TimeEdit, utvecklat av TimeEdit AB"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TimeEdit, developed by TimeEdit AB"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TimeEdit f\u00f6r studenter vid Karlstads universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TimeEdit for students at Karlstad University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDcDCCAlgCCQDVKUGzGrt/2jANBgkqhkiG9w0BAQsFADB6MQswCQYDVQQGEwJTRTEYMBYGA1UE\nCAwPVmFzdHJhIGdvdGFsYW5kMRMwEQYDVQQHDApHb3RoZW5idXJnMRQwEgYDVQQKDAtUaW1lRWRp\ndCBBQjELMAkGA1UECwwCSVQxGTAXBgNVBAMMEGF1dGgudGltZWVkaXQuc2UwHhcNMTUwNjE1MTAw\nMjEzWhcNMjUwNjEyMTAwMjEzWjB6MQswCQYDVQQGEwJTRTEYMBYGA1UECAwPVmFzdHJhIGdvdGFs\nYW5kMRMwEQYDVQQHDApHb3RoZW5idXJnMRQwEgYDVQQKDAtUaW1lRWRpdCBBQjELMAkGA1UECwwC\nSVQxGTAXBgNVBAMMEGF1dGgudGltZWVkaXQuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQCgv6XIGV5MzRQbAY8tc9x8Eyuiac+o/z6qUT6s6zSYRu83Jd0RZPRnk/9egxV8RElBDq/k\nMAkXhzejUGI+yFkvxyPpB0u4lct9U0a7mbOr+UqkH+ffxjhxZjEjI20FxX29woMhFRtA//bucQ8y\nxuzYhoJd/pXeXfJCpvKZlPJ3ycF9lkUb3nMMoFNIPlRDddb4tu+MpJljioOPIWR45+PyRXKW1ZMd\nEy8pMoYt42sbIIWJoxj+9/IDbaA7LPg7Zxj+ioWzz7zYA6zdKLj54aQUCrcJ0RZIThzr2gOvMRaT\n5sqDHDmrKFZD/Xd6HwCJkwN6qFPurfZG2GoSnwZ/A8zVAgMBAAEwDQYJKoZIhvcNAQELBQADggEB\nADv6hhEsCrpbERGv6rFlEvHmYtYrjgJBLF3a91PIvVGPENI6HwJhsges/5idijAIcJyeItd0+UAf\neTCMriyNnrqfOdOMaHMC+OXcS1+SV+ZLY6SlAWUzbNlwCTyjETfteMEX70fcKIT+Suv+4nA1ZS9o\ng3y728pny0W+yhYxgjs7mSfG2XZIjzV53qGqCscLu8ASWmlSsqtiUfGueWAfGWHEVDDIr95IMy/u\nTG/lyQTEzr6BTeWusqhm6UXKHguQTvdcpUfH+n4L34gCi0CwMcSfyeRecYdLYPbWKAksD570x5Rd\nYFMsQoFZQd+f5DZjuG5tfyWUpcNd+REWUddnOOM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://se.timeedit.net/web/kau/db1/timeedit/ssoResponse/personal_saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "false"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://test.vpp.midlands3cities.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itservicedesk@nottingham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Betts"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Craig.Betts@nottingham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Craig"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test.vpp.midlands3cities.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-09-11T11:05:52Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Test M3C VPP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.midlands3cities.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Nottingham"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.vpp.midlands3cities.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://test.vpp.midlands3cities.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.vpp.midlands3cities.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.vpp.midlands3cities.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.vpp.midlands3cities.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.vpp.midlands3cities.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://test.vpp.midlands3cities.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Virtual Postgraduate Platform (Test)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://test.vpp.midlands3cities.ac.uk/shibboleth-ds/logo_transparent.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "143"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Test M3C VPP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIJAN7ZAAJNPeUPMA0GCSqGSIb3DQEBBQUAMCkxJzAlBgNV\n\t\t\t\t\t\tBAMTHnRlc3QudnBwLm1pZGxhbmRzM2NpdGllcy5hYy51azAeFw0xNTA5MDgxMDQz\n\t\t\t\t\t\tMTFaFw0yNTA5MDUxMDQzMTFaMCkxJzAlBgNVBAMTHnRlc3QudnBwLm1pZGxhbmRz\n\t\t\t\t\t\tM2NpdGllcy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOVy\n\t\t\t\t\t\ti5GUm+F28xiNFY26JMyDaZrM4wuEguKF1PygIXygoZvSghGY+2UbElkVT8uq2RPw\n\t\t\t\t\t\t78VEevqqUkmImk74omwHqYslzDrUiPuKRNHSuA4juhf0fkfgws7/2uOzpsXwhSUr\n\t\t\t\t\t\tRhuXdYfYmoTC+mYf5W0p7akaYIaNpiJSMpfMr9QJ9XG1cstILpQLzWi1PrVYyQAe\n\t\t\t\t\t\t60FFP8iwXxny0d/GoCcUFcNVZHr/+RGOFpvfaTyx93EJ+MAQBqHjk9MZvCrzw8yp\n\t\t\t\t\t\t7USK13WTGscBtptQnFrdsrr/DgLYT47c1uO3msIPILLawG6zmuBc/cYGDnXys/x8\n\t\t\t\t\t\tRo2vgvitq0HTs5TV+zcCAwEAAaN/MH0wXAYDVR0RBFUwU4IedGVzdC52cHAubWlk\n\t\t\t\t\t\tbGFuZHMzY2l0aWVzLmFjLnVrhjFodHRwczovL3Rlc3QudnBwLm1pZGxhbmRzM2Np\n\t\t\t\t\t\tdGllcy5hYy51ay9zaGliYm9sZXRoMB0GA1UdDgQWBBRal19AbLQlRQl0TGi1/iWs\n\t\t\t\t\t\tv0laLDANBgkqhkiG9w0BAQUFAAOCAQEAgeQesA8L2G0ELsCf+2QeVDiNjC4pNJaY\n\t\t\t\t\t\t8fqjXdQnBnzuWr3l4oOA10xNfHWC00q8pWzhdltc5mB8HLLOTqGTg76DF65xBmKR\n\t\t\t\t\t\t1Wl2AAigCGOCIKuIeIRWn4d9SxO16aTGRIUhwnRYPk49s37ADm23/dtR1CWFjTM9\n\t\t\t\t\t\t37IYUFeXtf4YxIjKcjpWFM/P9zvNfipRugPIvitR+7QIVlbD0PMZlavt6016tPe3\n\t\t\t\t\t\tElHNeykkog1Bc/VQfYhB/x6uS+G/BMGKUMWHM/lw1n63G+xjAcge2Zd5tsE9Xlv7\n\t\t\t\t\t\tEMC0Aw8aFtO/f3rbkV8veNp4kgaxP2fF1LctGuFKMQThYzwcd9rjZQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.vpp.midlands3cities.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://test.vpp.midlands3cities.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.vpp.midlands3cities.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://test.vpp.midlands3cities.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://test.vpp.midlands3cities.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://test.vpp.midlands3cities.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.univ-artois.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "fed-admin@univ-artois.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.univ-artois.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-05-07T15:41:23Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univ-artois.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univ-artois.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.univ-artois.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-artois.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-artois.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 d'Artois"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 d'Artois"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUYze6+LHtf+jMXzwG8QReI+Kp9ZcwDQYJKoZIhvcNAQEF\nBQAwHTEbMBkGA1UEAxMSaWRwLnVuaXYtYXJ0b2lzLmZyMB4XDTEyMTExMzE2NTk1\nN1oXDTMyMTExMzE2NTk1N1owHTEbMBkGA1UEAxMSaWRwLnVuaXYtYXJ0b2lzLmZy\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkpHVwf2i1KtXPTZF/Qnr\ni0DtHLb6czJ/NmtUeYfWo8OM6P7Hkv58A9wXYX2eOX7RgFF4fyEbIn5rvFx3wdMG\nTwE2Cyq414V2HqCSXUtoAmWzhtuhQ5YuqvUkQ4QgUaSQMCAMxLmcAtY+XddfBuAg\nTtSzkh2JUaXUlIYHn8LKJw1r+Wp2X6gxZQyk8TAFzciOcwosVwOT8c2xAmK2ZYhL\n1CavsrTTRvXoHQobo2tmn2XrSHeSyjhMiTOJiDoCDu/XhOt781UdS9p0XFrHIru/\ndIzkv0Kk5uIqaz2idf2xX383qLZA0RfBXue4/yNu4X9aVxUT76JAB/fk+HegEAj8\nGwIDAQABo2swaTBIBgNVHREEQTA/ghJpZHAudW5pdi1hcnRvaXMuZnKGKWh0dHBz\nOi8vaWRwLnVuaXYtYXJ0b2lzLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRm\ng9Y0eqV3krWHdZkro9hJUiyqazANBgkqhkiG9w0BAQUFAAOCAQEAfv8qHbEOTIl2\nc1CNwZb4TfarrTY04ZHytU0tHNJWBL7c21yTO2a+vY1Xb2k3UYhWqPiujx6tY012\nU8mQmjAhk6geFaYgUsNfRxpviAAm9BaxdeMqo09sEE0IY6+Vl3m8gvSq1vuN0jGh\n6R1Jbqhj84FBJeSuRUF/VH+JiRxZA+FK3rP5Oo8DUKkAa3O59v1zzJjcw/gP2WaE\ns/eysRlm/+0o7pMPzFac9m9GmHWuyjifyoRWzNFaqCTEl2xG8eKp2h6lAAuPgu6w\nD/wjE0tsBNLEpO/XVtlNXVk2QQHpypl2XvrEpUpfOCjjb80yv4BD/1hONqUqp0GD\ntfGARKYulw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUSQ9eV+7UI3qVsdHcI6lx3hTPYsEwDQYJKoZIhvcNAQEF\nBQAwHTEbMBkGA1UEAxMSaWRwLnVuaXYtYXJ0b2lzLmZyMB4XDTA5MDUwNzA4NTky\nM1oXDTI5MDUwNzA4NTkyM1owHTEbMBkGA1UEAxMSaWRwLnVuaXYtYXJ0b2lzLmZy\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2UT2ctOv7Fz//FWQEyA2\nCEJWoCVCqiAKRMIVJTqnO+asQFnsCya4DHWEWzTRo9DgXBluIelrVbM7JgsG6eAT\ncfVZpRr2HejrhhvZ7j5FPCuy0oLNmMCtcmcqmkMzyDx2rCefJAoScwcBYoz1I8qO\nSAr8DUPcVTZdabL5+val+GdzheeHtUsSKX1Z8pRgL1NwWwR46DXty09Z/gsszY6b\nWJLZ3gs7oaQpdtUmAiMf95/F5mMb9AZZKj878fdztdVt4Vig4QTmAYaqF7GQ9oj6\n8A1gNL4iVHc8gIpGfKDFSFhWmpnLLLJoblREribjP5AWsJBSMkI5Nuu0J7ITDgXW\nvwIDAQABo2swaTBIBgNVHREEQTA/ghJpZHAudW5pdi1hcnRvaXMuZnKGKWh0dHBz\nOi8vaWRwLnVuaXYtYXJ0b2lzLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRy\n4kbAag+Wu/+JCxlZnf8v+nuV4DANBgkqhkiG9w0BAQUFAAOCAQEA1Z63uSJNJKme\nd/xq1BaFdQ6cAJQGxpCi9uDSD+GNcGK/auvUkmtxuCF6DAaY5mxSwJ9cx2KKEqiw\nXuJ3Vs7y3g7ez+0CvkoYZrq8pMRzhKZ+Lk1T8YJ/dNMnbqZjIAwYod1PtoJsYqjW\niEi2GWmBGh2jwbKI+zJJMquPH+aKIEA425xAse+E6Q+JtudVqzZoG0ktigtBpMlo\nBlby6pfzo7TZbF6FWkTbOfZtvsxW2XDFKvUYqXzpjJulQXljlKuh5Bjm+VBiFJLn\njm/fe9sgzhgCC7ONajuWtSG6VLszFulq60E8BV8TQiv3/ZwAnCDvQKxot/Hwd8jl\nyurjS9vfAQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 d'Artois"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-artois.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 d'Artois"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.wortech.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itservices@wortech.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Services"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itservices@wortech.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Services"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.wortech.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-08-26T15:44:57Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUVyuETbzgv93czUmf4A085Hv5gp0wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHTEbMBkGA1UEAxMSaWRwMi53b3J0ZWNoLmFjLnVrMB4XDTEyMDMyMzE0NDU1\n\t\t\t\t\t\tM1oXDTMyMDMyMzE0NDU1M1owHTEbMBkGA1UEAxMSaWRwMi53b3J0ZWNoLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAunWkrcL+hnjQ09UdnKBA\n\t\t\t\t\t\tBAw7lRBB3QYvOggtNnok7DzwWGpHcrXhx4KfzOfEJ3maUJYBdzRsT1dgt8F2vBkv\n\t\t\t\t\t\t2D7z8ysuV28CB3WTOYescJS67mZ3JuvIIWOOs20wpTwrKQxqA0Jl17by6VBrD0mg\n\t\t\t\t\t\t+h2Uo+DN18KFfOPchT7r8MrIzvGBZKyy5PSsHDteW2FcVeMKA01HGgtcKOhqAWGS\n\t\t\t\t\t\t2eAmRH4JpTAHW5GtuBpQucXBGF//+WWVCoJ9tR05IhuPZTYYvPE+wYN6m6530ZVt\n\t\t\t\t\t\tVjuQWq8bbK1vk4xLyTjkHv1ZB+8cU/h8zZjGyQYxYdEf2FvoujXBDZE0FezZ1y56\n\t\t\t\t\t\tFQIDAQABo2swaTBIBgNVHREEQTA/ghJpZHAyLndvcnRlY2guYWMudWuGKWh0dHBz\n\t\t\t\t\t\tOi8vaWRwMi53b3J0ZWNoLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQr\n\t\t\t\t\t\t3EpVDeHCnuNCrrLjnA2+sOs8NjANBgkqhkiG9w0BAQUFAAOCAQEACM1zfxfzXQ07\n\t\t\t\t\t\txIkBUtBRtzZGelYWvraMP1DHPt56zR0PSmqjIlA6dSZX48YQzSBBDbj3FvKxRp9F\n\t\t\t\t\t\tC7KrFook4NezTl5qifHGecDQoUF3i12YQJLpwWIfFoTeQWwgWlRkk5elSYuiqkTv\n\t\t\t\t\t\tJE5UzTJbRQP19dxNcOPFFNOdq2LRPgAYumiUf5jNggjT4EQWOxhcaeA+TE8mcAuo\n\t\t\t\t\t\teKDV+Q789bIiGbvRHpVekbME32dIf4PUuGeLSpTmMDPNkGUYK1xaIOe5lcjRNZeS\n\t\t\t\t\t\tvMgWcHDE/JL/TU1/E8l0OtwcrU4pNPVvcm5ibuX3ADUHT+ZO10elrc8pCMJCFuME\n\t\t\t\t\t\tcu2/4uSuxQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wortech.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.wortech.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.wortech.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp2.wortech.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.wortech.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp2.wortech.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2.wortech.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.wortech.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.wortech.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wortech.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUVyuETbzgv93czUmf4A085Hv5gp0wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHTEbMBkGA1UEAxMSaWRwMi53b3J0ZWNoLmFjLnVrMB4XDTEyMDMyMzE0NDU1\n\t\t\t\t\t\tM1oXDTMyMDMyMzE0NDU1M1owHTEbMBkGA1UEAxMSaWRwMi53b3J0ZWNoLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAunWkrcL+hnjQ09UdnKBA\n\t\t\t\t\t\tBAw7lRBB3QYvOggtNnok7DzwWGpHcrXhx4KfzOfEJ3maUJYBdzRsT1dgt8F2vBkv\n\t\t\t\t\t\t2D7z8ysuV28CB3WTOYescJS67mZ3JuvIIWOOs20wpTwrKQxqA0Jl17by6VBrD0mg\n\t\t\t\t\t\t+h2Uo+DN18KFfOPchT7r8MrIzvGBZKyy5PSsHDteW2FcVeMKA01HGgtcKOhqAWGS\n\t\t\t\t\t\t2eAmRH4JpTAHW5GtuBpQucXBGF//+WWVCoJ9tR05IhuPZTYYvPE+wYN6m6530ZVt\n\t\t\t\t\t\tVjuQWq8bbK1vk4xLyTjkHv1ZB+8cU/h8zZjGyQYxYdEf2FvoujXBDZE0FezZ1y56\n\t\t\t\t\t\tFQIDAQABo2swaTBIBgNVHREEQTA/ghJpZHAyLndvcnRlY2guYWMudWuGKWh0dHBz\n\t\t\t\t\t\tOi8vaWRwMi53b3J0ZWNoLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQr\n\t\t\t\t\t\t3EpVDeHCnuNCrrLjnA2+sOs8NjANBgkqhkiG9w0BAQUFAAOCAQEACM1zfxfzXQ07\n\t\t\t\t\t\txIkBUtBRtzZGelYWvraMP1DHPt56zR0PSmqjIlA6dSZX48YQzSBBDbj3FvKxRp9F\n\t\t\t\t\t\tC7KrFook4NezTl5qifHGecDQoUF3i12YQJLpwWIfFoTeQWwgWlRkk5elSYuiqkTv\n\t\t\t\t\t\tJE5UzTJbRQP19dxNcOPFFNOdq2LRPgAYumiUf5jNggjT4EQWOxhcaeA+TE8mcAuo\n\t\t\t\t\t\teKDV+Q789bIiGbvRHpVekbME32dIf4PUuGeLSpTmMDPNkGUYK1xaIOe5lcjRNZeS\n\t\t\t\t\t\tvMgWcHDE/JL/TU1/E8l0OtwcrU4pNPVvcm5ibuX3ADUHT+ZO10elrc8pCMJCFuME\n\t\t\t\t\t\tcu2/4uSuxQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Worcester College of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wortech.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Heart of Worcestershire College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp01.stfc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:obuservicedesk@rl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OBU Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Akkas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ali.akkas@stfc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ali"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp01.stfc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2007-08-07T13:24:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFFDCCA/ygAwIBAgIUfvk+kIvgObeH9FlTOzyxUUtzNfEwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwTTELMAkGA1UEBhMCQk0xGTAXBgNVBAoTEFF1b1ZhZGlzIExpbWl0ZWQxIzAh\n\t\t\t\t\t\tBgNVBAMTGlF1b1ZhZGlzIEdsb2JhbCBTU0wgSUNBIEcyMB4XDTE2MDMzMDEwMjEz\n\t\t\t\t\t\tOFoXDTE5MDMzMDEwMjEzNFowgZsxCzAJBgNVBAYTAkdCMRIwEAYDVQQIEwlXaWx0\n\t\t\t\t\t\tc2hpcmUxEDAOBgNVBAcTB1NXSU5ET04xMjAwBgNVBAoTKVNjaWVuY2UgYW5kIFRl\n\t\t\t\t\t\tY2hub2xvZ3kgRmFjaWxpdGllcyBDb3VuY2lsMRAwDgYDVQQLEwdSQUwtQ1NEMSAw\n\t\t\t\t\t\tHgYDVQQDExdzaGliYm9sZXRoMDEuc3RmYy5hYy51azCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBAIfVik5J16T3kGyLocrYaK+15zqqqQN/h4RYYRVYSsPk\n\t\t\t\t\t\tMX7srSQJq1nt/svUTKWBllfwySXccVX2YhgM/nuTbJtf6yKGNq1ZogsjRZv1m2rr\n\t\t\t\t\t\tyOHVwQEpFpGfdt0MmXVR1bvEi5O3+U+Ian6A8oTQMgmhVCXCTTdt3fAeYqN6DlwQ\n\t\t\t\t\t\t38JPFhIlbyEhrUgCnZeE19ftAdfAiwXD2bJy0hnuMh7j8PKIwsWkAx0a8BdQ1LKR\n\t\t\t\t\t\t/TgJhluGVZiMXgS4cljX0SJS9+eXIvNC1V+EMM03dOrP1mPJIfxY2mrEfwDbhC9H\n\t\t\t\t\t\t1OKRqdDYnHUTYNCSvhDiApRK7ApeobEqolHOr3cWfG0CAwEAAaOCAZswggGXMHMG\n\t\t\t\t\t\tCCsGAQUFBwEBBGcwZTAqBggrBgEFBQcwAYYeaHR0cDovL29jc3AucXVvdmFkaXNn\n\t\t\t\t\t\tbG9iYWwuY29tMDcGCCsGAQUFBzAChitodHRwOi8vdHJ1c3QucXVvdmFkaXNnbG9i\n\t\t\t\t\t\tYWwuY29tL3F2c3NsZzIuY3J0MCIGA1UdEQQbMBmCF3NoaWJib2xldGgwMS5zdGZj\n\t\t\t\t\t\tLmFjLnVrMFEGA1UdIARKMEgwRgYMKwYBBAG+WAACZAEBMDYwNAYIKwYBBQUHAgEW\n\t\t\t\t\t\tKGh0dHA6Ly93d3cucXVvdmFkaXNnbG9iYWwuY29tL3JlcG9zaXRvcnkwDgYDVR0P\n\t\t\t\t\t\tAQH/BAQDAgWgMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAfBgNVHSME\n\t\t\t\t\t\tGDAWgBSRGWKtWxenMPvw3jklsb2MubhRJzA6BgNVHR8EMzAxMC+gLaArhilodHRw\n\t\t\t\t\t\tOi8vY3JsLnF1b3ZhZGlzZ2xvYmFsLmNvbS9xdnNzbGcyLmNybDAdBgNVHQ4EFgQU\n\t\t\t\t\t\tTw22e+slTxSJFHTxYGz0C7Mw4gowDQYJKoZIhvcNAQELBQADggEBAHh9RRtAH0lX\n\t\t\t\t\t\tRcmNtw4jrDkcdnJcwjaddVpfQfVvIFGqB4NkKOmccYugppso5+UEHcpHivsMcKAa\n\t\t\t\t\t\tQok/yANO6fNzdKCjZIApV9Q9rpwIQSbJlXbg/DvUYc9mqeUKOMlIzw3Q+G1XK4o8\n\t\t\t\t\t\tB5HfGyldcM8X+NyiC8tocRG4iFdMT2J4M1cIfeDn9xHPDzWex9bZLktLkssdzjtw\n\t\t\t\t\t\tiKTQHPv55BOqJ12e0rTNTilpErtzr5AhYXDKKNYAHTYxHcyI75aqE+/11dsHdOKb\n\t\t\t\t\t\toUdCBAJx12/CTfHNdDOdr7FHk4fwcUsCvAUTL8hSwSv+fu00lpRe/UoMk26E4Xkv\n\t\t\t\t\t\tayT9vCad35E="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stfc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth01.stfc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth01.stfc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth01.stfc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth01.stfc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth01.stfc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth01.stfc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth01.stfc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth01.stfc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stfc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFFDCCA/ygAwIBAgIUfvk+kIvgObeH9FlTOzyxUUtzNfEwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwTTELMAkGA1UEBhMCQk0xGTAXBgNVBAoTEFF1b1ZhZGlzIExpbWl0ZWQxIzAh\n\t\t\t\t\t\tBgNVBAMTGlF1b1ZhZGlzIEdsb2JhbCBTU0wgSUNBIEcyMB4XDTE2MDMzMDEwMjEz\n\t\t\t\t\t\tOFoXDTE5MDMzMDEwMjEzNFowgZsxCzAJBgNVBAYTAkdCMRIwEAYDVQQIEwlXaWx0\n\t\t\t\t\t\tc2hpcmUxEDAOBgNVBAcTB1NXSU5ET04xMjAwBgNVBAoTKVNjaWVuY2UgYW5kIFRl\n\t\t\t\t\t\tY2hub2xvZ3kgRmFjaWxpdGllcyBDb3VuY2lsMRAwDgYDVQQLEwdSQUwtQ1NEMSAw\n\t\t\t\t\t\tHgYDVQQDExdzaGliYm9sZXRoMDEuc3RmYy5hYy51azCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBAIfVik5J16T3kGyLocrYaK+15zqqqQN/h4RYYRVYSsPk\n\t\t\t\t\t\tMX7srSQJq1nt/svUTKWBllfwySXccVX2YhgM/nuTbJtf6yKGNq1ZogsjRZv1m2rr\n\t\t\t\t\t\tyOHVwQEpFpGfdt0MmXVR1bvEi5O3+U+Ian6A8oTQMgmhVCXCTTdt3fAeYqN6DlwQ\n\t\t\t\t\t\t38JPFhIlbyEhrUgCnZeE19ftAdfAiwXD2bJy0hnuMh7j8PKIwsWkAx0a8BdQ1LKR\n\t\t\t\t\t\t/TgJhluGVZiMXgS4cljX0SJS9+eXIvNC1V+EMM03dOrP1mPJIfxY2mrEfwDbhC9H\n\t\t\t\t\t\t1OKRqdDYnHUTYNCSvhDiApRK7ApeobEqolHOr3cWfG0CAwEAAaOCAZswggGXMHMG\n\t\t\t\t\t\tCCsGAQUFBwEBBGcwZTAqBggrBgEFBQcwAYYeaHR0cDovL29jc3AucXVvdmFkaXNn\n\t\t\t\t\t\tbG9iYWwuY29tMDcGCCsGAQUFBzAChitodHRwOi8vdHJ1c3QucXVvdmFkaXNnbG9i\n\t\t\t\t\t\tYWwuY29tL3F2c3NsZzIuY3J0MCIGA1UdEQQbMBmCF3NoaWJib2xldGgwMS5zdGZj\n\t\t\t\t\t\tLmFjLnVrMFEGA1UdIARKMEgwRgYMKwYBBAG+WAACZAEBMDYwNAYIKwYBBQUHAgEW\n\t\t\t\t\t\tKGh0dHA6Ly93d3cucXVvdmFkaXNnbG9iYWwuY29tL3JlcG9zaXRvcnkwDgYDVR0P\n\t\t\t\t\t\tAQH/BAQDAgWgMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAfBgNVHSME\n\t\t\t\t\t\tGDAWgBSRGWKtWxenMPvw3jklsb2MubhRJzA6BgNVHR8EMzAxMC+gLaArhilodHRw\n\t\t\t\t\t\tOi8vY3JsLnF1b3ZhZGlzZ2xvYmFsLmNvbS9xdnNzbGcyLmNybDAdBgNVHQ4EFgQU\n\t\t\t\t\t\tTw22e+slTxSJFHTxYGz0C7Mw4gowDQYJKoZIhvcNAQELBQADggEBAHh9RRtAH0lX\n\t\t\t\t\t\tRcmNtw4jrDkcdnJcwjaddVpfQfVvIFGqB4NkKOmccYugppso5+UEHcpHivsMcKAa\n\t\t\t\t\t\tQok/yANO6fNzdKCjZIApV9Q9rpwIQSbJlXbg/DvUYc9mqeUKOMlIzw3Q+G1XK4o8\n\t\t\t\t\t\tB5HfGyldcM8X+NyiC8tocRG4iFdMT2J4M1cIfeDn9xHPDzWex9bZLktLkssdzjtw\n\t\t\t\t\t\tiKTQHPv55BOqJ12e0rTNTilpErtzr5AhYXDKKNYAHTYxHcyI75aqE+/11dsHdOKb\n\t\t\t\t\t\toUdCBAJx12/CTfHNdDOdr7FHk4fwcUsCvAUTL8hSwSv+fu00lpRe/UoMk26E4Xkv\n\t\t\t\t\t\tayT9vCad35E="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Science and Technology Facilities Council"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.scitech.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Science and Technology Facilities Council"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://wikis.ncl.ac.uk/shibboleth/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Franks"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chris.franks@ncl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Franks"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chris.franks@ncl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://wikis.ncl.ac.uk/shibboleth/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Newcastle University Wiki Server"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ncl.ac.uk/itservice/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Newcastle upon Tyne"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://wikis.ncl.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://wikis.ncl.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wikis.ncl.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wikis.ncl.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://wikis.ncl.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC0zCCAbugAwIBAgIJAJ5lZZ3UDF+vMA0GCSqGSIb3DQEBBQUAMA8xDTALBgNV\n\t\t\t\t\t\tBAMTBHdvb2wwHhcNMTAwNzIxMTUwNjAyWhcNMjAwNzE4MTUwNjAyWjAPMQ0wCwYD\n\t\t\t\t\t\tVQQDEwR3b29sMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAq9QD8/89\n\t\t\t\t\t\tD4fl/yN46TE0Et2YC+V42N2i+mVGf5RSajMAL5/kA72SMDKlLs3l8npwHhQYqbx1\n\t\t\t\t\t\tku4UX+q+VwWTzRu5zzX0LHIstRQwexB9ht6LHt+Uh+keEz/uIagt1J8ORtH1yU81\n\t\t\t\t\t\tr/q+pvnmzInZ8fMTEntwrnZmHZr1OxXrd55YlpYIFbGqHsnov9jmSQcpHRe3dGMN\n\t\t\t\t\t\twuFvxL9xZO3dFem0hL3HpB/i2rObcTx9QXjCmf3SwaKOOA9Mug9bxCHUmd15eS8h\n\t\t\t\t\t\tX396YwLmsl5OeIRceedKj1zW3xLAeqckyPJ9hjIY5qcRpnnRnKRUxTe+jNbWc+hf\n\t\t\t\t\t\t8TBhvibjUUwmUQIDAQABozIwMDAPBgNVHREECDAGggR3b29sMB0GA1UdDgQWBBSV\n\t\t\t\t\t\t6Mqy3JMWnbtIamyrPz/QWZVA5jANBgkqhkiG9w0BAQUFAAOCAQEAnb8LFzMKf73A\n\t\t\t\t\t\tMt8+ATRNF2kGgTbNybqCCYytGtwRCklUm/2+ZyjxygRWBzZ+GhRf1n9lKtgaJVzr\n\t\t\t\t\t\tdCD0Xe52goYAfZTzf/QV05IHu6rpVDa4z96UlOa138GW5iwPMrvwAktEQVR8OePo\n\t\t\t\t\t\tgx51PZjK4oz1i6RnwOcMQo5Qoa9pIW2ikoH9DvpP9vzWEhZ00fk7Rw3iy4VMnZL2\n\t\t\t\t\t\tlcL8YuTGkE1YWdFoQHkQpZ1fAHZ6cJMLcqFGLMRWGrDUqtIT1c507zFu9VLLuMGT\n\t\t\t\t\t\t+/se1eh3vEctX9ZbP3mjDEzhlm3ru/jHCQmBfaneobWjg11tv9WUmBBz0FlcXiLx\n\t\t\t\t\t\tFht0jB8U9w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC0zCCAbugAwIBAgIJAJ5lZZ3UDF+vMA0GCSqGSIb3DQEBBQUAMA8xDTALBgNV\n\t\t\t\t\t\tBAMTBHdvb2wwHhcNMTAwNzIxMTUwNjAyWhcNMjAwNzE4MTUwNjAyWjAPMQ0wCwYD\n\t\t\t\t\t\tVQQDEwR3b29sMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAq9QD8/89\n\t\t\t\t\t\tD4fl/yN46TE0Et2YC+V42N2i+mVGf5RSajMAL5/kA72SMDKlLs3l8npwHhQYqbx1\n\t\t\t\t\t\tku4UX+q+VwWTzRu5zzX0LHIstRQwexB9ht6LHt+Uh+keEz/uIagt1J8ORtH1yU81\n\t\t\t\t\t\tr/q+pvnmzInZ8fMTEntwrnZmHZr1OxXrd55YlpYIFbGqHsnov9jmSQcpHRe3dGMN\n\t\t\t\t\t\twuFvxL9xZO3dFem0hL3HpB/i2rObcTx9QXjCmf3SwaKOOA9Mug9bxCHUmd15eS8h\n\t\t\t\t\t\tX396YwLmsl5OeIRceedKj1zW3xLAeqckyPJ9hjIY5qcRpnnRnKRUxTe+jNbWc+hf\n\t\t\t\t\t\t8TBhvibjUUwmUQIDAQABozIwMDAPBgNVHREECDAGggR3b29sMB0GA1UdDgQWBBSV\n\t\t\t\t\t\t6Mqy3JMWnbtIamyrPz/QWZVA5jANBgkqhkiG9w0BAQUFAAOCAQEAnb8LFzMKf73A\n\t\t\t\t\t\tMt8+ATRNF2kGgTbNybqCCYytGtwRCklUm/2+ZyjxygRWBzZ+GhRf1n9lKtgaJVzr\n\t\t\t\t\t\tdCD0Xe52goYAfZTzf/QV05IHu6rpVDa4z96UlOa138GW5iwPMrvwAktEQVR8OePo\n\t\t\t\t\t\tgx51PZjK4oz1i6RnwOcMQo5Qoa9pIW2ikoH9DvpP9vzWEhZ00fk7Rw3iy4VMnZL2\n\t\t\t\t\t\tlcL8YuTGkE1YWdFoQHkQpZ1fAHZ6cJMLcqFGLMRWGrDUqtIT1c507zFu9VLLuMGT\n\t\t\t\t\t\t+/se1eh3vEctX9ZbP3mjDEzhlm3ru/jHCQmBfaneobWjg11tv9WUmBBz0FlcXiLx\n\t\t\t\t\t\tFht0jB8U9w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://wikis.ncl.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://wikis.ncl.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wikis.ncl.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wikis.ncl.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wikis.ncl.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://wikis.ncl.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wikis.ncl.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://wikis.ncl.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://wikis.ncl.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://wikis.ncl.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://namidp.services.uu.nl/nidp/saml2/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://namidp.services.uu.nl/nidp/saml2/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2014-09-01T16:50:23Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/dd83d3078a00c0103c00102b7d61c479",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "soliscom.uu.nl"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uu.nl"
              },
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Universiteit Utrecht"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Universiteit Utrecht (NetIQ)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/uu.png",
                    "height": "36",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universiteit Utrecht"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universiteit Utrecht"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universiteit Utrecht"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universiteit Utrecht"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uu.nl/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uu.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universiteit Utrecht"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universiteit Utrecht"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.uvm.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "saa@uvm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Systems Architecture and Administration"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "security@uvm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Security Officer"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpline@uvm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uvm.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uvm.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uvm.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFUjCCBDqgAwIBAgIRAJpLcZsSJzmf55NyB+1EceUwDQYJKoZIhvcNAQEFBQAw\nUTELMAkGA1UEBhMCVVMxEjAQBgNVBAoTCUludGVybmV0MjERMA8GA1UECxMISW5D\nb21tb24xGzAZBgNVBAMTEkluQ29tbW9uIFNlcnZlciBDQTAeFw0xMzExMjUwMDAw\nMDBaFw0xNTExMjUyMzU5NTlaMIHBMQswCQYDVQQGEwJVUzEOMAwGA1UEERMFMDU0\nMDUxCzAJBgNVBAgTAlZUMRMwEQYDVQQHEwpCdXJsaW5ndG9uMSEwHwYDVQQJExg4\nNSBTb3V0aCBQcm9zcGVjdCBTdHJlZXQxHjAcBgNVBAoTFVVuaXZlcnNpdHkgb2Yg\nVmVybW9udDEnMCUGA1UECxMeRW50ZXJwcmlzZSBUZWNobm9sb2d5IFNlcnZpY2Vz\nMRQwEgYDVQQDEwtpZHAudXZtLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBAO02BTdgJYJ1umJvRaLGVmBBa3nOV9uSyKov+zeZZfH1IqfhOgqT+mDk\nAVKfbTNh0qF/S0IweZIBiGkPue1+YPz0DnV3g95RzV5rrJ/p6Poc+LGnobWn4vvC\nPQr73mfhNZowPwAM9VJP1290ALpi3ln4ASCarIZag5ovkn8mAB8/8K6yNK+7X3Pu\nWHkchTVFEXzmZp2DTVgCEcJFyZf9kiGeHt1+Sn1KcgpkhXT6crYklFQC/nvjA3oo\nJu6O+GoAQF9lt4zaZONm55SUUlS/avuxfZSJt83FWf0NILiuq4pKaNDAf/9o7sgB\n8anDRO29C0goFSQJmSVhhtU3bG35qA8CAwEAAaOCAbIwggGuMB8GA1UdIwQYMBaA\nFEhPWvovSppe4FDza3tVpd71vjRdMB0GA1UdDgQWBBTKmnxvf209+AM7+jdbzdzR\neSv3IDAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggr\nBgEFBQcDAQYIKwYBBQUHAwIwZwYDVR0gBGAwXjBSBgwrBgEEAa4jAQQDAQEwQjBA\nBggrBgEFBQcCARY0aHR0cHM6Ly93d3cuaW5jb21tb24ub3JnL2NlcnQvcmVwb3Np\ndG9yeS9jcHNfc3NsLnBkZjAIBgZngQwBAgIwPQYDVR0fBDYwNDAyoDCgLoYsaHR0\ncDovL2NybC5pbmNvbW1vbi5vcmcvSW5Db21tb25TZXJ2ZXJDQS5jcmwwbwYIKwYB\nBQUHAQEEYzBhMDkGCCsGAQUFBzAChi1odHRwOi8vY2VydC5pbmNvbW1vbi5vcmcv\nSW5Db21tb25TZXJ2ZXJDQS5jcnQwJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmlu\nY29tbW9uLm9yZzAWBgNVHREEDzANggtpZHAudXZtLmVkdTANBgkqhkiG9w0BAQUF\nAAOCAQEAIDDbRJaVlbIHelz9+g25LuMR4c88NkEU+AU7lOSwqQOQV3YwMMJBYJLg\n7eXYlB9NFDnwG0V69HAwopAwWt5TdJt4PJSo+xLeiviiAispFySDranhfI94qDC8\nJf8l1gUVUDL+B3cEWnQklx68H1lfSLN94GB5bD7xt+39EecYwFnzs+RpO4M1oO7L\nHxjbXfPhY5K37DkkhMHiK9+jCRTYbj/eADvpVU4ejP3xSYInk0066P9msJ3gRkkH\nkk33CouamgWP4Pee76HO+VGW0xIz/yMZJXiTeKosuKskZCUBvJwToIm1iuIOG2jP\nqjXzgEnZ8+QfHnA0xxrbXh07lwGqag=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEMzCCAxugAwIBAgIJAOuLhHtr2WBAMA0GCSqGSIb3DQEBBQUAMIGvMQswCQYD\nVQQGEwJVUzEQMA4GA1UECAwHVmVybW9udDETMBEGA1UEBwwKQnVybGluZ3RvbjEe\nMBwGA1UECgwVVW5pdmVyc2l0eSBvZiBWZXJtb250MScwJQYDVQQLDB5FbnRlcnBy\naXNlIFRlY2hub2xvZ3kgU2VydmljZXMxFDASBgNVBAMMC2lkcC51dm0uZWR1MRow\nGAYJKoZIhvcNAQkBFgtzYWFAdXZtLmVkdTAeFw0xNDA0MDgxNzEzMjJaFw0yNjA0\nMDUxNzEzMjJaMIGvMQswCQYDVQQGEwJVUzEQMA4GA1UECAwHVmVybW9udDETMBEG\nA1UEBwwKQnVybGluZ3RvbjEeMBwGA1UECgwVVW5pdmVyc2l0eSBvZiBWZXJtb250\nMScwJQYDVQQLDB5FbnRlcnByaXNlIFRlY2hub2xvZ3kgU2VydmljZXMxFDASBgNV\nBAMMC2lkcC51dm0uZWR1MRowGAYJKoZIhvcNAQkBFgtzYWFAdXZtLmVkdTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJt7xhhCKcVL2j8XvJXe33vkuSji\ndZVzviuW2c7TAHWaHNe9fxc5N6ssYj+ROUJSlWlOgfofOTxQRu4sJGZKDty0Dbik\nXtcjNChZd3pIt8AVhNjWadgIfx7gP8IoA9N7X5QkWS7iZuuyGVR0yTnNdCb4FJL3\nQUU+ajrZMQ+27BXnHYun+GkWuu3+tajU36bMAnqjTdj7NFwmsfWeIzshgraSwkwJ\njhfel2HtdfpeLK6qHSQvU6FeRzbSPx2xedU2VSUq49vZigyEw2Fa9Zw8SCJfhlo5\nnzJuPVTNE0XMkk5dnoqadRsCn0KCpBwHHGi35nGITyYBGCEQWo/ve0lY1qcCAwEA\nAaNQME4wHQYDVR0OBBYEFPVdAz1F17jrlRRBzlL80HN4XVXsMB8GA1UdIwQYMBaA\nFPVdAz1F17jrlRRBzlL80HN4XVXsMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEF\nBQADggEBADhXfpByGRv/2I2BjVm2pIPthi38K7oeZ26cr76wDkFVxcJMqJwX5hbo\neAeFD33dg+O2fQREMDifBnjzhXyLywRAVZUpuw1eKG3UVpPTW28nHFcz0gPBbwSv\nJ2zmELg+J411jdPmewl/FHvHJ2tktWAA25i6uX3g0Nxh58o3EcYZZXiSE5Y6695k\nBC/BRuiGNnpU9qPLNakDDngWHtT9n3Vik5yU8hIdjqFr54D/+Cuu7igmZ3Rw+SJ2\nvjh8uRVZP56GSzxu2j+8GR5XnCegIroPqrHp+E57CW5BcJf4EGXoDWX8P6DD8Nys\nD82TCdiNkm20wl1h/lwK1Vs+qR1fbEc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uvm.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.uvm.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uvm.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.uvm.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uvm.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uvm.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uvm.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uvm.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.uvm.edu/it/account/?Page=sso.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Vermont"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Vermont Identity Provider"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.uvm.edu/www/images/templates/uvmlogo-words.gif",
                    "lang": "en",
                    "height": "31",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "290"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://idp.uvm.edu/idp/privacy.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFUjCCBDqgAwIBAgIRAJpLcZsSJzmf55NyB+1EceUwDQYJKoZIhvcNAQEFBQAw\nUTELMAkGA1UEBhMCVVMxEjAQBgNVBAoTCUludGVybmV0MjERMA8GA1UECxMISW5D\nb21tb24xGzAZBgNVBAMTEkluQ29tbW9uIFNlcnZlciBDQTAeFw0xMzExMjUwMDAw\nMDBaFw0xNTExMjUyMzU5NTlaMIHBMQswCQYDVQQGEwJVUzEOMAwGA1UEERMFMDU0\nMDUxCzAJBgNVBAgTAlZUMRMwEQYDVQQHEwpCdXJsaW5ndG9uMSEwHwYDVQQJExg4\nNSBTb3V0aCBQcm9zcGVjdCBTdHJlZXQxHjAcBgNVBAoTFVVuaXZlcnNpdHkgb2Yg\nVmVybW9udDEnMCUGA1UECxMeRW50ZXJwcmlzZSBUZWNobm9sb2d5IFNlcnZpY2Vz\nMRQwEgYDVQQDEwtpZHAudXZtLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBAO02BTdgJYJ1umJvRaLGVmBBa3nOV9uSyKov+zeZZfH1IqfhOgqT+mDk\nAVKfbTNh0qF/S0IweZIBiGkPue1+YPz0DnV3g95RzV5rrJ/p6Poc+LGnobWn4vvC\nPQr73mfhNZowPwAM9VJP1290ALpi3ln4ASCarIZag5ovkn8mAB8/8K6yNK+7X3Pu\nWHkchTVFEXzmZp2DTVgCEcJFyZf9kiGeHt1+Sn1KcgpkhXT6crYklFQC/nvjA3oo\nJu6O+GoAQF9lt4zaZONm55SUUlS/avuxfZSJt83FWf0NILiuq4pKaNDAf/9o7sgB\n8anDRO29C0goFSQJmSVhhtU3bG35qA8CAwEAAaOCAbIwggGuMB8GA1UdIwQYMBaA\nFEhPWvovSppe4FDza3tVpd71vjRdMB0GA1UdDgQWBBTKmnxvf209+AM7+jdbzdzR\neSv3IDAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggr\nBgEFBQcDAQYIKwYBBQUHAwIwZwYDVR0gBGAwXjBSBgwrBgEEAa4jAQQDAQEwQjBA\nBggrBgEFBQcCARY0aHR0cHM6Ly93d3cuaW5jb21tb24ub3JnL2NlcnQvcmVwb3Np\ndG9yeS9jcHNfc3NsLnBkZjAIBgZngQwBAgIwPQYDVR0fBDYwNDAyoDCgLoYsaHR0\ncDovL2NybC5pbmNvbW1vbi5vcmcvSW5Db21tb25TZXJ2ZXJDQS5jcmwwbwYIKwYB\nBQUHAQEEYzBhMDkGCCsGAQUFBzAChi1odHRwOi8vY2VydC5pbmNvbW1vbi5vcmcv\nSW5Db21tb25TZXJ2ZXJDQS5jcnQwJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmlu\nY29tbW9uLm9yZzAWBgNVHREEDzANggtpZHAudXZtLmVkdTANBgkqhkiG9w0BAQUF\nAAOCAQEAIDDbRJaVlbIHelz9+g25LuMR4c88NkEU+AU7lOSwqQOQV3YwMMJBYJLg\n7eXYlB9NFDnwG0V69HAwopAwWt5TdJt4PJSo+xLeiviiAispFySDranhfI94qDC8\nJf8l1gUVUDL+B3cEWnQklx68H1lfSLN94GB5bD7xt+39EecYwFnzs+RpO4M1oO7L\nHxjbXfPhY5K37DkkhMHiK9+jCRTYbj/eADvpVU4ejP3xSYInk0066P9msJ3gRkkH\nkk33CouamgWP4Pee76HO+VGW0xIz/yMZJXiTeKosuKskZCUBvJwToIm1iuIOG2jP\nqjXzgEnZ8+QfHnA0xxrbXh07lwGqag=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEMzCCAxugAwIBAgIJAOuLhHtr2WBAMA0GCSqGSIb3DQEBBQUAMIGvMQswCQYD\nVQQGEwJVUzEQMA4GA1UECAwHVmVybW9udDETMBEGA1UEBwwKQnVybGluZ3RvbjEe\nMBwGA1UECgwVVW5pdmVyc2l0eSBvZiBWZXJtb250MScwJQYDVQQLDB5FbnRlcnBy\naXNlIFRlY2hub2xvZ3kgU2VydmljZXMxFDASBgNVBAMMC2lkcC51dm0uZWR1MRow\nGAYJKoZIhvcNAQkBFgtzYWFAdXZtLmVkdTAeFw0xNDA0MDgxNzEzMjJaFw0yNjA0\nMDUxNzEzMjJaMIGvMQswCQYDVQQGEwJVUzEQMA4GA1UECAwHVmVybW9udDETMBEG\nA1UEBwwKQnVybGluZ3RvbjEeMBwGA1UECgwVVW5pdmVyc2l0eSBvZiBWZXJtb250\nMScwJQYDVQQLDB5FbnRlcnByaXNlIFRlY2hub2xvZ3kgU2VydmljZXMxFDASBgNV\nBAMMC2lkcC51dm0uZWR1MRowGAYJKoZIhvcNAQkBFgtzYWFAdXZtLmVkdTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJt7xhhCKcVL2j8XvJXe33vkuSji\ndZVzviuW2c7TAHWaHNe9fxc5N6ssYj+ROUJSlWlOgfofOTxQRu4sJGZKDty0Dbik\nXtcjNChZd3pIt8AVhNjWadgIfx7gP8IoA9N7X5QkWS7iZuuyGVR0yTnNdCb4FJL3\nQUU+ajrZMQ+27BXnHYun+GkWuu3+tajU36bMAnqjTdj7NFwmsfWeIzshgraSwkwJ\njhfel2HtdfpeLK6qHSQvU6FeRzbSPx2xedU2VSUq49vZigyEw2Fa9Zw8SCJfhlo5\nnzJuPVTNE0XMkk5dnoqadRsCn0KCpBwHHGi35nGITyYBGCEQWo/ve0lY1qcCAwEA\nAaNQME4wHQYDVR0OBBYEFPVdAz1F17jrlRRBzlL80HN4XVXsMB8GA1UdIwQYMBaA\nFPVdAz1F17jrlRRBzlL80HN4XVXsMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEF\nBQADggEBADhXfpByGRv/2I2BjVm2pIPthi38K7oeZ26cr76wDkFVxcJMqJwX5hbo\neAeFD33dg+O2fQREMDifBnjzhXyLywRAVZUpuw1eKG3UVpPTW28nHFcz0gPBbwSv\nJ2zmELg+J411jdPmewl/FHvHJ2tktWAA25i6uX3g0Nxh58o3EcYZZXiSE5Y6695k\nBC/BRuiGNnpU9qPLNakDDngWHtT9n3Vik5yU8hIdjqFr54D/+Cuu7igmZ3Rw+SJ2\nvjh8uRVZP56GSzxu2j+8GR5XnCegIroPqrHp+E57CW5BcJf4EGXoDWX8P6DD8Nys\nD82TCdiNkm20wl1h/lwK1Vs+qR1fbEc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idp.uvm.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Vermont"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uvm.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Vermont"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.inshea.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "SOCCALINGAM"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Sejiane.Soccalingam@inshea.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "HAFFNER"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Didier.Haffner@inshea.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.inshea.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-05-22T17:43:45Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.inshea.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.inshea.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.inshea.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "inshea.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.inshea.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "staff and students"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnel et \u00e9tudiants"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "11",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INS HEA - Institut national sup\u00e9rieur de formation et de recherche pour l'\u00e9ducation des jeunes handicap\u00e9s et les enseignements adapt\u00e9s"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INS HEA - Institut national sup\u00e9rieur de formation et de recherche pour l'\u00e9ducation des jeunes handicap\u00e9s et les enseignements adapt\u00e9s"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUJbK6nstF0pm/+lEcGZ5dEj8AFb4wDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAwwNaWRwLmluc2hlYS5mcjAeFw0xNTA1MjAwODUxMzhaFw0z\nNTA1MjAwODUxMzhaMBgxFjAUBgNVBAMMDWlkcC5pbnNoZWEuZnIwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCahuHmZ6NDcW9HfvttC0XLT2KxuADsDKJe\n2ACC5LNMAKbPDi6V3kjOA1Zk+dbI4BfSGDc0fGuJG/AxwPs2Aib5iNDnqYAGCdsF\nk+Yy30cxyIgAOsSQHcM6ylmiGbSUu/cMi2GnV5wR+hB0Idg4unraPQZZKS8BYAk9\nwsY1/qiEE4yD9xIf+xZN5ayMNwhuuCAtOYCPU/dM1hJS4lcmjxWT6flgiTLqgcd2\nUHMeyjgAx+0XJdDB2sterF9IQaRLW3SeVss1VulpDGuH4a9pIRHwXkZSMgy+l5ta\nzTI58LO55BL9ECg3N3iVehYmdMJyeF4PFUnwAgmv3qdU+SeYlm69AgMBAAGjYTBf\nMB0GA1UdDgQWBBTeDLA+ljfEcR8dCt4jK+6NTNns6zA+BgNVHREENzA1gg1pZHAu\naW5zaGVhLmZyhiRodHRwczovL2lkcC5pbnNoZWEuZnIvaWRwL3NoaWJib2xldGgw\nDQYJKoZIhvcNAQEFBQADggEBAFG8x0TGKW8ksapTCq7Zo3jUThjmlqxCVjVj8T//\nSL5wLdXoqT/ykUHwk/w3bhB0suGepIez/UpUahK/wiNxJlWO/HV5fcVucf3Y+X7E\nipYxj92wwzC5c+BU0Hp/l4YLe/VTI2WRn6Ir1h09udLxrnanvdsqV1FN8wI0bB9T\nBf9T9mnR+nYvfPnk5/hox3490z7h9wOddP/I+BT55OOCecjZZxc7BhcqCVMHVYop\n7giVJzQjJAvZh/gTvvZE3LFD83JAwjLBovLc8ZPb7xPNy7fk+9eH1hOkEeOs9kcZ\n549vcVK5oOJCGuRuLlb0XayJKoOPX9vZ+DEGQdVAZaRbVuI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INS HEA - Institut national sup\u00e9rieur de formation et de recherche pour l'\u00e9ducation des jeunes handicap\u00e9s et les enseignements adapt\u00e9s"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.inshea.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INS HEA - Institut national sup\u00e9rieur de formation et de recherche pour l'\u00e9ducation des jeunes handicap\u00e9s et les enseignements adapt\u00e9s"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.marshall.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "aractingi1@marshall.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Edward Aractingi"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "systems@marshall.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Systems Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.marshall.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.marshall.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.marshall.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.marshall.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.marshall.edu/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.marshall.edu/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "marshall.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idp.marshall.edu/idpinfo.html"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.marshall.edu/logo.png",
                    "lang": "en",
                    "height": "200",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "800"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://idp.marshall.edu/idp_privacy.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Marshall University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVANGAwu+l/UWmtqeKbBJJeQMw2rmCMA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMMEGlkcC5tYXJzaGFsbC5lZHUwHhcNMTUwMTI2MTg1MjIy\nWhcNMzUwMTI2MTg1MjIyWjAbMRkwFwYDVQQDDBBpZHAubWFyc2hhbGwuZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkQnVnt67CT4IQe666qWZD8WI\n/lIHAF1Zm5bGkCiBR2Bz1DhGEPUzGbkbbBFPQK5tmYG71eE0cRckXQRwZNyrTo+Z\n5dB303LF2vXBGDxC5NTP5c2xKy/4OC+nMGkVp6Nwwhs0mLQpR16B438m6DcmiNdp\nvuoWpf25/Azy7RskIKQdXwmfmENbidvHEclS/A13aCLw1KIDvKViPAmYUpzmEVqd\nXUuEOeNCGaUFb2spJ8HqhWHZUpt/k/OjvY02CHDIiBF1SuUtcfdGltOJkMMM35Bs\njs1JeGotEy4IhLYmbpwOBSXbMK7xfCmaf0xQkI9ZLxI9/yGYy+f+WseNrCqjYwID\nAQABo2cwZTAdBgNVHQ4EFgQUPhjqgMn/CPXKcLThs7V9WqJA8ncwRAYDVR0RBD0w\nO4IQaWRwLm1hcnNoYWxsLmVkdYYnaHR0cHM6Ly9pZHAubWFyc2hhbGwuZWR1L2lk\ncC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBBQUAA4IBAQBANyIvhLg35hH8hscI3tZa\nHOtCyl0HDpHCNuwWY2k6NPt5LGhPR2YzShyTaxw4uXr/b8LGJt5M4r7xponFJzMl\nwewXOuiqbWnEBFsOIti6VgQxe5ezssfe/FBT9ajXJeaDdvOgynaIYMh8jBHCuYF3\nKTCjPZPIfa7HqJo093cyBY96qCYkYXXJfYGsb/AisqHXyzQQHbIQsW8dLC+ouTEa\nR21kn0ymq/VE5kJml2rLvTB8Msh76fdsxVz1IHvXexZCiuGIYHbVfJEzOlukooug\nt17n6E3j/nC8A5MtLGLUCIpW+p7tJdEF7fRdBxvs2ZyC8NaXfkSJX/ELF5P3km3d"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idp.marshall.edu/error.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Marshall University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.marshall.edu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Marshall University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.lsbsu.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.lsbsu.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-09-09T12:15:48Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "London South Bank University Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lsbsu.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.lsbsu.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.lsbsu.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.lsbsu.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.lsbsu.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.lsbsu.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.lsbsu.org/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.lsbsu.org/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.lsbsu.org/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.lsbsu.org/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.lsbsu.org/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.lsbsu.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.lsbsu.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.lsbsu.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.lsbsu.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.lsbsu.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.lsbsu.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://aai.phzg.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@phzg.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "PH Zug"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Benhauresch"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@phzg.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Abdel"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://aai.phzg.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2016-02-03T12:37:23Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUOOTmZVjBjC279frTIAaYq+ifz90wDQYJKoZIhvcNAQEL\nBQAwFjEUMBIGA1UEAwwLYWFpLnBoemcuY2gwHhcNMTYwMTI1MTQyNjAwWhcNMTkw\nMTI1MTQyNjAwWjAWMRQwEgYDVQQDDAthYWkucGh6Zy5jaDCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAJ51IJDg8QXH85nk4kJAlGdhCYmWwpKbDs6EXOPd\nDgJrxFaagDye9pEhn0yPUGmffwoYNThgnwK1ey/BScMkyj6T3tf5keRJb310Kx+c\n7k/njd95etdPr66hMUCuEqjfRDQHahWmfSwRlqrBqGFsqakXEyeb/QKBnNabLTJF\nrro4J/Ksi3nhDULuUZdyMgVmYlLYzDpom8rGkthO2NfdDjJglU3P2MQEnGhK9QBH\n0eWfpfSkJAwnhClRiZCrGwQYttd9TSCeBWzKjw2oc3hJyLjjj9sFoF9tu2Gkq5uz\nI1qLLxEkUZmnxujs/REqspHGV/426tAqWHVWIbgNXk5LbN8CAwEAAaNdMFswHQYD\nVR0OBBYEFPZvaY0aI/wNV/Y1V8VMyzP/kIZ+MDoGA1UdEQQzMDGCC2FhaS5waHpn\nLmNohiJodHRwczovL2FhaS5waHpnLmNoL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3\nDQEBCwUAA4IBAQCI+nd4PfpVbJbtooDsc7Dz6PSY7x86rLr+czLzkEUMtUvZi2Q9\n24gRjmvcfpw6wRXqTwG1Z5YF4Q75M+VaF8I1elefa9g+nSVQUmu8gzr4LPDw0W34\nlKn+ro4ZS9QogBv4oDcHvlX93YPiIaYJ8j6VC9XKDD3H/UZNxRnoHdRgA0m+i1Ox\nWCgmFxcsMQTUMRb5TH+4a0RmaRbWJw58L4izT2uoPUu+D5VoP+OfKkaPCvye62U+\n66uW622+YK2IZLvBWZYghMxHAvMgipNAEqNUO8na6B7KuMejSYWLXNNeJFyJhj/R\nMUqrWZjNuXCqJ8mSsSSLsStwBg12rRffNeX/"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "phzg.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai.phzg.ch/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai.phzg.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai.phzg.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "phzg.ch"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.phzg.ch/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.phzg.ch/"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "P\u00e4dagogische Hochschule Zug"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "P\u00e4dagogische Hochschule Zug"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABmJLR0QA/wD/AP+gvaeTAAAACXBIWXMAAAsTAAALEwEAmpwYAAAAB3RJTUUH3QQLDRgHVFIaOQAAAQZJREFUOMvtkqFKgwEUhb/zT+aC1SCWxQkzi1EcGPQFfAsxWcRFi91gsYpBYUHBblaTwhwLwoxikN/99x7Dhi+gcR8czjnh3nRgxp8RmV0wBraAW8QOpicxTNEUIHiyaQkqi7qg9ORqrm0fXQP7mAUVYKhJYLGsZARsh1ksRJnQF6waLjFLiOJN4lCmAwyBA8zABqCGOLM5KcQF0EfsAcdOmjY9J6xk2lNtRNoR3pz29wyvReVeps8zfBrhdoavqsqdqPwZYZ4zfh+8xiQPpv6R6fsM32XYkb6J8CjDu9XYL1G5VY2tr3S3IcBQCuaBb6AOJKa0AGjIfCFkeHCwjngkZzP8D34AEVXAHRHc3DkAAAAASUVORK5CYII=",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "28",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PH Zug - P\u00e4dagogische Hochschule Zug"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PH Zug - P\u00e4dagogische Hochschule Zug"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "phzg.ch"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.16251,8.51746"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUOOTmZVjBjC279frTIAaYq+ifz90wDQYJKoZIhvcNAQEL\nBQAwFjEUMBIGA1UEAwwLYWFpLnBoemcuY2gwHhcNMTYwMTI1MTQyNjAwWhcNMTkw\nMTI1MTQyNjAwWjAWMRQwEgYDVQQDDAthYWkucGh6Zy5jaDCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAJ51IJDg8QXH85nk4kJAlGdhCYmWwpKbDs6EXOPd\nDgJrxFaagDye9pEhn0yPUGmffwoYNThgnwK1ey/BScMkyj6T3tf5keRJb310Kx+c\n7k/njd95etdPr66hMUCuEqjfRDQHahWmfSwRlqrBqGFsqakXEyeb/QKBnNabLTJF\nrro4J/Ksi3nhDULuUZdyMgVmYlLYzDpom8rGkthO2NfdDjJglU3P2MQEnGhK9QBH\n0eWfpfSkJAwnhClRiZCrGwQYttd9TSCeBWzKjw2oc3hJyLjjj9sFoF9tu2Gkq5uz\nI1qLLxEkUZmnxujs/REqspHGV/426tAqWHVWIbgNXk5LbN8CAwEAAaNdMFswHQYD\nVR0OBBYEFPZvaY0aI/wNV/Y1V8VMyzP/kIZ+MDoGA1UdEQQzMDGCC2FhaS5waHpn\nLmNohiJodHRwczovL2FhaS5waHpnLmNoL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3\nDQEBCwUAA4IBAQCI+nd4PfpVbJbtooDsc7Dz6PSY7x86rLr+czLzkEUMtUvZi2Q9\n24gRjmvcfpw6wRXqTwG1Z5YF4Q75M+VaF8I1elefa9g+nSVQUmu8gzr4LPDw0W34\nlKn+ro4ZS9QogBv4oDcHvlX93YPiIaYJ8j6VC9XKDD3H/UZNxRnoHdRgA0m+i1Ox\nWCgmFxcsMQTUMRb5TH+4a0RmaRbWJw58L4izT2uoPUu+D5VoP+OfKkaPCvye62U+\n66uW622+YK2IZLvBWZYghMxHAvMgipNAEqNUO8na6B7KuMejSYWLXNNeJFyJhj/R\nMUqrWZjNuXCqJ8mSsSSLsStwBg12rRffNeX/"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "error_url": "https://extranet.phzg.ch"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PH Zug - P\u00e4dagogische Hochschule Zug"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PH Zug - P\u00e4dagogische Hochschule Zug"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.phzg.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.phzg.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "phzg.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www07test.sub.su.se",
    {
      "entity_id": "https://www07test.sub.su.se",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www07test.sub.su.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "swamid"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www07test.sub.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIB5TCCAU6gAwIBAgIJAMMRnP48jAtqMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE3d3dzA3dGVzdC5zdWIuc3Uuc2UwHhcNMDkxMjA4MTAyMjMzWhcNMTIxMjA3\nMTAyMjMzWjAeMRwwGgYDVQQDExN3d3cwN3Rlc3Quc3ViLnN1LnNlMIGfMA0GCSqG\nSIb3DQEBAQUAA4GNADCBiQKBgQC9adDbmgkldLxg7+sU4Yh7vgHpMpCWJx3PJG4z\n1oqyG2AdYjjWeNkXpindtpadS7KaVcV+Zoc1PzqLOdp89gX5J84sox/XzCPu/RAZ\nlxtruQxRXbkYYTQYtOJaevl6eaPWsR1r2x/RQ8IW9iNOAiuw3D1CudvvphPi0M4p\nYma7NwIDAQABoyswKTAnBgNVHSUEIDAeBggrBgEFBQcDAQYIKwYBBQUHAwIGCCsG\nAQUFBwMEMA0GCSqGSIb3DQEBBQUAA4GBAKgR4QcvuxFjM3GXE1iyl8ehd5VkQv7x\nbi95mXj6IdK6mzg5QwofBSltHWNKv/AHpPuBzWd0LjCstdWeJXOCoEJe7twLsFGG\nkU+Y2c688RcV0cUVNvcympR5pYNU7ky0uPd/RCV4vnZ9DQqAKCcB/3wZ2cbfyBIR\ngG19ycA9AsUe"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www07test.sub.su.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "swamid"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www07test.sub.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIB5TCCAU6gAwIBAgIJAMMRnP48jAtqMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE3d3dzA3dGVzdC5zdWIuc3Uuc2UwHhcNMDkxMjA4MTAyMjMzWhcNMTIxMjA3\nMTAyMjMzWjAeMRwwGgYDVQQDExN3d3cwN3Rlc3Quc3ViLnN1LnNlMIGfMA0GCSqG\nSIb3DQEBAQUAA4GNADCBiQKBgQC9adDbmgkldLxg7+sU4Yh7vgHpMpCWJx3PJG4z\n1oqyG2AdYjjWeNkXpindtpadS7KaVcV+Zoc1PzqLOdp89gX5J84sox/XzCPu/RAZ\nlxtruQxRXbkYYTQYtOJaevl6eaPWsR1r2x/RQ8IW9iNOAiuw3D1CudvvphPi0M4p\nYma7NwIDAQABoyswKTAnBgNVHSUEIDAeBggrBgEFBQcDAQYIKwYBBQUHAwIGCCsG\nAQUFBwMEMA0GCSqGSIb3DQEBBQUAA4GBAKgR4QcvuxFjM3GXE1iyl8ehd5VkQv7x\nbi95mXj6IdK6mzg5QwofBSltHWNKv/AHpPuBzWd0LjCstdWeJXOCoEJe7twLsFGG\nkU+Y2c688RcV0cUVNvcympR5pYNU7ky0uPd/RCV4vnZ9DQqAKCcB/3wZ2cbfyBIR\ngG19ycA9AsUe"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www07test.sub.su.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www07test.sub.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www07test.sub.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www07test.sub.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www07test.sub.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www07test.sub.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www07test.sub.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www07test.sub.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www07test.sub.su.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www07test.sub.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www07test.sub.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://expert.antagning.se/ecs-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://expert.antagning.se/ecs-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://expert.antagning.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://expert.antagning.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://expert.antagning.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://expert.antagning.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://expert.antagning.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "expert.antagning.se"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://expert.antagning.se/ecs-sp"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIJANSBcY8AW9T/MA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE2V4cGVydC5hbnRhZ25pbmcuc2UwHhcNMTEwNTA5MTc0MTQ3WhcNMjEwNTA2\nMTc0MTQ3WjAeMRwwGgYDVQQDExNleHBlcnQuYW50YWduaW5nLnNlMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtylQ0TngqqfQUnyBdtd1+WfFCBaFa1MY\nTwc7L/toQr6WJ1QfQyFZgWTEM48PySKVxt+NByyY9VXmcIhADPiP+QiPccME4ink\nx+/xmU532IW6IW1lg3QOLh2tG5fplJZvbmW5ni/tv5Rw/bSDFmagw3AyasIM1OpK\nvbDzJXM80KYR77nNHlS6498D3KcCjJ8gyuzk8XpvDZhCHJ/B3Vz+FvK05w/ljaBF\nF0qpQCDoOKK2+fJhV97wVy5jkzTMS/bMCYxiq3/LjxLmEwTBAiNF3MDEV7yW0TZc\njmyrvL6jOrTTO6ayOI4N8tHTy6lWBKwNkTryZXhlWarL9r2o1R+9bQIDAQABo2Uw\nYzBCBgNVHREEOzA5ghNleHBlcnQuYW50YWduaW5nLnNlhiJodHRwczovL2V4cGVy\ndC5hbnRhZ25pbmcuc2UvZWNzLXNwMB0GA1UdDgQWBBQa1efPa+KRN4VdbtmNatIz\nE2xf2DANBgkqhkiG9w0BAQUFAAOCAQEAexJmaW4Kn8/Toc2VB0XxUTxFhVPl1Yvx\nmTNQw/gFEeguL4bQeHTJQ5UIB43vTCR7Z4ZEWpZjdCm7AI88HoxtMF5ktm9YBAIk\no1ANyEWZ+vjviRUncnudPoutH8xoM+WzyCXLsEHPTfMu5KLb8U80Wgn8/0qDSEwt\niD+vjf5QaeVmd8i7HUeWg2R6e1EmRNeJssg7wAMeoWD76oOY4s55kmRG3GOY+iVV\nPi755TKRrhgKLRu6X2ohz0/H8QNDkVpo/0u/zlW4iNVOyLeSzPuQhDl0xy4LTKo7\nhMvkdB9ux/vPq93rCzcdDnW+zoZmsj1EXtqjDSSEgb/6zJ+ExbZ29Q=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=expert.antagning.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "expert.antagning.se"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://expert.antagning.se/ecs-sp"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIJANSBcY8AW9T/MA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE2V4cGVydC5hbnRhZ25pbmcuc2UwHhcNMTEwNTA5MTc0MTQ3WhcNMjEwNTA2\nMTc0MTQ3WjAeMRwwGgYDVQQDExNleHBlcnQuYW50YWduaW5nLnNlMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtylQ0TngqqfQUnyBdtd1+WfFCBaFa1MY\nTwc7L/toQr6WJ1QfQyFZgWTEM48PySKVxt+NByyY9VXmcIhADPiP+QiPccME4ink\nx+/xmU532IW6IW1lg3QOLh2tG5fplJZvbmW5ni/tv5Rw/bSDFmagw3AyasIM1OpK\nvbDzJXM80KYR77nNHlS6498D3KcCjJ8gyuzk8XpvDZhCHJ/B3Vz+FvK05w/ljaBF\nF0qpQCDoOKK2+fJhV97wVy5jkzTMS/bMCYxiq3/LjxLmEwTBAiNF3MDEV7yW0TZc\njmyrvL6jOrTTO6ayOI4N8tHTy6lWBKwNkTryZXhlWarL9r2o1R+9bQIDAQABo2Uw\nYzBCBgNVHREEOzA5ghNleHBlcnQuYW50YWduaW5nLnNlhiJodHRwczovL2V4cGVy\ndC5hbnRhZ25pbmcuc2UvZWNzLXNwMB0GA1UdDgQWBBQa1efPa+KRN4VdbtmNatIz\nE2xf2DANBgkqhkiG9w0BAQUFAAOCAQEAexJmaW4Kn8/Toc2VB0XxUTxFhVPl1Yvx\nmTNQw/gFEeguL4bQeHTJQ5UIB43vTCR7Z4ZEWpZjdCm7AI88HoxtMF5ktm9YBAIk\no1ANyEWZ+vjviRUncnudPoutH8xoM+WzyCXLsEHPTfMu5KLb8U80Wgn8/0qDSEwt\niD+vjf5QaeVmd8i7HUeWg2R6e1EmRNeJssg7wAMeoWD76oOY4s55kmRG3GOY+iVV\nPi755TKRrhgKLRu6X2ohz0/H8QNDkVpo/0u/zlW4iNVOyLeSzPuQhDl0xy4LTKo7\nhMvkdB9ux/vPq93rCzcdDnW+zoZmsj1EXtqjDSSEgb/6zJ+ExbZ29Q=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=expert.antagning.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://expert.antagning.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://expert.antagning.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://expert.antagning.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://expert.antagning.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://expert.antagning.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://expert.antagning.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://expert.antagning.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://expert.antagning.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://expert.antagning.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://expert.antagning.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.futuremedicine.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.futuremedicine.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Atypon Systems: Future Medicine Ltd"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.futuremedicine.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID8TCCAtmgAwIBAgIJAJ/77lkMaSGrMA0GCSqGSIb3DQEBBQUAMIG3MQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEUMBIGA1UEBxMLU2FudGEgQ2xh\n\t\t\t\t\t\tcmExHTAbBgNVBAoTFEF0eXBvbiBTeXN0ZW1zLCBJbmMuMR0wGwYDVQQLExRBdHlw\n\t\t\t\t\t\tb24gU3lzdGVtcywgSW5jLjEfMB0GA1UEAxMWd3d3LmZ1dHVyZW1lZGljaW5lLmNv\n\t\t\t\t\t\tbTEeMBwGCSqGSIb3DQEJARYPdmFrZUBhdHlwb24uY29tMB4XDTA5MTAyMDIwMDgz\n\t\t\t\t\t\tMFoXDTE5MTAxODIwMDgzMFowgbcxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpDYWxp\n\t\t\t\t\t\tZm9ybmlhMRQwEgYDVQQHEwtTYW50YSBDbGFyYTEdMBsGA1UEChMUQXR5cG9uIFN5\n\t\t\t\t\t\tc3RlbXMsIEluYy4xHTAbBgNVBAsTFEF0eXBvbiBTeXN0ZW1zLCBJbmMuMR8wHQYD\n\t\t\t\t\t\tVQQDExZ3d3cuZnV0dXJlbWVkaWNpbmUuY29tMR4wHAYJKoZIhvcNAQkBFg92YWtl\n\t\t\t\t\t\tQGF0eXBvbi5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQD2IolM\n\t\t\t\t\t\tmAnByBWRn9mH2ZgyhN4KN18sMwlebyxrBCZhJOujYy//cbdF7I3tFLYPXhjqqhaa\n\t\t\t\t\t\taGFWkqSI47mbWX4OisiIY5JGdDMux76PQDno+oiiC10Hv2gbVZg7HH9TfaH3huBj\n\t\t\t\t\t\tT5nyI1iCD5EYjJScda0PBDuGa8I4w7+3HigzpX1i6byUgQS482fPMRIlHYEZhj99\n\t\t\t\t\t\tudmTrTqf6G55Ftooe4YZVogiUJGfZ8HN8x62JkLTRXYYlvTTDXD4u64cmJfnXQ5R\n\t\t\t\t\t\tSZXWT6qklJGBGFWaOfUvdcWKPcrk6VMvu6qWVFpAjzhvkprgxH2jOU2L0jq6bmV+\n\t\t\t\t\t\tFbHL6XfOzYNd7IRxAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBABfRCQbbPRMMrFXP\n\t\t\t\t\t\tLQcmKtEHoLRyrgp8V/Otj4fVzp3vrgQLq6a3pleT8ypb4KEWmLfKuJ94Ew4HoQDo\n\t\t\t\t\t\tTebFPPD37AJd6UynhKonh6KDW6SphFHr6mbyo3RoPLlK0ksWcKa4eyOXTTCHeQ5R\n\t\t\t\t\t\tcZEndtU6U7kAynxPaKAJjGM4FJeiCNKxrfrAiTckIkT9L4+AOCS6YAmM2axVZVnL\n\t\t\t\t\t\tCYtfL5oR2aEzKbxYlFbHiS7aW8bcu6xU6ngCO198AOZYgTDLj/fkyOBy9ANlkeZh\n\t\t\t\t\t\tCJpYbgCtuw3wcIbLndCEu88kiGZI+nKGariT+XxJCEgmZPZ5bjZahzfAn15+aK7m\n\t\t\t\t\t\tJPGtRd4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.futuremedicine.com/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.futuremedicine.com/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.futuremedicine.com/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://crowdtest.nordu.net/shibboleth",
    {
      "entity_id": "http://crowdtest.nordu.net/shibboleth",
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://crowdtest.nordu.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://crowdtest.nordu.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://crowdtest.nordu.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://crowdtest.nordu.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://crowdtest.nordu.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://crowdtest.nordu.net/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://crowdtest.nordu.net/Shibboleth.sso/DS/nordu.net",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://crowdtest.nordu.net/Shibboleth.sso/DS/kalmar2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "crowdtest.nordu.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJAKWJTGBj1S7LMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE2Nyb3dkdGVzdC5ub3JkdS5uZXQwHhcNMTEwMjE1MTMyNzI4WhcNMjEwMjEy\nMTMyNzI4WjAeMRwwGgYDVQQDExNjcm93ZHRlc3Qubm9yZHUubmV0MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAlEs5rrhH2oKPjDmsh7moYJV2rI5rz4vg\no4DaAAx4n9Ejw9SgmpNeu7D8EXn/7xf2yg/cuvmsJx1GpxSTy3N6d9YmbGwXT5B3\n5MIkHYsKEZx2uNJ1+pAOQIBIWErssnRlH5qkwKwFQBoQ9dbAi4DWdp43nHkZkdx7\nX4Sgy7Tm+oLjaF16gM4WOH4RYC1hYd/yhJD0v5Nun3FbVZ79GkJCkh+Szs8rMUWT\nYiNDO0xsLL2xtYObTtu22qbjFIU9VgQZzGuJJbLGVufr15R+cmArht2Dnsm6rmLb\nzQyFS8J+1q601uoq0s67narTLWwAzHcNW/tTLnnFHc08BIgfOR0inQIDAQABo0Ew\nPzAeBgNVHREEFzAVghNjcm93ZHRlc3Qubm9yZHUubmV0MB0GA1UdDgQWBBRp4YdO\nelj63vO7ZYFF+ovp3mNRQzANBgkqhkiG9w0BAQUFAAOCAQEALzd7eQ9U3yRB3b/0\neBnG1DnaKAr48+EUx4anRziB41LTk3ZhmryWpJcuA737kzty3DjKjL2Trw1I3bfU\nzoaL8dYAdljdS5JAIN2m62haOrPJVublLgUw/N+72tVWVoPOBAvDvFy1WpSB8eeW\nhEEHS6yHI49FksKzRVruhdt6HeVkQ6h1y5p67AkaFoPOspI1+BCVk8fCYkHGzAkO\n6JIfKe9zwsG74AiO93x+bItRklp8d4uOXiuTOGGqwAt0Brdn/RJSUYbHfQLrVFHK\nVdA1Cg5KpGKZ7XitW5cDVgS72jJ0pb4GsYI5V0eA7/oUL9jV65LzVNGC87UjzhBA\nwOJ1sg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=crowdtest.nordu.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "crowdtest.nordu.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJAKWJTGBj1S7LMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE2Nyb3dkdGVzdC5ub3JkdS5uZXQwHhcNMTEwMjE1MTMyNzI4WhcNMjEwMjEy\nMTMyNzI4WjAeMRwwGgYDVQQDExNjcm93ZHRlc3Qubm9yZHUubmV0MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAlEs5rrhH2oKPjDmsh7moYJV2rI5rz4vg\no4DaAAx4n9Ejw9SgmpNeu7D8EXn/7xf2yg/cuvmsJx1GpxSTy3N6d9YmbGwXT5B3\n5MIkHYsKEZx2uNJ1+pAOQIBIWErssnRlH5qkwKwFQBoQ9dbAi4DWdp43nHkZkdx7\nX4Sgy7Tm+oLjaF16gM4WOH4RYC1hYd/yhJD0v5Nun3FbVZ79GkJCkh+Szs8rMUWT\nYiNDO0xsLL2xtYObTtu22qbjFIU9VgQZzGuJJbLGVufr15R+cmArht2Dnsm6rmLb\nzQyFS8J+1q601uoq0s67narTLWwAzHcNW/tTLnnFHc08BIgfOR0inQIDAQABo0Ew\nPzAeBgNVHREEFzAVghNjcm93ZHRlc3Qubm9yZHUubmV0MB0GA1UdDgQWBBRp4YdO\nelj63vO7ZYFF+ovp3mNRQzANBgkqhkiG9w0BAQUFAAOCAQEALzd7eQ9U3yRB3b/0\neBnG1DnaKAr48+EUx4anRziB41LTk3ZhmryWpJcuA737kzty3DjKjL2Trw1I3bfU\nzoaL8dYAdljdS5JAIN2m62haOrPJVublLgUw/N+72tVWVoPOBAvDvFy1WpSB8eeW\nhEEHS6yHI49FksKzRVruhdt6HeVkQ6h1y5p67AkaFoPOspI1+BCVk8fCYkHGzAkO\n6JIfKe9zwsG74AiO93x+bItRklp8d4uOXiuTOGGqwAt0Brdn/RJSUYbHfQLrVFHK\nVdA1Cg5KpGKZ7XitW5cDVgS72jJ0pb4GsYI5V0eA7/oUL9jV65LzVNGC87UjzhBA\nwOJ1sg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=crowdtest.nordu.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://crowdtest.nordu.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://crowdtest.nordu.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://crowdtest.nordu.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://crowdtest.nordu.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://crowdtest.nordu.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://crowdtest.nordu.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://crowdtest.nordu.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://crowdtest.nordu.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://crowdtest.nordu.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://crowdtest.nordu.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-demo-03.its.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-demo-03.its.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-03.its.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-03.its.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-03.its.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-03.its.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-03.its.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-demo-03.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-demo-03.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;demo-03"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;demo-03"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-demo-03.its.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-demo-03.its.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIJALoCuTss2H9SMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\nBAMTGWxhZG9rMy1kZW1vLTAzLml0cy51bXUuc2UwHhcNMTIxMjA3MDcyODE1WhcN\nMjIxMjA1MDcyODE1WjAkMSIwIAYDVQQDExlsYWRvazMtZGVtby0wMy5pdHMudW11\nLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtCWTsROjG4XTb5Z5\nRDv/5jMUg9K8Lrl/oKA5WR8qCkoWHPBh6ZguiDW5EBU30McD5+5VrKNcnJpAC9r6\nDMxj/ItY1ygy49NDAtzF8cgwcUfgAaGDPOLIyVO3wZ7A3sAlA2ZQ7XFF5hM0sJCR\nCDo5mIt79/Sp0C3uXSSeYPZpD+XBByYez5D1g5wiCxGlEt8K0LOoQnUlLXSnfeWw\nLSs011SKWTmxrvMxRbipzJ4jDRrt/iwF/7BBix9ttmfzWDJo3f/lohpKZeqOG6BY\nazQm5LdzsZ1pMIi6h3wOQOW7jHB89CuT9ghEXAsXtkd8A0dPBqI06IAGL/baxXWV\nLVY+fwIDAQABo3EwbzBOBgNVHREERzBFghlsYWRvazMtZGVtby0wMy5pdHMudW11\nLnNlhihodHRwczovL2xhZG9rMy1kZW1vLTAzLml0cy51bXUuc2UvZ3VpLXNwMB0G\nA1UdDgQWBBREcC+pdvDX2684yykTCO0bBqgRjTANBgkqhkiG9w0BAQUFAAOCAQEA\nK9xpSHq1DVE2OIAxget0qluLRUGLdcUXz+cm+tMh1DDkjyKt6Xqs6ipNEU5tcsiy\nH48lFPUtsXj684qvU0KUOY4mKztr2pe9+uekunzufdAu+jqMP8iHuPurDbMCP6uf\nnzdTzILt8TweefP7sReQpKniOeagBUqev7Xr46NT4PB1UlRIVqsaSS9mu2oWw1R1\nXsE0AissQN4ZaXbFQwUqhFo8E5U+Z+ISAdl4h3mdMpKCym62Z+sQSlwap/u6Gw+q\n9qSmvbirIZaGQlmFi/1QDZtF6PnKti/Jrtm4XQyYyi60fXtei96duahx7LLMMOtw\nb/vkajQh9nHWAfPhgIOgkQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-demo-03.its.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-03.its.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-03.its.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-03.its.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-03.its.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-03.its.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-03.its.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-demo-03.its.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-demo-03.its.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-demo-03.its.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://heimdall.comodo.net/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vladimir.markevich@comodo.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Vladimir Markevich"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "grigoriy.sandu@comodo.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Grigoriy Sandu"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://heimdall.comodo.net/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://heimdall.comodo.net/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://heimdall.comodo.net/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "comodo.com"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Comodo CA Ltd."
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUeoauRjtUFtyGeW8GAiurwge2vzswDQYJKoZIhvcNAQEL\nBQAwHjEcMBoGA1UEAwwTaGVpbWRhbGwuY29tb2RvLm5ldDAeFw0xNTA3MTQxMzQy\nMzBaFw0zNTA3MTQxMzQyMzBaMB4xHDAaBgNVBAMME2hlaW1kYWxsLmNvbW9kby5u\nZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCB7a9NlB0HesrZ51OT\nZ90aB/lgb3IJJ80lwIGKBd0GE2qa/DKpcrGL+pai7JJbqbO3tnP+1nMS+xTvkrQY\n++TiQDBOT5nVKPOq7tikq5/Z1rVkmYdU+KUkFwsi5ZKRAEdvzXWmjJ5rF1oGKL9d\nN9//ZxksKQd8y78q/5DSKrN69VCzzCD1Z9zfE9dQnUKEl/MtOPv/qnPBcZ/JgDOZ\n0fnWgDFi4JeKEXI6kknALuQ8OVNDPF/UJ4sYEtTuxyYS9cgOb/4ZKWlVpR6FKJmy\n/y7+DuyNrUR9Ey7o4RfG7IsTT+VQ8G5pKeMc10/p+430ZGlE8N1CyU0tyQAtjIf0\nkpE5AgMBAAGjbTBrMB0GA1UdDgQWBBTvrrr8YxgnyduHiDye722jC+a3/DBKBgNV\nHREEQzBBghNoZWltZGFsbC5jb21vZG8ubmV0hipodHRwczovL2hlaW1kYWxsLmNv\nbW9kby5uZXQvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAErHkST3\nbe+V085kSTF03R2SP6DdlLXuSiYX6tdmZRRBeWm7ls0PEdTlsLDdadYw2EnTZSAY\nUwjPCMSY6W5SQe2nNijJWCDMrlhNR4/7HdiB7rCsSJOBPncz2qdfFN0ZmJksPout\nRBGtViHoSZjtSvggJiU2vg8fVudqCObfSrODSDBBLO7Yp7XQ6uQi3kttXZPVS6cN\nEfw+g0ff7sNi8dyUW2ZiCndGXag4E7O04cqCpJln0ngTpfQkULA9D8tE5BkYUpid\n1FzEexQmwIXLUTmlL9NdxGlhKhi6mZXqEYqoubwN3xfzQQhApYzNrNVaQ2UJ4qzP\n3PIcpg44PgkUh1w="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Comodo CA Ltd."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.comodo.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Comodo CA Ltd."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://bir-shib.hosted.exlibrisgroup.com/shib",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bir-shib.hosted.exlibrisgroup.com/shib",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-06-29T09:37:01Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "This is a Shibboleth SP for Primo Resource Discovery at University of Birmingham"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://exlibrisgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ex Libris (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bir-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://bir-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bir-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bir-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bir-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://bir-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://bir-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is an Ex Libris Primo Hosted SP on behalf of the University of Birmingham"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Birmingham - Primo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAOZSwyuu1CqhMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB2FpbzAwMzcwHhcNMTUwNjMwMTA1NTM0WhcNMjUwNjI3MTA1NTM0WjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdhaW8wMDM3MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tusry3ZvAanlgA68B6Yvxcy8l5E8HmFEQD5S2oCA494AOQySUJpkCzzs93g23O1Cm\n\t\t\t\t\t\tj1yLQyy3yqvtIn5ONZmJ5R29GbwfTZv0vzGu+V0D28KFMb6wR6kH5iKrrE3D37A7\n\t\t\t\t\t\tabCseX4rmf8Lw3eOn79/Kjct8qb4EZadYXrsSTd12/9RhHKwLfOTDBV9yj3EUUqt\n\t\t\t\t\t\t0+rsSulfJoztB0t9SDImLtO4PM+p418PjeR3JWW73LRfHZ7SzU9buz2flNNn8e2C\n\t\t\t\t\t\tG0ITXFgVNWdDa5PlnTEyZAf/ccIcvA2DawdMbtjNig+6Bg7yj8QooNjf/g6Kq8G1\n\t\t\t\t\t\tcB8BiFrqz26J+7E8iaZLZQIDAQABozUwMzASBgNVHREECzAJggdhaW8wMDM3MB0G\n\t\t\t\t\t\tA1UdDgQWBBQPCuFc7OkX0mQek4Bejrfa37rqjzANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tTgoIXbhWwAbDb76D5iZCUHVFjvQjnERpp3jlfrKY3C9LjzPYc3twFvPG4w7MGRbD\n\t\t\t\t\t\tczej5XbWS1N+Vmt5J+IYAuixsjN0R3gX1qH/IWQqNHOHXvFgYFiKQo7H1jFUvkjb\n\t\t\t\t\t\tbqL9G+f0JpLatyfPh8u0S3fGRR0jBlu675wsfg8qYJxUrbrM8/DW7Wz3dUzjLabX\n\t\t\t\t\t\tMGaxx53SXzMEMV7RVALiL/WqFnBNMMhVMGN27yzdxwgqce4hhpcvLPYNo4PArJQa\n\t\t\t\t\t\tgDW+va8wE5WWvSEvJWFKXohCGuDoye6fuPZTDSL9xiiSdRaXomq36ryBKJUr9Fj/\n\t\t\t\t\t\tEQZPbfR3TWxmQ1uuBBFT6A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bir-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://bir-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bir-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://bir-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://bir-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://bir-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://dash.cdlib.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "uc3@ucop.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ken Weiss"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "uc3@ucop.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Perry Willett"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "uc3@ucop.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marisa Strong"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dash.cdlib.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of California - Office of the President"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ucop.edu/welcome.html"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of California - Office of the President"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://cdl-datashare-p01.ucop.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dash.cdlib.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dash.ucop.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dash.berkeley.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "4"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dash.ucla.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "5"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dash.lib.uci.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "6"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dash.ucmerced.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "7"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://oneshare.cdlib.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "8"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dash-ucla.cdlib.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "9"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://datasets.lbl.gov/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "10"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dash.library.ucsc.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "11"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://datashare.ucsf.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "12"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://uc3-dash2-prd.cdlib.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "13"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dash.ucr.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "14"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://dash.ucop.edu/xtf/search?smode=aboutPage"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Dash"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This application allows UC faculty and researchers to publish and share digital datasets"
                  }
                ],
                "logo": [
                  {
                    "text": "https://dash.cdlib.org/img/dash_cdl_logo.png",
                    "lang": "en",
                    "height": "87",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "400"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://dash.ucop.edu/xtf/search?smode=policiesPage"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+jCCAeKgAwIBAgIJANuskh/271uNMA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\nBAMTEWNkbC1kYXRhc2hhcmUtcDAxMB4XDTE0MDQxODIxNTkxOFoXDTI0MDQxNTIx\nNTkxOFowHDEaMBgGA1UEAxMRY2RsLWRhdGFzaGFyZS1wMDEwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCxVqo0F5p0Qay3VsMQXGqqjGtkhuCad4KqWEpk\ndb6QHThFViTMvnqu6wiyTyO3X7aA1ulmhEeuHfhg90x9ZnoJW7+f44i+0llQQ8mg\ndgD4wM9p1kEphtz1GDbditcE0zmtiZijtpJjqFPcXl00H3f9AIus7/h1BmoWTiez\nF0B6X09EftzYkkiy/JLko4k+tXmj5lIuA2aUaHGPfNKZjLw/T6VgRdsqBTG2d+DC\nFqBxnYQ3ZU4gE8FCLAEhaQLTWQmxCZBVqqOVdmXrS9bjr2ZTZI9V1Pg401qQliOH\n39lZ7uPaY4nlBkz6D4poVS9IoTH1YhFIKtWh+LNEhvmUH2bjAgMBAAGjPzA9MBwG\nA1UdEQQVMBOCEWNkbC1kYXRhc2hhcmUtcDAxMB0GA1UdDgQWBBTxLjtpIsbvFJKb\nvB3mD8Un+3Ao1jANBgkqhkiG9w0BAQUFAAOCAQEAex7D/0obm2Piuk2ZalNX3Wvz\n+AuQ3Sb9azm5Vj3+G9fwQJdHEUrChorAmqib/gI1w792aSytbaM343/2nGSCJW9W\nuvkemOr+jbm0JCWhUKc4sPmMO7GotidoQfGr1aAzEim/fOMCzYLnFHlXtvmVrZdG\ncKOTG5vtDYWdMsyKzK8RNsqrmGkisEeOI3u2rSs4tTlZaBDXBWSLz4lFfaN4uegs\nbupGBQl1QGU2y9Z9S+LYW0uSgrhIJ7PPmi9AIbFiwXbEVnfxgmD9GP/JNQkaBZ4Y\nY524rv83ThrN0whXjjslG9Ctitm1E4PNqEWkVzfxwP0I1Sbte0bRiIreDlInYA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cdl-datashare-p01.ucop.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://cdl-datashare-p01.ucop.edu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cdl-datashare-p01.ucop.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://cdl-datashare-p01.ucop.edu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dash.cdlib.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dash.cdlib.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dash.cdlib.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dash.cdlib.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dash.berkeley.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dash.berkeley.edu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dash.berkeley.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dash.berkeley.edu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dash.ucop.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dash.ucop.edu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dash.ucop.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dash.ucop.edu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dash.ucla.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dash.ucla.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "18"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dash.ucla.edu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "19"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dash.ucla.edu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "20"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dash.lib.uci.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "21"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dash.lib.uci.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "22"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dash.lib.uci.edu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "23"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dash.lib.uci.edu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "24"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dash.ucmerced.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "25"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dash.ucmerced.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "26"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dash.ucmerced.edu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "27"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dash.ucmerced.edu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "28"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://oneshare.cdlib.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "29"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://oneshare.cdlib.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "30"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://oneshare.cdlib.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "31"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://oneshare.cdlib.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "32"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dash-ucla.cdlib.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "33"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dash-ucla.cdlib.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "34"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dash-ucla.cdlib.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "35"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dash-ucla.cdlib.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "36"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://datasets.lbl.gov/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "37"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://datasets.lbl.gov/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "38"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://datasets.lbl.gov/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "39"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://datasets.lbl.gov/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "40"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dash.library.ucsc.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "41"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dash.library.ucsc.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "42"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dash.library.ucsc.edu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "43"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dash.library.ucsc.edu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "44"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://datashare.ucsf.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "45"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://datashare.ucsf.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "46"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://datashare.ucsf.edu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "47"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://datashare.ucsf.edu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "48"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uc3-dash2-prd.cdlib.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "49"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uc3-dash2-prd.cdlib.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "50"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://uc3-dash2-prd.cdlib.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "51"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://uc3-dash2-prd.cdlib.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "52"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dash.ucr.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "53"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dash.ucr.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "54"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dash.ucr.edu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "55"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dash.ucr.edu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "56"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Dash"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This application allows UC faculty and researchers to publish and share digital datasets"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.gmit.ie/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McGinty"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dmcginty@gmit.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Donal"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.gmit.ie/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.heanet.ie/services/identity-access/edugate#join"
              }
            ],
            "registration_instant": "2010-11-03T00:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.gmit.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.gmit.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.gmit.ie/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gmit.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.gmit.ie"
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/gmit.png",
                    "height": "69",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "220"
                  }
                ],
                "display_name": [
                  {
                    "lang": "ga",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Instit\u00faid Teicneola\u00edochta na Gaillimhe-Maigh Eo"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Galway-Mayo Institute of Technology"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.2777683,-9.014748"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAK1VqQ01fdIHdnIs7Fwl1MsmJPtwMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2lkcC5nbWl0LmllMB4XDTEwMTExNjE2NTAwM1oXDTMw\nMTExNjE2NTAwM1owFjEUMBIGA1UEAxMLaWRwLmdtaXQuaWUwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCgPVXvHQh3F+3gO0sfFAVRwENQ75ZDdvLraifP\nKX7cmP700PPyVl/lab3aoei080w4iZ++yDrgHVg0O6+CSqLylPKX4Pdv7Ps/UAPd\nAA/yteXGUe0sRxzmgOGmDA2uDt6FYORt2NHcIIuBtKFSi7HMkLe8pVs1NMGMx59X\nTaArq/vfQnPaSEW4N2CcVAArku1wohHOlC1TMf+6jRU/N456Zjq+ZRylefluTVdx\n3tBn2GZiiYJD3q4nbNJeDjnOS5dn4nvTjLTd7Y+5E8t8yCJyCyTE6U9d3m4+Mfh9\njrtk7HO5HDO8WCoBA4OmsOTLquqQWZhnqMQY6wuWTLU9lf+lAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2lkcC5nbWl0LmllhiJodHRwczovL2lkcC5nbWl0LmllL2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBQAy0oW5uPZ0SagPA9AU5m0PWSQEjANBgkqhkiG\n9w0BAQUFAAOCAQEAVZhK+rTfpxznv4ihlhBYvuibLTvWJWD6zqrc3CRVElaKpC2N\nHKCPxF5Yw783trr/DWgkHVpva6yGDrDVRd45qCqJmNGKRniR9+kgjsbvfBPEoDeQ\nwe2aIVIPuAArSitpWyiZ+betcnUQSV6vq6SEZrlb9SG1hMd3ckBd9t5xj0cd61Cx\n2CR9ovcj7c97IVlWb4AN93uWsVV8hGpF0d/hJfkT0Wfr5oEfOn8P/1O18M3z000s\nVRvGY2BZumdJim91SBMiwBI51Xv44nkEUtrIwVRipdAshJAynpRHPVEyJQmxn4sR\nSg5aRgRfZLgvyxogDq0OlqHMA3nOustdeietHQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Galway-Mayo Institute of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gmit.ie"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Galway-Mayo Institute of Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://esupotp-cas.univ-paris1.fr",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Anli Aymar"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Aymar.Anli@univ-paris1.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://esupotp-cas.univ-paris1.fr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2016-04-18T17:28:43Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/preprod"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/national"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 Paris 1 Panth\u00e9on-Sorbonne"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-paris1.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 Paris 1 Panth\u00e9on-Sorbonne"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://esupotp-cas.univ-paris1.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "esup-otp test"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "D\u00e9monstrateur d'authentification multi-facteur utilisant les composants esup-otp"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TEST - ESUP OTP"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TEST - ESUP OTP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJAM3dOUiLh5BUMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\nBAMTG3NlcnZpY2UtdGVzdC51bml2LXBhcmlzMS5mcjAeFw0xNTA0MTAwODU1NDBa\nFw0yNTA0MDcwODU1NDBaMCYxJDAiBgNVBAMTG3NlcnZpY2UtdGVzdC51bml2LXBh\ncmlzMS5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMWXb2MlNifM\n3I8+xbq2dQ00FIawjVHm0P+0sUeE5Wwo9YwhiQViTdx7AxBT/22zJMAO7uXm37eH\nx7TKtc08lp1YF1kI5V3YljUuHbX4QSWOSnfTw2RT/UTbD2lmZsFt0vMTA6b9yO+J\n+mySiADwOSe463w+R3FXsrg4s6neH9czeXZyjiMBm7JPyzyA7gYRq/VT9uoBiISZ\nXyt/918T4WO5F8RCXm0nQIM9NYs/zWcuKw2wnlbaSY9034Fat5Z65jew3euCQnwf\nFWVVlZqrEvdQC3AnRFzAGchvlMSc3Sf6GoOMlaHZlubEGw+swnrgtPxkHC1uds1L\n9iVHESxOeX0CAwEAAaNJMEcwJgYDVR0RBB8wHYIbc2VydmljZS10ZXN0LnVuaXYt\ncGFyaXMxLmZyMB0GA1UdDgQWBBRdOgUdjYWmRjODjzpVbaML6BuhqDANBgkqhkiG\n9w0BAQUFAAOCAQEAvshzKl03HsyImCSIbMZWCy7yaiUrwgshiE5FZXHYbFsVbxfS\nj79fyA3D1vMxI3K/Nk/14rRj29swaG46F2AvhkBY9h/1HexdQHihxv2b9DUmzr0R\nVfANrKjqzrVGn0DhOjGjD+K3Mr1sS/pvNzqCcOXc1Rk+BIZ5M9v2VKP9WhJ9TMmc\nrSYjr+xXy3Vc28+AkFL+eQRW1+3HIe1HWmjuXEkvDlnBgHG88+WQCSTo1Zp1mKyV\nktTZDl73ke3dpFMKqNuCZTa6mAvFpNrrOhn6Vz42JQtA0hooIulB2tgxylLS4kVm\netINiPmnz/y304LB3BsXERnSp9MYB2paz9zpvw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJAM3dOUiLh5BUMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\nBAMTG3NlcnZpY2UtdGVzdC51bml2LXBhcmlzMS5mcjAeFw0xNTA0MTAwODU1NDBa\nFw0yNTA0MDcwODU1NDBaMCYxJDAiBgNVBAMTG3NlcnZpY2UtdGVzdC51bml2LXBh\ncmlzMS5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMWXb2MlNifM\n3I8+xbq2dQ00FIawjVHm0P+0sUeE5Wwo9YwhiQViTdx7AxBT/22zJMAO7uXm37eH\nx7TKtc08lp1YF1kI5V3YljUuHbX4QSWOSnfTw2RT/UTbD2lmZsFt0vMTA6b9yO+J\n+mySiADwOSe463w+R3FXsrg4s6neH9czeXZyjiMBm7JPyzyA7gYRq/VT9uoBiISZ\nXyt/918T4WO5F8RCXm0nQIM9NYs/zWcuKw2wnlbaSY9034Fat5Z65jew3euCQnwf\nFWVVlZqrEvdQC3AnRFzAGchvlMSc3Sf6GoOMlaHZlubEGw+swnrgtPxkHC1uds1L\n9iVHESxOeX0CAwEAAaNJMEcwJgYDVR0RBB8wHYIbc2VydmljZS10ZXN0LnVuaXYt\ncGFyaXMxLmZyMB0GA1UdDgQWBBRdOgUdjYWmRjODjzpVbaML6BuhqDANBgkqhkiG\n9w0BAQUFAAOCAQEAvshzKl03HsyImCSIbMZWCy7yaiUrwgshiE5FZXHYbFsVbxfS\nj79fyA3D1vMxI3K/Nk/14rRj29swaG46F2AvhkBY9h/1HexdQHihxv2b9DUmzr0R\nVfANrKjqzrVGn0DhOjGjD+K3Mr1sS/pvNzqCcOXc1Rk+BIZ5M9v2VKP9WhJ9TMmc\nrSYjr+xXy3Vc28+AkFL+eQRW1+3HIe1HWmjuXEkvDlnBgHG88+WQCSTo1Zp1mKyV\nktTZDl73ke3dpFMKqNuCZTa6mAvFpNrrOhn6Vz42JQtA0hooIulB2tgxylLS4kVm\netINiPmnz/y304LB3BsXERnSp9MYB2paz9zpvw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://esupotp-cas.univ-paris1.fr/cas/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://esupotp-cas.univ-paris1.fr/cas/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "TEST - ESUP OTP"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "TEST - ESUP OTP"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "D\u00e9monstrateur d'authentification multi-facteur utilisant les composants esup-otp"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "esup-otp test"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "uid",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://wiki.helsinki.fi/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Aalto"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ok-wiki@helsinki.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Erkki"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Peltonen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:haka-hy@helsinki.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Janne"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Aalto"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ok-wiki@helsinki.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Erkki"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://wiki.helsinki.fi/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.csc.fi/english/institutions/haka/instructions/join/eduGAINRegistrationStatement/"
              }
            ],
            "registration_authority": "http://www.csc.fi/haka",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Helsingin yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Helsinki"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Helsingfors universitet"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.helsinki.fi/yliopisto/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.helsinki.fi/yliopisto/"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.helsinki.fi/yliopisto/"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Helsingin yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Helsinki"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Helsingfors universitet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://wiki.helsinki.fi/Shibboleth.sso/HAKALogin",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Tool for group collaboration and web-publishing."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://wiki.helsinki.fi/tietosuojaseloste.html"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://wiki.helsinki.fi/tietosuojaseloste.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Helsinki Wiki Service"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Helsingin yliopiston Wiki-palvelu"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEmzCCA4OgAwIBAgIRAL/NhOjMkfeL3Flgd4NNgaswDQYJKoZIhvcNAQELBQAw\nZDELMAkGA1UEBhMCTkwxFjAUBgNVBAgTDU5vb3JkLUhvbGxhbmQxEjAQBgNVBAcT\nCUFtc3RlcmRhbTEPMA0GA1UEChMGVEVSRU5BMRgwFgYDVQQDEw9URVJFTkEgU1NM\nIENBIDIwHhcNMTUwMjIzMDAwMDAwWhcNMTgwMzE5MjM1OTU5WjA+MSEwHwYDVQQL\nExhEb21haW4gQ29udHJvbCBWYWxpZGF0ZWQxGTAXBgNVBAMTEHdpa2kuaGVsc2lu\na2kuZmkwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQD0yKGvBZhrRP5x\nxspDugWdniB+0HGYQAvWWgqJyOnIGhY/9SwwooTOOcp/ManA6aKyekbxuIl3WF3/\nNACSkVhCxAEBhYeRIEWc82W7k4BEJJ29fR71Pi9P2uLssK061B0ebsbFPk2piZ1T\nBHDSFGjDY9+DPcYogLG0KVscyD+9bw/eLhsIPJyKxI3Wu47BedsoQqQxCrXYiLS0\neSIVv2Jf5/q/qzSD4V5doSN3U7CV7FqSpzY2g4RiAgTyYrxWi51pENh9k0h0Lr8d\nVHDh1fuN2n9NPp5b2fS1oOfIvvMJlneMkv/XsBjaGHVM17QW5xwIzIlSQfDIzFE2\nH/5RFA8zAgMBAAGjggFsMIIBaDAfBgNVHSMEGDAWgBRb0IocmjJb4LXdllQb4YYo\nsP22vTAdBgNVHQ4EFgQU8d+lPhlixSKViDV0U18nzRuoWrgwDgYDVR0PAQH/BAQD\nAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMC\nMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1UdHwQzMDEw\nL6AtoCuGKWh0dHA6Ly9jcmwudXNlcnRydXN0LmNvbS9URVJFTkFTU0xDQTIuY3Js\nMGwGCCsGAQUFBwEBBGAwXjA1BggrBgEFBQcwAoYpaHR0cDovL2NydC51c2VydHJ1\nc3QuY29tL1RFUkVOQVNTTENBMi5jcnQwJQYIKwYBBQUHMAGGGWh0dHA6Ly9vY3Nw\nLnVzZXJ0cnVzdC5jb20wGwYDVR0RBBQwEoIQd2lraS5oZWxzaW5raS5maTANBgkq\nhkiG9w0BAQsFAAOCAQEARLwtShgCBMuGMhf08m1KTZ4AQPd25ql8mvzIvVXiTq1s\nV4D9BJ22lf6Lkiq91BLHzVdHYfb8XsEdETzRO4671PgQr4f258X1BGdgxBh0KQfz\nqbSXxHWnzqpf+0zfDG6D3VO16gkJUXzBRv/kM81RnlV3/iYqKZC/Qd3S3c5jklxU\nArWOB2iYWyMs+VyAa7QpzFb/8B+OavnRsPefw07lCBqqo6ppoVeuOemONAgbhXwj\nz9noWRAiG/hZbUjEfQ1sWvT/TLwjdWzTstDFmp59tex3SSbq02IZSCimUGp6OJVS\nN4ZdWQZqu5CJ4NhvqVlUpnxq9UfK5HSPDf6iGa7ogw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://wiki.helsinki.fi/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "2",
              "location": "https://wiki.helsinki.fi/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "false"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Tool for group collaboration and web-publishing."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Helsingin yliopiston Wiki-palvelu"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "University of Helsinki Wiki Service"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "cn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.stanmore.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.stanmore.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/stanmore.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/stanmore.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stanmore.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Stanmore College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.stanmore.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.plumpton.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@plumpton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Plumpton College IT Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Howe"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sam.howe@plumpton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sam"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.plumpton.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-15T13:18:29Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVAJgtMhzTWBfgn2Mz2ywEeOKpkBfcMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCQxIjAgBgNVBAMMGXNoaWJib2xldGgucGx1bXB0b24uYWMudWswHhcNMTUw\n\t\t\t\t\t\tNTE0MDgyNjU0WhcNMzUwNTE0MDgyNjU0WjAkMSIwIAYDVQQDDBlzaGliYm9sZXRo\n\t\t\t\t\t\tLnBsdW1wdG9uLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tmR5vQ9l9UXO+q029dr7chrDPHg7SeCo191STaB+nUBr3e6+bJyc2j2CH6dcbjvB1\n\t\t\t\t\t\t62DtiyswciLcTe/yBMJPOcay4bUuLb3y/C8Gp20PXOyaV2Y6DaIfdMYDUdWbUQiO\n\t\t\t\t\t\t+vFUOMH5rHlGh5Di/2sKlypLUgX0wer4sQ71xjTG9kPpzP9nHkAznWIoevb93il4\n\t\t\t\t\t\t++pmY3DFDsoNo4YbO8//VK0YXgBcvoQumNvMp9WVnlkLtIqqtDEYKrNgNybDPmtr\n\t\t\t\t\t\tpUhVOIKjiJGfEzP53xsGnmVlpPi+SPL7YLLzdexpkBx5MWHvctm6CiuV7OGpKXC6\n\t\t\t\t\t\tPuJy3neGCGkc9pIBT9+AoQIDAQABo3kwdzAdBgNVHQ4EFgQU50Tr9x/EKj4E0udh\n\t\t\t\t\t\tk1kzOHWYz90wVgYDVR0RBE8wTYIZc2hpYmJvbGV0aC5wbHVtcHRvbi5hYy51a4Yw\n\t\t\t\t\t\taHR0cHM6Ly9zaGliYm9sZXRoLnBsdW1wdG9uLmFjLnVrL2lkcC9zaGliYm9sZXRo\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQAyFtJrWrXKkOCbXLt0LDHe9GTgD8IoEQwKlqqX\n\t\t\t\t\t\tgHfTjGf9pFVhESpe5cUwEw+7oH4S5ppJJ3riL60ne2TTxtEbcgFIb1FUbT2HlN8u\n\t\t\t\t\t\tRRCpL+RttzkxMZzeF3aW/SMCyQbYGNUNNbhSgoZMW49Jbd9Cdy9sAfceaGhOSsaW\n\t\t\t\t\t\tesuNMSX9FSuYApTZpeWaiotpimdGlRc7TLet48XBRTFbXjdYEjgABaAbcihGW8wp\n\t\t\t\t\t\tBZmeXBv22v17AxYxHXh22k0X1za7CqNt3UVGhafqrPZeNCNMGcX+S8BSa5rAKsop\n\t\t\t\t\t\ttWP38Ae6DWHxNP91fg5Ojh9o0ae5hYTYukEBySuMj2ZJ2HPx"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "plumpton.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.plumpton.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.plumpton.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.plumpton.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.plumpton.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.plumpton.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.plumpton.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.plumpton.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.plumpton.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.plumpton.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.plumpton.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.plumpton.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "plumpton.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVAJgtMhzTWBfgn2Mz2ywEeOKpkBfcMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCQxIjAgBgNVBAMMGXNoaWJib2xldGgucGx1bXB0b24uYWMudWswHhcNMTUw\n\t\t\t\t\t\tNTE0MDgyNjU0WhcNMzUwNTE0MDgyNjU0WjAkMSIwIAYDVQQDDBlzaGliYm9sZXRo\n\t\t\t\t\t\tLnBsdW1wdG9uLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tmR5vQ9l9UXO+q029dr7chrDPHg7SeCo191STaB+nUBr3e6+bJyc2j2CH6dcbjvB1\n\t\t\t\t\t\t62DtiyswciLcTe/yBMJPOcay4bUuLb3y/C8Gp20PXOyaV2Y6DaIfdMYDUdWbUQiO\n\t\t\t\t\t\t+vFUOMH5rHlGh5Di/2sKlypLUgX0wer4sQ71xjTG9kPpzP9nHkAznWIoevb93il4\n\t\t\t\t\t\t++pmY3DFDsoNo4YbO8//VK0YXgBcvoQumNvMp9WVnlkLtIqqtDEYKrNgNybDPmtr\n\t\t\t\t\t\tpUhVOIKjiJGfEzP53xsGnmVlpPi+SPL7YLLzdexpkBx5MWHvctm6CiuV7OGpKXC6\n\t\t\t\t\t\tPuJy3neGCGkc9pIBT9+AoQIDAQABo3kwdzAdBgNVHQ4EFgQU50Tr9x/EKj4E0udh\n\t\t\t\t\t\tk1kzOHWYz90wVgYDVR0RBE8wTYIZc2hpYmJvbGV0aC5wbHVtcHRvbi5hYy51a4Yw\n\t\t\t\t\t\taHR0cHM6Ly9zaGliYm9sZXRoLnBsdW1wdG9uLmFjLnVrL2lkcC9zaGliYm9sZXRo\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQAyFtJrWrXKkOCbXLt0LDHe9GTgD8IoEQwKlqqX\n\t\t\t\t\t\tgHfTjGf9pFVhESpe5cUwEw+7oH4S5ppJJ3riL60ne2TTxtEbcgFIb1FUbT2HlN8u\n\t\t\t\t\t\tRRCpL+RttzkxMZzeF3aW/SMCyQbYGNUNNbhSgoZMW49Jbd9Cdy9sAfceaGhOSsaW\n\t\t\t\t\t\tesuNMSX9FSuYApTZpeWaiotpimdGlRc7TLet48XBRTFbXjdYEjgABaAbcihGW8wp\n\t\t\t\t\t\tBZmeXBv22v17AxYxHXh22k0X1za7CqNt3UVGhafqrPZeNCNMGcX+S8BSa5rAKsop\n\t\t\t\t\t\ttWP38Ae6DWHxNP91fg5Ojh9o0ae5hYTYukEBySuMj2ZJ2HPx"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Plumpton College Shibboleth"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.plumpton.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Plumpton College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sal-shib-test.hosted.exlibrisgroup.com/shib",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sal-shib-test.hosted.exlibrisgroup.com/shib",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-01-12T10:53:11Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "This is a Test Shibboleth SP for Primo Resource Discovery at University of Salford"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://exlibrisgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ex Libris (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sal-shib-test.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sal-shib-test.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sal-shib-test.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sal-shib-test.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sal-shib-test.hosted.exlibrisgroup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sal-shib-test.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is a Test Shibboleth SP for Primo Resource Discovery at University of Salford"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Salford - Primo Test"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAKhHDi1Wde/sMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB2FpbzAwMzEwHhcNMTUwMzIzMTU1NzA5WhcNMjUwMzIwMTU1NzA5WjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdhaW8wMDMxMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\t4/0RKaaUdMCgBK5+SX/9L/ZXX2KxjMfp7ZxYz0VovDPzlQIlUN+IHUpovrVz26e8\n\t\t\t\t\t\tNb6vPfBz5tkPuNmSLxpczKZ2hS/p1F+qPrFJDx+bmMegdCSMYA04DUghxB0sCwfR\n\t\t\t\t\t\t6hthSCYQV057UW8rRcsmMQa1O4+uX+Z2wN62/9vIiMCbXwBZPf/OYz/ElrkfGr+P\n\t\t\t\t\t\tjcGaixk4aYo+hamcWEoj6z1hSoDPx3FIF+BKXjvY+/2/hy+Ua1tG8bfy2VFByur3\n\t\t\t\t\t\tryw8YeT0wNXwGEYR29P40xuCLlyhGFR43vwlsw/MYL0NJcgvnuG6EPciboS5r0TC\n\t\t\t\t\t\tSuGrT+X25IEgVvBg1xrM4QIDAQABozUwMzASBgNVHREECzAJggdhaW8wMDMxMB0G\n\t\t\t\t\t\tA1UdDgQWBBTInhdrgTkzot8a/5AqpBZBWaXqZTANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tJmaJQVhaEPetwhNHpGemPnTa3Wx74BQuv+bfuRjRkmfCytBRiHab5JdDnaJcETwk\n\t\t\t\t\t\tK9zOBCYeczxYMuQVPAC0kmcWwPRx/fHu2aBQ6JB1xUGPJK8QxwQBfBwiP5v0GuSZ\n\t\t\t\t\t\t7RkNy+mRmAHH6Wux06mC3o4fhL12qlw2WKqVHk5iK3+ku2ytsqmPX5LfA/NxT2lt\n\t\t\t\t\t\t2gUrhELqzgsUkRPXLwTeZJ1I3SzrJr9iTOgnjB/scJUp5EFBuQuWFizTg0iCfL77\n\t\t\t\t\t\t1nZCeVMiGP0nRXxb9l5+WVnuomPltvSWbmWetOsESzfHa0NDYRoD0Tcmo3HivT94\n\t\t\t\t\t\twcpDxFonOrfUYE8n7Dc8Gg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sal-shib-test.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sal-shib-test.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sal-shib-test.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sal-shib-test.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sal-shib-test.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sal-shib-test.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://login.aaiedu.hr/wayf/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Voncina"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dubravko.voncina@srce.hr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dubravko"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "aai@srce.hr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "AAI@EduHr operations team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.aaiedu.hr/wayf/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "hr",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.aaiedu.hr/docs/AAI@EduHr-pravilnik-ver1.3.1.pdf"
              }
            ],
            "registration_instant": "2014-07-01T08:00:00Z",
            "registration_authority": "http://www.srce.hr",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "AAI@EduHr"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aaiedu.hr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "AAI@EduHr"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.aaiedu.hr/wayf/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.aaiedu.hr/wayf/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.aaiedu.hr/wayf/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.aaiedu.hr/wayf/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.aaiedu.hr/wayf/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "WAYF bridging element for eduGAIN enabled services"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "WAYF bridging element for eduGAIN enabled services registered within AAI@EduHr federation"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.5",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sus-shib.hosted.exlibrisgroup.com/shib",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sus-shib.hosted.exlibrisgroup.com/shib",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-04-09T09:18:09Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "This is a Shibboleth SP for University Of Sussex"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://exlibrisgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ex Libris (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sus-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sus-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sus-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sus-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sus-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sus-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is an Ex Libris Primo Hosted SP on behalf of University Of Sussex"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University Of Sussex - Primo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAIJI2WEAW9Y7MA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB2FpbzAwMjUwHhcNMTUwNDAyMTkyMDI3WhcNMjUwMzMwMTkyMDI3WjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdhaW8wMDI1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\t43SuJp+ilw1b6Flc1gVIngrmUp4T1/yt4b+iX4ICVyq6oad2GpOkvBAt8eiHLarb\n\t\t\t\t\t\tXo2SjJnDPtG8lonXvYw9JuS/C8IawW4mTMOycJVbJ3JkiRmxmlh+nYgdCfb8iyBr\n\t\t\t\t\t\tir8WsAEv7Y7LwhjjqbxDr+SBjv2b5OBXiY6hfsnM5WFRWooYeoFV6ZhklHOpBmg0\n\t\t\t\t\t\tVN3abKhBMmCFr2DN5uSZL6YmYTV9j6JHn1mipdlOXRYlTQUJ0arwqcVePXSYvoAI\n\t\t\t\t\t\tOlPAznx/YImbmBLPO8xHLjV0+9nGjaTC5Df8whRdH5NRmqtP5RkpaDLkhx1ji0Pd\n\t\t\t\t\t\ttLKPhBgPnXbD048x3iFbQQIDAQABozUwMzASBgNVHREECzAJggdhaW8wMDI1MB0G\n\t\t\t\t\t\tA1UdDgQWBBTpDDGYVTeATO9zpmojtgcarmDyWTANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tPo6C2ZqJOs5S+VlroHOtGm/Y+B1p/iFxO/EO506flEYDmGKS3cl5/T9znshX7NH7\n\t\t\t\t\t\tU/S4BJDeh2yT85i0bEGzb64UYbcXXJ5iqyV9FI30KlxuETOBKgmZyxnrfB9UWlHq\n\t\t\t\t\t\tYXevx6z1SvB2BNixqIXASbQZ9SgxdHMScfYMXlssYuEdpZBkVHyxgz7AM9mOE4Ip\n\t\t\t\t\t\taUpiOEsPvGM4TNKFuwsRIoTNgXBvuwHPX2YMJFq5VHCRh3Mzckb5YBOp44JTpjLy\n\t\t\t\t\t\tV379XyFD4ydqADU0uPiyX1VrYoVqBhzt81A5NqVrS+ebSGkkQbgXV/1wH416tGay\n\t\t\t\t\t\tBqUkPiCh/jaWeBCQR1PCrQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sus-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sus-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sus-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sus-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sus-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sus-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.derby-college.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "De Ville"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Tim.DeVille@derby-college.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "De Ville"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Tim.DeVille@derby-college.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.derby-college.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-03-04T12:29:50Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRzCCAi+gAwIBAgIUcC6CXJaCoz2x+pFU5TLdMtrg238wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwIjEgMB4GA1UEAxMXaWRwLmRlcmJ5LWNvbGxlZ2UuYWMudWswHhcNMTMwMjI3\n\t\t\t\t\t\tMTQ1MjI3WhcNMzMwMjI3MTQ1MjI3WjAiMSAwHgYDVQQDExdpZHAuZGVyYnktY29s\n\t\t\t\t\t\tbGVnZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANKo3Qc2\n\t\t\t\t\t\tRMSfWk1c1/JbDgHOfWx7BuEhOPpxw1wA315Bx7qEY028YMvkjdBB4DZ6ZPlzGFGi\n\t\t\t\t\t\tu1bQ2nVGz4ahT+LJ+1e9kdye++z2/y/na9kccJVONn6pQlPgug52YYVs1wI/ACIt\n\t\t\t\t\t\tPiJB6IOIIUgtJN72uinqr+I8wWKcRPBJ6ZUFU4BHFzmC0iC7UPijsv+fHmcthY3k\n\t\t\t\t\t\tkjdMKKVLbEyq48zV/oPzDI+4B2VQu1P9M1m7+XXKRFYuXuUS7710UsaU2j4gQOjh\n\t\t\t\t\t\tFCthyCt3gttOTbLlaec/V0Hr8ctqhTGuaW634A0Bko/fODY/cpIrLU6jRfAduOys\n\t\t\t\t\t\tX+tyrAWT8hOxaOMCAwEAAaN1MHMwUgYDVR0RBEswSYIXaWRwLmRlcmJ5LWNvbGxl\n\t\t\t\t\t\tZ2UuYWMudWuGLmh0dHBzOi8vaWRwLmRlcmJ5LWNvbGxlZ2UuYWMudWsvaWRwL3No\n\t\t\t\t\t\taWJib2xldGgwHQYDVR0OBBYEFOVeW4p4HL3i4+XUVYpOWc8AfM+cMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBBQUAA4IBAQC+SiFq81er0JPaxOKmw0XHjk0PKu2DAIsB1Xq0A1Djk1OMHpKQ\n\t\t\t\t\t\t/lCjaD3qU6RASglCJZTvxk5gzqgDIxDNjQSpMg9/V809+obnMfKm1wwm9KHTFSEk\n\t\t\t\t\t\ttO+NXUTVcPDWuvSyz/Xv/M0dwxGcBsA+saiw+UvZu2gbWgNVLosn4SZoAFyD1l8w\n\t\t\t\t\t\t6YNqj0N7g3wnxLC6Dteg+/Lf6j4jHLDpcCxxUisEe0+GFAOSw2bGoeyQEeiTF6KH\n\t\t\t\t\t\tmQf6rM44WGIuo+CX4bDORSxyyv8iQ8L2G07CxC8+Cc0eh+WKH83V0zCXKMJYNkaP\n\t\t\t\t\t\tTBvmtDKuzTAZk6ZEZ+7qKvpc/kVYTqFBqyD0"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "derby-college.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.derby-college.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.derby-college.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.derby-college.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.derby-college.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.derby-college.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.derby-college.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.derby-college.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.derby-college.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "derby-college.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRzCCAi+gAwIBAgIUcC6CXJaCoz2x+pFU5TLdMtrg238wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwIjEgMB4GA1UEAxMXaWRwLmRlcmJ5LWNvbGxlZ2UuYWMudWswHhcNMTMwMjI3\n\t\t\t\t\t\tMTQ1MjI3WhcNMzMwMjI3MTQ1MjI3WjAiMSAwHgYDVQQDExdpZHAuZGVyYnktY29s\n\t\t\t\t\t\tbGVnZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANKo3Qc2\n\t\t\t\t\t\tRMSfWk1c1/JbDgHOfWx7BuEhOPpxw1wA315Bx7qEY028YMvkjdBB4DZ6ZPlzGFGi\n\t\t\t\t\t\tu1bQ2nVGz4ahT+LJ+1e9kdye++z2/y/na9kccJVONn6pQlPgug52YYVs1wI/ACIt\n\t\t\t\t\t\tPiJB6IOIIUgtJN72uinqr+I8wWKcRPBJ6ZUFU4BHFzmC0iC7UPijsv+fHmcthY3k\n\t\t\t\t\t\tkjdMKKVLbEyq48zV/oPzDI+4B2VQu1P9M1m7+XXKRFYuXuUS7710UsaU2j4gQOjh\n\t\t\t\t\t\tFCthyCt3gttOTbLlaec/V0Hr8ctqhTGuaW634A0Bko/fODY/cpIrLU6jRfAduOys\n\t\t\t\t\t\tX+tyrAWT8hOxaOMCAwEAAaN1MHMwUgYDVR0RBEswSYIXaWRwLmRlcmJ5LWNvbGxl\n\t\t\t\t\t\tZ2UuYWMudWuGLmh0dHBzOi8vaWRwLmRlcmJ5LWNvbGxlZ2UuYWMudWsvaWRwL3No\n\t\t\t\t\t\taWJib2xldGgwHQYDVR0OBBYEFOVeW4p4HL3i4+XUVYpOWc8AfM+cMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBBQUAA4IBAQC+SiFq81er0JPaxOKmw0XHjk0PKu2DAIsB1Xq0A1Djk1OMHpKQ\n\t\t\t\t\t\t/lCjaD3qU6RASglCJZTvxk5gzqgDIxDNjQSpMg9/V809+obnMfKm1wwm9KHTFSEk\n\t\t\t\t\t\ttO+NXUTVcPDWuvSyz/Xv/M0dwxGcBsA+saiw+UvZu2gbWgNVLosn4SZoAFyD1l8w\n\t\t\t\t\t\t6YNqj0N7g3wnxLC6Dteg+/Lf6j4jHLDpcCxxUisEe0+GFAOSw2bGoeyQEeiTF6KH\n\t\t\t\t\t\tmQf6rM44WGIuo+CX4bDORSxyyv8iQ8L2G07CxC8+Cc0eh+WKH83V0zCXKMJYNkaP\n\t\t\t\t\t\tTBvmtDKuzTAZk6ZEZ+7qKvpc/kVYTqFBqyD0"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Derby College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.derby-college.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Derby College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://oxfordbrookes.idm.oclc.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Support Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Support Desk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://oxfordbrookes.idm.oclc.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-07-15T15:57:54Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Oxford Brookes University online resources"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oclc.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "OCLC (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEIDCCAwigAwIBAgIBAjANBgkqhkiG9w0BAQUFADBtMSUwIwYDVQQDFBwqLm94\n\t\t\t\t\t\tZm9yZGJyb29rZXMuaWRtLm9jbGMub3JnMQswCQYDVQQGEwJVSzENMAsGA1UEChME\n\t\t\t\t\t\tT0NMQzEoMCYGCSqGSIb3DQEJARYZamFtZXMuaHV0Y2hpbnNvbkBvY2xjLm9yZzAe\n\t\t\t\t\t\tFw0xMzA3MTIxNjAzMjRaFw0yMzA3MTIxNjAzMjRaMG0xJTAjBgNVBAMUHCoub3hm\n\t\t\t\t\t\tb3JkYnJvb2tlcy5pZG0ub2NsYy5vcmcxCzAJBgNVBAYTAlVLMQ0wCwYDVQQKEwRP\n\t\t\t\t\t\tQ0xDMSgwJgYJKoZIhvcNAQkBFhlqYW1lcy5odXRjaGluc29uQG9jbGMub3JnMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAr98hUqEihQmuIR7RB4Y0re+Z\n\t\t\t\t\t\tIJfBuWjAwmklHjbQ107kHndb4WfbCcDCrUDZ01RoPPkGwHajnpg2K5pXY6bg+Ljf\n\t\t\t\t\t\tQ9QjnVvnLnVv5nICmNy6K3t1DsQ0v+eK0+CrEpvUGjdhfBD2z6FOJpjcKdhZXvAH\n\t\t\t\t\t\ts2DWovpT/eoje9C5lZ+Ur22hHj+Sit5GiAWjPsE84Tdmzwp3OIcAXga/Pq0ClnNk\n\t\t\t\t\t\tdjFeZNIwaspWxik0s/hHaPUmBBm1HYqLcPXo4JjV3jLPdgH4ZlQZHx/XGIh8lUio\n\t\t\t\t\t\t3S7ZV9rvguSAQwXCkrgChCt0TnuDik99upgOFr0FlUR2AvKazaQ2vXtbMdZ6yQID\n\t\t\t\t\t\tAQABo4HKMIHHMB0GA1UdDgQWBBQl//EPgt0B3DrTbBuX38VSyb/r7TCBlwYDVR0j\n\t\t\t\t\t\tBIGPMIGMgBQl//EPgt0B3DrTbBuX38VSyb/r7aFxpG8wbTElMCMGA1UEAxQcKi5v\n\t\t\t\t\t\teGZvcmRicm9va2VzLmlkbS5vY2xjLm9yZzELMAkGA1UEBhMCVUsxDTALBgNVBAoT\n\t\t\t\t\t\tBE9DTEMxKDAmBgkqhkiG9w0BCQEWGWphbWVzLmh1dGNoaW5zb25Ab2NsYy5vcmeC\n\t\t\t\t\t\tAQIwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAa2zH9XCznFPWbsSL\n\t\t\t\t\t\tY2Hhaw/Xm97dFWsIIFFbRFZYl1AynVS4b5q3v5ZCzwKfKDqclhZm13E7PJufvBfV\n\t\t\t\t\t\trgs3zZBkoVTyUIc7KV6bk2qIR3IjB4ITG1BBn8a54b+AjjXqty1HWBBZ+UZ/r+38\n\t\t\t\t\t\tYPLmj20+F/PjJ+4ODI6YM+Rp9Ct7si1ahxtUn+4Yl+lr6Z7bJRLUuUbBk/M3q6UK\n\t\t\t\t\t\tci+Pgp7VeTDMUoK9qC84LxTPeNIOYJN5nbf5u3VU8KvrglIDqRWmGz2nRAtcWhaY\n\t\t\t\t\t\ttJol7RM0jtXXFrnpQdLWdsPTV6GFZcUmaTv0sY8m7BY5VGz8mhXAEc9lOuWGbNvy\n\t\t\t\t\t\tGoyFwA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://login.oxfordbrookes.idm.oclc.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.oxfordbrookes.idm.oclc.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.oxfordbrookes.idm.oclc.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.oxfordbrookes.idm.oclc.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.cbpf.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Orlanna Oliveira"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lanna@cbpf.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.cbpf.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID9jCCAt4CAQAwDQYJKoZIhvcNAQEFBQAwgcAxNjA0BgNVBAoTLUNCUEYgLSBD\nZW50cm8gQnJhc2lsZWlybyBkZSBQZXNxdWlzYXMgRmlzaWNhczEMMAoGA1UECxMD\nQ0FUMRwwGgYJKoZIhvcNAQkBFg1sYW5uYUBjYnBmLmJyMRcwFQYDVQQHEw5SaW8g\nZGUgSmFuZWlybzEXMBUGA1UECBMOUmlvIGRlIEphbmVpcm8xCzAJBgNVBAYTAkJS\nMRswGQYDVQQDExJzaGliYm9sZXRoLmNicGYuYnIwHhcNMTUxMDE2MTQxOTE3WhcN\nMTgxMDE1MTQxOTE3WjCBwDE2MDQGA1UEChMtQ0JQRiAtIENlbnRybyBCcmFzaWxl\naXJvIGRlIFBlc3F1aXNhcyBGaXNpY2FzMQwwCgYDVQQLEwNDQVQxHDAaBgkqhkiG\n9w0BCQEWDWxhbm5hQGNicGYuYnIxFzAVBgNVBAcTDlJpbyBkZSBKYW5laXJvMRcw\nFQYDVQQIEw5SaW8gZGUgSmFuZWlybzELMAkGA1UEBhMCQlIxGzAZBgNVBAMTEnNo\naWJib2xldGguY2JwZi5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAOP5KsReKesB+mSCPtKECtbEHR4HmL5nDtsirSweQs/0B91kQoYgNl7AMpmOt25p\nsGrWAF8poXJIZsFnVeFPRxXxamtOsbsmCNc5RFipG7ZNpnJEmH+TFVAFfBzav/xj\nhH0RQPGJ2CxGBxeS+zY6GzKqlKRCNTP0uud/dVeVw2A17FNJbOA7kEucrhVyxI1D\n7nOrYuMmL4H84Pe7SpXHWpdEZaiiuvbSW1XM+mHNlvBDNOWLilTB+LP7Xjq7Fpjr\nXTGvJ+zKL9SMEOnn8lc/6Iszu4ffg0S5xbJ+wwqBND2SLNxvJQtF9Ee3b/KjA2AI\nMRc4ZZ8eQZq4RKD65BBW7zkCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAlbBD9rz1\nTZSKOHEkt0TwLnhlwKJBqAQYrhr4kMeJdEmnQszWYNPmTnuaJ7byo0U95g9mJDRm\nqS+tX+qIOv/ds9qKY9bEXZOGKMo0srgMWaKufEOegxaZkP6x3nhCB6DzEmXuMVg+\n1HDGoHIZJuDZpXEE3Hdu1KiuQFhmcnO5MQ99WoMI3+Vy36Wrm/mdhyplkLTb1S3S\nmtit3VgXMl3KNv9IcRISBY9oyZdOTzHP/676+HwNYB888FApyKlmLnTvMtxCwuI8\np2bQTau4MNCPHLB6bYabI5bb21dowUM2UHgRMMQ3KtX9QADp8jQquqO10GIciPe4\nXQmKkysRlE2Thg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cbpf.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.cbpf.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.cbpf.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.cbpf.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.cbpf.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.cbpf.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.cbpf.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.cbpf.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.cbpf.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cbpf.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://portal.cbpf.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://portal.cbpf.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CBPF - Centro Brasileiro de Pesquisas Fisicas"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CBPF - Centro Brasileiro de Pesquisas Fisicas"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CBPF - Centro Brasileiro de Pesquisas Fisicas"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CBPF - Centro Brasileiro de Pesquisas Fisicas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID9jCCAt4CAQAwDQYJKoZIhvcNAQEFBQAwgcAxNjA0BgNVBAoTLUNCUEYgLSBD\nZW50cm8gQnJhc2lsZWlybyBkZSBQZXNxdWlzYXMgRmlzaWNhczEMMAoGA1UECxMD\nQ0FUMRwwGgYJKoZIhvcNAQkBFg1sYW5uYUBjYnBmLmJyMRcwFQYDVQQHEw5SaW8g\nZGUgSmFuZWlybzEXMBUGA1UECBMOUmlvIGRlIEphbmVpcm8xCzAJBgNVBAYTAkJS\nMRswGQYDVQQDExJzaGliYm9sZXRoLmNicGYuYnIwHhcNMTUxMDE2MTQxOTE3WhcN\nMTgxMDE1MTQxOTE3WjCBwDE2MDQGA1UEChMtQ0JQRiAtIENlbnRybyBCcmFzaWxl\naXJvIGRlIFBlc3F1aXNhcyBGaXNpY2FzMQwwCgYDVQQLEwNDQVQxHDAaBgkqhkiG\n9w0BCQEWDWxhbm5hQGNicGYuYnIxFzAVBgNVBAcTDlJpbyBkZSBKYW5laXJvMRcw\nFQYDVQQIEw5SaW8gZGUgSmFuZWlybzELMAkGA1UEBhMCQlIxGzAZBgNVBAMTEnNo\naWJib2xldGguY2JwZi5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAOP5KsReKesB+mSCPtKECtbEHR4HmL5nDtsirSweQs/0B91kQoYgNl7AMpmOt25p\nsGrWAF8poXJIZsFnVeFPRxXxamtOsbsmCNc5RFipG7ZNpnJEmH+TFVAFfBzav/xj\nhH0RQPGJ2CxGBxeS+zY6GzKqlKRCNTP0uud/dVeVw2A17FNJbOA7kEucrhVyxI1D\n7nOrYuMmL4H84Pe7SpXHWpdEZaiiuvbSW1XM+mHNlvBDNOWLilTB+LP7Xjq7Fpjr\nXTGvJ+zKL9SMEOnn8lc/6Iszu4ffg0S5xbJ+wwqBND2SLNxvJQtF9Ee3b/KjA2AI\nMRc4ZZ8eQZq4RKD65BBW7zkCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAlbBD9rz1\nTZSKOHEkt0TwLnhlwKJBqAQYrhr4kMeJdEmnQszWYNPmTnuaJ7byo0U95g9mJDRm\nqS+tX+qIOv/ds9qKY9bEXZOGKMo0srgMWaKufEOegxaZkP6x3nhCB6DzEmXuMVg+\n1HDGoHIZJuDZpXEE3Hdu1KiuQFhmcnO5MQ99WoMI3+Vy36Wrm/mdhyplkLTb1S3S\nmtit3VgXMl3KNv9IcRISBY9oyZdOTzHP/676+HwNYB888FApyKlmLnTvMtxCwuI8\np2bQTau4MNCPHLB6bYabI5bb21dowUM2UHgRMMQ3KtX9QADp8jQquqO10GIciPe4\nXQmKkysRlE2Thg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CBPF - Centro Brasileiro de Pesquisas Fisicas"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CBPF - Centro Brasileiro de Pesquisas Fisicas"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://portal.cbpf.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://portal.cbpf.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CBPF - Centro Brasileiro de Pesquisas Fisicas"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CBPF - Centro Brasileiro de Pesquisas Fisicas"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://commons.lbl.gov/sp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jmpetersen@lbl.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Julie Petersen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "gahaverkamp@lbl.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Greg Haverkamp"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://commons.lbl.gov/sp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lawrence Berkeley National Laboratory"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lbl.gov/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Lawrence Berkeley National Laboratory"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://commons.lbl.gov/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://commons.lbl.gov/display/itdivision/Commons"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Berkeley Lab Commons is the Lawrence Berkeley National Laboratory's enterprise wiki (Confluence)"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.lbl.gov/Disclaimers.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Berkeley Lab Commons"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAMFvgJRFOa3hMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGNvbW1vbnMyLmxibC5nb3YwHhcNMTAxMTA0MDAyMjQ5WhcNMjAxMTAxMDAy\nMjQ5WjAbMRkwFwYDVQQDExBjb21tb25zMi5sYmwuZ292MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAwRm530qhkb6e09J3QHgu7OuhnOeJ3VHN6DGXfmNc\n2b2/5ql79th6kpugJF5/Bxm1OYjK3bdEPGaG8yJ1utWZ14cPqFeHIh951cRkWU7L\nFJQ+yJPFKvMwmXmcGEqy1NFfFmCRQRC3WRkH7/Hp7WGRPkXWiLh4rUBPNKNzAXr4\nGhvQrQ2AN9bhChNa1zY08PvYucM2y78yQ7+FdMVXET2cDIPW6FzSBpHVBLwJ6Irh\nd2cdRUDSBVak+ZhnzpvLlf9LfsdUftHNyak6wCjnK8RjaTwFYrBGUZCE8BcD/yV1\nDGlpBhVNEq9e2EoKf2LBfwyDaMIZ72Eeu0mBdFZQjpWKWQIDAQABoz4wPDAbBgNV\nHREEFDASghBjb21tb25zMi5sYmwuZ292MB0GA1UdDgQWBBQd8cXLi8vWArhLTP46\nW9mLkn2wtTANBgkqhkiG9w0BAQUFAAOCAQEAVKXVe1GfD2rFtVhgA4rveGs6uwqs\n8O0JGBGvmd9FYVjaRQDaOTvqjiszasu+UWi2vFV5EGZxaqTYqjJ4Lhp2wUj2QO5i\nq7EJsdUsN4tLJITWjslojXyRJSWEpZLtV8zwfK+jQSL3x83Hw0odz4rFm0dOSpeP\nYJpo1KfvO/6SkHOHgNILhH7hgl+a0GxaeLslNfdKBrhShuO2biVvr7Z4gJvG+V0A\n8zm3+1KQvoPGwJQpRH1w9JWsereq+l6RO8mL07n3KOf+R18aD1z27hgrB2xnXRvJ\ny5ro/o5ZL+nrpKyCIDL0mIb1ZgA7Zu+R0m1wrHPSQrQjjw1R7aA/7XL8jg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://commons.lbl.gov/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://commons.lbl.gov/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Berkeley Lab Commons"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Berkeley Lab Commons is the Lawrence Berkeley National Laboratory's enterprise wiki (Confluence)"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.nottingham.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itservicedesk@nottingham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "University of Nottingham IT Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Betts"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Craig.Betts@nottingham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Craig"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.nottingham.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-05-25T14:11:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIElDCCA3ygAwIBAgIJALURZkw6iwLLMA0GCSqGSIb3DQEBBQUAMIHKMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEYMBYGA1UECBMPTm90dGluZ2hhbXNoaXJlMRMwEQYDVQQHEwpOb3R0\n\t\t\t\t\t\taW5naGFtMSEwHwYDVQQKExhVbml2ZXJzaXR5IG9mIE5vdHRpbmdoYW0xHTAbBgNV\n\t\t\t\t\t\tBAsTFEluZm9ybWF0aW9uIFNlcnZpY2VzMR0wGwYDVQQDExRpZHAubm90dGluZ2hh\n\t\t\t\t\t\tbS5hYy51azErMCkGCSqGSIb3DQEJARYcY3JhaWcuYmV0dHNAbm90dGluZ2hhbS5h\n\t\t\t\t\t\tYy51azAeFw0xNjAzMTgxMzMxNTdaFw0yNjAzMTYxMzMxNTdaMIHKMQswCQYDVQQG\n\t\t\t\t\t\tEwJHQjEYMBYGA1UECBMPTm90dGluZ2hhbXNoaXJlMRMwEQYDVQQHEwpOb3R0aW5n\n\t\t\t\t\t\taGFtMSEwHwYDVQQKExhVbml2ZXJzaXR5IG9mIE5vdHRpbmdoYW0xHTAbBgNVBAsT\n\t\t\t\t\t\tFEluZm9ybWF0aW9uIFNlcnZpY2VzMR0wGwYDVQQDExRpZHAubm90dGluZ2hhbS5h\n\t\t\t\t\t\tYy51azErMCkGCSqGSIb3DQEJARYcY3JhaWcuYmV0dHNAbm90dGluZ2hhbS5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANqHIPWC7p3lSRZFkpRn\n\t\t\t\t\t\tPJHq0cAvrShLxNI7eJzDsSnAoS7Oo+GuVoxU67L42AVHaFgL4FN2RFwOT7z1SCuU\n\t\t\t\t\t\tTIgR9pktqtj4DfZdZGJ37x39K61G3AZsAIdWtSfxz8jp/xdeSeQ8eMwXFF4EHKCB\n\t\t\t\t\t\tLg+JYqdU7Pj6E164OZTVMDvaL1bAB8PoJdak5prkF+mPypnbT3IJR+QS1DQ7BZ2C\n\t\t\t\t\t\tmBdwqMwpEsekqIFMJrdTkUD+GXo6FumWaMInDL9XA6LZxze6Yv4FhfsVAkrGVbtV\n\t\t\t\t\t\tXcmojk+bRDzghyNTy1g1jD0MZjNRvLmu2QIjnfBg5MlAzSz8MmU9PUHk0bpurbE6\n\t\t\t\t\t\tB+UCAwEAAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBH\n\t\t\t\t\t\tZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFPcu5ZkbXg9hkbtAfTstwTbJ\n\t\t\t\t\t\tHc+LMB8GA1UdIwQYMBaAFPcu5ZkbXg9hkbtAfTstwTbJHc+LMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQABXuIZB0oMlQ1eBm5/DzS8ydENYaOQzXbS7jtvyz0KdeD9JKgvxiJi\n\t\t\t\t\t\tI00RfzKCNm57dql8CBlNXiHGSZy5Q7wW6gYPuIJGGDFVbpkS1vGfj7WQuQhAqy7Y\n\t\t\t\t\t\tfJK7GrDycQHPyNWPRePhFH2lXJmdItbO7vMuF+ms4u3T+TP5pMNE+NPx5idyS3B1\n\t\t\t\t\t\te9H/OIaO4IEaTepcAab7HiAhpH1iPV/uzwWtflhD2MTfn+f63gXs8e+pqb24q37f\n\t\t\t\t\t\tOvug2b1EsArqCTc6H4dbQbOZVdDdbp/aYgqDllPdzQgzycfFij+asND0yMxxIUIN\n\t\t\t\t\t\t6LlTVJOiWX48GPxWBbsakO74dpdgXC/2"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nottingham.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.nottingham.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nottingham.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.nottingham.ac.uk/shibboleth-idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.nottingham.ac.uk/shibboleth-idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.nottingham.ac.uk/shibboleth-idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.nottingham.ac.uk/shibboleth-idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.nottingham.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nottingham.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nottingham.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIElDCCA3ygAwIBAgIJALURZkw6iwLLMA0GCSqGSIb3DQEBBQUAMIHKMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEYMBYGA1UECBMPTm90dGluZ2hhbXNoaXJlMRMwEQYDVQQHEwpOb3R0\n\t\t\t\t\t\taW5naGFtMSEwHwYDVQQKExhVbml2ZXJzaXR5IG9mIE5vdHRpbmdoYW0xHTAbBgNV\n\t\t\t\t\t\tBAsTFEluZm9ybWF0aW9uIFNlcnZpY2VzMR0wGwYDVQQDExRpZHAubm90dGluZ2hh\n\t\t\t\t\t\tbS5hYy51azErMCkGCSqGSIb3DQEJARYcY3JhaWcuYmV0dHNAbm90dGluZ2hhbS5h\n\t\t\t\t\t\tYy51azAeFw0xNjAzMTgxMzMxNTdaFw0yNjAzMTYxMzMxNTdaMIHKMQswCQYDVQQG\n\t\t\t\t\t\tEwJHQjEYMBYGA1UECBMPTm90dGluZ2hhbXNoaXJlMRMwEQYDVQQHEwpOb3R0aW5n\n\t\t\t\t\t\taGFtMSEwHwYDVQQKExhVbml2ZXJzaXR5IG9mIE5vdHRpbmdoYW0xHTAbBgNVBAsT\n\t\t\t\t\t\tFEluZm9ybWF0aW9uIFNlcnZpY2VzMR0wGwYDVQQDExRpZHAubm90dGluZ2hhbS5h\n\t\t\t\t\t\tYy51azErMCkGCSqGSIb3DQEJARYcY3JhaWcuYmV0dHNAbm90dGluZ2hhbS5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANqHIPWC7p3lSRZFkpRn\n\t\t\t\t\t\tPJHq0cAvrShLxNI7eJzDsSnAoS7Oo+GuVoxU67L42AVHaFgL4FN2RFwOT7z1SCuU\n\t\t\t\t\t\tTIgR9pktqtj4DfZdZGJ37x39K61G3AZsAIdWtSfxz8jp/xdeSeQ8eMwXFF4EHKCB\n\t\t\t\t\t\tLg+JYqdU7Pj6E164OZTVMDvaL1bAB8PoJdak5prkF+mPypnbT3IJR+QS1DQ7BZ2C\n\t\t\t\t\t\tmBdwqMwpEsekqIFMJrdTkUD+GXo6FumWaMInDL9XA6LZxze6Yv4FhfsVAkrGVbtV\n\t\t\t\t\t\tXcmojk+bRDzghyNTy1g1jD0MZjNRvLmu2QIjnfBg5MlAzSz8MmU9PUHk0bpurbE6\n\t\t\t\t\t\tB+UCAwEAAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBH\n\t\t\t\t\t\tZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFPcu5ZkbXg9hkbtAfTstwTbJ\n\t\t\t\t\t\tHc+LMB8GA1UdIwQYMBaAFPcu5ZkbXg9hkbtAfTstwTbJHc+LMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQABXuIZB0oMlQ1eBm5/DzS8ydENYaOQzXbS7jtvyz0KdeD9JKgvxiJi\n\t\t\t\t\t\tI00RfzKCNm57dql8CBlNXiHGSZy5Q7wW6gYPuIJGGDFVbpkS1vGfj7WQuQhAqy7Y\n\t\t\t\t\t\tfJK7GrDycQHPyNWPRePhFH2lXJmdItbO7vMuF+ms4u3T+TP5pMNE+NPx5idyS3B1\n\t\t\t\t\t\te9H/OIaO4IEaTepcAab7HiAhpH1iPV/uzwWtflhD2MTfn+f63gXs8e+pqb24q37f\n\t\t\t\t\t\tOvug2b1EsArqCTc6H4dbQbOZVdDdbp/aYgqDllPdzQgzycfFij+asND0yMxxIUIN\n\t\t\t\t\t\t6LlTVJOiWX48GPxWBbsakO74dpdgXC/2"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Nottingham"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nottingham.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Nottingham"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://falconidp.uwrf.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dots@uwrf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert Rust"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dots@uwrf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jason Winget"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dots@uwrf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Division of Technology Services"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "abuse@uwrf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jason Winget"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://falconidp.uwrf.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://falconidp.uwrf.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://falconidp.uwrf.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://falconidp.uwrf.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://falconidp.uwrf.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://falconidp.uwrf.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uwrf.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uwrf.edu/DoTS/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is the identity provider for Falcon accounts hosted at the University of Wisconsin-River Falls"
                  }
                ],
                "logo": [
                  {
                    "text": "https://falconidp.uwrf.edu/idp/images/UWRFWordmark.png",
                    "lang": "en",
                    "height": "75",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "213"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Wisconsin-River Falls"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAN/U2QOyvHgKyQfthCk3DrLhvoMRMA0GCSqGSIb3DQEB\nBQUAMB0xGzAZBgNVBAMTEmZhbGNvbmlkcC51d3JmLmVkdTAeFw0xMzA3MDkxODQw\nNTdaFw0zMzA3MDkxODQwNTdaMB0xGzAZBgNVBAMTEmZhbGNvbmlkcC51d3JmLmVk\ndTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKeTbfup9d9iGUkT8ZXG\n3ab5ITZHLhPFUMz5K5Gf+RtP67qY6IfW5XerKd+DqWYnYOqIsEno6iUJi6FRhwd6\nK93ikNM/ttaOeObwSl2NmgJBJjQv+o6ps4NVH+eiYesCKf9FDzq6epJWD1OoBYFz\n1rmXUGvkg0vfElQYWb4dcbkD6pL9Eh6xRlSSqqUSTzEHq+dtAGkv9qR9VPvx0QQK\nT71CoRSgD74k3aeksTrAnO7qUnuvFtQ2B4SxpHUEWYr/ke1W6WEyJZ8G0MOZz3hS\nvi4FLuW7vaW8k9qjtRtnJGr1ZC/beZjDS4bijgDCX2deTpP2sBpp/yJOdcBNpxYI\n+BcCAwEAAaNrMGkwSAYDVR0RBEEwP4ISZmFsY29uaWRwLnV3cmYuZWR1hilodHRw\nczovL2ZhbGNvbmlkcC51d3JmLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n5c6lokB0p4KGA/8AM1m/zHjlANswDQYJKoZIhvcNAQEFBQADggEBAHw+PG5JCERF\nb+n8FO6q3Bk31nVxjhz+mrhGMb2rRpVYHWsGNuN8idHLQeFlyVSkI22lkuzZVHii\nFM6PiSsO7aHWNzLBUI5GQu6fpE+Tsv95fMOWxUGGyzxwku6DHiMJF2LIif/e0pHe\nCsl6HQ1d+LYePGNt1MFuhEGMA3A2hp5vOgVYDgUPPcnclrLZBo4kcQXnckbyC5OM\nhdhoAotvi5J7+ke4HlphH3QPxhnn70l2h2B0IIxefoGWccXQ4bYnELjT+vNjXPQI\na0R32mN78I6LMoHGNX8WHv33oD3cBCwKQ0ZiSGPg56Q7QkPEugLOZkjVwgGe9YcR\nACtYScHQvMw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://falconidp.uwrf.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Wisconsin-River Falls"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uwrf.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Wisconsin-River Falls"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://identites.ensea.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "federation@ensea.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://identites.ensea.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2011-05-11T08:50:03Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://identites.ensea.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://identites.ensea.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://identites.ensea.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ensea.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ensea.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENSEA"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENSEA"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEcTCCA1mgAwIBAgIQUg9Ih5mPMJpavDCAsMuZqTANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQxNTAwMDAwMFoXDTE3MDQxNDIzNTk1OVowQDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRswGQYDVQQDExJpZGVudGl0ZXMu\nZW5zZWEuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDQWllKmvIV\n9KtnhWX8cmcTAmcq5cxrkRCWzZZJXSyvqZ1Glf5jvvErdyXPBhI1bJ7+wP0AkOVk\nI/WznWeap7PcnDjeDspzDP9FDoEJOAkw8LGsAtuJI64TGfnTBSvjAcxAexubp3zW\n0FjrqL+6oQxkL4GcZ6eaQF1uvFl7CPO7D3lWcFBgg2PRUl0Ig6ZUK0/PBgdjNRbi\nvxhRyQRloYJp3AGhSNn+STyNSAB071vUZG8ChVs2lNZY1insE46cYdVo1YqSgjL5\nt6zdNJaJRHs7aTWq4S7Z700sKJ7W42mlUpF9SCjGUU8gS3xoHlI+9o5vnRmsO3fa\n+j0FPaw+9QZbAgMBAAGjggFvMIIBazAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3\nV0fqkOO57TAdBgNVHQ4EFgQUrahgQ8RDG2G7cIicKcbpWSxYc5MwDgYDVR0PAQH/\nBAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUF\nBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1UdHwQz\nMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0Eu\nY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3Mu\ndGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9v\nY3NwLnRjcy50ZXJlbmEub3JnMB0GA1UdEQQWMBSCEmlkZW50aXRlcy5lbnNlYS5m\ncjANBgkqhkiG9w0BAQUFAAOCAQEAnQAOMurBNe5YOWk6SekHmnTsHcGz0h2aLp36\nIIorkCb3f78T6/oPRvlFWvTIOjVNbxXzFKJrJA4fu7dDRx/6ckPGjVJwXHRb7rOv\ngc9hEfb3v4bMhxWOX7WyvNEyewKe84vrobDxHqpXpL7KU5LAJNPYglZr62yiJI9z\nwKvG/2aZDxc5DdjeTq32zVxO9KE8QDfMA14cHTimjnOhSV8MNIp5uLHv8827pLeT\nSP1F5eWtaNyrocG8x1mL3qMePnZl92Fuj0F4FhHkAnhWCxWjCou9sQa8KeBcCO9W\nQK1LMEX5HeO8HKnIkLfCYBO3LiMoZmq45EvpF/kWQqI9WQacXQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEcTCCA1mgAwIBAgIQG4CD0xtQn3PW9uGm5cYkdzANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDEyNDAwMDAwMFoXDTE3MDMwODIzNTk1OVowQDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRswGQYDVQQDExJpZGVudGl0ZXMu\nZW5zZWEuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDF0Ed4XZzY\nrYz4dsdiRwqrHk+MC33vn/BJf+JkwnSBPtfVsOUcFH3BGJ0B051QpD2oCPOIiz2V\n9rzP6E9PFP3MGuuwKtnGZnDBBSMYEp+yKewjehfV07qgoO/VLZtAA3dxjbxQrmal\nC13sqrKaafTJdHtyjhZNUpDzc8Ig5pgEj/rLymcJVgp3mjEAkm3J8fP/upEYdx4e\nEQD2XgIBuBGZThSuJOTOUXtf1qF9JhDswlHst28jHzp31MDybWdZ1xTyUVo3pYwW\nUPStS9HdvfNoz/fR5+Pmdfu+rpXTZ7jjgnMkQy84qHtbH4u/d3vFjKPCx0DZ7UFA\nSHaH/Ue3OQZtAgMBAAGjggFvMIIBazAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3\nV0fqkOO57TAdBgNVHQ4EFgQUhUrcsTUfWA/zwCZFVUrW0BpWBCIwDgYDVR0PAQH/\nBAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUF\nBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1UdHwQz\nMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0Eu\nY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3Mu\ndGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9v\nY3NwLnRjcy50ZXJlbmEub3JnMB0GA1UdEQQWMBSCEmlkZW50aXRlcy5lbnNlYS5m\ncjANBgkqhkiG9w0BAQUFAAOCAQEAgym0ss96sn/udEY0m2qHQ5VNt3gfc1oAlX8w\no44C1pPjZRbvySLWF+qc7VQP6HrbuiEjA47o1tZoqkh01FntuQfM+9V3naFa74Wl\nKOAbEiTSJsOTZLbmr1j0lovOlxJ4UddRVWMjCIfbgsUw+ZtoRvUqnO16pcZXrLCa\nHMl1RBtfEkwVl+vESzYk/sSOQ+CXJoi6spKXV0tpBS8Lf/I9IRjayHALjWwklb8l\nfbatPd5QbO8MzMD3Oak05pvHRKvtI7ZWxsbQIg/40sT4KmWDxmkLIDLY/2E8hUDN\naWAcMmjEoKVXB6St7+El4x83Ul04VV3UNYrTOdDO64mVnp8j2A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ENSEA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ensea.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ENSEA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.vivomiles.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Raven-Stoker"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:thunder@everlution.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Thunder"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Raven-Stoker"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:thunder@everlution.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Thunder"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.vivomiles.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Everlution Software Limited: Vivomiles"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vivomiles.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Everlution Software Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.vivomiles.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.vivomiles.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.vivomiles.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.vivomiles.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp.vivomiles.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN66lpSg173QMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHNwLnZpdm9taWxlcy5jb20wHhcNMTEwNDA1MTMzMTU5WhcNMjEwNDAyMTMz\n\t\t\t\t\t\tMTU5WjAbMRkwFwYDVQQDExBzcC52aXZvbWlsZXMuY29tMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAzARjQBBuE87LSlNd6570gHLigYhVXr46123MR5ln\n\t\t\t\t\t\t/VOeFHcnof6+To7Ztlh81cM4BoR9tf5j7UxzSFW5iepICzDDzSmT4IyoBvDwZwCT\n\t\t\t\t\t\tnEw5RuYdlLDK26PVad6EhSMAm9JTmICCtO1VqfeslKCk5/MS2aq+I2W9aypnNNrC\n\t\t\t\t\t\t3q8tg3fzmnXaBYBhJ3ToUszK/y/fu2cpzZZA6NaJjnmDe0GvJiqP2O3Ylx46QABv\n\t\t\t\t\t\t8tU/Pur11+htjB4JVDS/SaiXtRP07E6db2EBYUbvYiG5hQZal+J+XBHyRIyHP5AP\n\t\t\t\t\t\tRKdb9CGo9JKB+0wl9Gegqh859jUK2vs/Vum4MMczPwIozQIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghBzcC52aXZvbWlsZXMuY29tMB0GA1UdDgQWBBTTtb+JbRhX8ff+vn8w\n\t\t\t\t\t\tt9K9SiJs/DANBgkqhkiG9w0BAQUFAAOCAQEARXepedwie+WYAgs5k9Xr7TbLD2ut\n\t\t\t\t\t\tGunzGs/1QdR4rA6w7vz93tL2zYDq/D7GcfNnR343Y2/0nRIAbHc+MDo/IrjWxP0c\n\t\t\t\t\t\tBOa7wztmyrmetlg+Xh8me0VqLoMlTbQms7RrzI1uHzb03qwr6q+bk88Pv0rTWNd3\n\t\t\t\t\t\tuT01Jln+UHrfihCK+14tXFCr8VOtRad+q28tUyeQ+KIs3kV9K1vCAkP4FX5GCCNn\n\t\t\t\t\t\tzGhDgZb6TogMbP9LbAMiYAX8n5ye3ffm9059+4qUBCaMNwD2zIxvU/5/JNKu3B1G\n\t\t\t\t\t\tRPjrEJyHJANuvnu/9Nywj3LyZt4iPzxjZchE7n0pyK4SIcMptWwWbJC1wQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN66lpSg173QMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHNwLnZpdm9taWxlcy5jb20wHhcNMTEwNDA1MTMzMTU5WhcNMjEwNDAyMTMz\n\t\t\t\t\t\tMTU5WjAbMRkwFwYDVQQDExBzcC52aXZvbWlsZXMuY29tMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAzARjQBBuE87LSlNd6570gHLigYhVXr46123MR5ln\n\t\t\t\t\t\t/VOeFHcnof6+To7Ztlh81cM4BoR9tf5j7UxzSFW5iepICzDDzSmT4IyoBvDwZwCT\n\t\t\t\t\t\tnEw5RuYdlLDK26PVad6EhSMAm9JTmICCtO1VqfeslKCk5/MS2aq+I2W9aypnNNrC\n\t\t\t\t\t\t3q8tg3fzmnXaBYBhJ3ToUszK/y/fu2cpzZZA6NaJjnmDe0GvJiqP2O3Ylx46QABv\n\t\t\t\t\t\t8tU/Pur11+htjB4JVDS/SaiXtRP07E6db2EBYUbvYiG5hQZal+J+XBHyRIyHP5AP\n\t\t\t\t\t\tRKdb9CGo9JKB+0wl9Gegqh859jUK2vs/Vum4MMczPwIozQIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghBzcC52aXZvbWlsZXMuY29tMB0GA1UdDgQWBBTTtb+JbRhX8ff+vn8w\n\t\t\t\t\t\tt9K9SiJs/DANBgkqhkiG9w0BAQUFAAOCAQEARXepedwie+WYAgs5k9Xr7TbLD2ut\n\t\t\t\t\t\tGunzGs/1QdR4rA6w7vz93tL2zYDq/D7GcfNnR343Y2/0nRIAbHc+MDo/IrjWxP0c\n\t\t\t\t\t\tBOa7wztmyrmetlg+Xh8me0VqLoMlTbQms7RrzI1uHzb03qwr6q+bk88Pv0rTWNd3\n\t\t\t\t\t\tuT01Jln+UHrfihCK+14tXFCr8VOtRad+q28tUyeQ+KIs3kV9K1vCAkP4FX5GCCNn\n\t\t\t\t\t\tzGhDgZb6TogMbP9LbAMiYAX8n5ye3ffm9059+4qUBCaMNwD2zIxvU/5/JNKu3B1G\n\t\t\t\t\t\tRPjrEJyHJANuvnu/9Nywj3LyZt4iPzxjZchE7n0pyK4SIcMptWwWbJC1wQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.vivomiles.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.vivomiles.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.vivomiles.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.vivomiles.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.vivomiles.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp.vivomiles.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.vivomiles.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp.vivomiles.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp.vivomiles.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp.vivomiles.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.bsz-bw.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hotline"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hotline@aai.dfn.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "DFN-AAI"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hotline"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hotline@aai.dfn.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "DFN-AAI"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.bsz-bw.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2014-10-28T08:48:10Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://aai.dfn.de/category/bwidm-member"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.bsz-bw.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGyjCCBbKgAwIBAgIHGAAaqAVbcDANBgkqhkiG9w0BAQsFADB9MQswCQYDVQQG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\ncyobduSNkOZaUoroSIY="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.bsz-bw.de,OU=Webserver,O=Bibliotheksservice-Zentrum Baden-Wuerttemberg,L=Konstanz,ST=Baden-Wuerttemberg,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bsz-bw.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.bsz-bw.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.bsz-bw.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.bsz-bw.de/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.bsz-bw.de/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.bsz-bw.de:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.bsz-bw.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.bsz-bw.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.bsz-bw.de/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.bsz-bw.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.bsz-bw.de/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.bsz-bw.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.bsz-bw.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bsz-bw.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.bsz-bw.de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.bsz-bw.de"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider des Bibliotheksservice-Zentrums Baden-W\u00fcrttemberg"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider of Bibliotheksservice-Zentrums Baden-Wuerttemberg"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.bsz-bw.de/idp/images/favicon.ico",
                    "height": "32",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "32"
                  },
                  {
                    "text": "https://idp.bsz-bw.de/idp/images/logo.gif",
                    "height": "49",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Bibliotheksservice-Zentrum Baden-W\u00fcrttemberg"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Bibliotheksservice-Zentrum Baden-Wuerttemberg"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.bsz-bw.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGyjCCBbKgAwIBAgIHGAAaqAVbcDANBgkqhkiG9w0BAQsFADB9MQswCQYDVQQG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\ncyobduSNkOZaUoroSIY="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.bsz-bw.de,OU=Webserver,O=Bibliotheksservice-Zentrum Baden-Wuerttemberg,L=Konstanz,ST=Baden-Wuerttemberg,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bibliotheksservice Zentrum Baden-Wuerttemberg"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bibliotheksservice Zentrum Baden-Wuerttemberg"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bsz-bw.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bsz-bw.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e56"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e56"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.plumpton.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.plumpton.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-12-11T17:22:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/plumpton.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/plumpton.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "plumpton.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Plumpton College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.plumpton.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://kitcatalogue.alpha.jisc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hamilton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:martin.hamilton@jisc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hamilton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:martin.hamilton@jisc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://kitcatalogue.alpha.jisc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-01-08T14:34:35Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Jisc Kit-Catalogue Test Site"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jisc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Jisc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://kitcatalogue.alpha.jisc.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://kitcatalogue.alpha.jisc.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://kitcatalogue.alpha.jisc.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://kitcatalogue.alpha.jisc.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://kitcatalogue.alpha.jisc.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://kitcatalogue.alpha.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Test site for Jisc Kit-Catalogue pilot"
                  }
                ],
                "logo": [
                  {
                    "text": "https://kitcatalogue.alpha.jisc.ac.uk/images/logo-kc.jpg",
                    "height": "54",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "194"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Jisc Kit-Catalogue Test Site"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAKMeseZKJGIoMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\n\t\t\t\t\t\tBAMTD2lwLTE3Mi0zMS01LTI1MzAeFw0xNTEyMTQxOTQ1NDlaFw0yNTEyMTExOTQ1\n\t\t\t\t\t\tNDlaMBoxGDAWBgNVBAMTD2lwLTE3Mi0zMS01LTI1MzCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBALUnNJa3XZMlI4YgQu95YMzWuru+5cgqOzwxoRoQUvw4\n\t\t\t\t\t\tECYGxNEqHXv1JNqXt90WdZmsfRaUt1khkX/xVGnyJUdbcLaWBfJYBsGD/ECTDMHe\n\t\t\t\t\t\tLAOQ9Z+VgkEQK+UsVy9nr55Pu8egTbmZWDrWolvHq++OcJpzxMV17j+tupChPKQ5\n\t\t\t\t\t\t0oFJmb/Z0wk4G5h9sU21tNOO3CNKtE+2GF1moOXDmSkBwx1L6ysbIC0FPA/RIcwx\n\t\t\t\t\t\t54wuHlOR77GujLY1vRUaftRZSGxtTJX19ivl5xuD4vRvToO5Aeii3ythFd72FfCn\n\t\t\t\t\t\txVb6F/d22iCX4fbBOLKNTO+pRyqghwMHCa4UmulrGPsCAwEAAaM9MDswGgYDVR0R\n\t\t\t\t\t\tBBMwEYIPaXAtMTcyLTMxLTUtMjUzMB0GA1UdDgQWBBTnSpLUEXnd6lMdVr8pAp20\n\t\t\t\t\t\t8yjgZjANBgkqhkiG9w0BAQUFAAOCAQEAadAOGIH8I3mNUshcPJoShOnV1bFVawd9\n\t\t\t\t\t\tMJ89nBNOWQOTg/pnrCJnKqHfSN4rRNxhhd61tBYS8bJhoIcQw5ZsVETNJtWSxPIc\n\t\t\t\t\t\t73TS4zdIvtWLV0RChU/jIzxP1zvoJbB7h7M47223J7QGeJ9TedHh0k06A//Owpe+\n\t\t\t\t\t\tXHmUMZZiEPLxTk4hpTd5VbqqZAQs0aliLq00sPEMSB1uxvl/DENe2otIt8bBcjvy\n\t\t\t\t\t\toE077Tm5R1jVQ2zGmZWncGY13wiGAJOskAkQQN7MsdwWfjdnlywG/tH1pcSgXEiJ\n\t\t\t\t\t\tVAt7x31QCs60bw6OBdviHmBM95dSxeJ6UECgCYv53RAqTOqBW1cG9g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://kitcatalogue.alpha.jisc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://kitcatalogue.alpha.jisc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://kitcatalogue.alpha.jisc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://kitcatalogue.alpha.jisc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://kitcatalogue.alpha.jisc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://kitcatalogue.alpha.jisc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.amersham.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dawe"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pdawe@amersham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Phil"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dawe"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pdawe@amersham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Phil"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.amersham.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-07-04T19:36:23Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVALWxW6Db2xAPZ4pIJ+T4NU75vxlwMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB0xGzAZBgNVBAMTEmlkcC5hbWVyc2hhbS5hYy51azAeFw0xMzA2MjUwOTAy\n\t\t\t\t\t\tMDBaFw0zMzA2MjUwOTAyMDBaMB0xGzAZBgNVBAMTEmlkcC5hbWVyc2hhbS5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALBkBn27OKELkBJlv3xe\n\t\t\t\t\t\txyxrvYJPhrrcBe5aaNzPDLZTjf2zpF92jpg6oyMJv7PQK2HXEx2fHFy/NCXjkDl+\n\t\t\t\t\t\tpxiqgb7SZJiJ1YGecBRPG1oknGjfUqVXwXTCr26QB33MXVIbgQj1408jC9qdZo9x\n\t\t\t\t\t\tncXPgZYFOChtwsfu2U6aGRjikTuLSh4zTsVIFWR/gR8ngaqILV6cYx3tiS2c3rct\n\t\t\t\t\t\t/porpcnulNMws8d2YzKV3QX6/W6arNh+lPjBs6Vs1BdkvwumJahwuZulIxMQcpZ6\n\t\t\t\t\t\t7i/JO6SguAWwfbTJTecgXR5gffP6Yu/O33XgL2jk+04YFIn9LUGilJmiybv+NS18\n\t\t\t\t\t\t//ECAwEAAaNrMGkwSAYDVR0RBEEwP4ISaWRwLmFtZXJzaGFtLmFjLnVrhilodHRw\n\t\t\t\t\t\tczovL2lkcC5hbWVyc2hhbS5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n\t\t\t\t\t\tVMTR+Ij7KaIfnySohB/Q57z9M+AwDQYJKoZIhvcNAQEFBQADggEBADSE/dbwVCpK\n\t\t\t\t\t\tZrwpDxt4orHeX9/xPeUmxu8+uE34TgjCtmUq1HrkvIIDAQBtJlxcSC3hC4YTCa+S\n\t\t\t\t\t\tha1f6ydDdui5qhnXB9lsp3GIoiEQ6dp9+UdugUnugk8Fr+PCkqKg4DLlZDexgWRQ\n\t\t\t\t\t\t2yYSL7KWBmNJsV+SnTOS2HZcFRKP1JxLjquZ49MXqmb0zm0itXCBkjsTUBbnAkCV\n\t\t\t\t\t\tVrs01QqpXSy391maFDQlnzLS9Tf1lDC9k2Ap41tV34a39CdU4hk5eSd1izdg1F/C\n\t\t\t\t\t\tT1m7Vb/gKNqpwHzxUnfNtZm8EOudFsbqyPO5YIVJ7Bh4GOf1L8q8JTSRwR/Sle0R\n\t\t\t\t\t\t7tCYiJS1fps="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "amersham.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.amersham.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.amersham.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.amersham.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.amersham.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.amersham.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.amersham.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.amersham.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.amersham.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.amersham.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.amersham.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.amersham.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "amersham.ac.uk"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Amersham & Wycombe College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVALWxW6Db2xAPZ4pIJ+T4NU75vxlwMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB0xGzAZBgNVBAMTEmlkcC5hbWVyc2hhbS5hYy51azAeFw0xMzA2MjUwOTAy\n\t\t\t\t\t\tMDBaFw0zMzA2MjUwOTAyMDBaMB0xGzAZBgNVBAMTEmlkcC5hbWVyc2hhbS5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALBkBn27OKELkBJlv3xe\n\t\t\t\t\t\txyxrvYJPhrrcBe5aaNzPDLZTjf2zpF92jpg6oyMJv7PQK2HXEx2fHFy/NCXjkDl+\n\t\t\t\t\t\tpxiqgb7SZJiJ1YGecBRPG1oknGjfUqVXwXTCr26QB33MXVIbgQj1408jC9qdZo9x\n\t\t\t\t\t\tncXPgZYFOChtwsfu2U6aGRjikTuLSh4zTsVIFWR/gR8ngaqILV6cYx3tiS2c3rct\n\t\t\t\t\t\t/porpcnulNMws8d2YzKV3QX6/W6arNh+lPjBs6Vs1BdkvwumJahwuZulIxMQcpZ6\n\t\t\t\t\t\t7i/JO6SguAWwfbTJTecgXR5gffP6Yu/O33XgL2jk+04YFIn9LUGilJmiybv+NS18\n\t\t\t\t\t\t//ECAwEAAaNrMGkwSAYDVR0RBEEwP4ISaWRwLmFtZXJzaGFtLmFjLnVrhilodHRw\n\t\t\t\t\t\tczovL2lkcC5hbWVyc2hhbS5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n\t\t\t\t\t\tVMTR+Ij7KaIfnySohB/Q57z9M+AwDQYJKoZIhvcNAQEFBQADggEBADSE/dbwVCpK\n\t\t\t\t\t\tZrwpDxt4orHeX9/xPeUmxu8+uE34TgjCtmUq1HrkvIIDAQBtJlxcSC3hC4YTCa+S\n\t\t\t\t\t\tha1f6ydDdui5qhnXB9lsp3GIoiEQ6dp9+UdugUnugk8Fr+PCkqKg4DLlZDexgWRQ\n\t\t\t\t\t\t2yYSL7KWBmNJsV+SnTOS2HZcFRKP1JxLjquZ49MXqmb0zm0itXCBkjsTUBbnAkCV\n\t\t\t\t\t\tVrs01QqpXSy391maFDQlnzLS9Tf1lDC9k2Ap41tV34a39CdU4hk5eSd1izdg1F/C\n\t\t\t\t\t\tT1m7Vb/gKNqpwHzxUnfNtZm8EOudFsbqyPO5YIVJ7Bh4GOf1L8q8JTSRwR/Sle0R\n\t\t\t\t\t\t7tCYiJS1fps="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Amersham & Wycombe College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.amersham.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Amersham & Wycombe College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib1.napier.ac.uk/entity",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Foley"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:citsupport@napier.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Todd"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:J.Todd@napier.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib1.napier.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-05-08T17:11:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUTi/qwLJiY52T4kltTmNqkd1B5l4wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHTEbMBkGA1UEAxMSc2hpYjEubmFwaWVyLmFjLnVrMB4XDTE0MDMyNDE2MjEy\n\t\t\t\t\t\tNloXDTM0MDMyNDE2MjEyNlowHTEbMBkGA1UEAxMSc2hpYjEubmFwaWVyLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAiWQo/dClCX3CqsYfxWDB\n\t\t\t\t\t\touKIAl/kkobQLrukfV5cyu9P94PBOQK/hR+S2V7zxtZ/vmE+kWO9SXfnTJv8hBhr\n\t\t\t\t\t\t0QiF64tK2fllzTRGC5NoWBy2iJ7LsxxI37wmB5n195mfaenb+nOdEF3XYhTer1NR\n\t\t\t\t\t\tc/PjrcnWmWOImGGS770Gra7jC+i4LDqlVRihJQHfUooStIPghmblu7qsIjUZ+LUU\n\t\t\t\t\t\tXc8RK12Va5Wl0CvEJj0jPNUZ9IjuJjlLcz27Ot1XFiLMdo3qBCk4VM9pTB8k6Y4Z\n\t\t\t\t\t\tJ7GaEo4PlMja9u6qerThIFeIGPzfCg9wvExNi5T+qjgO75C4pcduMWCipa4Lbt/F\n\t\t\t\t\t\tswIDAQABo2swaTBIBgNVHREEQTA/ghJzaGliMS5uYXBpZXIuYWMudWuGKWh0dHBz\n\t\t\t\t\t\tOi8vc2hpYjEubmFwaWVyLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSc\n\t\t\t\t\t\t+TA4/2hb/0/5R4QBKnrA3hTQ0jANBgkqhkiG9w0BAQUFAAOCAQEAhP6pcfyhqfAc\n\t\t\t\t\t\tSolKIRerz/8MieqSFSBR+MCc3Ow4MeGcf++7wim6IPKpAlBXl8T8BatoqO9yVLLB\n\t\t\t\t\t\t2AFpRHHlgoYceryrlwcWJOcyX/DwPBvaqEZgg16IwGZ6dwrVm+qHlRWZgOPs3blY\n\t\t\t\t\t\t0AvEsoucZkWGp4q5rVXTSb8V+PZ++QQuvxPpN6ZweVJWLyqNTiprHzg3ef+lecK2\n\t\t\t\t\t\tFeboIZjNCsRtYo3FhXguhrf4ORkzU6jmm4iqdqApQbNyPuQ/W+6GQ7EQcU0dyK9M\n\t\t\t\t\t\tNVZrPTK8LScXAcwOoMDzltNhzLHUa/WJUB95shI9hXSscHrpt8oQfHyAsrUoV07t\n\t\t\t\t\t\tDeJEdpoirw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "napier.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib1.napier.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib1.napier.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.napier.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.napier.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.napier.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.napier.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib1.napier.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib1.napier.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "napier.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUTi/qwLJiY52T4kltTmNqkd1B5l4wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHTEbMBkGA1UEAxMSc2hpYjEubmFwaWVyLmFjLnVrMB4XDTE0MDMyNDE2MjEy\n\t\t\t\t\t\tNloXDTM0MDMyNDE2MjEyNlowHTEbMBkGA1UEAxMSc2hpYjEubmFwaWVyLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAiWQo/dClCX3CqsYfxWDB\n\t\t\t\t\t\touKIAl/kkobQLrukfV5cyu9P94PBOQK/hR+S2V7zxtZ/vmE+kWO9SXfnTJv8hBhr\n\t\t\t\t\t\t0QiF64tK2fllzTRGC5NoWBy2iJ7LsxxI37wmB5n195mfaenb+nOdEF3XYhTer1NR\n\t\t\t\t\t\tc/PjrcnWmWOImGGS770Gra7jC+i4LDqlVRihJQHfUooStIPghmblu7qsIjUZ+LUU\n\t\t\t\t\t\tXc8RK12Va5Wl0CvEJj0jPNUZ9IjuJjlLcz27Ot1XFiLMdo3qBCk4VM9pTB8k6Y4Z\n\t\t\t\t\t\tJ7GaEo4PlMja9u6qerThIFeIGPzfCg9wvExNi5T+qjgO75C4pcduMWCipa4Lbt/F\n\t\t\t\t\t\tswIDAQABo2swaTBIBgNVHREEQTA/ghJzaGliMS5uYXBpZXIuYWMudWuGKWh0dHBz\n\t\t\t\t\t\tOi8vc2hpYjEubmFwaWVyLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSc\n\t\t\t\t\t\t+TA4/2hb/0/5R4QBKnrA3hTQ0jANBgkqhkiG9w0BAQUFAAOCAQEAhP6pcfyhqfAc\n\t\t\t\t\t\tSolKIRerz/8MieqSFSBR+MCc3Ow4MeGcf++7wim6IPKpAlBXl8T8BatoqO9yVLLB\n\t\t\t\t\t\t2AFpRHHlgoYceryrlwcWJOcyX/DwPBvaqEZgg16IwGZ6dwrVm+qHlRWZgOPs3blY\n\t\t\t\t\t\t0AvEsoucZkWGp4q5rVXTSb8V+PZ++QQuvxPpN6ZweVJWLyqNTiprHzg3ef+lecK2\n\t\t\t\t\t\tFeboIZjNCsRtYo3FhXguhrf4ORkzU6jmm4iqdqApQbNyPuQ/W+6GQ7EQcU0dyK9M\n\t\t\t\t\t\tNVZrPTK8LScXAcwOoMDzltNhzLHUa/WJUB95shI9hXSscHrpt8oQfHyAsrUoV07t\n\t\t\t\t\t\tDeJEdpoirw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Edinburgh Napier University (legacy)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.napier.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Edinburgh Napier University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://uisshibb1.uis.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tllos1@uis.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tulio Llosa"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tllos1@uis.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tulio Llosa"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tllos1@uis.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tulio Llosa"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://uisshibb1.uis.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://uisshibb1.uis.edu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://uisshibb1.uis.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uisshibb1.uis.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://uisshibb1.uis.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://uisshibb1.uis.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uisshibb1.uis.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uis.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uis.edu"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Illinois At Springfield"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "User Identification Service @ Illinois Springfield"
                  }
                ],
                "logo": [
                  {
                    "text": "https://uofi.box.com/shared/static/l5b0pac3r6fgffnybw4olbrs68dwwxar.jpg",
                    "lang": "en",
                    "height": "183",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "131"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.uis.edu/informationtechnologyservices/about/policies.html#acceptuse"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAKHOcYSjaC5wZJQOZRw+J1v3yp5iMA0GCSqGSIb3DQEB\nBQUAMBwxGjAYBgNVBAMTEXVpc3NoaWJiMS51aXMuZWR1MB4XDTExMTEyMTIzMjQx\nM1oXDTMxMTEyMTIzMjQxM1owHDEaMBgGA1UEAxMRdWlzc2hpYmIxLnVpcy5lZHUw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCrBJ9UQjC2vfAIWHXN44ct\nh7f3ixq6gWlqpxu7xRIZbYQQf+R5vUX9EvsqsOlx4TBB3xKr4dbz/qzfB+u/EdBc\nRKpYKY+Vh8S8bj8A3juUlGzQSXM68pDV3F0Au4zP6uSx6LRj51n/fuapZhOleIJ4\nzYvsxrCVL3rgxaA2qHrl97FqzPt0UXVzezmeZAvIKdCqiP26rLKLwzVi1dHcjD1B\n/k4EwJSGE0G97GUs9usU268ckHWAjTP+y/kPN9it5PVmleDupq8sDdSlrGnoQHiR\nbVFM+b1vNb/2aIUXVbv/LNV7U3H5AodWfo9pnWn3RUukttbgEEXsySaiCYp7V4SP\nAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEXVpc3NoaWJiMS51aXMuZWR1hihodHRwczov\nL3Vpc3NoaWJiMS51aXMuZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQvUhoH\nDE3ZkxAMiVnfnl8OvlzZOzANBgkqhkiG9w0BAQUFAAOCAQEAi1RhYj99ekYjwezn\na0YWdnvSXx6fkh2YL+16Jv82JpKxi7sUmY4uocaRBe4qurUejs6oYPEDZ7ukAu17\nErSXYIhCo2RyRkYbPU15zf43DHIk3985x6Bt6uRvK95OEId1++UpdtXWajWLUQHX\nYSaParDLi6VuuWrkeep/G3ZZgErjMGhLosTJh73S2urmUflN9FBy9Tr2M+qlLE6R\nVSeGSuGQh526tY5HlqaZ6pYmQ4EFj5Iu9fhAlpQy2fvR16UjPG+dV7HwmdK3isqk\nLWaYSk6XCWIh1fIli2rNF5GbETJGOGfypjDL6f1P60+Sc8rg39XRANxBhbjLipD7\n9FRlnA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://uisshibb1.uis.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Illinois At Springfield"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uis.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Illinois At Springfield"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://beta.kib.ki.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://beta.kib.ki.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://beta.kib.ki.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://beta.kib.ki.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://beta.kib.ki.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://beta.kib.ki.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "1",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "samadhi"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAM1x+5LlJQVQMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\nBAMTB3NhbWFkaGkwHhcNMDkwODE0MTEzMzM4WhcNMTkwODEyMTEzMzM4WjASMRAw\nDgYDVQQDEwdzYW1hZGhpMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\nwBagrMP26PtYqxBexJdsMdyDYCT74qvR5wLeW1znJTS9I1eK8ghXZ0Wy+uGunUU7\nePkQPDySt3dNOW6hOx9o8Z+/JqwSARj07glBpkN2psiza+7BQP/+l/4iBixGlDea\nwb59dC25cUA5k+YAV1fx6uwufQ/65iRKYilRVxzzSmorrrUuzbKA/Dh6MNCWDkU2\nppxJ/FS0IiR88rj2ZHZbz2wb1ATLnkevD4mUuRY39P9yxb63bTeCG7GboHrVBmNt\nrrlskaeeIYNHIkiWqbPrW/IMCgMFim7r7fiYebTvhw037UtTFDnwI8DDmcfpvbff\n2hztelbzoERAkXardDqx5QIDAQABozUwMzASBgNVHREECzAJggdzYW1hZGhpMB0G\nA1UdDgQWBBTIRU/xxcULxzxNef3jHDp1W2Br7jANBgkqhkiG9w0BAQUFAAOCAQEA\nDsNpDbtB/fhZIlNN11erKFH1VKgZIsLBu86uEYwi3sqK9+DNk40sdG1U0INY21g5\nsTG/vlt6qyuLcB9C5BA+8Ms3T01vcWg+//4KM4OZuLM/0ylSDxhVCHwJU5erI9Bt\nJSqVQ12JHctvIqdIQm0JRR6CCXVdm6Wjy5vVQZEoIanxcyjd0AUF458M7arGk1RB\npvLrKdwx16cOS9mkuq5Jg0Oj2yiUjx1WRzNzqAVQXpBb0ZZz0oKGiOqa0AgyfVKs\naNy8twh152lw5iqjY7qxb9QDhtJpzlPnQk2CmHJbQUXrCK8cLSWSDsiCcaQVicb+\n15HeV+PRFYV9dngg8gm2vg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=samadhi"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "samadhi"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAM1x+5LlJQVQMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\nBAMTB3NhbWFkaGkwHhcNMDkwODE0MTEzMzM4WhcNMTkwODEyMTEzMzM4WjASMRAw\nDgYDVQQDEwdzYW1hZGhpMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\nwBagrMP26PtYqxBexJdsMdyDYCT74qvR5wLeW1znJTS9I1eK8ghXZ0Wy+uGunUU7\nePkQPDySt3dNOW6hOx9o8Z+/JqwSARj07glBpkN2psiza+7BQP/+l/4iBixGlDea\nwb59dC25cUA5k+YAV1fx6uwufQ/65iRKYilRVxzzSmorrrUuzbKA/Dh6MNCWDkU2\nppxJ/FS0IiR88rj2ZHZbz2wb1ATLnkevD4mUuRY39P9yxb63bTeCG7GboHrVBmNt\nrrlskaeeIYNHIkiWqbPrW/IMCgMFim7r7fiYebTvhw037UtTFDnwI8DDmcfpvbff\n2hztelbzoERAkXardDqx5QIDAQABozUwMzASBgNVHREECzAJggdzYW1hZGhpMB0G\nA1UdDgQWBBTIRU/xxcULxzxNef3jHDp1W2Br7jANBgkqhkiG9w0BAQUFAAOCAQEA\nDsNpDbtB/fhZIlNN11erKFH1VKgZIsLBu86uEYwi3sqK9+DNk40sdG1U0INY21g5\nsTG/vlt6qyuLcB9C5BA+8Ms3T01vcWg+//4KM4OZuLM/0ylSDxhVCHwJU5erI9Bt\nJSqVQ12JHctvIqdIQm0JRR6CCXVdm6Wjy5vVQZEoIanxcyjd0AUF458M7arGk1RB\npvLrKdwx16cOS9mkuq5Jg0Oj2yiUjx1WRzNzqAVQXpBb0ZZz0oKGiOqa0AgyfVKs\naNy8twh152lw5iqjY7qxb9QDhtJpzlPnQk2CmHJbQUXrCK8cLSWSDsiCcaQVicb+\n15HeV+PRFYV9dngg8gm2vg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=samadhi"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://beta.kib.ki.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://beta.kib.ki.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://beta.kib.ki.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://beta.kib.ki.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://beta.kib.ki.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://beta.kib.ki.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://beta.kib.ki.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://beta.kib.ki.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://beta.kib.ki.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://beta.kib.ki.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sds.geschkult.fu-berlin.de/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT des Fachbereichs Geschichts- und Kulturwissenschaften"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servermaster@geschkult.fu-berlin.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Funktionsadresse"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT-Support des Fachbereichs Geschichts- und Kulturwissenschaften"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@geschkult.fu-berlin.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Funktionsadresse"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sds.geschkult.fu-berlin.de/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2014-11-27T10:01:09Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Freie Universit\u00e4t Berlin"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Freie Universit\u00e4t Berlin"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://identity.fu-berlin.de/idp-fub/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://identity.fu-berlin.de/idp-fub/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e5"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e5"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sds.geschkult.fu-berlin.de/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sds.geschkult.fu-berlin.de/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sds.geschkult.fu-berlin.de/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sds.geschkult.fu-berlin.de/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Kunst und Funktion"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Kunst und Funktion"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Die Geschichte der Kunst im Wandel ihrer Funktionen\", kurz \"Kunst und Funktion\" genannt, ist ein Internet-Lernprogramm, das einen \u00dcberblick \u00fcber die Kunstgeschichte in 30 Kapiteln unter der besonderen Fragestellung der Funktion von Kunst bietet."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Die Geschichte der Kunst im Wandel ihrer Funktionen\", kurz \"Kunst und Funktion\" genannt, ist ein Internet-Lernprogramm, das einen \u00dcberblick \u00fcber die Kunstgeschichte in 30 Kapiteln unter der besonderen Fragestellung der Funktion von Kunst bietet."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "o",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sds.geschkult.fu-berlin.de/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.kunst-und-funktion.de/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.kunst-und-funktion.de/"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Die Geschichte der Kunst im Wandel ihrer Funktionen\", kurz \"Kunst und Funktion\" genannt, ist ein Internet-Lernprogramm, das einen \u00dcberblick \u00fcber die Kunstgeschichte in 30 Kapiteln unter der besonderen Fragestellung der Funktion von Kunst bietet."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Die Geschichte der Kunst im Wandel ihrer Funktionen\", kurz \"Kunst und Funktion\" genannt, ist ein Internet-Lernprogramm, das einen \u00dcberblick \u00fcber die Kunstgeschichte in 30 Kapiteln unter der besonderen Fragestellung der Funktion von Kunst bietet."
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kunst und Funktion"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kunst und Funktion"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "sds.geschkult.fu-berlin.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGHzCCBQegAwIBAgIHGPldZLrBDjANBgkqhkiG9w0BAQsFADCBtTELMAkGA1UE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\nTJpLI0EqYx0IYLCS+WkpctBenwMkYEuIOu88njquyjpZqjY="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=sds.geschkult.fu-berlin.de,OU=Fachbereich Geschichts- und Kulturwissenschaften,O=Freie Universitaet Berlin,L=Berlin,ST=Berlin,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sds.geschkult.fu-berlin.de/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sds.geschkult.fu-berlin.de/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sds.geschkult.fu-berlin.de/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sds.geschkult.fu-berlin.de/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sds.geschkult.fu-berlin.de/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sds.geschkult.fu-berlin.de/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sds.geschkult.fu-berlin.de/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sds.geschkult.fu-berlin.de/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sds.geschkult.fu-berlin.de/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sds.geschkult.fu-berlin.de/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.wm.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "emmyer@wm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Eric Myers"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "chris@wm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris Peck"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.wm.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.wm.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.wm.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAMp2BzquGFXmISEolT3i+yenY4MrMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC53bS5lZHUwHhcNMTAwMzMwMTM0MTM5WhcNMzAw\nMzMwMTM0MTM5WjAVMRMwEQYDVQQDEwppZHAud20uZWR1MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAgHTuDpXR5FygeQhXnlQGd39kAgOSs+DCT7twJ39T\n7kuKNd0XAlChg3LSPUMFIPwGWg7xfS9s/bodGuHgLpfpL/m7NW++rDwjoPnhfCYc\n0lXUBNHahowMENdbdQGFpDwX/fS80UHenIiwLnG9z5DpjiiSZTlvRPpZ5wZF8ixj\neIKuCbSIz8Z9Bi0AOXRwV5L5OPLqiphPN65PFy0HYC/cOL6mxvbGkzUVjxFQXACC\ntQ//C7vkO9ftqP+jolPE/tZsQBcIVsAL7FRJHAOfmpN3/09mpFVu6en/9bqd20nK\nDYsK2FAu97mrGWpfYFk/nWMMIwdL2KinVhzLNcwr5g8DvwIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAud20uZWR1hiFodHRwczovL2lkcC53bS5lZHUvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFOxc2i6eoVNj767TtoVMNQlnIjXbMA0GCSqGSIb3DQEB\nBQUAA4IBAQAvfO9Y0q3AQ7+Zf74Oq7okfZOuWPH8Pnrdnia+U8KiG7HSPkes7g1/\niv0tmzMTJWxc1OVq727xBV6IxNdFz0I25MEwPWYbOEAAc+MfLR13h7lvZ60QSJQc\nMRNuRN37kDjfWkWxSHVGLodEU/Y5i72C03aH6bUDNEurVk63lqWm2hxAAvegTyoH\nEeZaazkU17D9zucq5RlcsDxCpPCD8nnB+59J8cpyX0GHOdiwWptZQvXx/VQpqlJT\nDX2ljKn2p2dgvW3kdPGTKp09DtjpRc8nLRqbwakIsa/Q9Ufr1emzm1RLun0hKIS8\n306VYkYFpdyAxtQI164I/aiuurKKJQxG"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wm.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.wm.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.wm.edu/idp/profile/Shibboleth/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.wm.edu/idp/profile/Shibboleth/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.wm.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.wm.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wm.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "College of William and Mary"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAMp2BzquGFXmISEolT3i+yenY4MrMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC53bS5lZHUwHhcNMTAwMzMwMTM0MTM5WhcNMzAw\nMzMwMTM0MTM5WjAVMRMwEQYDVQQDEwppZHAud20uZWR1MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAgHTuDpXR5FygeQhXnlQGd39kAgOSs+DCT7twJ39T\n7kuKNd0XAlChg3LSPUMFIPwGWg7xfS9s/bodGuHgLpfpL/m7NW++rDwjoPnhfCYc\n0lXUBNHahowMENdbdQGFpDwX/fS80UHenIiwLnG9z5DpjiiSZTlvRPpZ5wZF8ixj\neIKuCbSIz8Z9Bi0AOXRwV5L5OPLqiphPN65PFy0HYC/cOL6mxvbGkzUVjxFQXACC\ntQ//C7vkO9ftqP+jolPE/tZsQBcIVsAL7FRJHAOfmpN3/09mpFVu6en/9bqd20nK\nDYsK2FAu97mrGWpfYFk/nWMMIwdL2KinVhzLNcwr5g8DvwIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAud20uZWR1hiFodHRwczovL2lkcC53bS5lZHUvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFOxc2i6eoVNj767TtoVMNQlnIjXbMA0GCSqGSIb3DQEB\nBQUAA4IBAQAvfO9Y0q3AQ7+Zf74Oq7okfZOuWPH8Pnrdnia+U8KiG7HSPkes7g1/\niv0tmzMTJWxc1OVq727xBV6IxNdFz0I25MEwPWYbOEAAc+MfLR13h7lvZ60QSJQc\nMRNuRN37kDjfWkWxSHVGLodEU/Y5i72C03aH6bUDNEurVk63lqWm2hxAAvegTyoH\nEeZaazkU17D9zucq5RlcsDxCpPCD8nnB+59J8cpyX0GHOdiwWptZQvXx/VQpqlJT\nDX2ljKn2p2dgvW3kdPGTKp09DtjpRc8nLRqbwakIsa/Q9Ufr1emzm1RLun0hKIS8\n306VYkYFpdyAxtQI164I/aiuurKKJQxG"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "College of William and Mary"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wm.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "College of William and Mary"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.antagning.se/shibboleth-idp",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 10 470 06 28"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "UHR Systemdrift"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "appldrift_saml@uhr.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Universityadmissions.se"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 10 470 06 28"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "H\u00e5kan Pettersson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "appldrift_saml@uhr.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Universityadmissions.se"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 10 470 06 28"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "UHR Systemdrift"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "appldrift_saml@uhr.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Universityadmissions.se"
          }
        }
      ],
      "entity_id": "https://shibboleth.antagning.se/shibboleth-idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "studera.nu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.antagning.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.antagning.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.antagning.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.antagning.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.antagning.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.antagning.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.antagning.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.antagning.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "studera.nu"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r s\u00f6kande med konto i NyA-systemet."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Identity Provider for students with account in the NyA-system."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Antagning.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universityadmissions.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Antagning.se"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universityadmissions.se"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uhr.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UHR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.lmc.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:computerhelpdesk@lmc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Computer Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McCaig"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:i.mccaig@lmc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.lmc.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEpTCCA42gAwIBAgIRANrEQ8SK6/aNfqeZLMcYlvIwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzAxMjkwMDAwMDBaFw0xNjAxMjkyMzU5NTlaMHgxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRMwEQYDVQQIEwpMYW5jYXNoaXJlMRIwEAYDVQQHEwlMYW5jYXN0ZXIx\n\t\t\t\t\t\tKDAmBgNVBAoTH0xhbmNhc3RlciBhbmQgTW9yZWNhbWJlIENvbGxlZ2UxFjAUBgNV\n\t\t\t\t\t\tBAMTDWlkcC5sbWMuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCluLZDgGWwGcgMVxaUrk6Sndi0cTm0e6pEfPMA4I+87qOhWIW8AXGwqqvR3e4g\n\t\t\t\t\t\t+mq+iG5xSPfuUfY5/ydrfoHXJGkLPp6ahhvOeIzbnMUfCT4UDdjFkjwcFkBuO5rR\n\t\t\t\t\t\tggG09cK1XrIRK3RlYM/r2yyp/c8PjJvM6aIslqYCuuQkh5257IOfU8DUg4u9nUxJ\n\t\t\t\t\t\t2PrPoMStJNDF6Z35wYbSAwpk8NkqkeYYcJFM/bSg034q3bv4f7wN+x3MTmw0i0dP\n\t\t\t\t\t\tAee4NWlEpj4O3bZHud3cl/pgStgYjcwk3LHGDlVFx6dRJXAhNHOtQR8i8nsmAwA7\n\t\t\t\t\t\th9xEepy066ZcXFeKPxdHCSxDAgMBAAGjggFqMIIBZjAfBgNVHSMEGDAWgBQMvZNo\n\t\t\t\t\t\tDPPeq6NJays3V0fqkOO57TAdBgNVHQ4EFgQU1Ehkp2hbUZ/Lk8faPtBptPizvcUw\n\t\t\t\t\t\tDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUH\n\t\t\t\t\t\tAwEGCCsGAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIC\n\t\t\t\t\t\tMDoGA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVS\n\t\t\t\t\t\tRU5BU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDov\n\t\t\t\t\t\tL2NydC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGG\n\t\t\t\t\t\tGmh0dHA6Ly9vY3NwLnRjcy50ZXJlbmEub3JnMBgGA1UdEQQRMA+CDWlkcC5sbWMu\n\t\t\t\t\t\tYWMudWswDQYJKoZIhvcNAQEFBQADggEBABsF25GfLllyt4c1UAjQWdR0nPerYNlV\n\t\t\t\t\t\tEJ9xzPMJ5euw4U1CMjNBgmcFMSmiFO86QMjDCiFGO087LgHnSFqMSuI34FJUqWmL\n\t\t\t\t\t\teU/Nyks3DR/+IZ9NHeQmQxP7ttRVZLqBwWm5k31d+Ch/rgPrmsmL4X2L2o0pSQJ5\n\t\t\t\t\t\tpJHYb3Q4TsFbreKBs8Bq7zeGKtMAoiZrjhP9QkXveWV590I9Hj6Z6Wpk9mcBN1Xx\n\t\t\t\t\t\tEFiUYc67MpmwjkobQXpBBHhdZDq85pddff4kqd/rgjNbAWaBMZ3Db22msPvZkEcw\n\t\t\t\t\t\tYplNVj4iVlAZp/HFmJURCXZDpHI10D7HTYsUQxZq3Ow+kCXXn2MCu9g="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAPgRF90SkOfrpvO6fGRYgI1fbQGVMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBgxFjAUBgNVBAMMDWlkcC5sbWMuYWMudWswHhcNMTYwMTI3MTY1MzI1WhcN\n\t\t\t\t\t\tMzYwMTI3MTY1MzI1WjAYMRYwFAYDVQQDDA1pZHAubG1jLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkUGshyWkRQtm/uK0j7jEkw70Es3ZGuHS\n\t\t\t\t\t\tihlGpm4nX9H7M/jrAMFNSOsZO1LHYe6m0FZlahn46c8vygU4VSrwwf+Kpxi4TYDK\n\t\t\t\t\t\tIeON0WQ/vsGp/0NwfzSaaLU+Os02ZDYLdqnvIh27jytp5rDDnBnpxhqgKNc9zjFn\n\t\t\t\t\t\ti1C4lF3nNiK8XHOm7QJHdYhRBeNbiuRADbhImQdsiisYa7gLpQPTwmLHqtbead5+\n\t\t\t\t\t\tK30Q1IndesNEQ01s6vzkjo6fddFXYXEOZ7zJDDuinHZZbpNArxYqwdo0+OVP0ylB\n\t\t\t\t\t\t29NjSZOLNEr2Nb9swyi1HmxeNOkbLC3ev8YOpqOLRH0imkq/gUC7bwIDAQABo2Ew\n\t\t\t\t\t\tXzAdBgNVHQ4EFgQU/kzETxpCb/KwxtmH7ITaJmenc3MwPgYDVR0RBDcwNYINaWRw\n\t\t\t\t\t\tLmxtYy5hYy51a4YkaHR0cHM6Ly9pZHAubG1jLmFjLnVrL2lkcC9zaGliYm9sZXRo\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQBUk3RzG3TzK8qGS9v4HS70KnFXh1z3HhSIym87\n\t\t\t\t\t\tCJWIzcLXiqg5+lqcDVgHZ3n4QGtPIjUEaAMr8XnoyBrNbkD7AJQMr5COvlEkDvh6\n\t\t\t\t\t\tfNWhvR92+m4N0Yo2enGNcTIvunXeC5Shw6uNrqzulqyb+l/I2DzzueztiwRBuc3F\n\t\t\t\t\t\tuvRl5+UvWUQ1dHbT4Ad06LEe/fz2GijBYN3HZOQWUAR/uO0l33U/F/A4SmaC0rJa\n\t\t\t\t\t\tNkdxh/uOkDan5WM/AE5Fe2CouZrHItuY8riu+fWjyGiznIfBoHDTiprbE7NDgd6g\n\t\t\t\t\t\tnqCb0LLQ84AQKuxaMFLRtqgD4cK5zggpl8SLoPw/IdTulbB8"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lmc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.lmc.ac.uk/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.lmc.ac.uk/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.lmc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.lmc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.lmc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.lmc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.lmc.ac.uk/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.lmc.ac.uk/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lmc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEpTCCA42gAwIBAgIRANrEQ8SK6/aNfqeZLMcYlvIwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzAxMjkwMDAwMDBaFw0xNjAxMjkyMzU5NTlaMHgxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRMwEQYDVQQIEwpMYW5jYXNoaXJlMRIwEAYDVQQHEwlMYW5jYXN0ZXIx\n\t\t\t\t\t\tKDAmBgNVBAoTH0xhbmNhc3RlciBhbmQgTW9yZWNhbWJlIENvbGxlZ2UxFjAUBgNV\n\t\t\t\t\t\tBAMTDWlkcC5sbWMuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCluLZDgGWwGcgMVxaUrk6Sndi0cTm0e6pEfPMA4I+87qOhWIW8AXGwqqvR3e4g\n\t\t\t\t\t\t+mq+iG5xSPfuUfY5/ydrfoHXJGkLPp6ahhvOeIzbnMUfCT4UDdjFkjwcFkBuO5rR\n\t\t\t\t\t\tggG09cK1XrIRK3RlYM/r2yyp/c8PjJvM6aIslqYCuuQkh5257IOfU8DUg4u9nUxJ\n\t\t\t\t\t\t2PrPoMStJNDF6Z35wYbSAwpk8NkqkeYYcJFM/bSg034q3bv4f7wN+x3MTmw0i0dP\n\t\t\t\t\t\tAee4NWlEpj4O3bZHud3cl/pgStgYjcwk3LHGDlVFx6dRJXAhNHOtQR8i8nsmAwA7\n\t\t\t\t\t\th9xEepy066ZcXFeKPxdHCSxDAgMBAAGjggFqMIIBZjAfBgNVHSMEGDAWgBQMvZNo\n\t\t\t\t\t\tDPPeq6NJays3V0fqkOO57TAdBgNVHQ4EFgQU1Ehkp2hbUZ/Lk8faPtBptPizvcUw\n\t\t\t\t\t\tDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUH\n\t\t\t\t\t\tAwEGCCsGAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIC\n\t\t\t\t\t\tMDoGA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVS\n\t\t\t\t\t\tRU5BU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDov\n\t\t\t\t\t\tL2NydC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGG\n\t\t\t\t\t\tGmh0dHA6Ly9vY3NwLnRjcy50ZXJlbmEub3JnMBgGA1UdEQQRMA+CDWlkcC5sbWMu\n\t\t\t\t\t\tYWMudWswDQYJKoZIhvcNAQEFBQADggEBABsF25GfLllyt4c1UAjQWdR0nPerYNlV\n\t\t\t\t\t\tEJ9xzPMJ5euw4U1CMjNBgmcFMSmiFO86QMjDCiFGO087LgHnSFqMSuI34FJUqWmL\n\t\t\t\t\t\teU/Nyks3DR/+IZ9NHeQmQxP7ttRVZLqBwWm5k31d+Ch/rgPrmsmL4X2L2o0pSQJ5\n\t\t\t\t\t\tpJHYb3Q4TsFbreKBs8Bq7zeGKtMAoiZrjhP9QkXveWV590I9Hj6Z6Wpk9mcBN1Xx\n\t\t\t\t\t\tEFiUYc67MpmwjkobQXpBBHhdZDq85pddff4kqd/rgjNbAWaBMZ3Db22msPvZkEcw\n\t\t\t\t\t\tYplNVj4iVlAZp/HFmJURCXZDpHI10D7HTYsUQxZq3Ow+kCXXn2MCu9g="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAPgRF90SkOfrpvO6fGRYgI1fbQGVMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBgxFjAUBgNVBAMMDWlkcC5sbWMuYWMudWswHhcNMTYwMTI3MTY1MzI1WhcN\n\t\t\t\t\t\tMzYwMTI3MTY1MzI1WjAYMRYwFAYDVQQDDA1pZHAubG1jLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkUGshyWkRQtm/uK0j7jEkw70Es3ZGuHS\n\t\t\t\t\t\tihlGpm4nX9H7M/jrAMFNSOsZO1LHYe6m0FZlahn46c8vygU4VSrwwf+Kpxi4TYDK\n\t\t\t\t\t\tIeON0WQ/vsGp/0NwfzSaaLU+Os02ZDYLdqnvIh27jytp5rDDnBnpxhqgKNc9zjFn\n\t\t\t\t\t\ti1C4lF3nNiK8XHOm7QJHdYhRBeNbiuRADbhImQdsiisYa7gLpQPTwmLHqtbead5+\n\t\t\t\t\t\tK30Q1IndesNEQ01s6vzkjo6fddFXYXEOZ7zJDDuinHZZbpNArxYqwdo0+OVP0ylB\n\t\t\t\t\t\t29NjSZOLNEr2Nb9swyi1HmxeNOkbLC3ev8YOpqOLRH0imkq/gUC7bwIDAQABo2Ew\n\t\t\t\t\t\tXzAdBgNVHQ4EFgQU/kzETxpCb/KwxtmH7ITaJmenc3MwPgYDVR0RBDcwNYINaWRw\n\t\t\t\t\t\tLmxtYy5hYy51a4YkaHR0cHM6Ly9pZHAubG1jLmFjLnVrL2lkcC9zaGliYm9sZXRo\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQBUk3RzG3TzK8qGS9v4HS70KnFXh1z3HhSIym87\n\t\t\t\t\t\tCJWIzcLXiqg5+lqcDVgHZ3n4QGtPIjUEaAMr8XnoyBrNbkD7AJQMr5COvlEkDvh6\n\t\t\t\t\t\tfNWhvR92+m4N0Yo2enGNcTIvunXeC5Shw6uNrqzulqyb+l/I2DzzueztiwRBuc3F\n\t\t\t\t\t\tuvRl5+UvWUQ1dHbT4Ad06LEe/fz2GijBYN3HZOQWUAR/uO0l33U/F/A4SmaC0rJa\n\t\t\t\t\t\tNkdxh/uOkDan5WM/AE5Fe2CouZrHItuY8riu+fWjyGiznIfBoHDTiprbE7NDgd6g\n\t\t\t\t\t\tnqCb0LLQ84AQKuxaMFLRtqgD4cK5zggpl8SLoPw/IdTulbB8"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lancaster and Morecambe College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lmc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Lancaster and Morecambe College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://oala.surrey.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gill"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:c.j.gill@surrey.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Claire"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Minhas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:a.minhas@surrey.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Abdul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://oala.surrey.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-05-09T14:53:23Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://oala.surrey.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://oala.surrey.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "surrey.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIITOCMDokwhbkwDQYJKoZIhvcNAQEFBQAwOzEdMBsGA1UE\n\t\t\t\t\t\tCgwUVW5pdmVyc2l0eSBvZiBTdXJyZXkxGjAYBgNVBAMMEW9hbGEuc3VycmV5LmFj\n\t\t\t\t\t\tLnVrMB4XDTEyMDMyOTExMjUyM1oXDTIyMDMyOTExMjUyM1owOzEdMBsGA1UECgwU\n\t\t\t\t\t\tVW5pdmVyc2l0eSBvZiBTdXJyZXkxGjAYBgNVBAMMEW9hbGEuc3VycmV5LmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAlQUcfoCNygSZkRb1rvMz\n\t\t\t\t\t\tqIdbaZhcLek/W5QweKu1cWymyjBOFHK2Ioj3gFotYvLqp/CwaX9Ku++urHOtfW4C\n\t\t\t\t\t\tFdYt2uZi34Frap5Q34QiDcIfSpm+tb8YmsuJczxTfJ7Azywd3uEFjPqcNKyRJPMC\n\t\t\t\t\t\tj8aoMdcpjf8JwjO97ngErjEdjdlaehVTk1jhylDj40UOXdIuuKiHTo+rC9/fHN87\n\t\t\t\t\t\t5Iz1xrANl4rb5JdV96iXZamGjXYMXhlJ70JIGkerWyW2fAggDTmrfL5vWiKD4SnJ\n\t\t\t\t\t\t2yTz5N5OA7PARBZSmyiri9dWuiB0hled2Vjzee2FDKEfuBZ04PRku6ZsljETVDmO\n\t\t\t\t\t\tnQIDAQABo1AwTjAdBgNVHQ4EFgQUsVamXCDZmaPx60a0iF4Ra5i4X0gwHwYDVR0j\n\t\t\t\t\t\tBBgwFoAUsVamXCDZmaPx60a0iF4Ra5i4X0gwDAYDVR0TBAUwAwEB/zANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAeOQBpi5xhTBE6nbSLMoxTWl04TFjyNx3efNdK9v6yJthudfJ\n\t\t\t\t\t\tnjM/yh51DlNLclhx1DG0mxSaqrLi3Z/ZccYsKtZJVLWD0BaNQyXegPG4eyOLH4sq\n\t\t\t\t\t\tbmFhvrffVsmifynPezbM2QSDcz3nHZZQEUQg+j4THrqSka4oJEYlMtsgTRjbrFYf\n\t\t\t\t\t\tCeUkTgB5mVNUfTS23sXp544zCo0W8kUF5ViUNuNL6p2XPRpXnrmVePgz1TU2egd2\n\t\t\t\t\t\tpcWxqlhKnQawqVRhixnxUXrSAcFCW3t6PV1Y7abxl17ux5qZxRVPa0KTr4nZioQZ\n\t\t\t\t\t\t7f8wd1sz16xoVOAfi93qMNDb+ha44YQFQKHoPg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIITOCMDokwhbkwDQYJKoZIhvcNAQEFBQAwOzEdMBsGA1UE\n\t\t\t\t\t\tCgwUVW5pdmVyc2l0eSBvZiBTdXJyZXkxGjAYBgNVBAMMEW9hbGEuc3VycmV5LmFj\n\t\t\t\t\t\tLnVrMB4XDTEyMDMyOTExMjUyM1oXDTIyMDMyOTExMjUyM1owOzEdMBsGA1UECgwU\n\t\t\t\t\t\tVW5pdmVyc2l0eSBvZiBTdXJyZXkxGjAYBgNVBAMMEW9hbGEuc3VycmV5LmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAlQUcfoCNygSZkRb1rvMz\n\t\t\t\t\t\tqIdbaZhcLek/W5QweKu1cWymyjBOFHK2Ioj3gFotYvLqp/CwaX9Ku++urHOtfW4C\n\t\t\t\t\t\tFdYt2uZi34Frap5Q34QiDcIfSpm+tb8YmsuJczxTfJ7Azywd3uEFjPqcNKyRJPMC\n\t\t\t\t\t\tj8aoMdcpjf8JwjO97ngErjEdjdlaehVTk1jhylDj40UOXdIuuKiHTo+rC9/fHN87\n\t\t\t\t\t\t5Iz1xrANl4rb5JdV96iXZamGjXYMXhlJ70JIGkerWyW2fAggDTmrfL5vWiKD4SnJ\n\t\t\t\t\t\t2yTz5N5OA7PARBZSmyiri9dWuiB0hled2Vjzee2FDKEfuBZ04PRku6ZsljETVDmO\n\t\t\t\t\t\tnQIDAQABo1AwTjAdBgNVHQ4EFgQUsVamXCDZmaPx60a0iF4Ra5i4X0gwHwYDVR0j\n\t\t\t\t\t\tBBgwFoAUsVamXCDZmaPx60a0iF4Ra5i4X0gwDAYDVR0TBAUwAwEB/zANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAeOQBpi5xhTBE6nbSLMoxTWl04TFjyNx3efNdK9v6yJthudfJ\n\t\t\t\t\t\tnjM/yh51DlNLclhx1DG0mxSaqrLi3Z/ZccYsKtZJVLWD0BaNQyXegPG4eyOLH4sq\n\t\t\t\t\t\tbmFhvrffVsmifynPezbM2QSDcz3nHZZQEUQg+j4THrqSka4oJEYlMtsgTRjbrFYf\n\t\t\t\t\t\tCeUkTgB5mVNUfTS23sXp544zCo0W8kUF5ViUNuNL6p2XPRpXnrmVePgz1TU2egd2\n\t\t\t\t\t\tpcWxqlhKnQawqVRhixnxUXrSAcFCW3t6PV1Y7abxl17ux5qZxRVPa0KTr4nZioQZ\n\t\t\t\t\t\t7f8wd1sz16xoVOAfi93qMNDb+ha44YQFQKHoPg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Surrey (Institutional Login)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.surrey.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Surrey"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.gakunin.nii.ac.jp/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:gakunin-help@nii.ac.jp"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "GakuNin Office"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.gakunin.nii.ac.jp/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.gakunin.jp/en-Join/"
              },
              {
                "lang": "ja",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.gakunin.jp/join/"
              }
            ],
            "registration_instant": "2011-04-13T00:00:00Z",
            "registration_authority": "https://www.gakunin.jp",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFFjCCA/6gAwIBAgIIQvhX//m5bm0wDQYJKoZIhvcNAQELBQAwbTELMAkGA1UE\nBhMCSlAxEDAOBgNVBAcTB0FjYWRlbWUxKjAoBgNVBAoTIU5hdGlvbmFsIEluc3Rp\ndHV0ZSBvZiBJbmZvcm1hdGljczEgMB4GA1UEAxMXTklJIE9wZW4gRG9tYWluIENB\nIC0gRzQwHhcNMTUwMjA0MDgwNzAzWhcNMTcwMzA2MDgwNzAzWjCBqTELMAkGA1UE\nBhMCSlAxEDAOBgNVBAcTB0FjYWRlbWUxKjAoBgNVBAoTIU5hdGlvbmFsIEluc3Rp\ndHV0ZSBvZiBJbmZvcm1hdGljczE8MDoGA1UECxMzQ3liZXIgU2NpZW5jZSBJbmZy\nYXN0cnVjdHVyZSBEZXZlbG9wbWVudCBEZXBhcnRtZW50MR4wHAYDVQQDExVpZHAu\nZ2FrdW5pbi5uaWkuYWMuanAwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQDXXwFpWC18sK3XbwBgN5HCYCS79K85nL9v95nVJzQoWrihKuEEMgd6gzo0fjk6\nj6fb3/CZwihxnzMExyhadH6zC84Q92B7riSpv+gABvJW6no5js9gmDUqkyUG9qaS\nQSQtqNv/RKsuCRW79xeiYZnCMFvUEXiOQ4zFFAZX00ywz9jxWP7E56yAKHyLBgNl\nZFGTKAFH0W35831dWlj3HsU0sbpoBiSrWSXvx7lJefifK5vqQc7tuDSx0kRa/aqT\n7fb6cq8EQURzdcuQnIFaUaKRggeV1VOBk7fMNuL6dSz0zFRtnS+bBZbJ+1GQJ/0+\nHatU3vCzfpuuLy/C9AHIUOQ9AgMBAAGjggF7MIIBdzAdBgNVHSUEFjAUBggrBgEF\nBQcDAQYIKwYBBQUHAwIwHwYDVR0jBBgwFoAUGQtvOR8xAzRf5NJAHzfmjediOXww\nSgYDVR0fBEMwQTA/oD2gO4Y5aHR0cDovL3JlcG8xLnNlY29tdHJ1c3QubmV0L3Nw\ncGNhL25paS9vZGNhMy9mdWxsY3JsZzQuY3JsMA4GA1UdDwEB/wQEAwIFoDAdBgNV\nHQ4EFgQUXtG5Fo87Sb3QyTZYKnEj9dGy1QwwWgYDVR0gBFMwUTBPBgwrBgEEAYH8\nCAMCAQEwPzA9BggrBgEFBQcCARYxaHR0cHM6Ly9yZXBvMS5zZWNvbXRydXN0Lm5l\ndC9zcGNwcC9jcHMvaW5kZXguaHRtbDA8BggrBgEFBQcBAQQwMC4wLAYIKwYBBQUH\nMAGGIGh0dHA6Ly9uaWlnNC5vY3NwLnNlY29tdHJ1c3QubmV0MCAGA1UdEQQZMBeC\nFWlkcC5nYWt1bmluLm5paS5hYy5qcDANBgkqhkiG9w0BAQsFAAOCAQEAIu3RKglN\nOD7MqWIlsOAMu+DuNRUgp7pb378ZWIAUjl8EkTrQxEPkkoLhq9DW5lgzL7ZnLEyf\n/abCfJrFtgkGEDg9y1iT0RsDa0vpnC6wzaGcC3U0dgOW+R3SHqrXtMl+Rj/bbOCW\n0BWHGatck3VuOAc88RcDREd56JCg/wSdUYjYFpmnlqHgg7a99v0AEVS4KK1vZE+u\nMpBaL5qG7KNpHy8CCU1wNjs1HOcwgHGs9KSxbNGjANe9zaaO8MjjTtWbLIOGKhmb\nVUx4Q0xL6Qh+DGRS32KKmGkY8/7O/mdjT1O7rFqFgDgZJSThq5fnDpZm1vIoOPJh\nw7tfpr+kkFoj6Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gakunin.nii.ac.jp"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.gakunin.nii.ac.jp:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.gakunin.nii.ac.jp:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.gakunin.nii.ac.jp/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.gakunin.nii.ac.jp/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.gakunin.nii.ac.jp/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gakunin.nii.ac.jp"
              },
              {
                "logo": [
                  {
                    "text": "https://idp.gakunin.nii.ac.jp/images/gakunin64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "ja",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u5b66\u8a8dIdP"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "GakuNin IdP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:35.692558,139.757999"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFFjCCA/6gAwIBAgIIQvhX//m5bm0wDQYJKoZIhvcNAQELBQAwbTELMAkGA1UE\nBhMCSlAxEDAOBgNVBAcTB0FjYWRlbWUxKjAoBgNVBAoTIU5hdGlvbmFsIEluc3Rp\ndHV0ZSBvZiBJbmZvcm1hdGljczEgMB4GA1UEAxMXTklJIE9wZW4gRG9tYWluIENB\nIC0gRzQwHhcNMTUwMjA0MDgwNzAzWhcNMTcwMzA2MDgwNzAzWjCBqTELMAkGA1UE\nBhMCSlAxEDAOBgNVBAcTB0FjYWRlbWUxKjAoBgNVBAoTIU5hdGlvbmFsIEluc3Rp\ndHV0ZSBvZiBJbmZvcm1hdGljczE8MDoGA1UECxMzQ3liZXIgU2NpZW5jZSBJbmZy\nYXN0cnVjdHVyZSBEZXZlbG9wbWVudCBEZXBhcnRtZW50MR4wHAYDVQQDExVpZHAu\nZ2FrdW5pbi5uaWkuYWMuanAwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQDXXwFpWC18sK3XbwBgN5HCYCS79K85nL9v95nVJzQoWrihKuEEMgd6gzo0fjk6\nj6fb3/CZwihxnzMExyhadH6zC84Q92B7riSpv+gABvJW6no5js9gmDUqkyUG9qaS\nQSQtqNv/RKsuCRW79xeiYZnCMFvUEXiOQ4zFFAZX00ywz9jxWP7E56yAKHyLBgNl\nZFGTKAFH0W35831dWlj3HsU0sbpoBiSrWSXvx7lJefifK5vqQc7tuDSx0kRa/aqT\n7fb6cq8EQURzdcuQnIFaUaKRggeV1VOBk7fMNuL6dSz0zFRtnS+bBZbJ+1GQJ/0+\nHatU3vCzfpuuLy/C9AHIUOQ9AgMBAAGjggF7MIIBdzAdBgNVHSUEFjAUBggrBgEF\nBQcDAQYIKwYBBQUHAwIwHwYDVR0jBBgwFoAUGQtvOR8xAzRf5NJAHzfmjediOXww\nSgYDVR0fBEMwQTA/oD2gO4Y5aHR0cDovL3JlcG8xLnNlY29tdHJ1c3QubmV0L3Nw\ncGNhL25paS9vZGNhMy9mdWxsY3JsZzQuY3JsMA4GA1UdDwEB/wQEAwIFoDAdBgNV\nHQ4EFgQUXtG5Fo87Sb3QyTZYKnEj9dGy1QwwWgYDVR0gBFMwUTBPBgwrBgEEAYH8\nCAMCAQEwPzA9BggrBgEFBQcCARYxaHR0cHM6Ly9yZXBvMS5zZWNvbXRydXN0Lm5l\ndC9zcGNwcC9jcHMvaW5kZXguaHRtbDA8BggrBgEFBQcBAQQwMC4wLAYIKwYBBQUH\nMAGGIGh0dHA6Ly9uaWlnNC5vY3NwLnNlY29tdHJ1c3QubmV0MCAGA1UdEQQZMBeC\nFWlkcC5nYWt1bmluLm5paS5hYy5qcDANBgkqhkiG9w0BAQsFAAOCAQEAIu3RKglN\nOD7MqWIlsOAMu+DuNRUgp7pb378ZWIAUjl8EkTrQxEPkkoLhq9DW5lgzL7ZnLEyf\n/abCfJrFtgkGEDg9y1iT0RsDa0vpnC6wzaGcC3U0dgOW+R3SHqrXtMl+Rj/bbOCW\n0BWHGatck3VuOAc88RcDREd56JCg/wSdUYjYFpmnlqHgg7a99v0AEVS4KK1vZE+u\nMpBaL5qG7KNpHy8CCU1wNjs1HOcwgHGs9KSxbNGjANe9zaaO8MjjTtWbLIOGKhmb\nVUx4Q0xL6Qh+DGRS32KKmGkY8/7O/mdjT1O7rFqFgDgZJSThq5fnDpZm1vIoOPJh\nw7tfpr+kkFoj6Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GakuNin IdP"
          },
          {
            "lang": "ja",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u5b66\u8a8dIdP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.gakunin.jp/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National Institute of Informatics"
          },
          {
            "lang": "ja",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u56fd\u7acb\u60c5\u5831\u5b66\u7814\u7a76\u6240"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.highwire.org/entity/ecspubs",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.highwire.org/entity/ecspubs",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-09-26T17:52:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Electrochemical Society"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://ecsdl.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HighWire Press, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.highwire.org/applications/ecspubs/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.highwire.org/applications/ecspubs/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIJAMTRVlqTJ11lMA0GCSqGSIb3DQEBBQUAMIG+MQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBD\n\t\t\t\t\t\taXR5MRcwFQYDVQQKEw5IaWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUx\n\t\t\t\t\t\tIDAeBgNVBAMTF3NoaWJib2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkB\n\t\t\t\t\t\tFiZzaGliYm9sZXRoLWFkbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTAeFw0xNDA0\n\t\t\t\t\t\tMTUxOTQzMDNaFw0yNDA0MTIxOTQzMDNaMIG+MQswCQYDVQQGEwJVUzETMBEGA1UE\n\t\t\t\t\t\tCBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBDaXR5MRcwFQYDVQQKEw5I\n\t\t\t\t\t\taWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUxIDAeBgNVBAMTF3NoaWJi\n\t\t\t\t\t\tb2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkBFiZzaGliYm9sZXRoLWFk\n\t\t\t\t\t\tbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALPB99M9iWjentrddY/rLgzKn1X0j4Ao191iyiowBBt/r/pmn2oz\n\t\t\t\t\t\tfrbONkkTVBB++mNtiufK6jyKnBM5mffPOkXHRo+K1DQec7TvpQ1PmLv/BpBgPrr9\n\t\t\t\t\t\tldViOSUnYJuB0IgJVV8oylgeH2Ay0XRkNPlBUjBA2fUPWVpXcvFe+aD2tLdVR9uO\n\t\t\t\t\t\tXvfTMxAEGqzxTU+OxO6pW2sBXNBmGvZQ0TRyovQh5+pTURY/lm0V/iWvRmRe51WE\n\t\t\t\t\t\tO/nhYyvRuMmNj8EL38o10S9TXuCkVzY00hK5cclaFge7gz/tfjmadVVcbe8xCVxc\n\t\t\t\t\t\tnb1lhmt1kH2XtKvU5hyZMTO+VUfXQvqcQyECAwEAAaN7MHkwCQYDVR0TBAIwADAs\n\t\t\t\t\t\tBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYD\n\t\t\t\t\t\tVR0OBBYEFJpUZq/XaW9/bPvjffkxX0IDvuPiMB8GA1UdIwQYMBaAFJpUZq/XaW9/\n\t\t\t\t\t\tbPvjffkxX0IDvuPiMA0GCSqGSIb3DQEBBQUAA4IBAQCq/FF56ZB1cL3KbniEJP99\n\t\t\t\t\t\tU9wTD6KpOrWxvqNbUSV1cefLf5cYHonOjy6oAJSSBSNuP7U5Q//0tXtkvlJoqGUY\n\t\t\t\t\t\tvqngmeg9wLZ/Fla3tXcDdTj0n1F+NZOx9vBDacIk0Ua4aHXDA4bdytzkV1QyZDRq\n\t\t\t\t\t\tQ8vq7RoQ8E5IF7Cll+kt2dZXQk8o6Qp3w2ppoMRtYdKOQassqn+V1MYcMPgdxZkS\n\t\t\t\t\t\tDrcgzktR/JMb5OmPrp4mSy1OWDGrFvUIigsLBPZV9tw1f7y42lnbmQas3RCS30yr\n\t\t\t\t\t\tCtUPT/PQDkCdBRViGmmMkYwjdaOTiHOJveWtrVXu8vLvO36pqFF4Kft0pgqlfvAE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.highwire.org/applications/ecspubs/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.highwire.org/applications/ecspubs/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.highwire.org/applications/ecspubs/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.highwire.org/applications/ecspubs/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://gisela-gw.ct.infn.it/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fargetta"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:marco.fargetta@ct.infn.it"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:credentials-admin@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marco"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rotondo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:riccardo.rotondo@ct.infn.it"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:credentials-admin@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Riccardo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Scardaci"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:diego.scardaci@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Diego"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barbera"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:roberto.barbera@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roberto"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://gisela-gw.ct.infn.it/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2011-11-30T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INFN Catania"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INFN Catania"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ct.infn.it/en/home"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ct.infn.it/it/home"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INFN - the National Institute of Nuclear Physics. Catania division"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INFN - Istituto Nazionale di Fisica Nucleare. Sezione di Catania"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://gisela-gw.ct.infn.it/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://gisela-gw.ct.infn.it/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gisela-gw.ct.infn.it/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://gisela-gw.ct.infn.it/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://gisela-gw.ct.infn.it/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service provides information for Grid users, Application developers and\n                        Grid site administrators. It is mainly devoted to the people involved in the\n                        GISELA project but many pages are of general interest"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Questo servizio fornisce informazioni per utenti Grid, sviluppatori ed amministratori\n                        di siti Grid. Esso \u00e8 principalmente indirizzato alle persone coinvolte nel progetto europeo\n                        GISELA ma molte informazioni sono di interesse generale"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "GISELA Science Gateway"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "GISELA Science Gateway"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://gisela-gw.ct.infn.it/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://gisela-gw.ct.infn.it/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFhDCCBGygAwIBAgIRAOyXU1f6GS689kEaSDAhQPYwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDA1MTkwMDAwMDBaFw0xNzA1MTgyMzU5NTlaMEAxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEbMBkGA1UEAxMSbGlmZXJheS5j\ndC5pbmZuLml0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApizyvtMI\nuoSnnz/fvk7lcXwoDUk11NVAlg5w4zh01YKNvy5SzBu0eRIzRos/ALs4CwmxrmCv\n3JQPA4xxItxVd8x9Q+YElQteEcX+mWXXW5LI5XE3xhPzkdFeQrhkinAK2JreSn6E\nTQk8YO1rOxW3qCpKeYZ2VQF3grAU/JRWbvLF+r2j4zE27n+RzBxnYeZ9rtJ/67gU\n7t1S39DRDTyKit7dJIYl50n9g3atWGALb56QoVnlR+RPRxVI9EFd2hEXfrxWXGdt\nF2v6YIMSAAM5l2/SlEmhQSSkmQ4zXcmPrzC6pte9NWoPOTsQnCnocwMJ16aXsnQy\nBxaoywMtq8NsdwIDAQABo4ICgTCCAn0wHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsr\nN1dH6pDjue0wHQYDVR0OBBYEFCy5dq76F94vaAuznAys6UmGxySTMA4GA1UdDwEB\n/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEF\nBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8E\nMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENB\nLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNz\nLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8v\nb2NzcC50Y3MudGVyZW5hLm9yZzCCAS0GA1UdEQSCASQwggEgghJsaWZlcmF5LmN0\nLmluZm4uaXSCGWFwcGxpY2F0aW9ucy5ldS1kZWNpZGUuZXWCGWFwcGxpY2F0aW9u\ncy5ldW1lZGdyaWQuZXWCEGdpbGRhLmN0LmluZm4uaXSCFGdpc2VsYS1ndy5jdC5p\nbmZuLml0gg1ndy5jdC5pbmZuLml0ghNnd2VhdGhlci5jdC5pbmZuLml0ghBnd2xp\nYi5jdC5pbmZuLml0gh9pbmRpY2F0ZS1ndy5jb25zb3J6aW8tY29tZXRhLml0ghFy\naWNldmkuY3QuaW5mbi5pdIIUdmlyYWxncmlkLmN0LmluZm4uaXSCFHd3dy5jaGFp\nbi1wcm9qZWN0LmV1ghZ3d3cuc3BlY2lhbC1wcm9qZWN0Lml0MA0GCSqGSIb3DQEB\nBQUAA4IBAQCEZIHNNQPD5WkGSlUhCN/BRSharmQ6dT0NiwjQNmRODCpVqBgwVZY0\nVUlAobHaF186QXeiNYge8ZYSpYY2VhBa4znL7IjFODE3FsaJNseKgsyNFqKR8xNO\nnsOCM//SN9N79hwH8yAxLhGyxbnInpOhE6rEkbhtowTjqhDq26cGGlH8JTTPuYvY\nJhgPGGkxo1286x1nuN4ELKvwZ7RF+YTH/WPOIBMNi+ee+vxrIhWbU6iy97f7k4PA\n2e35ZQ6gutnmX2v/ybFWh0ruO4zszYKiMo+zGyLvYmIpV/+Mjs26KbqqrBOS1jjN\nW3MiH8HMxzzYHExNCvzrAgN1TfB+SCiB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gisela-gw.ct.infn.it/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://gisela-gw.ct.infn.it/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://gisela-gw.ct.infn.it/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://gisela-gw.ct.infn.it/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://gisela-gw.ct.infn.it/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://gisela-gw.ct.infn.it/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "GISELA Science Gateway"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This service provides information for Grid users, Application developers and\n                    Grid site administrators. It is mainly devoted to the people involved in the\n                    GISELA project but many pages are of general interest"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.audionetwork.nen.gov.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chapman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:phil@atomwide.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Phil"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chapman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:phil@atomwide.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Phil"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.audionetwork.nen.gov.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "South West Grid for Learning Trust: Audio Networks free audio resources for the NEN community"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.swgfl.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "South West Grid for Learning Trust"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.audionetwork.nen.gov.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.audionetwork.nen.gov.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.audionetwork.nen.gov.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.audionetwork.nen.gov.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.audionetwork.nen.gov.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.audionetwork.nen.gov.uk/Shibboleth.sso/lgfl-uso",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.audionetwork.nen.gov.uk/Shibboleth.sso/swgfl-merlin",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIJAI9De290KMmjMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\n\t\t\t\t\t\tBAMTG3d3dy5hdWRpb25ldHdvcmsubmVuLmdvdi51azAeFw0xNjA0MDQxMjA0NDla\n\t\t\t\t\t\tFw0yNjA0MDIxMjA0NDlaMCYxJDAiBgNVBAMTG3d3dy5hdWRpb25ldHdvcmsubmVu\n\t\t\t\t\t\tLmdvdi51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALs1Xvl+YUxg\n\t\t\t\t\t\t6qrTPBEvjP6U+Xj56/NxYlBQ0MzjGNDYKOb5wybkgaZF/pcQxLlEzYGvJnYVCazq\n\t\t\t\t\t\tpuniTJlyRAvDHjWzvXb5sdahZCCvfp9Y+xHYa8UuqLxP/oWod7L2ChpL+y0vzLkn\n\t\t\t\t\t\tyYi20IIPOQQRAr2Dq7lXG0ChHjEwNWWJl35iLVvGSLIKrkEOwHNYBstONR7t+SqW\n\t\t\t\t\t\tYD0F5la2s7Or1F0UpQSUSXy79FzhJwkyS163ZDZoa/tvBGPrNXjMFROuGJN9lS3L\n\t\t\t\t\t\td95KKUP8LHSQK5oZMZw935F3ix2ngI7W/GAlt6Ti3cKDMON03cdnqDc8iyIj4Ik+\n\t\t\t\t\t\t1BiA6QdXoXECAwEAAaN5MHcwVgYDVR0RBE8wTYIbd3d3LmF1ZGlvbmV0d29yay5u\n\t\t\t\t\t\tZW4uZ292LnVrhi5odHRwczovL3d3dy5hdWRpb25ldHdvcmsubmVuLmdvdi51ay9z\n\t\t\t\t\t\taGliYm9sZXRoMB0GA1UdDgQWBBTDPBGJEh/Z6ywq5BZ8z7RJmk1oozANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAeVpk8i9TSBMdQAK6VkXePV/FP3oZYisazSdX0UmizwLsCOyO\n\t\t\t\t\t\tHXJeSjSwyZ1jnQmyF2L7uf72oBNx6FaqjoekRPFxIBnvs0wKJuLHwIH2NbgMiq+V\n\t\t\t\t\t\t9rLOfGYZfdn+tJAYtJGuj7LkN14u+/JlP6ym2yZOvY+N6bVg2RFFgeD71p3xTUDv\n\t\t\t\t\t\tfGsyAXTqQEYU2CngSFCw9d6pq1BN6YwWvDE0QpX3Ls7h6kThEHtFfkDwbWyGEU4/\n\t\t\t\t\t\tqJWu76dirfXs/94KyGifoqEnn/x6anu70lEhOelauKILot8oovzk9NgQW3r4T9rL\n\t\t\t\t\t\tucr/IH/AZ5ql3zVht/DYm/eSHqFItcWR9pgj3w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.audionetwork.nen.gov.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.audionetwork.nen.gov.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.audionetwork.nen.gov.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.audionetwork.nen.gov.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.audionetwork.nen.gov.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.audionetwork.nen.gov.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.audionetwork.nen.gov.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.audionetwork.nen.gov.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.audionetwork.nen.gov.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.audionetwork.nen.gov.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://samltest.swamid.se/re_nren/sp.xml",
    {
      "entity_id": "https://samltest.swamid.se/re_nren/sp.xml",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish Academic Identity Federation (SWAMID)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.swamid.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SWAMID"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://samltest.swamid.se/disco",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFcTCCBFmgAwIBAgIQIu7k1beHBKgWb27d90Ad9jANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQwODAwMDAwMFoXDTE3MDQwNzIzNTk1OVowQDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRswGQYDVQQDExJzYW1sdGVzdC5z\nd2FtaWQuc2UwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCcJfNqCJmM\nCWZ9+h9MAT9WbT/e+eRpGE9H8eucnnq4weTeFbT+2Ma15hY8hI6gP4GsDIZsaxTu\nDGgIYXctfnl9MTz+9rlANOo8Wjuz6CJ2trJ6BdhPvkoITuSqmIWkFbmP7/0NGkoG\n167CGp/Eq5yZnUOdiKXquH2S5OCw3mB4HGpjUk7T13cN0jOOPiK2cQhUTuUUMaVO\nei0QblIfK/+9fusfYOjd5uzNg1QZ9FvvbB/wTw4Z11eGcZWKpAprIrbx6iw119eL\nU7dvJhgA96VJmesDQejf96Xtpn7bCbxdyBqw2AtooamyrVjnAeQ8NDXW7td9MUuM\n4/yhN9H+fHTVJNs8dCX5FKayw5YoxF8eTMjRk0ObICMrLl8M/EiOG9Eqfc3TPGTF\ndn81sOGc3WzifRyG5fXUx/Xw9vXVkRAkVO6T4n6OUQxn2be9hwXR7yFw9tTplPIl\ndabhc7iWU7NgEBcBI3RWCcRNv0OVsXIMDeGZ64SOm4mpKbXMVebsnSLXxV69T1l4\nM8EegMpraRWHrbtF27FkKZPZgCbNaQbfW4vtJoN9rN07Flz8GLr200WXAepXT14L\ndGwXqjx6Cu2oilkl2OoNWQbRg3dvn1j6XqnRLbio4bvuiCYYEPpjuWcHOs/GwMnz\npml7EL51yz9PTwNZTQXsLH/xKlzWf1BuBQIDAQABo4IBbzCCAWswHwYDVR0jBBgw\nFoAUDL2TaAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFG40O0IHvLK2kXS6s4hN\nCq0DTtPLMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQG\nCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgG\nBmeBDAECATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEu\nb3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKG\nKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsG\nAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJz\nYW1sdGVzdC5zd2FtaWQuc2UwDQYJKoZIhvcNAQEFBQADggEBAHnWOLDwhrYWfd7q\n2fwTaiRP/x/tVPocNgi/wgwo6oZzC1Ru/HPjfUmnj11zkOOHeF8cf2BT2diRptPi\nqDc+7HN8GrM87+Deqvjj4pw7j4hwMpcfNd2AzqW4nPmw4LgiRehITtUtMxL9mkDh\neN0pgldD544xQRUdxYmD9nUWiIaTmuxNqusKkqUTD/kO41i+BxIeaWiXsw6IC7o6\nkPPUQHr1h2na805Kjoy5ML8K2EO+kcvFqfo42gtwa7mN38hKB+jbKF5VqqmoSb4m\nln/3lobOqcV8rrFKjvnjC6iNTbdpQ65o8CoOcfzhWmb/7RxkZ4a9fyzxVS8fMAi6\nu3Qzm3Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFcTCCBFmgAwIBAgIQIu7k1beHBKgWb27d90Ad9jANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQwODAwMDAwMFoXDTE3MDQwNzIzNTk1OVowQDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRswGQYDVQQDExJzYW1sdGVzdC5z\nd2FtaWQuc2UwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCcJfNqCJmM\nCWZ9+h9MAT9WbT/e+eRpGE9H8eucnnq4weTeFbT+2Ma15hY8hI6gP4GsDIZsaxTu\nDGgIYXctfnl9MTz+9rlANOo8Wjuz6CJ2trJ6BdhPvkoITuSqmIWkFbmP7/0NGkoG\n167CGp/Eq5yZnUOdiKXquH2S5OCw3mB4HGpjUk7T13cN0jOOPiK2cQhUTuUUMaVO\nei0QblIfK/+9fusfYOjd5uzNg1QZ9FvvbB/wTw4Z11eGcZWKpAprIrbx6iw119eL\nU7dvJhgA96VJmesDQejf96Xtpn7bCbxdyBqw2AtooamyrVjnAeQ8NDXW7td9MUuM\n4/yhN9H+fHTVJNs8dCX5FKayw5YoxF8eTMjRk0ObICMrLl8M/EiOG9Eqfc3TPGTF\ndn81sOGc3WzifRyG5fXUx/Xw9vXVkRAkVO6T4n6OUQxn2be9hwXR7yFw9tTplPIl\ndabhc7iWU7NgEBcBI3RWCcRNv0OVsXIMDeGZ64SOm4mpKbXMVebsnSLXxV69T1l4\nM8EegMpraRWHrbtF27FkKZPZgCbNaQbfW4vtJoN9rN07Flz8GLr200WXAepXT14L\ndGwXqjx6Cu2oilkl2OoNWQbRg3dvn1j6XqnRLbio4bvuiCYYEPpjuWcHOs/GwMnz\npml7EL51yz9PTwNZTQXsLH/xKlzWf1BuBQIDAQABo4IBbzCCAWswHwYDVR0jBBgw\nFoAUDL2TaAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFG40O0IHvLK2kXS6s4hN\nCq0DTtPLMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQG\nCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgG\nBmeBDAECATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEu\nb3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKG\nKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsG\nAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJz\nYW1sdGVzdC5zd2FtaWQuc2UwDQYJKoZIhvcNAQEFBQADggEBAHnWOLDwhrYWfd7q\n2fwTaiRP/x/tVPocNgi/wgwo6oZzC1Ru/HPjfUmnj11zkOOHeF8cf2BT2diRptPi\nqDc+7HN8GrM87+Deqvjj4pw7j4hwMpcfNd2AzqW4nPmw4LgiRehITtUtMxL9mkDh\neN0pgldD544xQRUdxYmD9nUWiIaTmuxNqusKkqUTD/kO41i+BxIeaWiXsw6IC7o6\nkPPUQHr1h2na805Kjoy5ML8K2EO+kcvFqfo42gtwa7mN38hKB+jbKF5VqqmoSb4m\nln/3lobOqcV8rrFKjvnjC6iNTbdpQ65o8CoOcfzhWmb/7RxkZ4a9fyzxVS8fMAi6\nu3Qzm3Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://samltest.swamid.se/acs/re_nren/redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://samltest.swamid.se/acs/re_nren/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib.mines-albi.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ORTEU Catherine"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "catherine.orteu@mines-albi.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "OTTON Emmanuel"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "emmanuel.otton@mines-albi.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.mines-albi.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-02-12T16:14:41Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.mines-albi.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.mines-albi.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.mines-albi.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mines-albi.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.enstimac.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mines-Albi"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole des mines d'Albi-Carmaux"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAP0DZFmoaqaMkf4YJmDc1SwYfx2yMA0GCSqGSIb3DQEB\nBQUAMB0xGzAZBgNVBAMMEnNoaWIubWluZXMtYWxiaS5mcjAeFw0xNTAyMTcwODU0\nNDhaFw0zNTAyMTcwODU0NDhaMB0xGzAZBgNVBAMMEnNoaWIubWluZXMtYWxiaS5m\ncjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIVlu4wyAmLrCkmiUliB\nffvyAmfDXYpQ0p9cjFJY7lN5DzaUNgObehddk7YFmyzBcfl7QKILPO4a81e3TcNr\n8+RXWspk3qkIcTwPrIPhp2vbcjRZR/j10akqG8A2D1beHNJbQ4K5IqfJG0EFeSc0\nut1LrdW/ZSiUMNESZHa8ASJU7yHJO667ij9yYAA8IHDgN57vO15Z/kHeFOGddNDo\nMR4Gn1NLytcC+AVZghIw+Asj/Ch6049LcxEXBj4nFvaa8JNdxJJVcetDMbXg/jsE\nJwgBfnlCn5PmuTaBBRI4YmaBjSJdNvepYcH0IhiJjrkp8HbNHIkwGmCfyCsVCxz1\nMHUCAwEAAaNrMGkwHQYDVR0OBBYEFCXTZozk5rGaw1NTmqrzTXYM5TLrMEgGA1Ud\nEQRBMD+CEnNoaWIubWluZXMtYWxiaS5mcoYpaHR0cHM6Ly9zaGliLm1pbmVzLWFs\nYmkuZnIvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEFBQADggEBAHmGkCqHUGFu\nK6g9Cy+JUbNDGILpNw8T4o/8acA/D5fwooiU7e2vo9/vX9WDOu7HU8jSW+gQxFLe\n9OhUpOZq6WV5R1zhFS8tkvhAXNtPGvon33QxcmT7nAS9epiQMrpbkBL6L+B9Rp/z\nrqj9lwITB6M5lt9s7WCWPr7yqGM4vyB7Gos/2Ng9XoK1IKl5LfMtmEbHlv454dlK\nnxi4i5Y1wnnNHebY9PNYU+rJPabA1HsrC4qBw9jFiTa2LonPdXIc9SYTxASbcZ96\nSksdcOTnimu/nRLGQnwqpOvNYEsom3R26wT2q0C8Joro18KXAZ7ebzn0/l0jOi+Q\n8o++pmkdoIw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ecole des mines d'Albi-Carmaux"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.enstimac.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ecole des mines d'Albi-Carmaux"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://auth.u-pec.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bastien SORET"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "bastien.soret@u-pec.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Baptiste Le Negaret"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "baptiste.le-negaret@u-pec.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://auth.u-pec.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2010-08-30T16:20:09Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.u-pec.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.u-pec.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://auth.u-pec.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "u-pec.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.u-pec.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Paris Est Cr\u00e9teil - UPEC"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Paris Est Cr\u00e9teil - UPEC"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUL8rXSh9z8lwFNYmrUxZVQXXbx1AwDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNYXV0aC51LXBlYy5mcjAeFw0xMDA3MjMwOTI3MzJaFw0z\nMDA3MjMwOTI3MzJaMBgxFjAUBgNVBAMTDWF1dGgudS1wZWMuZnIwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC3CIB42PQo6cg8vYefYuJnhAadIkFr7TKV\nlldoy+uQ8qcyF8ElQdIvvYxkUN0N1RVC9xqez1EiPQ8yKoiH3e24JbaLWMYO5J/K\nBxFYHwRkrSoW150GkvzCP1l7BuQr9x3fEQPsZjk48uZMzguOJY2JyEneyidxYv7g\n+XgUrBDK+OerHBWRYXAezuguxn/zr+aOEXx3htVlUI3S6yXoEFr7URasktJ5qAKj\nO/DfX2rZcUKV9fvGS+dnq4a/kqWD8ycH6NUVu7IbLtCgHLp0BQg6QPkM2Z+AskJv\ngqHxqhpP8zzD5HU5T3aV+MQ9XIg7l3vlebhp6bF4mlM+K8r9noIvAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDWF1dGgudS1wZWMuZnKGJGh0dHBzOi8vYXV0aC51LXBlYy5m\nci9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUx0iOH60s6SQCa/NwoN7hZBocV8Iw\nDQYJKoZIhvcNAQEFBQADggEBAJvL8HOgBpnBhBJJwuM0fWUjxDDN8eoF4kL59Vlz\nmaqV9N3mG3UDGBTcT6jjJ/zO7Pb53PJ69Adj7+d8PSyfSs2y2BC+YDOOzWfgrx3m\nDVmVBV/uKJfqRq4rMXsNekVyTmRiVojF3Qzeic6HbwTWMbLEmDxWgAVKOSg0Hu1j\nCANZRHLjo7NC6KWC0Hh0tXrenjG9yvVUxLOE7nnzMiQth4gMlRuLMsWuG5c12RZ7\nuna3UJI0MM77yR3S40ltFU6EKnQi3HO3TsP2QNWtkyuBaAhBzI8MuL/P3RPpUTca\n+m1oLcwCBV+imJ+QVPGoY154Eg5BcWrcB2wSC+6+CCPRZks="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Paris Est Cr\u00e9teil - UPEC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.u-pec.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Paris Est Cr\u00e9teil - UPEC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://appdb-dev.marie.hellasgrid.gr/edugain-connect",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chatziangelou"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mhaggel@iasa.gr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marios"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chatziangelou"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "appdb-support@iasa.gr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marios"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://appdb-dev.marie.hellasgrid.gr/edugain-connect",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Accelerating Systems and Applications - Greek Research and Technology Network"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u0399\u03bd\u03c3\u03c4\u03b9\u03c4\u03bf\u03cd\u03c4\u03bf \u0395\u03c0\u03b9\u03c4\u03b1\u03c7\u03c5\u03bd\u03c4\u03b9\u03ba\u03ce\u03bd \u03a3\u03c5\u03c3\u03c4\u03b7\u03bc\u03ac\u03c4\u03c9\u03bd \u03ba\u03b1\u03b9 \u0395\u03c6\u03b1\u03c1\u03bc\u03bf\u03b3\u03ce\u03bd - \u0395\u03b8\u03bd\u03b9\u03ba\u03cc \u0394\u03af\u03ba\u03c4\u03c5\u03bf \u0388\u03c1\u03b5\u03c5\u03bd\u03b1\u03c2 \u03ba\u03b1\u03b9 \u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03af\u03b1\u03c2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iasa.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iasa.gr/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.grnet.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.grnet.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IASA - GRNET"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u0399\u0395\u03a3\u0395 - \u0395\u0394\u0395\u03a4"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://appdb-dev.marie.hellasgrid.gr/auth/module.php/saml/sp/saml2-logout.php/edugain-connect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://appdb-dev.marie.hellasgrid.gr/auth/module.php/saml/sp/saml2-logout.php/edugain-connect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://wiki.appdb.egi.eu/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EGI Applications Database (DEV - Connect)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "EGI Software & Cloud Marketplace (Development Instance - Connect)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://appdb-dev.marie.hellasgrid.gr/images/appdblogo.png",
                    "height": "128",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "120"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://wiki.appdb.egi.eu/main:about:terms"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://wiki.appdb.egi.eu/main:about:terms"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://appdb-dev.marie.hellasgrid.gr/auth/module.php/saml/sp/saml2-acs.php/edugain-connect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://appdb-dev.marie.hellasgrid.gr/auth/module.php/saml/sp/saml1-acs.php/edugain-connect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://appdb-dev.marie.hellasgrid.gr/auth/module.php/saml/sp/saml2-acs.php/edugain-connect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://appdb-dev.marie.hellasgrid.gr/auth/module.php/saml/sp/saml1-acs.php/edugain-connect/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "EGI Applications Database (DEV - Connect)"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "EGI Software & Cloud Marketplace (Development Instance - Connect)"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sgw.garr.it/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sgwadmin@garr.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sgw.garr.it/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2013-05-09T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GARR Science Gateway erogato da Consortium GARR"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GARR Science Gateway provided by Consortium GARR"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.garr.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.garr.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consortium GARR"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consortium GARR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sgw.garr.it/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sgw.garr.it/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sgw.garr.it/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sgw.garr.it/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sgw.garr.it/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sgw.garr.it/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sgw.garr.it/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://sgw.garr.it"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://sgw.garr.it"
                  }
                ],
                "description": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Questo servizio permette di eseguire applicazioni scientifiche appartenenti a domini diversi su risorse di calcolo e di storage distribuite sul territorio italiano e in altre regioni del mondo. Attraverso il GARR Science Gateway, gli utenti possono accedere in maniera trasparente ed uniforme a risorse locali, grid e cloud"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service allows to run scientific applications belonging to several domains on computational and storage resources distributed all over Italy and other regions of the world. Through the GARR Science Gateway, local, grid and cloud based resources can be accessed in a seamless and uniform way."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://sgw.garr.it/policy/"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://sgw.garr.it/policy/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "GARR - Science Gateway"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "GARR - Science Gateway"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE6TCCA9GgAwIBAgIRALptUo7+DEUSrs09PRm311swDQYJKoZIhvcNAQEFBQAw\nPzELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEfMB0GA1UEAxMWVEVSRU5B\nIGVTY2llbmNlIFNTTCBDQTAeFw0xNTAxMDcwMDAwMDBaFw0xNjAyMDYyMzU5NTla\nMIGCMRMwEQYKCZImiZPyLGQBGRYDb3JnMRYwFAYKCZImiZPyLGQBGRYGdGVyZW5h\nMRMwEQYKCZImiZPyLGQBGRYDdGNzMSEwHwYDVQQLExhEb21haW4gQ29udHJvbCBW\nYWxpZGF0ZWQxGzAZBgNVBAMTEnNnLWxpZmVyYXkuZ2Fyci5pdDCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALX1GKeAFimAFVU5XaPX0Jb/UnbO9FMew0rS\nCwlGA/57V+7Gr0RsuCsmUoMOuITbTCz0K23A1e9mPflSuJNPQf30d/jE+rf3icrK\nM7wZVzKdqyodzV7d2e0p1LjVz7qE/DCREUI9ADZJpMRRLk2hWfBxog93SIM3YwFq\nu6r+BySrtDuwwAbiz3Hvo3QL+dsQbX8p8doML8O1F8S2KC82Pn5piyq+QzeYzJeL\nevr+8XyUzmDVEahQ8OxU0UxsSwm19WIqhYY3TB5o2Y0fxhCJzOA6Ypg9gul/o+Jp\nTsi1HJFrbWhQxI9rNmcy6VIoH45stsYkiFrdgY2xb2WlsH7/ad0CAwEAAaOCAZow\nggGWMB8GA1UdIwQYMBaAFCPTl73A2KGUYYgNhbbMdZ/JeTuSMB0GA1UdDgQWBBQj\nk9y2Mc0DO7GK4AOzZF2f+FDsWDAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIw\nADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwMAYDVR0gBCkwJzANBgsr\nBgEEAbIxAQICHTAMBgoqhkiG90wFAgIBMAgGBmeBDAECATBCBgNVHR8EOzA5MDeg\nNaAzhjFodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQWVTY2llbmNlU1NM\nQ0EuY3JsMHUGCCsGAQUFBwEBBGkwZzA9BggrBgEFBQcwAoYxaHR0cDovL2NydC50\nY3MudGVyZW5hLm9yZy9URVJFTkFlU2NpZW5jZVNTTENBLmNydDAmBggrBgEFBQcw\nAYYaaHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwKgYDVR0RBCMwIYISc2ctbGlm\nZXJheS5nYXJyLml0ggtzZ3cuZ2Fyci5pdDANBgkqhkiG9w0BAQUFAAOCAQEAQcaR\nDxdFgJsT0c5yNj/3GqYtNVwyWXN7AWul/V4VGq9sp36IqV2wmqScGkCEWHGsaUrX\nK5mNW5cmEM8Yqhew/Bvl8I10lvVreZ2TVvd+YGa2aLdIdhKld0fEMZ2RR5AYzGPY\n34PFlE6JqWOWHTvxwYGTv+tIy+Pel0D06afKEJ3PaVCcs2HuM/PxxQ/fDmvABZwR\noV/0KZ66qrvlXYsF2RYt0SOixsJC4YOkirXzoT7Pb8jSizVZJ3DWfwvdAlXU0DNE\nhrolz4U0Hxn5gCYTiDXtQBe4c8dj4IJYa1vTZgpJnO4aDQcQeuKLiJmSuOnTuuE1\nL0omxxTTWQuG2yPHqQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sgw.garr.it/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sgw.garr.it/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sgw.garr.it/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sgw.garr.it/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sgw.garr.it/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sgw.garr.it/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "GARR Science Gateway"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "GARR Science Gateway"
                }
              ],
              "service_description": [
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Questo servizio permette di eseguire applicazioni scientifiche appartenenti a domini diversi su risorse di calcolo e di storage distribuite sul territorio italiano e in altre regioni del mondo. Attraverso il GARR Science Gateway, gli utenti possono accedere in maniera trasparente ed uniforme a risorse locali, grid e cloud"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This service allows to run scientific applications belonging to several domains on computational and storage resources distributed all over Italy and other regions of the world. Through the GARR Science Gateway, local, grid and cloud based resources can be accessed in a seamless and uniform way."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "http://sts.windesheim.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://sts.windesheim.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-03-30T16:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/7c588283e83a906442b0591b722db36b",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hogeschool Windesheim"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hogeschool Windesheim"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/windesheim.png",
                    "height": "25",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hogeschool Windesheim"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Windesheim University of Applied Sciences"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hogeschool Windesheim"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hogeschool Windesheim University of Applied Sciences"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.windesheim.nl/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.windesheim.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hogeschool Windesheim"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hogeschool Windesheim University of Applied Sciences"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://atlas.sciencespo-lille.eu/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Laurent Marescaux"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "laurent.marescaux@sciencespo-lille.eu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Olivier Dilly"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "olivier.dilly@sciencespo-lille.eu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://atlas.sciencespo-lille.eu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-05-13T13:23:27Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://atlas.sciencespo-lille.eu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://atlas.sciencespo-lille.eu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://atlas.sciencespo-lille.eu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sciencespo-lille.eu"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.sciencespo-lille.eu"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Students Teachers personals"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Etudiants professeurs personnels"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sciences Po Lille"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sciences Po Lille"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTzCCAjegAwIBAgIUGuZxVz1Bu+epmwWqUK/URnWK7hIwDQYJKoZIhvcNAQEF\nBQAwJDEiMCAGA1UEAwwZYXRsYXMuc2NpZW5jZXNwby1saWxsZS5ldTAeFw0xNTEx\nMTIxMzE0NDdaFw0zNTExMTIxMzE0NDdaMCQxIjAgBgNVBAMMGWF0bGFzLnNjaWVu\nY2VzcG8tbGlsbGUuZXUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCw\ngDqC8d06qD0uaiYmgTaIPvq7OGMzdvEK23FT2rXNmD46EsL+0fDmz1Ar6A2YMe/c\nCAWcxNWdl1l81Y4Zq9CYFOHESYmJa0VbDiXKUm9uZ7gExCTpgs95aln7FKdhxH70\ncvkjbsP/ysR8pWIZyF2dNiwCOUzoE6X6/ubR5gBPNFRjeXOaW07kaciXUQWQ46rV\n95aU1ub6m6DoY0iE+2f6VczyeH3dvY2vwUnlv4iyzGdbxy2/0sYp/MRhyV2DSU2X\npH0OAW2b5Pd8GjjGRc2edRHV2nAzyxbgsLVHcs6BzoDWAGzQMh1LBtM3N8rA0yFU\n/rqOufiuPYKcwz+P8CCvAgMBAAGjeTB3MB0GA1UdDgQWBBSrw58/CJGCUJ8MPUxN\nhWlZJI1sbTBWBgNVHREETzBNghlhdGxhcy5zY2llbmNlc3BvLWxpbGxlLmV1hjBo\ndHRwczovL2F0bGFzLnNjaWVuY2VzcG8tbGlsbGUuZXUvaWRwL3NoaWJib2xldGgw\nDQYJKoZIhvcNAQEFBQADggEBAF3JLrl6A+5QxHkQo+HCpW9NL6aBdTq5YwzL6erj\n19thGmKsnQqNXciF6cNnLmdfFkvRgAzCOGDRiaCp8c5LsL9uJMdh0nUfHMEMnA8W\nlCFPOng5QZSsrSnqDtJCmgQMWjn4Y/lyHZvLEeEmAl+fU06EzsV+Se2stt4VixZO\nU6Du0lDqi/MoimHux0PPUD2efRHRGrs77E1NSq9Q8jdVC4GBBvaIbqr2yCq9k0jR\nYS0hp+6TuMBb4zuEDByqoDE4JwtkYAZOHSoSFa6O259tu7X9ANQDpNAthjl8KpiI\nkh+YDh3r2c1z2DXiAjWLKaHE+yDmAhbUvJsrS5vL9oQL6nQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Sciences Po Lille"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sciencespo-lille.eu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Sciences Po Lille"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.unipa.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Brignola"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pietro.brignola@unipa.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pietro"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem-support@unipa.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.unipa.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2014-10-16T12:25:43Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unipa.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.unipa.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unipa.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unipa.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://portale.unipa.it/amministrazione/area7/ssp09/set49/uob72/en/idem/"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://portale.unipa.it/amministrazione/area7/ssp09/set49/uob72/idem/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Palermo"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 degli Studi di Palermo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for the users of University of Palermo"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti dell'Universit\u00e0 di Palermo"
                  }
                ],
                "logo": [
                  {
                    "text": "https://skin.unipa.it/img/logo_unipa_title.jpg",
                    "height": "78",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "192"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://portale.unipa.it/amministrazione/area7/ssp09/set49/uob72/en/idem/privacy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAJbsMbEZBInRgijJc7/Hgow8W9aSMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDGlkcC51bmlwYS5pdDAeFw0xMzA2MDQxMzE5MTVaFw0x\nNjA2MDQxMzE5MTVaMBcxFTATBgNVBAMTDGlkcC51bmlwYS5pdDCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAICtvYrANCS0BU0KB5frRETwLi5R/tVwnIvp\nynl79CAd0jdq6iWNCpmXSDqlaF9AwxP6UtrhkGB26XeDKzckBiSY05cSlvnqMi28\naFpd2OXf/vhjEsVQjMK8wp+0qUPU5EbHs9dGKc11FHK+q44uZ3v70nF8oBU7L32T\nAc+/Yybr7pwAQ+NzRgiwfpubdUNCMic4TSnfkBv5zCpmUJFG42Ea1gEsdQWujHg/\nWua+nXSw3/a4Z03gJaWS97aAMVHfacZXreanqL9cyXfj6NkTDE3KT855ulVo+VjW\nz9GvqjBz+16eEMBiLvtF/5ISBVMvQJoU0l5B5/TbT70z/DkOO0sCAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMaWRwLnVuaXBhLml0hiNodHRwczovL2lkcC51bmlwYS5pdC9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUDbRcvvy9sUEoe72DxrviYkk7NpUwDQYJ\nKoZIhvcNAQEFBQADggEBABiKzyN69m5uduiYHrs+Ev6jg30TdU0iGcXhPI4gJivR\nT/ttPWH7S5hn8/HRKGAiDc9D+dXTqmjeRD9TIzRb/9GlqD2DutPZIQCmbepX7A4m\naZwyzzrbUcazqXdkv8Q+nQFoItzenxRNm52WNAlYKC82Lfrd15qrGw2RbQkxJBPQ\nbbEIk2a+SXsa+bjEJgFerDbdKVS21Ct5dU13iCObhzdxlXdmCSQiWUrjBvSLZJnb\nljNhr2Khy1bJz90c4T+i/Bk1mb+zB9ylzn/osseY1+1H0UFr9cH0kNp3CMroJlf9\nIjdH/J9P4kLHeAqbi9fTD2jaLUo+79uMXP3ftfsvj74="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAJbsMbEZBInRgijJc7/Hgow8W9aSMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDGlkcC51bmlwYS5pdDAeFw0xMzA2MDQxMzE5MTVaFw0x\nNjA2MDQxMzE5MTVaMBcxFTATBgNVBAMTDGlkcC51bmlwYS5pdDCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAICtvYrANCS0BU0KB5frRETwLi5R/tVwnIvp\nynl79CAd0jdq6iWNCpmXSDqlaF9AwxP6UtrhkGB26XeDKzckBiSY05cSlvnqMi28\naFpd2OXf/vhjEsVQjMK8wp+0qUPU5EbHs9dGKc11FHK+q44uZ3v70nF8oBU7L32T\nAc+/Yybr7pwAQ+NzRgiwfpubdUNCMic4TSnfkBv5zCpmUJFG42Ea1gEsdQWujHg/\nWua+nXSw3/a4Z03gJaWS97aAMVHfacZXreanqL9cyXfj6NkTDE3KT855ulVo+VjW\nz9GvqjBz+16eEMBiLvtF/5ISBVMvQJoU0l5B5/TbT70z/DkOO0sCAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMaWRwLnVuaXBhLml0hiNodHRwczovL2lkcC51bmlwYS5pdC9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUDbRcvvy9sUEoe72DxrviYkk7NpUwDQYJ\nKoZIhvcNAQEFBQADggEBABiKzyN69m5uduiYHrs+Ev6jg30TdU0iGcXhPI4gJivR\nT/ttPWH7S5hn8/HRKGAiDc9D+dXTqmjeRD9TIzRb/9GlqD2DutPZIQCmbepX7A4m\naZwyzzrbUcazqXdkv8Q+nQFoItzenxRNm52WNAlYKC82Lfrd15qrGw2RbQkxJBPQ\nbbEIk2a+SXsa+bjEJgFerDbdKVS21Ct5dU13iCObhzdxlXdmCSQiWUrjBvSLZJnb\nljNhr2Khy1bJz90c4T+i/Bk1mb+zB9ylzn/osseY1+1H0UFr9cH0kNp3CMroJlf9\nIjdH/J9P4kLHeAqbi9fTD2jaLUo+79uMXP3ftfsvj74="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 degli Studi di Palermo"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Palermo"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unipa.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unipa.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli Studi di Palermo"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Palermo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://saas1.kuali.co/auth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@kuali.co"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kuali Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://saas1.kuali.co/auth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Kuali, Inc."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.kuali.co/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Kuali, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://saml1.kuali.co/auth/saml/meta.xml",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://kuali.co/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Kuali Software as a Service"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.kuali.co/privacy-policy/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kuali SaaS"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEtTCCAp2gAwIBAgIBAjANBgkqhkiG9w0BAQsFADAjMQswCQYDVQQGEwJVUzEU\nMBIGA1UEAxMLS3VhbGlDbyBDQTIwHhcNMTUwODA1MTMyNzU4WhcNMTYwODA0MTMy\nNzU4WjAyMQswCQYDVQQGEwJVUzEOMAwGA1UEChMFS3VhbGkxEzARBgNVBAMUCiou\na3VhbGkuY28wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCvwBzIrXtL\n6w9aq6Mb2hoaBqch3Ghz/eANQBE9Ozo2jeGyAyEEIrR/3d78jEl0HkXutV8X53V/\nJgFltH5J85mf753dxbDpqR1UgnEgrEg/bxUw5pnh3kYErHzikKXfCtRGyaiReKXs\nU7pclQfqvhNwIL5dClshfWxCLvY+pYIFpMlRl9RCfbKzUoN1TyFuM9QoS5smjl1U\nASxfP7kzhCphfi8W0cZHmiFO8TQJuGWCKwR8kZ7CX6Zxjp7/iuNJHxIdJ/OkUMbl\nZUQRFfwD1bmZ6Es2FFuxPN3UTu8r0yBPrOxuFGoemuKIPVRVJ5DCuFhSV257tL38\n8Hh4KJtRVdVZAgMBAAGjgeQwgeEwCQYDVR0TBAIwADARBglghkgBhvhCAQEEBAMC\nBkAwKwYJYIZIAYb4QgENBB4WHFRpbnlDQSBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUw\nHQYDVR0OBBYEFBlqBFDtphbHtfEBZ2ZrBc2+IvVgMFMGA1UdIwRMMEqAFMJIZWiM\nI0cTh1DgKevrW6tGx/gsoSekJTAjMQswCQYDVQQGEwJVUzEUMBIGA1UEAxMLS3Vh\nbGlDbyBDQTKCCQC6nV0eMTjM2zAJBgNVHRIEAjAAMBUGA1UdEQQOMAyBCioua3Vh\nbGkuY28wDQYJKoZIhvcNAQELBQADggIBACXT4/QIgJEvIoieb3gHunogsWGEC2jU\ngC5nS2Absp4CCz8Z8nonQXVXNSzJtjRPU9kQR8JOtrWRiHIuwRkBEDZjII3vo2Cs\nk/Wfdf5MXfJK17ZmRqyVBQ0cHz3dgeUmhDLP2HzTuY/pMIBjm5GilQOUBYxvoPMx\nsB9FyEp9QBrrAhZdf+NNckMkuRh7D3Dae4d+7XAVL/52z2mlJmDZj3prrxq+wQVq\n+vuCjp9RASzFWbR/Qlb9ku1SMIaAuQlH4tpdkqOe79t2SJWdTnZ9Wi4+dmvQSBrz\nLBHHjrLRDwNd3vHWVjI4S1jp7ltBRIMsxuFzBqo7NDhz+U/1yvLJEBtmB9CNc/RJ\nzzwlLWSG+JsITxMDoZ3fh34MSJOxe6eXavAt1rE6d7nSu1HkhfD+v33vxr0xfUoG\ntqNM7CaaErTQeAzAvnmLAzhOezJnRqYrMAllPBRztyWjwlX2KT4JPwisaMR6kAPl\nIu2yOmEo7KmxcFTTMMEb1KFdPONH3xwxi7NYxU5ltMokPVnLrMLJXwI+63ED7JLx\nYWV3klx9aYUSSTFIoHOyukyq7yy+yh4fUnQH/Y0YPqwQ4Z0wmJNeaYElOu9gPEhj\nKX7X5FEfXoZHWDUo3ql5oLj/KCkD2A8+xATkcjvo9dw4FF3dJtmLIIPjGlDi8+pG\n9/elGcE7Yp1W"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGBzCCBO+gAwIBAgIQAgqfxGs7uxxVAflOSJIAezANBgkqhkiG9w0BAQsFADBN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\nkDd5wSrsHHkE2gc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://saas1.kuali.co/auth/saml/consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://saas1.kuali.co/auth/saml/consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://saas2.kuali.co/auth/saml/consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://saas2.kuali.co/auth/saml/consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://saml1.kuali.co/auth/saml/consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://saml1.kuali.co/auth/saml/consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://saml1-stg.kuali.co/auth/saml/consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://saml1-stg.kuali.co/auth/saml/consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://saml1-tst.kuali.co/auth/saml/consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://saml1-tst.kuali.co/auth/saml/consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Kuali SaaS"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Kuali Software as a Service"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.inserm-transfert.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "resnat.dsi@inserm.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.inserm-transfert.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-10-26T17:34:57Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.inserm-transfert.fr/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.inserm-transfert.fr/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.inserm-transfert.fr/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.inserm-transfert.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.inserm-transfert.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.inserm-transfert.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "inserm-transfert.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.inserm.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "staff"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "personnel"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INSERM-Transfert"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INSERM-Transfert"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAJ0+TvIeavAjFYxpT+7F0r61FktEMA0GCSqGSIb3DQEB\nBQUAMCIxIDAeBgNVBAMMF2lkcC5pbnNlcm0tdHJhbnNmZXJ0LmZyMB4XDTE1MTEw\nNTExMTYzM1oXDTM1MTEwNTExMTYzM1owIjEgMB4GA1UEAwwXaWRwLmluc2VybS10\ncmFuc2ZlcnQuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCyFxGe\n9J5hJ5TpheBI7GLLtSoXL8K7CzhW3FSGllYxg/rFOslJZ7reFKvochYc0PBAvXei\nS0XO1eAfMuDhNCchq7bIPkEW78ptBO6VPqCt5QLQTRfAh8TCIRYSPMU4Z643Yuy5\nVWOPhL3h66MYSBaYgFKpdImxO+1f6xlQu59NoshcWL3PhbX8rV/NCrjrk6v+ZBpi\nyMixH5eMihA636eU2JATjRtiqBOtoPyanGD6W095Ojk9PACthlKtEjTdy9p+rQt6\n0vymAAvCbrLSVc5sGwfAF08dGv/tQt+ry6BzQyeJQJW1H0moLfjvDyVi8DEGNDqn\n9QBSVydMSGmRImdFAgMBAAGjdTBzMB0GA1UdDgQWBBSzBOmHUIetjuQbwGmKlilB\nonqRmjBSBgNVHREESzBJghdpZHAuaW5zZXJtLXRyYW5zZmVydC5mcoYuaHR0cHM6\nLy9pZHAuaW5zZXJtLXRyYW5zZmVydC5mci9pZHAvc2hpYmJvbGV0aDANBgkqhkiG\n9w0BAQUFAAOCAQEAc5DK3X/GfYxevOJDvTdAc3W0PkfqBsp1D1ko4/khPvG6MJax\nEMjN/zE5e8miWXnkn+MQpzkKCHsLaeu6HD6LjHqkE+RtVK8fD6AMgw9XXWD+QCyT\n6MOahvn1ibDfQmZt+TOLL9kJOGLUMjeGtcH0yXkXb6bCdq9/yyiev7SnkNjS1YnM\nPtOxxP015w7/b9XDcshiRp7Xq/SExT4u5lweQiuYCtQG50GglyTnAiusgudwOJe2\nx3BVTdBOVbAslCRJv87S1z+DTBWmau+d8f5UDihF4YOpGRfIdo6wMf5JFn9BvZ7X\nJEYjjQM1FVU+uKub1f4DfSjgrc4HvczfZY1hnw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAIJyc+Gfzp0eVbXdBuMNzE3AyFxwMA0GCSqGSIb3DQEB\nCwUAMCIxIDAeBgNVBAMMF2lkcC5pbnNlcm0tdHJhbnNmZXJ0LmZyMB4XDTE1MDkx\nNzE0MDQ1NloXDTM1MDkxNzE0MDQ1NlowIjEgMB4GA1UEAwwXaWRwLmluc2VybS10\ncmFuc2ZlcnQuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC4J/qi\nFHfMKCtfFrKtx0RO/5ltByejYDObLpFXsRiVw3YgvFw7UEFKPQyDu+zydE3La76v\neYvYkA0As/x9DxnUxui2FaZrFS8Fyd9Ty//MoeatQ7TptIxsLr8BGS2XXqE0LcuP\n5r/KAMazSvvz77OjjU0XW/prDL+6KSL1RRJoGkVzup9j4dKDtcQ3daj6/ISG3tif\nUfLDDfeW3Q0zBY+ROY69gM5hUytpASLTOXK9acJAle57a2YoyjK2JBdnrFUUHN7p\nh8IV+RB7kvJNVYrgQSM3/UGAgV7kbYfSizByBFcjwdOrkax3brcm1G8GSxmN6kuT\na7gnycLSevkW5prDAgMBAAGjdTBzMB0GA1UdDgQWBBRIN86FLK0AxMvmltTCimJ3\nmLjKkTBSBgNVHREESzBJghdpZHAuaW5zZXJtLXRyYW5zZmVydC5mcoYuaHR0cHM6\nLy9pZHAuaW5zZXJtLXRyYW5zZmVydC5mci9pZHAvc2hpYmJvbGV0aDANBgkqhkiG\n9w0BAQsFAAOCAQEAatuPIuWH5lqbqqSWL67JrE+BlawU0c/Q5B6Zjs0QRzvwQzrw\nNXzORY0nBEs1xg0VB35h8yMRhZowOj1gMCQDAkw3WeA9/TjZcDzlbHzVmmohlicm\nDF2hFjpP2dj9x2Vsn8/VuENBuJcQl2Zq6WoMlMPijQILJF3kErZM4JrXkbIB3fKd\nCJX0zPBriZsEKtzvHyKP/J8fI2Xn5uyvK8Z2WI1JyGr9r69EHXtN1ERk/jkdM+vf\nIDXLNZxDZcZALVhexi2xQG6uuu4dr/CnjWMJjDPN9nvx4WBsmPl1K7Tx0GRmF7gJ\nxIMPqERTBQpVvk4wmDf5mFKRvz1TjqYd32QhVA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INSERM-Transfert"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.inserm.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INSERM-Transfert"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.surf.nl",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.surf.nl",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-06-08T16:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/adc14b08480e6f3288d996344c6f4459",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "surf.nl"
              },
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Co\u00f6peratie SURF U.A."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Co\u00f6peratie SURF U.A."
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/surf.png",
                    "height": "86",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "44"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SURF (nieuw)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SURF (nieuw)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SURF (nieuw)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.surf.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Co\u00f6peratie SURF U.A."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www-test.ted.is.ed.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:is.helpline@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-certs@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Apps Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www-test.ted.is.ed.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-07-16T09:37:16Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Timetabling Web Apps - TEST Environment"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www-test.ted.is.ed.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www-test.ted.is.ed.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www-test.ted.is.ed.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www-test.ted.is.ed.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www-test.ted.is.ed.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www-test.ted.is.ed.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www-test.ted.is.ed.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJAPxnziiUKyZ8MA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\n\t\t\t\t\t\tBAMTFXNhdC13ZWIta2IxdC5lZC5hYy51azAeFw0xMzA3MTIxMDUzMjdaFw0yMzA3\n\t\t\t\t\t\tMTAxMDUzMjdaMCAxHjAcBgNVBAMTFXNhdC13ZWIta2IxdC5lZC5hYy51azCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJfQj3Fn3JObYydckX3u9Dgezz1N\n\t\t\t\t\t\tuVQK64kW5bCjUOT6/KxL8nHOOrPKwcbEUF064oRDPVxgJ3zbK2JCgKZWEWAU6ASy\n\t\t\t\t\t\tKJ23D7kkNdMWiBO41XYDyBuRI3KChJbG7nJqEMCM2P9VPlCTzQGy8iCcVKoRKZfa\n\t\t\t\t\t\thnpkxOcLhX70jJ0pIlXAFA10qW9jc5KxFIRZXWP+4r0A3zcdSLsqKkTdUt2jRb81\n\t\t\t\t\t\toKlSn109dSQ4pV+hZ+LCpll64LxxDNXEGHeBTM+YHJB4Yp85a+r9Tsas1crstwyc\n\t\t\t\t\t\ti5R2MorDFB2w+Pht7rae3GrIMYuwJ9GyalJaKVCcA4t57irCa5uLv6413UUCAwEA\n\t\t\t\t\t\tAaNDMEEwIAYDVR0RBBkwF4IVc2F0LXdlYi1rYjF0LmVkLmFjLnVrMB0GA1UdDgQW\n\t\t\t\t\t\tBBQZ60I7N9IvNRrNpbwngvPuMBFzXTANBgkqhkiG9w0BAQUFAAOCAQEAFuXgykYH\n\t\t\t\t\t\tRzeNpD2HxF7BsMxfuYR/nKhwn2KpL/zjGHqrEsYlpiHtlS9rmYFUv8Z82QQZEvhF\n\t\t\t\t\t\thbEvVnWKd1Q0YaGHJa4BDVU1pSkCcvZjn798FvsOET7prY1zJqbjwBnBWC0grbUL\n\t\t\t\t\t\tRVct5cZ3xl7UjkprTAlGBP2uYJCgoAphtoXLSox1n2Yd4UQ4X+JHRWqhL5aqW8YA\n\t\t\t\t\t\tpkuYejIZPEvWevPpt7h817zE0VwGTGcIOUnrN3qVFWtiTFW/6cHPa0gkCpa0/4y5\n\t\t\t\t\t\twDxLtTKopgZv59F6rJ2XK+pISqynmu0u1Yx9c9sALZ8juKgF6vzB54wRCwHIBUE2\n\t\t\t\t\t\tntsJEvhCORTfww=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www-test.ted.is.ed.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www-test.ted.is.ed.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www-test.ted.is.ed.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www-test.ted.is.ed.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www-test.ted.is.ed.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www-test.ted.is.ed.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www-cvdc.eng.cam.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:falcon-support@ucs.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Falcon Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:falcon-support@ucs.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Falcon Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www-cvdc.eng.cam.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-02-18T13:59:35Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Cambridge: Cambridge Vehicle Dynamics Consortium"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eng.cam.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Cambridge"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAOB8D/FajzX8MA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHd3dy1mYWxjb24uY3N4LmNhbS5hYy51azAeFw0xMDAxMTgxMTAwMDdaFw0y\n\t\t\t\t\t\tMDAxMTYxMTAwMDdaMCMxITAfBgNVBAMTGHd3dy1mYWxjb24uY3N4LmNhbS5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKpU2AuemKJSIeDmgjkZ\n\t\t\t\t\t\ttPgKaPPkM5CKu3QUHm5JzmtnG3UFMxbOumt6sxWWF72ceXQNPgBNGqFI/sFdaCIo\n\t\t\t\t\t\tHxZj+Z2i+k7/IVXhc4wjs72YUfrjvTMDhHHzndm3KkJS8imsIYQ8/bBnJEF93zVJ\n\t\t\t\t\t\tgPYTrX1C8JxqF/wfY/XCGbEqHgJtqDrSEvK+vLF7LaYI4oTotZOg/vhN7uwaEa7n\n\t\t\t\t\t\tGU2+bKuhcAL+rolEM6sbdrQAj3KarTafacfh9IiAclzyOQTA6pfjFWrucNIuWXc4\n\t\t\t\t\t\tYhaEPyOMubMsp+0eXZAwEPTJ61x+nQZd3UAf7Rm5v7agrzRAdqdwpnqb4yyprJlI\n\t\t\t\t\t\t+lkCAwEAAaNGMEQwIwYDVR0RBBwwGoIYd3d3LWZhbGNvbi5jc3guY2FtLmFjLnVr\n\t\t\t\t\t\tMB0GA1UdDgQWBBTz/ES/EvNaSsqqXUxLuIFc9YHi/TANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAAvFTJS2L6StZuqKA935AD3bBOHe5pg+LCF6ydHdTuyWEJYIWBRJ1WXsKMyaG\n\t\t\t\t\t\tyvdlX60XziJARq2UiYxt4yRjuGLAjQl9kNdrlqeb2AJFnA5E1Mt56FtzPiwu2zrC\n\t\t\t\t\t\tTQlklC4Xfie1Yaw2kEVO2vAoRfg9bgSBfyvFC4oR3vCery3Z687oCeQqDp7LPRcn\n\t\t\t\t\t\t+k5qQD8pout57IYzwyo7GPeVkYEPb3GO2KYmoENlDR/xah2VcsTZF7aIsMBFxaPv\n\t\t\t\t\t\tO+oqrQcnQXTviY9yWLbAlSrPPqGNYDxayVHn+zDSO4scLlOoqZJ8iC5NboNKqFyB\n\t\t\t\t\t\tRsenNm/aXp0wIU+jHVmi/GAPCQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-demo-01.its.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-demo-01.its.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;demo-01"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;demo-01"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-demo-01.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-demo-01.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIJAMRYGhBhn5UuMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\nBAMTG2xhZG9rMy1kZW1vLTAxLmxhZG9rLnVtdS5zZTAeFw0xNDEwMDcxNDQ2MzVa\nFw0yNDEwMDQxNDQ2MzVaMCYxJDAiBgNVBAMTG2xhZG9rMy1kZW1vLTAxLmxhZG9r\nLnVtdS5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOalh/0b61hE\nOCTOh82ytTf3633I9ZrsKD1XGlCICIYNbgrqRwA/T2NqX6cnQh2hgTqlUUaVX7WZ\nq3VDCmi84v3RRoDC5mrP84vWejNzVMZKCwugp0KhnDQbWb1qzQnGTI5ezgjuXmIr\nqPlBPC0AaLTb+6jX9VRA+rJqiHuJATF+5fm1xwiJ5QR67DiVeHewcGP3r9Z3Fb5g\nKSmbd0GmkXZb4F10pmFGE7471ZTgcrL9soAaA8hlc2+jL1UVvtE7PY9VTcnD540Y\nkoL9kIfnMWIO/x06fWJQkphfrQu41Rh4UMt9e5qcJcUA/knmw/OWPH2/svDhv0mO\nrip3BLBPe+MCAwEAAaOBgzCBgDBfBgNVHREEWDBWghtsYWRvazMtZGVtby0wMS5s\nYWRvay51bXUuc2WGN2h0dHBzOi8vbGFkb2szLWRlbW8tMDEubGFkb2sudW11LnNl\nL3N0dWRlbnQtZnJvbnRlbmQtc3AwHQYDVR0OBBYEFLboAtPLn/yoa6dvPyfFZXlD\nPY9vMA0GCSqGSIb3DQEBBQUAA4IBAQBWwcRdfbwtKbNYHuI2mLxjoh2Zac/ns7BR\nuY/ZmbDJ/Yhk6vdiU0/jwP2TkIs0Z9/oXetVuQICtgRLdBBSBSNpUMsMqR+tJ6Ab\netzXToph/gvyv8XNjahPtOOLvtK/874r5JuqfktFcsTjhxoxvEsRq+H6xUnitw77\nIq/yhze6jvJn+5zRr/vkwpKJBLobXjytbvaahijlJxKgj+FBEkwUTotNnz5G4SsA\npYOMqd8nZEwrLoOlQXb5MKRDS0cdjiDGh7RDvQgs05MTMHQI/C7pwoAm8XWEfZlP\ndoapb4k+1TzJZ+MDX6jwvVMl0DN5+rmuHjkmu75L+UERnVJRSbIK"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-demo-01.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://hpc-wayf.sdu.dk/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Birnbaum Jensen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lasse@sdu.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lasse"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://hpc-wayf.sdu.dk/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2014-05-27T10:41:03Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Syddansk Universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Southern Denmark"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://sdu.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sdu.dk/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Syddansk Universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Southern Denmark"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://hpc-wayf.sdu.dk/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Form\u00e5let er at administrere bruger-adgangen til HPC-centret."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The purpose is to manage user access to the HPC centre."
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DeIC Nationale HPC-Center, SDU"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DeIC National HPC Centre, SDU"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFOzCCBCOgAwIBAgIQB39SLNLwoqeoeeq8If/1ITANBgkqhkiG9w0BAQsFADBk MQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ QW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg Q0EgMzAeFw0xNTA5MDMwMDAwMDBaFw0xODA5MDcxMjAwMDBaMIGBMQswCQYDVQQG EwJESzEaMBgGA1UECBMRUmVnaW9uIFN5ZGRhbm1hcmsxDzANBgNVBAcTBk9kZW5z ZTEdMBsGA1UEChMUU3lkZGFuc2sgVW5pdmVyc2l0ZXQxEzARBgNVBAsTCklULVNl cnZpY2UxETAPBgNVBAMMCCouc2R1LmRrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A MIIBCgKCAQEAzVQFqrhdUdkursHSLNBKUiPfkiKA1O1zSd7h0sUR0qrbzc2zKCkt ipe30W5lSuPZm1uJIsA1RzyQ5B1ER32kQRQBXctmTRVPKgem+J2wiQV7jkauDbsC TrfSeWesFfKyV7dKo0iKD4A0SASRMhoRCPxPI3/k4GqXFhJeySEK61YNWP80zaXg UMhMIdCXp0M2ZHFXC0thCul0/c5zUIxalN4i4wFCXl1cFt/9xb4qcu4IdAswghus Lbvs2LAMOGkKRp7PMX5uUE3Sln25EhvUJiGQFhqCPhhTNnjUwDUzPkFkYjFNF591 Go6MqWG/2xmNlovSWp4c3CJtwOit2JSn1wIDAQABo4IByTCCAcUwHwYDVR0jBBgw FoAUZ/2IIBQnmMcJ0iUZu+lREWN1UGIwHQYDVR0OBBYEFI2NVtdB0beyq/m/Ptty DLz2BW2XMBsGA1UdEQQUMBKCCCouc2R1LmRrggZzZHUuZGswDgYDVR0PAQH/BAQD AgWgMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjBrBgNVHR8EZDBiMC+g LaArhilodHRwOi8vY3JsMy5kaWdpY2VydC5jb20vVEVSRU5BU1NMQ0EzLmNybDAv oC2gK4YpaHR0cDovL2NybDQuZGlnaWNlcnQuY29tL1RFUkVOQVNTTENBMy5jcmww TAYDVR0gBEUwQzA3BglghkgBhv1sAQEwKjAoBggrBgEFBQcCARYcaHR0cHM6Ly93 d3cuZGlnaWNlcnQuY29tL0NQUzAIBgZngQwBAgIwbgYIKwYBBQUHAQEEYjBgMCQG CCsGAQUFBzABhhhodHRwOi8vb2NzcC5kaWdpY2VydC5jb20wOAYIKwYBBQUHMAKG LGh0dHA6Ly9jYWNlcnRzLmRpZ2ljZXJ0LmNvbS9URVJFTkFTU0xDQTMuY3J0MAwG A1UdEwEB/wQCMAAwDQYJKoZIhvcNAQELBQADggEBACwyOmcd3i6MYbah+i/MzZWi yUWsG/FOJmdG0krY+RtiBlLQ8UKDyJMjaeg/NNriwq7z3WZGpciSLRgEWPeoSsYT YQlR50Qn9CXIGWq6AOpIHFA3nMsicPjw7uZzSKRMWUS7DcQghBFZTXd2e1Ad5lBY 1hBjnsaVNJTLPhw0sGbJps2yzlm/ea3YnsmjdeOjXf1H1qA+3JgSJrSQlUkbrSyk DujmhIyKT/QZ9t/a3z8meNCiZogGDtehtmbPlPXWz6Tk6qif1dR4wF4t8/YwEjsr gKZxbMEVH0NYQf+3t4TiQyY1eJWbb70ALhio4HgYEpTy+6nPBP8kuDsl69X4esw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hpc-wayf.sdu.dk/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Form\u00e5let er at administrere bruger-adgangen til HPC-centret."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The purpose is to manage user access to the HPC centre."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "DeIC Nationale HPC-Center, SDU"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "DeIC National HPC Centre, SDU"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "cn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "organizationName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp3.leeds.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itservicedesk@leeds.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Powell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:r.g.powell@leeds.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ray"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp3.leeds.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-08-25T11:01:40Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp3.leeds.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp3.leeds.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp3.leeds.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp3.leeds.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp3.leeds.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp3.leeds.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "leeds.ac.uk"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Test IdP for University of Leeds"
                  }
                ],
                "logo": [
                  {
                    "text": "https://strategy.leeds.ac.uk/logo/uol64px.gif",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Leeds Test"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUYURZnINS9EeqJg0pAXf/MdmQ54gwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwGzEZMBcGA1UEAwwQaWRwMy5sZWVkcy5hYy51azAeFw0xNTA4MTgxMDAyMjVa\n\t\t\t\t\t\tFw0zNTA4MTgxMDAyMjVaMBsxGTAXBgNVBAMMEGlkcDMubGVlZHMuYWMudWswggEi\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCruBWfogh3dxD2RdBKI3/F4Fmb\n\t\t\t\t\t\tvvJBYCBgbiofz49DRT6qFNMWibY/EZczXWMBdCego16JYu3MVOouHSWTYgwk4V+q\n\t\t\t\t\t\tGTojKkCk8ScDbMtx04PNPAFHL7ungi0MhxkXt5/MpwDFrJlGzGZrccV/u3zb9qCL\n\t\t\t\t\t\tUnjv0GuvgvmYvSnJ4WdVCrc0v2d9H625pT92uEsV1adFmC3OJ8Jk5R9k/LE2AByL\n\t\t\t\t\t\tiZqD5UZFf9Y8WZKUTFzkjYJRFJXZqMNv75jOMa867f+nSYOpBAghj575/N30yC5r\n\t\t\t\t\t\tdLRMwTal8cvs+wF/R9lVbLYSCvsJ5QNnL+BQiPOGsJob0/0TvewSl8nUaLsFAgMB\n\t\t\t\t\t\tAAGjZzBlMB0GA1UdDgQWBBSRdNZCmAme05qVft4XFWv4VbNkeTBEBgNVHREEPTA7\n\t\t\t\t\t\tghBpZHAzLmxlZWRzLmFjLnVrhidodHRwczovL2lkcDMubGVlZHMuYWMudWsvaWRw\n\t\t\t\t\t\tL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAEqN4qG5ILyxJ4wuiubbDqFR\n\t\t\t\t\t\t5o708PBQRxMvBHn+oIliu1B7SJnvDZOlKGYAZGJf78aqMAPb7ECIAeAJ0AYgxhWW\n\t\t\t\t\t\tjIsqrC41zNRWj1OtBJ+H8hPqw/4a8nVpSZuvdbilCwPBBYMng50vaM95POgMnod4\n\t\t\t\t\t\tHOw/xVyhphAwgNR8BgACE8IlPSnLtravHFB1ZBhQ/uWJnNECbkdMvUCkDsds4By1\n\t\t\t\t\t\twDSxOl7VTLDNRwSyhXrYozc8reRh0prFGigUqguyp/KTojHZG/M2aU9M7YzMh+U7\n\t\t\t\t\t\tuEIXZi3EMZmm5CTTQtCTIVJC/VfROS3pgnC+ur3qQfmWPXsHH8l155E6jogL1Jc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVALRts/OJ9FYIac96GkaAZZXUS5IZMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMBsxGTAXBgNVBAMMEGlkcDMubGVlZHMuYWMudWswHhcNMTUwODE4MTAwMjIz\n\t\t\t\t\t\tWhcNMzUwODE4MTAwMjIzWjAbMRkwFwYDVQQDDBBpZHAzLmxlZWRzLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAh2OwSxoyvPCB74HzqJhDeHie\n\t\t\t\t\t\tcrlPJGRqWFrciKDnfstpAE/NaEjmceuI1Lu/1AITg+a9euKWuhSyPYSA3zPbdSBb\n\t\t\t\t\t\tLw9AEuw7Wt416KukY/RRvSPdDPHr1L3DAx2iDLj0zbq48Tc1shx3szin/HjgUrfe\n\t\t\t\t\t\tYHwZkDrkP/z8x4hE3/mTzj+Lp4SKDqJ4TET1aLY5C8PdCRrnfiPMkkWRacVDPk52\n\t\t\t\t\t\t64/ylNFdxvln31pR/POsDCfU5YvFyyIprMOV+dujRaLFnhHrtEUJNj+8efMXAyjp\n\t\t\t\t\t\tu+kXkBwgBlhkjztFzKYlmvnn+cZR44REIbgTvOM+9sAA9yeCxxnncp1BRGjBAwID\n\t\t\t\t\t\tAQABo2cwZTAdBgNVHQ4EFgQUcOb6y7ZYG4QsQhyd+hPo+5/rrigwRAYDVR0RBD0w\n\t\t\t\t\t\tO4IQaWRwMy5sZWVkcy5hYy51a4YnaHR0cHM6Ly9pZHAzLmxlZWRzLmFjLnVrL2lk\n\t\t\t\t\t\tcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQAIBTExL0Jxyg+nZiH5RrpW\n\t\t\t\t\t\tTA/i7GiJ6sNbwvwKz2FHd5Uw2E8RCcsBWjJMfPEl8YDXHLHkvW8kv+AqbPDGeMHX\n\t\t\t\t\t\tDwz+2UuS0Qj4dACEZ1HuZLRzfKdtBBcY6I58suWppBDNuR0Mp+QXMPtgQUsbcLDq\n\t\t\t\t\t\tN++zgEOkLj64nmPrr7os2toELnDS2OzbBQknQqJKQASrdMGMocfgjAlQJ3zZ1zTS\n\t\t\t\t\t\tA0cvGu36rI4udLJQcopfcIwkXSdoUf61rWhHC4flU5k94R1MIOZcPNGioPWUgopB\n\t\t\t\t\t\tkal0cnkoz2TNoT4WXv/Ob5J91TLyToRkod6npSNk+hSaCy554OiimCnyrqUPyKrW"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUKhTirYyDRSrB8gvM2sn66nNngqQwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwGzEZMBcGA1UEAwwQaWRwMy5sZWVkcy5hYy51azAeFw0xNTA4MTgxMDAyMjRa\n\t\t\t\t\t\tFw0zNTA4MTgxMDAyMjRaMBsxGTAXBgNVBAMMEGlkcDMubGVlZHMuYWMudWswggEi\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDdkM29DJqAD9YmOgFummgJNCUJ\n\t\t\t\t\t\ttitEUqaTnSLpwWzGJXNpRFA9T7uVbOF03GCU6SeTg/mpfm1J3E2WtpIb5OBxPb4N\n\t\t\t\t\t\t4FITd2s+gMH3FcfQ5zLMsWeEJtx0lt4OvZjPqs/e73S09h03WTK8ExumPpsyccG7\n\t\t\t\t\t\thFqYwJggsJZqHEYvqSH4NZFCG5GIkXRUi0qISC2JgxsP4aAVez8+oChVq26qMcBw\n\t\t\t\t\t\tV/tVoUf5hoFWX9Kp0tI9HcWjcgv3HyQSKDueFx2fADoMfy1vVsHYkYP2BZMONwsf\n\t\t\t\t\t\tBuZW/hu7NmVMfiNJAqJlPbZJ6OEWmwKJDbtiCrNv5lg0WMgh/pZpzMDjJAn9AgMB\n\t\t\t\t\t\tAAGjZzBlMB0GA1UdDgQWBBTAXntceiuy/zgkze2/eUi6QvuSjTBEBgNVHREEPTA7\n\t\t\t\t\t\tghBpZHAzLmxlZWRzLmFjLnVrhidodHRwczovL2lkcDMubGVlZHMuYWMudWsvaWRw\n\t\t\t\t\t\tL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBACMWrgv/5Qv9HpEsmPHo0IlV\n\t\t\t\t\t\t2oKtEZLU+hSJ81bejv9+QyabxXobKtc7mOhsaqUE0uXbMsMQvDXdjiaO1yca4r0p\n\t\t\t\t\t\tiKY9MLVlFmWvGztsgto5MCzv1DIYrFQt1dhoXJQdurJF8Q58jNEizvjBR+lyUoIA\n\t\t\t\t\t\t/zxOmg1dwK54FWFr9zRecsYaGTZGDZM0cIeApcQARtV6fpdoqwGFj1Nezcf8nwZ3\n\t\t\t\t\t\troJ5ROffd5RGxn9XQzbuPN7iovAhN4rgzxaAb2seIX70IlHk7D13AUKJYV+8gW7S\n\t\t\t\t\t\tb1/t3dWvVAtKbFtDuK6uceoSakimTq266X2PvA+HjRhZS0adgH4dYDtEkiG3Vg0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Leeds Test"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.leeds.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Leeds"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.uic.edu/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rullfig@uic.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roberto Ullfig"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mat@uic.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mathew Willis"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jtk@uic.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Johnathan Kupferer"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "wallenr@uic.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Allen Randall"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.uic.edu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.uic.edu:8443/shibboleth-idp/AA",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.uic.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIJAMnh1KsacvUeMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEnNoaWJib2xldGgudWljLmVkdTAeFw0xMTA3MTgxNjQzNDdaFw0yMTA3MTUx\nNjQzNDdaMB0xGzAZBgNVBAMTEnNoaWJib2xldGgudWljLmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAK/LA9eioSPqX+ipdmNMyZerjyPhPWBiem4f\npiOGnBiua76pGvvujhlaPnWT3YfwFWLpKKuPt0nBgk8SC9PTlP2oubVqF9FIFA5O\nUHtAj3nrkXNCu67HLzaW8ClGwCwdImCcTnXXhp1c8iVcRjp2r+DcxjYHpXLyT3o8\n8BmWnGJX8fCo8gtnVukc6Xv+J+gSOFRmCnvbkBkeiALNn3lkJgdvdJhAHE+OcRg1\n4kEmt3/mxOENVouRMi505ez4hMH4iR3fvD3w+1rGKtrNYCBrvagqUSZ2fBF3k6tG\nTQfzNswoGiSrLAkrMZ+N8qjkC/hdQNj4t48uKzEUYvcka7x5q2sCAwEAAaN+MHww\nHQYDVR0OBBYEFPCmz0jymFskc2beyFTMGZ8F7ERVME0GA1UdIwRGMESAFPCmz0jy\nmFskc2beyFTMGZ8F7ERVoSGkHzAdMRswGQYDVQQDExJzaGliYm9sZXRoLnVpYy5l\nZHWCCQDJ4dSrGnL1HjAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBY\nWrbjYC+bfwb1gPCchi0vil5x92avIJjQv/AOIT5xp9vmg6km429KXD5BoI32tf7i\nSgmwOllxtLGLE8j7EKZwcVcm3JYo5PIVzWX8yI2q2UpUZKFryoS/KFUoolDN1bNQ\nRnrLeO1Pwy7i93H8mnLGBa/S0+pcjEitKdC+VGEw+i+ZVVBCZMsyggzLK8KIrJPr\nI7vNFfld6a9DYkGUK59mwUwfVU1syUk0Eht25bNa4wKkWGf4OYV83x36xWMyN2Yy\n9fvlUHzM13HdEFvfPytJ2z1wpDUVZaGJ5LWb13cSpTZ2yEyllrRW8we9Paoac8js\nEj+l4a6PybN1ttx/R08j"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uic.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.uic.edu/idp/cgi-bin/shib-logout.cgi?return=https://shibboleth.uic.edu/shibboleth-logout.html",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.uic.edu/shibboleth-idp/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.uic.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.uic.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.uic.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.uic.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.uic.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uic.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Illinois at Chicago"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIJAMnh1KsacvUeMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEnNoaWJib2xldGgudWljLmVkdTAeFw0xMTA3MTgxNjQzNDdaFw0yMTA3MTUx\nNjQzNDdaMB0xGzAZBgNVBAMTEnNoaWJib2xldGgudWljLmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAK/LA9eioSPqX+ipdmNMyZerjyPhPWBiem4f\npiOGnBiua76pGvvujhlaPnWT3YfwFWLpKKuPt0nBgk8SC9PTlP2oubVqF9FIFA5O\nUHtAj3nrkXNCu67HLzaW8ClGwCwdImCcTnXXhp1c8iVcRjp2r+DcxjYHpXLyT3o8\n8BmWnGJX8fCo8gtnVukc6Xv+J+gSOFRmCnvbkBkeiALNn3lkJgdvdJhAHE+OcRg1\n4kEmt3/mxOENVouRMi505ez4hMH4iR3fvD3w+1rGKtrNYCBrvagqUSZ2fBF3k6tG\nTQfzNswoGiSrLAkrMZ+N8qjkC/hdQNj4t48uKzEUYvcka7x5q2sCAwEAAaN+MHww\nHQYDVR0OBBYEFPCmz0jymFskc2beyFTMGZ8F7ERVME0GA1UdIwRGMESAFPCmz0jy\nmFskc2beyFTMGZ8F7ERVoSGkHzAdMRswGQYDVQQDExJzaGliYm9sZXRoLnVpYy5l\nZHWCCQDJ4dSrGnL1HjAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBY\nWrbjYC+bfwb1gPCchi0vil5x92avIJjQv/AOIT5xp9vmg6km429KXD5BoI32tf7i\nSgmwOllxtLGLE8j7EKZwcVcm3JYo5PIVzWX8yI2q2UpUZKFryoS/KFUoolDN1bNQ\nRnrLeO1Pwy7i93H8mnLGBa/S0+pcjEitKdC+VGEw+i+ZVVBCZMsyggzLK8KIrJPr\nI7vNFfld6a9DYkGUK59mwUwfVU1syUk0Eht25bNa4wKkWGf4OYV83x36xWMyN2Yy\n9fvlUHzM13HdEFvfPytJ2z1wpDUVZaGJ5LWb13cSpTZ2yEyllrRW8we9Paoac8js\nEj+l4a6PybN1ttx/R08j"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://shibboleth.uic.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Illinois at Chicago"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uic.edu/index.html/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Illinois at Chicago"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso.vgtu.lt/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Savin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso@vgtu.lt"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pylyp"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.vgtu.lt/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://fedi.litnet.lt/en/policy"
              },
              {
                "lang": "lt",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://fedi.litnet.lt/lt/informacija/tvarka"
              }
            ],
            "registration_instant": "2013-10-15T07:19:00Z",
            "registration_authority": "https://fedi.litnet.lt",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.vgtu.lt/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.vgtu.lt/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vgtu.lt"
              },
              {
                "description": [
                  {
                    "lang": "lt",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "VGTU vieningas prisijungimas"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "VGTU SSO"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Vilnius Gediminas Technical University"
                  },
                  {
                    "lang": "lt",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Vilniaus Gedimino technikos universitetas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "vgtu.lt"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:54.722310,25.335782"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "158.129.192.0/19"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "158.129.224.0/20"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:778:6204::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID2TCCAsGgAwIBAgIJAJxLaKaVPb80MA0GCSqGSIb3DQEBBQUAMIGCMQswCQYD\nVQQGEwJMVDEQMA4GA1UECAwHVmlsbml1czEQMA4GA1UEBwwHVmlsbml1czENMAsG\nA1UECgwEVkdUVTELMAkGA1UECwwCSVQxFDASBgNVBAMMC3Nzby52Z3R1Lmx0MR0w\nGwYJKoZIhvcNAQkBFg5maWxzYXZAdmd0dS5sdDAeFw0xMzAzMDUxMDU3NDRaFw0y\nMzAzMDUxMDU3NDRaMIGCMQswCQYDVQQGEwJMVDEQMA4GA1UECAwHVmlsbml1czEQ\nMA4GA1UEBwwHVmlsbml1czENMAsGA1UECgwEVkdUVTELMAkGA1UECwwCSVQxFDAS\nBgNVBAMMC3Nzby52Z3R1Lmx0MR0wGwYJKoZIhvcNAQkBFg5maWxzYXZAdmd0dS5s\ndDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANPBRmQdW7yE6Ob47RS6\n3wc6eamLrbcZ8d3BHbkTKOg3zvty9kNGlsRHKJKaTxZJHxxJeGyFK7wD1T7esm6H\n4xlGd/vPkJ8BiJGaYFt+z6AK0U/C24lAUTBme0XE12kVhR2Ld+AbocdKbgRvkQDs\n2nupi8bT8GrcLPqEVNfrEcuoWPR0VDrn+cc9eQWsnwAi6vqPNG9BP+tXun1mKRNj\nLwe7xpIU2dEt4kNNvHKHzbuqMOePvURsMLYWM0GiLA5qMXU/plsgEva09gSONJqU\no5PiF5CkcFZqyyJNKznIAZnLuFWJR7a3G4ArQ0BEuGzv7nchzVf+ffdClMlYOflW\nas0CAwEAAaNQME4wHQYDVR0OBBYEFHaPCulJCIz/U1G0e7fraytboJPGMB8GA1Ud\nIwQYMBaAFHaPCulJCIz/U1G0e7fraytboJPGMAwGA1UdEwQFMAMBAf8wDQYJKoZI\nhvcNAQEFBQADggEBACoR6yldDCdkFwAM/UvbmAAhYizDFszWNi53//exw4Q7LYFF\nExl7h6jjnZphO8/JpYBQ8gqthhEyQe1QRs/3ZBkWJC6mhUu9V6pv/n+10wPew8fm\n2W6FIgprTmjfz98BCff/Bk7SAqssJRGSKKmgqetMcBXQDEcAQ9i1RpFK/j51mQ6+\nynBRvynN0wpAGbKYnKlH4nZhe9DDhKO+P9MDMzbDrTudjZViRUXYxY0Ay8Kfm3Tg\njL+Yw8/LGhSXO0k9XfCcLVC+e+4YQEUOCQNgOPDRKmZH/jntqXmfY0Dtak0612n8\nRmJzwybPFyeNY+yeZhb+XEWT9uwq3YM7Zl85YSg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID2TCCAsGgAwIBAgIJAJxLaKaVPb80MA0GCSqGSIb3DQEBBQUAMIGCMQswCQYD\nVQQGEwJMVDEQMA4GA1UECAwHVmlsbml1czEQMA4GA1UEBwwHVmlsbml1czENMAsG\nA1UECgwEVkdUVTELMAkGA1UECwwCSVQxFDASBgNVBAMMC3Nzby52Z3R1Lmx0MR0w\nGwYJKoZIhvcNAQkBFg5maWxzYXZAdmd0dS5sdDAeFw0xMzAzMDUxMDU3NDRaFw0y\nMzAzMDUxMDU3NDRaMIGCMQswCQYDVQQGEwJMVDEQMA4GA1UECAwHVmlsbml1czEQ\nMA4GA1UEBwwHVmlsbml1czENMAsGA1UECgwEVkdUVTELMAkGA1UECwwCSVQxFDAS\nBgNVBAMMC3Nzby52Z3R1Lmx0MR0wGwYJKoZIhvcNAQkBFg5maWxzYXZAdmd0dS5s\ndDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANPBRmQdW7yE6Ob47RS6\n3wc6eamLrbcZ8d3BHbkTKOg3zvty9kNGlsRHKJKaTxZJHxxJeGyFK7wD1T7esm6H\n4xlGd/vPkJ8BiJGaYFt+z6AK0U/C24lAUTBme0XE12kVhR2Ld+AbocdKbgRvkQDs\n2nupi8bT8GrcLPqEVNfrEcuoWPR0VDrn+cc9eQWsnwAi6vqPNG9BP+tXun1mKRNj\nLwe7xpIU2dEt4kNNvHKHzbuqMOePvURsMLYWM0GiLA5qMXU/plsgEva09gSONJqU\no5PiF5CkcFZqyyJNKznIAZnLuFWJR7a3G4ArQ0BEuGzv7nchzVf+ffdClMlYOflW\nas0CAwEAAaNQME4wHQYDVR0OBBYEFHaPCulJCIz/U1G0e7fraytboJPGMB8GA1Ud\nIwQYMBaAFHaPCulJCIz/U1G0e7fraytboJPGMAwGA1UdEwQFMAMBAf8wDQYJKoZI\nhvcNAQEFBQADggEBACoR6yldDCdkFwAM/UvbmAAhYizDFszWNi53//exw4Q7LYFF\nExl7h6jjnZphO8/JpYBQ8gqthhEyQe1QRs/3ZBkWJC6mhUu9V6pv/n+10wPew8fm\n2W6FIgprTmjfz98BCff/Bk7SAqssJRGSKKmgqetMcBXQDEcAQ9i1RpFK/j51mQ6+\nynBRvynN0wpAGbKYnKlH4nZhe9DDhKO+P9MDMzbDrTudjZViRUXYxY0Ay8Kfm3Tg\njL+Yw8/LGhSXO0k9XfCcLVC+e+4YQEUOCQNgOPDRKmZH/jntqXmfY0Dtak0612n8\nRmJzwybPFyeNY+yeZhb+XEWT9uwq3YM7Zl85YSg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "lt",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Vilniaus Gedimino technikos universitetas"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Vilnius Gediminas Technical University"
          }
        ],
        "organization_url": [
          {
            "lang": "lt",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vgtu.lt"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vgtu.lt/index.php?lang=2"
          }
        ],
        "organization_name": [
          {
            "lang": "lt",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Vilniaus Gedimino technikos universitetas"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Vilnius Gediminas Technical University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://livesrv.ex.vr.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Robert Chrudina"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:robert.chrudina@tieto.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://livesrv.ex.vr.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAKrFALRGt/sXrJc+5j0adTu2M0/4MA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEGxpdmVzcnYuZXgudnIuc2UwHhcNMTExMDExMDkwNjI1\nWhcNMzExMDExMDkwNjI1WjAbMRkwFwYDVQQDExBsaXZlc3J2LmV4LnZyLnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnXd832CJ92pEWl9agbHgE+yc\nzLwonOox29ZXk9x68vd5+n+36bO1gkb4dg+8xgHR3WqXOUwVajMWtUkhH7YN1dq2\nh8JzOQ20oTTfJQi13uzL+uyfu3Z+X1mAnxfAz8wr1IjRLBfjgCiyii87/TcpEZBl\nlT8p6W3E8hiB8Qdbd7FJf52q6y4nRikMlYK0JMAg9v9SvQPZoSd0Fift5Mt92Tes\n73vmimu0FK/2AkvDw7ANTV1YfuyFYUgZ6koRe1gO3JUFIKYXMgovUh2Gy9VjxW0h\n/YeOxgGUb8sC33VHDUd03oB90XcSdih+KaSxkw6gWUyuQZ9GvnzfYPpj2nblCQID\nAQABo2cwZTBEBgNVHREEPTA7ghBsaXZlc3J2LmV4LnZyLnNlhidodHRwczovL2xp\ndmVzcnYuZXgudnIuc2UvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFKHqhiJr9a82\nJ7vvd4BcjZn84W0qMA0GCSqGSIb3DQEBBQUAA4IBAQBpzAB/oEEbx4Hnbd9H+B/U\nZkIrKc9RNnz76jr0EHVGma3iy7EeueJLdgEBgmwvYrzl5dyWSLrdw/sXBsuer7wM\nFeegMJozSv56MrpSoAODBsCeyrmldFGqRzBu5KjF9/MVRpwBqXEZnDEPe4gDKP+b\nJdxMfnBNi8mPEIZK/cAPcdnNYatIvWFzrvcGfLwUlJvEPt3FVPxibY8rMqS0v4vl\nE829C4X5CIQjd4L9PA+L4s+/jp4zrJsyouvLGs2IQqTQYQYPajUoql2GT7w+NUju\n7yrPHZ1JX3HLDgrZHMW5EZ5df29H0UA1YU9mTvpo3CCy3fzJINtdT5JRBXtEqudj"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vr.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://livesrv.ex.vr.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://livesrv.ex.vr.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://livesrv.ex.vr.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://livesrv.ex.vr.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://livesrv.ex.vr.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://livesrv.ex.vr.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://livesrv.ex.vr.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://livesrv.ex.vr.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vr.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAKrFALRGt/sXrJc+5j0adTu2M0/4MA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEGxpdmVzcnYuZXgudnIuc2UwHhcNMTExMDExMDkwNjI1\nWhcNMzExMDExMDkwNjI1WjAbMRkwFwYDVQQDExBsaXZlc3J2LmV4LnZyLnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnXd832CJ92pEWl9agbHgE+yc\nzLwonOox29ZXk9x68vd5+n+36bO1gkb4dg+8xgHR3WqXOUwVajMWtUkhH7YN1dq2\nh8JzOQ20oTTfJQi13uzL+uyfu3Z+X1mAnxfAz8wr1IjRLBfjgCiyii87/TcpEZBl\nlT8p6W3E8hiB8Qdbd7FJf52q6y4nRikMlYK0JMAg9v9SvQPZoSd0Fift5Mt92Tes\n73vmimu0FK/2AkvDw7ANTV1YfuyFYUgZ6koRe1gO3JUFIKYXMgovUh2Gy9VjxW0h\n/YeOxgGUb8sC33VHDUd03oB90XcSdih+KaSxkw6gWUyuQZ9GvnzfYPpj2nblCQID\nAQABo2cwZTBEBgNVHREEPTA7ghBsaXZlc3J2LmV4LnZyLnNlhidodHRwczovL2xp\ndmVzcnYuZXgudnIuc2UvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFKHqhiJr9a82\nJ7vvd4BcjZn84W0qMA0GCSqGSIb3DQEBBQUAA4IBAQBpzAB/oEEbx4Hnbd9H+B/U\nZkIrKc9RNnz76jr0EHVGma3iy7EeueJLdgEBgmwvYrzl5dyWSLrdw/sXBsuer7wM\nFeegMJozSv56MrpSoAODBsCeyrmldFGqRzBu5KjF9/MVRpwBqXEZnDEPe4gDKP+b\nJdxMfnBNi8mPEIZK/cAPcdnNYatIvWFzrvcGfLwUlJvEPt3FVPxibY8rMqS0v4vl\nE829C4X5CIQjd4L9PA+L4s+/jp4zrJsyouvLGs2IQqTQYQYPajUoql2GT7w+NUju\n7yrPHZ1JX3HLDgrZHMW5EZ5df29H0UA1YU9mTvpo3CCy3fzJINtdT5JRBXtEqudj"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Vetenskapsr\u00e5det"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Vetenskapsr\u00e5det"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vr.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "VR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-demo-p02.its.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-demo-p02.its.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-p02.its.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-p02.its.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-p02.its.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-p02.its.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-p02.its.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-demo-p02.its.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-demo-p02.its.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;demo-p02"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;demo-p02"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-demo-p02.its.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-demo-p02.its.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTjCCAjagAwIBAgIJAPCiY3IS8HVbMA0GCSqGSIb3DQEBBQUAMCUxIzAhBgNV\nBAMTGmxhZG9rMy1kZW1vLXAwMi5pdHMudW11LnNlMB4XDTE1MDIxNjExNDk1MFoX\nDTI1MDIxMzExNDk1MFowJTEjMCEGA1UEAxMabGFkb2szLWRlbW8tcDAyLml0cy51\nbXUuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDS+FfC2UkbJdtC\nazgygjVbWrdTV0m+eSjTi5VfheP0WWJe9dWRy8j3n//aqlPkj60gDsSrkWi/rtby\n19+rDfTWpCWD3h1D70ux3yMs1KWvIbZQlHsu/HLbizeS/rhF/AEKPNJsk4U/v8SW\nwOGqu9M4bkXuFxQSvZlPdRhkOdWXlKYmlhlLo85xv9yVJjvuxv+zxGXQaP5vFB83\njNqP5HalZmb8rOkLwp5CVlamvSt2LSU4jwllkGSLRpfBMN4A3v4geBh7E8wkdqvH\n3/Q1ab5n2m5wlgDyIbO11XtKrU13vJfGECuTXbD7MUuGcY2yL9YbjRbdSS72Iizm\nVaXy/GOlAgMBAAGjgYAwfjBdBgNVHREEVjBUghpsYWRvazMtZGVtby1wMDIuaXRz\nLnVtdS5zZYY2aHR0cHM6Ly9sYWRvazMtZGVtby1wMDIuaXRzLnVtdS5zZS9zdHVk\nZW50LWZyb250ZW5kLXNwMB0GA1UdDgQWBBQzAAruFz9ub6BSvXemvLpUrz3TPTAN\nBgkqhkiG9w0BAQUFAAOCAQEAzOD0qVApYCrFimtnVsdMNNzMp6aVvIkFiilEFi2O\npXJP0lVDEqkKAjGVXCaGPDjh440cV7cti8J3ZRzGiBQnpzVn/Er8HlvSgZR1Ycna\nsA2B9+PSOdUGhmUs7Ec9d8g0f2Zc5OTMgcAA9rHD+YHpjc8IScJ1XJqprTO3Yy8l\nz09kl0PlaF9QVykdg9seYN96Iyycld5uxQhEOWlFd6dHkXY59yfhza/R7FwoeMew\nuDWwlfOf6tW1J+ovIM43YkXE4KbwIUhiwdPR1oSnkUn3+4naKYwC/eB9qsN8B38B\nPgRf9awC3vDMvS6jY6AqIn9r2KPVqV4TWqBvYG0ARJrG+Q=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-demo-p02.its.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-p02.its.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-p02.its.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-p02.its.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-p02.its.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-p02.its.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-p02.its.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-demo-p02.its.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-demo-p02.its.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-demo-p02.its.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:incommon:tamu.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "unix-admin@tamu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Xavier Chapa"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "unix-admin@tamu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Xavier Chapa"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tgolson@tamu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Thomas Golson"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tgolson@tamu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Thomas Golson"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:tamu.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.tamu.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.tamu.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFHzCCBAegAwIBAgICAM0wDQYJKoZIhvcNAQEFBQAwgbQxMDAuBgNVBAMTJ1Rl\neGFzIEEgYW5kIE0gVW5pdmVyc2l0eSBPcGVuU3lzdGVtcyBDQTELMAkGA1UEBhMC\nVVMxDjAMBgNVBAgTBVRleGFzMRgwFgYDVQQHEw9Db2xsZWdlIFN0YXRpb24xITAf\nBgNVBAoTGFRleGFzIEEgYW5kIE0gVW5pdmVyc2l0eTEmMCQGCSqGSIb3DQEJARYX\ndW5peC1lbmdpbmVlcnNAdGFtdS5lZHUwHhcNMTMwMjE4MTYyNDQ3WhcNMTcwMjE3\nMTYyNDQ3WjCBqTELMAkGA1UEBhMCVVMxDjAMBgNVBAgTBVRleGFzMSEwHwYDVQQK\nExhUZXhhcyBBIGFuZCBNIFVuaXZlcnNpdHkxKzApBgNVBAsTIkNvbXB1dGluZyBh\nbmQgSW5mb3JtYXRpb24gU2VydmljZXMxFTATBgNVBAMTDGlkcC50YW11LmVkdTEj\nMCEGCSqGSIb3DQEJARYUdW5peC1hZG1pbnNAdGFtdS5lZHUwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDLXA+lr+iaQoWFlPXZ/dpgU02YNVyvoKwhEmkx\nZ4w115hYWd8lNpVSay7cuiWaDRLeyDPKRc44pVseI6VQEfxDDTvbtFZ1y50/Ebmu\n3hd+hXKCnMhfx2yey3A1wBPyVPNPjXyRzS6vnRO0qh5jF8LHltHCO1zJcnZVVvin\nQJCwsaO3gVr0qeLZizRxpzPUuG0jLgquIw5qHaIDizUGU/jwBXhFtjlBNc84nFr1\nOKOsrP1ueEoqYRMrXtLoMJO+UUKm9etohB4b+IPGsFk6RxerEtvFl5i1qmHg4aF+\ncLAqLw01khAMCF+P1a3P7Q4wxnFJlC/ZlI1P1D5AeVUt5sJFAgMBAAGjggFCMIIB\nPjAJBgNVHRMEAjAAMB0GA1UdDgQWBBSfnAZqaUuadGj4HzAppnUyO62NsTCB4QYD\nVR0jBIHZMIHWgBRLzeA92ieIxqAcIsb5RhD8f5GT56GBuqSBtzCBtDEwMC4GA1UE\nAxMnVGV4YXMgQSBhbmQgTSBVbml2ZXJzaXR5IE9wZW5TeXN0ZW1zIENBMQswCQYD\nVQQGEwJVUzEOMAwGA1UECBMFVGV4YXMxGDAWBgNVBAcTD0NvbGxlZ2UgU3RhdGlv\nbjEhMB8GA1UEChMYVGV4YXMgQSBhbmQgTSBVbml2ZXJzaXR5MSYwJAYJKoZIhvcN\nAQkBFhd1bml4LWVuZ2luZWVyc0B0YW11LmVkdYIBADAuBglghkgBhvhCAQQEIRYf\naHR0cHM6Ly93d3cudGFtdS5lZHUvY2EtY3JsLnBlbTANBgkqhkiG9w0BAQUFAAOC\nAQEARKaoqJ/EjPOponWaTYQW1VdypIdzQpBm82oHcjdz7/sXW+wFfu4UsmVFBQLL\nXkfMTyG0WNv1BKykI92ncUt9Py3tfmVx07IeZoyrJFBxvrGgI4AyoxiyDuwsXGox\ndeGefFdCjJwEavxdjHp2u7oLZI9C02JXBLiEqhAzXwJZqSOB7FRDeiFKlpxuZ0EL\nn6ynZa0trJl8dOzuRr7KcJYA77fYlce8yxQpeStvuGECneHFLwOdzm4ijqJOKhn6\n/T7yIyJS/3kH2Abpfri1MULpvY+Y+GxJj6tgG5akFDw1WLvG2lWViEsACWBVZGw5\nHEC94c/SIH+rUVVS/RftJxbjFQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tamu.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.tamu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.tamu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.tamu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.tamu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.tamu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tamu.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://infrastructure.tamu.edu/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://infrastructure.tamu.edu/images/TAM-PrimaryMarkA.png",
                    "lang": "en",
                    "height": "400",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Texas A & M University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFHzCCBAegAwIBAgICAM0wDQYJKoZIhvcNAQEFBQAwgbQxMDAuBgNVBAMTJ1Rl\neGFzIEEgYW5kIE0gVW5pdmVyc2l0eSBPcGVuU3lzdGVtcyBDQTELMAkGA1UEBhMC\nVVMxDjAMBgNVBAgTBVRleGFzMRgwFgYDVQQHEw9Db2xsZWdlIFN0YXRpb24xITAf\nBgNVBAoTGFRleGFzIEEgYW5kIE0gVW5pdmVyc2l0eTEmMCQGCSqGSIb3DQEJARYX\ndW5peC1lbmdpbmVlcnNAdGFtdS5lZHUwHhcNMTMwMjE4MTYyNDQ3WhcNMTcwMjE3\nMTYyNDQ3WjCBqTELMAkGA1UEBhMCVVMxDjAMBgNVBAgTBVRleGFzMSEwHwYDVQQK\nExhUZXhhcyBBIGFuZCBNIFVuaXZlcnNpdHkxKzApBgNVBAsTIkNvbXB1dGluZyBh\nbmQgSW5mb3JtYXRpb24gU2VydmljZXMxFTATBgNVBAMTDGlkcC50YW11LmVkdTEj\nMCEGCSqGSIb3DQEJARYUdW5peC1hZG1pbnNAdGFtdS5lZHUwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDLXA+lr+iaQoWFlPXZ/dpgU02YNVyvoKwhEmkx\nZ4w115hYWd8lNpVSay7cuiWaDRLeyDPKRc44pVseI6VQEfxDDTvbtFZ1y50/Ebmu\n3hd+hXKCnMhfx2yey3A1wBPyVPNPjXyRzS6vnRO0qh5jF8LHltHCO1zJcnZVVvin\nQJCwsaO3gVr0qeLZizRxpzPUuG0jLgquIw5qHaIDizUGU/jwBXhFtjlBNc84nFr1\nOKOsrP1ueEoqYRMrXtLoMJO+UUKm9etohB4b+IPGsFk6RxerEtvFl5i1qmHg4aF+\ncLAqLw01khAMCF+P1a3P7Q4wxnFJlC/ZlI1P1D5AeVUt5sJFAgMBAAGjggFCMIIB\nPjAJBgNVHRMEAjAAMB0GA1UdDgQWBBSfnAZqaUuadGj4HzAppnUyO62NsTCB4QYD\nVR0jBIHZMIHWgBRLzeA92ieIxqAcIsb5RhD8f5GT56GBuqSBtzCBtDEwMC4GA1UE\nAxMnVGV4YXMgQSBhbmQgTSBVbml2ZXJzaXR5IE9wZW5TeXN0ZW1zIENBMQswCQYD\nVQQGEwJVUzEOMAwGA1UECBMFVGV4YXMxGDAWBgNVBAcTD0NvbGxlZ2UgU3RhdGlv\nbjEhMB8GA1UEChMYVGV4YXMgQSBhbmQgTSBVbml2ZXJzaXR5MSYwJAYJKoZIhvcN\nAQkBFhd1bml4LWVuZ2luZWVyc0B0YW11LmVkdYIBADAuBglghkgBhvhCAQQEIRYf\naHR0cHM6Ly93d3cudGFtdS5lZHUvY2EtY3JsLnBlbTANBgkqhkiG9w0BAQUFAAOC\nAQEARKaoqJ/EjPOponWaTYQW1VdypIdzQpBm82oHcjdz7/sXW+wFfu4UsmVFBQLL\nXkfMTyG0WNv1BKykI92ncUt9Py3tfmVx07IeZoyrJFBxvrGgI4AyoxiyDuwsXGox\ndeGefFdCjJwEavxdjHp2u7oLZI9C02JXBLiEqhAzXwJZqSOB7FRDeiFKlpxuZ0EL\nn6ynZa0trJl8dOzuRr7KcJYA77fYlce8yxQpeStvuGECneHFLwOdzm4ijqJOKhn6\n/T7yIyJS/3kH2Abpfri1MULpvY+Y+GxJj6tgG5akFDw1WLvG2lWViEsACWBVZGw5\nHEC94c/SIH+rUVVS/RftJxbjFQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Texas A & M University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tamu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Texas A & M University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://jira-test.it.su.se/Shibboleth.sso",
    {
      "entity_id": "https://jira-test.it.su.se/Shibboleth.sso",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jira-test.it.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://jira-test.it.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jira-test.it.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://jira-test.it.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jira-test.it.su.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://jira-test.it.su.se/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://jira-test.it.su.se/Shibboleth.sso/WAYF/wavelan",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "jira-test-app1"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJALGCNK9nNxZDMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDmppcmEtdGVzdC1hcHAxMB4XDTEwMDgyNjEyMzI1MloXDTIwMDgyMzEyMzI1\nMlowGTEXMBUGA1UEAxMOamlyYS10ZXN0LWFwcDEwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDO4PWB2RnZzDupQuf0rCArOypgHuDgHZxndiGjGQz80v2N\n3eYm7nPaJC9pTMZX8p6zhYw1CPRn+Gi8u53gRZKT2i7+drIBBHZPc1spTYLM4sUZ\nNlLWpaGfGLkRFfbq518xL6HGRRVmMcZlSAERhht6AqOxbfgoK88dihomUEnX4ANE\nwLbBJPHg/tERZnqjlwLF+Ftbpk9+Gfq9X7A5FSKo7Za+j6Puk1EzzzxqdmN60Jlf\nF9/T9eQh7zw3pJUKemh7/wp4zkNwkp7iyOhq1389QqUDFx74hZOQjFB60lm0z/Vp\nHFgq0nlvHOGE2cpTcq6MmFT3r8RFpTzft00y2QENAgMBAAGjPDA6MBkGA1UdEQQS\nMBCCDmppcmEtdGVzdC1hcHAxMB0GA1UdDgQWBBSL7ZJAZ3DDSKpgRMGXwhP9aNbZ\n7zANBgkqhkiG9w0BAQUFAAOCAQEAJtgLdreha5LTqtjQgQuXu+2l3iT2tHS0oX0I\nZKcL+r2e3eSBY/r2maj4rI2y727zBQblf+slQBe0mAbBV0EGycgUiibukAQpIAze\n2I2EgrGBuWkFJJPGi71fOwiZFBJpHO2fSHc5wxEhgipRJrC4Es4TjZ2d2VbpAIC/\nzVshHJgtGbOSJmyi3OOih0YSwWX6sGWPNHEb7jKmfadfLreVEG30bVUDtxKy5tZA\nI0v8p/Tq2BIBdK6rTSh/5u2UVR52qJLh8Y7/+HG8DukTaEHWtPmLbuR3NZ2mWgdn\nSKTYQay0lG3RNe7C3dTRD2RvZznqpkhRVqNqWJHGdfuP4uiVfQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=jira-test-app1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "jira-test-app1"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJALGCNK9nNxZDMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDmppcmEtdGVzdC1hcHAxMB4XDTEwMDgyNjEyMzI1MloXDTIwMDgyMzEyMzI1\nMlowGTEXMBUGA1UEAxMOamlyYS10ZXN0LWFwcDEwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDO4PWB2RnZzDupQuf0rCArOypgHuDgHZxndiGjGQz80v2N\n3eYm7nPaJC9pTMZX8p6zhYw1CPRn+Gi8u53gRZKT2i7+drIBBHZPc1spTYLM4sUZ\nNlLWpaGfGLkRFfbq518xL6HGRRVmMcZlSAERhht6AqOxbfgoK88dihomUEnX4ANE\nwLbBJPHg/tERZnqjlwLF+Ftbpk9+Gfq9X7A5FSKo7Za+j6Puk1EzzzxqdmN60Jlf\nF9/T9eQh7zw3pJUKemh7/wp4zkNwkp7iyOhq1389QqUDFx74hZOQjFB60lm0z/Vp\nHFgq0nlvHOGE2cpTcq6MmFT3r8RFpTzft00y2QENAgMBAAGjPDA6MBkGA1UdEQQS\nMBCCDmppcmEtdGVzdC1hcHAxMB0GA1UdDgQWBBSL7ZJAZ3DDSKpgRMGXwhP9aNbZ\n7zANBgkqhkiG9w0BAQUFAAOCAQEAJtgLdreha5LTqtjQgQuXu+2l3iT2tHS0oX0I\nZKcL+r2e3eSBY/r2maj4rI2y727zBQblf+slQBe0mAbBV0EGycgUiibukAQpIAze\n2I2EgrGBuWkFJJPGi71fOwiZFBJpHO2fSHc5wxEhgipRJrC4Es4TjZ2d2VbpAIC/\nzVshHJgtGbOSJmyi3OOih0YSwWX6sGWPNHEb7jKmfadfLreVEG30bVUDtxKy5tZA\nI0v8p/Tq2BIBdK6rTSh/5u2UVR52qJLh8Y7/+HG8DukTaEHWtPmLbuR3NZ2mWgdn\nSKTYQay0lG3RNe7C3dTRD2RvZznqpkhRVqNqWJHGdfuP4uiVfQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=jira-test-app1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jira-test.it.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://jira-test.it.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jira-test.it.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://jira-test.it.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://jira-test.it.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://jira-test.it.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jira-test.it.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://jira-test.it.su.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://jira-test.it.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://jira-test.it.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.nrcresearchpress.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.nrcresearchpress.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Atypon Systems: NRC Research Press"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nrcresearchpress.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDtTCCAp2gAwIBAgIJALKKItp/j602MA0GCSqGSIb3DQEBBQUAMIGZMQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEUMBIGA1UEBxMLU2FudGEgQ2xh\n\t\t\t\t\t\tcmExHTAbBgNVBAoTFEF0eXBvbiBTeXN0ZW1zLCBJbmMuMR0wGwYDVQQLExRBdHlw\n\t\t\t\t\t\tb24gU3lzdGVtcywgSW5jLjEhMB8GA1UEAxMYd3d3Lm5yY3Jlc2VhcmNocHJlc3Mu\n\t\t\t\t\t\tY29tMB4XDTExMDExODIyMTkyOFoXDTIxMDExNTIyMTkyOFowgZkxCzAJBgNVBAYT\n\t\t\t\t\t\tAlVTMRMwEQYDVQQIEwpDYWxpZm9ybmlhMRQwEgYDVQQHEwtTYW50YSBDbGFyYTEd\n\t\t\t\t\t\tMBsGA1UEChMUQXR5cG9uIFN5c3RlbXMsIEluYy4xHTAbBgNVBAsTFEF0eXBvbiBT\n\t\t\t\t\t\teXN0ZW1zLCBJbmMuMSEwHwYDVQQDExh3d3cubnJjcmVzZWFyY2hwcmVzcy5jb20w\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDcz5rmUAuG5ucWJq6TAKiy\n\t\t\t\t\t\tjdkO5jrOKk+rUFbtvHqCdEy0ndFUraE+sQO4zuRabXKzI6p7sF090VqDi9NZ4Zq0\n\t\t\t\t\t\tuK2m6Wuwkzr5DRstBamZXzUZdFZ/NOQxFIQbhx+ZNVx02IlK89CZmzRzaczqgwtd\n\t\t\t\t\t\tj0IPZY2SpWeZuRfFZ0H6IBI/I5rL+HaokTdZaYgRUasqu7HFdKquN369iP7Qqe7l\n\t\t\t\t\t\tYhm9XtVnEMLsHuPy1gNkyOddLdHKt9oKzKkql7IkhcGbE/f4YrKIqxC5SvdSE9cg\n\t\t\t\t\t\tih+IO/OAyHn+cS0LqNCECRbdnViUgUaSr5/s9FXTTMsEMtJtgZQyEzGW9B9omLhJ\n\t\t\t\t\t\tAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBADcSQSrkKZG/QL6LSKSG8rKB0BxWNFvO\n\t\t\t\t\t\t3mEBndEEsioTZzPGzSfuMcEDdICWyILaXN7HraUkTCvSD1N9n/AS8uu+jCoe+f8z\n\t\t\t\t\t\tcV3f15LjxYyZI9ZmO9eixGA2huK2LsRzAj93TWYK7Q0CuZrTq/3J/vJ+xvM2habG\n\t\t\t\t\t\tPToSEnpA/ALGVSXSxGpLJYn84qX9ub0yX1yYNmleylRkHqFwYHvdU5Hk7UZdrCKZ\n\t\t\t\t\t\tvMIejpaSZn0yf3ZFn8eebCpLnlVN0FLNCgel39FLMGqNbey0wpFbzocv4fvX6pmi\n\t\t\t\t\t\tBz9FTGLHvLqpoRV/zghBPM32BhT8U6PJfC56HlfNfbRtx9nHZK2GfJw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.nrcresearchpress.com/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.nrcresearchpress.com/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.nrcresearchpress.com/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.login.amdigital.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Porritt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:glyn@amdigital.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Glyn"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Arthur"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dave@amdigital.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dave"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.login.amdigital.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-12-04T15:40:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Adam Matthew resources"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.amdigital.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Adam Matthew Digital Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.login.amdigital.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.login.amdigital.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.login.amdigital.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.login.amdigital.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.login.amdigital.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.login.amdigital.co.uk/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.login.amdigital.co.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.login.amdigital.co.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Unique primary source collections from archives around the world; spanning the social sciences and humanities"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.login.amdigital.co.uk/images/MDUI-logo.png",
                    "height": "132",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "286"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Adam Matthew resources"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIJAOnoeaY+22sjMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\n\t\t\t\t\t\tBAMTGXd3dy5sb2dpbi5hbWRpZ2l0YWwuY28udWswHhcNMTMxMTIwMTYyNzE4WhcN\n\t\t\t\t\t\tMTgxMTE5MTYyNzE4WjAkMSIwIAYDVQQDExl3d3cubG9naW4uYW1kaWdpdGFsLmNv\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAwXZuSpA1eklgnNFN\n\t\t\t\t\t\t7cYjfzOg87Q4W87KhDui8HmowwT+tBRV9aK9RNFOHUmZKmatrb21961DakpvyFqo\n\t\t\t\t\t\ti4y2PgCK9x5tcP5z0stQCiJXz/GT7Nm4mqxCS9klruJJYkzIQENLo1gClAGDPejq\n\t\t\t\t\t\t0yuxrRn0X0V+kkjmJfhtj6a4vQsQiI1YxLNfPWRcUq+aY5R5J2hOBduYRn13+6q3\n\t\t\t\t\t\toLGGY2kEzTwngPz4m1PqNKNCmb4yh5XUTXpgezUIdUOqU5lJ37yZKI3eyxZ67hV7\n\t\t\t\t\t\tbeQWNq8YM+Mtc9ixQ0MXQw/U0uxc44OtwbJwh01oyS/d2A4LDrDltJL+RlUXtzcc\n\t\t\t\t\t\t4+loHQIDAQABo3UwczBSBgNVHREESzBJghl3d3cubG9naW4uYW1kaWdpdGFsLmNv\n\t\t\t\t\t\tLnVrhixodHRwczovL3d3dy5sb2dpbi5hbWRpZ2l0YWwuY28udWsvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQUMG4nqf/bwYPBqgWIdiRkXSCtscIwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAHdJJS5QMsr/cP/m+VLjrFCz8Ml6Bi8GUIU2SIUsIC/3/j63XCFlxIsym1rn\n\t\t\t\t\t\tc/dH4eAqTz/LETocV6DNhhn6PaykG4UArmTxwsn3bMweKoEwaRil1RlW4OjIObf4\n\t\t\t\t\t\tVlbw8Tjk9FYykL4G/LzDmdIhv8lneYDJT/F49OTmPr7K9k+JP59l1w49bf8vsZpo\n\t\t\t\t\t\t04zpJsF8r9kckt62qAKuKPins7pqw3o9/MYZtO59VAQkMfdEvUEXKmTgG09PoIFN\n\t\t\t\t\t\tmEeoIiYaNa73mEKJuM5v0mSxz4BZJmjNaUgp+RlXOSf5UajsxGvvaaXPS+wswNNc\n\t\t\t\t\t\tamjS1hLdrKCw7Y9NYB5V297KDVc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.login.amdigital.co.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.login.amdigital.co.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.login.amdigital.co.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.login.amdigital.co.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.login.amdigital.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.login.amdigital.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.login.amdigital.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.login.amdigital.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.login.amdigital.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.login.amdigital.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.parisdescartes.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "adm-fed@parisdescartes.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.parisdescartes.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2011-09-09T17:29:16Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.parisdescartes.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.parisdescartes.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.parisdescartes.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "parisdescartes.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-paris5.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.parisdescartes.fr/"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Paris 5 - Paris Descartes"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Paris 5 - Paris Descartes"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUCeX+1RyxljYfEToWmdNXc2pDXeEwDQYJKoZIhvcNAQEF\nBQAwIDEeMBwGA1UEAxMVaWRwLnBhcmlzZGVzY2FydGVzLmZyMB4XDTExMDcxODA5\nNDAxN1oXDTMxMDcxODA5NDAxN1owIDEeMBwGA1UEAxMVaWRwLnBhcmlzZGVzY2Fy\ndGVzLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApzgVP4bVQvl3\nhlaeglS/rp6q1fosBpoKU/jKxkQICkcK4HchoSD0RVwToWNdM8f8JojRjJmp3TeN\n7Kmdsu2xJEZMfsGa65AoVdhAvcgsNzMfhJ7DU8XkRjxL28bwa7lPOb6oBmWqUvnb\nQbbdy2H3nSjnVTy/9EldAyWETvUfkwsRuC7i7mB2efJmomCLByq3mUrk99qrTgH1\nxucnBhbinTknGsjFgbHokkvwxom4+OQdG+zKZweSN/idCzRPw5zBDffocZ13+z33\nCPkiTPhG/AcDlfya2/P7/VS1Q+C3+H2S/l+gSmLojWPkiTRWNZ/C3WOJPkMNpGM7\naQ8tqXfS3wIDAQABo3EwbzBOBgNVHREERzBFghVpZHAucGFyaXNkZXNjYXJ0ZXMu\nZnKGLGh0dHBzOi8vaWRwLnBhcmlzZGVzY2FydGVzLmZyL2lkcC9zaGliYm9sZXRo\nMB0GA1UdDgQWBBQXUqz0RpnQqx46u1clGA9UWxcPlDANBgkqhkiG9w0BAQUFAAOC\nAQEAYo3b9PwJ6jwuAQPliMg0MSdgmb71MVDmPp3OatPxwWGbOqHUgo3G3x8trtRn\nagcy/HgFnOO47EkdLmNzBjISH1LX9JucHrhEeYKHloviYB3xvq7h0v7hDNZMBWJG\nojtsnvw3I3/6jj6JRcNsp3Qlbi7lsrYlqIPtuzdNR3YcDu+XpBfhl3geqTrCjS2O\n4j7fvgpptJEtZPWF29JmHMc4rLS6NM/2BqRSNkFE1HO8hE0WGg68ffk5+8qb+qGr\nHmjpc9MLvwXTRloHXrKPzQo7qBSID6wZnNC/cArK2ZYK6XiUR5I0AqOI2i5bWSYe\n26qh1S8ToVhwUvbZyVO+SyqjLw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Paris 5 - Paris Descartes"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.parisdescartes.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Paris 5 - Paris Descartes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://fs-elcira-srv01.dir.garr.it/simplesamlphp/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "GARR"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:grid-tech@garr.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Administrator"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://fs-elcira-srv01.dir.garr.it/simplesamlphp/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2014-09-15T12:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "La rete italiana dell'universit\u00e0e della ricerca"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Italian Academic and Research Network"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.garr.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.garr.it/b/eng"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consortium GARR"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consortium GARR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://fs-elcira-srv01.dir.garr.it/simplesamlphp/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://fs-elcira-srv01.dir.garr.it/elcira/index.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://fs-elcira-srv01.dir.garr.it/elcira/index.html"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "FileSender ELCIRA by GARR is a secure way to share big files with everybody!"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "FileSender ELCIRA da GARR \u00e8 un modo sicuro di condividere grossi file con tutti!"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://fs-elcira-srv01.dir.garr.it/elcira/privacy_en.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://fs-elcira-srv01.dir.garr.it/elcira/privacy_it.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Filesender for ELCIRA"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Filesender per ELCIRA"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://primo-login.garrbox.garr.it/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://primo-login.garrbox.garr.it/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIJAO2pE5Vwv7FYMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\nBAMMG2ZzLWVsY2lyYS1zcnYwMS5kaXIuZ2Fyci5pdDAeFw0xNDAxMTYwOTU4MDZa\nFw0zNDAxMTEwOTU4MDZaMCYxJDAiBgNVBAMMG2ZzLWVsY2lyYS1zcnYwMS5kaXIu\nZ2Fyci5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANqr3aW47/9U\nURqjOL6HmX1aZ4+5UGQ/CT0PcYJ2GibpuNms31QIEtm6PqRAQ/r3Qc7V4wDclat2\nww0SfKDT2NxRBah8QagbVxVVwWPFBFu4uvmbehz8jCahq5zia0hBlrR/Y0VgWj0Z\n7HKo7rfUyOhNRU0VxkesatjSqls8e1LxnNHTEM22aLbvrgcwSvX/XvNUclvA+edd\nOzCpWUQb4HJtDFAA0fKmbGueE45vwdvTpyVx1BL2N4PZpsDm5TdTEEr6zsMLtOFX\n+Dq7V9wWTYvILX8i5VaeVnZBH9a1Ou95fy2D+ZDlt+nnDJWo3Wqkr92lvV87oFA+\n0O4TBp4Wx3MCAwEAAaNQME4wHQYDVR0OBBYEFLJde/JWquiDiJENwGPkXggyxJSy\nMB8GA1UdIwQYMBaAFLJde/JWquiDiJENwGPkXggyxJSyMAwGA1UdEwQFMAMBAf8w\nDQYJKoZIhvcNAQEFBQADggEBAL/MIhivMBtcl6mGu2V+JppTsgLfGdrQ7YPBVNr1\n4RKxQjhLUfOY8UXji0aIUHmXXJBRQ3aYtu/n93S5lTMT4iX1bdugLDEL4UWUXgey\n8Ag7LUT8NNXnfoJ5eWcvxX8ijMw1h9I4J9NLosipIOIunRDBvt2YZHqWz6HE6zLk\nPWgsJBLXOn8WzFUQILgE58UNB8FRyszfjwQaMZxbr450A7MLzoocoHruvtyGmU/b\nu+8MvFPZtUgqakjD/z7nC7Xb8sLzvLIl2ImMzcnNvh3w25+kDZiDyhs/HpuLyWp0\nQ1BGI7m2w2Bezwz70P9B1CA26dzfKrAkCDGytwKMtiUwEB4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIJAO2pE5Vwv7FYMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\nBAMMG2ZzLWVsY2lyYS1zcnYwMS5kaXIuZ2Fyci5pdDAeFw0xNDAxMTYwOTU4MDZa\nFw0zNDAxMTEwOTU4MDZaMCYxJDAiBgNVBAMMG2ZzLWVsY2lyYS1zcnYwMS5kaXIu\nZ2Fyci5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANqr3aW47/9U\nURqjOL6HmX1aZ4+5UGQ/CT0PcYJ2GibpuNms31QIEtm6PqRAQ/r3Qc7V4wDclat2\nww0SfKDT2NxRBah8QagbVxVVwWPFBFu4uvmbehz8jCahq5zia0hBlrR/Y0VgWj0Z\n7HKo7rfUyOhNRU0VxkesatjSqls8e1LxnNHTEM22aLbvrgcwSvX/XvNUclvA+edd\nOzCpWUQb4HJtDFAA0fKmbGueE45vwdvTpyVx1BL2N4PZpsDm5TdTEEr6zsMLtOFX\n+Dq7V9wWTYvILX8i5VaeVnZBH9a1Ou95fy2D+ZDlt+nnDJWo3Wqkr92lvV87oFA+\n0O4TBp4Wx3MCAwEAAaNQME4wHQYDVR0OBBYEFLJde/JWquiDiJENwGPkXggyxJSy\nMB8GA1UdIwQYMBaAFLJde/JWquiDiJENwGPkXggyxJSyMAwGA1UdEwQFMAMBAf8w\nDQYJKoZIhvcNAQEFBQADggEBAL/MIhivMBtcl6mGu2V+JppTsgLfGdrQ7YPBVNr1\n4RKxQjhLUfOY8UXji0aIUHmXXJBRQ3aYtu/n93S5lTMT4iX1bdugLDEL4UWUXgey\n8Ag7LUT8NNXnfoJ5eWcvxX8ijMw1h9I4J9NLosipIOIunRDBvt2YZHqWz6HE6zLk\nPWgsJBLXOn8WzFUQILgE58UNB8FRyszfjwQaMZxbr450A7MLzoocoHruvtyGmU/b\nu+8MvFPZtUgqakjD/z7nC7Xb8sLzvLIl2ImMzcnNvh3w25+kDZiDyhs/HpuLyWp0\nQ1BGI7m2w2Bezwz70P9B1CA26dzfKrAkCDGytwKMtiUwEB4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://fs-elcira-srv01.dir.garr.it/simplesamlphp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://fs-elcira-srv01.dir.garr.it/simplesamlphp/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://fs-elcira-srv01.dir.garr.it/simplesamlphp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://fs-elcira-srv01.dir.garr.it/simplesamlphp/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Filesender erogato da GARR per il progetto ELCIRA"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Filesender provided by GARR for the ELCIRA project"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "uid",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.edina.ac.uk/shibboleth/mediahub",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:edina@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EDINA Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Soares"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ben.soares@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ben"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.edina.ac.uk/shibboleth/mediahub",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Edinburgh: EDINA Mediahub"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://edina.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vsp2.edina.ac.uk/mediahub/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vsp2.edina.ac.uk/mediahub/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vsp2.edina.ac.uk/mediahub/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vsp2.edina.ac.uk/mediahub/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vsp2.edina.ac.uk/mediahub/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The definitive academic video, image & audio resource"
                  }
                ],
                "logo": [
                  {
                    "text": "https://auth.edina.ac.uk/public/images/splogos/mediahub.png",
                    "height": "84",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "JISC MediaHub"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIESDCCAzCgAwIBAgIJAKrBnZO7TvNTMA0GCSqGSIb3DQEBBQUAMIGkMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjERMA8GA1UECBMIU2NvdGxhbmQxEjAQBgNVBAcTCUVkaW5idXJnaDEk\n\t\t\t\t\t\tMCIGA1UEChMbVGhlIFVuaXZlcnNpdHkgb2YgRWRpbmJ1cmdoMQ4wDAYDVQQLEwVF\n\t\t\t\t\t\tRElOQTEZMBcGA1UEAxMQdnNwMi5lZGluYS5hYy51azEdMBsGCSqGSIb3DQEJARYO\n\t\t\t\t\t\tZWRpbmFAZWQuYWMudWswHhcNMTAwMjAxMTY0OTI1WhcNMjAwMTMwMTY0OTI1WjCB\n\t\t\t\t\t\tpDELMAkGA1UEBhMCR0IxETAPBgNVBAgTCFNjb3RsYW5kMRIwEAYDVQQHEwlFZGlu\n\t\t\t\t\t\tYnVyZ2gxJDAiBgNVBAoTG1RoZSBVbml2ZXJzaXR5IG9mIEVkaW5idXJnaDEOMAwG\n\t\t\t\t\t\tA1UECxMFRURJTkExGTAXBgNVBAMTEHZzcDIuZWRpbmEuYWMudWsxHTAbBgkqhkiG\n\t\t\t\t\t\t9w0BCQEWDmVkaW5hQGVkLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAynwMFgT8x37YBNpxAGTtLJxF3iG1adpqRmin40XS86HdJP21dzsH7JD1\n\t\t\t\t\t\tRanxUJJOWU8wud9e//ZZTC58TZbc8Zp0JRc5hlTOmLRksYt4B0QxrCqJ4EmFKlIM\n\t\t\t\t\t\tigE5ZNgoR+lwS1ENKikIHibnVcNF9IpIkX8sTzCY18JcileM8Yz5b+R91yoha1MU\n\t\t\t\t\t\tasRefMf2j7RR6kldAJw2Xj63aFtN0NXL6Z+HiLyg4JNslJTH9c3Ha88tI+6Ce1Q6\n\t\t\t\t\t\trG7rztkpHAD5Rd+ovQMysk9ihA3RN18X0Uu8LqExH2tUqq51Fmd+KQ04hyjE4gx+\n\t\t\t\t\t\tw2T6MwPmdp6zLQSXFf6x9CeRai7MwwIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCG\n\t\t\t\t\t\tSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4E\n\t\t\t\t\t\tFgQU59hHQ8+jwnn2x3Yz4BDaEaDHUrswHwYDVR0jBBgwFoAU59hHQ8+jwnn2x3Yz\n\t\t\t\t\t\t4BDaEaDHUrswDQYJKoZIhvcNAQEFBQADggEBAB5CEE4B61l2mn/sBlc7+qN+obOW\n\t\t\t\t\t\tgZURJvs/EeIlfR7LpWRITMSn4pE5mPR4R96tL0vNXc1jl5c2sTV9dtztazWmU+Z1\n\t\t\t\t\t\tu3rniEM6jETPFqlmYhOPFzYWoQTB0LGv3Id0NR4dCFDtFNl+EPaQAug9C39gkOCN\n\t\t\t\t\t\tiLZJlzOZxUALuUvebPbZMfqSTo8SdFT1Cv2No0hQIBjvlO1OimSjAWgkFR3snW8b\n\t\t\t\t\t\txzZ/lWUqrLDZYSo5LXQad3yNfhwi4dMJ5PRuAuTH1akdwlVf4AIeIQDm3QBKJIhj\n\t\t\t\t\t\tTOGrFRiCdlp4cIQwN66UelzUH2KjlI/iQXYLbq5uUHN/EI47I/E0gpnYr5E="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIESDCCAzCgAwIBAgIJAKrBnZO7TvNTMA0GCSqGSIb3DQEBBQUAMIGkMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjERMA8GA1UECBMIU2NvdGxhbmQxEjAQBgNVBAcTCUVkaW5idXJnaDEk\n\t\t\t\t\t\tMCIGA1UEChMbVGhlIFVuaXZlcnNpdHkgb2YgRWRpbmJ1cmdoMQ4wDAYDVQQLEwVF\n\t\t\t\t\t\tRElOQTEZMBcGA1UEAxMQdnNwMi5lZGluYS5hYy51azEdMBsGCSqGSIb3DQEJARYO\n\t\t\t\t\t\tZWRpbmFAZWQuYWMudWswHhcNMTAwMjAxMTY0OTI1WhcNMjAwMTMwMTY0OTI1WjCB\n\t\t\t\t\t\tpDELMAkGA1UEBhMCR0IxETAPBgNVBAgTCFNjb3RsYW5kMRIwEAYDVQQHEwlFZGlu\n\t\t\t\t\t\tYnVyZ2gxJDAiBgNVBAoTG1RoZSBVbml2ZXJzaXR5IG9mIEVkaW5idXJnaDEOMAwG\n\t\t\t\t\t\tA1UECxMFRURJTkExGTAXBgNVBAMTEHZzcDIuZWRpbmEuYWMudWsxHTAbBgkqhkiG\n\t\t\t\t\t\t9w0BCQEWDmVkaW5hQGVkLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAynwMFgT8x37YBNpxAGTtLJxF3iG1adpqRmin40XS86HdJP21dzsH7JD1\n\t\t\t\t\t\tRanxUJJOWU8wud9e//ZZTC58TZbc8Zp0JRc5hlTOmLRksYt4B0QxrCqJ4EmFKlIM\n\t\t\t\t\t\tigE5ZNgoR+lwS1ENKikIHibnVcNF9IpIkX8sTzCY18JcileM8Yz5b+R91yoha1MU\n\t\t\t\t\t\tasRefMf2j7RR6kldAJw2Xj63aFtN0NXL6Z+HiLyg4JNslJTH9c3Ha88tI+6Ce1Q6\n\t\t\t\t\t\trG7rztkpHAD5Rd+ovQMysk9ihA3RN18X0Uu8LqExH2tUqq51Fmd+KQ04hyjE4gx+\n\t\t\t\t\t\tw2T6MwPmdp6zLQSXFf6x9CeRai7MwwIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCG\n\t\t\t\t\t\tSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4E\n\t\t\t\t\t\tFgQU59hHQ8+jwnn2x3Yz4BDaEaDHUrswHwYDVR0jBBgwFoAU59hHQ8+jwnn2x3Yz\n\t\t\t\t\t\t4BDaEaDHUrswDQYJKoZIhvcNAQEFBQADggEBAB5CEE4B61l2mn/sBlc7+qN+obOW\n\t\t\t\t\t\tgZURJvs/EeIlfR7LpWRITMSn4pE5mPR4R96tL0vNXc1jl5c2sTV9dtztazWmU+Z1\n\t\t\t\t\t\tu3rniEM6jETPFqlmYhOPFzYWoQTB0LGv3Id0NR4dCFDtFNl+EPaQAug9C39gkOCN\n\t\t\t\t\t\tiLZJlzOZxUALuUvebPbZMfqSTo8SdFT1Cv2No0hQIBjvlO1OimSjAWgkFR3snW8b\n\t\t\t\t\t\txzZ/lWUqrLDZYSo5LXQad3yNfhwi4dMJ5PRuAuTH1akdwlVf4AIeIQDm3QBKJIhj\n\t\t\t\t\t\tTOGrFRiCdlp4cIQwN66UelzUH2KjlI/iQXYLbq5uUHN/EI47I/E0gpnYr5E="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vsp2.edina.ac.uk/mediahub/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vsp2.edina.ac.uk/mediahub/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vsp2.edina.ac.uk/mediahub/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vsp2.edina.ac.uk/mediahub/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vsp2.edina.ac.uk/mediahub/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vsp2.edina.ac.uk/mediahub/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vsp2.edina.ac.uk/mediahub/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vsp2.edina.ac.uk/mediahub/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vsp2.edina.ac.uk/mediahub/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vsp2.edina.ac.uk/mediahub/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vsp3.edina.ac.uk/mediahub/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vsp3.edina.ac.uk/mediahub/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vsp3.edina.ac.uk/mediahub/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vsp3.edina.ac.uk/mediahub/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vsp3.edina.ac.uk/mediahub/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vsp3.edina.ac.uk/mediahub/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vsp4.edina.ac.uk/mediahub/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "18"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vsp4.edina.ac.uk/mediahub/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "19"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vsp4.edina.ac.uk/mediahub/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "20"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vsp4.edina.ac.uk/mediahub/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "21"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vsp4.edina.ac.uk/mediahub/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "22"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vsp4.edina.ac.uk/mediahub/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "23"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://auth.edina.ac.uk/mediahub/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "24"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://auth.edina.ac.uk/mediahub/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "25"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://auth.edina.ac.uk/mediahub/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "26"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://auth.edina.ac.uk/mediahub/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "27"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.edina.ac.uk/mediahub/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "28"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://auth.edina.ac.uk/mediahub/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "29"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://courses.sci-gaia.eu/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fargetta"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:discourse-support@sci-gaia.eu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marco"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barbera"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:discourse-support@sci-gaia.eu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roberto"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://courses.sci-gaia.eu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2015-09-11T09:47:08Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Corsi online del progetto Sci-GaIA erogato dall'Universit\u00e0 degli Studi di Catania"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Sci-GaIA Online Courses provided by the University of Catania"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unict.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unict.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli Studi Catania"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Catania"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://courses.sci-gaia.eu/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://courses.sci-gaia.eu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://courses.sci-gaia.eu/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://courses.sci-gaia.eu/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://courses.sci-gaia.eu/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://courses.sci-gaia.eu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://courses.sci-gaia.eu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://courses.sci-gaia.eu/about"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Sci-GaIA Online Courses is an e-learning environment where partners' users can find courses that explain the technologies used in the project"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "I corsi online del progetto Sci-GaIA sono dei servizi di e-learning dove gli utenti degli enti partner possono apprendere le tecnologie usate nel progetto"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://courses.sci-gaia.eu/privacy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sci-GaIA Online Courses"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Corsi online del progetto Europeo Sci-GaIA"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEoDCCA4igAwIBAgIQGwF3QYiICE7zq1+Nt9wGqDANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMjAeFw0xNTA2MTcwMDAwMDBaFw0xODA2MTYyMzU5NTlaMEExITAfBgNVBAsT\nGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEcMBoGA1UEAxMTY291cnNlcy5zY2kt\nZ2FpYS5ldTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN4lCXNr6Wa2\n7qGn46QSJV6939bVVX/wWLncPuEoJddioKqZpF8E01LS+izmWv85Z0KpeyD3RDx3\n+Mrlfs5lGdVHpsKQA1zGR6qRHi/P13XUspk3q5BC0FEhF2pYvQyc54/BqWdjIvZJ\nIalpLdwn/xZ3ERZlE0oKu44dxs1AHEvDRLtB6WSliR6H8CiSE3gDnKT1reQV3enk\nIhJe+bSI3UxuJ+475OmEdWW4FjPTcQe0+14RTAHiFo+SKKPD1LAJbYRgOjSXQYpS\n0Ffs39xDmlZjDaW++TaDZ0RZbrK2R2WUIdB2Y7ZO3+aXmBysDTvqa6eXMxvQ0zZd\nGZISmkPwGDkCAwEAAaOCAW8wggFrMB8GA1UdIwQYMBaAFFvQihyaMlvgtd2WVBvh\nhiiw/ba9MB0GA1UdDgQWBBRmh4KfdTq82DONTL864+9HD8KmljAOBgNVHQ8BAf8E\nBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUH\nAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0fBDMw\nMTAvoC2gK4YpaHR0cDovL2NybC51c2VydHJ1c3QuY29tL1RFUkVOQVNTTENBMi5j\ncmwwbAYIKwYBBQUHAQEEYDBeMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnVzZXJ0\ncnVzdC5jb20vVEVSRU5BU1NMQ0EyLmNydDAlBggrBgEFBQcwAYYZaHR0cDovL29j\nc3AudXNlcnRydXN0LmNvbTAeBgNVHREEFzAVghNjb3Vyc2VzLnNjaS1nYWlhLmV1\nMA0GCSqGSIb3DQEBCwUAA4IBAQBk718ij3B7Tp2/wjtwus0QvG6/tjzaCejSkFm0\nAPEOAkbduLYkBldzdeWnZiF497mcviriDGMHS6G7nQSurvO/Z/uzZLEX4BVWAhKM\nrILvvdJe+NLrWUc/RblncN83MTwbMsiHRwhaZftX3mdPTZzxNFINijC2wkv4qP7i\nG5QeNpfgG7xfnsOgfYsTwsuLsTqBuQLWMDyXBUIrL4AOD+IRezFBCaVCtii/sWdb\no9dq23HNLskw/04BBIzTcUrrRx5+0jImH6nY9d6ZLGNglpZaogQfPtbt2T6/5lrg\nZmVmVnUteKWWW6Oo6YhuL9+2hwAf62ASzOOl1K9BXieFU0T5"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://courses.sci-gaia.eu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://courses.sci-gaia.eu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://courses.sci-gaia.eu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://courses.sci-gaia.eu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://courses.sci-gaia.eu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://courses.sci-gaia.eu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Sci-GaIA Online Courses"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Corsi online del progetto Europeo Sci-GaIA"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Sci-GaIA Online Courses is an e-learning environment where partners' users can find courses that explain the technologies used in the project"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "I corsi online del progetto Sci-GaIA sono dei servizi di e-learning dove gli utenti degli enti partner possono apprendere le tecnologie usate nel progetto"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "transientId",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.2.3.4.5.6.7.8.9.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sistemas.uepg.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Luiz Gustavo Barros"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "gustavo@uepg.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sistemas.uepg.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE2zCCA8OgAwIBAgIQCOU7rX76FeJ9Ci35yhOEPDANBgkqhkiG9w0BAQsFADA8\nMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMVGhhd3RlLCBJbmMuMRYwFAYDVQQDEw1U\naGF3dGUgU1NMIENBMB4XDTEzMTEyMjAwMDAwMFoXDTE2MTIyMTIzNTk1OVowgasx\nCzAJBgNVBAYTAkJSMQ8wDQYDVQQIEwZQYXJhbmExFTATBgNVBAcUDFBvbnRhIEdy\nb3NzYTEuMCwGA1UEChQlVW5pdmVyc2lkYWRlIEVzdGFkdWFsIGRlIFBvbnRhIEdy\nb3NzYTEpMCcGA1UECxQgQ2VudHJvIGRlIFByb2Nlc3NhbWVudG8gZGUgRGFkb3Mx\nGTAXBgNVBAMUEHNpc3RlbWFzLnVlcGcuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQC4Z3ynISGCCLmgO6uxZXCyCy2217M4h4R8pK0wB6tQUBxqU6jr\nVI2iw1O1Xw3H18qFkk6BdjDF4fJaF9qY3qwZ5JMrL2kKCWubkHB67Ig13R8bKVGL\nSCl/h8UAbhU6g8PDUSEN/gyPVT8H/g8jOeJAS3ruE9XVdbYQUUEHV6sCBRSztz2U\nNtlGDeQYZ0haN7sX2kXk1vx4xYLzYhTEavajLtY2Kcsp8u/Uy8f1IuV9chNsLfdl\naZrnMT/Z28qCoWAeFfz4M6bAZ6Gcyy0TeSI8BDmAqsH7WVukEZ5WEhI/wQx3+z9V\n0YnDr3ZTZlDn1Z+1WLjvRpwDfYN048D3DnABAgMBAAGjggFnMIIBYzAbBgNVHREE\nFDASghBzaXN0ZW1hcy51ZXBnLmJyMAkGA1UdEwQCMAAwQgYDVR0gBDswOTA3Bgpg\nhkgBhvhFAQc2MCkwJwYIKwYBBQUHAgEWG2h0dHBzOi8vd3d3LnRoYXd0ZS5jb20v\nY3BzLzAOBgNVHQ8BAf8EBAMCBaAwHwYDVR0jBBgwFoAUp6KDuzRFQD381TBPErk+\noQGf9tswOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL3N2ci1vdi1jcmwudGhhd3Rl\nLmNvbS9UaGF3dGVPVi5jcmwwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMC\nMGkGCCsGAQUFBwEBBF0wWzAiBggrBgEFBQcwAYYWaHR0cDovL29jc3AudGhhd3Rl\nLmNvbTA1BggrBgEFBQcwAoYpaHR0cDovL3N2ci1vdi1haWEudGhhd3RlLmNvbS9U\naGF3dGVPVi5jZXIwDQYJKoZIhvcNAQELBQADggEBADyZXmy6yj//w3chkKMS5mDJ\nc+QyGYnnANYl+3chFGMdOA0MbZV/r6bPpLj0ieHgH76jvCGq7cYDOIX2mJL5UaBt\npFzP3P/mcrKtgiWVRKPTPSyIEOK3WhAch+kTAiyuf9BAdZXi8GUcF1SYOqxzbWKI\ngYTclKgiji9i8hTJ8NYvLjerxo+hYzXcehaXKvMH78M3qkbHQgu4vKy75hj1O3zw\nsHWt+1i6mNY63pFCGL9zZeuvmoj5USwrwcZXQ2tkwbIMAfqiuGYZnyW7oGYvYagZ\nn41/XeNFdPEQgN8XAz72MitYRzlpUzt8hPgz8zW8yn5JZ3fv56NgRigMwsQgLew="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uepg.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sistemas.uepg.br/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sistemas.uepg.br/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sistemas.uepg.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sistemas.uepg.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sistemas.uepg.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sistemas.uepg.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sistemas.uepg.br/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sistemas.uepg.br/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uepg.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uepg.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uepg.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UEPG - Universidade Estadual de Ponta Grossa"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UEPG - Universidade Estadual de Ponta Grossa"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UEPG - Universidade Estadual de Ponta Grossa"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UEPG - Universidade Estadual de Ponta Grossa"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE2zCCA8OgAwIBAgIQCOU7rX76FeJ9Ci35yhOEPDANBgkqhkiG9w0BAQsFADA8\nMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMVGhhd3RlLCBJbmMuMRYwFAYDVQQDEw1U\naGF3dGUgU1NMIENBMB4XDTEzMTEyMjAwMDAwMFoXDTE2MTIyMTIzNTk1OVowgasx\nCzAJBgNVBAYTAkJSMQ8wDQYDVQQIEwZQYXJhbmExFTATBgNVBAcUDFBvbnRhIEdy\nb3NzYTEuMCwGA1UEChQlVW5pdmVyc2lkYWRlIEVzdGFkdWFsIGRlIFBvbnRhIEdy\nb3NzYTEpMCcGA1UECxQgQ2VudHJvIGRlIFByb2Nlc3NhbWVudG8gZGUgRGFkb3Mx\nGTAXBgNVBAMUEHNpc3RlbWFzLnVlcGcuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQC4Z3ynISGCCLmgO6uxZXCyCy2217M4h4R8pK0wB6tQUBxqU6jr\nVI2iw1O1Xw3H18qFkk6BdjDF4fJaF9qY3qwZ5JMrL2kKCWubkHB67Ig13R8bKVGL\nSCl/h8UAbhU6g8PDUSEN/gyPVT8H/g8jOeJAS3ruE9XVdbYQUUEHV6sCBRSztz2U\nNtlGDeQYZ0haN7sX2kXk1vx4xYLzYhTEavajLtY2Kcsp8u/Uy8f1IuV9chNsLfdl\naZrnMT/Z28qCoWAeFfz4M6bAZ6Gcyy0TeSI8BDmAqsH7WVukEZ5WEhI/wQx3+z9V\n0YnDr3ZTZlDn1Z+1WLjvRpwDfYN048D3DnABAgMBAAGjggFnMIIBYzAbBgNVHREE\nFDASghBzaXN0ZW1hcy51ZXBnLmJyMAkGA1UdEwQCMAAwQgYDVR0gBDswOTA3Bgpg\nhkgBhvhFAQc2MCkwJwYIKwYBBQUHAgEWG2h0dHBzOi8vd3d3LnRoYXd0ZS5jb20v\nY3BzLzAOBgNVHQ8BAf8EBAMCBaAwHwYDVR0jBBgwFoAUp6KDuzRFQD381TBPErk+\noQGf9tswOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL3N2ci1vdi1jcmwudGhhd3Rl\nLmNvbS9UaGF3dGVPVi5jcmwwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMC\nMGkGCCsGAQUFBwEBBF0wWzAiBggrBgEFBQcwAYYWaHR0cDovL29jc3AudGhhd3Rl\nLmNvbTA1BggrBgEFBQcwAoYpaHR0cDovL3N2ci1vdi1haWEudGhhd3RlLmNvbS9U\naGF3dGVPVi5jZXIwDQYJKoZIhvcNAQELBQADggEBADyZXmy6yj//w3chkKMS5mDJ\nc+QyGYnnANYl+3chFGMdOA0MbZV/r6bPpLj0ieHgH76jvCGq7cYDOIX2mJL5UaBt\npFzP3P/mcrKtgiWVRKPTPSyIEOK3WhAch+kTAiyuf9BAdZXi8GUcF1SYOqxzbWKI\ngYTclKgiji9i8hTJ8NYvLjerxo+hYzXcehaXKvMH78M3qkbHQgu4vKy75hj1O3zw\nsHWt+1i6mNY63pFCGL9zZeuvmoj5USwrwcZXQ2tkwbIMAfqiuGYZnyW7oGYvYagZ\nn41/XeNFdPEQgN8XAz72MitYRzlpUzt8hPgz8zW8yn5JZ3fv56NgRigMwsQgLew="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UEPG - Universidade Estadual de Ponta Grossa"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UEPG - Universidade Estadual de Ponta Grossa"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uepg.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uepg.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UEPG - Universidade Estadual de Ponta Grossa"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UEPG - Universidade Estadual de Ponta Grossa"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.sussexstudent.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.sussexstudent.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-08-18T14:24:25Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Sussex Students\u2019 Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sussexstudent.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.sussexstudent.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.sussexstudent.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.sussexstudent.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.sussexstudent.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.sussexstudent.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.sussexstudent.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.sussexstudent.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.sussexstudent.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.sussexstudent.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.sussexstudent.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.sussexstudent.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.sussexstudent.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.sussexstudent.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.sussexstudent.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.sussexstudent.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.sussexstudent.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.protectnetwork.org/protectnetwork-idp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@protectnetwork.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tech Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@protectnetwork.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tech Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.protectnetwork.org/protectnetwork-idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.protectnetwork.org/protectnetwork-idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.protectnetwork.org/protectnetwork-idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.protectnetwork.org/protectnetwork-idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.protectnetwork.org/protectnetwork-idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "idp.protectnetwork.org"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEMDCCAxigAwIBAgIJALJxC01MGf/hMA0GCSqGSIb3DQEBBQUAMG0xCzAJBgNV\n\t\t\t\t\t\tBAYTAlVTMQ4wDAYDVQQIEwVUZXhhczEPMA0GA1UEBxMGQXVzdGluMRcwFQYDVQQK\n\t\t\t\t\t\tEw5Qcm90ZWN0TmV0d29yazEkMCIGA1UEAxMbdGNhcy1pZHAucHJvdGVjdG5ldHdv\n\t\t\t\t\t\tcmsub3JnMB4XDTExMDcyMTE2MzMxN1oXDTIxMDcxODE2MzMxN1owbTELMAkGA1UE\n\t\t\t\t\t\tBhMCVVMxDjAMBgNVBAgTBVRleGFzMQ8wDQYDVQQHEwZBdXN0aW4xFzAVBgNVBAoT\n\t\t\t\t\t\tDlByb3RlY3ROZXR3b3JrMSQwIgYDVQQDExt0Y2FzLWlkcC5wcm90ZWN0bmV0d29y\n\t\t\t\t\t\tay5vcmcwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDWh2R4Tus8Thwl\n\t\t\t\t\t\t4Fnlmz6QrwL/imYN5di4q0gmWMJ03oBfIGireuZKfiI1FXeBsAq2p5XKZRQvWyKX\n\t\t\t\t\t\tJ1z2Z+FbG1Og5s6bZSzIjq7bGac0FPtJ+0vgIy74RKJZDZNR2rzzlW2WCIe1zHUh\n\t\t\t\t\t\tbF0K1RVJZz8nbMDQ+H2Zf74Gi4dXwgQnLCkkPV9ocinv3bq6Iq0H/ySgHGdmazzv\n\t\t\t\t\t\tvSW8C1Ny2WDfEqCWUkR9AKnTjyww3/f0PgHKuuvSKs6KArC00rD+v2hE+PT4M0oa\n\t\t\t\t\t\tTqSIbM5uu6f+Xfu10EQVG7O7Wmj2aAN0/D8/+Eeeh/8Se6XX81S7h/dNRrQh7yKM\n\t\t\t\t\t\t6WIp2pPPAgMBAAGjgdIwgc8wHQYDVR0OBBYEFKWOH8Lch5mEhcxZR+E1w8nvx6Hl\n\t\t\t\t\t\tMIGfBgNVHSMEgZcwgZSAFKWOH8Lch5mEhcxZR+E1w8nvx6HloXGkbzBtMQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzEOMAwGA1UECBMFVGV4YXMxDzANBgNVBAcTBkF1c3RpbjEXMBUGA1UE\n\t\t\t\t\t\tChMOUHJvdGVjdE5ldHdvcmsxJDAiBgNVBAMTG3RjYXMtaWRwLnByb3RlY3RuZXR3\n\t\t\t\t\t\tb3JrLm9yZ4IJALJxC01MGf/hMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAACHlDYkgEzbaCatnF1IYcvy5j/T7dpOlvww+vJSK9Al3BlOmESHrEIS46XO\n\t\t\t\t\t\t9vfk/PgNUM3oYG5prW+azSUJVDfJspSzH0d8IFCI95UlItC9Ivmxpuo1ZcH60fpI\n\t\t\t\t\t\tM4Kb8fLeOfmsbpVZsxj8tSRByARlK4tzHf2+rLOn7jZRTsPcoxrxYIyesbbshhDy\n\t\t\t\t\t\tv2ZE+NoOehZXaAYgZkB3PE0s6Ph+pUYIRSZ7bud1YNlx9QkUoYuwgR+hX895l19Z\n\t\t\t\t\t\tfouPZ1KljFoiTY8iwjRUUNV2Lx2hZUsDHj/4Ea23TY+fc/7OSS4K0BIO4LmUQo1Z\n\t\t\t\t\t\tqg057Ao66R7RAwvB3jNS9ydAiNM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ProtectNetwork"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.protectnetwork.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "9Star Research, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp-manage.dev.ja.net/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smith"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rhys.smith@jisc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rhys"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smith"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rhys.smith@jisc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rhys"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-manage.dev.ja.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-13T15:21:42Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Jisc Managed Federation Services Management Portal"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jisc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "JISC Collections and Janet Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-manage.dev.ja.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-manage.dev.ja.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-manage.dev.ja.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://idp-manage.dev.ja.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-manage.dev.ja.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://idp-manage.dev.ja.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://idp-manage.dev.ja.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The management portal for customers of Jisc's Managed Federation Services, allowing you to configure your managed services."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Jisc Managed Federation Services Management Portal"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWjCCAkICCQDOHlUJNPwmhzANBgkqhkiG9w0BAQsFADBvMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEQMA4GA1UECAwHQnJpc3RvbDEQMA4GA1UEBwwHQnJpc3RvbDENMAsGA1UECgwE\n\t\t\t\t\t\tSklTQzENMAsGA1UECwwESklTQzEeMBwGA1UEAwwVaWRwLW1hbmFnZS5kZXYuamEu\n\t\t\t\t\t\tbmV0MB4XDTE2MDQxMzE0MzYxNVoXDTM2MDQwODE0MzYxNVowbzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEDAOBgNVBAgMB0JyaXN0b2wxEDAOBgNVBAcMB0JyaXN0b2wxDTALBgNVBAoM\n\t\t\t\t\t\tBEpJU0MxDTALBgNVBAsMBEpJU0MxHjAcBgNVBAMMFWlkcC1tYW5hZ2UuZGV2Lmph\n\t\t\t\t\t\tLm5ldDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALtjgdxWTdMzzvNS\n\t\t\t\t\t\t7Ha6n+JP6nvhXcZnq44Asu0pE9QRUkksR2Vg7gTZ/LaIvkuqtkLIhvkgAPbqfIz9\n\t\t\t\t\t\toND64ZRCTolOXJJVxUHeIOPywU9KnDl39cxo1bekooGnK7qKYzvFScoFoGgHO5jK\n\t\t\t\t\t\tAoFCk1ZOHtIzr6Kaeu5yTxSkbNhiaGtbPan1lat55vkP8QL0BCBNoNtNAOdJH5dY\n\t\t\t\t\t\tZqInuYZ13ILcQNl89GHRzuhOAKXfnsE/0ADaToJ/BXa/z1TmPtmLyvUkeiUuHkKQ\n\t\t\t\t\t\tDptfwTP30Mjbml83/peddV2Kd+8c+8NTM5aqgyNQUMFYuOrUjoZO87Fd/J1BMtDE\n\t\t\t\t\t\tIhyKhHkCAwEAATANBgkqhkiG9w0BAQsFAAOCAQEARaLiyC4TEjDN1x8+gsVLms5x\n\t\t\t\t\t\tQ++YVAT1HZu9hFL5oMaLn8YtqSGc7BsLSpfh2Hf4XV2gJgbYPfamkksDCgc2t1RL\n\t\t\t\t\t\tF5lFdUIQy/vEIpMB7jLxVL0ycM+7UDf5xoDbeSU70/QDEeQPghEQB02LT/JIkK/J\n\t\t\t\t\t\tQta20b6WwAnddSwDSy30uy9QT9dTdrvVAYJ+ldhiN8Zwj7Z1XvyxwdHYjRjPRM/x\n\t\t\t\t\t\tX+EP0gi5aL/w6LO1Caf/5b0DHbDfAVmOVZo6ehc5U013wXddNGn3sTupjWKZLf8N\n\t\t\t\t\t\tDewWUSzNy4072Zd3eSsG374NubCwlD+xRDo1cd4g4f4pypdXlXVePAN9wR4KKw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-manage.dev.ja.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-manage.dev.ja.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://idp-manage.dev.ja.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://idp-manage.dev.ja.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://idp-manage.dev.ja.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://idp-manage.dev.ja.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://opn-shibb.hosted.exlibrisgroup.com/shib",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Benoit.Ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Benoit.Ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://opn-shibb.hosted.exlibrisgroup.com/shib",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-12-16T12:23:01Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "This is Shibboleth SP for Primo Resource Discovery at Open University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://exlibrisgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ex Libris (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://opn-shibb.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://opn-shibb.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://opn-shibb.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://opn-shibb.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://opn-shibb.hosted.exlibrisgroup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://opn-shibb.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is an Ex Libris Primo Hosted SP on behalf of the Open University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Open University - Primo Production"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAN/TZ90ziE5NMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB2FpbzAwMTEwHhcNMTQxMTAzMDg1NDE2WhcNMjQxMDMxMDg1NDE2WjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdhaW8wMDExMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tnQx6etOky8LDPvPoToHiJSBUUbPpQxiLjqkEvq+FDfpM4PFPMUJ2TjBh80tv2cXj\n\t\t\t\t\t\tXiWLfQkTWtLlf+abgvENsiGaHlK2AZ5b8t60q+42VKpU59G3wz8MusZ36HWrKVQC\n\t\t\t\t\t\tZu9tTjVv/0ghCHEkOQpqd67HTi9aAu0YnrKO55qky/e/cYi9um5DnjLlF+crQ4yr\n\t\t\t\t\t\tgZM/8LQctNdhogyBcAt6xBg8Jr2XHW1xsfkSkDIoYZXayCvAvcc0Mo7NNH+N5BYp\n\t\t\t\t\t\t27LP0y2iwzLJW8Qed08YvSmW1r958jSVgbytxciA7Lq2qkYqHijj3vgThN50btxY\n\t\t\t\t\t\tmVKrJb2kJ3eC9mZKfZGZnwIDAQABozUwMzASBgNVHREECzAJggdhaW8wMDExMB0G\n\t\t\t\t\t\tA1UdDgQWBBRi4CFW+JRCErw9kobNaWoBKMNngzANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tYki1ymUQA9dc6srKtRlQ+ve4SKgz/P52iL9nr4AUWa4nhXKcbFpSs1NSni11Cmyj\n\t\t\t\t\t\tW9d2eOoamn2xBVY1DhsuHD2AMHggzmC9/OJoALwpK8Elan/Ax5ixWcphvv7b0dMT\n\t\t\t\t\t\taQHbE5PSPEPEy9zVle7EXtDsViu1D++1VaX0lXwZpbwT6c3nEmrnVjJRs+VWElQk\n\t\t\t\t\t\t/QU/IhyoAsyU3z5FdHN7/4vnuL1JjOoPmo+ZVGNBpGYhGKty8wxHB8/dh5GlnkkJ\n\t\t\t\t\t\t3uWpg4tWuMrZ4NMjURafjthODllX0DUfx6IoE/jm5zrASucS3YGtZwLUCz6/Tls3\n\t\t\t\t\t\tP6vTQuQBvTVROWTP/epCTQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://opn-shibb.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://opn-shibb.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://opn-shibb.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://opn-shibb.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://opn-shibb.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://opn-shibb.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://adfs.rijnhuizen.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs.rijnhuizen.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-06-10T09:10:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/661c4d0e3681c2dc5cddb51f3ff7e852",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "FOM-Instituut DIFFER"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "FOM-Instituut DIFFER"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/differ.png",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "40"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FOM-Instituut DIFFER"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FOM-Instituut DIFFER"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "FOM-Instituut DIFFER"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.differ.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "FOM-Instituut DIFFER"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ifsudestemg.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Elder Marcelino"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "elder.marcelino@ifsudestemg.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ifsudestemg.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID3jCCAsYCAQIwDQYJKoZIhvcNAQEFBQAwgbQxFjAUBgNVBAoTDUlGIFN1ZGVz\ndGUgTUcxFzAVBgNVBAsTDlBST0RJL0RHVEkvQ1JJMSUwIwYJKoZIhvcNAQkBFhZj\ncmlAaWZzdWRlc3RlbWcuZWR1LmJyMRUwEwYDVQQHEwxKdWl6IGRlIEZvcmExFTAT\nBgNVBAgTDE1pbmFzIEdlcmFpczELMAkGA1UEBhMCQlIxHzAdBgNVBAMTFmlkcC5p\nZnN1ZGVzdGVtZy5lZHUuYnIwHhcNMTQwNTI2MTkzNjM4WhcNMTcwNTI1MTkzNjM4\nWjCBtDEWMBQGA1UEChMNSUYgU3VkZXN0ZSBNRzEXMBUGA1UECxMOUFJPREkvREdU\nSS9DUkkxJTAjBgkqhkiG9w0BCQEWFmNyaUBpZnN1ZGVzdGVtZy5lZHUuYnIxFTAT\nBgNVBAcTDEp1aXogZGUgRm9yYTEVMBMGA1UECBMMTWluYXMgR2VyYWlzMQswCQYD\nVQQGEwJCUjEfMB0GA1UEAxMWaWRwLmlmc3VkZXN0ZW1nLmVkdS5icjCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMEoOjQZlyUQUe1L4itiQULFj/VW1LhW\nnUTS1MuWbER1HiWpuT6UJFMY+0q0d/tQ0RPXQakkvpWPC1yxR7iknXgg9oxjSb9T\n9WjLPbdvQCMPFCVe/aBgwUZ9RdLsETcuHagJ+ebD7QB1NnVhco9/rE398YHT+5X7\nOZkFuqOSKaEw7+79Jt5Vc4w6Tc6fPzrCAaT7G7YuXKRq0I8WV3xJClz0OwHZymz8\neEBB7F/E0kr61/XRQjf3i4+F6pad8UT6FkmWbEvfFr54OtvqaPKL9tZWPnncrg4r\nShw2qieG3AqcXO2jIGC3Iyk/TSS6lQQHYv1v5ELst87SQ8tSwuO8Yp8CAwEAATAN\nBgkqhkiG9w0BAQUFAAOCAQEAXmh5aRLYZn3vwyFcDKhR2i1SmaDMlJnN73ubJ8Pk\n3gwuyPcj/XdpLSFsCSKNeM2BAljp5D8i93+j9RjR/GvKA4pchq4DdVrw/45gcW57\nbnC1Dux/0kfBgZLy8GUg612ZdWm0F2kttOI/kDWmlWOFERcqmja0LM4cwzs+byj8\nWum6NyNsy/5XSVhTMA7xUcypbrU/d7S9I2ik9Kope2e4Oihu5GX1YvtapIOzZ2EQ\n0yyvP5Y629IcqIzAMqR5tcYK9dMl2fmFQBhwdGciJKxQaAdyQkKvrXfSkuV/mi0V\nNPp10MrDZ1q+QBfffi16WobvmUBWgpE7UqgwTmJztWx7yA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ifsudestemg.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ifsudestemg.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ifsudestemg.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ifsudestemg.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ifsudestemg.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ifsudestemg.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ifsudestemg.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ifsudestemg.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifsudestemg.edu.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifsudestemg.edu.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFSudesteMG - Instituto Federal do Sudeste de Minas Gerais"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFSudesteMG - Instituto Federal do Sudeste de Minas Gerais"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFSudesteMG - Instituto Federal do Sudeste de Minas Gerais"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFSudesteMG - Instituto Federal do Sudeste de Minas Gerais"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID3jCCAsYCAQIwDQYJKoZIhvcNAQEFBQAwgbQxFjAUBgNVBAoTDUlGIFN1ZGVz\ndGUgTUcxFzAVBgNVBAsTDlBST0RJL0RHVEkvQ1JJMSUwIwYJKoZIhvcNAQkBFhZj\ncmlAaWZzdWRlc3RlbWcuZWR1LmJyMRUwEwYDVQQHEwxKdWl6IGRlIEZvcmExFTAT\nBgNVBAgTDE1pbmFzIEdlcmFpczELMAkGA1UEBhMCQlIxHzAdBgNVBAMTFmlkcC5p\nZnN1ZGVzdGVtZy5lZHUuYnIwHhcNMTQwNTI2MTkzNjM4WhcNMTcwNTI1MTkzNjM4\nWjCBtDEWMBQGA1UEChMNSUYgU3VkZXN0ZSBNRzEXMBUGA1UECxMOUFJPREkvREdU\nSS9DUkkxJTAjBgkqhkiG9w0BCQEWFmNyaUBpZnN1ZGVzdGVtZy5lZHUuYnIxFTAT\nBgNVBAcTDEp1aXogZGUgRm9yYTEVMBMGA1UECBMMTWluYXMgR2VyYWlzMQswCQYD\nVQQGEwJCUjEfMB0GA1UEAxMWaWRwLmlmc3VkZXN0ZW1nLmVkdS5icjCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMEoOjQZlyUQUe1L4itiQULFj/VW1LhW\nnUTS1MuWbER1HiWpuT6UJFMY+0q0d/tQ0RPXQakkvpWPC1yxR7iknXgg9oxjSb9T\n9WjLPbdvQCMPFCVe/aBgwUZ9RdLsETcuHagJ+ebD7QB1NnVhco9/rE398YHT+5X7\nOZkFuqOSKaEw7+79Jt5Vc4w6Tc6fPzrCAaT7G7YuXKRq0I8WV3xJClz0OwHZymz8\neEBB7F/E0kr61/XRQjf3i4+F6pad8UT6FkmWbEvfFr54OtvqaPKL9tZWPnncrg4r\nShw2qieG3AqcXO2jIGC3Iyk/TSS6lQQHYv1v5ELst87SQ8tSwuO8Yp8CAwEAATAN\nBgkqhkiG9w0BAQUFAAOCAQEAXmh5aRLYZn3vwyFcDKhR2i1SmaDMlJnN73ubJ8Pk\n3gwuyPcj/XdpLSFsCSKNeM2BAljp5D8i93+j9RjR/GvKA4pchq4DdVrw/45gcW57\nbnC1Dux/0kfBgZLy8GUg612ZdWm0F2kttOI/kDWmlWOFERcqmja0LM4cwzs+byj8\nWum6NyNsy/5XSVhTMA7xUcypbrU/d7S9I2ik9Kope2e4Oihu5GX1YvtapIOzZ2EQ\n0yyvP5Y629IcqIzAMqR5tcYK9dMl2fmFQBhwdGciJKxQaAdyQkKvrXfSkuV/mi0V\nNPp10MrDZ1q+QBfffi16WobvmUBWgpE7UqgwTmJztWx7yA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFSudesteMG - Instituto Federal do Sudeste de Minas Gerais"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFSudesteMG - Instituto Federal do Sudeste de Minas Gerais"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifsudestemg.edu.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifsudestemg.edu.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IF Sudeste MG - Instituto Federal de Educacao, Ciencia e Tecnologia do Sudeste de Minas Gerais"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IF Sudeste MG - Instituto Federal de Educacao, Ciencia e Tecnologia do Sudeste de Minas Gerais"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp2.civ.cvut.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Strupl"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "strupl@vc.cvut.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp2.civ.cvut.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2010-09-22T14:10:51Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/university"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFSDCCBDCgAwIBAgIQBXyYdVS7UxZI1dayu2ZXbDANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMzAeFw0xNTExMTMwMDAwMDBaFw0xODExMjExMjAwMDBaMIGOMQswCQYDVQQG\nEwJDWjEdMBsGA1UECAwUSGxhdm7DrSBtxJtzdG8gUHJhaGExEDAOBgNVBAcTB1By\nYWhhIDYxMzAxBgNVBAoMKsSMZXNrw6kgdnlzb2vDqSB1xI1lbsOtIHRlY2huaWNr\nw6kgdiBQcmF6ZTEZMBcGA1UEAxMQaWRwMi5jaXYuY3Z1dC5jejCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAKFi5O/MIGOQ7k41iOHwDzkOIJL/0F5TZyR6\nsTBSLWTOlTo5JIeaWj4vcL6Vww6kbnV9uQci/8eEOSrnI9DHrfA59vjgcH67PE1E\nzEhgCaCfrcNT1RnLBsb0OgyXay9sfr/Ylq0UORDTyPNSp8zDOPpwzvcz5dmfQ4uO\nOP1R6H5h1BPJ0MlRaTtnuIaNQ71nUHmy0UWQc2dJTqf0xEXUSzbr28LD9TlaJjm9\noPdnwPxPGUvc5YjxAe5ElH179C/rIkxaz0313LwOrYWEdNn0KNJ6mRkD4Xcj0MiJ\nVD201Gjw6nSWnXLvfqOPxpv+vfKpnGnAUzBaMySV0spSVkU/iUECAwEAAaOCAckw\nggHFMB8GA1UdIwQYMBaAFGf9iCAUJ5jHCdIlGbvpURFjdVBiMB0GA1UdDgQWBBQ5\nzJX+DRBUzFYzzJTV7wxCcFZTOTAbBgNVHREEFDASghBpZHAyLmNpdi5jdnV0LmN6\nMA4GA1UdDwEB/wQEAwIFoDAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIw\nawYDVR0fBGQwYjAvoC2gK4YpaHR0cDovL2NybDMuZGlnaWNlcnQuY29tL1RFUkVO\nQVNTTENBMy5jcmwwL6AtoCuGKWh0dHA6Ly9jcmw0LmRpZ2ljZXJ0LmNvbS9URVJF\nTkFTU0xDQTMuY3JsMEwGA1UdIARFMEMwNwYJYIZIAYb9bAEBMCowKAYIKwYBBQUH\nAgEWHGh0dHBzOi8vd3d3LmRpZ2ljZXJ0LmNvbS9DUFMwCAYGZ4EMAQICMG4GCCsG\nAQUFBwEBBGIwYDAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AuZGlnaWNlcnQuY29t\nMDgGCCsGAQUFBzAChixodHRwOi8vY2FjZXJ0cy5kaWdpY2VydC5jb20vVEVSRU5B\nU1NMQ0EzLmNydDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3DQEBCwUAA4IBAQAEdk6P\nHL6Vy1eHvc76Rvsdf1eeZYgQhC83Mu3Jl7YdJ3Gn0e9/Ae2uFUI3ojr0OUEqyLNy\nQyeDENJQ0bmn8N10sXxSSx4kTXe+FXjpCk/voBuAwIkm1e00/xmgfWLq40FVmZTe\nA4+h8NYs+ZVSDvLlBnsSj9urq61ARMT3jGlNeTzC0V+6CE9SizLKMJ1c5/jNzGM0\nV9zEp+fa293vqzGiIWE+Jk982d31nGCZR1WdrPcjGd2s3oEPc09v+pn5TTdHEeo+\nANYmEJCunBeqEsRfmPxWNVpqZB+YKKqbDRGVQpSJUN8ck7lFolqJBnncLaNXBJP3\nEL3PvAXtdbMpcuHB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cvut.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.civ.cvut.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.civ.cvut.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp2.civ.cvut.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.civ.cvut.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp2.civ.cvut.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2.civ.cvut.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.civ.cvut.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.civ.cvut.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cvut.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.cvut.cz/en"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.cvut.cz/cs"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for CTU in Prague"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro \u010cVUT v Praze"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp2.civ.cvut.cz/idp/images/logo_cvut_40pix.png",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "53"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Czech Technical University in Prague"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u010cesk\u00e9 vysok\u00e9 u\u010den\u00ed technick\u00e9 v Praze"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFSDCCBDCgAwIBAgIQBXyYdVS7UxZI1dayu2ZXbDANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMzAeFw0xNTExMTMwMDAwMDBaFw0xODExMjExMjAwMDBaMIGOMQswCQYDVQQG\nEwJDWjEdMBsGA1UECAwUSGxhdm7DrSBtxJtzdG8gUHJhaGExEDAOBgNVBAcTB1By\nYWhhIDYxMzAxBgNVBAoMKsSMZXNrw6kgdnlzb2vDqSB1xI1lbsOtIHRlY2huaWNr\nw6kgdiBQcmF6ZTEZMBcGA1UEAxMQaWRwMi5jaXYuY3Z1dC5jejCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAKFi5O/MIGOQ7k41iOHwDzkOIJL/0F5TZyR6\nsTBSLWTOlTo5JIeaWj4vcL6Vww6kbnV9uQci/8eEOSrnI9DHrfA59vjgcH67PE1E\nzEhgCaCfrcNT1RnLBsb0OgyXay9sfr/Ylq0UORDTyPNSp8zDOPpwzvcz5dmfQ4uO\nOP1R6H5h1BPJ0MlRaTtnuIaNQ71nUHmy0UWQc2dJTqf0xEXUSzbr28LD9TlaJjm9\noPdnwPxPGUvc5YjxAe5ElH179C/rIkxaz0313LwOrYWEdNn0KNJ6mRkD4Xcj0MiJ\nVD201Gjw6nSWnXLvfqOPxpv+vfKpnGnAUzBaMySV0spSVkU/iUECAwEAAaOCAckw\nggHFMB8GA1UdIwQYMBaAFGf9iCAUJ5jHCdIlGbvpURFjdVBiMB0GA1UdDgQWBBQ5\nzJX+DRBUzFYzzJTV7wxCcFZTOTAbBgNVHREEFDASghBpZHAyLmNpdi5jdnV0LmN6\nMA4GA1UdDwEB/wQEAwIFoDAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIw\nawYDVR0fBGQwYjAvoC2gK4YpaHR0cDovL2NybDMuZGlnaWNlcnQuY29tL1RFUkVO\nQVNTTENBMy5jcmwwL6AtoCuGKWh0dHA6Ly9jcmw0LmRpZ2ljZXJ0LmNvbS9URVJF\nTkFTU0xDQTMuY3JsMEwGA1UdIARFMEMwNwYJYIZIAYb9bAEBMCowKAYIKwYBBQUH\nAgEWHGh0dHBzOi8vd3d3LmRpZ2ljZXJ0LmNvbS9DUFMwCAYGZ4EMAQICMG4GCCsG\nAQUFBwEBBGIwYDAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AuZGlnaWNlcnQuY29t\nMDgGCCsGAQUFBzAChixodHRwOi8vY2FjZXJ0cy5kaWdpY2VydC5jb20vVEVSRU5B\nU1NMQ0EzLmNydDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3DQEBCwUAA4IBAQAEdk6P\nHL6Vy1eHvc76Rvsdf1eeZYgQhC83Mu3Jl7YdJ3Gn0e9/Ae2uFUI3ojr0OUEqyLNy\nQyeDENJQ0bmn8N10sXxSSx4kTXe+FXjpCk/voBuAwIkm1e00/xmgfWLq40FVmZTe\nA4+h8NYs+ZVSDvLlBnsSj9urq61ARMT3jGlNeTzC0V+6CE9SizLKMJ1c5/jNzGM0\nV9zEp+fa293vqzGiIWE+Jk982d31nGCZR1WdrPcjGd2s3oEPc09v+pn5TTdHEeo+\nANYmEJCunBeqEsRfmPxWNVpqZB+YKKqbDRGVQpSJUN8ck7lFolqJBnncLaNXBJP3\nEL3PvAXtdbMpcuHB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u010cesk\u00e9 vysok\u00e9 u\u010den\u00ed technick\u00e9 v Praze"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Czech Technical University in Prague"
          }
        ],
        "organization_url": [
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cvut.cz/cs"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cvut.cz/en"
          }
        ],
        "organization_name": [
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u010cVUT"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CTU"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibidp.wqeic.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Laurenti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:roger.laurenti@wqeic.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roger"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Laurenti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:roger.laurenti@wqeic.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roger"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibidp.wqeic.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-03-28T12:51:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEijCCA3KgAwIBAgIJANv4hjZSaLpQMA0GCSqGSIb3DQEBBQUAMIHFMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEXMBUGA1UECAwOTGVpY2VzdGVyc2hpcmUxEjAQBgNVBAcMCUxlaWNl\n\t\t\t\t\t\tc3RlcjEuMCwGA1UECgwlV3lnZ2VzdG9uICYgUXVlZW4gRWxpemFiZXRoIEkgQ29s\n\t\t\t\t\t\tbGVnZTEUMBIGA1UECwwLSVQgU2VydmljZXMxHDAaBgNVBAMME3NoaWJpZHAud3Fl\n\t\t\t\t\t\taWMuYWMudWsxJTAjBgkqhkiG9w0BCQEWFml0aGVscGRlc2tAd3FlaWMuYWMudWsw\n\t\t\t\t\t\tHhcNMTQwMzE4MTIzNDU4WhcNMjQwMzE1MTIzNDU4WjCBxTELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tFzAVBgNVBAgMDkxlaWNlc3RlcnNoaXJlMRIwEAYDVQQHDAlMZWljZXN0ZXIxLjAs\n\t\t\t\t\t\tBgNVBAoMJVd5Z2dlc3RvbiAmIFF1ZWVuIEVsaXphYmV0aCBJIENvbGxlZ2UxFDAS\n\t\t\t\t\t\tBgNVBAsMC0lUIFNlcnZpY2VzMRwwGgYDVQQDDBNzaGliaWRwLndxZWljLmFjLnVr\n\t\t\t\t\t\tMSUwIwYJKoZIhvcNAQkBFhZpdGhlbHBkZXNrQHdxZWljLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxVKEV8L05iIYj4KRgdBCcBJRuW6c6Kal\n\t\t\t\t\t\tXrqwV6y55rPuKo+oAKPQ1D2N9/zLq7abDb5ftS0MaXMEg9oqiRc9d15J4cPMT5wp\n\t\t\t\t\t\th2icZMShZP14pouI4ia7hqgwzFpF1PYD77ZFRRNIyBh9fBeiB155D2NeUCJhu4Xl\n\t\t\t\t\t\triUhKCedOAfnL50GNTNpKEYxLjtrzVzHyrenKMUnF4aiq2G7DOfeWK9i/eItNETq\n\t\t\t\t\t\tWF1lvNfYqxcKHjcUVmcs8ACHUEh4MLesvZdl9sZtP52gdxfNiCiAo1BJIxsqJ8HB\n\t\t\t\t\t\t0NLOJK70YEU+To3XM9cONSUOffftTrB+9tmzRB+vc9mBGasg53+zgwIDAQABo3sw\n\t\t\t\t\t\teTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBD\n\t\t\t\t\t\tZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUSrv6hTErz+8nx1Np6R8mpyg4DU8wHwYDVR0j\n\t\t\t\t\t\tBBgwFoAUSrv6hTErz+8nx1Np6R8mpyg4DU8wDQYJKoZIhvcNAQEFBQADggEBABiy\n\t\t\t\t\t\tAqUhi20nKdQmVmHq0Rj6uWosu1NCYYVGAtrEfzG2pNFiKm7yGI5AsKYcYR80VEds\n\t\t\t\t\t\t3QO66RRc4jtSEJokDpcuim7QsW08+87alhMfJSj+/Y2YMTRG6Ruv/WDXHln1OoFS\n\t\t\t\t\t\tmyDjdSWk4gIrAMQc5/AbnYtvgAJxmlvKOST34hXOCX5HXTu2hUjruPop15+ucwYC\n\t\t\t\t\t\tcPVkx4NgoOPsM60BJJElzhBwYBBZmBTDfSg9XkvY41YCcKS5dyCqfkG0SD55tubN\n\t\t\t\t\t\tIR2ATC49n4iiDdgsestoH8IsHHoClXDv1wMFL5TfGS2BJq3PWWYN/bB9R7xL2F6N\n\t\t\t\t\t\tSlZXFQLen4vcwe+CNlM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wqeic.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.wqeic.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.wqeic.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.wqeic.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.wqeic.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibidp.wqeic.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.wqeic.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.wqeic.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.wqeic.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wqeic.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEijCCA3KgAwIBAgIJANv4hjZSaLpQMA0GCSqGSIb3DQEBBQUAMIHFMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEXMBUGA1UECAwOTGVpY2VzdGVyc2hpcmUxEjAQBgNVBAcMCUxlaWNl\n\t\t\t\t\t\tc3RlcjEuMCwGA1UECgwlV3lnZ2VzdG9uICYgUXVlZW4gRWxpemFiZXRoIEkgQ29s\n\t\t\t\t\t\tbGVnZTEUMBIGA1UECwwLSVQgU2VydmljZXMxHDAaBgNVBAMME3NoaWJpZHAud3Fl\n\t\t\t\t\t\taWMuYWMudWsxJTAjBgkqhkiG9w0BCQEWFml0aGVscGRlc2tAd3FlaWMuYWMudWsw\n\t\t\t\t\t\tHhcNMTQwMzE4MTIzNDU4WhcNMjQwMzE1MTIzNDU4WjCBxTELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tFzAVBgNVBAgMDkxlaWNlc3RlcnNoaXJlMRIwEAYDVQQHDAlMZWljZXN0ZXIxLjAs\n\t\t\t\t\t\tBgNVBAoMJVd5Z2dlc3RvbiAmIFF1ZWVuIEVsaXphYmV0aCBJIENvbGxlZ2UxFDAS\n\t\t\t\t\t\tBgNVBAsMC0lUIFNlcnZpY2VzMRwwGgYDVQQDDBNzaGliaWRwLndxZWljLmFjLnVr\n\t\t\t\t\t\tMSUwIwYJKoZIhvcNAQkBFhZpdGhlbHBkZXNrQHdxZWljLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxVKEV8L05iIYj4KRgdBCcBJRuW6c6Kal\n\t\t\t\t\t\tXrqwV6y55rPuKo+oAKPQ1D2N9/zLq7abDb5ftS0MaXMEg9oqiRc9d15J4cPMT5wp\n\t\t\t\t\t\th2icZMShZP14pouI4ia7hqgwzFpF1PYD77ZFRRNIyBh9fBeiB155D2NeUCJhu4Xl\n\t\t\t\t\t\triUhKCedOAfnL50GNTNpKEYxLjtrzVzHyrenKMUnF4aiq2G7DOfeWK9i/eItNETq\n\t\t\t\t\t\tWF1lvNfYqxcKHjcUVmcs8ACHUEh4MLesvZdl9sZtP52gdxfNiCiAo1BJIxsqJ8HB\n\t\t\t\t\t\t0NLOJK70YEU+To3XM9cONSUOffftTrB+9tmzRB+vc9mBGasg53+zgwIDAQABo3sw\n\t\t\t\t\t\teTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBD\n\t\t\t\t\t\tZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUSrv6hTErz+8nx1Np6R8mpyg4DU8wHwYDVR0j\n\t\t\t\t\t\tBBgwFoAUSrv6hTErz+8nx1Np6R8mpyg4DU8wDQYJKoZIhvcNAQEFBQADggEBABiy\n\t\t\t\t\t\tAqUhi20nKdQmVmHq0Rj6uWosu1NCYYVGAtrEfzG2pNFiKm7yGI5AsKYcYR80VEds\n\t\t\t\t\t\t3QO66RRc4jtSEJokDpcuim7QsW08+87alhMfJSj+/Y2YMTRG6Ruv/WDXHln1OoFS\n\t\t\t\t\t\tmyDjdSWk4gIrAMQc5/AbnYtvgAJxmlvKOST34hXOCX5HXTu2hUjruPop15+ucwYC\n\t\t\t\t\t\tcPVkx4NgoOPsM60BJJElzhBwYBBZmBTDfSg9XkvY41YCcKS5dyCqfkG0SD55tubN\n\t\t\t\t\t\tIR2ATC49n4iiDdgsestoH8IsHHoClXDv1wMFL5TfGS2BJq3PWWYN/bB9R7xL2F6N\n\t\t\t\t\t\tSlZXFQLen4vcwe+CNlM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Wyggeston & QEI College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wqeic.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Wyggeston and Queen Elizabeth I College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp-hosting.renater.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Anass Chabli"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "anass.chabli@renater.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-hosting.renater.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-11-17T17:56:03Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-hosting.renater.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-hosting.renater.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-hosting.renater.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "genci.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.renater.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IdP Hosting"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IdP Hosting"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RENATER Connect"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RENATER Connect"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUZRhn1oG2f7FG4yfsnI73Z2W/5jswDQYJKoZIhvcNAQEL\nBQAwITEfMB0GA1UEAwwWaWRwLWhvc3RpbmcucmVuYXRlci5mcjAeFw0xNTExMTcx\nNjM4NDVaFw0zNTExMTcxNjM4NDVaMCExHzAdBgNVBAMMFmlkcC1ob3N0aW5nLnJl\nbmF0ZXIuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCLq4oRzxaf\nXL5i0ZfOQhGvcAW7awDjuMgYzi1geOxe1aTlCrYFosPkzSY9J/HarXGc8pS6VY2q\nbrHh7wHTxP2QPw64CaQYUumOhZRvlkSGdj0vKYn7DBKewYfHND1nr+TN4ZybZVCe\nGvpIQBhwN2SARKPAxjVZIpwcKskLcHsakh2TNknkxSsu4LBkx6VYzQr8JCcH+YCx\nrVTGHoMdjNDlrEkKBJrReB7VpC1yKdXDXsQNtWKojiQvbI3Zau2gduxaAUAs4Wlz\n+3gC3poaANXsRbYO5t8PU8VLulVx1j8SkRcyAunXXGLuPIZ0AwX6cREM77vuMoF1\nrgc6sdu8WEmTAgMBAAGjczBxMB0GA1UdDgQWBBRHn9jRWEpSgGuXm+Fcat1vfMSM\nZzBQBgNVHREESTBHghZpZHAtaG9zdGluZy5yZW5hdGVyLmZyhi1odHRwczovL2lk\ncC1ob3N0aW5nLnJlbmF0ZXIuZnIvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEL\nBQADggEBAIiIsPKolz/Ct7HOQDvJXJ3VT2ov8TQT2DA75cJ9qK1TVEQTnZtsla2x\nheA2WFYt2Hf1/N/y9salEo1r5zXlaTi/D3QQBjl8jQK9uibY3Ta4bk27XePxAv8I\nMAWWy529LU5M7/AViEMkPT96kPcOJST5XgXzZN2I8dkVQ+L6SUutqvvVju7MDwP/\ndSqzvGLJpKzSnmgITqMT/RBPbgJUsETAr/5gOnfkJ1RQfbKjl/QzuQTKYPu4XeKJ\nz7+v1Ag9m2btxCUdJMaMDn/FUJKSzxOogW3vJ1ZIAXFMnEgSuhrM5/GoyiEqyCfj\neTynT1A7tmOPmxyMyv76cficIt0xGao="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RENATER Connect"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.renater.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RENATER Connect"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://cafe.ifnmg.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rogerio Luiz"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rogerio.luiz@ifnmg.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.ifnmg.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID9DCCAtwCAQAwDQYJKoZIhvcNAQEFBQAwgb8xNDAyBgNVBAoTK0lGTk1HIC0g\nSW5zdGl0dWRvIEZlZGVyYWwgZG8gTm9ydGUgZGUgTWluYXMxDTALBgNVBAsTBERH\nVEkxIDAeBgkqhkiG9w0BCQEWEWNndGlAaWZubWcuZWR1LmJyMRYwFAYDVQQHEw1N\nb250ZXMgQ2xhcm9zMRUwEwYDVQQIEwxNaW5hcyBHZXJhaXMxCzAJBgNVBAYTAkJS\nMRowGAYDVQQDExFjYWZlLmlmbm1nLmVkdS5icjAeFw0xNjAxMjkxNDM3NDZaFw0x\nOTAxMjgxNDM3NDZaMIG/MTQwMgYDVQQKEytJRk5NRyAtIEluc3RpdHVkbyBGZWRl\ncmFsIGRvIE5vcnRlIGRlIE1pbmFzMQ0wCwYDVQQLEwRER1RJMSAwHgYJKoZIhvcN\nAQkBFhFjZ3RpQGlmbm1nLmVkdS5icjEWMBQGA1UEBxMNTW9udGVzIENsYXJvczEV\nMBMGA1UECBMMTWluYXMgR2VyYWlzMQswCQYDVQQGEwJCUjEaMBgGA1UEAxMRY2Fm\nZS5pZm5tZy5lZHUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDJ\n/Rihj/Xa7N9if4Hg7W+hUk3RzcevTdkb7PjYvtZuBc+C0vT+UF6jjPssebdBC8eg\npVYGV39o9Z3XKlSXa93Q8Jmi0XXeku0iWQj19hQy1cd3JdXvOEVZspLhBTKlHBiq\n9ckhiFBD03uxQhKNCtsAXsuyp+u8T+gHS6EIE9fccaE4TbaLsB3OwOSmxi2mVDg1\nK//ijxUISU1cHJyY/hHspd+FeavfIyFGXxdz32s5zydI8jBO8T0GJ+3iXhFyI3XM\n2A1yBQs6lo2AaDiuIv+Fid2WVGefF3DkQInC0/vkypcUgyTnsF9v6noeBhvUJoOX\n2TXh02Uy0yWzgMYPx9oPAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBALJttKKA5w5u\npaXvoKIgczdMAgpXYajvrFtz7K58GL3tGn4Cxkji6ZiR3HV6VbivsNtoFqNqRVGB\neJWnfaRemUx4JZyjsO8ZYS+z+U+xV0kEnNsFYCmW23Tq18xT6rtF6hb+9meVImhe\n1TYH5KbNKbJThFfvmdlv++XdVlF/p75syVn+VIdsv4hJvE/mZ07kQz5XKZ2jWFew\nUtzJHrKw+r+jXRfclzTKouMHeeAR+wqJ382uaBJQu1o96kJHQnSzJzLH3HCr01N7\n3l0Bz5/iRUBbOU+TJvsLyGXMMbbUqiQd1fml9nne35OBMfJqBdWNzEmeor19SUmg\ndXlUgHJU9wo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.ifnmg.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.ifnmg.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.ifnmg.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.ifnmg.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.ifnmg.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.ifnmg.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.ifnmg.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.ifnmg.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifnmg.edu.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifnmg.edu.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFNMG - Instituto Federal Do Norte De Minas Gerais"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFNMG - Instituto Federal Do Norte De Minas Gerais"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFNMG - Instituto Federal Do Norte De Minas Gerais"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFNMG - Instituto Federal Do Norte De Minas Gerais"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID9DCCAtwCAQAwDQYJKoZIhvcNAQEFBQAwgb8xNDAyBgNVBAoTK0lGTk1HIC0g\nSW5zdGl0dWRvIEZlZGVyYWwgZG8gTm9ydGUgZGUgTWluYXMxDTALBgNVBAsTBERH\nVEkxIDAeBgkqhkiG9w0BCQEWEWNndGlAaWZubWcuZWR1LmJyMRYwFAYDVQQHEw1N\nb250ZXMgQ2xhcm9zMRUwEwYDVQQIEwxNaW5hcyBHZXJhaXMxCzAJBgNVBAYTAkJS\nMRowGAYDVQQDExFjYWZlLmlmbm1nLmVkdS5icjAeFw0xNjAxMjkxNDM3NDZaFw0x\nOTAxMjgxNDM3NDZaMIG/MTQwMgYDVQQKEytJRk5NRyAtIEluc3RpdHVkbyBGZWRl\ncmFsIGRvIE5vcnRlIGRlIE1pbmFzMQ0wCwYDVQQLEwRER1RJMSAwHgYJKoZIhvcN\nAQkBFhFjZ3RpQGlmbm1nLmVkdS5icjEWMBQGA1UEBxMNTW9udGVzIENsYXJvczEV\nMBMGA1UECBMMTWluYXMgR2VyYWlzMQswCQYDVQQGEwJCUjEaMBgGA1UEAxMRY2Fm\nZS5pZm5tZy5lZHUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDJ\n/Rihj/Xa7N9if4Hg7W+hUk3RzcevTdkb7PjYvtZuBc+C0vT+UF6jjPssebdBC8eg\npVYGV39o9Z3XKlSXa93Q8Jmi0XXeku0iWQj19hQy1cd3JdXvOEVZspLhBTKlHBiq\n9ckhiFBD03uxQhKNCtsAXsuyp+u8T+gHS6EIE9fccaE4TbaLsB3OwOSmxi2mVDg1\nK//ijxUISU1cHJyY/hHspd+FeavfIyFGXxdz32s5zydI8jBO8T0GJ+3iXhFyI3XM\n2A1yBQs6lo2AaDiuIv+Fid2WVGefF3DkQInC0/vkypcUgyTnsF9v6noeBhvUJoOX\n2TXh02Uy0yWzgMYPx9oPAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBALJttKKA5w5u\npaXvoKIgczdMAgpXYajvrFtz7K58GL3tGn4Cxkji6ZiR3HV6VbivsNtoFqNqRVGB\neJWnfaRemUx4JZyjsO8ZYS+z+U+xV0kEnNsFYCmW23Tq18xT6rtF6hb+9meVImhe\n1TYH5KbNKbJThFfvmdlv++XdVlF/p75syVn+VIdsv4hJvE/mZ07kQz5XKZ2jWFew\nUtzJHrKw+r+jXRfclzTKouMHeeAR+wqJ382uaBJQu1o96kJHQnSzJzLH3HCr01N7\n3l0Bz5/iRUBbOU+TJvsLyGXMMbbUqiQd1fml9nne35OBMfJqBdWNzEmeor19SUmg\ndXlUgHJU9wo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFNMG - Instituto Federal Do Norte De Minas Gerais"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFNMG - Instituto Federal Do Norte De Minas Gerais"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifnmg.edu.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifnmg.edu.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFNMG - Instituto Federal Do Norte De Minas Gerais"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFNMG - Instituto Federal Do Norte De Minas Gerais"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://federatie.radboudumc.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://federatie.radboudumc.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-12-11T14:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/568f98e047ca9a6b553540a0f6ce3cfd",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Radboud UMC"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Radboud UMC"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/Radboudumc.jpg",
                    "height": "300",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "500"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Radboud UMC"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Radboud UMC"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Radboud UMC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.radboudumc.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Radboud UMC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.esrc.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.esrc.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/esrc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/esrc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "esrc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Economic & Social Research Council"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.esrc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.salisbury.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibsupport@salisbury.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibsupport@salisbury.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibsupport@salisbury.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.salisbury.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.salisbury.edu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.salisbury.edu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.salisbury.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.salisbury.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.salisbury.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.salisbury.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.salisbury.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.salisbury.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "salisbury.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Salisbury University Shibboleth Identity Provider allows SU faculty, staff and students to access external service providers using their SU NetID."
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth.salisbury.edu/idp/images/sulogobig.gif",
                    "lang": "en",
                    "height": "72",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "228"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Salisbury University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSzCCAjOgAwIBAgIUY64S0cXi06fxxH8FDOgtO3uuMFAwDQYJKoZIhvcNAQEF\nBQAwIzEhMB8GA1UEAxMYc2hpYmJvbGV0aC5zYWxpc2J1cnkuZWR1MB4XDTEzMDYy\nODEzMDA1M1oXDTMzMDYyODEzMDA1M1owIzEhMB8GA1UEAxMYc2hpYmJvbGV0aC5z\nYWxpc2J1cnkuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAlmxb\nXdTKUdXuAsbatHPWmcfBSYCwVKM3vQnNw0q7sKMD1G3dM0QOrdcplsKVXMjRz/Cv\n+UWIx/XLpBszh++1NRBts2vxgsFSazW1+KrMq1+phHIBaYIffBhlaXSmzPOthMQC\n96ZZvYrqEtSlN5FBx4RHokrmDRw+fAeOHIpIMhcHRscWp85UjK9pR/h/g4GRgRxn\nlH/OXjmiBVB2xA0UBl+7wM1XVyv61URCrZSduNtR8o7iBVFDaRCmE8PWasjaSVJg\nZCgSVY3qxVUZYlGhXCyjXXIRorHa03CZ2buJ3FyZNE9KHoriXOhvm9Dd9ZYBPhpk\nJZhxlLKPs8pKSjsNMwIDAQABo3cwdTBUBgNVHREETTBLghhzaGliYm9sZXRoLnNh\nbGlzYnVyeS5lZHWGL2h0dHBzOi8vc2hpYmJvbGV0aC5zYWxpc2J1cnkuZWR1L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBRuLalbqNtdk/j4ITBwvtjm1GP80zANBgkq\nhkiG9w0BAQUFAAOCAQEAT3R829x+66m4UmzDZtj2QY/IwXuOWjpwZsBptf38DdTJ\n2DtTDlqyzQt69Y+bWqCRICkl9GgCwN8+FqFAkGtQ/W3PdDg/O3t22XGPf8TLByrd\nO1p9AZ9XPegE0xFAxu+/sQx58KIX/6R6bL7XcH436M9w0ktyaQVHXbvLWH+7jFc2\nbCpHxVJ1k3zEgA3KI1K7Dp6n8pAVA35ZVP0EO1i7Wjae+pThMCzm8XVQ/9q8AuKy\ngYLlfmoR7oW8554uAku/74AnF7W89rMyaWcsv3mjTpLvYTNaD6BIRmG8ykuCRPq3\nkqmLDZGykto7PgAKNYbdUf1tzfrYMVhNBrGkMBv1QA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Salisbury University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.salisbury.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Salisbury University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dev2.webauth.soton.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Serviceline@soton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Serviceline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Peters"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:C.L.Peters@soton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Clayton"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dev2.webauth.soton.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSzCCAjOgAwIBAgIUPOcPr59teRI4vOHciwPs5r9o5TkwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwIzEhMB8GA1UEAxMYZGV2Mi53ZWJhdXRoLnNvdG9uLmFjLnVrMB4XDTEwMDYx\n\t\t\t\t\t\tNTEwNDIxNVoXDTMwMDYxNTEwNDIxNVowIzEhMB8GA1UEAxMYZGV2Mi53ZWJhdXRo\n\t\t\t\t\t\tLnNvdG9uLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkbKW\n\t\t\t\t\t\tFxrO0yijODGXGnZsTss0l1AFNxzbyKg1IgddAyCY6TGHdRoC6ZNfKJbWAw+QWf3B\n\t\t\t\t\t\tKJwyuu//krjW5E87wZM7Dh8c2FTC36+MJJd3DLGqefQqxrYhVdJ0/StZjHZlpOj/\n\t\t\t\t\t\tE6MMaJXhoCxQtQmP1aRQC8LSuXFv6bpDag9hjrZhaZhlWgaG0WgyPx8fF6AgZKjy\n\t\t\t\t\t\t1MSZj54orWP3esFMmD2ezDScE9soIrGm4eSSsdqPhgTilmog6Uz2hUtcsnmlbbgA\n\t\t\t\t\t\tlF83pRCXJ7OxkQO6mBJDQU9djmJdA0PoJP8FTla/ijZs6IiB9QiRdk7G2QbhPaP0\n\t\t\t\t\t\tsuUfeMqVnE1KqkRY1QIDAQABo3cwdTBUBgNVHREETTBLghhkZXYyLndlYmF1dGgu\n\t\t\t\t\t\tc290b24uYWMudWuGL2h0dHBzOi8vZGV2Mi53ZWJhdXRoLnNvdG9uLmFjLnVrL2lk\n\t\t\t\t\t\tcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSgTna3WVRPamY0vInfC+IQ8ePCGDANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAVWZaM6RBcVL8il/nWq30MvZXQ4JkisIQ9gpiMWMERU0j\n\t\t\t\t\t\tUyYdJX9tlXZkNpuVuILS356iO73JOPt1LblSpQ6ZiBSaiyJjQqdscj3T/Ek7hSlY\n\t\t\t\t\t\toSPy6ZjbNqDClIPmVnHgSXriIJ3Aa07S40HgIBQxkZvIspPnazhMz/+v1E/6f88c\n\t\t\t\t\t\tOc+0MNLXz4767rs4wcCFppi3ZPVw3ncs3Bk22T5rBEa5mRBd5QWSqrkWQ6cRCqfD\n\t\t\t\t\t\tmEn396/yBTAFpAWjc4TXmKy9hS8S9V5dZEWRexGH5GFvXCAkinm0FBH82xGjIPHK\n\t\t\t\t\t\td+ZyDCU4c8uPzoTu3FJLWrcOLWzaWH3OE/URxPKVfQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "soton.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://dev2.webauth.soton.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev2.webauth.soton.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://dev2.webauth.soton.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev2.webauth.soton.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dev2.webauth.soton.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev2.webauth.soton.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://dev2.webauth.soton.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev2.webauth.soton.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "soton.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSzCCAjOgAwIBAgIUPOcPr59teRI4vOHciwPs5r9o5TkwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwIzEhMB8GA1UEAxMYZGV2Mi53ZWJhdXRoLnNvdG9uLmFjLnVrMB4XDTEwMDYx\n\t\t\t\t\t\tNTEwNDIxNVoXDTMwMDYxNTEwNDIxNVowIzEhMB8GA1UEAxMYZGV2Mi53ZWJhdXRo\n\t\t\t\t\t\tLnNvdG9uLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkbKW\n\t\t\t\t\t\tFxrO0yijODGXGnZsTss0l1AFNxzbyKg1IgddAyCY6TGHdRoC6ZNfKJbWAw+QWf3B\n\t\t\t\t\t\tKJwyuu//krjW5E87wZM7Dh8c2FTC36+MJJd3DLGqefQqxrYhVdJ0/StZjHZlpOj/\n\t\t\t\t\t\tE6MMaJXhoCxQtQmP1aRQC8LSuXFv6bpDag9hjrZhaZhlWgaG0WgyPx8fF6AgZKjy\n\t\t\t\t\t\t1MSZj54orWP3esFMmD2ezDScE9soIrGm4eSSsdqPhgTilmog6Uz2hUtcsnmlbbgA\n\t\t\t\t\t\tlF83pRCXJ7OxkQO6mBJDQU9djmJdA0PoJP8FTla/ijZs6IiB9QiRdk7G2QbhPaP0\n\t\t\t\t\t\tsuUfeMqVnE1KqkRY1QIDAQABo3cwdTBUBgNVHREETTBLghhkZXYyLndlYmF1dGgu\n\t\t\t\t\t\tc290b24uYWMudWuGL2h0dHBzOi8vZGV2Mi53ZWJhdXRoLnNvdG9uLmFjLnVrL2lk\n\t\t\t\t\t\tcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSgTna3WVRPamY0vInfC+IQ8ePCGDANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAVWZaM6RBcVL8il/nWq30MvZXQ4JkisIQ9gpiMWMERU0j\n\t\t\t\t\t\tUyYdJX9tlXZkNpuVuILS356iO73JOPt1LblSpQ6ZiBSaiyJjQqdscj3T/Ek7hSlY\n\t\t\t\t\t\toSPy6ZjbNqDClIPmVnHgSXriIJ3Aa07S40HgIBQxkZvIspPnazhMz/+v1E/6f88c\n\t\t\t\t\t\tOc+0MNLXz4767rs4wcCFppi3ZPVw3ncs3Bk22T5rBEa5mRBd5QWSqrkWQ6cRCqfD\n\t\t\t\t\t\tmEn396/yBTAFpAWjc4TXmKy9hS8S9V5dZEWRexGH5GFvXCAkinm0FBH82xGjIPHK\n\t\t\t\t\t\td+ZyDCU4c8uPzoTu3FJLWrcOLWzaWH3OE/URxPKVfQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Southampton (Dev 2.x)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.soton.ac.uk/isolutions/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Southampton"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.lapinamk.fi/idp/shibboleth",
    {
      "entity_id": "https://idp.lapinamk.fi/idp/shibboleth",
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "true",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.lapinamk.fi/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.tokem.fi"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lapinamk.fi"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ramk.fi"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tokem.fi"
              },
              {
                "display_name": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lapin ammattikorkeakoulu"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lapplands YH"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lapland UAS"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "kalmar"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "finland"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "tags",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEbDCCA1SgAwIBAgIRAPU41ovbqC7No8q/JafFb+0wDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDAxMjMwMDAwMDBaFw0xNzAxMjIyMzU5NTlaMD0xITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEYMBYGA1UEAxMPaWRwLmxhcGlu\nYW1rLmZpMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAr050+KUHu9a+\nje75uUh/iQCBuoBdOtTRN5NHKK4cRKfM2+0+10zSvCxbcbul0T+yKbiHL5fVVOmm\nT3EZ0M0uInzjgICg63u5HmaF90DjFLpBtaZX/TTaWzvdFODFgqnZabyW/30ea7Zq\n5/8b0NK5Q/klEFYO4TIgkkBVwIlI6pGU/X9V596iEPHfyylR2dEIARviYTeqdQg3\nGVig/DngKBcan11pmEu3mhjVJl+yXRQeGhdeNXC7k8e3XMwEn/L2TEFy909qgHdT\n3Jm2y0g7SHzRoPt4UGJVx0t5dYFRPSEfJcxlP6/B5boU0RpYMa3AjBv7Nnk12+Ww\nvNQAf8Mt3wIDAQABo4IBbDCCAWgwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH\n6pDjue0wHQYDVR0OBBYEFBghh/DvfWtZXDg/l/liGeY0dFwlMA4GA1UdDwEB/wQE\nAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcD\nAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAx\nMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNy\nbDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRl\ncmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8vb2Nz\ncC50Y3MudGVyZW5hLm9yZzAaBgNVHREEEzARgg9pZHAubGFwaW5hbWsuZmkwDQYJ\nKoZIhvcNAQEFBQADggEBACI8smMl17k5l6eOmo1E9yZkF/QasMOd7NaiNT7Cmddt\nnAHtPG7nNFJX+Vj7aOhxZb6Dicp8aPueeswp1tX36PLj4QImXwLs/MoZ0DRUpsAI\ndqBucmey2exV/eIsfLoEOGnoe9aJJHbf1FS/0c4JR7PUfKShp7mYrROKmVZ+N/ya\nohzJ/hrZTS8lhx46mWsy8WJoZyvV8SSU7SJTblRU1rbjhMIwXWGpAXgq69Oa72IY\nSUNstvZgVwotwKijIBs0iDamz8pzrMKBN1Qft+gzNRC19ijM3S+Ydrx23uBOJz9S\niBFAJu7GLakQ21kx0iJw7Cvw3dG4QswwoiTV55pAx6g="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Taipale"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:markku.taipale@lapinamk.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Markku"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Heikkila"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jukka.heikkila@lapinamk.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jukka"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lapin amk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lapland University of Applied Sciences"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lapplands Yrkesh\u00f6gskola"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lapinamk.fi"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lapinamk.fi"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lapinamk.fi"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Lapin amk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Lapland University of Applied Sciences"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Lapplands Yrkesh\u00f6gskola"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor"
    }
  ],
  [
    "https://shibboleth.midkent.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ict.helpdesk@midkent.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ICT Help"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ict.helpdesk@midkent.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ICT Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.midkent.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-10-02T15:56:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTzCCAjegAwIBAgIUNoEJdB/0XMNzrx6TpF9l+vmgmH0wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJDEiMCAGA1UEAxMZc2hpYmJvbGV0aDIubWlka2VudC5hYy51azAeFw0xNDA1\n\t\t\t\t\t\tMDYxMzEzNTVaFw0zNDA1MDYxMzEzNTVaMCQxIjAgBgNVBAMTGXNoaWJib2xldGgy\n\t\t\t\t\t\tLm1pZGtlbnQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCZ\n\t\t\t\t\t\tFxthTyRgoHipxaAAoald9sOKxKf6dmrKSu8aZe0aI2vELihyQ80EBbhq+ELFUKzr\n\t\t\t\t\t\t+ZMA2BGC7j2xlzplC7evTx1hTIFwCr6r+5Ezh6yhozKDkMCLVh8SkCqoMuVLkwr+\n\t\t\t\t\t\t414KLGmmPqS51QuRajcDJu/5kg12CI8rvw3M6NvEhmduwuRZFCwuDOEB9nftY3PY\n\t\t\t\t\t\t9B6bIx7wBLO9YflPbfP/+kZUqp5iwoWZrsHiX/do8w2zHp5hH0ny3dmAtqNhDzEA\n\t\t\t\t\t\txCvvyeU0FXjKcz+0INbl4VMvyjGzfrqSL8CuDx8xegcIWg3p8Q7ZqqNAIOb+3GQ0\n\t\t\t\t\t\tMfv+SNteBe1wsMXzOcIXAgMBAAGjeTB3MFYGA1UdEQRPME2CGXNoaWJib2xldGgy\n\t\t\t\t\t\tLm1pZGtlbnQuYWMudWuGMGh0dHBzOi8vc2hpYmJvbGV0aDIubWlka2VudC5hYy51\n\t\t\t\t\t\tay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUGgaMdXWEPm2ueSgt1bplk0u9X1Mw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAFLDEKLNrzHBhOjb3jING7WIb57xMaTCN2n57blH\n\t\t\t\t\t\tPWD826DN9EQiqh8zCbhw/b8K7GQmZBbL7egvh0imC7kzdEqDiGeK4BV7YG1i1TUA\n\t\t\t\t\t\thS8mQvrMq7xl7SHPOEHEFxxZE2b65R3JYZQhyrFaOOEGv95d+8QbOG7XaAC5JBLS\n\t\t\t\t\t\tAk8fnTEGoUAB4X7VPvdzUe48WHAf3O7GkhvbMTZ0t9nqGI5teTltQNINbI5DEhBJ\n\t\t\t\t\t\tdTJO4nNaoq6TBit1NCGIlKxCzhYMZFPLEsLSqW7D+CVZurqOaLlr5EyIHVNpx4ai\n\t\t\t\t\t\tvNAdDLuB+XgGcIT+ib/E14TMVg3qCAbW6YqD9N2ZywV41Wk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "midkent.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth2.midkent.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2.midkent.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth2.midkent.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2.midkent.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth2.midkent.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2.midkent.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth2.midkent.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2.midkent.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "midkent.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTzCCAjegAwIBAgIUNoEJdB/0XMNzrx6TpF9l+vmgmH0wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJDEiMCAGA1UEAxMZc2hpYmJvbGV0aDIubWlka2VudC5hYy51azAeFw0xNDA1\n\t\t\t\t\t\tMDYxMzEzNTVaFw0zNDA1MDYxMzEzNTVaMCQxIjAgBgNVBAMTGXNoaWJib2xldGgy\n\t\t\t\t\t\tLm1pZGtlbnQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCZ\n\t\t\t\t\t\tFxthTyRgoHipxaAAoald9sOKxKf6dmrKSu8aZe0aI2vELihyQ80EBbhq+ELFUKzr\n\t\t\t\t\t\t+ZMA2BGC7j2xlzplC7evTx1hTIFwCr6r+5Ezh6yhozKDkMCLVh8SkCqoMuVLkwr+\n\t\t\t\t\t\t414KLGmmPqS51QuRajcDJu/5kg12CI8rvw3M6NvEhmduwuRZFCwuDOEB9nftY3PY\n\t\t\t\t\t\t9B6bIx7wBLO9YflPbfP/+kZUqp5iwoWZrsHiX/do8w2zHp5hH0ny3dmAtqNhDzEA\n\t\t\t\t\t\txCvvyeU0FXjKcz+0INbl4VMvyjGzfrqSL8CuDx8xegcIWg3p8Q7ZqqNAIOb+3GQ0\n\t\t\t\t\t\tMfv+SNteBe1wsMXzOcIXAgMBAAGjeTB3MFYGA1UdEQRPME2CGXNoaWJib2xldGgy\n\t\t\t\t\t\tLm1pZGtlbnQuYWMudWuGMGh0dHBzOi8vc2hpYmJvbGV0aDIubWlka2VudC5hYy51\n\t\t\t\t\t\tay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUGgaMdXWEPm2ueSgt1bplk0u9X1Mw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAFLDEKLNrzHBhOjb3jING7WIb57xMaTCN2n57blH\n\t\t\t\t\t\tPWD826DN9EQiqh8zCbhw/b8K7GQmZBbL7egvh0imC7kzdEqDiGeK4BV7YG1i1TUA\n\t\t\t\t\t\thS8mQvrMq7xl7SHPOEHEFxxZE2b65R3JYZQhyrFaOOEGv95d+8QbOG7XaAC5JBLS\n\t\t\t\t\t\tAk8fnTEGoUAB4X7VPvdzUe48WHAf3O7GkhvbMTZ0t9nqGI5teTltQNINbI5DEhBJ\n\t\t\t\t\t\tdTJO4nNaoq6TBit1NCGIlKxCzhYMZFPLEsLSqW7D+CVZurqOaLlr5EyIHVNpx4ai\n\t\t\t\t\t\tvNAdDLuB+XgGcIT+ib/E14TMVg3qCAbW6YqD9N2ZywV41Wk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mid-Kent College of Higher and Further Education"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.midkent.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Mid-Kent College of Higher and Further Education"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shiblogin.hull.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:libhelp@hull.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Library help"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McLoughlin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Michael.McLoughlin@hull.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shiblogin.hull.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-06-28T11:48:17Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIULUB2P8Qd8xEzfYUd14VtQqBiwXswDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAxMUc2hpYmxvZ2luLmh1bGwuYWMudWswHhcNMTMwNjI2MTQy\n\t\t\t\t\t\tODQwWhcNMzMwNjI2MTQyODQwWjAfMR0wGwYDVQQDExRzaGlibG9naW4uaHVsbC5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK4dV4SFn79Mv9KA\n\t\t\t\t\t\tul1dlv9rPUfQuZPBVkNNjCtGk+KA3RpDPcidgV/2s8AdMG8NTknoT4vFzPYlgyaS\n\t\t\t\t\t\tg2/tpzHKx9XqqJJQcAG4EvA3Pf8GF80Jk/hiI9T21tlp1S10g6KAU9hhqcsFZPR1\n\t\t\t\t\t\tjSCtK45yjQ/WMzxdh/ds99qmCkjEQIn253Ra15vcoQApdSCusPO5oTENBK0SUTQe\n\t\t\t\t\t\tuhGdWJlFBDHs7eHX+Fngyx066FrlrgUsCpiCor54m7DTB3NBOCD5LlpZMGJonrS6\n\t\t\t\t\t\tO3XX/Bdt03ZdbPVLoAMb1hDY0uaIxrcCg3gMuIa9+wE5PsA/gvU60+uv3lzVzvsI\n\t\t\t\t\t\tw81aZxsCAwEAAaNvMG0wTAYDVR0RBEUwQ4IUc2hpYmxvZ2luLmh1bGwuYWMudWuG\n\t\t\t\t\t\tK2h0dHBzOi8vc2hpYmxvZ2luLmh1bGwuYWMudWsvaWRwL3NoaWJib2xldGgwHQYD\n\t\t\t\t\t\tVR0OBBYEFLMPSMcSqArLLEqd9nbiw7CBYaO3MA0GCSqGSIb3DQEBBQUAA4IBAQCs\n\t\t\t\t\t\tsKAv5nTTPIJ70oUcqtifzfHIYYCKnAKU0M6ug6Vcd0mFZJJ705u3dmtsTDylbDC7\n\t\t\t\t\t\tsNDHtw/gbrmPb6PCGK0+8Ifr0yl16/i5vAzm7oCN2OqTsX94qAlWuey8xNIF9SW5\n\t\t\t\t\t\t3q7n2jTOvOo4293pV1hNFGkpZSrqM/KaNhgOxOKx2ezb17QvEmKXX/JUJprOA+Y1\n\t\t\t\t\t\tiWz5dMqvNl4a8Gbvp71bMtREfKa6m904CBCK69NKllb4kqRRoXggkVQjHQlLChv1\n\t\t\t\t\t\t+e+c96h5fZroNkwofpqn6rpmvQfSmV2eRkpShhOjXXOarehRMQ+TIJJhdYR/w/8R\n\t\t\t\t\t\t/I7/29liqhV3JptWNE4C"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hull.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shiblogin.hull.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shiblogin.hull.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shiblogin.hull.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shiblogin.hull.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shiblogin.hull.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shiblogin.hull.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shiblogin.hull.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shiblogin.hull.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shiblogin.hull.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shiblogin.hull.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shiblogin.hull.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hull.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://library.hull.ac.uk/screens/newlogo.jpg",
                    "height": "80",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Hull (Shibboleth)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIULUB2P8Qd8xEzfYUd14VtQqBiwXswDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAxMUc2hpYmxvZ2luLmh1bGwuYWMudWswHhcNMTMwNjI2MTQy\n\t\t\t\t\t\tODQwWhcNMzMwNjI2MTQyODQwWjAfMR0wGwYDVQQDExRzaGlibG9naW4uaHVsbC5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK4dV4SFn79Mv9KA\n\t\t\t\t\t\tul1dlv9rPUfQuZPBVkNNjCtGk+KA3RpDPcidgV/2s8AdMG8NTknoT4vFzPYlgyaS\n\t\t\t\t\t\tg2/tpzHKx9XqqJJQcAG4EvA3Pf8GF80Jk/hiI9T21tlp1S10g6KAU9hhqcsFZPR1\n\t\t\t\t\t\tjSCtK45yjQ/WMzxdh/ds99qmCkjEQIn253Ra15vcoQApdSCusPO5oTENBK0SUTQe\n\t\t\t\t\t\tuhGdWJlFBDHs7eHX+Fngyx066FrlrgUsCpiCor54m7DTB3NBOCD5LlpZMGJonrS6\n\t\t\t\t\t\tO3XX/Bdt03ZdbPVLoAMb1hDY0uaIxrcCg3gMuIa9+wE5PsA/gvU60+uv3lzVzvsI\n\t\t\t\t\t\tw81aZxsCAwEAAaNvMG0wTAYDVR0RBEUwQ4IUc2hpYmxvZ2luLmh1bGwuYWMudWuG\n\t\t\t\t\t\tK2h0dHBzOi8vc2hpYmxvZ2luLmh1bGwuYWMudWsvaWRwL3NoaWJib2xldGgwHQYD\n\t\t\t\t\t\tVR0OBBYEFLMPSMcSqArLLEqd9nbiw7CBYaO3MA0GCSqGSIb3DQEBBQUAA4IBAQCs\n\t\t\t\t\t\tsKAv5nTTPIJ70oUcqtifzfHIYYCKnAKU0M6ug6Vcd0mFZJJ705u3dmtsTDylbDC7\n\t\t\t\t\t\tsNDHtw/gbrmPb6PCGK0+8Ifr0yl16/i5vAzm7oCN2OqTsX94qAlWuey8xNIF9SW5\n\t\t\t\t\t\t3q7n2jTOvOo4293pV1hNFGkpZSrqM/KaNhgOxOKx2ezb17QvEmKXX/JUJprOA+Y1\n\t\t\t\t\t\tiWz5dMqvNl4a8Gbvp71bMtREfKa6m904CBCK69NKllb4kqRRoXggkVQjHQlLChv1\n\t\t\t\t\t\t+e+c96h5fZroNkwofpqn6rpmvQfSmV2eRkpShhOjXXOarehRMQ+TIJJhdYR/w/8R/\n\t\t\t\t\t\tI7/29liqhV3JptWNE4C"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Hull (Shibboleth)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hull.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Hull"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://muse.jhu.edu/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:muse@press.jhu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Project MUSE"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Malloy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:malloy@jhu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://muse.jhu.edu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2012-02-24T14:57:13Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Project MUSE"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://muse.jhu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Johns Hopkins University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://muse.jhu.edu/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://muse.jhu.edu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://muse.jhu.edu/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://muse.jhu.edu/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://muse.jhu.edu/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDtTCCAp2gAwIBAgIJAJsinS4vDTq8MA0GCSqGSIb3DQEBCwUAMHExCzAJBgNV\n\t\t\t\t\t\tBAYTAlVTMREwDwYDVQQIDAhNYXJ5bGFuZDESMBAGA1UEBwwJQmFsdGltb3JlMQ0w\n\t\t\t\t\t\tCwYDVQQKDARKSFVQMRUwEwYDVQQLDAxQcm9qZWN0IE1VU0UxFTATBgNVBAMMDG11\n\t\t\t\t\t\tc2Uuamh1LmVkdTAeFw0xNTA4MTgyMTA0MzRaFw0yMDA4MTYyMTA0MzRaMHExCzAJ\n\t\t\t\t\t\tBgNVBAYTAlVTMREwDwYDVQQIDAhNYXJ5bGFuZDESMBAGA1UEBwwJQmFsdGltb3Jl\n\t\t\t\t\t\tMQ0wCwYDVQQKDARKSFVQMRUwEwYDVQQLDAxQcm9qZWN0IE1VU0UxFTATBgNVBAMM\n\t\t\t\t\t\tDG11c2Uuamh1LmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJqS\n\t\t\t\t\t\t/g/BqhsCoRpoq427pZFAq0MkP2VvDkUYmMlq3njNGMcvMxtxnra7hWAySwiodE2O\n\t\t\t\t\t\t4H+puUlMjVvYHoDQr9/n2rysPQx9OiOP/8GKgV36GNIcy0WuUXO+JY/dAlLaV/ah\n\t\t\t\t\t\ts+UILC7SJ40cMhj/+EcdaOYMDrdI+ZA+e6XM+oHfOWFkUaCpih+TKQheFQnnAnWY\n\t\t\t\t\t\tEMzYtXtGbemPtJJ/0vevvqR9bFYJE+eTsJ9rBS/nnBBqbJ3V5krdRNUmsa0u/Mlj\n\t\t\t\t\t\tt5fomwzCIAIVnKFXBuCjMLNEkSUYZK29hmHOEvts1pyxAWtgY0rxOp70CT9E3hhY\n\t\t\t\t\t\txRhOFjjp9dosBFO1Ee0CAwEAAaNQME4wHQYDVR0OBBYEFAvC4mzMXcwfdOwWLpah\n\t\t\t\t\t\t8/peibBpMB8GA1UdIwQYMBaAFAvC4mzMXcwfdOwWLpah8/peibBpMAwGA1UdEwQF\n\t\t\t\t\t\tMAMBAf8wDQYJKoZIhvcNAQELBQADggEBAB7tTBcm1rYwJk8yosLkC4kBbeow8GCq\n\t\t\t\t\t\t9Ap+ddnjEJPll7M44cx7yj7rW34/NFl9BTohmDkMtnLE+zWFErvJMOX5pQWLOGKt\n\t\t\t\t\t\tP/fsfcHjpnd8H7UhmF5986mzB1HsZP+F2Nbvuv+WuDiIXdb4eM0zjliJ/Jvqbzkt\n\t\t\t\t\t\t5yXSiJJfqpwnhMYNkVNJ/Igt88gxU4aggYla4Iw15R0K71Vqcvr++ukcM/ynRXU2\n\t\t\t\t\t\toHZUC5SuhcR2dJp7Ot3j1UHJB8ZQk3128v33S2ConZWqkw1WvXiav1kuocWsv0Lk\n\t\t\t\t\t\tsDIRUBUgNv1n6knfP5PLUiQlE5tt4yG1ZbXdDhCJ4Qho8vNNZkTx00c="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://muse.jhu.edu/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://muse.jhu.edu/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://muse.jhu.edu/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://muse.jhu.edu/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://muse.jhu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://muse.jhu.edu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://muse.jhu.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://muse.jhu.edu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://muse.jhu.edu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://muse.jhu.edu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idpcove.trafford.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fitton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Dave.Fitton@trafford.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fitton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Dave.Fitton@trafford.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idpcove.trafford.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-02-23T17:18:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDajCCAlICCQCVc3XLOQv9+zANBgkqhkiG9w0BAQsFADB3MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjETMBEGA1UECAwKQWx0cmluY2hhbTEXMBUGA1UEBwwOV2VzdCBUaW1wZXJsZXkx\n\t\t\t\t\t\tGTAXBgNVBAoMEFRyYWZmb3JkIENvbGxlZ2UxHzAdBgNVBAMMFmlkcGNvdmUudHJh\n\t\t\t\t\t\tZmZvcmQuYWMudWswHhcNMTQxMjA5MTU1NTM0WhcNMzQxMjA0MTU1NTM0WjB3MQsw\n\t\t\t\t\t\tCQYDVQQGEwJHQjETMBEGA1UECAwKQWx0cmluY2hhbTEXMBUGA1UEBwwOV2VzdCBU\n\t\t\t\t\t\taW1wZXJsZXkxGTAXBgNVBAoMEFRyYWZmb3JkIENvbGxlZ2UxHzAdBgNVBAMMFmlk\n\t\t\t\t\t\tcGNvdmUudHJhZmZvcmQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\n\t\t\t\t\t\tAoIBAQD7sJfsHDjKt7dMslxllHKBiHTHBeOBLs1KDY5Kg25Sjkp02ait4oq4sQCX\n\t\t\t\t\t\t3UDiaxMBhhmJEgw+W7wBuwClB3WCZi6aP2sat/tW9szyitzPyFC/2LZOjlNMiahF\n\t\t\t\t\t\t8xRGXyA7tjTuZXCoY1wYhMUu4Hg6qtqHK2ttkGZ8+3zotGx43x+d3LvO5iPfJb9b\n\t\t\t\t\t\tXPVqaEqNbwhlUoM8L9CP4o+QQGNgVfLZb24L2st0m40RJEkOZ/Z3gx7/CofZMwWX\n\t\t\t\t\t\tB9rm2Qe7zqmXTgXvU9HJzVNHm9+TIpgWx70ShlvW23QNMhh7eVB7RCzkV8kdIzbg\n\t\t\t\t\t\tGnIICbv71ZQCo0TlsWX2kMamS3IhAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAAp+\n\t\t\t\t\t\tJmdx1q13B+nUfMjhccBOK4+AVqCn9+HIa7cJhaMn1sOjSzlA1DlXYPc5yUMWqybC\n\t\t\t\t\t\t97zM0rdpEWs3Agd0N48tpRWW3g2qXksRCqIqt7c+pYzWwTzhVSx4cLqNxSkvQzye\n\t\t\t\t\t\tnkh6J5FNsJLtf3vSLSpJMoCtA5RX2XmtzfiXT3qCX2MREhp0QsOsuJs+wrEGk5lI\n\t\t\t\t\t\tqmdaNl77S0srnYHly4ARx00938Uh3aaj2B7/sVO9DL+4A+jrp3MPkvU4V+0kRRGM\n\t\t\t\t\t\tzyHmhmFL4JdeMZVKlYOBfa5BaRelpB0b43d6BJj7U3DYWaloLk+5Ybf1rXm+DN6f\n\t\t\t\t\t\tT8iifVdbRcCwOj+bpI8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "trafford.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idpcove.trafford.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idpcove.trafford.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idpcove.trafford.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idpcove.trafford.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idpcove.trafford.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idpcove.trafford.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idpcove.trafford.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idpcove.trafford.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "trafford.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDajCCAlICCQCVc3XLOQv9+zANBgkqhkiG9w0BAQsFADB3MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjETMBEGA1UECAwKQWx0cmluY2hhbTEXMBUGA1UEBwwOV2VzdCBUaW1wZXJsZXkx\n\t\t\t\t\t\tGTAXBgNVBAoMEFRyYWZmb3JkIENvbGxlZ2UxHzAdBgNVBAMMFmlkcGNvdmUudHJh\n\t\t\t\t\t\tZmZvcmQuYWMudWswHhcNMTQxMjA5MTU1NTM0WhcNMzQxMjA0MTU1NTM0WjB3MQsw\n\t\t\t\t\t\tCQYDVQQGEwJHQjETMBEGA1UECAwKQWx0cmluY2hhbTEXMBUGA1UEBwwOV2VzdCBU\n\t\t\t\t\t\taW1wZXJsZXkxGTAXBgNVBAoMEFRyYWZmb3JkIENvbGxlZ2UxHzAdBgNVBAMMFmlk\n\t\t\t\t\t\tcGNvdmUudHJhZmZvcmQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\n\t\t\t\t\t\tAoIBAQD7sJfsHDjKt7dMslxllHKBiHTHBeOBLs1KDY5Kg25Sjkp02ait4oq4sQCX\n\t\t\t\t\t\t3UDiaxMBhhmJEgw+W7wBuwClB3WCZi6aP2sat/tW9szyitzPyFC/2LZOjlNMiahF\n\t\t\t\t\t\t8xRGXyA7tjTuZXCoY1wYhMUu4Hg6qtqHK2ttkGZ8+3zotGx43x+d3LvO5iPfJb9b\n\t\t\t\t\t\tXPVqaEqNbwhlUoM8L9CP4o+QQGNgVfLZb24L2st0m40RJEkOZ/Z3gx7/CofZMwWX\n\t\t\t\t\t\tB9rm2Qe7zqmXTgXvU9HJzVNHm9+TIpgWx70ShlvW23QNMhh7eVB7RCzkV8kdIzbg\n\t\t\t\t\t\tGnIICbv71ZQCo0TlsWX2kMamS3IhAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAAp+\n\t\t\t\t\t\tJmdx1q13B+nUfMjhccBOK4+AVqCn9+HIa7cJhaMn1sOjSzlA1DlXYPc5yUMWqybC\n\t\t\t\t\t\t97zM0rdpEWs3Agd0N48tpRWW3g2qXksRCqIqt7c+pYzWwTzhVSx4cLqNxSkvQzye\n\t\t\t\t\t\tnkh6J5FNsJLtf3vSLSpJMoCtA5RX2XmtzfiXT3qCX2MREhp0QsOsuJs+wrEGk5lI\n\t\t\t\t\t\tqmdaNl77S0srnYHly4ARx00938Uh3aaj2B7/sVO9DL+4A+jrp3MPkvU4V+0kRRGM\n\t\t\t\t\t\tzyHmhmFL4JdeMZVKlYOBfa5BaRelpB0b43d6BJj7U3DYWaloLk+5Ybf1rXm+DN6f\n\t\t\t\t\t\tT8iifVdbRcCwOj+bpI8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Trafford College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.trafford.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Trafford College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://stir.unidesk.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:IS.Helpdesk@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-techmgt@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Application Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://stir.unidesk.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-20T13:24:51Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Unidesk - University of Stirling"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://stir.unidesk.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://stir.unidesk.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://stir.unidesk.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://stir.unidesk.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://stir.unidesk.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://stir.unidesk.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAPHsl6kKrFrnMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\n\t\t\t\t\t\tBAMTEmxpdmUudW5pZGVzay5hYy51azAeFw0xMjA0MTExNDU4MjhaFw0yMjA0MDkx\n\t\t\t\t\t\tNDU4MjhaMB0xGzAZBgNVBAMTEmxpdmUudW5pZGVzay5hYy51azCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBAL9qh/Dehm5jJdWdeFPNKqcjMdiqii8Iz9Rc\n\t\t\t\t\t\ttCAsEwRsYww4EQDG7MxG5hg4NSS+iIPFCp9gR+G7hTnZAMGgNpxs2vk4vs9lmhRY\n\t\t\t\t\t\tGmB7Y1NFloP9Pcsu+MaufaLzxi6bzIXV4dBVHqVnIcgxchDIsXmPE6xlq4poEq+q\n\t\t\t\t\t\tXJ3aFE/eWwxfwN9z0s5yeICzsil73xk9T9NLeNAeYq+jfVTcdqDbBHY6eHtMOYh/\n\t\t\t\t\t\tuPVYYxkKXjkgSH5cwG0b+7qN4z+uzKDNBXxnI1Nz+bLOazXW6ljQIDtAPQZMJSlr\n\t\t\t\t\t\t3OepVaQS+fMBi0Sku5yvADgINdXxkz6H4Zx4pZg/rTQBQ/8u2esCAwEAAaNAMD4w\n\t\t\t\t\t\tHQYDVR0RBBYwFIISbGl2ZS51bmlkZXNrLmFjLnVrMB0GA1UdDgQWBBQ2tPlzxC8e\n\t\t\t\t\t\takC2nh9qrG4TWfI3tzANBgkqhkiG9w0BAQUFAAOCAQEAWPY3Nv9ChZ+4XVNANhLq\n\t\t\t\t\t\tfGF7SbiPmUNj9vWGNjCp8Ma0tdDOZPvqBRzxKkkR+LS+fHpSQQ54RuNeZrulWBiN\n\t\t\t\t\t\takZe3LZiSH9AHG2uD0lDuxr0UQt1AHGDiLjFXuRg9+CdqqrdT3Anmy6exDDfRsjH\n\t\t\t\t\t\tk+ZJflkEtqTNd0dbEVlkYlg8Baqx/ZMOxkccx8PtQt1yptAMsH4Rn92vXLd9d3JM\n\t\t\t\t\t\tH1mrFuiriqrgsAfVLmzc4WeGmB+dK01cSB+CY7hKnoe7ds1y7kNhOmZ9HP3Iy7ev\n\t\t\t\t\t\tgF2RCdnqkP9zScihW4b20PlVa/sWMUyCj2uZE1lSO51PJcGVU0H/JFrBEpaM7u6t\n\t\t\t\t\t\tjg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://stir.unidesk.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://stir.unidesk.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://stir.unidesk.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://stir.unidesk.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://stir.unidesk.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://stir.unidesk.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://acm.jordanpublishing.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Needham"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:andrew_needham@jordanpublishing.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tomlin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul_tomlin@jordanpublishing.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:electronic@jordanpublishing.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jordan Publishing technical support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://acm.jordanpublishing.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-01-24T14:36:38Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Jordan Publishing / Family Law"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jordanpublishing.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Jordan Publishing Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://acm.jordanpublishing.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://acm.jordanpublishing.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://acm.jordanpublishing.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://acm.jordanpublishing.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://acm.jordanpublishing.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://acm.jordanpublishing.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://acm.jordanpublishing.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "For access to law reports, case law, commentary, precedents and legal and administrative changes."
                  }
                ],
                "logo": [
                  {
                    "text": "https://acm.jordanpublishing.co.uk/jordanslogo.gif",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "252"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Jordan Publishing / Family Law"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDXDCCAkQCCQDTaBl/liB+TjANBgkqhkiG9w0BAQUFADBwMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEQMA4GA1UECBMHQnJpc3RvbDEQMA4GA1UEBxMHQnJpc3RvbDEYMBYGA1UEChMP\n\t\t\t\t\t\tSm9yZGFucyBMaW1pdGVkMSMwIQYDVQQDExphY20uam9yZGFucHVibGlzaGluZy5j\n\t\t\t\t\t\tby51azAeFw0xNDA0MTExMzI0MDhaFw0zNDA0MDYxMzI0MDhaMHAxCzAJBgNVBAYT\n\t\t\t\t\t\tAkdCMRAwDgYDVQQIEwdCcmlzdG9sMRAwDgYDVQQHEwdCcmlzdG9sMRgwFgYDVQQK\n\t\t\t\t\t\tEw9Kb3JkYW5zIExpbWl0ZWQxIzAhBgNVBAMTGmFjbS5qb3JkYW5wdWJsaXNoaW5n\n\t\t\t\t\t\tLmNvLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxdNdQ/zoNOHv\n\t\t\t\t\t\textaFGXUUXF+9ZtugYQ/crjvLAe5JHtyHf/AVm3U9sKk/4y5GTbkgGAwCsVQJuBL\n\t\t\t\t\t\tnsTRquAex08OPjmLrz2XVxo6jJ7FPxVTpawIXE8+fsbQeVX2RYteRMDFmXWvESEc\n\t\t\t\t\t\tD3i3C8O93BoDq5DbtJFTd5UQ2QLxIAmNFo+UWSrQeUIM208NETIEeanzhz3ijeFL\n\t\t\t\t\t\tB+zrDbU/1JbFLTrHfi1gQ1hU+RuSqm/W/5CJ4DxH7yBvnkHvtPpUKqD2bTMz0hRs\n\t\t\t\t\t\txDz1+OIwycpuwDYjoGhahXmYhjy+p4psY4quT/KU3AUiXJXNI2oQxLSvIt5jPUHp\n\t\t\t\t\t\tFECw7TCzaQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCqh2dvtGPtBBuT+AfL2xhB\n\t\t\t\t\t\tnhK0hElXSK6GknMKVdABfEO61d0VOxcAg+Hz8aE1bAdyzOej4aWj96Jx6bJWtuGs\n\t\t\t\t\t\tVrxEIH27lbu5u/MNPfcw8HjsN+lm1gadgsgjOv6+upzyNmaKuGR6B+1hOBlju3W5\n\t\t\t\t\t\t2J7qMtO7HO8Rksw+kJu2LtJqxtf3HX6/guL21OnlwTTaeBj0mysrt6ZVwRfKhw07\n\t\t\t\t\t\t2pDkzODd43svRZC2++k6vuhapuiiJaaBEBBnNgP5+nqRDXGbKRNXEIb3LAAfckBP\n\t\t\t\t\t\txpTob2Kh4PtL+W5T/4P0CreCM9f6V8GQemPBioiMrU9ihn9qChy/bYvPwRW7D+Rk"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://acm.jordanpublishing.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://acm.jordanpublishing.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://acm.jordanpublishing.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://acm.jordanpublishing.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://acm.jordanpublishing.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://acm.jordanpublishing.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.newdur.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.newdur.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/newdur.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/newdur.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "newdur.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "New College Durham"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.newdur.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://bm.stars.manchester.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pssauth.support@manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stars Authentication Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pssauth.support@manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stars Authentication Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bm.stars.manchester.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Manchester: Building Maintenance Organization"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.manchester.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Manchester"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bm.stars.manchester.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://bm.stars.manchester.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bm.stars.manchester.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bm.stars.manchester.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://bm.stars.manchester.ac.uk/Shibboleth.sso/STARSDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3zCCAcegAwIBAgIJAJuqRlY/1A1jMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\n\t\t\t\t\t\tBAMTCHZpbGxhbnVzMB4XDTA5MDUyMjA5MjYyN1oXDTE5MDUyMDA5MjYyN1owEzER\n\t\t\t\t\t\tMA8GA1UEAxMIdmlsbGFudXMwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDMytraxBwzCmyK3cnajuHo5sb2Hhs0aTIAEaUTpcP2qo/yQlT/S5Wjsm5tPtue\n\t\t\t\t\t\tpA8z0h56Y4on/k9gGGXnjej+23pfX/dPFCLEyE3MODunTkml1ObptRdMJT6CWRwg\n\t\t\t\t\t\tm9tdWr8r355vAbS/nEn0s0z3dwHBSuf7/q4GZoBkdbUG5TkOJidlWwe5y2OXSspU\n\t\t\t\t\t\tlehsON69DPXTxujsn9QNYzmdGxui+nrhHsj8hjPEQc9QcFDq7kXuDkM3Lry84h2p\n\t\t\t\t\t\tkWGXRebVqEGvs6b7CUxvS5xiOChpx6fTi0/LZQQRCzrtVOuYeb9o6wVejmzW6qun\n\t\t\t\t\t\tKH7dJCc14fgN2Icd7XYqIXYNAgMBAAGjNjA0MBMGA1UdEQQMMAqCCHZpbGxhbnVz\n\t\t\t\t\t\tMB0GA1UdDgQWBBTwGMy2sDPsfBZdE/1WuaxJDqVNuzANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAlvJzqsg5+ZiZ0XChtGL3j1n8PbGeah5AfEfXRvS6RrHu7/3w4WOy+XBpGteu\n\t\t\t\t\t\t8rqE/HkgqcpnXGS61TEU2HmdnNxqMTpGZoI7zbOkkcsNpvvG+dU5OdlEoTgJHuRI\n\t\t\t\t\t\t12EgBWjTXMweohxDkLANWaqfB9yVDT1MspMkxKmYalZK95N9M/d6gJfXWwU4GSd0\n\t\t\t\t\t\t4jfwMr9FzpOLAbxAHIohMA2djNfA2gNuve8PqIfBz6iaUAN0SGhGWMWWEL2B+uYZ\n\t\t\t\t\t\t2vtfZ+CtpWQteMiXFGEfEL/3U5OtjBxt7JaQxaJJ6iRTk5jdl+EI4NxHzmITf3+O\n\t\t\t\t\t\tEId1IbbmDWSHoeSw5za0bFOJcg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3zCCAcegAwIBAgIJAJuqRlY/1A1jMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\n\t\t\t\t\t\tBAMTCHZpbGxhbnVzMB4XDTA5MDUyMjA5MjYyN1oXDTE5MDUyMDA5MjYyN1owEzER\n\t\t\t\t\t\tMA8GA1UEAxMIdmlsbGFudXMwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDMytraxBwzCmyK3cnajuHo5sb2Hhs0aTIAEaUTpcP2qo/yQlT/S5Wjsm5tPtue\n\t\t\t\t\t\tpA8z0h56Y4on/k9gGGXnjej+23pfX/dPFCLEyE3MODunTkml1ObptRdMJT6CWRwg\n\t\t\t\t\t\tm9tdWr8r355vAbS/nEn0s0z3dwHBSuf7/q4GZoBkdbUG5TkOJidlWwe5y2OXSspU\n\t\t\t\t\t\tlehsON69DPXTxujsn9QNYzmdGxui+nrhHsj8hjPEQc9QcFDq7kXuDkM3Lry84h2p\n\t\t\t\t\t\tkWGXRebVqEGvs6b7CUxvS5xiOChpx6fTi0/LZQQRCzrtVOuYeb9o6wVejmzW6qun\n\t\t\t\t\t\tKH7dJCc14fgN2Icd7XYqIXYNAgMBAAGjNjA0MBMGA1UdEQQMMAqCCHZpbGxhbnVz\n\t\t\t\t\t\tMB0GA1UdDgQWBBTwGMy2sDPsfBZdE/1WuaxJDqVNuzANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAlvJzqsg5+ZiZ0XChtGL3j1n8PbGeah5AfEfXRvS6RrHu7/3w4WOy+XBpGteu\n\t\t\t\t\t\t8rqE/HkgqcpnXGS61TEU2HmdnNxqMTpGZoI7zbOkkcsNpvvG+dU5OdlEoTgJHuRI\n\t\t\t\t\t\t12EgBWjTXMweohxDkLANWaqfB9yVDT1MspMkxKmYalZK95N9M/d6gJfXWwU4GSd0\n\t\t\t\t\t\t4jfwMr9FzpOLAbxAHIohMA2djNfA2gNuve8PqIfBz6iaUAN0SGhGWMWWEL2B+uYZ\n\t\t\t\t\t\t2vtfZ+CtpWQteMiXFGEfEL/3U5OtjBxt7JaQxaJJ6iRTk5jdl+EI4NxHzmITf3+O\n\t\t\t\t\t\tEId1IbbmDWSHoeSw5za0bFOJcg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bm.stars.manchester.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://bm.stars.manchester.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bm.stars.manchester.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bm.stars.manchester.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bm.stars.manchester.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://bm.stars.manchester.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bm.stars.manchester.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://bm.stars.manchester.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://bm.stars.manchester.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://bm.stars.manchester.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://aai-logon.unibas.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-urz@unibas.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "URZ"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Spalinger"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:h.spalinger@unibas.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hanspeter"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Keller"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:stefan.keller@unibas.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stefan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://aai-logon.unibas.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2016-04-15T07:53:22Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAIGaAPMD0ysvMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE2FhaS1sb2dvbi51bmliYXMuY2gwHhcNMTMwNjEwMTI0NTAzWhcNMTYwNjA5\nMTI0NTAzWjAeMRwwGgYDVQQDExNhYWktbG9nb24udW5pYmFzLmNoMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0sjUfHm8YYP/fqHeV5IOcRO2g3zV6TOe\nfbk1yAgSqqGP3D8JK21UKr+peWz2CAMHyc4BcXB6Cg16VEzHOVHUU63oelsuU8oI\nEyhmuaTlq/S2SBfOReCvBqp0oaWtwbfOxDfDgV0xHPu9moIDT1x5du1BO3pUTxej\n0yRqb1wC8R3UGjmWl7wmN8VYSLv5dKkG9KHCgzKSG7lCci6QqBP+M8ybNiYcLmQA\nSjOnuaynq1dyT47WBQ1YZ62M7HWUX5w90cuhHAtywP/mCARXjad/Htp0CTGg3fTP\n0wPaFCdl+yLQueJx9w7zzgM/o35yhN0RIWi1c187clIxPPX4AcXMzQIDAQABo20w\nazBKBgNVHREEQzBBghNhYWktbG9nb24udW5pYmFzLmNohipodHRwczovL2FhaS1s\nb2dvbi51bmliYXMuY2gvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFD7wTYVRLRII\nPl6cNexk0jYnA11hMA0GCSqGSIb3DQEBBQUAA4IBAQBK82sJwITJPwhRQvze600Q\nMxUVMDbSzcwTtj+4AZsb50mqX7GMirULzJTIEy8CQLyX5XAgUvxHCaiJq2NosJ7A\nYxxq9JoKJm8RZYIapWec8tio9ZUlhvyby7zhMz8yqjRmi3DENUoXvf25qfyz4o6m\nFYbOgkAp/4zVAkJ0ZXjCiAyLpnvNRT/1+kS9vvnHikecCEfOpjbG+8Bz2Qbse4ST\nHweUZV4m0fJXvQW/Ug/RVYq0GLtcGukTez8axMtYMnuA/NxzxQEo+uHe83KSXAPQ\nrcVXBQVY2qXZn91QHZJqxRwfLJ/fo82KwH6SJLjL2jW80zNCkfHvl4ycorbM+Wf9"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUJPalJTWJDz9EVTsE+B37AIIVQlIwDQYJKoZIhvcNAQEL\nBQAwHjEcMBoGA1UEAwwTYWFpLWxvZ29uLnVuaWJhcy5jaDAeFw0xNjAzMjIwNzUw\nMjdaFw0xOTAzMjIwNzUwMjdaMB4xHDAaBgNVBAMME2FhaS1sb2dvbi51bmliYXMu\nY2gwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCaGXDVQYx0hXX42jfE\n92157kAarhTPlGfwPCNn+7KxWjbI3W8zWMpLlcv+h3lPdN7fgwZdUUEsHogw7loE\n5twc/DOq1YRJHmCwEsts8KPKmdN3VAvFN2ViYsGqvEfjR40H+qMqzgBfljKBEegy\nkecZUFIbwAaviVkGrRdjYCFlHGFcktWd9lTAbPWP/Tm9nWNTDgdPpsJnIDSqzNgd\n23Z3O9q4p+Yts2W8PnVeDFvV4j9ytMjGgcpJkZ9nnk8YUAWFhqnfayDOxSx5NSQL\nwELfsMlstDAq+ystg60XQLYSZJyVeDbi1wmCP/2ZOhXeiRJF27+/ajhNFXVHRn1Q\n2+lHAgMBAAGjbTBrMB0GA1UdDgQWBBQySqS4cWUaOOsuJ1ERBml1NPYyCTBKBgNV\nHREEQzBBghNhYWktbG9nb24udW5pYmFzLmNohipodHRwczovL2FhaS1sb2dvbi51\nbmliYXMuY2gvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBABkqZnb2\nkRtNp7Zav6LPnJEppXj+na2Q13CRYVDyWA9JZsAw7/oxxI4AaKNBlYW59ow8SVlS\nrZy6l/Vma2RD0Eeicw7C2av1OveoJ2F9gWebniZ3vv5NwXz2lVKZhnjkqCCOWLMH\nrT+EpiWo55j3QKPo4ix7eekxAepS+ArAW0neKC3HP9FfTstBNEc1B6RJYFGfE/Ip\nYrwshwIXssrCaU4DiIchUs+3VlPI2SR/1hGb6inqxP8Ok8N/MNXMGjmTmySDgpix\nZDOu/bqxpCjk7gHtiyBZrv7+D2rbC6cSfO6recpFDY4RHwG/PjSqXpAYLhBBna6+\ncZM1IGyAkaEe5Mo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unibas.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-logon.unibas.ch:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-logon.unibas.ch:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aai-logon.unibas.ch/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai-logon.unibas.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai-logon.unibas.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aai-logon.unibas.ch/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-logon.unibas.ch:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-logon.unibas.ch:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unibas.ch"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unibas.ch/de/"
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unibas.ch/en/"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unibas.ch"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Universit\u00e4t Basel"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Basel"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Universit\u00e9 de B\u00e2le"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAgklEQVQ4EbVRQQ6AMAib/o/X8kANi90KG3GJ0wu0tJTMUv74ROSKe2ecaU4IMwHmXFMtBly5tyXAvND1JpiJMv5Y2uoiOlDV6u/M08W0iAcDCJzOlXvTAcPT/gKILdVSOCliDtn/iFlaxvM17YFwPpuYcyYACAxzvzqHrta3BU78Fdzl9FuPpzdbqAAAAABJRU5ErkJggg==",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e4t Basel"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Basel"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de B\u00e2le"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "unibas.ch"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.55898,7.58352"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.43.196.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.43.192.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:620:200::/48"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.43.196.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.29.0/25"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.8.136.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "131.152.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "131.152.188.64/26"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "131.152.193.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "131.152.194.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "131.152.227.192/29"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "131.152.227.200/30"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "131.152.227.204/31"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "131.152.227.206/32"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAIGaAPMD0ysvMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE2FhaS1sb2dvbi51bmliYXMuY2gwHhcNMTMwNjEwMTI0NTAzWhcNMTYwNjA5\nMTI0NTAzWjAeMRwwGgYDVQQDExNhYWktbG9nb24udW5pYmFzLmNoMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0sjUfHm8YYP/fqHeV5IOcRO2g3zV6TOe\nfbk1yAgSqqGP3D8JK21UKr+peWz2CAMHyc4BcXB6Cg16VEzHOVHUU63oelsuU8oI\nEyhmuaTlq/S2SBfOReCvBqp0oaWtwbfOxDfDgV0xHPu9moIDT1x5du1BO3pUTxej\n0yRqb1wC8R3UGjmWl7wmN8VYSLv5dKkG9KHCgzKSG7lCci6QqBP+M8ybNiYcLmQA\nSjOnuaynq1dyT47WBQ1YZ62M7HWUX5w90cuhHAtywP/mCARXjad/Htp0CTGg3fTP\n0wPaFCdl+yLQueJx9w7zzgM/o35yhN0RIWi1c187clIxPPX4AcXMzQIDAQABo20w\nazBKBgNVHREEQzBBghNhYWktbG9nb24udW5pYmFzLmNohipodHRwczovL2FhaS1s\nb2dvbi51bmliYXMuY2gvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFD7wTYVRLRII\nPl6cNexk0jYnA11hMA0GCSqGSIb3DQEBBQUAA4IBAQBK82sJwITJPwhRQvze600Q\nMxUVMDbSzcwTtj+4AZsb50mqX7GMirULzJTIEy8CQLyX5XAgUvxHCaiJq2NosJ7A\nYxxq9JoKJm8RZYIapWec8tio9ZUlhvyby7zhMz8yqjRmi3DENUoXvf25qfyz4o6m\nFYbOgkAp/4zVAkJ0ZXjCiAyLpnvNRT/1+kS9vvnHikecCEfOpjbG+8Bz2Qbse4ST\nHweUZV4m0fJXvQW/Ug/RVYq0GLtcGukTez8axMtYMnuA/NxzxQEo+uHe83KSXAPQ\nrcVXBQVY2qXZn91QHZJqxRwfLJ/fo82KwH6SJLjL2jW80zNCkfHvl4ycorbM+Wf9"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUJPalJTWJDz9EVTsE+B37AIIVQlIwDQYJKoZIhvcNAQEL\nBQAwHjEcMBoGA1UEAwwTYWFpLWxvZ29uLnVuaWJhcy5jaDAeFw0xNjAzMjIwNzUw\nMjdaFw0xOTAzMjIwNzUwMjdaMB4xHDAaBgNVBAMME2FhaS1sb2dvbi51bmliYXMu\nY2gwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCaGXDVQYx0hXX42jfE\n92157kAarhTPlGfwPCNn+7KxWjbI3W8zWMpLlcv+h3lPdN7fgwZdUUEsHogw7loE\n5twc/DOq1YRJHmCwEsts8KPKmdN3VAvFN2ViYsGqvEfjR40H+qMqzgBfljKBEegy\nkecZUFIbwAaviVkGrRdjYCFlHGFcktWd9lTAbPWP/Tm9nWNTDgdPpsJnIDSqzNgd\n23Z3O9q4p+Yts2W8PnVeDFvV4j9ytMjGgcpJkZ9nnk8YUAWFhqnfayDOxSx5NSQL\nwELfsMlstDAq+ystg60XQLYSZJyVeDbi1wmCP/2ZOhXeiRJF27+/ajhNFXVHRn1Q\n2+lHAgMBAAGjbTBrMB0GA1UdDgQWBBQySqS4cWUaOOsuJ1ERBml1NPYyCTBKBgNV\nHREEQzBBghNhYWktbG9nb24udW5pYmFzLmNohipodHRwczovL2FhaS1sb2dvbi51\nbmliYXMuY2gvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBABkqZnb2\nkRtNp7Zav6LPnJEppXj+na2Q13CRYVDyWA9JZsAw7/oxxI4AaKNBlYW59ow8SVlS\nrZy6l/Vma2RD0Eeicw7C2av1OveoJ2F9gWebniZ3vv5NwXz2lVKZhnjkqCCOWLMH\nrT+EpiWo55j3QKPo4ix7eekxAepS+ArAW0neKC3HP9FfTstBNEc1B6RJYFGfE/Ip\nYrwshwIXssrCaU4DiIchUs+3VlPI2SR/1hGb6inqxP8Ok8N/MNXMGjmTmySDgpix\nZDOu/bqxpCjk7gHtiyBZrv7+D2rbC6cSfO6recpFDY4RHwG/PjSqXpAYLhBBna6+\ncZM1IGyAkaEe5Mo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e4t Basel"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Basel"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de B\u00e2le"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unibas.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unibas.ch/"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unibas.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "unibas.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayf.ruc.dk/idp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayf.ruc.dk/idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2010-08-17T13:34:58Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayf.ruc.dk/idp/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ruc.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Roskilde Universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Roskilde University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "ruc.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICuDCCAaACAQcwDQYJKoZIhvcNAQELBQAwIjEgMB4GA1UEAwwXaHR0cHM6Ly93\nYXlmLnJ1Yy5kay9pZHAwHhcNMTUwMTAxMDAwMDAwWhcNMjUxMjMxMjM1OTU5WjAi\nMSAwHgYDVQQDDBdodHRwczovL3dheWYucnVjLmRrL2lkcDCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAMeIDApqEFO4jhn4gnWuA54SIILLdtH1Ah7cGkKx\n6MUJTmtLORYA2pW5zU8N+nQl0hmGs9eyYMlAyaJ08IY8gNAqj5uT5p/f4RQVL8j/\n7fmxIFfa9/6HUMe9lX2OzOealJWOnsdn9ag9YHKRYEk7QA5WbMHnOVqqRLfonvr7\nDF6vB2m4TFWdhI13vdL4DJP8Rn61cA77qVDwUv9gyUmdSRJpKotIcXLTUPaoE2Zh\nHAGkJLr91RnLGLS3mPyCEpQPgEc5lVq+frknrZwl1eI5wxHJQAinnsZdCsvrcq2u\nMhxd12r4JnJnm3fsR1Q4jPjaOgVzLvcwU6e3KeUoS87DUEkCAwEAATANBgkqhkiG\n9w0BAQsFAAOCAQEAbtW14fZzIDzTyThrU4usSNj4k55+3GjCX5RJPrnKe+NAVtOv\n+iNWzIDQOsEseFp/ZdJAauGt4VAf8bKnoFGqrnDLjPOu19i4ZU4zs8+n4oXYdSO5\noynonbNEFOmR8N11WvwiVzhff7vsCZBDfAzagT5EGGxt943ewFft/fCD3dmJi4om\neJmXoB5FPAQMLr3DzWb/j2O+3fbGa/FsfTtENtC+3TXKx7thYNlK3r/SfTuu/z25\n/6UOqRf2QoOU8rSzeh8FinMSZmOcghsD6gVacAQE1fOj10cun8iV6S/n08Qq9ANO\nLvJ2p7KuCR1XMFXRBimf3zUsLH5CKx4AOaUJ+A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Roskilde Universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Roskilde University"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ruc.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ruc.dk/en"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Roskilde Universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Roskilde University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.canarie.ca/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Network Operations Center"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@canarie.ca"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.canarie.ca/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.canarie.ca/templates/services/docs/CAF_join_en.pdf"
              }
            ],
            "registration_instant": "2012-08-28T00:00:00Z",
            "registration_authority": "http://www.canarie.ca",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAJ3fH1HeYIxXxMXYbZ/Bx85j/JgKMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC5jYW5hcmllLmNhMB4XDTExMDcwNjE0MzUxMloX\nDTMxMDcwNjE0MzUxMlowGTEXMBUGA1UEAxMOaWRwLmNhbmFyaWUuY2EwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCcmyqTo01QVuqHI/ZXAdYP+iX6NjP2\ntopfFsR4y8TVYFN4vMvb5ZSFWPPjJ8T3O2epI8Hy9q4FWyPn1Pa/CZoFi1EMhu7b\nQJpOmLzeX6FOvf1X/5De2JnWv7JWMpUMeVqupe2YeCtoaXfViHOB9pW0go2zr6R8\najvQKxNX46V/o1ND6YwnlKRNsh4hn46cPtl/DNeKYFz4Uj6OHBRSfMHTZCWVENJB\nife66AS7X5hC6o7o2Sd5VHr0TgY+ZeKrl3/33war+RIGXr6cRW9iA9yEeW0Oi13Q\n3hkjPT7MNkvNJjWpERR7aBogQ3z5Id8Ygl+WASbyfoiXNCHPa3USAaynAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC5jYW5hcmllLmNhhiVodHRwczovL2lkcC5jYW5h\ncmllLmNhL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRDEuTlL5Y/HfiEJ/wzCfCz\notFdxjANBgkqhkiG9w0BAQUFAAOCAQEAD6WiCAdkGjA7Bza59pnn+/z5/Jhwn7Mf\n+WS0WAPz686nIxYjblMBjIVITedkAFvwnEBn0Rs+XNXrc90uRFCNFf4VfSP9NLEf\n7cTPNxHiGt6TqOju2Rg6OBmNwRqAtFNqKG7VeKgoiZ4FcRVU2AdQ8fYnxxtwO4xJ\n8Md//Yp0lGQzj2FpSU7dnbVRGWAEE3g1Ghjrwe9Aj6e6lunZNaIdTZ6Yvnsa5qly\nDngkPipfHlmi56QMo9Iqa3nEKaCv2ykKzTIIUdgDI/M8sHXgitp5tFrAK8f96iBu\nzwZrSXVMnjQppB7E2l48gea/BPyFP4FBlxeN8E6aIXH09uN+HbcohQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "canarie.ca"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.canarie.ca:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.canarie.ca:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.canarie.ca/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.canarie.ca/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.canarie.ca/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.canarie.ca/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.canarie.ca:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.canarie.ca:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "canarie.ca"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.canarie.ca/en/about/aboutus"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.canarie.ca/fr/a-propos/quinoussommes"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Canada\u00e2s Advanced Research and Innovation Network"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Le r\u00e9seau \u00e9volu\u00e9 de recherche et d'innovation du Canada"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CANARIE"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CANARIE"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAJ3fH1HeYIxXxMXYbZ/Bx85j/JgKMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC5jYW5hcmllLmNhMB4XDTExMDcwNjE0MzUxMloX\nDTMxMDcwNjE0MzUxMlowGTEXMBUGA1UEAxMOaWRwLmNhbmFyaWUuY2EwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCcmyqTo01QVuqHI/ZXAdYP+iX6NjP2\ntopfFsR4y8TVYFN4vMvb5ZSFWPPjJ8T3O2epI8Hy9q4FWyPn1Pa/CZoFi1EMhu7b\nQJpOmLzeX6FOvf1X/5De2JnWv7JWMpUMeVqupe2YeCtoaXfViHOB9pW0go2zr6R8\najvQKxNX46V/o1ND6YwnlKRNsh4hn46cPtl/DNeKYFz4Uj6OHBRSfMHTZCWVENJB\nife66AS7X5hC6o7o2Sd5VHr0TgY+ZeKrl3/33war+RIGXr6cRW9iA9yEeW0Oi13Q\n3hkjPT7MNkvNJjWpERR7aBogQ3z5Id8Ygl+WASbyfoiXNCHPa3USAaynAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC5jYW5hcmllLmNhhiVodHRwczovL2lkcC5jYW5h\ncmllLmNhL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRDEuTlL5Y/HfiEJ/wzCfCz\notFdxjANBgkqhkiG9w0BAQUFAAOCAQEAD6WiCAdkGjA7Bza59pnn+/z5/Jhwn7Mf\n+WS0WAPz686nIxYjblMBjIVITedkAFvwnEBn0Rs+XNXrc90uRFCNFf4VfSP9NLEf\n7cTPNxHiGt6TqOju2Rg6OBmNwRqAtFNqKG7VeKgoiZ4FcRVU2AdQ8fYnxxtwO4xJ\n8Md//Yp0lGQzj2FpSU7dnbVRGWAEE3g1Ghjrwe9Aj6e6lunZNaIdTZ6Yvnsa5qly\nDngkPipfHlmi56QMo9Iqa3nEKaCv2ykKzTIIUdgDI/M8sHXgitp5tFrAK8f96iBu\nzwZrSXVMnjQppB7E2l48gea/BPyFP4FBlxeN8E6aIXH09uN+HbcohQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Canada's Advanced Research and Innovation Network"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Le r\u00e9seau \u00e9volu\u00e9 de recherche et d'innovation du Canada"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.canarie.ca/en/about/aboutus"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.canarie.ca/fr/a-propos/quinoussommes"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CANARIE"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CANARIE"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://thalamoss-data.ics.muni.cz/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Holub"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "holub@ics.muni.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sochor"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "325304@mail.muni.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://thalamoss-data.ics.muni.cz/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2014-01-07T17:17:02Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Computer Science, Masaryk University"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ustav vypocetni techniky, Masarykova univerzita"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ics.muni.cz/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ics.muni.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Computer Science, Masaryk University"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ustav vypocetni techniky, Masarykova univerzita"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://thalamoss-data.ics.muni.cz/auth/shibboleth.sso/slo/soap",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://thalamoss-data.ics.muni.cz/auth/shibboleth.sso/slo/redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://thalamoss-data.ics.muni.cz/auth/shibboleth.sso/slo/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://thalamoss-data.ics.muni.cz/auth/shibboleth.sso/slo/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "THALAMOSS Data Management Platform"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Management platform for THALAMOSS project on personalized therapy of b-thalassaemia"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "false",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "false",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:sn",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "is_required": "true",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:cn",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:displayName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:givenName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "o",
                  "is_required": "false",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:o",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "false",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:mail",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "o",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "1",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://thalamoss-data.ics.muni.cz/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://thalamoss-data.ics.muni.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Management and distribution platform for THALAMOSS project on personalized therapy of b-thalassaemia"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "System pro spravu a distribuci dat projektu THALAMOSS pro personalizovanou lecbu b-thalassemie"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "THALAMOSS Data Management Platform"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "System pro spravu dat projektu THALAMOSS"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://thalamoss-data.ics.muni.cz/auth/shibboleth.sso/ds",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://thalamoss-data.ics.muni.cz/auth/shibboleth.sso/ds",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://thalamoss-data.ics.muni.cz/auth/shibboleth.sso/artifact/soap",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "thalamoss-data.ics.muni.cz"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEgTCCA2mgAwIBAgIQNd5X+bSLsMpg3WZ/IC3PmjANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMTIxODAwMDAwMFoXDTE2MTIxNzIzNTk1OVowSDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMSMwIQYDVQQDExp0aGFsYW1vc3Mt\nZGF0YS5pY3MubXVuaS5jejCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAKUGwM1e1CiGbQVgLW460tAetS5QUTSANMKZEzThUgJYdI2mYJWp9NwF5bXelMo+\nlFObDPcG7wEc8+DpdpKGskBEE4SmcHbcKFE8/hmCYHPbf5AUrjPCei3XKDMbtIaC\nHtmut5AjE4gsG9GJa5vCFCjcsJgIdIat/PQp7++IOMc+qXx5WR22mUroYR15V89u\njGe7CfjonOUmB4xxj5AVW73xcGEsAgYS1vmCGo3utSiawlgBKYENCTyb6e1AdbQ6\nMS1SBcN1gvFQH6ONoX2gXFG5NAEF1PCwevcUePVoJyUux5grmnBH6wE/7SOp8ygI\n7c6bUVZINmO9s5KY+Ohc7LUCAwEAAaOCAXcwggFzMB8GA1UdIwQYMBaAFAy9k2gM\n896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBT+kNRsn7KWuNVl5xuCU3uOlH3ElTAO\nBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcD\nAQYIKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEw\nOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJF\nTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8v\nY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYa\naHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwJQYDVR0RBB4wHIIadGhhbGFtb3Nz\nLWRhdGEuaWNzLm11bmkuY3owDQYJKoZIhvcNAQEFBQADggEBAGXev97kSHOHKFTd\nPb2+xAETh0vA4q5UFVUF96i0yqpOlpmeWF7gV+7VCSI0WOVfWJQE8LeE17KRymb2\nh4G6AetotMBoKdzPxVmuSTIT2GA3q/cMeNWt9Kc1xaFZ73/vV9kJ5ioA/Vqpbk3B\nBOn8kS74xu0s1frpPS3rn23kRY/3LsQORCi0RUhNcio1LcGbkUQ1J7nlEYXt62rH\n6kAGlj0ycmn4GA0vnQbgw7iAYh72rPmH2vvLyXrEf6wKo9L1ywQ7ag9BvQaxCLoT\ngRtPrP5JXkY5jYK6rsPAUltcTEPXxRkxG7CX92WXKlX5/1MXRk3wZV5ZYyh+TGKe\n3EudFd0="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=thalamoss-data.ics.muni.cz,OU=Domain Control Validated"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://thalamoss-data.ics.muni.cz/auth/shibboleth.sso/nim/soap",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://thalamoss-data.ics.muni.cz/auth/shibboleth.sso/nim/redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://thalamoss-data.ics.muni.cz/auth/shibboleth.sso/nim/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://thalamoss-data.ics.muni.cz/auth/shibboleth.sso/nim/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://thalamoss-data.ics.muni.cz/auth/shibboleth.sso/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://thalamoss-data.ics.muni.cz/auth/shibboleth.sso/saml2/post-simplesign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://thalamoss-data.ics.muni.cz/auth/shibboleth.sso/saml2/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://thalamoss-data.ics.muni.cz/auth/shibboleth.sso/saml2/ecp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://thalamoss-data.ics.muni.cz/auth/shibboleth.sso/saml/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://thalamoss-data.ics.muni.cz/auth/shibboleth.sso/saml/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayf.supportcenter.dk/mg/saml2/idp/metadata.php?unit=mg",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayf.supportcenter.dk/mg/saml2/idp/metadata.php?unit=mg",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2010-08-17T13:56:14Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayf.supportcenter.dk/mg/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mg.itsf.dk"
              },
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Marselisborg Gymnasium"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Marselisborg Gymnasium"
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Marselisborg Gymnasium"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Marselisborg Gymnasium"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "mg.itsf.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCDCCAfACAQcwDQYJKoZIhvcNAQELBQAwSjFIMEYGA1UEAww/aHR0cHM6Ly93\nYXlmLnN1cHBvcnRjZW50ZXIuZGsvbWcvc2FtbDIvaWRwL21ldGFkYXRhLnBocD91\nbml0PW1nMB4XDTE1MDEwMTAwMDAwMFoXDTI1MTIzMTIzNTk1OVowSjFIMEYGA1UE\nAww/aHR0cHM6Ly93YXlmLnN1cHBvcnRjZW50ZXIuZGsvbWcvc2FtbDIvaWRwL21l\ndGFkYXRhLnBocD91bml0PW1nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAx4gMCmoQU7iOGfiCda4DnhIggst20fUCHtwaQrHoxQlOa0s5FgDalbnNTw36\ndCXSGYaz17JgyUDJonTwhjyA0CqPm5Pmn9/hFBUvyP/t+bEgV9r3/odQx72VfY7M\n55qUlY6ex2f1qD1gcpFgSTtADlZswec5WqpEt+ie+vsMXq8HabhMVZ2EjXe90vgM\nk/xGfrVwDvupUPBS/2DJSZ1JEmkqi0hxctNQ9qgTZmEcAaQkuv3VGcsYtLeY/IIS\nlA+ARzmVWr5+uSetnCXV4jnDEclACKeexl0Ky+tyra4yHF3Xavgmcmebd+xHVDiM\n+No6BXMu9zBTp7cp5ShLzsNQSQIDAQABMA0GCSqGSIb3DQEBCwUAA4IBAQANBX1K\n0nCKZFi+ffDN4WvL1ni3UJsSIKBNiUog/S68DO+tpoSL214oLGv+mXmZNIyhCKzh\nxezmXJnamKq1+WDVmUhF0gYzZqFw+iAOkCEYUkNvkBT8EZ7FKwNBoMPCYQaqK4cK\nE8WaWXFqrMeOg1CZygVsl4S8WmnfAPtv6jaxvjDevKBcLn9moXby6yRlEjjI5stI\n7FexaJxFGjLT8SFYEI79wDAogEmyJHLim0fzaXdIvpIwTPADo9fO/4gl5bNUDVtO\n5t71b6/cYsHlSLBNd8XNiYShhAKZ6oIHeJHHm2OdLdvse446F+UaFct8R9MvVg61\ngldjnwhQkoXCB2mN"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Marselisborg Gymnasium"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Marselisborg Gymnasium"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.marselisborg-gym.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.marselisborg-gym.dk"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Marselisborg Gymnasium"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Marselisborg Gymnasium"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib-idp.ucl.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lib-eresource-help@ucl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Library e-resource help"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barker"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:systems@ucl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adrian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib-idp.ucl.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-12-04T11:40:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEBjCCAu6gAwIBAgIJAL1ZxB217UWjMA0GCSqGSIb3DQEBBQUAMIGDMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEPMA0GA1UEBwwGTG9uZG9uMSIwIAYDVQQKDBlVbml2ZXJzaXR5IENv\n\t\t\t\t\t\tbGxlZ2UgTG9uZG9uMRswGQYDVQQDDBJzaGliLWlkcC51Y2wuYWMudWsxIjAgBgkq\n\t\t\t\t\t\thkiG9w0BCQEWE3VrZXJuYS1yYUB1Y2wuYWMudWswHhcNMTQwMTI4MTUyODA0WhcN\n\t\t\t\t\t\tMzQwMTIzMTUyODA0WjCBgzELMAkGA1UEBhMCR0IxDzANBgNVBAcMBkxvbmRvbjEi\n\t\t\t\t\t\tMCAGA1UECgwZVW5pdmVyc2l0eSBDb2xsZWdlIExvbmRvbjEbMBkGA1UEAwwSc2hp\n\t\t\t\t\t\tYi1pZHAudWNsLmFjLnVrMSIwIAYJKoZIhvcNAQkBFhN1a2VybmEtcmFAdWNsLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvqkif+72KaxIswUf\n\t\t\t\t\t\tg18mBnkqiMaO23A1P2ovEyKwROBCOAtnEMQS04vNVa9xFdbz1HBDtdkXsQQrdDSi\n\t\t\t\t\t\tNH7uTxOoliLe581gdJW5yOPZaLa/23YSsdbJxBykcFIXDNUCIDa5IefR6EnPHUCu\n\t\t\t\t\t\tLBFtMGQDfv8FAQBrFj0sRTc+9c5WMvSe0GToJ4RepVS7ZudffDbIeDVEh4Tg+3yH\n\t\t\t\t\t\t2dXIj5u6UVhg8ocYM4hk3Fjg1uggdW7EjxZBf5rjIax2e6316ppteVSEBxwxj9FI\n\t\t\t\t\t\tlZU3iBn6ihgf3Ix6Gp/sQQvk6WcLFd6269iPt1/BTupcKiJlcSEAv8kfbJksRnvS\n\t\t\t\t\t\tCMw13wIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NM\n\t\t\t\t\t\tIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUNk7UuvDUFbJTfGTthmZA\n\t\t\t\t\t\tbhQIyU8wHwYDVR0jBBgwFoAUNk7UuvDUFbJTfGTthmZAbhQIyU8wDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAFfIkvqQOaajAbNmCX6aO+Hl4xJRnDf7zDENT0iwe7llYeA4C9Mg\n\t\t\t\t\t\trPkCX31HnS+m7lx42q8T/ultqoeiIRfHGPFSwYrBsWqFOZtxjZVSFYtuKyM/W2+G\n\t\t\t\t\t\tidRkeM71d3s1jkfx9nhphI27iK860nYlmbPp+a+JzjDrFXLi21vY4WkWRJoVcnPe\n\t\t\t\t\t\tRC5J5k/16Nz+bxbzqUUPenUNiYyCbrxH7vZnqQ9xlN57YD0yfCzTQ+TyKIHWXC4I\n\t\t\t\t\t\t1erUYkjIA7Zm87b9RXqPLiISMLio1Ncl1ppJZqu8a34sNyvYDKPtzcKZ4v0gxovk\n\t\t\t\t\t\taskhslrZvXeC4StCDJMj32vSTmKVQZ9S8F0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucl.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-idp.ucl.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.ucl.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib-idp.ucl.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-idp.ucl.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib-idp.ucl.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-idp.ucl.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-idp.ucl.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.ucl.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucl.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://www.ucl.ac.uk/images/shib-ucl-logo-80-60.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://www.ucl.ac.uk/images/shib-ucl-logo-16-16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UCL (University College London)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEBjCCAu6gAwIBAgIJAL1ZxB217UWjMA0GCSqGSIb3DQEBBQUAMIGDMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEPMA0GA1UEBwwGTG9uZG9uMSIwIAYDVQQKDBlVbml2ZXJzaXR5IENv\n\t\t\t\t\t\tbGxlZ2UgTG9uZG9uMRswGQYDVQQDDBJzaGliLWlkcC51Y2wuYWMudWsxIjAgBgkq\n\t\t\t\t\t\thkiG9w0BCQEWE3VrZXJuYS1yYUB1Y2wuYWMudWswHhcNMTQwMTI4MTUyODA0WhcN\n\t\t\t\t\t\tMzQwMTIzMTUyODA0WjCBgzELMAkGA1UEBhMCR0IxDzANBgNVBAcMBkxvbmRvbjEi\n\t\t\t\t\t\tMCAGA1UECgwZVW5pdmVyc2l0eSBDb2xsZWdlIExvbmRvbjEbMBkGA1UEAwwSc2hp\n\t\t\t\t\t\tYi1pZHAudWNsLmFjLnVrMSIwIAYJKoZIhvcNAQkBFhN1a2VybmEtcmFAdWNsLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvqkif+72KaxIswUf\n\t\t\t\t\t\tg18mBnkqiMaO23A1P2ovEyKwROBCOAtnEMQS04vNVa9xFdbz1HBDtdkXsQQrdDSi\n\t\t\t\t\t\tNH7uTxOoliLe581gdJW5yOPZaLa/23YSsdbJxBykcFIXDNUCIDa5IefR6EnPHUCu\n\t\t\t\t\t\tLBFtMGQDfv8FAQBrFj0sRTc+9c5WMvSe0GToJ4RepVS7ZudffDbIeDVEh4Tg+3yH\n\t\t\t\t\t\t2dXIj5u6UVhg8ocYM4hk3Fjg1uggdW7EjxZBf5rjIax2e6316ppteVSEBxwxj9FI\n\t\t\t\t\t\tlZU3iBn6ihgf3Ix6Gp/sQQvk6WcLFd6269iPt1/BTupcKiJlcSEAv8kfbJksRnvS\n\t\t\t\t\t\tCMw13wIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NM\n\t\t\t\t\t\tIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUNk7UuvDUFbJTfGTthmZA\n\t\t\t\t\t\tbhQIyU8wHwYDVR0jBBgwFoAUNk7UuvDUFbJTfGTthmZAbhQIyU8wDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAFfIkvqQOaajAbNmCX6aO+Hl4xJRnDf7zDENT0iwe7llYeA4C9Mg\n\t\t\t\t\t\trPkCX31HnS+m7lx42q8T/ultqoeiIRfHGPFSwYrBsWqFOZtxjZVSFYtuKyM/W2+G\n\t\t\t\t\t\tidRkeM71d3s1jkfx9nhphI27iK860nYlmbPp+a+JzjDrFXLi21vY4WkWRJoVcnPe\n\t\t\t\t\t\tRC5J5k/16Nz+bxbzqUUPenUNiYyCbrxH7vZnqQ9xlN57YD0yfCzTQ+TyKIHWXC4I\n\t\t\t\t\t\t1erUYkjIA7Zm87b9RXqPLiISMLio1Ncl1ppJZqu8a34sNyvYDKPtzcKZ4v0gxovk\n\t\t\t\t\t\taskhslrZvXeC4StCDJMj32vSTmKVQZ9S8F0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UCL (University College London)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ucl.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University College London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://teton.accessiblelearning.com/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rob.armas@dsaim.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert Armas"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "haris.gunadi@dsaim.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Haris Gunadi"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://teton.accessiblelearning.com/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Accessible Information Management, LLC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://accessiblelearning.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Accessible Information Management, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://teton.accessiblelearning.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.accessiblelearning.com"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Accessible Information Management, LLC"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "AIM LLC provides software and support, systems implementation and integration, strategic consulting, and technology management services to help colleges and universities build, unify, and manage their disability services accommodations. Enterprise solutions for administration and recordkeeping. Portal solutions to enhance Web-based experiences and support community building Technology management services to better manage technology resources and provide metrics on demand. Bringing together people, processes, and technology, AIM LLC works with colleges and universities to help them strengthen performance and services through improved data accuracy and integrity, increased accountability, and enhanced educational experiences."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.accessiblelearning.com/Shibboleth/logo.png",
                    "lang": "en",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.accessiblelearning.com/Policies.aspx"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFVjCCBD6gAwIBAgIJAPw5+wFnu56MMA0GCSqGSIb3DQEBCwUAMIG0MQswCQYD\nVQQGEwJVUzEQMA4GA1UECBMHQXJpem9uYTETMBEGA1UEBxMKU2NvdHRzZGFsZTEa\nMBgGA1UEChMRR29EYWRkeS5jb20sIEluYy4xLTArBgNVBAsTJGh0dHA6Ly9jZXJ0\ncy5nb2RhZGR5LmNvbS9yZXBvc2l0b3J5LzEzMDEGA1UEAxMqR28gRGFkZHkgU2Vj\ndXJlIENlcnRpZmljYXRlIEF1dGhvcml0eSAtIEcyMB4XDTE2MDIyNjA1MjczOFoX\nDTE5MDIyNjA1MjczOFowSjEhMB8GA1UECxMYRG9tYWluIENvbnRyb2wgVmFsaWRh\ndGVkMSUwIwYDVQQDExx0ZXRvbi5hY2Nlc3NpYmxlbGVhcm5pbmcuY29tMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmmKd3sm0vS5UJiuO2DVhxLIMqsv5\nJB4koBNk+eShYregVP6Epdqcn/PCRmQ6/pGwqrAxTQYQ93lPNz0ujS5sf3HG7wN0\nJYcY89aOuxYHEWW1GjpvAO2V7vm4CgapyqWbulBuGQdkfHJ9YgY/U+537t9Viyyk\nHhTtR5/xiXG2TOpC1/qqvTH2ggq8EJypiOZR5jsIZkSsxkVM/uzAoa+C6V4sRwWO\nZEZLvD2cLYn7keqov/Av7EYTuOOU+bN1epy5HK6BCcNNRHiLw+k8DY8K0o384JKI\nwsCzp1uG6Xmc59i1CYTS9JBGT/Vvmm/fZm9bhGfRF9E2wLOr5zxds3EHDwIDAQAB\no4IB0jCCAc4wDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYB\nBQUHAwIwDgYDVR0PAQH/BAQDAgWgMDcGA1UdHwQwMC4wLKAqoCiGJmh0dHA6Ly9j\ncmwuZ29kYWRkeS5jb20vZ2RpZzJzMS0yMDAuY3JsMFMGA1UdIARMMEowSAYLYIZI\nAYb9bQEHFwEwOTA3BggrBgEFBQcCARYraHR0cDovL2NlcnRpZmljYXRlcy5nb2Rh\nZGR5LmNvbS9yZXBvc2l0b3J5LzB2BggrBgEFBQcBAQRqMGgwJAYIKwYBBQUHMAGG\nGGh0dHA6Ly9vY3NwLmdvZGFkZHkuY29tLzBABggrBgEFBQcwAoY0aHR0cDovL2Nl\ncnRpZmljYXRlcy5nb2RhZGR5LmNvbS9yZXBvc2l0b3J5L2dkaWcyLmNydDAfBgNV\nHSMEGDAWgBRAwr0njsw0gzCiM9f7bLPwtCyAzjBJBgNVHREEQjBAghx0ZXRvbi5h\nY2Nlc3NpYmxlbGVhcm5pbmcuY29tgiB3d3cudGV0b24uYWNjZXNzaWJsZWxlYXJu\naW5nLmNvbTAdBgNVHQ4EFgQUqGC1LFz3KZ2p7Yj4zA72Nc/fWBcwDQYJKoZIhvcN\nAQELBQADggEBAAgyYXTdv8fieKV/rp4+sYgsv5FHyQ6QJHFQKRl3epnwDf8T6uWe\nlQ7bXB1pV0y1hFQZmhETKv+A/UdRrgqzO38kIo7lvYwDTdfEX71aPALOce9vwNyi\nxaoo3uQ1sfeeCuAFycecH0b5n6DE6TydC/KyPTNJ/uBVVhB5fxtyR+IsL8OFn3ZU\n5Z0rF9fuWcx0GX3PiEnrCMRBgcUTOSzfXKihBawmIUFuxI8ZbHOh8azAx5y+SAnW\nENqPeEB2aGX/xBWLgXLr/wU/XULpX0jDk0oNJI38MWIuGThEx5aMNUzQXGdU0VoY\nTzxgcDbG96dYGaEDayPv2UC1/5/X8IEw8E8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://teton.accessiblelearning.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://teton.accessiblelearning.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://teton.accessiblelearning.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://teton.accessiblelearning.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://teton.accessiblelearning.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://teton.accessiblelearning.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Accessible Information Management, LLC"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "AIM LLC provides software and support, systems implementation and integration, strategic consulting, and technology management services to help colleges and universities build, unify, and manage their disability services accommodations. Enterprise solutions for administration and recordkeeping. Portal solutions to enhance Web-based experiences and support community building Technology management services to better manage technology resources and provide metrics on demand. Bringing together people, processes, and technology, AIM LLC works with colleges and universities to help them strengthen performance and services through improved data accuracy and integrity, increased accountability, and enhanced educational experiences."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "cn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "o",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.walesdtc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wood"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:WoodSN2@cardiff.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wood"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:WoodSN2@cardiff.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.walesdtc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-08-28T13:10:37Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Wales Doctoral Training College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.walesdtc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cardiff University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.walesdtc.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.walesdtc.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.walesdtc.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.walesdtc.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.walesdtc.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.walesdtc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.walesdtc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAPbailijb9L3MA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHNvY3NpMDEuY2YuYWMudWswHhcNMTMwMzI2MDk0NDQ2WhcNMjMwMzI0MDk0\n\t\t\t\t\t\tNDQ2WjAbMRkwFwYDVQQDExBzb2NzaTAxLmNmLmFjLnVrMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEA0ujf4w6Wex5S5yUwoVVgRe3Idf4qrmCg9JTCq9xJ\n\t\t\t\t\t\tXOVhWbYusvj70tVT0hLrlHafwjby3OzrPEUfct/9H02YUGoqjSXPxTDiPOENZzsW\n\t\t\t\t\t\tjE2YHjotmOHEtilSJnyvOQpTfJFv8S2HbA4NoXJR9OOTsy+8YgLrLHS8zzpPpEcC\n\t\t\t\t\t\tDQOlsRlb1kqdkfpgpGEadhFy8XB9iGhVIuJDEr/p1Q+c5zcBCXwrFy2p8XjgAEj4\n\t\t\t\t\t\tfRaHaW5uDhdXFTrl0icKTElrAoyqs+Pot44TRUNG/B/4SLsMKCapHvDLjxJRobx2\n\t\t\t\t\t\t9KR7Bvwyf397i2nQqdrjVFsqtj89Asv0lUxm6DtUGz4y9QIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghBzb2NzaTAxLmNmLmFjLnVrMB0GA1UdDgQWBBSw4X82LGsMUJHKB8Gj\n\t\t\t\t\t\ttSyINoYALzANBgkqhkiG9w0BAQUFAAOCAQEAyZGq7fE3UF+pIIyEq3/2wkktaJZN\n\t\t\t\t\t\ta6QW3X0WXJ2SDHZLBVpz4tqIHeFIM0IKliKvfg/7mgD42x3dB4w9+mdIrYhPn/BI\n\t\t\t\t\t\tGdpNTxW+NnGBW7CwEtLkBtkmQRYUXFSu5CJHF8Epe1TeNmd3DBMx5BdruFPrL/Rv\n\t\t\t\t\t\tzxKp5iQima7G/GzVSqAWKfswtpC3nw15I2UylDnPUaSw0W4fFViFiVjfS5wOQicg\n\t\t\t\t\t\tVwKUrkl1bpbG60AK3IBkQJsV4Jj4lswoDbrBvugoKqAQ3QsKuYRFOw5EMGTwhjEx\n\t\t\t\t\t\tpkeB18XsxDB/+q81BcLHYxqHOeAWUr7x/dhavNYQVZ5FdNgt5bAbHOjBNw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.walesdtc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.walesdtc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.walesdtc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.walesdtc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.walesdtc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.walesdtc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.soc.cas.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Van\u00ed\u010dek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vanicekp@utia.cas.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.soc.cas.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2014-07-24T14:09:34Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/avcr"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVALbz3ZMe+jLBrE4lIU9+JcxfX6G1MA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC5zb2MuY2FzLmN6MB4XDTE0MDYwNDA3NTk0N1oX\nDTM0MDYwNDA3NTk0N1owGTEXMBUGA1UEAxMOaWRwLnNvYy5jYXMuY3owggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCb17jsUD7gY8vMDwIgjf3Gc8HIGatp\ndVo0qPKs2kIwbOpNxtfiK3QFGoj6zFNcCbDXwcRJM/2AqrMRAj+WgnHQrjctYB5o\n400kvDKluqce92qZI0luJzxBZR1UVeC5gSy8JUd6rorDYqNDcXyl8Mb1iutbxids\n87Pb+SOpSurSC5LE0hy24WFQnkAf2rZneZD4iH6E6kNTDJIf9rTyavwjeIGpSNd+\n8BjD8Qj4bcxm6VPGrB++LVYNgn4Ml7dU4KoLf51tfeeP8u0Z8xfSXkus+LKlaVTc\nJ4GZJ2Ey6Lk14yV69ymgGtJPc59xINg7GkE4BudWhqAROnt+P3olyTA/AgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC5zb2MuY2FzLmN6hiVodHRwczovL2lkcC5zb2Mu\nY2FzLmN6L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTA+sWvwXfF656DdVRMXO8T\nQkaZQjANBgkqhkiG9w0BAQUFAAOCAQEAYYB87sKunI6qPwmASoXHNGDyUhqiGOs6\njZBxKmcJdoeQMWvjBuQ4kRUo/F8MedGeEYnLkmmN4tMBtQH5FK6dAHDuhkLNXR5Q\nG3DrhuVv4F8kBTkee/6Buhd0mF/+XMcWaY7GIvnDH6bNIdTfO8EbjvuHRlr+ggVc\nxET2sHeYcwo+slmPebr/5fOYzpaE3ypqNyyTfiz44HQOAsOz7SL6t3wBTexdDlB3\nO7+c6VYyjsE8KPx9JoSjkoD05nPA06Irj0aAXPUrTHXk0UaFU8uHGzh06u/mtlVK\nIaV6L2n5KTVFbtfvJSuGFGB/t3VqhVLT7svoSLCvwetSHRXNmlLnqg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "soc.cas.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.soc.cas.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.soc.cas.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.soc.cas.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.soc.cas.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.soc.cas.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.soc.cas.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.soc.cas.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.soc.cas.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.soc.cas.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.soc.cas.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.soc.cas.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "soc.cas.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.soc.cas.cz/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.soc.cas.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider SOU AV CR employees."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance SO\u00da AV \u010cR"
                  }
                ],
                "logo": [
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-soc-44.png",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "70"
                  },
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-soc-1237.png",
                    "height": "1237",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "1959"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Sociology AS CR"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sociologick\u00fd \u00fastav AV \u010cR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVALbz3ZMe+jLBrE4lIU9+JcxfX6G1MA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC5zb2MuY2FzLmN6MB4XDTE0MDYwNDA3NTk0N1oX\nDTM0MDYwNDA3NTk0N1owGTEXMBUGA1UEAxMOaWRwLnNvYy5jYXMuY3owggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCb17jsUD7gY8vMDwIgjf3Gc8HIGatp\ndVo0qPKs2kIwbOpNxtfiK3QFGoj6zFNcCbDXwcRJM/2AqrMRAj+WgnHQrjctYB5o\n400kvDKluqce92qZI0luJzxBZR1UVeC5gSy8JUd6rorDYqNDcXyl8Mb1iutbxids\n87Pb+SOpSurSC5LE0hy24WFQnkAf2rZneZD4iH6E6kNTDJIf9rTyavwjeIGpSNd+\n8BjD8Qj4bcxm6VPGrB++LVYNgn4Ml7dU4KoLf51tfeeP8u0Z8xfSXkus+LKlaVTc\nJ4GZJ2Ey6Lk14yV69ymgGtJPc59xINg7GkE4BudWhqAROnt+P3olyTA/AgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC5zb2MuY2FzLmN6hiVodHRwczovL2lkcC5zb2Mu\nY2FzLmN6L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTA+sWvwXfF656DdVRMXO8T\nQkaZQjANBgkqhkiG9w0BAQUFAAOCAQEAYYB87sKunI6qPwmASoXHNGDyUhqiGOs6\njZBxKmcJdoeQMWvjBuQ4kRUo/F8MedGeEYnLkmmN4tMBtQH5FK6dAHDuhkLNXR5Q\nG3DrhuVv4F8kBTkee/6Buhd0mF/+XMcWaY7GIvnDH6bNIdTfO8EbjvuHRlr+ggVc\nxET2sHeYcwo+slmPebr/5fOYzpaE3ypqNyyTfiz44HQOAsOz7SL6t3wBTexdDlB3\nO7+c6VYyjsE8KPx9JoSjkoD05nPA06Irj0aAXPUrTHXk0UaFU8uHGzh06u/mtlVK\nIaV6L2n5KTVFbtfvJSuGFGB/t3VqhVLT7svoSLCvwetSHRXNmlLnqg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Sociology, Public Research Institution"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Sociologick\u00fd \u00fastav AV \u010cR, v.v.i."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.soc.cas.cz/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.soc.cas.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Sociology of the Academy of Sciences of the Czech Republic"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Sociologick\u00fd \u00fastav AV \u010cR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.leedstrinity.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.leedstrinity.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/leedstrinity.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/leedstrinity.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "leedstrinity.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Leeds Trinity University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.leedstrinity.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.studentsales.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Onder"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ali@studentsales.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ali"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Onder"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ali@studentsales.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ali"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.studentsales.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-11-24T10:57:14Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Student Sales"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.studentsales.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Student Sales Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.studentsales.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.studentsales.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.studentsales.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.studentsales.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.studentsales.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.studentsales.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.studentsales.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Global Platform for Student Discounts"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.studentsales.com/images/logos/ss-logo.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Student Sales"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAOmLHL1xUklsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHN0dWRlbnRzYWxlcy5jb20wHhcNMTUxMTIwMDAxNjU1WhcNMjUxMTE3MDAx\n\t\t\t\t\t\tNjU1WjAbMRkwFwYDVQQDExBzdHVkZW50c2FsZXMuY29tMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEA70S80v6V31QEGYPuyrzqohqkaIp6WGfjJRbDvrtt\n\t\t\t\t\t\tYF5NeVJB97kpiG4IguuMvkXCa1IR99IIBueUnWqgdcb+z3t5mLsScW2kZR/S2M4a\n\t\t\t\t\t\tCgT2jN+md/sN8iQ1Sj7dp0h90ouHK1sL2qo2IDEeJYQyPhVupOjPj5HuYrCr5qWG\n\t\t\t\t\t\tnFV8wXJvhX0thFnK2QnKr3i40wdDivFOksxrn5JcjV+x6SFae2yhVKLB+J2hHMC/\n\t\t\t\t\t\tWl4QUrho2BUMxfyoTMfkqYCHeLWTA2mK5uYzsveKTFmRyY/0sW6t4+beSEOWFDf8\n\t\t\t\t\t\t6PxdOsMbZ3OxEyo4V2n47e7ALXkDUByXb2gmY/l/68ycbQIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghBzdHVkZW50c2FsZXMuY29tMB0GA1UdDgQWBBTdv/6HZA/dTF7F0BVi\n\t\t\t\t\t\tPKgnRRbVezANBgkqhkiG9w0BAQUFAAOCAQEA5EBVNeUA9ZvdOs5ufjCJYC7aEYvI\n\t\t\t\t\t\t8h7J4TWOTulH8WyG5MSn9x0bvPZrP862cvG7UhyRqPVZHAG//+lyQou9W4yN3XZD\n\t\t\t\t\t\tKMy8L0vKOqlIerKU//xhznrMWYeRrjZvAqSDtOTxAr+++goE8F5HvzSgbrKwPUYG\n\t\t\t\t\t\tToXGcQ6BZoztcSH8SHbeLqbBT7O33u1uvJmLpy0/FBhSGa/T3Nv6NxAnyoK3/u3S\n\t\t\t\t\t\tqOQR16hpXiNGbsbwdg5x/8OXwMYxW238zxIDRAlorgDPvyzQwJmkdbJ3JXAdli7Y\n\t\t\t\t\t\tQuuv0pXFaKbFjyCOog/Ite+KJWonNI6tGPrpqMl9yd67mY0KrDeEiNOeXQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.studentsales.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.studentsales.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.studentsales.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.studentsales.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.studentsales.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.studentsales.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idem-idp.imtlucca.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webmaster@imtlucca.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idem-idp.imtlucca.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2013-10-09T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAIF5g404xBT9pz/2nuMWOQA6KHj6MA0GCSqGSIb3DQEB\nBQUAMB8xHTAbBgNVBAMTFGlkZW0taWRwLmltdGx1Y2NhLml0MB4XDTEzMDkxMDE2\nMTEyNVoXDTMzMDkxMDE2MTEyNVowHzEdMBsGA1UEAxMUaWRlbS1pZHAuaW10bHVj\nY2EuaXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCecL5DE82gqAf8\ncuxD6rg+49Rt5l/hie4RKn2YpPYoxLxrr0TuE2PV2D/04dHJmT4g8HClV80HwHHx\ncT6hItjkLtBN2JeogwefBnk4tQdaEluvd/r3RNZF9Re5NKcrHNMPJGd8RqZPwL/Z\nMpPIHTJzO1WNpPO+H4w/tYVJdhlE1vn/0d3lCYBdX6FT4i10XxWx7er9sdEj9ndX\n8LhHuA2O2z197jHEEufG6XAThBV8XACOaqNkw+nVbk2GS4EltIOZRqdeC0qvATs8\nAiWGpK5K7bgdIfItscYTkDpbOeZwFUkdxpOJ7ujqMgjZCbJ0WfPXmWEFGuixYXki\nLXM7vQQLAgMBAAGjbzBtMEwGA1UdEQRFMEOCFGlkZW0taWRwLmltdGx1Y2NhLml0\nhitodHRwczovL2lkZW0taWRwLmltdGx1Y2NhLml0L2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBRw6DX3JFHnfUlXHQXxcYUaIkKDmTANBgkqhkiG9w0BAQUFAAOCAQEA\nEzNzUHWImZwxpf8bu1BudPjcmtyQqHyPThTrpAd6UWm+MiwCPRdEYEfgWSnvGh0B\nSTzyTtF/0PTMXNt+ocPryWFlpigO6d4H/QBWNtlPqWmLfLFsrTm1Cvy6ihmSsqVk\nnFN3qHAfJd0Xl05zk0oxDg6u8CXWzlFJcKxm2P8ujJYkJVHkt3saNinZop7+oazU\nYM5NpKde4RG0tQJvDuzN3xFLCtTUZe9EnOV0tniikwk4ZGDFy7F14POhmYvq+V+W\nPMrXoG08C30q+20nepBYJz2JoY9nQlmGor4yK6Ft8RvgmYq1BuwEkAHYnWf4B26l\nBgRrAVj5NpDfLOfRZq+LOg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "imtlucca.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idem-idp.imtlucca.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idem-idp.imtlucca.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idem-idp.imtlucca.it/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idem-idp.imtlucca.it/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idem-idp.imtlucca.it:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idem-idp.imtlucca.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idem-idp.imtlucca.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idem-idp.imtlucca.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idem-idp.imtlucca.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idem-idp.imtlucca.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idem-idp.imtlucca.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "imtlucca.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.imtlucca.it/campus/idem.php"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.imtlucca.it/campus/idem.php"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IMT Lucca - Identity Provider"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IMT Lucca - Identity Provider"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for IMT Lucca users. This IdP permits to access services presents in the IDEM GARR Federation"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider per gli utenti di IMT Lucca. Questo IdP permette di accedere a servizi disponibili nella federazione GARR IDEM"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.imtlucca.it/_img/logo/new/logo_imt_16x16_square_blueback.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://www.imtlucca.it/_img/logo/new/logo_imt_16x16_square_blueback.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://www.imtlucca.it/_img/logo/new/logo_imt_80x80_square_blueback.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://www.imtlucca.it/_img/logo/new/logo_imt_80x80_square_blueback.png",
                    "lang": "it",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.imtlucca.it/campus/idem.php"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.imtlucca.it/campus/idem.php"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAIF5g404xBT9pz/2nuMWOQA6KHj6MA0GCSqGSIb3DQEB\nBQUAMB8xHTAbBgNVBAMTFGlkZW0taWRwLmltdGx1Y2NhLml0MB4XDTEzMDkxMDE2\nMTEyNVoXDTMzMDkxMDE2MTEyNVowHzEdMBsGA1UEAxMUaWRlbS1pZHAuaW10bHVj\nY2EuaXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCecL5DE82gqAf8\ncuxD6rg+49Rt5l/hie4RKn2YpPYoxLxrr0TuE2PV2D/04dHJmT4g8HClV80HwHHx\ncT6hItjkLtBN2JeogwefBnk4tQdaEluvd/r3RNZF9Re5NKcrHNMPJGd8RqZPwL/Z\nMpPIHTJzO1WNpPO+H4w/tYVJdhlE1vn/0d3lCYBdX6FT4i10XxWx7er9sdEj9ndX\n8LhHuA2O2z197jHEEufG6XAThBV8XACOaqNkw+nVbk2GS4EltIOZRqdeC0qvATs8\nAiWGpK5K7bgdIfItscYTkDpbOeZwFUkdxpOJ7ujqMgjZCbJ0WfPXmWEFGuixYXki\nLXM7vQQLAgMBAAGjbzBtMEwGA1UdEQRFMEOCFGlkZW0taWRwLmltdGx1Y2NhLml0\nhitodHRwczovL2lkZW0taWRwLmltdGx1Y2NhLml0L2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBRw6DX3JFHnfUlXHQXxcYUaIkKDmTANBgkqhkiG9w0BAQUFAAOCAQEA\nEzNzUHWImZwxpf8bu1BudPjcmtyQqHyPThTrpAd6UWm+MiwCPRdEYEfgWSnvGh0B\nSTzyTtF/0PTMXNt+ocPryWFlpigO6d4H/QBWNtlPqWmLfLFsrTm1Cvy6ihmSsqVk\nnFN3qHAfJd0Xl05zk0oxDg6u8CXWzlFJcKxm2P8ujJYkJVHkt3saNinZop7+oazU\nYM5NpKde4RG0tQJvDuzN3xFLCtTUZe9EnOV0tniikwk4ZGDFy7F14POhmYvq+V+W\nPMrXoG08C30q+20nepBYJz2JoY9nQlmGor4yK6Ft8RvgmYq1BuwEkAHYnWf4B26l\nBgRrAVj5NpDfLOfRZq+LOg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IMT Institute for Advanced Studies Lucca"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IMT Institute for Advanced Studies Lucca"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.imtlucca.it"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.imtlucca.it"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IMT Institute for Advanced Studies Lucca"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IMT Institute for Advanced Studies Lucca"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://stipendieansokan-test.uaf.uu.se/stipendium",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Stipendiehantering"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "stipendie-datordrift@its.uu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Uppsala universitet"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://stipendieansokan-test.uaf.uu.se/stipendium",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute_value": [
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "http://www.swamid.se/category/hei-service"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "http://www.swamid.se/category/research-and-education"
              }
            ],
            "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
            "name": "http://macedir.org/entity-category",
            "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Uppsala universitet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uu.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UU"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://stipendieansokan-test.uaf.uu.se:80/stipendium/saml/SingleLogout/alias/defaultAlias",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "http://stipendieansokan-test.uaf.uu.se:80/stipendium/saml/SingleLogout/alias/defaultAlias",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://stipendieansokan-test.uaf.uu.se/stipendium/stipac/login?lang=en"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://stipendieansokan-test.uaf.uu.se/stipendium/stipac/login"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "System f\u00f6r att s\u00f6ka och hantera stipendium vid Uppsala universitet (Test)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Scholarship management system at Uppsala university (Test)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://stipendieansokan-test.uaf.uu.se/stipendium/img/UU-logga_125x125.png",
                    "height": "125",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "125"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Scholarship Test"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Stipendiehantering Test"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYzCCAkugAwIBAgIEXsncWDANBgkqhkiG9w0BAQsFADBiMQswCQYDVQQGEwJzZTEQMA4GA1UE\nCBMHU3ZlcmlnZTEQMA4GA1UEBxMHVXBwc2FsYTELMAkGA1UEChMCVVUxCzAJBgNVBAsTAklUMRUw\nEwYDVQQDEwxUb21teSBTdGVudmkwHhcNMTQwMTIxMTIzMzIxWhcNMTcxMDEyMTIzMzIxWjBiMQsw\nCQYDVQQGEwJzZTEQMA4GA1UECBMHU3ZlcmlnZTEQMA4GA1UEBxMHVXBwc2FsYTELMAkGA1UEChMC\nVVUxCzAJBgNVBAsTAklUMRUwEwYDVQQDEwxUb21teSBTdGVudmkwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQCYm9zOwWOyPzD3W2ophyDRR2YKEuWdP1ZzQAUf7nwBRa0sf62UODcvavGJ\nFK+yVjdtDayls5KPyIfHiW0vJAjWPrhCRE/Nk4pCyPhEbVhBtSA/JfXUEtB9Otf79G8PmxCJGfUN\nTeaFIl1PhEjQtQGS9IHe/N0P/Gxn9hJL+452ePbScB0hpC2/Z61GV2GDmz8l8g2FS4BXC/OxpqkR\nTfWqVvO7h8UJrrPfntqLTEHpD9Ex0LAy9RBXAj/4eUt8obzr84IJLITF875icjXyRcq0510gtGAr\nLytJxy/5KQ/Y2rUVfVBSg3m4C5BRiTAKjNncx+JFhq665tyiLtOTITxPAgMBAAGjITAfMB0GA1Ud\nDgQWBBTFo53xd9YijvyHlNUZ6Gt1YLLjQTANBgkqhkiG9w0BAQsFAAOCAQEAEFmcm96wM5/SwNCj\ni5uX3XFkQ2IDqeVmAAOmY/3cRh/kXxSM1OR1rifCl4kQlHHxV/9+r1EwiJ+LIhhnBHwJLM2TVFKD\nDRm5Lq9ghRzjiKponRltsGQzdZx5b5dAsG+J3J0TWJCp+HXoO6FNbIs0WAPm2nGkICyUi+ZBmdM1\nNHqA2JtG95d1VrNeZMmou7CdUBqRIWSlQPcGhawq4tKrs/6C79JLwfDhIPidJ3V0gkVSjm1FSNC5\nDJLTyRKIJB8d1r0/RpePenawO79D5eJlDeUTpu0LcPMyCKPGVT0tFaU/TyF6Jn8CJ2ZIlybtdXtp\nlQDSN7w4inBTDBIKvjWfVg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "http://stipendieansokan-test.uaf.uu.se:80/stipendium/saml/SSO/alias/defaultAlias",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "http://stipendieansokan-test.uaf.uu.se:80/stipendium/saml/SSO/alias/defaultAlias",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "http://stipendieansokan-test.uaf.uu.se:80/stipendium/saml/SSO/alias/defaultAlias",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:profiles:holder-of-key:SSO:browser",
              "extension_attributes": {
                "{urn:oasis:names:tc:SAML:2.0:profiles:holder-of-key:SSO:browser}ProtocolBinding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact"
              },
              "location": "http://stipendieansokan-test.uaf.uu.se:80/stipendium/saml/HoKSSO/alias/defaultAlias",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:profiles:holder-of-key:SSO:browser",
              "extension_attributes": {
                "{urn:oasis:names:tc:SAML:2.0:profiles:holder-of-key:SSO:browser}ProtocolBinding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST"
              },
              "location": "http://stipendieansokan-test.uaf.uu.se:80/stipendium/saml/HoKSSO/alias/defaultAlias",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://shib.towson.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shib@towson.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Technical Issues"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "scs@towson.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Student Computing Services"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpcenter@towson.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OTS Help Center"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shib@towson.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Technical Issues"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.towson.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.towson.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.towson.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUeUyjo2SlWE+7HVwZNNPhmaRq7IUwDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPc2hpYi50b3dzb24uZWR1MB4XDTEwMTExOTIwNTAwNloX\nDTMwMTExOTIwNTAwNlowGjEYMBYGA1UEAxMPc2hpYi50b3dzb24uZWR1MIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAm+80ygl/7o0zJ9WOjMmCcxXoQDbC\nK3nzwqwBlbdZsrbyI2CK1jVdbm14qwX+CV7RcPlYn1UySNa5IKKcA5Peg4ZYgMY6\nZcql5VYe9soBEek/i/hDoUehZmk6IWOvJA/EdL+eVGU1YmFDTFVvdc0/VZVnSh3r\nMwAwULUIUYJ+VzEmGv2RvrH6q15DUlkvCu+DWbkAWOK2ttXI1jcBwciBtRkoeL6t\nvxSZLB62zaPMEwu337Qkb1nYW72LLJWxmdb5uoC6BO1mE/Gz1VnFGHLmWZESj31m\nghMM3Jq1c5F7pyw15ItYnp+cuEjhACYGUDXsVVzm0IHfU8Hn8pZ4+XfodQIDAQAB\no2UwYzBCBgNVHREEOzA5gg9zaGliLnRvd3Nvbi5lZHWGJmh0dHBzOi8vc2hpYi50\nb3dzb24uZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTxJKAJrXHxDDfkW8v/\n6jWfrJawZDANBgkqhkiG9w0BAQUFAAOCAQEAPPBq7pprx9bbAblcUa4ma65htZ4K\nadAHoIcglr33+nQqXBHzfVosNT9iB2lZcOYsICLu0Y9CuPVHKvVQDQlgXsn5YaWu\niv5oVv3pl91q0eE621oFH+igbl2RpiKENNj4w1fNTikJLIWXSEYpZa5jdmhLNn6Y\nz9FJuXn8i7FSvQfu8kOsjmKOCUD333hzjWzy1mYA59Y1dvfz3WGu4FeUB6F6sHLw\nq4DITFHAjZ2SWqqovGnDQE4gDkjMo9VcoCkuJXlDe5tcL4p4VVCpTxAf1gjVjZI8\nnFkR2HziVx5kyIQzS4OseZJhuckZtZM/ln/unK1EHe7e7DEx/l47qSDrBg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "towson.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.towson.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.towson.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.towson.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.towson.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.towson.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.towson.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "towson.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://shib.towson.edu/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Towson University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Towson University Shibboleth Identity Provider allows TU faculty, staff and students to access external service providers using their TU NetID."
                  }
                ],
                "logo": [
                  {
                    "text": "https://shib.towson.edu/tulogo.png",
                    "lang": "en",
                    "height": "95",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "150"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://inside.towson.edu/generalcampus/tupolicies/categorylist.cfm?thecategory=Information%20Technology"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUeUyjo2SlWE+7HVwZNNPhmaRq7IUwDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPc2hpYi50b3dzb24uZWR1MB4XDTEwMTExOTIwNTAwNloX\nDTMwMTExOTIwNTAwNlowGjEYMBYGA1UEAxMPc2hpYi50b3dzb24uZWR1MIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAm+80ygl/7o0zJ9WOjMmCcxXoQDbC\nK3nzwqwBlbdZsrbyI2CK1jVdbm14qwX+CV7RcPlYn1UySNa5IKKcA5Peg4ZYgMY6\nZcql5VYe9soBEek/i/hDoUehZmk6IWOvJA/EdL+eVGU1YmFDTFVvdc0/VZVnSh3r\nMwAwULUIUYJ+VzEmGv2RvrH6q15DUlkvCu+DWbkAWOK2ttXI1jcBwciBtRkoeL6t\nvxSZLB62zaPMEwu337Qkb1nYW72LLJWxmdb5uoC6BO1mE/Gz1VnFGHLmWZESj31m\nghMM3Jq1c5F7pyw15ItYnp+cuEjhACYGUDXsVVzm0IHfU8Hn8pZ4+XfodQIDAQAB\no2UwYzBCBgNVHREEOzA5gg9zaGliLnRvd3Nvbi5lZHWGJmh0dHBzOi8vc2hpYi50\nb3dzb24uZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTxJKAJrXHxDDfkW8v/\n6jWfrJawZDANBgkqhkiG9w0BAQUFAAOCAQEAPPBq7pprx9bbAblcUa4ma65htZ4K\nadAHoIcglr33+nQqXBHzfVosNT9iB2lZcOYsICLu0Y9CuPVHKvVQDQlgXsn5YaWu\niv5oVv3pl91q0eE621oFH+igbl2RpiKENNj4w1fNTikJLIWXSEYpZa5jdmhLNn6Y\nz9FJuXn8i7FSvQfu8kOsjmKOCUD333hzjWzy1mYA59Y1dvfz3WGu4FeUB6F6sHLw\nq4DITFHAjZ2SWqqovGnDQE4gDkjMo9VcoCkuJXlDe5tcL4p4VVCpTxAf1gjVjZI8\nnFkR2HziVx5kyIQzS4OseZJhuckZtZM/ln/unK1EHe7e7DEx/l47qSDrBg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://shib.towson.edu/errorpage.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Towson University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://towson.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Towson University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.davidsonccc.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "donald_beck@davidsonccc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Donald Beck"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.davidsonccc.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.davidsonccc.edu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.davidsonccc.edu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.davidsonccc.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.davidsonccc.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.davidsonccc.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.davidsonccc.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.davidsonccc.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.davidsonccc.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "davidsonccc.edu"
              },
              {
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.davidsonccc.edu/about-dccc/consumer-information"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Davidson County Community College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAOPBqGh9irD58qMJrkXkh/ezrjfMMA0GCSqGSIb3DQEB\nBQUAMB4xHDAaBgNVBAMTE2lkcC5kYXZpZHNvbmNjYy5lZHUwHhcNMTQwNDEwMTUz\nNDA4WhcNMzQwNDEwMTUzNDA4WjAeMRwwGgYDVQQDExNpZHAuZGF2aWRzb25jY2Mu\nZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAgwDFkLeubg1tsp9u\n7DHvJcOPiwgrYeKok6Vj4UXwz4tDkapdJYh/E1pl9rT6dgkL0US1b82RFqm8Yue2\nd2jW6K2srUC7agsXZgpgW2a3m3bi/BGZw8DkS9CQIe8xadfzhfDLa783qq3hBpcK\nU3xA7FDbdLT2Esl/C2xs/Ba582XSxzEHQZiMLte9u71d6pCmcpYsvK6EQ06DXg4V\nScb/eI0iNakeYfV18HjZckPBj+Vy9EbfHfOpL9eF7z/94vWgV/NsP5MOu0D2xvJM\nseD8ivFlhh2KUO5pwjfRXP4D2Vs5O/4r/KClxKKH5EMme2biuMZfuSNTvETJduLj\n4qD1QQIDAQABo20wazBKBgNVHREEQzBBghNpZHAuZGF2aWRzb25jY2MuZWR1hipo\ndHRwczovL2lkcC5kYXZpZHNvbmNjYy5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0O\nBBYEFJI6cN+BwFdJN7T2pAEoF8e2rnSoMA0GCSqGSIb3DQEBBQUAA4IBAQBKj7NQ\nnOs2xkYeMXw9uE8uAgTcLBD1/wgeSU33yg/G+CSZqTn6bkLegvQcmiMYUptq8nyQ\nYNMTYEHOtKYNCgbAbm15PzUVqAFibC908FvHZrVl6ikbVel8JRmZAHVY/h5afDzR\nbwBZpmSAmNn2LvOAkNkuLco9Mdk684pvzIOf9IYVtIo/D5IxPD3vTWItvVozOdqH\nqC2o1XXHUUwLwPgrSOcGIJw6C59R6EljLEKdGh7y+w+ilOgYg124WsGfU3d8Fl3w\nF6ZaB5MM41/G/pJ4M3CEOhOKVa4H/0+IGBf+K6pNcBGbCqXz0GDPgBGlsiU/7yfS\nF3CFoqtbWNwbBjfZ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Davidson County Community College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.davidsonccc.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Davidson County Community College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://uk.ihs.com/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:customer.support@ihs.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Customer Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cooley"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:trevor.cooley@ihs.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Trevor"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://uk.ihs.com/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-03-03T10:05:50Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IHS (Global) Limited"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://uk.ihs.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IHS (Global) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ihssso.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.ihssso.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ihssso.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ihssso.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ihssso.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.ihssso.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.ihssso.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEGjCCAwKgAwIBAgIJANbtDttZCw1wMA0GCSqGSIb3DQEBBQUAMIGNMQswCQYD\n\t\t\t\t\t\tVQQGEwJVSzEQMA4GA1UECBMHRW5nbGFuZDESMBAGA1UEBxMJQnJhY2tuZWxsMQww\n\t\t\t\t\t\tCgYDVQQKEwNJSFMxCzAJBgNVBAsTAklUMRYwFAYDVQQDEw13d3cuaWhzdGkuY29t\n\t\t\t\t\t\tMSUwIwYJKoZIhvcNAQkBFhZob3N0aW5nc3VwcG9ydEBpaHMuY29tMB4XDTA5MDky\n\t\t\t\t\t\tMjEwMzM0OFoXDTE5MDkyMDEwMzM0OFowgY0xCzAJBgNVBAYTAlVLMRAwDgYDVQQI\n\t\t\t\t\t\tEwdFbmdsYW5kMRIwEAYDVQQHEwlCcmFja25lbGwxDDAKBgNVBAoTA0lIUzELMAkG\n\t\t\t\t\t\tA1UECxMCSVQxFjAUBgNVBAMTDXd3dy5paHN0aS5jb20xJTAjBgkqhkiG9w0BCQEW\n\t\t\t\t\t\tFmhvc3RpbmdzdXBwb3J0QGlocy5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQC/Ba3IwwsIvQgkzb/ssluNjiU95zWtyFMBCJ9b03XmB12QPF+/nTEV\n\t\t\t\t\t\tVFu8Lm4btL7bu4FEQs04rWfxQ4EWpNgeh//UzohcUkikRT+empVepOlyxMCBr+3Q\n\t\t\t\t\t\tfq/JN8P9riOuhW6uiADUWQ1OXOTdl4lAUXzSc7e/N+7vg4wIb7xzFDtp6h8BqhdF\n\t\t\t\t\t\ta/noDPXXFesxtEq0ZjSVYahNMOhpsIZXNPKjuBlCFM/IC+5K6LYCY+2qYcuKH4YB\n\t\t\t\t\t\tQtDtc7/KKJK0i3SpormleAXE9UPX+79nQ2uqUbhNG6OQzKpD+nIYDN/sPec8u2m8\n\t\t\t\t\t\t2c+GPkqg8pKQz6LzdL8uTN5sZHgzQvg9AgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJ\n\t\t\t\t\t\tYIZIAYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1Ud\n\t\t\t\t\t\tDgQWBBR99TJ9Meg90c3p614N474dVMS82DAfBgNVHSMEGDAWgBR99TJ9Meg90c3p\n\t\t\t\t\t\t614N474dVMS82DANBgkqhkiG9w0BAQUFAAOCAQEAPM9Luz4hiaqXrCtcJ8NmNp40\n\t\t\t\t\t\tb8x/zkUTI9VRq0EtIlD2UqnVVAh4HrGgGI0wnlzIdyaMdfjied/PBflfDto5tTz9\n\t\t\t\t\t\tZ/9C4EViX91kOmApwJyiScP/cJX4BjUk08vORqIbu8oXlOfmcCAjT5+Y6RcloS9h\n\t\t\t\t\t\tnkGwwNk8UnymkQtqw/MnK3DKTxcLdG4iphtzwpbcnAgO/Nb/mT8/tRWy215OuDII\n\t\t\t\t\t\tDzE+93eMDZMqxG6X3jyYtfF9f551vCFvTDvOxkDd9dnSYPzb+++8BfTYtEnwpNiK\n\t\t\t\t\t\tyKYcCFVxFCy1km7h2HBrOZMLUAbs0gGoTmSRAEByt0E3C8xzV1Ywu9htzRHmog=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ihssso.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.ihssso.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ihssso.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.ihssso.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.ihssso.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.ihssso.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://preklin.nu/simplesaml/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dangler"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "alexander.dangler@gmail.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alexander"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://preklin.nu/simplesaml/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "http://preklin.nu/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.preklin.nu/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.preklin.nu/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration av inbjudningar f\u00f6r firande av l\u00e4karprogrammets f\u00f6rsta fyra terminer p\u00e5 Uppsala universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Adminstration of guest invites for the student celebration for completion of the first four semesters at the medicine program at Uppsala University"
                  }
                ],
                "logo": [
                  {
                    "text": "https://weblogin.uu.se/idp/UUlogin/img/logga-50.png",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Preklin p\u00e5 Uppsala Universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Preklin p\u00e5 Uppsala University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID6zCCAtOgAwIBAgIJAJf4AFVzk7oTMA0GCSqGSIb3DQEBCwUAMIGLMQswCQYD\nVQQGEwJTRTEQMA4GA1UECAwHVVBQU0FMQTEQMA4GA1UEBwwHVVBQU0FMQTEQMA4G\nA1UECgwHUHJla2xpbjEaMBgGA1UEAwwRQWxleGFuZGVyIERhbmdsZXIxKjAoBgkq\nhkiG9w0BCQEWG2FsZXhhbmRlci5kYW5nbGVyQGdtYWlsLmNvbTAeFw0xNTA5MDQx\nNDUxNDNaFw0yNTA5MDMxNDUxNDNaMIGLMQswCQYDVQQGEwJTRTEQMA4GA1UECAwH\nVVBQU0FMQTEQMA4GA1UEBwwHVVBQU0FMQTEQMA4GA1UECgwHUHJla2xpbjEaMBgG\nA1UEAwwRQWxleGFuZGVyIERhbmdsZXIxKjAoBgkqhkiG9w0BCQEWG2FsZXhhbmRl\nci5kYW5nbGVyQGdtYWlsLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\nggEBAMXpMfWVvvE6WSUXJGxjuFO4Egw4v/iqB5imiwMlOTMp8SkQqp+ZjlUQ+XH1\n8wAbLhpUK37GUdMnnlFv9MosDikL8OV+t6lyncyYrLjYQBdXBzgE/g4fnujDu0kG\n7sQ6YYFk2DS8XIIZRbDdBDbaVshjnacbiLmBXAbZA6VgsvtI1+4Kuig60iThKtli\nTXdU2qUkzT40EUbuck0rPygy2FnsnG2ggdddFwW2v3mNxyz0+03FacG82q3wIenM\nR++QYSnBMYuUPxWpt0niMNurW1ePkfScOn4L9kB+wZAUptUtLjpbk6M4Ec4wyrdE\nbTdg2v9gO1DaKKLDQM59POsO2RcCAwEAAaNQME4wHQYDVR0OBBYEFATpr5UP8UW/\nVrxInHT9QPqJWCHWMB8GA1UdIwQYMBaAFATpr5UP8UW/VrxInHT9QPqJWCHWMAwG\nA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQELBQADggEBADi+d3Z3FJz0X9FyN4Fj7X1n\nCWD0aufIZ4ke6UW49PMbIBkL1qMhjWhOGdhPqQExLoGJw33OKtOXTMRwk9P0M7Z+\niGkPsASOWf2+po5AvYYaE41yACyhR3z3TtdRdEK9wiEUx0otU5rT9o5oWEk4orap\n3m623aO3cMuwum0U3HKx+EQHQVeBmix4JJq996fFLHkyNXbBU/ddHsyneuHC7jtQ\nn2/PvABPMf4yqzv522ZTszEuJKEp7WI9ctMUDqPxwOxMTdY83O7AH3UZSyIPDEHC\nDpkx/wL59aMiGk9AtYes2Mr1wU44nh2/JRWkSRBU4Ep+sb9jRFbn4/RZaNZqRnc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://preklin.nu/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "http://preklin.nu/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.mines.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mbrookov@mines.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matthew B. Brookover"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "erickson@mines.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael Erickson"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.mines.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.mines.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.mines.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.mines.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.mines.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.mines.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mines.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Colorado School of Mines"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVALrVjyviCwnipvwjtC7VXHNfQYsFMA0GCSqGSIb3DQEB\nBQUAMBgxFjAUBgNVBAMTDWlkcC5taW5lcy5lZHUwHhcNMTQwNDA3MjAzMTE4WhcN\nMzQwNDA3MjAzMTE4WjAYMRYwFAYDVQQDEw1pZHAubWluZXMuZWR1MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmypcCiTRtq+l22di6Wp200buqUJTdKZe\npWQ7uOhe64ns1HbPyXBeCAnUI3yLeUduwrj/VDJEQsh5Sdpg/I8lkf3zUoDNEUeM\ntp8nZjRDCysLZcotlaT1nfFj5g/Yvk1BBb+09y+Orovcv3NLY9DE42qK5CrnWdqO\n6TWme1sgNtClkFBgxDbXGGQzNqHHvAUQooSiDVB716u4t0KlKREvDNdmx5KJ7jjO\nstlMOxw2L1xnGs7dScUDR9AYxWuZ2v7l5sgeTGVGY39DJbRk4jHi4vxsVYBlq18/\nWFoS94t4g32KpDYclxfZIlkgibU0E9Bw8wcnq5h9My1J0aKOS+366QIDAQABo2Ew\nXzA+BgNVHREENzA1gg1pZHAubWluZXMuZWR1hiRodHRwczovL2lkcC5taW5lcy5l\nZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFNxq63HQJW8lr4dh/q1gtcJJ0bFg\nMA0GCSqGSIb3DQEBBQUAA4IBAQB2/aY7NYBtrztFTQeQjhUg76xuVzBskqvgIKfU\n4YeYjvK86VNEKlppGkylFHm817Sy2yeDozoKV2jS46GOlg9ZgE7NGiLdK1NP2vup\nS5KdtuOu7wnrrzkKQqY3zL4TDwK4qPZxOAFZcFSYdoPNGc+fKrhw7bo6S+ZSjFtm\n68I/MXFy+Q9iGYh6dPC5x3PRn0hn1TPTJ1GczhkNGFZLZqnE4Pb/gPXwbSx3jvyv\npDZoqzjpdIxwH4osA5q6R8DkFUHxsOQlPHTZozbBtkIcKigYYG2sEmKmHUxmV9zu\nt6dBbef3d3Mj0qVgNOz7Nyvv1qrAUw8WUziVYMzIeS9tQJa1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Colorado School of Mines"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mines.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Colorado School of Mines"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.uni.opole.pl/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Paszkiewicz"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idp@uni.opole.pl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "S\u0142awomir"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.uni.opole.pl/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.pionier.net.pl/en/index.php?page=rps"
              }
            ],
            "registration_instant": "2015-12-02T00:00:00Z",
            "registration_authority": "https://aai.pionier.net.pl",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.uni.opole.pl/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.uni.opole.pl/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.uni.opole.pl/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.uni.opole.pl/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.uni.opole.pl:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.uni.opole.pl:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uni.opole.pl"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Opole University Identity Provider"
                  },
                  {
                    "lang": "pl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Dostawca To\u017csamo\u015bci Uniwersytetu Opolskiego"
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth.uni.opole.pl/idp/logouo_header.png",
                    "lang": "en",
                    "height": "55",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "165"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Opole University"
                  },
                  {
                    "lang": "pl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Uniwersytet Opolski"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUJYgjpRkfWuuLnYgjmOtFu6kZyuQwDQYJKoZIhvcNAQEL\nBQAwGjEYMBYGA1UEAwwPaWRwLmV4YW1wbGUub3JnMB4XDTE1MDQzMDA2NTU1MloX\nDTM1MDQzMDA2NTU1MlowGjEYMBYGA1UEAwwPaWRwLmV4YW1wbGUub3JnMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvpolQ/zhvPO0OGBOJu8JjMLurb10\nqNcR+RuS/YUZ2wbnjggMSCHm+X+dY2RAX2Qu3sty2f6Rizpwa4dHcTVARrHonPu2\n0j+bFjQndzODqAbg3IsD+i9P2qPXJOZ0atgfcf5FQ+h8AgOST3pRX9YSwDcOZ/mO\nhoDlitxWJmXxX+e39Ix0/ONtfpy+R9JKE+UEuqZ/xBiwmKwfRll5M4V7mZj8UcFW\n/AvoWol8h+UUtHSweZxZYAad1nniIlDOBN//ABM+wRc4saC/bB/wV1NTi8ZQp8i+\nMEZ+81TwOmpxo/z5EOPbl0/rl1VhG54yxjFFgqI13tn4QLoJWUGozYO1dwIDAQAB\no2UwYzAdBgNVHQ4EFgQUA1adRNultXunWuW5NyNRqc46bdowQgYDVR0RBDswOYIP\naWRwLmV4YW1wbGUub3JnhiZodHRwczovL2lkcC5leGFtcGxlLm9yZy9pZHAvc2hp\nYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAooPuGuUZiJUc+9rW8FnHvflucH3h\nrpu75Fyp6/e7U+KpiKAmrdo83/Ve4GadEhBEANZ/lbu1z5eZTurXhPA6j4Df89Xf\n3GkPpyy9YoFvKypn/FeUAMpyo+BlNSnzAQuC+b+AYZrKwjwBKk9vrpGPJ7uUsz9D\nVBWHN6W0pQqExq6qXfgcLGnluzqJ0LbNGJrndfKV4WN/MAE52zVo24f9huQandRt\nPTimpBVSen6/qlR87r67YGV6/jgfL3Q8N5g42sT2iT/05Q22aYaIk1+e9X44jIos\ngn4E7aCKeaHFN/LG+NCNR1Fq+g0vDJIPe6FDeaC+kqK84MtvxqxG/wJxBQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVANM9C5l48yMhTAHJ9LbCXXOK1yQHMA0GCSqGSIb3DQEB\nCwUAMBoxGDAWBgNVBAMMD2lkcC5leGFtcGxlLm9yZzAeFw0xNTA0MzAwNjU1NTBa\nFw0zNTA0MzAwNjU1NTBaMBoxGDAWBgNVBAMMD2lkcC5leGFtcGxlLm9yZzCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALCW6XciidnTK7mHBV+aDlGBuNKk\nPj6O3bXSdt0cQQhMlKS7rNmxMaKsS1SxKB/E5OcUeL1DjAqICGpYls33cWIgLvSB\nwTkLRWQRLxsV2cvdRK6Deb32Tf7KeR3w0coHpYQ8GeYVTGA98F2Ovmo/ZUgXr2qK\nC55rOrmbyPs7Bqi9jjeFDNaczu3Y25kkp1sultt4AZZOtMkIsjypnYkhxn9/2fVp\nW/ZFXqoemfT3N63t1SWNZc+Yaeo82kvbLcrkFeOdkD2vmXMXSjt/+LGOnI8fpARy\nr/57UVycEpyfDp+Fve+EeUOP7LMQMVpLTQJxLFesL0lTTUsgx1PktUmc18ECAwEA\nAaNlMGMwHQYDVR0OBBYEFKlA/UMF3cCICQgPWEmRaIAaALeYMEIGA1UdEQQ7MDmC\nD2lkcC5leGFtcGxlLm9yZ4YmaHR0cHM6Ly9pZHAuZXhhbXBsZS5vcmcvaWRwL3No\naWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAA95wRr3PU93Cy9Cu2oCIOPpNrHm\n7FO524QdyhuInC9Ue6ZGrez2J9TNJIblQzzsCw+STD0A0Hs8oHuZxl0hV8USsq4f\nZNkdoRIntpIpOt7VefS2pxNDP1JGzgI36S2dgRPgNGBhtsd+5EjRCOPONeUy2gx/\nOeBnwcw8j36pQHdRlZKQVspAS5h0ePRHbS7luIQDeL8ZUkXIXuLEmnjHXnJzWUCP\nN5DC9rjlhu2+0Z1KeiuZgmVAiB66BFvjXCnkWIK5kh+/C/BYQpgHDx7B9nBYr5Xb\n2iYaqN73c9+XwBSf0+vYLC9Ivn6fAXMUN/wkK1FH9hjX09wBPR8LS2oq5fg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUEVPEG+BAdndjuiWqotqWKaPL2jowDQYJKoZIhvcNAQEL\nBQAwGjEYMBYGA1UEAwwPaWRwLmV4YW1wbGUub3JnMB4XDTE1MDQzMDA2NTU1MVoX\nDTM1MDQzMDA2NTU1MVowGjEYMBYGA1UEAwwPaWRwLmV4YW1wbGUub3JnMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoGJI6hLgX21HDCZsTHQoI4xA91YD\nLNuTv2q+nxSHeYy3uCDCAbDAuwJDnpdbdGlYadVvG1gHTkHRMc7pS2HSgd5y27Ig\nTMzAUeLLJM1ZUajJs8d7g32LLGQEHIFAwidYB+saKaCOCSRowLx5Cw5vFWLxEEih\nevERL6P8J3mb/6vzTSJeqYU9XQxI8+FQQY9mI7JLaprn60dHj3S/XnxLmbVEgQ2Z\n/jSRFDAufZ8Jv9EAqMqmRtXEakaYjQzM/anu0wPE+CeBHQA6geobUN+L1sbs70iE\neei8gvGiI+Y+2cQzSjIL0qEH3YFcLV05R2iRgUN1aMXywxLOlfRhl9bOrQIDAQAB\no2UwYzAdBgNVHQ4EFgQU/rP7y0WdXMLRdHdnxh5xPbLpFskwQgYDVR0RBDswOYIP\naWRwLmV4YW1wbGUub3JnhiZodHRwczovL2lkcC5leGFtcGxlLm9yZy9pZHAvc2hp\nYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAL1YSqSt0GbkJqiBsKvf0NgInNIAz\n25HjG/RxxETiQicxIrusYLgOb9czKQKGi9cWxyKY00cVBPLq9J2TIg0URWJBZMnh\nQzcZS9Bz4eDIuQ/s1zzOTxJzeAUJHIIme8DwEx+VNJHdVuntmf44TsxdOxxTPg0S\ndd55ODSvyXtIcJcCSj4Iuh6iQM+Wlq2PAH4GxhPmevz/Yl/5kEGIKrAjcfDOTwaD\nvp0OaVjVxH3HPESQTqPd2JrOVd4Ghtf59oadIMAwGxQ93/Ci33s9iaoHYEQtnHdQ\nKbGw/zFpxtXvzKZu3tXYOU79RQceiSTlOhm2JNPPL43AwNw6rsX69prLZg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Opole University"
          },
          {
            "lang": "pl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Uniwersytet Opolski"
          }
        ],
        "organization_url": [
          {
            "lang": "pl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni.opole.pl/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni.opole.pl/en"
          }
        ],
        "organization_name": [
          {
            "lang": "pl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Uniwersytet Opolski"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Opole University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.kpi.ua/simplesaml/module.php/saml/sp/metadata.php/ntuu-kpi-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@kpi.ua"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TechSupport"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.kpi.ua/simplesaml/module.php/saml/sp/metadata.php/ntuu-kpi-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://peano.uran.ua/~eng/policy.htm"
              }
            ],
            "registration_instant": "2015-05-12T11:04:00Z",
            "registration_authority": "https://peano.uran.ua",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "ru",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u041d\u0422\u0423\u0423 \"\u041a\u041f\u0418\""
          },
          {
            "lang": "uk",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u041d\u0422\u0423\u0423 \"\u041a\u041f\u0406\""
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NTUU \"KPI\""
          }
        ],
        "organization_url": [
          {
            "lang": "ru",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://kpi.ua/ru"
          },
          {
            "lang": "uk",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://kpi.ua"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://kpi.ua/en"
          }
        ],
        "organization_name": [
          {
            "lang": "ru",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u041d\u0430\u0446\u0438\u043e\u043d\u0430\u043b\u044c\u043d\u044b\u0439 \u0422\u0435\u0445\u043d\u0438\u0447\u0435\u0441\u043a\u0438\u0439 \u0423\u043d\u0438\u0432\u0435\u0440\u0441\u0438\u0442\u0435\u0442 \u0423\u043a\u0440\u0430\u0438\u043d\u044b \"\u041a\u0438\u0435\u0432\u0441\u043a\u0438\u0439 \u043f\u043e\u043b\u0438\u0442\u0435\u0445\u043d\u0438\u0447\u0435\u0441\u043a\u0438\u0439 \u0438\u043d\u0441\u0442\u0438\u0442\u0443\u0442\""
          },
          {
            "lang": "uk",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u041d\u0430\u0446\u0456\u043e\u043d\u0430\u043b\u044c\u043d\u0438\u0439 \u0422\u0435\u0445\u043d\u0456\u0447\u043d\u0438\u0439 \u0423\u043d\u0456\u0432\u0435\u0440\u0441\u0438\u0442\u0435\u0442 \u0423\u043a\u0440\u0430\u0457\u043d\u0438 \"\u041a\u0438\u0457\u0432\u0441\u044c\u043a\u0438\u0439 \u043f\u043e\u043b\u0456\u0442\u0435\u0445\u043d\u0456\u0447\u043d\u0438\u0439 \u0456\u043d\u0441\u0442\u0438\u0442\u0443\u0442\""
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National Technical University of Ukraine \"Kyiv Polytechnic Institute\""
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.kpi.ua/simplesaml/module.php/saml/sp/saml2-logout.php/ntuu-kpi-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://sp.kpi.ua"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Service Provider for NTUU KPI"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://sp.kpi.ua/privacy-policy.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NTUU KPI SP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFjDCCBHSgAwIBAgIQEUOHKK6sc4pWmFK5HgFIITANBgkqhkiG9w0BAQsFADCB\nkDELMAkGA1UEBhMCR0IxGzAZBgNVBAgTEkdyZWF0ZXIgTWFuY2hlc3RlcjEQMA4G\nA1UEBxMHU2FsZm9yZDEaMBgGA1UEChMRQ09NT0RPIENBIExpbWl0ZWQxNjA0BgNV\nBAMTLUNPTU9ETyBSU0EgRG9tYWluIFZhbGlkYXRpb24gU2VjdXJlIFNlcnZlciBD\nQTAeFw0xNTEyMDMwMDAwMDBaFw0xNzAzMDUyMzU5NTlaMIGZMSEwHwYDVQQLExhE\nb21haW4gQ29udHJvbCBWYWxpZGF0ZWQxQjBABgNVBAsTOVByb3ZpZGVkIGJ5IENl\nbnRlciBvZiBVa3JhaW5pYW4gSW50ZXJuZXQgTmFtZXMgKFVLUk5BTUVTKTEcMBoG\nA1UECxMTVWtybmFtZXMgRG9tYWluIFNTTDESMBAGA1UEAxMJc3Aua3BpLnVhMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvonPE5+8bja2hn3MFzSwhuAB\nvFZBdpUq7//hvcpNsdHSjNBL5oWTT99bO+E4hIjf5HaSl1T6ZcH2KNl1AWHFKZnO\npLoi57mX0e8iMYXkOC5SCxSOEURgyBzjDO0bg26NuxWKnTHNjcRqTt3X+aI8qOHa\nEbvokM6E4MmKUErQqBlC85KrNS6Mn6oclRjNP/QYfKk5LE1wQwEa9WEGIMfzXwbz\nIFA61/Shscrq2LOEYAo1L/2Lp6xWPgnPrHXJNN1jj8tvINnslAJ6qTVNPbGWDgni\nzY5rAhcNSJOeWfaKsJdSD4vrcFWhMsf34HI+/EYyn99mjSzU5FtAoEzAcjqFiQID\nAQABo4IB1TCCAdEwHwYDVR0jBBgwFoAUkK9qOpRaC9iQ6hJWc99DtDoo2ucwHQYD\nVR0OBBYEFIMTyzQx9IadYPh9b4ApSthFUYIFMA4GA1UdDwEB/wQEAwIFoDAMBgNV\nHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjBPBgNVHSAE\nSDBGMDoGCysGAQQBsjEBAgIHMCswKQYIKwYBBQUHAgEWHWh0dHBzOi8vc2VjdXJl\nLmNvbW9kby5jb20vQ1BTMAgGBmeBDAECATBUBgNVHR8ETTBLMEmgR6BFhkNodHRw\nOi8vY3JsLmNvbW9kb2NhLmNvbS9DT01PRE9SU0FEb21haW5WYWxpZGF0aW9uU2Vj\ndXJlU2VydmVyQ0EuY3JsMIGFBggrBgEFBQcBAQR5MHcwTwYIKwYBBQUHMAKGQ2h0\ndHA6Ly9jcnQuY29tb2RvY2EuY29tL0NPTU9ET1JTQURvbWFpblZhbGlkYXRpb25T\nZWN1cmVTZXJ2ZXJDQS5jcnQwJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmNvbW9k\nb2NhLmNvbTAjBgNVHREEHDAagglzcC5rcGkudWGCDXd3dy5zcC5rcGkudWEwDQYJ\nKoZIhvcNAQELBQADggEBAIFHyhglkkb80erci5a4pK6Vgsi2C34WxnUZzcwWmD3G\nm3UJsOkNPDAv3E1bifayu05nZQdLHy1crtgKs0q5FkqhPSBs6iOzr5YObCZOCVl7\nrYyarYeMXdqcPYKuRYXPO3Z8RGoVPYRyUU7gi5lyz+5i1EeSFqEkwVGTV7EzjBtr\nscGwj5R7R1F8+6m+zW6wLnJqIIYUZ8UpxtF7n/Mtza8bdJQJ+39JeHX+ZErdYh3e\n2a7XcvfmOg9UBEhd/UhzCegDplloCmxzt2dmmlFEPj/IA5wJCtc0nUmeirxhYoZx\n5GHTzCwt0Z2osUZDlKP/lZr+nSBukUtRYtyoNNJoUJ0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.kpi.ua/simplesaml/module.php/saml/sp/saml2-acs.php/ntuu-kpi-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp.kpi.ua/simplesaml/module.php/saml/sp/saml1-acs.php/ntuu-kpi-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.kpi.ua/simplesaml/module.php/saml/sp/saml2-acs.php/ntuu-kpi-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp.kpi.ua/simplesaml/module.php/saml/sp/saml1-acs.php/ntuu-kpi-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "NTUU KPI SP"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Service Provider for NTUU KPI"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "transientId",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.2.3.4.5.6.7.8.9.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:incommon:jmu.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@jmu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "linuxteam@jmu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Unix/Linux Group"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:jmu.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://itfederation.jmu.edu/shibboleth-idp/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://itfederation.jmu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://itfederation.jmu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://itfederation.jmu.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "jmu.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://itfederation.jmu.edu/idp/images/James_Madison_logo_black.png",
                    "lang": "en",
                    "height": "125",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "230"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "James Madison University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEvTCCA6WgAwIBAgIJAMwnlWaj6tOPMA0GCSqGSIb3DQEBBQUAMIGaMQswCQYD\nVQQGEwJVUzERMA8GA1UECBMIVmlyZ2luaWExFTATBgNVBAcTDEhhcnJpc29uYnVy\nZzEhMB8GA1UEChMYSmFtZXMgTWFkaXNvbiBVbml2ZXJzaXR5MR8wHQYDVQQLExZJ\nbmZvcm1hdGlvbiBUZWNobm9sb2d5MR0wGwYDVQQDExRpdGZlZGVyYXRpb24uam11\nLmVkdTAeFw0xMjA2MDUxNTExMTRaFw0yMjA2MDUxNTExMTRaMIGaMQswCQYDVQQG\nEwJVUzERMA8GA1UECBMIVmlyZ2luaWExFTATBgNVBAcTDEhhcnJpc29uYnVyZzEh\nMB8GA1UEChMYSmFtZXMgTWFkaXNvbiBVbml2ZXJzaXR5MR8wHQYDVQQLExZJbmZv\ncm1hdGlvbiBUZWNobm9sb2d5MR0wGwYDVQQDExRpdGZlZGVyYXRpb24uam11LmVk\ndTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMoRMpZ+1Y8Z6de8v1Zj\n3UYNEj0b2V/mSd9rseQtcAgPMwL2khVt/GJoPpdG7DGmRCATuVpkzD/k1vA06cBO\nknCHpOhHvn2AgYyfPFqbHY1bBLE0sKqynnj2W5S19Sb+9DYl5lY7gQsoXCX5o0ql\niBjp7Yqo1aMT/rImOZlcw4r7GL/dTi+0Q1ScWUX+YNCJF22sAg/HctNjqCkEwPqV\nv5K0UHZ96YpdOXmC+pzQ9oo33RANpaMGHpA63eM70rzVZccVspb0LG8sZZLuTavH\nXTpGf2tR2TauKS1zP9ok0ZD5rweDem3BKtRP7i9R+tuejzHi3JH2Dur59At616y1\njN0CAwEAAaOCAQIwgf8wHQYDVR0OBBYEFJ50wNaJkgk5WSLNo0w/NhDjxmYpMIHP\nBgNVHSMEgccwgcSAFJ50wNaJkgk5WSLNo0w/NhDjxmYpoYGgpIGdMIGaMQswCQYD\nVQQGEwJVUzERMA8GA1UECBMIVmlyZ2luaWExFTATBgNVBAcTDEhhcnJpc29uYnVy\nZzEhMB8GA1UEChMYSmFtZXMgTWFkaXNvbiBVbml2ZXJzaXR5MR8wHQYDVQQLExZJ\nbmZvcm1hdGlvbiBUZWNobm9sb2d5MR0wGwYDVQQDExRpdGZlZGVyYXRpb24uam11\nLmVkdYIJAMwnlWaj6tOPMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEB\nAK8EXe8Og7W6M384gTsVNHcG1h6B6pmXhHZfVwVucYEenggcSQ7ErWCZliCE0Ae8\nhfiqPZDdLrrzaF6/gp6sfueuRbKXaa41FfcuvOGaUs25TD3hf7tH2N4Voq7akAtP\nYCdtupLvbB7eM8CFJwKdOc43tLUO3eG4eJzMWV6hX+PwwqCbZIvcKbFpFhzMSN/u\nMsH+FBVwtyV/jxAkRpw/MRczHruwPObYT6mKoVMdOaP0NvAEtqQRFBuJQh760wpz\nQzYSjyLb8gehpoRs8nWw73l8FgKhXa/hz06Vp9hibCfxxSWb8bktOu8MruAM4zVe\nItgUieNNRzPjqrr/K8B4rWo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "error_url": "https://itfederation.jmu.edu/shiberror.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "James Madison University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jmu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "James Madison University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:cru.fr:federation:uhb.fr",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "admin-unix@uhb.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:cru.fr:federation:uhb.fr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-04-23T13:48:41Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.uhb.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.uhb.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.uhb.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uhb.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-haute-bretagne.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-rennes2.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uhb.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 Rennes 2"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 Rennes 2"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUN1TTOPl4sgCyt2P8GnFSEqcJLsYwDQYJKoZIhvcNAQEL\nBQAwJTEjMCEGA1UEAwwac2hpYmJvbGV0aC51bml2LXJlbm5lczIuZnIwHhcNMTUx\nMjE2MTAwNjMwWhcNMzUxMjE2MTAwNjMwWjAlMSMwIQYDVQQDDBpzaGliYm9sZXRo\nLnVuaXYtcmVubmVzMi5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAIc9O9Uc1ocyQeZVnWbdvw+UblNoZd3h2l7+uSYeVlDh+w1hiwzyqJgkfSm4cnIh\nQuyDreblxUi4kWchq8CNl2h5iUuXvbx+9T5p5okrLVzVr5gTblr5Zbt0XKUwM2ij\n1CRtUJIKRDvulteDWpidBHHpKcQcCeqX+Sua1C/btdXogib8tK3jsnEMPLTpDgr1\nNaKPx0zDq42+lK6iNXKCpMrELsuY+8zhSpQ5MEfFGv3Mn/SJxazHZL4zeXfAsmWn\nkgU0tsb5laOKFPPDH/1w0oVXCBjMaiXNo9pN4vniKqNcKqdt3LScnXgx+6nRLUl7\nVoZnBD/wUox/H/WoaCZJG98CAwEAAaNrMGkwHQYDVR0OBBYEFJCVUOEA0sf43c8F\ntG9gw6OOIT13MEgGA1UdEQRBMD+CGnNoaWJib2xldGgudW5pdi1yZW5uZXMyLmZy\nhiF1cm46bWFjZTpjcnUuZnI6ZmVkZXJhdGlvbjp1aGIuZnIwDQYJKoZIhvcNAQEL\nBQADggEBAH9uybT+vMHuOwrR2CaLsaosmDUwnBW49igCi/MOIPHMfBEjxjwWTM6c\nuRZ54Ek7Z5kw6Z0xXS7o4FBLvh5cBXynmxIoYBEyEhCcEREuY0HkoXjHEtkQyEh8\nFbiu42dnzjVPtsLiURycXoGWdN9eYdPkZT/x7b60utBFJ7Y1lCA2+6D0eMXJI/bu\n8NO/uK3WHCdPWA/p0orBLN8WkStgmHv+4coHn++h0KqBASF6zJNKd4HJz8ihfdi+\nCQJuCqQLnHVwpjJ0xEHustvaFv2zyxP6P/af8iLUK+9UciOk7Cp4LjrdlBmMrf5Q\nQisFJWc/MGN0ISKidXg5cRqLoBnSgnw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIElDCCA3ygAwIBAgIQLdnpFQuu69xl9z7dAWPZhzANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDQwMjAwMDAwMFoXDTE2MDQwMTIzNTk1OVowSDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMSMwIQYDVQQDExpzaGliYm9sZXRo\nLnVuaXYtcmVubmVzMi5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAKFFb2IxKCffcTQOFyEl2g99rJUdjkOchNMt7alge6/T4/wRxcl7G/2Q+DahU6s9\ni4lUCYFV9iKi7Ia2eYUfn69r3KjN9q+h2fbb/BMyKt6lZicqQkrU1Kk3NSzQWiCZ\nquB8hy8W8sW7qZ2kfgCR3AZ+0bHchCMwYTDI+MKe0NURzxf/PiqSWe8PvYo0fs6L\nRAqwLW6X6DOfF8CbOVlHf8MpUaFLXWn5XZ8iEMA4+EnaJ1uxMqVeLNqU1jTQqKni\ndQ+JFCZvMJqRtuXeVvBawkTsCh1JWAUU/2FcnD7RN340aLC5V3F3ZN3hZCjJiXv7\nboO5MMJpIJkbrtHJJw+Mo7kCAwEAAaOCAYowggGGMB8GA1UdIwQYMBaAFAy9k2gM\n896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBSyIireJ6nPkGljLFuPuPxNpmdY7zAO\nBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcD\nAQYIKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEw\nOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJF\nTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8v\nY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYa\naHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwOAYDVR0RBDEwL4Iac2hpYmJvbGV0\naC51bml2LXJlbm5lczIuZnKCEXNoaWJib2xldGgudWhiLmZyMA0GCSqGSIb3DQEB\nBQUAA4IBAQCgvAbpw5E3Kf9+PokHstck4ysikCjOebRAFilM9lu8xRc4lyuMTlr9\neMdckFM3kO7wa6iiNPieFCnCsok8ZZ1wGI1qUkKYKE2DtxbEiTVfPtwQhnGQPDp4\nrnneYYlTeIQawTxr9kf+uwiaTKm1AGU1gMcT2tM9dfnQ+5Zt1DukJUWLMxq5upmz\nfhb8GprtsM8qv0z2+6Fat+iIu0GfmOaDZ/gDsW++cOD9P6K25GrdmVk20rC3oyy1\nOABUhu/g7vs9SnH4R/DZfgZ3U2WrVo8n/P9zcmNwfefBBC267M8I7c73wxZza+fb\n/K7h56t2aaVkVbRdvi8tEncI1Fzw5lq5"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 Rennes 2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uhb.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 Rennes 2"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.utsystem.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "netadmin@utsystem.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Network Admin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pcaskey@utsystem.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul Caskey"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@utsystem.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.utsystem.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.utsystem.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.utsystem.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVANsuFgw2Z5XryWlzufSAgriNo5pDMA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEGlkcC51dHN5c3RlbS5lZHUwHhcNMDkwNjIwMjEyNzIy\nWhcNMjkwNjIwMjEyNzIyWjAbMRkwFwYDVQQDExBpZHAudXRzeXN0ZW0uZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAiUJ9hGEJw0EIBIL2InLhCsZZ\n7maurudIUPt9NVQxPFHI7DwhTXwEjhYbTCnNYHS1JjEdnqzYLZitKfLYMkxPapVu\nfEDVBoLCnabRjKuOjLgIraYX5/rdvzgJPGAn7chL76ut5S3EuQNQ7LDD0KWR71qH\ny3TjZD3RXImFCRXvjLOlZR9+jVA1bKLzcafWUyHTv9wW8s/EyN+33ghOwRNzuH9W\n4ZUvUU2/22MYDlHwbCmwfvF8cYoHfk9WK+fgN+5BGGk+YJvjTAdek6tqeLPsFcR5\ncxvDwjyq00sZPb/xDRCTEgtx3StEYSEXqU1Z62/uHmlZ/oeFW21j59ls/CRp3wID\nAQABo2cwZTBEBgNVHREEPTA7ghBpZHAudXRzeXN0ZW0uZWR1hidodHRwczovL2lk\ncC51dHN5c3RlbS5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFErG8hS4tDz7\n5KwTs0pGvgb1DeR7MA0GCSqGSIb3DQEBBQUAA4IBAQAO4uo9SuOK3/uLJozn+W0L\nMymzQ6OLLZHuOX2lr/+2+I4YXzp8uqdwp8M7+GVlKDU+7JVEfFl+d7mtPrtThdYz\naSjip2XjOQdaE/+vY/oD/G750YAZsxOsWQQKPZIC4LClHjLz2H36Wc8nuTKxZzV+\nFLOa1rOT3iYnL2rY+Mzqet3mwz/yoPq8M1/0J/HtvEWyhRkt7SBPnoNZbMt0y33H\nDbzkGdzI4NTA/flqEuAXBrjkg64qktKR7YTkFRWvy1pl44MqiVmP5nvZgVZZmRYg\nBaqXA+v1pIIo2tL8IuUiQxH1KsnDCXE/F74PcEu2CDCVKEgaVEB1v6tGFZwYr2V7"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utsystem.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.utsystem.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.utsystem.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.utsystem.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.utsystem.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.utsystem.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.utsystem.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utsystem.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Logon service for The University of Texas System Administration"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idm.utsystem.edu/images/UTSystemSeal-Small.jpg",
                    "lang": "en",
                    "height": "75",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "75"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.utsystem.edu/privacy.htm"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Texas System"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVANsuFgw2Z5XryWlzufSAgriNo5pDMA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEGlkcC51dHN5c3RlbS5lZHUwHhcNMDkwNjIwMjEyNzIy\nWhcNMjkwNjIwMjEyNzIyWjAbMRkwFwYDVQQDExBpZHAudXRzeXN0ZW0uZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAiUJ9hGEJw0EIBIL2InLhCsZZ\n7maurudIUPt9NVQxPFHI7DwhTXwEjhYbTCnNYHS1JjEdnqzYLZitKfLYMkxPapVu\nfEDVBoLCnabRjKuOjLgIraYX5/rdvzgJPGAn7chL76ut5S3EuQNQ7LDD0KWR71qH\ny3TjZD3RXImFCRXvjLOlZR9+jVA1bKLzcafWUyHTv9wW8s/EyN+33ghOwRNzuH9W\n4ZUvUU2/22MYDlHwbCmwfvF8cYoHfk9WK+fgN+5BGGk+YJvjTAdek6tqeLPsFcR5\ncxvDwjyq00sZPb/xDRCTEgtx3StEYSEXqU1Z62/uHmlZ/oeFW21j59ls/CRp3wID\nAQABo2cwZTBEBgNVHREEPTA7ghBpZHAudXRzeXN0ZW0uZWR1hidodHRwczovL2lk\ncC51dHN5c3RlbS5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFErG8hS4tDz7\n5KwTs0pGvgb1DeR7MA0GCSqGSIb3DQEBBQUAA4IBAQAO4uo9SuOK3/uLJozn+W0L\nMymzQ6OLLZHuOX2lr/+2+I4YXzp8uqdwp8M7+GVlKDU+7JVEfFl+d7mtPrtThdYz\naSjip2XjOQdaE/+vY/oD/G750YAZsxOsWQQKPZIC4LClHjLz2H36Wc8nuTKxZzV+\nFLOa1rOT3iYnL2rY+Mzqet3mwz/yoPq8M1/0J/HtvEWyhRkt7SBPnoNZbMt0y33H\nDbzkGdzI4NTA/flqEuAXBrjkg64qktKR7YTkFRWvy1pl44MqiVmP5nvZgVZZmRYg\nBaqXA+v1pIIo2tL8IuUiQxH1KsnDCXE/F74PcEu2CDCVKEgaVEB1v6tGFZwYr2V7"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idm.utsystem.edu/error.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Texas System"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utsystem.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Texas System"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso.it.utsa.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mark.mccoy@utsa.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark McCoy"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "anthony.espinoza@utsa.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Anthony Espinoza"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "oitconnect@utsa.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support - OIT Connect"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.it.utsa.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.it.utsa.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.it.utsa.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAM22PHlkUkZ7H2NuIyyIWIZjQU43MA0GCSqGSIb3DQEB\nBQUAMBoxGDAWBgNVBAMTD3Nzby5pdC51dHNhLmVkdTAeFw0xMjA2MTgxOTQ5MjJa\nFw0zMjA2MTgxOTQ5MjJaMBoxGDAWBgNVBAMTD3Nzby5pdC51dHNhLmVkdTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAI5rIo2M+9aJDim1gChL/SwuXKCd\nS1L18jQ9m/ic2ym9/RBmPTpC3RKhSrXWWodP7zvB0QHTs6lCajS7jOI2ekEJzgw1\nnspJ35XPYMIC/o7779I3O6p8NyVPB4kX3PXkubLg+GmdYDwTlb3uyjWOWrXekqRm\nT/KrXFZTCrQClpKGA02tw/NvBVjhbhe0MoNZQ1m61RmwNAhsgSLsYttqKYZ2Wsd4\ncycSqepne4HScUaSUML0upV7JKqwHzmI2XCxVPmqH94wvpGTVciCJvhySHUC6wY4\n2KQ8JLCXAwjHWVLpUIBQqbKmRdKdsGPDj29lfZVJB1vC+DiQ1Vp4cB0lbWkCAwEA\nAaNlMGMwQgYDVR0RBDswOYIPc3NvLml0LnV0c2EuZWR1hiZodHRwczovL3Nzby5p\ndC51dHNhLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUljPRLnL+kddcavGE\naB+lDMkHJCowDQYJKoZIhvcNAQEFBQADggEBAIJSItYxCCiwhl+DZo3cS5SW3PZy\nrGK+gj2zz5sPLZmnxWZjuDhlLNgNUJUUDdj9cIXNnvNbDrI8Zc0qYU6pObZBuqCj\n0E/JwdqV5Eg+VvqF6JQNAq2P5SNchrYUMKHzP1L3jxlXktfaS4eMx2uHIVY8R68D\niQ5fliYThKrJqgk6ednPEtrrPilgj6Uf3xDhgEUpwz3BnaD+wspgy8Q5bMopemQP\ne8g7uW6MNZsIkFmTB9uoLKl8uR1ZltQ5yUbsAGX/quNNp90GfSQ6+yGoCgzKB7Y+\n9VJ4X+72+6wE0PfyOB3MGALob67EhNvVLTo+NdYVUd87EYCbcRgbTdAsbes="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utsa.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso.it.utsa.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.it.utsa.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sso.it.utsa.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.it.utsa.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.it.utsa.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.it.utsa.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utsa.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Use your myUTSA ID to login to services across the UT System federation, other Universities worldwide, and 3rd party applications affiliated with UTSA."
                  }
                ],
                "logo": [
                  {
                    "text": "https://sso.it.utsa.edu/images/utsa-logo.png",
                    "lang": "en",
                    "height": "54",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "338"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.utsa.edu/policies/privacy.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Texas at San Antonio"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAM22PHlkUkZ7H2NuIyyIWIZjQU43MA0GCSqGSIb3DQEB\nBQUAMBoxGDAWBgNVBAMTD3Nzby5pdC51dHNhLmVkdTAeFw0xMjA2MTgxOTQ5MjJa\nFw0zMjA2MTgxOTQ5MjJaMBoxGDAWBgNVBAMTD3Nzby5pdC51dHNhLmVkdTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAI5rIo2M+9aJDim1gChL/SwuXKCd\nS1L18jQ9m/ic2ym9/RBmPTpC3RKhSrXWWodP7zvB0QHTs6lCajS7jOI2ekEJzgw1\nnspJ35XPYMIC/o7779I3O6p8NyVPB4kX3PXkubLg+GmdYDwTlb3uyjWOWrXekqRm\nT/KrXFZTCrQClpKGA02tw/NvBVjhbhe0MoNZQ1m61RmwNAhsgSLsYttqKYZ2Wsd4\ncycSqepne4HScUaSUML0upV7JKqwHzmI2XCxVPmqH94wvpGTVciCJvhySHUC6wY4\n2KQ8JLCXAwjHWVLpUIBQqbKmRdKdsGPDj29lfZVJB1vC+DiQ1Vp4cB0lbWkCAwEA\nAaNlMGMwQgYDVR0RBDswOYIPc3NvLml0LnV0c2EuZWR1hiZodHRwczovL3Nzby5p\ndC51dHNhLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUljPRLnL+kddcavGE\naB+lDMkHJCowDQYJKoZIhvcNAQEFBQADggEBAIJSItYxCCiwhl+DZo3cS5SW3PZy\nrGK+gj2zz5sPLZmnxWZjuDhlLNgNUJUUDdj9cIXNnvNbDrI8Zc0qYU6pObZBuqCj\n0E/JwdqV5Eg+VvqF6JQNAq2P5SNchrYUMKHzP1L3jxlXktfaS4eMx2uHIVY8R68D\niQ5fliYThKrJqgk6ednPEtrrPilgj6Uf3xDhgEUpwz3BnaD+wspgy8Q5bMopemQP\ne8g7uW6MNZsIkFmTB9uoLKl8uR1ZltQ5yUbsAGX/quNNp90GfSQ6+yGoCgzKB7Y+\n9VJ4X+72+6wE0PfyOB3MGALob67EhNvVLTo+NdYVUd87EYCbcRgbTdAsbes="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://www.utsa.edu/oit/oitConnect.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Texas at San Antonio"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utsa.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Texas at San Antonio"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://mds.sunet.se/shibboleth",
    {
      "entity_id": "https://mds.sunet.se/shibboleth",
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish University Network (SUNET)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sunet.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SUNET"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mds.sunet.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mds.sunet.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mds.sunet.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mds.sunet.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mds.sunet.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://mds.sunet.se/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "mds.sunet.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+TCCAeGgAwIBAgIJAOvVefVlKf4tMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDG1kcy5zdW5ldC5zZTAeFw0xMTEwMDMwOTIwMDRaFw0yMTA5MzAwOTIwMDRa\nMBcxFTATBgNVBAMTDG1kcy5zdW5ldC5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAMM1mRFzygysIo9Qw7XabyoIe0nbATiS428GJ2oB3PSDLjmnf1CI\nkXwSBogHyAvdmQF04QCxeGki39cib/hTsxEbA14iGc/uyEbs4tFMgPvSPh3t8Uos\n1a8iHngnjpA0VuBH7VP3w0nCvj1eV5EobHKVk0NLgtXDgl87w6COPEre/5QN9IBf\n0/M7uO7zueXhpAzyO2+u+tZN2uacy5L2KTdiFxvFHAjaEjMnlVzbD7wehALIXNBg\nxtHUSITj2nwTjq7X/3sQbrusYL9DrW7RKLzzLSuHxRr4Dz+PESOjZUxBjTcwE4uJ\n2fmPuHfCtsxXHUnm7Ap3Df5I1exmSjc3inkCAwEAAaNIMEYwJQYDVR0RBB4wHIIM\nbWRzLnN1bmV0LnNlhgxtZHMuc3VuZXQuc2UwHQYDVR0OBBYEFB+CPP645D+t0FSk\n/40HaWtGmOP6MA0GCSqGSIb3DQEBBQUAA4IBAQAz/rf6fDHJU8Dp6hahHkVNRWRu\ncdVruda7guUIJ6MQWgl1N9Twfm2OvUSaM5fPtsqfoYTkv4ThVs8vGYyw+Y2oAnBa\nXKvUeP6S6et7cKQZCtpi9UgK8s1dHK7oqJaluW9tGes1Mcer/qKFdYunLlXYi8PA\nPRgEOb2hquFNE5V+0vXeiVqo/fAhlHxZ5jJbSQ2RnnN7ycVCQDZZlaEYPrGpaZVS\n9gYHwnECD5EPl8QsVymK2Co28pXAwpdo4btmWAeDhmy+8yOMjoS+T3k+/wiEmLLp\ndnjCadQzQamnqs4mfuypLT2wWWjkat9QKAM9gHkMwcC1Uv2RM2QeR8FDySJX"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=mds.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "mds.sunet.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+TCCAeGgAwIBAgIJAOvVefVlKf4tMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDG1kcy5zdW5ldC5zZTAeFw0xMTEwMDMwOTIwMDRaFw0yMTA5MzAwOTIwMDRa\nMBcxFTATBgNVBAMTDG1kcy5zdW5ldC5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAMM1mRFzygysIo9Qw7XabyoIe0nbATiS428GJ2oB3PSDLjmnf1CI\nkXwSBogHyAvdmQF04QCxeGki39cib/hTsxEbA14iGc/uyEbs4tFMgPvSPh3t8Uos\n1a8iHngnjpA0VuBH7VP3w0nCvj1eV5EobHKVk0NLgtXDgl87w6COPEre/5QN9IBf\n0/M7uO7zueXhpAzyO2+u+tZN2uacy5L2KTdiFxvFHAjaEjMnlVzbD7wehALIXNBg\nxtHUSITj2nwTjq7X/3sQbrusYL9DrW7RKLzzLSuHxRr4Dz+PESOjZUxBjTcwE4uJ\n2fmPuHfCtsxXHUnm7Ap3Df5I1exmSjc3inkCAwEAAaNIMEYwJQYDVR0RBB4wHIIM\nbWRzLnN1bmV0LnNlhgxtZHMuc3VuZXQuc2UwHQYDVR0OBBYEFB+CPP645D+t0FSk\n/40HaWtGmOP6MA0GCSqGSIb3DQEBBQUAA4IBAQAz/rf6fDHJU8Dp6hahHkVNRWRu\ncdVruda7guUIJ6MQWgl1N9Twfm2OvUSaM5fPtsqfoYTkv4ThVs8vGYyw+Y2oAnBa\nXKvUeP6S6et7cKQZCtpi9UgK8s1dHK7oqJaluW9tGes1Mcer/qKFdYunLlXYi8PA\nPRgEOb2hquFNE5V+0vXeiVqo/fAhlHxZ5jJbSQ2RnnN7ycVCQDZZlaEYPrGpaZVS\n9gYHwnECD5EPl8QsVymK2Co28pXAwpdo4btmWAeDhmy+8yOMjoS+T3k+/wiEmLLp\ndnjCadQzQamnqs4mfuypLT2wWWjkat9QKAM9gHkMwcC1Uv2RM2QeR8FDySJX"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=mds.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mds.sunet.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mds.sunet.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mds.sunet.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mds.sunet.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mds.sunet.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://mds.sunet.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mds.sunet.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://mds.sunet.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://mds.sunet.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://mds.sunet.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.candi.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Omer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:terri.omer@candi.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Terri"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sivakumar"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Thambiayah.Sivakumar@candi.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Thambiayah"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.candi.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-09-06T17:37:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDXjCCAkYCCQCg/FLFP/fzOTANBgkqhkiG9w0BAQUFADBxMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEPMA0GA1UECBMGTG9uZG9uMRIwEAYDVQQHEwlJc2xpbmd0b24xIzAhBgNVBAoT\n\t\t\t\t\t\tGkNpdHkgYW5kIElzbGluZ3RvbiBDb2xsZWdlMRgwFgYDVQQDEw9pZHAuY2FuZGku\n\t\t\t\t\t\tYWMudWswHhcNMTQwODExMTA1MDAxWhcNMzQwODA2MTA1MDAxWjBxMQswCQYDVQQG\n\t\t\t\t\t\tEwJHQjEPMA0GA1UECBMGTG9uZG9uMRIwEAYDVQQHEwlJc2xpbmd0b24xIzAhBgNV\n\t\t\t\t\t\tBAoTGkNpdHkgYW5kIElzbGluZ3RvbiBDb2xsZWdlMRgwFgYDVQQDEw9pZHAuY2Fu\n\t\t\t\t\t\tZGkuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDYGeuw+zrL\n\t\t\t\t\t\tZf6PQdtZWCTr8hno/45ceRQxSzgkTQTvn9RNXjx1uUeXbektJang4mm8WPIBgPcf\n\t\t\t\t\t\tqeP+ySSswFnCQW/sH2qKUYUjQ8k9Jvumjc5z1EJJLSPnwCn4xKmNVTcioMZXmdz8\n\t\t\t\t\t\t0dbbJQllbRNUJzesKpEY3BxlaxtvNyY+G7l7dcDdtpCcuC5qpeFmBobH8+l6x5kv\n\t\t\t\t\t\tdwTqyynGIkzGGF9CmV24ZEDuRGhxmllkOeous5PGIugTS/fJzNUt0YutPO9gVJl6\n\t\t\t\t\t\tlSuLndEYogecKvlegQJ+cj7jxbK/PTFrHP+hQcjKYbZqRT5h9pBHsxzEoSYSzpvX\n\t\t\t\t\t\tXIKIQtCwkpgRAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBADiE+smBM3xMAZ9uD5rX\n\t\t\t\t\t\t/cVK+a9iC4ZLq99x6sbuCt40/nUkQeImH0XMQS2D8OqY0dkVC3Sgdpxr2rk9uNzB\n\t\t\t\t\t\t5BuP1ESK1Qm0PZ9883V0N5JJI5nAxlMvwBq0qFbiUpgs9XASK9vcL84a9B43IhKP\n\t\t\t\t\t\tBmUkLXnsyH/2lb5FqnOOOIASLg+kPH5pZgaBzlevct+T1EJ0n9lUpJOsCG7xG40R\n\t\t\t\t\t\tOTQ0RbpF+nldggrOT5IdT2xfd4GVmYuqBjnEZTjCFonujU5hVJ2rqacxDjK/qy1r\n\t\t\t\t\t\tPVGtTIe+TUbsRU4VYYaUPQx9TY5zeg5y5P71c0QhVOFl4vGU2Usoaa3/5GpdoRxT\n\t\t\t\t\t\tlHI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "candi.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.candi.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.candi.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.candi.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.candi.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.candi.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.candi.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.candi.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.candi.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "candi.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDXjCCAkYCCQCg/FLFP/fzOTANBgkqhkiG9w0BAQUFADBxMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEPMA0GA1UECBMGTG9uZG9uMRIwEAYDVQQHEwlJc2xpbmd0b24xIzAhBgNVBAoT\n\t\t\t\t\t\tGkNpdHkgYW5kIElzbGluZ3RvbiBDb2xsZWdlMRgwFgYDVQQDEw9pZHAuY2FuZGku\n\t\t\t\t\t\tYWMudWswHhcNMTQwODExMTA1MDAxWhcNMzQwODA2MTA1MDAxWjBxMQswCQYDVQQG\n\t\t\t\t\t\tEwJHQjEPMA0GA1UECBMGTG9uZG9uMRIwEAYDVQQHEwlJc2xpbmd0b24xIzAhBgNV\n\t\t\t\t\t\tBAoTGkNpdHkgYW5kIElzbGluZ3RvbiBDb2xsZWdlMRgwFgYDVQQDEw9pZHAuY2Fu\n\t\t\t\t\t\tZGkuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDYGeuw+zrL\n\t\t\t\t\t\tZf6PQdtZWCTr8hno/45ceRQxSzgkTQTvn9RNXjx1uUeXbektJang4mm8WPIBgPcf\n\t\t\t\t\t\tqeP+ySSswFnCQW/sH2qKUYUjQ8k9Jvumjc5z1EJJLSPnwCn4xKmNVTcioMZXmdz8\n\t\t\t\t\t\t0dbbJQllbRNUJzesKpEY3BxlaxtvNyY+G7l7dcDdtpCcuC5qpeFmBobH8+l6x5kv\n\t\t\t\t\t\tdwTqyynGIkzGGF9CmV24ZEDuRGhxmllkOeous5PGIugTS/fJzNUt0YutPO9gVJl6\n\t\t\t\t\t\tlSuLndEYogecKvlegQJ+cj7jxbK/PTFrHP+hQcjKYbZqRT5h9pBHsxzEoSYSzpvX\n\t\t\t\t\t\tXIKIQtCwkpgRAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBADiE+smBM3xMAZ9uD5rX\n\t\t\t\t\t\t/cVK+a9iC4ZLq99x6sbuCt40/nUkQeImH0XMQS2D8OqY0dkVC3Sgdpxr2rk9uNzB\n\t\t\t\t\t\t5BuP1ESK1Qm0PZ9883V0N5JJI5nAxlMvwBq0qFbiUpgs9XASK9vcL84a9B43IhKP\n\t\t\t\t\t\tBmUkLXnsyH/2lb5FqnOOOIASLg+kPH5pZgaBzlevct+T1EJ0n9lUpJOsCG7xG40R\n\t\t\t\t\t\tOTQ0RbpF+nldggrOT5IdT2xfd4GVmYuqBjnEZTjCFonujU5hVJ2rqacxDjK/qy1r\n\t\t\t\t\t\tPVGtTIe+TUbsRU4VYYaUPQx9TY5zeg5y5P71c0QhVOFl4vGU2Usoaa3/5GpdoRxT\n\t\t\t\t\t\tlHI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "City and Islington College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.candi.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "City and Islington College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://newcastle-shib.hosted.exlibrisgroup.com/shib",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://newcastle-shib.hosted.exlibrisgroup.com/shib",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-04-16T08:24:52Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "This is a Shibboleth SP for Primo Resource Discovery at Newcastle University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://exlibrisgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ex Libris (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://newcastle-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://newcastle-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://newcastle-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://newcastle-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://newcastle-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://newcastle-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is an Ex Libris Primo Hosted SP on behalf of the Newcastle University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Newcastle University - Primo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAM3G3V6n3/DyMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB2FpbzAwMjMwHhcNMTUwNDAyMTkxODQzWhcNMjUwMzMwMTkxODQzWjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdhaW8wMDIzMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\t10lVTkxpFfewuW8RJ+s4DI0pfnc7ivJJAknfWDyeMK7v+2IcHYIDPP8HceIsvMrT\n\t\t\t\t\t\ts6isYSfxldstWHVLnryC28nHQqHYCJKD9fpvnI7kAx37RQkibZkQISSxoDSIU98R\n\t\t\t\t\t\tKVJAi1FTktkUlzikf5+h1TSRLzQ4NNC3IteA2l2oa5xZyF82RG7+l6DL9YdAHn3p\n\t\t\t\t\t\ttb7NuSyCFT42DByigjHpXMtftqwTbyDDXMM5pCOBjPxRb/MskClt34mtv54OZxL9\n\t\t\t\t\t\t5bWvEu+/8aGJGL3f+xbaomKeNBiMn7OmpUxs7CUbbXMomEfUKCTdZWgd0SYWgmpP\n\t\t\t\t\t\tsxJO//Oou3UBEcDNPYu3PQIDAQABozUwMzASBgNVHREECzAJggdhaW8wMDIzMB0G\n\t\t\t\t\t\tA1UdDgQWBBQpCfhRMq7ReeliuqEX197+QmeA1jANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tKY0ioUfQCjmVFWXFNyO8s8ozsQ/lQAGwlWPYZ/2r36aGyOKaEpm6Sdze63qpKHY5\n\t\t\t\t\t\tB70lfaqx7TDmdfMZZpf8RFYsj7wK8MdQwEsglYsaxyJcPykuntC1oOppT7W1BVKq\n\t\t\t\t\t\ti/5547UPkU0PXP+UzFlKYUlEEWVaMgh5FHaGorWMNpoYxX4oUeVLIBLImOd6Cx4L\n\t\t\t\t\t\tA8SOJxVv2SduRNQxDAvKVbZnU+mI+9VHMdrodzMrhxGPVyuITPXeih3fRg2fILjE\n\t\t\t\t\t\tt3U+rPWHlfQEglmjad1ZKJfL5+Xn7BgKtbOyKXmVp+p5Nz9rqz67e232JHg1x/bx\n\t\t\t\t\t\tyYEgCW+gFHaAf9GfC646YQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://newcastle-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://newcastle-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://newcastle-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://newcastle-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://newcastle-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://newcastle-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp2.kcc.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jack"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:t.jack@kcc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tony"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Williams"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:r.williams@kcc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp2.kcc.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIHADCCBeigAwIBAgIULRvMHnjL6D0AX5xModcnwU4/M9gwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwSTELMAkGA1UEBhMCQk0xGTAXBgNVBAoTEFF1b1ZhZGlzIExpbWl0ZWQxHzAd\n\t\t\t\t\t\tBgNVBAMTFlF1b1ZhZGlzIEVWIFNTTCBJQ0EgRzEwHhcNMTYwNDAxMTIxNzI0WhcN\n\t\t\t\t\t\tMTgwNDAxMTIyNzAwWjCB6zETMBEGCysGAQQBgjc8AgEDEwJHQjEaMBgGA1UEDwwR\n\t\t\t\t\t\tR292ZXJubWVudCBFbnRpdHkxLjAsBgNVBAUTJUZ1cnRoZXIgYW5kIEhpZ2hlciBF\n\t\t\t\t\t\tZHVjYXRpb24gQWN0IDE5OTIxCzAJBgNVBAYTAkdCMRcwFQYDVQQIDA5HcmVhdGVy\n\t\t\t\t\t\tIExvbmRvbjEPMA0GA1UEBwwGTE9ORE9OMScwJQYDVQQKDB5LZW5zaW5ndG9uIGFu\n\t\t\t\t\t\tZCBDaGVsc2VhIENvbGxlZ2UxEDAOBgNVBAsMB0lUIERlcHQxFjAUBgNVBAMMDXNw\n\t\t\t\t\t\tMi5rY2MuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCjVvNL\n\t\t\t\t\t\toDJvVsyC+PAOr0XVIXPURXi3nYwSEUSwEnOx1anJL3eFhAR3hPLX50cW9j6nvS/i\n\t\t\t\t\t\tUj/GgpbzJoNjK/t01UV/5e0kNizLcXS/LJlGRONjwjqzhRiccGCTEIj9tFhsD3Kg\n\t\t\t\t\t\t7D67uCniXKlg6hIoKBf1prinGwiAoxjsIEoMIQVyiL1bmvwR9neO+CrhKMwMGFJk\n\t\t\t\t\t\tTwyOFANebp5/m6kSND8FrW+BIRBnLTzH7oCnIwuMIcDxVZYmrCEoU+NWtJQgLkkT\n\t\t\t\t\t\tRI1gMeiWV35i6uuDBi3UhWD5+Dwtj2c8OHUfbJeQKExVhxVuySBvsus7phndiCtb\n\t\t\t\t\t\tMhcfYd+bQigC4KfvAgMBAAGjggM7MIIDNzB3BggrBgEFBQcBAQRrMGkwOAYIKwYB\n\t\t\t\t\t\tBQUHMAKGLGh0dHA6Ly90cnVzdC5xdW92YWRpc2dsb2JhbC5jb20vcXZldnNzbDEu\n\t\t\t\t\t\tY3J0MC0GCCsGAQUFBzABhiFodHRwOi8vZXYub2NzcC5xdW92YWRpc2dsb2JhbC5j\n\t\t\t\t\t\tb20wHQYDVR0OBBYEFMfXwT/odsQn/Qh+84DwXb+f1nyUMAwGA1UdEwEB/wQCMAAw\n\t\t\t\t\t\tHwYDVR0jBBgwFoAUVViGzrp8dk6ZE6kP02yfwvXTPOMwUQYDVR0gBEowSDBGBgwr\n\t\t\t\t\t\tBgEEAb5YAAJkAQIwNjA0BggrBgEFBQcCARYoaHR0cDovL3d3dy5xdW92YWRpc2ds\n\t\t\t\t\t\tb2JhbC5jb20vcmVwb3NpdG9yeTA7BgNVHR8ENDAyMDCgLqAshipodHRwOi8vY3Js\n\t\t\t\t\t\tLnF1b3ZhZGlzZ2xvYmFsLmNvbS9xdmV2c3NsMS5jcmwwDgYDVR0PAQH/BAQDAgWg\n\t\t\t\t\t\tMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAsBgNVHREEJTAjgg1zcDIu\n\t\t\t\t\t\ta2NjLmFjLnVrghJwYXNzd29yZC5rY2MuYWMudWswggF/BgorBgEEAdZ5AgQCBIIB\n\t\t\t\t\t\tbwSCAWsBaQB3AGj2mPgfZIK+OozuuSgdTPxxUV1nk9RE0QpnrLtPT/vEAAABU9HK\n\t\t\t\t\t\t2SgAAAQDAEgwRgIhAPKH35oW8AoBlpg6UUzCwOEWOoOEJFjggHopL5ff9UrfAiEA\n\t\t\t\t\t\tuyz1xiydQkVmtoVLIy3cWf48filugtOkuLtGQLecO9cAdgCkuQmQtBhYFIe7E6LM\n\t\t\t\t\t\tZ3AKPDWYBPkb37jjd80OyA3cEAAAAVPRytvSAAAEAwBHMEUCIBrIZrxXF1YWyFan\n\t\t\t\t\t\tLokPH3a6gkpOqKe0iwrXN51ePR0mAiEAhWPuzwSkHCckHz0pS8Tx+paMLYpOanxU\n\t\t\t\t\t\tDHjwm7KI9lwAdgBWFAaaL9fC7NP14b1Esj7HRna5vJkRXMDvlJhV1onQ3QAAAVPR\n\t\t\t\t\t\tyuBOAAAEAwBHMEUCIQD3RTS4nUhCj0KfCxXnqQwyLGNs3C9tebWykvR++mqXrAIg\n\t\t\t\t\t\tQeRmlL9ep8uotPJH5vu6aetiINHpEgytEXmzlXZtmWUwDQYJKoZIhvcNAQELBQAD\n\t\t\t\t\t\tggEBAFF474gBUWeH9MSHtzL2Mi96SGRlmm+YOamojWDXkUz1c6gyLnzrLKSrvZaB\n\t\t\t\t\t\th5gYKz/cMBJudOhdP5+tbd66z3+S7uoMiKd/ls/E4gIiQ+Cwu4nkiL5MF1S0vAKP\n\t\t\t\t\t\tU5XXA8ANLRPxWloa361OxO/Yl3GXPcxEjT2UdR6p90jxzCx0cKPs7pzYZCirK6l8\n\t\t\t\t\t\t/eo6GJKz78I/mC/QRE5/BVQNkIHHin5ifefXEz8iWmK0ssyeVX0XM2SS3cejuYTe\n\t\t\t\t\t\tvvTm3eqQfCh9LxneNPZZ911fnN2nKExJWkLcuv89TaFyktIPYL3Hsg+tdaaKFsbM\n\t\t\t\t\t\tfq7V+we0vhHSHgskNFgy9NRL0mk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kcc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sp2.kcc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp2.kcc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sp2.kcc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp2.kcc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp2.kcc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp2.kcc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sp2.kcc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp2.kcc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kcc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIHADCCBeigAwIBAgIULRvMHnjL6D0AX5xModcnwU4/M9gwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwSTELMAkGA1UEBhMCQk0xGTAXBgNVBAoTEFF1b1ZhZGlzIExpbWl0ZWQxHzAd\n\t\t\t\t\t\tBgNVBAMTFlF1b1ZhZGlzIEVWIFNTTCBJQ0EgRzEwHhcNMTYwNDAxMTIxNzI0WhcN\n\t\t\t\t\t\tMTgwNDAxMTIyNzAwWjCB6zETMBEGCysGAQQBgjc8AgEDEwJHQjEaMBgGA1UEDwwR\n\t\t\t\t\t\tR292ZXJubWVudCBFbnRpdHkxLjAsBgNVBAUTJUZ1cnRoZXIgYW5kIEhpZ2hlciBF\n\t\t\t\t\t\tZHVjYXRpb24gQWN0IDE5OTIxCzAJBgNVBAYTAkdCMRcwFQYDVQQIDA5HcmVhdGVy\n\t\t\t\t\t\tIExvbmRvbjEPMA0GA1UEBwwGTE9ORE9OMScwJQYDVQQKDB5LZW5zaW5ndG9uIGFu\n\t\t\t\t\t\tZCBDaGVsc2VhIENvbGxlZ2UxEDAOBgNVBAsMB0lUIERlcHQxFjAUBgNVBAMMDXNw\n\t\t\t\t\t\tMi5rY2MuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCjVvNL\n\t\t\t\t\t\toDJvVsyC+PAOr0XVIXPURXi3nYwSEUSwEnOx1anJL3eFhAR3hPLX50cW9j6nvS/i\n\t\t\t\t\t\tUj/GgpbzJoNjK/t01UV/5e0kNizLcXS/LJlGRONjwjqzhRiccGCTEIj9tFhsD3Kg\n\t\t\t\t\t\t7D67uCniXKlg6hIoKBf1prinGwiAoxjsIEoMIQVyiL1bmvwR9neO+CrhKMwMGFJk\n\t\t\t\t\t\tTwyOFANebp5/m6kSND8FrW+BIRBnLTzH7oCnIwuMIcDxVZYmrCEoU+NWtJQgLkkT\n\t\t\t\t\t\tRI1gMeiWV35i6uuDBi3UhWD5+Dwtj2c8OHUfbJeQKExVhxVuySBvsus7phndiCtb\n\t\t\t\t\t\tMhcfYd+bQigC4KfvAgMBAAGjggM7MIIDNzB3BggrBgEFBQcBAQRrMGkwOAYIKwYB\n\t\t\t\t\t\tBQUHMAKGLGh0dHA6Ly90cnVzdC5xdW92YWRpc2dsb2JhbC5jb20vcXZldnNzbDEu\n\t\t\t\t\t\tY3J0MC0GCCsGAQUFBzABhiFodHRwOi8vZXYub2NzcC5xdW92YWRpc2dsb2JhbC5j\n\t\t\t\t\t\tb20wHQYDVR0OBBYEFMfXwT/odsQn/Qh+84DwXb+f1nyUMAwGA1UdEwEB/wQCMAAw\n\t\t\t\t\t\tHwYDVR0jBBgwFoAUVViGzrp8dk6ZE6kP02yfwvXTPOMwUQYDVR0gBEowSDBGBgwr\n\t\t\t\t\t\tBgEEAb5YAAJkAQIwNjA0BggrBgEFBQcCARYoaHR0cDovL3d3dy5xdW92YWRpc2ds\n\t\t\t\t\t\tb2JhbC5jb20vcmVwb3NpdG9yeTA7BgNVHR8ENDAyMDCgLqAshipodHRwOi8vY3Js\n\t\t\t\t\t\tLnF1b3ZhZGlzZ2xvYmFsLmNvbS9xdmV2c3NsMS5jcmwwDgYDVR0PAQH/BAQDAgWg\n\t\t\t\t\t\tMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAsBgNVHREEJTAjgg1zcDIu\n\t\t\t\t\t\ta2NjLmFjLnVrghJwYXNzd29yZC5rY2MuYWMudWswggF/BgorBgEEAdZ5AgQCBIIB\n\t\t\t\t\t\tbwSCAWsBaQB3AGj2mPgfZIK+OozuuSgdTPxxUV1nk9RE0QpnrLtPT/vEAAABU9HK\n\t\t\t\t\t\t2SgAAAQDAEgwRgIhAPKH35oW8AoBlpg6UUzCwOEWOoOEJFjggHopL5ff9UrfAiEA\n\t\t\t\t\t\tuyz1xiydQkVmtoVLIy3cWf48filugtOkuLtGQLecO9cAdgCkuQmQtBhYFIe7E6LM\n\t\t\t\t\t\tZ3AKPDWYBPkb37jjd80OyA3cEAAAAVPRytvSAAAEAwBHMEUCIBrIZrxXF1YWyFan\n\t\t\t\t\t\tLokPH3a6gkpOqKe0iwrXN51ePR0mAiEAhWPuzwSkHCckHz0pS8Tx+paMLYpOanxU\n\t\t\t\t\t\tDHjwm7KI9lwAdgBWFAaaL9fC7NP14b1Esj7HRna5vJkRXMDvlJhV1onQ3QAAAVPR\n\t\t\t\t\t\tyuBOAAAEAwBHMEUCIQD3RTS4nUhCj0KfCxXnqQwyLGNs3C9tebWykvR++mqXrAIg\n\t\t\t\t\t\tQeRmlL9ep8uotPJH5vu6aetiINHpEgytEXmzlXZtmWUwDQYJKoZIhvcNAQELBQAD\n\t\t\t\t\t\tggEBAFF474gBUWeH9MSHtzL2Mi96SGRlmm+YOamojWDXkUz1c6gyLnzrLKSrvZaB\n\t\t\t\t\t\th5gYKz/cMBJudOhdP5+tbd66z3+S7uoMiKd/ls/E4gIiQ+Cwu4nkiL5MF1S0vAKP\n\t\t\t\t\t\tU5XXA8ANLRPxWloa361OxO/Yl3GXPcxEjT2UdR6p90jxzCx0cKPs7pzYZCirK6l8\n\t\t\t\t\t\t/eo6GJKz78I/mC/QRE5/BVQNkIHHin5ifefXEz8iWmK0ssyeVX0XM2SS3cejuYTe\n\t\t\t\t\t\tvvTm3eqQfCh9LxneNPZZ911fnN2nKExJWkLcuv89TaFyktIPYL3Hsg+tdaaKFsbM\n\t\t\t\t\t\tfq7V+we0vhHSHgskNFgy9NRL0mk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Kensington and Chelsea College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kcc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Kensington and Chelsea College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth-sp.prod.proquest.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@proquest.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wilt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pqshibbolethtech@proquest.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth-sp.prod.proquest.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-08-14T16:15:53Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ProQuest"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.proquest.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Proquest Information and Learning Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-sp.prod.proquest.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth-sp.prod.proquest.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth-sp.prod.proquest.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth-sp.prod.proquest.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-sp.prod.proquest.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth-sp.prod.proquest.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWTCCAkGgAwIBAgIJALUXgtUwAcW1MA0GCSqGSIb3DQEBBQUAMCoxKDAmBgNV\n\t\t\t\t\t\tBAMTH3NoaWJib2xldGgtc3AucHJvZC5wcm9xdWVzdC5jb20wHhcNMTQwODA0MTgx\n\t\t\t\t\t\tNjMxWhcNMTcwODA0MTgxNjMxWjAqMSgwJgYDVQQDEx9zaGliYm9sZXRoLXNwLnBy\n\t\t\t\t\t\tb2QucHJvcXVlc3QuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tuL3AvdPUloVAT2SxU5zfIMS1Q51dz15rM97hcspWkeJbOJRzuWGmdn1NTO8wNgfH\n\t\t\t\t\t\tWMcvxCH+MlUZdixFEEZ/oghDCKYQyngBe5DFb1o2MmXyXidtaFVzKOdkvwkrGNB4\n\t\t\t\t\t\tAEAg0ee6EN72qxlUSk3md90GWsv2RVOicpxwKcpk/f8ibfuaqwUZoqyzBM9/jADp\n\t\t\t\t\t\tuBG3iyiNr1/uGvCBhghvTpHRjZ6+L1t1tY8fi9xs15kd8k5nxQi1BSoGcqkmGJXB\n\t\t\t\t\t\tOwBhn5mb5FjHGbzw6kbL/O+zWBLlzIIJmS3YsbgBiAGWbzIdGl366VRkea0yuVQE\n\t\t\t\t\t\tKybgYDA/W5ezLNSeEdmMlwIDAQABo4GBMH8wXgYDVR0RBFcwVYIfc2hpYmJvbGV0\n\t\t\t\t\t\taC1zcC5wcm9kLnByb3F1ZXN0LmNvbYYyaHR0cHM6Ly9zaGliYm9sZXRoLXNwLnBy\n\t\t\t\t\t\tb2QucHJvcXVlc3QuY29tL3NoaWJib2xldGgwHQYDVR0OBBYEFGaLI8FVRsbPeB4H\n\t\t\t\t\t\tQ2517x6lRlkqMA0GCSqGSIb3DQEBBQUAA4IBAQCqcb5MKykmiQCSv19us1E1+gk5\n\t\t\t\t\t\tLWew6OUY/rWRdM9EpVbKlMgo0A2KTuJ5qrI/miS69wv+5nbEPax007kP7Xd4e54K\n\t\t\t\t\t\tyK0KWmTt92O3Rie2uf1dIF/VDOaIGvny0WTNfgiRmGrq3KERz26j7vQXbk9WOdp3\n\t\t\t\t\t\t+L3v1Wr8+1N/MLrQ7JDZAygO3Xb4gGcGI9VWlPKL8o09K4fR8EM97p3qeqJINMqw\n\t\t\t\t\t\tQsWrBhm9Tb51QxpARIjlF8paFZ0h6ugS/thDOh50wvqJ8B0r3ozD6E2Mu3A0zF/o\n\t\t\t\t\t\tJ4Wfgn170Gts8ghZeFrntOIilzGjb13VgnUpVXqsMEkmYqtzmKOGxiVuIyXc"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-sp.prod.proquest.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth-sp.prod.proquest.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth-sp.prod.proquest.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth-sp.prod.proquest.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth-sp.prod.proquest.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth-sp.prod.proquest.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth-sp.prod.proquest.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth-sp.prod.proquest.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth-sp.prod.proquest.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth-sp.prod.proquest.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.plymouth.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@plymouth.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Morgan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:olly.morgan@plymouth.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olly"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Horne"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:john.horne@plymouth.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.plymouth.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-10-21T13:42:16Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVAKyHcygxYWHKhPBwJxtAsM65mkppMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCQxIjAgBgNVBAMTGXNoaWJib2xldGgucGx5bW91dGguYWMudWswHhcNMTMx\n\t\t\t\t\t\tMDAzMTQyOTA0WhcNMzMxMDAzMTQyOTA0WjAkMSIwIAYDVQQDExlzaGliYm9sZXRo\n\t\t\t\t\t\tLnBseW1vdXRoLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\t7/XpT5wwAH8Exy6GRuy5UQnZxgs/AuMqzHHOyTQY0h9zNIIDaOWMClV6uRFtAonE\n\t\t\t\t\t\tBw7hdGCh4Rp+0USw8BlOXE5MR+wCNPOhK4a/HnE2YNDG3BadDdaM5XEqaT+NGEXI\n\t\t\t\t\t\ta9bT3j7Py3sm3p6+sMp6gPb36VkrZABZBkc1hORvvM6DkEtge3cihaSFd8o57UHQ\n\t\t\t\t\t\tLuEda0EW2fq1obYWUFEHN6mW12D4HHl6S2NjIHbh/Ytnqui4qO+0G/FL79+N7S2O\n\t\t\t\t\t\t/hrV1zpM4kUl0GlMEWHy8Hayjpx8mff6pdmXxyFDy5tCmdYyy8Jj5Cc3NwqUtZu/\n\t\t\t\t\t\tE0klUwSGUatD15/FAnTzmwIDAQABo3kwdzBWBgNVHREETzBNghlzaGliYm9sZXRo\n\t\t\t\t\t\tLnBseW1vdXRoLmFjLnVrhjBodHRwczovL3NoaWJib2xldGgucGx5bW91dGguYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFDlNnbrNQSY8ZiIbc+S8WrOlEJc2\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQB9av5yp4nund76PaSJ2vRDvTXPSc5ZndJ0nj1L\n\t\t\t\t\t\ttcU5a2BVJFFrawhywnhdMMEA3fuQu5FRmleEJks2pS8Dx4Kbhk/6sEyiB1PzshYs\n\t\t\t\t\t\tJb6jGIV50inltedhNWRLxPZLxNb/vVZnObebZzVaRjVuWu0CImGGFHxj/T6VzXtb\n\t\t\t\t\t\tFzqACoxbXFZHV4khqLuBuCunbKy4VovkiT9T/fK8dDDgohiAbDpmOL3I+wN95kA5\n\t\t\t\t\t\tNbllXNhng/oE/3YWDzcLCj9tPB8xJaw2FdiH9vPmx06F2e3jxOBxOxCeOkx1N6hU\n\t\t\t\t\t\tRC5QBAnV84/JkA5Y1mD35/HCdF0B0gA38D2X6sTkFISlTYCM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "plymouth.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.plymouth.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.plymouth.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.plymouth.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.plymouth.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.plymouth.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.plymouth.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.plymouth.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.plymouth.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.plymouth.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.plymouth.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.plymouth.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "plymouth.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVAKyHcygxYWHKhPBwJxtAsM65mkppMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCQxIjAgBgNVBAMTGXNoaWJib2xldGgucGx5bW91dGguYWMudWswHhcNMTMx\n\t\t\t\t\t\tMDAzMTQyOTA0WhcNMzMxMDAzMTQyOTA0WjAkMSIwIAYDVQQDExlzaGliYm9sZXRo\n\t\t\t\t\t\tLnBseW1vdXRoLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\t7/XpT5wwAH8Exy6GRuy5UQnZxgs/AuMqzHHOyTQY0h9zNIIDaOWMClV6uRFtAonE\n\t\t\t\t\t\tBw7hdGCh4Rp+0USw8BlOXE5MR+wCNPOhK4a/HnE2YNDG3BadDdaM5XEqaT+NGEXI\n\t\t\t\t\t\ta9bT3j7Py3sm3p6+sMp6gPb36VkrZABZBkc1hORvvM6DkEtge3cihaSFd8o57UHQ\n\t\t\t\t\t\tLuEda0EW2fq1obYWUFEHN6mW12D4HHl6S2NjIHbh/Ytnqui4qO+0G/FL79+N7S2O\n\t\t\t\t\t\t/hrV1zpM4kUl0GlMEWHy8Hayjpx8mff6pdmXxyFDy5tCmdYyy8Jj5Cc3NwqUtZu/\n\t\t\t\t\t\tE0klUwSGUatD15/FAnTzmwIDAQABo3kwdzBWBgNVHREETzBNghlzaGliYm9sZXRo\n\t\t\t\t\t\tLnBseW1vdXRoLmFjLnVrhjBodHRwczovL3NoaWJib2xldGgucGx5bW91dGguYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFDlNnbrNQSY8ZiIbc+S8WrOlEJc2\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQB9av5yp4nund76PaSJ2vRDvTXPSc5ZndJ0nj1L\n\t\t\t\t\t\ttcU5a2BVJFFrawhywnhdMMEA3fuQu5FRmleEJks2pS8Dx4Kbhk/6sEyiB1PzshYs\n\t\t\t\t\t\tJb6jGIV50inltedhNWRLxPZLxNb/vVZnObebZzVaRjVuWu0CImGGFHxj/T6VzXtb\n\t\t\t\t\t\tFzqACoxbXFZHV4khqLuBuCunbKy4VovkiT9T/fK8dDDgohiAbDpmOL3I+wN95kA5\n\t\t\t\t\t\tNbllXNhng/oE/3YWDzcLCj9tPB8xJaw2FdiH9vPmx06F2e3jxOBxOxCeOkx1N6hU\n\t\t\t\t\t\tRC5QBAnV84/JkA5Y1mD35/HCdF0B0gA38D2X6sTkFISlTYCM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Plymouth University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.plymouth.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Plymouth"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.unochapeco.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jhony Maseto"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@unochapeco.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.unochapeco.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEMjCCAxoCAQAwDQYJKoZIhvcNAQEFBQAwgd4xRzBFBgNVBAoUPlVub2NoYXBl\nY8OzIC0gVW5pdmVyc2lkYWRlIENvbXVuaXTDoXJpYSBkYSBSZWdpw6NvIGRlIENo\nYXBlY8OzMRAwDgYDVQQLEwdEVEkvTk9DMSQwIgYJKoZIhvcNAQkBFhVub2NAdW5v\nY2hhcGVjby5lZHUuYnIxETAPBgNVBAcUCENoYXBlY8OzMRcwFQYDVQQIEw5TYW50\nYSBDYXRhcmluYTELMAkGA1UEBhMCQlIxIjAgBgNVBAMTGWlkcGNhZmUudW5vY2hh\ncGVjby5lZHUuYnIwHhcNMTYwMjA1MTIzNDE5WhcNMTkwMjA0MTIzNDE5WjCB3jFH\nMEUGA1UEChQ+VW5vY2hhcGVjw7MgLSBVbml2ZXJzaWRhZGUgQ29tdW5pdMOhcmlh\nIGRhIFJlZ2nDo28gZGUgQ2hhcGVjw7MxEDAOBgNVBAsTB0RUSS9OT0MxJDAiBgkq\nhkiG9w0BCQEWFW5vY0B1bm9jaGFwZWNvLmVkdS5icjERMA8GA1UEBxQIQ2hhcGVj\nw7MxFzAVBgNVBAgTDlNhbnRhIENhdGFyaW5hMQswCQYDVQQGEwJCUjEiMCAGA1UE\nAxMZaWRwY2FmZS51bm9jaGFwZWNvLmVkdS5icjCCASIwDQYJKoZIhvcNAQEBBQAD\nggEPADCCAQoCggEBAKqlbhCdvxxb2CiUDARN8aK4V3jTqHYTEAn1KAoRl9R+IwQu\nlbU6c4CkX6EIxWo+55LpWUe97pIKXB9/Xtj5TO2DSAY7dtiBByYQ7WBUkFwWnWgy\ner0c5aLw9UdmFF19tXzfrlio/UcSS5hilyk6WHdpIjs7hOimtCBrCuNtXXo8G0fW\nUVZncmb6tk+RSz6c96oIKyDIHV0hq6E9s+QoSQd+2kIAr3TGrE5kbGvzCfV2g4pv\nqRXgd+75ylrO0Q7dOtJX33/PQ9fb+8tjSoULMOguvPWx9ipoXwwpVb030z+eX4b2\nqWbToSf0QVDMFLPoF8AFU717I6SO4GaOjeq4pQUCAwEAATANBgkqhkiG9w0BAQUF\nAAOCAQEASI8FNjD7lztkzJ1dHeDZRS1Q5W3fpQHgbF0dkjBqD7RBp4DDRZQhqrQl\nmIS0ALPC3MC8vURb+ZQHJ8P6LXAmXn+g7FF134o/kvWWzf1h5jSCymzwiTK44egO\n5UEYXqPq4OT7u/ao+5TqNUMi7BUVhHdii/SZUOCwU2MG/m6fsaisj6RiNCemSo7q\nCJJhhufOn3vDZieOVMftowNlbfIhA1qUwq89xYYfCpl7WFxBML+YLYbldANvNORG\njwVUyBHQxt9gXIb24HHCxcGMadrci9TALlPS+mtq85EtGs2p/5rhxvnbOY1Zn5ut\n0nVBT2KqSJwmgHZ2HSiOz5h2xoemBg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unochapeco.edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idpcafe.unochapeco.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idpcafe.unochapeco.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idpcafe.unochapeco.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idpcafe.unochapeco.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idpcafe.unochapeco.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idpcafe.unochapeco.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idpcafe.unochapeco.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idpcafe.unochapeco.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unochapeco.edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unochapeco.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unochapeco.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNOCHAPECO - Universidade Comunitaria da Regiao de Chgapeco"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNOCHAPECO - Universidade Comunitaria da Regiao de Chgapeco"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNOCHAPECO - Universidade Comunitaria da Regiao de Chgapeco"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNOCHAPECO - Universidade Comunitaria da Regiao de Chgapeco"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEMjCCAxoCAQAwDQYJKoZIhvcNAQEFBQAwgd4xRzBFBgNVBAoUPlVub2NoYXBl\nY8OzIC0gVW5pdmVyc2lkYWRlIENvbXVuaXTDoXJpYSBkYSBSZWdpw6NvIGRlIENo\nYXBlY8OzMRAwDgYDVQQLEwdEVEkvTk9DMSQwIgYJKoZIhvcNAQkBFhVub2NAdW5v\nY2hhcGVjby5lZHUuYnIxETAPBgNVBAcUCENoYXBlY8OzMRcwFQYDVQQIEw5TYW50\nYSBDYXRhcmluYTELMAkGA1UEBhMCQlIxIjAgBgNVBAMTGWlkcGNhZmUudW5vY2hh\ncGVjby5lZHUuYnIwHhcNMTYwMjA1MTIzNDE5WhcNMTkwMjA0MTIzNDE5WjCB3jFH\nMEUGA1UEChQ+VW5vY2hhcGVjw7MgLSBVbml2ZXJzaWRhZGUgQ29tdW5pdMOhcmlh\nIGRhIFJlZ2nDo28gZGUgQ2hhcGVjw7MxEDAOBgNVBAsTB0RUSS9OT0MxJDAiBgkq\nhkiG9w0BCQEWFW5vY0B1bm9jaGFwZWNvLmVkdS5icjERMA8GA1UEBxQIQ2hhcGVj\nw7MxFzAVBgNVBAgTDlNhbnRhIENhdGFyaW5hMQswCQYDVQQGEwJCUjEiMCAGA1UE\nAxMZaWRwY2FmZS51bm9jaGFwZWNvLmVkdS5icjCCASIwDQYJKoZIhvcNAQEBBQAD\nggEPADCCAQoCggEBAKqlbhCdvxxb2CiUDARN8aK4V3jTqHYTEAn1KAoRl9R+IwQu\nlbU6c4CkX6EIxWo+55LpWUe97pIKXB9/Xtj5TO2DSAY7dtiBByYQ7WBUkFwWnWgy\ner0c5aLw9UdmFF19tXzfrlio/UcSS5hilyk6WHdpIjs7hOimtCBrCuNtXXo8G0fW\nUVZncmb6tk+RSz6c96oIKyDIHV0hq6E9s+QoSQd+2kIAr3TGrE5kbGvzCfV2g4pv\nqRXgd+75ylrO0Q7dOtJX33/PQ9fb+8tjSoULMOguvPWx9ipoXwwpVb030z+eX4b2\nqWbToSf0QVDMFLPoF8AFU717I6SO4GaOjeq4pQUCAwEAATANBgkqhkiG9w0BAQUF\nAAOCAQEASI8FNjD7lztkzJ1dHeDZRS1Q5W3fpQHgbF0dkjBqD7RBp4DDRZQhqrQl\nmIS0ALPC3MC8vURb+ZQHJ8P6LXAmXn+g7FF134o/kvWWzf1h5jSCymzwiTK44egO\n5UEYXqPq4OT7u/ao+5TqNUMi7BUVhHdii/SZUOCwU2MG/m6fsaisj6RiNCemSo7q\nCJJhhufOn3vDZieOVMftowNlbfIhA1qUwq89xYYfCpl7WFxBML+YLYbldANvNORG\njwVUyBHQxt9gXIb24HHCxcGMadrci9TALlPS+mtq85EtGs2p/5rhxvnbOY1Zn5ut\n0nVBT2KqSJwmgHZ2HSiOz5h2xoemBg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNOCHAPECO - Universidade Comunitaria da Regiao de Chgapeco"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNOCHAPECO - Universidade Comunitaria da Regiao de Chgapeco"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unochapeco.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unochapeco.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNOCHAPECO - Universidade Comunitaria da Regiao de Chgapeco"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNOCHAPECO - Universidade Comunitaria da Regiao de Chgapeco"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ubalt.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "gweitzel@ubalt.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "George Weitzel"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "gweitzel@ubalt.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "George Weitzel"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "gweitzel@ubalt.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "George Weitzel"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ubalt.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ubalt.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ubalt.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ubalt.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ubalt.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ubalt.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ubalt.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ubalt.edu"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Baltimore"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVALNBED/cJIrxyBgo57wvukY6HoaMMA0GCSqGSIb3DQEB\nBQUAMBgxFjAUBgNVBAMTDWlkcC51YmFsdC5lZHUwHhcNMTAwNDE0MTQxMDE0WhcN\nMzAwNDE0MTQxMDE0WjAYMRYwFAYDVQQDEw1pZHAudWJhbHQuZWR1MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkQQUyShLGEpGTZP5yXSVrvzSqb12zVFl\ni8lgmI3B11Djae9CB2MYvCxVPR45UbECwABRglgg0J3DbqF7sHJdx8e6wlQKtL3x\nj4lCNaQ3RuQTqiDFQjPN/pB9ZmCGNe0Xg/IGsdQMSyaAByvg704svGFGNV4w2+jX\nAZjn5uT0Ie2nzH7Ld5viKuuAg69qL3tCeViLGdLi968lyP88cDsoY3XVmhaWwvKa\nQEo4Ux4cps8T8AMSrM4WjL6utDB54QW2GO33c6UZdWRV1emGzko98wWM44Vdi2BW\ny+RioI1CeHK1N14WaoAbU3NNbNn3QmZIW/Wh25H94Q5svbpMmUm5oQIDAQABo2Ew\nXzA+BgNVHREENzA1gg1pZHAudWJhbHQuZWR1hiRodHRwczovL2lkcC51YmFsdC5l\nZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFNvNBX8NadYpqWmsgeMXG0GQNHo7\nMA0GCSqGSIb3DQEBBQUAA4IBAQAIbKuLg8lZhoSRwTj28WIdnGMK0rEJrt1LXAiO\nYNGxXgeMjZx0p6ztoOFFdjo9TVgEuxXx2ycmKz5eJ7SBAXRkt3NwX1YizRcyLRsC\nTnYa0K8gnnk14AGIqfVd0VaCfXLa7RE7+uVngWgHqkZrwkwGlesvAysdDG9RrXM4\n5aw9kh43lKx0nuGSCygLpWJJYtm9GW9XmRaNcnAOPiIHsICAeHFYbW+ZpBsd70BZ\nUW70RjR8T0DfLVxDaVoxG38lSnjyhJvNsFoapErardKKtSfjgAPEB9VJ01s73u3w\n8jympr7hYBlzGEVpM1EYCsSsULuEXTgFVg4RZnbigygJHpKA"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Baltimore"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ubalt.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Baltimore"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.nescolvoting.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.nescolvoting.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-06T11:49:44Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NESCOL Students' Association"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nescolvoting.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.nescolvoting.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.nescolvoting.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.nescolvoting.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.nescolvoting.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.nescolvoting.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.nescolvoting.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.nescolvoting.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.nescolvoting.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.nescolvoting.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.nescolvoting.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.nescolvoting.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.nescolvoting.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.vr-rut.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.vr-rut.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.vr-rut.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.vr-rut.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.vr-rut.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.vr-rut.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.vr-rut.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.vr-rut.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.vr-rut.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "RUT \u00e4r ett verktyg f\u00f6r registerbaserad forskning. Verktyget ger forskare m\u00f6jlighet att s\u00f6ka metadata i olika register"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.vr-rut.se/images/VR_LOGO_1_RGB.jpg",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RUT (Register Utilizer Tool)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "win-rf24mm32l83"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAOTa2uNYCVU9MA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD3dpbi1yZjI0bW0zMmw4MzAeFw0xNjAzMDExMzA3NTNaFw0yNjAyMjcxMzA3\nNTNaMBoxGDAWBgNVBAMTD3dpbi1yZjI0bW0zMmw4MzCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAK/8ukYtqTnQ4+tSe+5hrKPNitBG2REst7Nfe+qyYxu2\nNFjSRwevuzHzKKs0patxPGHhmlEZpx6+JjgKBTRXczhoHdyZWl7lHibW5qMsMeCl\nS5i9mDSHDvqAkeRYZZhXayp/vJSSDWiEe3i7vb4yLy85awFOe/BLZqtk7ssDggmF\ng85szFANxkIT8O4Hjz78aQ+1lUxPSzhyaMscrHpBnfU7evKCZAahpleq/NnsDeLW\nbRljNbriefxXWeyPMIExakcmBM/vfywPhDNESjINOuu5TcEyHRcR/sRUC7UUEVWh\nVHFXJKmgD9pC/QeEM8htnUiUyy75t0lS0PQkzx7okZcCAwEAAaM9MDswGgYDVR0R\nBBMwEYIPd2luLXJmMjRtbTMybDgzMB0GA1UdDgQWBBSfSCNYBNXMCLuZCaP+uEW2\nVhM9sTANBgkqhkiG9w0BAQUFAAOCAQEADzCCiLOo6A78foZAWiSsn6Xd3UZ3Zsdv\nMWS8rdQ5xdFtoxsbbpxEfjTb2O1XV2gBaKiBeljlbiF8uubM7B7Wu1xfwwz/3cTm\nz9ZCQzLgdSG9pVMzTM689xWYsaQBqmPKbwyDwxMtOnnAIsNmmgOK9yrJUZ1hH2lD\n0sOAFSK1e4pKRSI6HO+/wGnQ8/Jm5Mn/7WZo37EU6j8Hrn62AzNtrbPHykwW3doo\np71ZIXtZ6GZvPZl5p5PX8FjkgFX3GD0nb+i0UHm2ykaiEc3yYTmgAtK6M9x8+LL+\nF0wHmzyt5ULOiQxb2TLarz8pai4n1jfVuJ90NYOb1ntj44DysUs7Zw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=win-rf24mm32l83"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.vr-rut.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.vr-rut.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.vr-rut.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.vr-rut.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.vr-rut.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.vr-rut.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.vr-rut.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.vr-rut.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.vr-rut.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.digicert.com/sso",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@digicert.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "DigiCert"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "TCS Policy Management Authority"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tcs-pma@terena.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "G\u00c9ANT"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@digicert.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "DigiCert"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.digicert.com/sso",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2015-04-09T08:51:55Z",
            "registration_authority": "http://eduid.at",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "DigiCert"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.digicert.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "DigiCert Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.digicert.com/sso/saml/SingleLogout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.digicert.com/sso/saml/SingleLogout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Members from TCS-subscribing institutions can request personal, e-science personal, and e-science robot certificates here."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.digicert.com/images/d3/digicert-logo.png",
                    "height": "58",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "224"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "G\u00c9ANT Trusted Certificate Service (TCS)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFHzCCBAegAwIBAgIQDSPffA+3kdjXI6kqvoyBtDANBgkqhkiG9w0BAQsFADBl\nMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMRGlnaUNlcnQgSW5jMRkwFwYDVQQLExB3\nd3cuZGlnaWNlcnQuY29tMSQwIgYDVQQDExtEaWdpQ2VydCBTSEEyIEFzc3VyZWQg\nSUQgQ0EwHhcNMTUwNDA3MDAwMDAwWhcNMTgwNzA1MTIwMDAwWjBtMQswCQYDVQQG\nEwJVUzENMAsGA1UECBMEVXRhaDENMAsGA1UEBxMETGVoaTEXMBUGA1UEChMORGln\naUNlcnQsIEluYy4xJzAlBgNVBAMTHkRpZ2lDZXJ0IFNBTUwgU2VydmljZSBQcm92\naWRlcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN/+/QfL6NXaO4Ob\ngIzarBuLusqybTeFB5aRQRaTjYUGwTxbVSZWcKZFrfoki0InkQ4ez4+NGTglmObF\nAUXafigKICJx7D1LzKfHSETIZmxODC7ztS1LAEa2YF+bSny+UqjC8iBpVSnOPuzY\nemIntQGlgTC60QbGZ4jWGpAh/E4vuV+1ZEJlBMdo8OyVX7OKLqx0IZYnc5Ms8Q+P\n8fQVAMmmkxqnDWQJG7+Dg95Ir8yP9IqBPFgW/oYmiiu9hJgg5Fw79FRVSbR4AM7m\nH43grZdYwh2QhiBHe1RNMqSq8iqwRfQdgHCaXvTrAYRetXPAYl2aDZ5v+hiwYFeU\nDa+yfCECAwEAAaOCAcEwggG9MB8GA1UdIwQYMBaAFOcCI4AAT9jXvJQL2T90OUky\nPIp5MB0GA1UdDgQWBBTSQiXTihRDi2udzXW9NIwsexMenTAMBgNVHRMBAf8EAjAA\nMA4GA1UdDwEB/wQEAwIEsDATBgNVHSUEDDAKBggrBgEFBQcDAjBCBgNVHSAEOzA5\nMDcGCWCGSAGG/WwGATAqMCgGCCsGAQUFBwIBFhxodHRwczovL3d3dy5kaWdpY2Vy\ndC5jb20vQ1BTMIGIBgNVHR8EgYAwfjA9oDugOYY3aHR0cDovL2NybDMuZGlnaWNl\ncnQuY29tL0RpZ2lDZXJ0U0hBMkFzc3VyZWRJRENBLWcxLmNybDA9oDugOYY3aHR0\ncDovL2NybDQuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0U0hBMkFzc3VyZWRJRENBLWcx\nLmNybDB5BggrBgEFBQcBAQRtMGswJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmRp\nZ2ljZXJ0LmNvbTBDBggrBgEFBQcwAoY3aHR0cDovL2NhY2VydHMuZGlnaWNlcnQu\nY29tL0RpZ2lDZXJ0U0hBMkFzc3VyZWRJRENBLmNydDANBgkqhkiG9w0BAQsFAAOC\nAQEAza2jiq0WUEas3Ou70GkX9A2U9IkgFhYj7LsR2hxfwlnl/vDvHHxzZWuOJLIR\nYN4VEY6B+/vl8P2p2OdjIMATba5rqMmho+UkF7p7I0Auwc18oQ9fzZRq8ul+xtIX\nOiC2mZ2dG5VUXk1eR7qAKafGoNkOWzY6K0yb7NlUtGQDbZ5kBUqxH7z1uIPtjEBx\njv9ka0zHozKT+/vtNbAta7iuQtM05y2fSjXLeGpcTxnootfcFJtbpxiODd77a1Ax\n0b2CWHv1aZaDQHlMjsf1ZaVPjHkgLlTFAtgzceimrdGM7PM/EHUFHP94H1EggcYt\nn4mgYE+xr/VoR6tzNtvfyLXqxA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFHzCCBAegAwIBAgIQDSPffA+3kdjXI6kqvoyBtDANBgkqhkiG9w0BAQsFADBl\nMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMRGlnaUNlcnQgSW5jMRkwFwYDVQQLExB3\nd3cuZGlnaWNlcnQuY29tMSQwIgYDVQQDExtEaWdpQ2VydCBTSEEyIEFzc3VyZWQg\nSUQgQ0EwHhcNMTUwNDA3MDAwMDAwWhcNMTgwNzA1MTIwMDAwWjBtMQswCQYDVQQG\nEwJVUzENMAsGA1UECBMEVXRhaDENMAsGA1UEBxMETGVoaTEXMBUGA1UEChMORGln\naUNlcnQsIEluYy4xJzAlBgNVBAMTHkRpZ2lDZXJ0IFNBTUwgU2VydmljZSBQcm92\naWRlcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN/+/QfL6NXaO4Ob\ngIzarBuLusqybTeFB5aRQRaTjYUGwTxbVSZWcKZFrfoki0InkQ4ez4+NGTglmObF\nAUXafigKICJx7D1LzKfHSETIZmxODC7ztS1LAEa2YF+bSny+UqjC8iBpVSnOPuzY\nemIntQGlgTC60QbGZ4jWGpAh/E4vuV+1ZEJlBMdo8OyVX7OKLqx0IZYnc5Ms8Q+P\n8fQVAMmmkxqnDWQJG7+Dg95Ir8yP9IqBPFgW/oYmiiu9hJgg5Fw79FRVSbR4AM7m\nH43grZdYwh2QhiBHe1RNMqSq8iqwRfQdgHCaXvTrAYRetXPAYl2aDZ5v+hiwYFeU\nDa+yfCECAwEAAaOCAcEwggG9MB8GA1UdIwQYMBaAFOcCI4AAT9jXvJQL2T90OUky\nPIp5MB0GA1UdDgQWBBTSQiXTihRDi2udzXW9NIwsexMenTAMBgNVHRMBAf8EAjAA\nMA4GA1UdDwEB/wQEAwIEsDATBgNVHSUEDDAKBggrBgEFBQcDAjBCBgNVHSAEOzA5\nMDcGCWCGSAGG/WwGATAqMCgGCCsGAQUFBwIBFhxodHRwczovL3d3dy5kaWdpY2Vy\ndC5jb20vQ1BTMIGIBgNVHR8EgYAwfjA9oDugOYY3aHR0cDovL2NybDMuZGlnaWNl\ncnQuY29tL0RpZ2lDZXJ0U0hBMkFzc3VyZWRJRENBLWcxLmNybDA9oDugOYY3aHR0\ncDovL2NybDQuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0U0hBMkFzc3VyZWRJRENBLWcx\nLmNybDB5BggrBgEFBQcBAQRtMGswJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmRp\nZ2ljZXJ0LmNvbTBDBggrBgEFBQcwAoY3aHR0cDovL2NhY2VydHMuZGlnaWNlcnQu\nY29tL0RpZ2lDZXJ0U0hBMkFzc3VyZWRJRENBLmNydDANBgkqhkiG9w0BAQsFAAOC\nAQEAza2jiq0WUEas3Ou70GkX9A2U9IkgFhYj7LsR2hxfwlnl/vDvHHxzZWuOJLIR\nYN4VEY6B+/vl8P2p2OdjIMATba5rqMmho+UkF7p7I0Auwc18oQ9fzZRq8ul+xtIX\nOiC2mZ2dG5VUXk1eR7qAKafGoNkOWzY6K0yb7NlUtGQDbZ5kBUqxH7z1uIPtjEBx\njv9ka0zHozKT+/vtNbAta7iuQtM05y2fSjXLeGpcTxnootfcFJtbpxiODd77a1Ax\n0b2CWHv1aZaDQHlMjsf1ZaVPjHkgLlTFAtgzceimrdGM7PM/EHUFHP94H1EggcYt\nn4mgYE+xr/VoR6tzNtvfyLXqxA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://www.digicert.com/sso/saml/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.digicert.com/sso/saml/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "DigiCert's TCS Portal"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "attribute_value": [
                    {
                      "extension_attributes": {
                        "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                      },
                      "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                      "text": "urn:mace:terena.org:tcs:personal-user"
                    },
                    {
                      "extension_attributes": {
                        "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                      },
                      "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                      "text": "urn:mace:terena.org:tcs:escience-user"
                    }
                  ],
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute",
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "is_required": "true"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sso.siropglobal.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Brodbeck"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it@siropglobal.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andreas"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Brodbeck"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it@siropglobal.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andreas"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.siropglobal.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2015-01-27T10:55:43Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SiROP Association"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.siropglobal.org//"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "siropglobal.org"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.siropglobal.org/app/about?l=en"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Thousands of students and researchers use SiROP to post and search open positions such as internships, Master, Bachelor or PhD projects and PostDoc positions. We connect students, researchers and institutions."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.siropglobal.org/app/terms?l=en"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SiROP platform (www.siropglobal.org)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIJALzQmVldx2A3MA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE3Nzby5zaXJvcGdsb2JhbC5vcmcwHhcNMTQxMDI4MDgxNzI5WhcNMTcxMDI3\nMDgxNzI5WjAeMRwwGgYDVQQDExNzc28uc2lyb3BnbG9iYWwub3JnMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAx64WLavrAOUS3hrtNy48EdBVdzwbYcDg\n0HmBm6inH9I4yASQp+QSPXJ+5l3FymRLigGKt2HcLzNMsO7h7ptaMd+A3PI1UKT7\nyTu7kzOjsE+9iHgTQ4nbGhQt3yl5xjjBdYdqqQrEj5FWEbvYhA/Wt+iVQMMG+zoW\ndXDwyz9TTqL/UiE02mSt0Ro9ApmLk/kj/1MxUO5miBBuGyRrFUGdXNPgt1OSjPlI\n5VDjAXdg9CYDJffHUMhq6l/QextaQy1yFNDras8A8bGxTUe84VcAAjLIcnCtv827\nmWbwunc4mk4SDTUvVD0lEiB2xBujYPDbztE/DEzChiythqzU1mDDhwIDAQABo2kw\nZzBGBgNVHREEPzA9ghNzc28uc2lyb3BnbG9iYWwub3JnhiZodHRwczovL3Nzby5z\naXJvcGdsb2JhbC5vcmcvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUUHYB3v8YkZziQywd\n6zbzQeks38UwDQYJKoZIhvcNAQEFBQADggEBAGKoO/l+amYeu2+/uI57e52A9PX1\nJhjburFtSrayQizXS4zFSIbu9H8SUGzo7UQ2wLEM9uI/rAlmn4Z5VnvkstkODfFj\nI29JZYw3d817h4Jqi20lasU++TfHMYGmnN7Wv9OjIQbOHIIZBGqyL7z7cTLYybT3\n7EI41ClPlg1xYunxMCEcVueS5VCVDpi/iRRgbtf8GefqPWe6nZxcbpmADIPMO8q4\nL7afxqiM5NYZ1c/id4cxXS2tptR943z6Kzfyw6pEClx/1QOWd+muOiE87QTv8ACS\nKnGGy1QRuuesWG8bve/GvCzKfjPNQDlJZv69Hchj3OmVnUVfVBhFKXjlCEQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.siropglobal.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sso.siropglobal.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sso.siropglobal.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sso.siropglobal.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sso.siropglobal.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sso.siropglobal.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SiROP platform (www.siropglobal.org)"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Thousands of students and researchers use SiROP to post and search open positions such as internships, Master, Bachelor or PhD projects and PostDoc positions. We connect students, researchers and institutions."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.dawsonera.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth.support@dawsonbooks.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Weaver"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tim.weaver@dawsonbooks.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Stratford"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helen.stratford@dawsonbooks.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.dawsonera.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-10-23T17:30:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Dawsonera SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dawsonera.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Dawson Books Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.dawsonera.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.dawsonera.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.dawsonera.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.dawsonera.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.dawsonera.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.dawsonera.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dawsonera.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.dawsonera.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dawsonera.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDqjCCApKgAwIBAgIJAPw17BZZ42GoMA0GCSqGSIb3DQEBBQUAMGExCzAJBgNV\n\t\t\t\t\t\tBAYTAlVLMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIwEAYD\n\t\t\t\t\t\tVQQKEwlzZW1hbnRpY28xGjAYBgNVBAMTEXd3dy5kYXdzb25lcmEuY29tMB4XDTE0\n\t\t\t\t\t\tMTEyMDE0MTAwMFoXDTM0MTExNTE0MTAwMFowYTELMAkGA1UEBhMCVUsxDzANBgNV\n\t\t\t\t\t\tBAgTBlN1c3NleDERMA8GA1UEBxMIQnJpZ2h0b24xEjAQBgNVBAoTCXNlbWFudGlj\n\t\t\t\t\t\tbzEaMBgGA1UEAxMRd3d3LmRhd3NvbmVyYS5jb20wggEiMA0GCSqGSIb3DQEBAQUA\n\t\t\t\t\t\tA4IBDwAwggEKAoIBAQDHgNVCzYLg7SD9tKfQV00YAlrk5468kdoro4kdCSr3lnro\n\t\t\t\t\t\tBRtqzU6ZJtAUFG/eUALLvAGm/q0gK1DYLlfjhYccUsXwzRajQUdjmxuLenkg1bIO\n\t\t\t\t\t\tb8JIhyo0UTQniZH+4JSEvcH81Iusq1TRPAcpVxZn2lFv2qaArO+jRpAbbnnZApx1\n\t\t\t\t\t\tDMspj+twl8Kd+MUfibLNGFRJgqmJAwifPAD+cNEr0fOlVI0M4tye5xLPnx0YsGe1\n\t\t\t\t\t\t5u4D7l7NmPpYuPu/isWTlMIcbMJFEpExLGzi9GTfRbLdmytVp12geoWR2nxv9uaU\n\t\t\t\t\t\tygslHl+e8P45tpl0w6az/NlCw6v60Y7EgdROuj7rAgMBAAGjZTBjMEIGA1UdEQQ7\n\t\t\t\t\t\tMDmCEXd3dy5kYXdzb25lcmEuY29thiRodHRwczovL3d3dy5kYXdzb25lcmEuY29t\n\t\t\t\t\t\tL3NoaWJib2xldGgwHQYDVR0OBBYEFMtE823I+0YS2aPs/H9Ga0Jwi+NCMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQAJg9+Sr/kF5Wjo7f1FZEg46JbjJeoI4exlvyCe0NK7z1qX\n\t\t\t\t\t\tm5pX1qYwWPQ7LaXX7Zp3/OiK7GZ9PwjxPPos9SCCxIHiXUbQiVE0lZak2gmVQBtR\n\t\t\t\t\t\t5g5+mlEMzK5JdS/LpBg73bt9GmDOD8DW/gh5jK8leFeMYpB6S7kQtHBQjOCh25pK\n\t\t\t\t\t\t71r8Nn896gV+5qH8gGZl3n0sh3wFmCEm6MWMeO9O7sQ9mOpCyURGga0z9pNhuDT+\n\t\t\t\t\t\tYPUWnO6LjnDWB5N9pwW+4I/Aqr4RGYA07Qbzwwpy4EcLBjb8rksf65XfEKsJifBh\n\t\t\t\t\t\tK4PtNVSuIlt/QvKTAsFlP4X3c46Ol501WcVbYoD9"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.dawsonera.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.dawsonera.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.dawsonera.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.dawsonera.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.dawsonera.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.dawsonera.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.dawsonera.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.dawsonera.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.dawsonera.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.dawsonera.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dawsonera.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dawsonera.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dawsonera.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dawsonera.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dawsonera.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dawsonera.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.johnruskin.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.johnruskin.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/johnruskin.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/johnruskin.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "johnruskin.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "John Ruskin College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.johnruskin.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://brad.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Nieminen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:s.nieminen@bradford.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Satu"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:g.bell@bradford.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Geoff"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://brad.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.brad.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.brad.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brad.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDlDCCAnygAwIBAgIJANXFuAkInLUOMA0GCSqGSIb3DQEBBQUAMDoxHzAdBgNV\n\t\t\t\t\t\tBAoTFlVuaXZlcnNpdHkgb2YgQnJhZGZvcmQxFzAVBgNVBAMTDmlkcC5icmFkLmFj\n\t\t\t\t\t\tLnVrMB4XDTExMTIxNTA3MzU0NloXDTIxMTIxMjA3MzU0NlowOjEfMB0GA1UEChMW\n\t\t\t\t\t\tVW5pdmVyc2l0eSBvZiBCcmFkZm9yZDEXMBUGA1UEAxMOaWRwLmJyYWQuYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC0g3A4ViQaWo3ooKJCJzMT\n\t\t\t\t\t\tsuHZpnYar65+6QiDmZvx1QDGMT+YlYS1jmkuz4YGwJOdj4h9Up9dSCx4M3XweUuD\n\t\t\t\t\t\tbLclot8c05tOBBzm+8UHkaYnIYx/8GKE8+NKtscerr1UvHlOxTBPPFxogb4X0fQm\n\t\t\t\t\t\tiW+PEz9wDPpegj4WlY0ktaxgzjhjvZQwFVqGIBxBvdT6phfkWeK5xj2er956tBgl\n\t\t\t\t\t\tIgCq0fuBp6FVhH1fn+bzxyLN7ORWOnPYZeWbxwECCqRaYD6tsUH2+UL2G6SwnAct\n\t\t\t\t\t\t7H1K8pvsfvCjHzzDF67B95lTtql/9ifhb4L5Pb58ntwKDoU/G9oYQaN069lwNRIZ\n\t\t\t\t\t\tAgMBAAGjgZwwgZkwHQYDVR0OBBYEFDeVQv1JG+EQO/AiOsHDqnOjliqEMGoGA1Ud\n\t\t\t\t\t\tIwRjMGGAFDeVQv1JG+EQO/AiOsHDqnOjliqEoT6kPDA6MR8wHQYDVQQKExZVbml2\n\t\t\t\t\t\tZXJzaXR5IG9mIEJyYWRmb3JkMRcwFQYDVQQDEw5pZHAuYnJhZC5hYy51a4IJANXF\n\t\t\t\t\t\tuAkInLUOMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAIby+5WHVMoP\n\t\t\t\t\t\t2p0mzAeMxtM4hBVP3GKl1lkRTSO1AEXCrVbYuaAw45AfZnuadDiQAKFAC0OezT0S\n\t\t\t\t\t\tDQcVSpxrLN2LP8nMoFzhlWkk6gIjvRDPkzxOse7EIhtRWerm52D5uQ9b+31OKVcU\n\t\t\t\t\t\tTXce5suAR/hCXcr41iXDcNDJSQkV1WBfd6UR075umgTEi8ssmbYjM3tjWq+XIFSE\n\t\t\t\t\t\t6hvalVaP6I5fpC+lcQZTvgHtIkwm0PPGtqyVThivuW9469EITTfXx1fAGKiTzuPC\n\t\t\t\t\t\tu/73ycpe1n4szaouE0SYZplEht4mi/ZmDI7KrpwMISxEfdCAtz3E6mAfibmPoPie\n\t\t\t\t\t\t/PZXD7xJX28="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDlDCCAnygAwIBAgIJANXFuAkInLUOMA0GCSqGSIb3DQEBBQUAMDoxHzAdBgNV\n\t\t\t\t\t\tBAoTFlVuaXZlcnNpdHkgb2YgQnJhZGZvcmQxFzAVBgNVBAMTDmlkcC5icmFkLmFj\n\t\t\t\t\t\tLnVrMB4XDTExMTIxNTA3MzU0NloXDTIxMTIxMjA3MzU0NlowOjEfMB0GA1UEChMW\n\t\t\t\t\t\tVW5pdmVyc2l0eSBvZiBCcmFkZm9yZDEXMBUGA1UEAxMOaWRwLmJyYWQuYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC0g3A4ViQaWo3ooKJCJzMT\n\t\t\t\t\t\tsuHZpnYar65+6QiDmZvx1QDGMT+YlYS1jmkuz4YGwJOdj4h9Up9dSCx4M3XweUuD\n\t\t\t\t\t\tbLclot8c05tOBBzm+8UHkaYnIYx/8GKE8+NKtscerr1UvHlOxTBPPFxogb4X0fQm\n\t\t\t\t\t\tiW+PEz9wDPpegj4WlY0ktaxgzjhjvZQwFVqGIBxBvdT6phfkWeK5xj2er956tBgl\n\t\t\t\t\t\tIgCq0fuBp6FVhH1fn+bzxyLN7ORWOnPYZeWbxwECCqRaYD6tsUH2+UL2G6SwnAct\n\t\t\t\t\t\t7H1K8pvsfvCjHzzDF67B95lTtql/9ifhb4L5Pb58ntwKDoU/G9oYQaN069lwNRIZ\n\t\t\t\t\t\tAgMBAAGjgZwwgZkwHQYDVR0OBBYEFDeVQv1JG+EQO/AiOsHDqnOjliqEMGoGA1Ud\n\t\t\t\t\t\tIwRjMGGAFDeVQv1JG+EQO/AiOsHDqnOjliqEoT6kPDA6MR8wHQYDVQQKExZVbml2\n\t\t\t\t\t\tZXJzaXR5IG9mIEJyYWRmb3JkMRcwFQYDVQQDEw5pZHAuYnJhZC5hYy51a4IJANXF\n\t\t\t\t\t\tuAkInLUOMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAIby+5WHVMoP\n\t\t\t\t\t\t2p0mzAeMxtM4hBVP3GKl1lkRTSO1AEXCrVbYuaAw45AfZnuadDiQAKFAC0OezT0S\n\t\t\t\t\t\tDQcVSpxrLN2LP8nMoFzhlWkk6gIjvRDPkzxOse7EIhtRWerm52D5uQ9b+31OKVcU\n\t\t\t\t\t\tTXce5suAR/hCXcr41iXDcNDJSQkV1WBfd6UR075umgTEi8ssmbYjM3tjWq+XIFSE\n\t\t\t\t\t\t6hvalVaP6I5fpC+lcQZTvgHtIkwm0PPGtqyVThivuW9469EITTfXx1fAGKiTzuPC\n\t\t\t\t\t\tu/73ycpe1n4szaouE0SYZplEht4mi/ZmDI7KrpwMISxEfdCAtz3E6mAfibmPoPie\n\t\t\t\t\t\t/PZXD7xJX28="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Bradford"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.brad.ac.uk/library/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Bradford"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.numeriquepremium.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@numeriquepremium.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Info"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ghadiyali"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:openathens@publishingtechnology.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hatim"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.numeriquepremium.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-10-06T09:24:40Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NUM\u00e9RIQUE PREMIUM"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.numeriquepremium.com/shibboleth/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Publishing Technology plc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDpjCCAo6gAwIBAgIEVClg0jANBgkqhkiG9w0BAQUFADCBlDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFDASBgNVBAgTC094Zm9yZHNoaXJlMQ8wDQYDVQQHEwZPeGZvcmQxIzAhBgNV\n\t\t\t\t\t\tBAoTGlB1Ymxpc2hpbmcgVGVjaG5vbG9neSBQbGMuMRkwFwYDVQQLExBTY2hvbGFy\n\t\t\t\t\t\tbHkgT25saW5lMR4wHAYDVQQDExVQdWJsaXNoaW5nIFRlY2hub2xvZ3kwHhcNMTQw\n\t\t\t\t\t\tOTI5MTMzODI2WhcNMTkwOTI4MTMzODI2WjCBlDELMAkGA1UEBhMCR0IxFDASBgNV\n\t\t\t\t\t\tBAgTC094Zm9yZHNoaXJlMQ8wDQYDVQQHEwZPeGZvcmQxIzAhBgNVBAoTGlB1Ymxp\n\t\t\t\t\t\tc2hpbmcgVGVjaG5vbG9neSBQbGMuMRkwFwYDVQQLExBTY2hvbGFybHkgT25saW5l\n\t\t\t\t\t\tMR4wHAYDVQQDExVQdWJsaXNoaW5nIFRlY2hub2xvZ3kwggEiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tAQUAA4IBDwAwggEKAoIBAQCNSLZQXjnJCmfO04AwRYEK/6ylqGB33Pdl2S1j5JgC\n\t\t\t\t\t\tKNxcRWLVBts0i9L1Csmpk44Sx+gVbRLnMjoZxwT7XezB3MvAH390sdOpJEKhM6b7\n\t\t\t\t\t\tJOEl+iub4G82jwGmoQVMRwUQ9dMcdzJY6LVuUri5UmldDRpd60whIip7GJhCdIwz\n\t\t\t\t\t\tAkh6RJyYDua9R3GHdxYWMooekmgj75CUL6PtUN6jTdnlct48zPVzA1KNGxKaICs0\n\t\t\t\t\t\tyy4cmTBbPVB9w5lM4pgCS8uHyTHsQZ1n3vnn0EuEf0rbHKPtc/TDhTV9GbNtJJws\n\t\t\t\t\t\tpkaniaHmlMg1f7cfA37PDJOK7OzTn0FcgfXSO4DCfe8fAgMBAAEwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAGsjQgkLeTxZ/GPFKgGso5vqtENIZmyAAHt9KbRw3Fku1Z/xQ6US\n\t\t\t\t\t\t8EKYGN3fkPZ9E4UUGZCe2O7Lo6N5Pt7Kt6TbPhae4vkmE/Nm2i5YvjWn+fgO9/NF\n\t\t\t\t\t\tNSI0XmDOvGZokbGUDwZrrhibzHxGIcyaA1oodF37/oz3r10rZkLauW//CmOf6OUC\n\t\t\t\t\t\trGnKBPoQG2kIyG8rWoKDzWtcRcdqDea9kdZwmDftizoLtJtKIyW8FavtknHpRTSI\n\t\t\t\t\t\tsYwXGiixYKkmEHyqXZ04jYokm0cdrARdVvFexRd/m+0OO+25MxuBDEmCs+8HZD1c\n\t\t\t\t\t\twWYy4HqaGBWV3Iotfxxdus9i8nenq47abSQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDpjCCAo6gAwIBAgIEVClg0jANBgkqhkiG9w0BAQUFADCBlDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFDASBgNVBAgTC094Zm9yZHNoaXJlMQ8wDQYDVQQHEwZPeGZvcmQxIzAhBgNV\n\t\t\t\t\t\tBAoTGlB1Ymxpc2hpbmcgVGVjaG5vbG9neSBQbGMuMRkwFwYDVQQLExBTY2hvbGFy\n\t\t\t\t\t\tbHkgT25saW5lMR4wHAYDVQQDExVQdWJsaXNoaW5nIFRlY2hub2xvZ3kwHhcNMTQw\n\t\t\t\t\t\tOTI5MTMzODI2WhcNMTkwOTI4MTMzODI2WjCBlDELMAkGA1UEBhMCR0IxFDASBgNV\n\t\t\t\t\t\tBAgTC094Zm9yZHNoaXJlMQ8wDQYDVQQHEwZPeGZvcmQxIzAhBgNVBAoTGlB1Ymxp\n\t\t\t\t\t\tc2hpbmcgVGVjaG5vbG9neSBQbGMuMRkwFwYDVQQLExBTY2hvbGFybHkgT25saW5l\n\t\t\t\t\t\tMR4wHAYDVQQDExVQdWJsaXNoaW5nIFRlY2hub2xvZ3kwggEiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tAQUAA4IBDwAwggEKAoIBAQCNSLZQXjnJCmfO04AwRYEK/6ylqGB33Pdl2S1j5JgC\n\t\t\t\t\t\tKNxcRWLVBts0i9L1Csmpk44Sx+gVbRLnMjoZxwT7XezB3MvAH390sdOpJEKhM6b7\n\t\t\t\t\t\tJOEl+iub4G82jwGmoQVMRwUQ9dMcdzJY6LVuUri5UmldDRpd60whIip7GJhCdIwz\n\t\t\t\t\t\tAkh6RJyYDua9R3GHdxYWMooekmgj75CUL6PtUN6jTdnlct48zPVzA1KNGxKaICs0\n\t\t\t\t\t\tyy4cmTBbPVB9w5lM4pgCS8uHyTHsQZ1n3vnn0EuEf0rbHKPtc/TDhTV9GbNtJJws\n\t\t\t\t\t\tpkaniaHmlMg1f7cfA37PDJOK7OzTn0FcgfXSO4DCfe8fAgMBAAEwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAGsjQgkLeTxZ/GPFKgGso5vqtENIZmyAAHt9KbRw3Fku1Z/xQ6US\n\t\t\t\t\t\t8EKYGN3fkPZ9E4UUGZCe2O7Lo6N5Pt7Kt6TbPhae4vkmE/Nm2i5YvjWn+fgO9/NF\n\t\t\t\t\t\tNSI0XmDOvGZokbGUDwZrrhibzHxGIcyaA1oodF37/oz3r10rZkLauW//CmOf6OUC\n\t\t\t\t\t\trGnKBPoQG2kIyG8rWoKDzWtcRcdqDea9kdZwmDftizoLtJtKIyW8FavtknHpRTSI\n\t\t\t\t\t\tsYwXGiixYKkmEHyqXZ04jYokm0cdrARdVvFexRd/m+0OO+25MxuBDEmCs+8HZD1c\n\t\t\t\t\t\twWYy4HqaGBWV3Iotfxxdus9i8nenq47abSQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://www.numeriquepremium.com/session/shib",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.numeriquepremium.com/session/shib",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://test.shu.unidesk.ac.uk/tas/public/login/verify",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:is.helpline@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-certs@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Apps Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test.shu.unidesk.ac.uk/tas/public/login/verify",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-05T13:20:50Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Test Unidesk - Sheffiield Hallam"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0zCCArugAwIBAgIJAIZxYEaEw5lGMA0GCSqGSIb3DQEBCwUAME8xHzAdBgNV\n\t\t\t\t\t\tBAMTFnRlc3Quc2h1LnVuaWRlc2suYWMudWsxHzAdBgNVBAoTFnRlc3Quc2h1LnVu\n\t\t\t\t\t\taWRlc2suYWMudWsxCzAJBgNVBAYTAlVLMB4XDTE2MDQwMTEyMzYxOFoXDTI2MDMz\n\t\t\t\t\t\tMDEyMzYxOFowTzEfMB0GA1UEAxMWdGVzdC5zaHUudW5pZGVzay5hYy51azEfMB0G\n\t\t\t\t\t\tA1UEChMWdGVzdC5zaHUudW5pZGVzay5hYy51azELMAkGA1UEBhMCVUswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDJJlXnctUpVTPqInQC60gcrfsD4m5m\n\t\t\t\t\t\tGTWAWSXlYhKDfq6F7JZe0Nrph06Mx/SYqzwmSJWr9LeyA7gZaR/5lGR9rxAUn26/\n\t\t\t\t\t\tZvz14VxsTQlP2YnEePcAwyi698wulMGELyPN4zgo+oEBBpuRDXGqYH7OjqCI+Ktc\n\t\t\t\t\t\tGJ77yE6XM6TNTLMFFB93QdooI1QXcyOYjhYBq7PpRY4jkyozAW28GJMu6lBdpLua\n\t\t\t\t\t\tFoGw2N/Qy3aUFQ6WxK2If4URZqjj+W56vZj9COsAGonUO9RxiEFIyp3e+qBW0ua8\n\t\t\t\t\t\txps4G4tvV8PT23SGu5caTsAMkx/xdByTso4F5IAO6YLA9SXCDHkfwiX1AgMBAAGj\n\t\t\t\t\t\tgbEwga4wHQYDVR0OBBYEFDb5sE6vS/3tZXp/gPQKykHPSLV+MH8GA1UdIwR4MHaA\n\t\t\t\t\t\tFDb5sE6vS/3tZXp/gPQKykHPSLV+oVOkUTBPMR8wHQYDVQQDExZ0ZXN0LnNodS51\n\t\t\t\t\t\tbmlkZXNrLmFjLnVrMR8wHQYDVQQKExZ0ZXN0LnNodS51bmlkZXNrLmFjLnVrMQsw\n\t\t\t\t\t\tCQYDVQQGEwJVS4IJAIZxYEaEw5lGMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQADggEBAFBE8uejSEiTBVTy3ehydf78gUIz2mfDjtFFnoTK4Atok6I2ABqeXAlB\n\t\t\t\t\t\tp2LQ1dwM6nS3Or8dctOtx8aRmcvf8DTXWCcC3dSSLeU8lzl/GnBeGMKEoYAKmWVz\n\t\t\t\t\t\tp0O1/0XtuRc1m1j0OzCUnuDAI0Vn31fby2Q0oGYdwTGeCd+DjoEbCVLUPGGerb9T\n\t\t\t\t\t\tseyS9bm/fmyGdlKw6Y44M7Cj9crf7faGZkDbdXxIf+mCyQBNBS0X90LMHFcR/gr/\n\t\t\t\t\t\tV6IR7SHk+cpzw5ENh4+25GYzL0/qYDhp8YSYqU5ioWRqTLOZf11dLSWUQZUHmFE+\n\t\t\t\t\t\tsiyQlKd1yPLqIHp5HYHIQLLIZN+HLlM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0zCCArugAwIBAgIJAIZxYEaEw5lGMA0GCSqGSIb3DQEBCwUAME8xHzAdBgNV\n\t\t\t\t\t\tBAMTFnRlc3Quc2h1LnVuaWRlc2suYWMudWsxHzAdBgNVBAoTFnRlc3Quc2h1LnVu\n\t\t\t\t\t\taWRlc2suYWMudWsxCzAJBgNVBAYTAlVLMB4XDTE2MDQwMTEyMzYxOFoXDTI2MDMz\n\t\t\t\t\t\tMDEyMzYxOFowTzEfMB0GA1UEAxMWdGVzdC5zaHUudW5pZGVzay5hYy51azEfMB0G\n\t\t\t\t\t\tA1UEChMWdGVzdC5zaHUudW5pZGVzay5hYy51azELMAkGA1UEBhMCVUswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDJJlXnctUpVTPqInQC60gcrfsD4m5m\n\t\t\t\t\t\tGTWAWSXlYhKDfq6F7JZe0Nrph06Mx/SYqzwmSJWr9LeyA7gZaR/5lGR9rxAUn26/\n\t\t\t\t\t\tZvz14VxsTQlP2YnEePcAwyi698wulMGELyPN4zgo+oEBBpuRDXGqYH7OjqCI+Ktc\n\t\t\t\t\t\tGJ77yE6XM6TNTLMFFB93QdooI1QXcyOYjhYBq7PpRY4jkyozAW28GJMu6lBdpLua\n\t\t\t\t\t\tFoGw2N/Qy3aUFQ6WxK2If4URZqjj+W56vZj9COsAGonUO9RxiEFIyp3e+qBW0ua8\n\t\t\t\t\t\txps4G4tvV8PT23SGu5caTsAMkx/xdByTso4F5IAO6YLA9SXCDHkfwiX1AgMBAAGj\n\t\t\t\t\t\tgbEwga4wHQYDVR0OBBYEFDb5sE6vS/3tZXp/gPQKykHPSLV+MH8GA1UdIwR4MHaA\n\t\t\t\t\t\tFDb5sE6vS/3tZXp/gPQKykHPSLV+oVOkUTBPMR8wHQYDVQQDExZ0ZXN0LnNodS51\n\t\t\t\t\t\tbmlkZXNrLmFjLnVrMR8wHQYDVQQKExZ0ZXN0LnNodS51bmlkZXNrLmFjLnVrMQsw\n\t\t\t\t\t\tCQYDVQQGEwJVS4IJAIZxYEaEw5lGMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQADggEBAFBE8uejSEiTBVTy3ehydf78gUIz2mfDjtFFnoTK4Atok6I2ABqeXAlB\n\t\t\t\t\t\tp2LQ1dwM6nS3Or8dctOtx8aRmcvf8DTXWCcC3dSSLeU8lzl/GnBeGMKEoYAKmWVz\n\t\t\t\t\t\tp0O1/0XtuRc1m1j0OzCUnuDAI0Vn31fby2Q0oGYdwTGeCd+DjoEbCVLUPGGerb9T\n\t\t\t\t\t\tseyS9bm/fmyGdlKw6Y44M7Cj9crf7faGZkDbdXxIf+mCyQBNBS0X90LMHFcR/gr/\n\t\t\t\t\t\tV6IR7SHk+cpzw5ENh4+25GYzL0/qYDhp8YSYqU5ioWRqTLOZf11dLSWUQZUHmFE+\n\t\t\t\t\t\tsiyQlKd1yPLqIHp5HYHIQLLIZN+HLlM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.shu.unidesk.ac.uk/tas/public/login/verify",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://shib-sp-01.ntu.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cross"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Richard.cross@ntu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hallam"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lee.hallam@ntu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lee"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib-sp-01.ntu.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-09-04T10:58:58Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NTU Service Provider"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ntu.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Nottingham Trent University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-sp-01.ntu.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-sp-01.ntu.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-sp-01.ntu.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib-sp-01.ntu.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-sp-01.ntu.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib-sp-01.ntu.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shib-sp-01.ntu.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAMilnmPtn3NCMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHNoaWItc3AtMDEuYWRzLm50dS5hYy51azAeFw0xNTA2MjMxNDU5NDlaFw0y\n\t\t\t\t\t\tNTA2MjAxNDU5NDlaMCMxITAfBgNVBAMTGHNoaWItc3AtMDEuYWRzLm50dS5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOQoL0vvAnaIs2kuObQy\n\t\t\t\t\t\tzfl6uLKfZt3Swmk6mAScayoLf1/G1tuNOWuyIlx8Jk11y0FKaxEpQo74L6+O3p0+\n\t\t\t\t\t\tu50pAQbqztYPuDiZa0QXR6y2kMsaNIAg6tu3sDVZxuDm7Bb3+ooHXMFxvQX5JzQ1\n\t\t\t\t\t\th6YU4ZWWL8oEBtqB/ZAL1FQpOba+NTUubSyx/DlNJlMUgRhoayIRrTuSKcZ91vrP\n\t\t\t\t\t\tcXqUczaCupMmUMmkJwgMusv0AveKQ49/wYNF8317tiJTOYaqzRCmRbFNOSWW6EOV\n\t\t\t\t\t\t/1ScUF28R1QmdAXNHM/FNcVwupzmOkAfRwnHbMqC1u3PjjEXD04cYR0DOEoKFyzG\n\t\t\t\t\t\t3CcCAwEAAaNGMEQwIwYDVR0RBBwwGoIYc2hpYi1zcC0wMS5hZHMubnR1LmFjLnVr\n\t\t\t\t\t\tMB0GA1UdDgQWBBR53RT21evYt4Y0yQy0Ly/kxwSg4jANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAG3CAgAkm1MelQMF6jHBE59Jmun1sY2TXkLjVX9+HFHwhvTMrGhH/fvAFbNak\n\t\t\t\t\t\tPUwLyBnOxonMmNSifULYnI7AqjpdD1/r4/nZDYbSqGW4kXjkLi5V2dy0BxQGxpgf\n\t\t\t\t\t\tnaknk3+bFdPfSCAE/IejuZ5+rRtReydXQbt2HeYLV5WfycbBUIx7lWm3MH1ECKhJ\n\t\t\t\t\t\tmG8ADkLheueCWnsvTRGRbb81WEIYSK3O9xSlS2pvqDexY5yJRu0pHokx8Zb0v16F\n\t\t\t\t\t\tLkBdLAY/0llo1p+XKxoL7ipZMg1m2MRV95/IEePFEK3RuKVgF7HV6nV7oeBCeWu6\n\t\t\t\t\t\tEJSsJo3v9pO5Jxdkrf+rsCwOGw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-sp-01.ntu.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib-sp-01.ntu.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib-sp-01.ntu.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shib-sp-01.ntu.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shib-sp-01.ntu.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shib-sp-01.ntu.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://7t.lbic.lu.se/",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "M\u00e5rtensson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Anders.Martensson@med.lu.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Anders"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://7t.lbic.lu.se/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://7t.lbic.lu.se/simplesaml/module.php/saml/sp/saml2-logout.php/7t",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ans\u00f6kningshantering till nationella 7T anl\u00e4ggningen i Lund"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Application submission for use of the national 7T facility in Lund"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Nationella 7T anl\u00e4ggningen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "National 7T facility"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://7t.lbic.lu.se/simplesaml/module.php/saml/sp/saml2-acs.php/7t",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://7t.lbic.lu.se/simplesaml/module.php/saml/sp/saml1-acs.php/7t",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://7t.lbic.lu.se/simplesaml/module.php/saml/sp/saml2-acs.php/7t",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://7t.lbic.lu.se/simplesaml/module.php/saml/sp/saml1-acs.php/7t/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://webauth.uncc.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "EnterpriseWebServices-group@uncc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Enterprise Web Services"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "EnterpriseWebServices-group@uncc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Enterprise Web Services"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@uncc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://webauth.uncc.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webauth.uncc.edu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://webauth.uncc.edu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://webauth.uncc.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webauth.uncc.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://webauth.uncc.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://webauth.uncc.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uncc.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://webauth.uncc.edu"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of North Carolina At Charlotte"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for University of North Carolina at Charlotte."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.uncc.edu/sites/all/themes/unccedu/logo.png",
                    "lang": "en",
                    "height": "56",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "128"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://legal.uncc.edu/website-use-policies/privacy-statement"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUE9Q+gC5nxV1laEjS/0Wz6pcH+RQwDQYJKoZIhvcNAQEF\nBQAwGzEZMBcGA1UEAxMQd2ViYXV0aC51bmNjLmVkdTAeFw0xNDA1MDYxNzQxNDJa\nFw0zNDA1MDYxNzQxNDJaMBsxGTAXBgNVBAMTEHdlYmF1dGgudW5jYy5lZHUwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCPA7pMdoQeaLMV2OLrePUxY9p4\ngAHGqMpUruERe0+2/tg2AvL98eGHMaJ7Oijr9R4RuYONR5WoQc8if36bZ5XP1i7M\nEDq1MLA2BPWrX8b366AG0wjIOlCreimCSQ3zATSICW6i6pNwvJe3KqNKOxK+PWwo\nwX3BiOSYQX2ASmIzKuM5yyjNrlwcx2jAPDu86e0oEiS4CuT0D3Y99cWy/+FGN2uE\njrX/JuGWL2EOSthtVKT8qjYg4G7yXL4UobbG+LE3oOgk+fZG39sQK/a50VIhHAlG\nnS9C6B/2rvjX9h2RfrT2LIE7vhLqAtmt9C9O0k5CbniZHTQyHzilFvVmaPvLAgMB\nAAGjZzBlMEQGA1UdEQQ9MDuCEHdlYmF1dGgudW5jYy5lZHWGJ2h0dHBzOi8vd2Vi\nYXV0aC51bmNjLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUQKVbWSA/8qLr\npVyyPD+QGdlRE6QwDQYJKoZIhvcNAQEFBQADggEBAAqC3iIjFCbFr8f6YnMZml6f\nlwi4lUgeRafI2rOq26x3D2/V1HMDAT1INgy950E7ChakXMKG691ee3a00j02P0I1\neoJcrDRHrbt9fzobxOyhzU2qpaTZjMDTFD/du9GERjsz4TXRZcCvArOL7i1S8qWd\n+YDKvUr8y3UqFfJD+hvH+/dyGiKWOTFpr6ac0lS7ofTOb7wTse1jHZyjEhR768jD\nuhC6wP1FE5HmACR4pPylxXJbvSLCKqLGmT8xYKb2VthIY4sBXIpQZ7C0FUn4p+bd\nYv8S+IWg7U+XmXCrOaV03/kqASJCZW3gxtXJ3KKfsiH4tPfx3Wn3Msi03ZeVYMc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "error_url": "https://webauth.uncc.edu/error.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of North Carolina At Charlotte"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uncc.edu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of North Carolina At Charlotte"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:ucmerced.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "gfellin@ucmerced.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Greg Fellin"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "fgorham@ucmerced.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Faust Gorham"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jkamminga@ucmerced.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Kamminga"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:ucmerced.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.ucmerced.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.ucmerced.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEjDCCA3SgAwIBAgIJAOupCdJ2sSXbMA0GCSqGSIb3DQEBBQUAMIGKMQswCQYD\nVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEpMCcGA1UEChMgVW5pdmVyc2l0\neSBvZiBDYWxpZm9ybmlhLCBNZXJjZWQxHzAdBgNVBAsTFkluZm9ybWF0aW9uIFRl\nY2hub2xvZ3kxGjAYBgNVBAMTEXNoaWIudWNtZXJjZWQuZWR1MB4XDTEwMDgyMDIx\nNTY1MVoXDTM4MDEwNDIxNTY1MVowgYoxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpD\nYWxpZm9ybmlhMSkwJwYDVQQKEyBVbml2ZXJzaXR5IG9mIENhbGlmb3JuaWEsIE1l\ncmNlZDEfMB0GA1UECxMWSW5mb3JtYXRpb24gVGVjaG5vbG9neTEaMBgGA1UEAxMR\nc2hpYi51Y21lcmNlZC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQDfJkuFl7d2fl92r5hV56rYFJW5bHJGGXjmossXjEfaBVYaxnBC5HpWf2LxKhbm\nihJt5taV0icxGH8I1Pzc/5vHbWRmAWQPGjv+Zqs3/AbgdG9hwfgDrbFFHfZE7l2n\ndXhmWrjBu+M9CygbVkzTTMeLQ8HmlGeLJQRAixa85SL4j5ZGNGVK5Gi/NFjyuGL2\nTDLBVvmPlwLUM1T66QsCz0ceEm4OT1n1V8y+JQ8YR/bJa6CljdNKKCprFnBkVFhk\nEuybjb2/Mf2D+f0cY5TZntVA5cjWwZPy+3D9MKas/s41B5hZjqFv2mEf1jLYYM6k\nmv4oKL9kSBgGh9+JH+eES3uJAgMBAAGjgfIwge8wHQYDVR0OBBYEFL0bO2LYqE2L\nYMpAErrAY6uTagRFMIG/BgNVHSMEgbcwgbSAFL0bO2LYqE2LYMpAErrAY6uTagRF\noYGQpIGNMIGKMQswCQYDVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEpMCcG\nA1UEChMgVW5pdmVyc2l0eSBvZiBDYWxpZm9ybmlhLCBNZXJjZWQxHzAdBgNVBAsT\nFkluZm9ybWF0aW9uIFRlY2hub2xvZ3kxGjAYBgNVBAMTEXNoaWIudWNtZXJjZWQu\nZWR1ggkA66kJ0naxJdswDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEA\nlX6J5Df1EUiDuCwlFyRbmgch54ywFsIvKW/q2VfwH8DQePoQqetsm8frHtnKyBjN\nEKPwE63XV79n3mTei6kMFdB/e10SPa5vdOc/kzVvy4a2gBEfH+YPerbAiiAllKfW\nV9lkQ7BGzb8d9guY7ZZvy8BJyNqrcfdcqAETBWYLrJx65UYo4hJZyG/X1JUX3WZ8\nff2dPd5C7gboKQO4y76D1uEgwR+XEexamlmpLvREfaZMyN3dbpXCjYmvSayBGUgM\nI/HsbnejDezNN+Za/qaXjv+9wsXOGgmF3QQlQsbKXcLHb0eHYqaB604kQ6I+6y5X\nkFhAPTrlZdh9/KLkKhq9QA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucmerced.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.ucmerced.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.ucmerced.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.ucmerced.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.ucmerced.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.ucmerced.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.ucmerced.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucmerced.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of California, Merced"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEjDCCA3SgAwIBAgIJAOupCdJ2sSXbMA0GCSqGSIb3DQEBBQUAMIGKMQswCQYD\nVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEpMCcGA1UEChMgVW5pdmVyc2l0\neSBvZiBDYWxpZm9ybmlhLCBNZXJjZWQxHzAdBgNVBAsTFkluZm9ybWF0aW9uIFRl\nY2hub2xvZ3kxGjAYBgNVBAMTEXNoaWIudWNtZXJjZWQuZWR1MB4XDTEwMDgyMDIx\nNTY1MVoXDTM4MDEwNDIxNTY1MVowgYoxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpD\nYWxpZm9ybmlhMSkwJwYDVQQKEyBVbml2ZXJzaXR5IG9mIENhbGlmb3JuaWEsIE1l\ncmNlZDEfMB0GA1UECxMWSW5mb3JtYXRpb24gVGVjaG5vbG9neTEaMBgGA1UEAxMR\nc2hpYi51Y21lcmNlZC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQDfJkuFl7d2fl92r5hV56rYFJW5bHJGGXjmossXjEfaBVYaxnBC5HpWf2LxKhbm\nihJt5taV0icxGH8I1Pzc/5vHbWRmAWQPGjv+Zqs3/AbgdG9hwfgDrbFFHfZE7l2n\ndXhmWrjBu+M9CygbVkzTTMeLQ8HmlGeLJQRAixa85SL4j5ZGNGVK5Gi/NFjyuGL2\nTDLBVvmPlwLUM1T66QsCz0ceEm4OT1n1V8y+JQ8YR/bJa6CljdNKKCprFnBkVFhk\nEuybjb2/Mf2D+f0cY5TZntVA5cjWwZPy+3D9MKas/s41B5hZjqFv2mEf1jLYYM6k\nmv4oKL9kSBgGh9+JH+eES3uJAgMBAAGjgfIwge8wHQYDVR0OBBYEFL0bO2LYqE2L\nYMpAErrAY6uTagRFMIG/BgNVHSMEgbcwgbSAFL0bO2LYqE2LYMpAErrAY6uTagRF\noYGQpIGNMIGKMQswCQYDVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEpMCcG\nA1UEChMgVW5pdmVyc2l0eSBvZiBDYWxpZm9ybmlhLCBNZXJjZWQxHzAdBgNVBAsT\nFkluZm9ybWF0aW9uIFRlY2hub2xvZ3kxGjAYBgNVBAMTEXNoaWIudWNtZXJjZWQu\nZWR1ggkA66kJ0naxJdswDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEA\nlX6J5Df1EUiDuCwlFyRbmgch54ywFsIvKW/q2VfwH8DQePoQqetsm8frHtnKyBjN\nEKPwE63XV79n3mTei6kMFdB/e10SPa5vdOc/kzVvy4a2gBEfH+YPerbAiiAllKfW\nV9lkQ7BGzb8d9guY7ZZvy8BJyNqrcfdcqAETBWYLrJx65UYo4hJZyG/X1JUX3WZ8\nff2dPd5C7gboKQO4y76D1uEgwR+XEexamlmpLvREfaZMyN3dbpXCjYmvSayBGUgM\nI/HsbnejDezNN+Za/qaXjv+9wsXOGgmF3QQlQsbKXcLHb0eHYqaB604kQ6I+6y5X\nkFhAPTrlZdh9/KLkKhq9QA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of California, Merced"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ucmerced.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of California, Merced"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-p06.ladok.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-p06.ladok.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p06.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p06.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p06.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p06.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p06.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-p06.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-p06.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;p06"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;p06"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-p06.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-p06.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQTCCAimgAwIBAgIJAOix5zlBNSLEMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2xhZG9rMy1wMDYubGFkb2sudW11LnNlMB4XDTE0MTAwNzE0NDYwNloXDTI0\nMTAwNDE0NDYwNlowIjEgMB4GA1UEAxMXbGFkb2szLXAwNi5sYWRvay51bXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC8mIU82TtnYGRnBftG1eL8\nqquRI06Vuorrh6DF8RFIABn0T7Mo2nE1vADdHdeA1rX2sJvQIooZB+79RBRyc6e0\nyTg6kZGMvGKeo4VNWAe4lByWKWT5vgRj8CbRn8A+RMUFAf+P/ubvnpcGrbSlSosU\nG9hHzTzxTTgSIhP8SZzPEesfm9K+gXybdXdgAp+EjVoHs0rFL1U4lOYs512pt1G6\nuAejXrpqlivScL1my3eSWCcWcrknWNBm4FgxDiHojw9+vkYDQsV3HQfr7wO84HXS\nM8eQXLax6xV2eWQD9T5XJro5Azta9gFs5UnVc5LgV3CEwUnOrgBo3pz7pWGJKxBj\nAgMBAAGjejB4MFcGA1UdEQRQME6CF2xhZG9rMy1wMDYubGFkb2sudW11LnNlhjNo\ndHRwczovL2xhZG9rMy1wMDYubGFkb2sudW11LnNlL3N0dWRlbnQtZnJvbnRlbmQt\nc3AwHQYDVR0OBBYEFGpPLPhti69xSWX81LlGIpT/kj4mMA0GCSqGSIb3DQEBBQUA\nA4IBAQCXW6+mPm32KR3kXuL7HgWqsRqQWe/U5wu+nlShNm9QN7eoMEkAfA78nqdN\nZo0PzIXhtqD3aKnNfIacbTtygZuR3cJtX0CpHjPolHJOvx9WFiPJ8fe6PoX+xkN+\nj4KCk5eTiDm41nMyxHTMpxynFabRZ148ZrkZiADG6rXjSbpmKUFz5JGdhi29vSq1\nDTe5S39afa06bfVzOWLYd+UsjQka4OF951SDAF4Nx4fatoDkpO7Krz6XaGxlzS2W\nRvrQLObmzN2mBM1biJJS0AGapEiXzb+ZqqKf9zizvfKIJ9nhKqNv9SOGSFNX24QW\nPUO1EQo+arx4qeJ4W+ttDEFl+4Bd"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-p06.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p06.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p06.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p06.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p06.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p06.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p06.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-p06.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-p06.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-p06.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://idp.northampton.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Aynsworth"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mike.aynsworth@northampton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Aynsworth"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mike.aynsworth@northampton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://idp.northampton.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.northampton.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.northampton.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "northampton.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIJAO2YHtS7tStwMA0GCSqGSIb3DQEBBQUAMEgxJjAkBgNV\n\t\t\t\t\t\tBAoTHVRoZSBVbml2ZXJzaXR5IG9mIE5vcnRoYW1wdG9uMR4wHAYDVQQDExVpZHAu\n\t\t\t\t\t\tbm9ydGhhbXB0b24uYWMudWswHhcNMTEwNzAxMDkzMTA2WhcNMjEwNjI4MDkzMTA2\n\t\t\t\t\t\tWjBIMSYwJAYDVQQKEx1UaGUgVW5pdmVyc2l0eSBvZiBOb3J0aGFtcHRvbjEeMBwG\n\t\t\t\t\t\tA1UEAxMVaWRwLm5vcnRoYW1wdG9uLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAnXNIFiDdMKiB0epr5mrHoxdU9agPeWH+KMyutW6bz/58uYE1\n\t\t\t\t\t\tyQGCivZPOoYl2rLrkvz/CboDst49EfaphkC2wro4AlZWj3if/g7DBWDOfdFQ+uxQ\n\t\t\t\t\t\tZs53Bcx5htjbOAbIgnVM5qUXj0hY48VE4iUhIfXg2sS2rAtZ0mFBfbscxtiGReMy\n\t\t\t\t\t\tc+RK+d4FVe2FilXuhDsrSTbrzdRD+y/dJgyueh6wtQNK19y5VmrbUQv4eL7zu0Hj\n\t\t\t\t\t\tFiPBNH/fnAQG9vZJusj2GSGLqUdFwJ5WeBykmSCM0y+zCV7Lg5cgbzaDqw7GkFQ8\n\t\t\t\t\t\tnGaSChoZeOiZLGYyAJW8SWr4BItMCIzKYu39ZwIDAQABo4GqMIGnMB0GA1UdDgQW\n\t\t\t\t\t\tBBRubSh5GRDx+a/9clMJCs+uSzUUHjB4BgNVHSMEcTBvgBRubSh5GRDx+a/9clMJ\n\t\t\t\t\t\tCs+uSzUUHqFMpEowSDEmMCQGA1UEChMdVGhlIFVuaXZlcnNpdHkgb2YgTm9ydGhh\n\t\t\t\t\t\tbXB0b24xHjAcBgNVBAMTFWlkcC5ub3J0aGFtcHRvbi5hYy51a4IJAO2YHtS7tStw\n\t\t\t\t\t\tMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAJStfpsWeslB4rGZfXcf\n\t\t\t\t\t\t5L+TQ+01ukSjEVTCPk76BC/xyy8hgzVeHsoO1H1cBeQwiq5metEJvNP6Lws13An5\n\t\t\t\t\t\tjIDYCUbw79XqfIF8R8ElEX9yDQjQlvE1gnowcu06lnBMrKbSPKigSdfVgZnp5lm1\n\t\t\t\t\t\tnkOjNCIFua99k4/29oPYjY4N9j1RLfpsQj9I+b89yoRCcTzqdssL28bF5Yj2M9vn\n\t\t\t\t\t\ti4k/FGuhoklMy5g/PzA0oB9NOY30HJ90V6vcWCXZBx1etmURUhAzm4Ibz7eeoxVj\n\t\t\t\t\t\tW1alcTc/bTwRSru+aCuukrK0V+jlLDxxKJEwSi3BgOL2+e+RYXOWhU/kDbnbrc1e\n\t\t\t\t\t\tSCQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIJAO2YHtS7tStwMA0GCSqGSIb3DQEBBQUAMEgxJjAkBgNV\n\t\t\t\t\t\tBAoTHVRoZSBVbml2ZXJzaXR5IG9mIE5vcnRoYW1wdG9uMR4wHAYDVQQDExVpZHAu\n\t\t\t\t\t\tbm9ydGhhbXB0b24uYWMudWswHhcNMTEwNzAxMDkzMTA2WhcNMjEwNjI4MDkzMTA2\n\t\t\t\t\t\tWjBIMSYwJAYDVQQKEx1UaGUgVW5pdmVyc2l0eSBvZiBOb3J0aGFtcHRvbjEeMBwG\n\t\t\t\t\t\tA1UEAxMVaWRwLm5vcnRoYW1wdG9uLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAnXNIFiDdMKiB0epr5mrHoxdU9agPeWH+KMyutW6bz/58uYE1\n\t\t\t\t\t\tyQGCivZPOoYl2rLrkvz/CboDst49EfaphkC2wro4AlZWj3if/g7DBWDOfdFQ+uxQ\n\t\t\t\t\t\tZs53Bcx5htjbOAbIgnVM5qUXj0hY48VE4iUhIfXg2sS2rAtZ0mFBfbscxtiGReMy\n\t\t\t\t\t\tc+RK+d4FVe2FilXuhDsrSTbrzdRD+y/dJgyueh6wtQNK19y5VmrbUQv4eL7zu0Hj\n\t\t\t\t\t\tFiPBNH/fnAQG9vZJusj2GSGLqUdFwJ5WeBykmSCM0y+zCV7Lg5cgbzaDqw7GkFQ8\n\t\t\t\t\t\tnGaSChoZeOiZLGYyAJW8SWr4BItMCIzKYu39ZwIDAQABo4GqMIGnMB0GA1UdDgQW\n\t\t\t\t\t\tBBRubSh5GRDx+a/9clMJCs+uSzUUHjB4BgNVHSMEcTBvgBRubSh5GRDx+a/9clMJ\n\t\t\t\t\t\tCs+uSzUUHqFMpEowSDEmMCQGA1UEChMdVGhlIFVuaXZlcnNpdHkgb2YgTm9ydGhh\n\t\t\t\t\t\tbXB0b24xHjAcBgNVBAMTFWlkcC5ub3J0aGFtcHRvbi5hYy51a4IJAO2YHtS7tStw\n\t\t\t\t\t\tMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAJStfpsWeslB4rGZfXcf\n\t\t\t\t\t\t5L+TQ+01ukSjEVTCPk76BC/xyy8hgzVeHsoO1H1cBeQwiq5metEJvNP6Lws13An5\n\t\t\t\t\t\tjIDYCUbw79XqfIF8R8ElEX9yDQjQlvE1gnowcu06lnBMrKbSPKigSdfVgZnp5lm1\n\t\t\t\t\t\tnkOjNCIFua99k4/29oPYjY4N9j1RLfpsQj9I+b89yoRCcTzqdssL28bF5Yj2M9vn\n\t\t\t\t\t\ti4k/FGuhoklMy5g/PzA0oB9NOY30HJ90V6vcWCXZBx1etmURUhAzm4Ibz7eeoxVj\n\t\t\t\t\t\tW1alcTc/bTwRSru+aCuukrK0V+jlLDxxKJEwSi3BgOL2+e+RYXOWhU/kDbnbrc1e\n\t\t\t\t\t\tSCQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Northampton (IDP)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.northampton.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Northampton"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-09.ladok.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-09.ladok.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;09"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;09"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-09.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-09.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAKHAw32nqb4aMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wOS5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTQ0MzA5WhcNMjQx\nMDA0MTQ0MzA5WjAhMR8wHQYDVQQDExZsYWRvazMtMDkubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA4qCGNdWn1MRb1t4RmqEFKnRp\nZwc88GDSNVxdEHR6jRWUyPgugOa/s/b8Ef3J04ajiXdGJUjVkNaaoxOKgH7JNOW4\n29qfjzgKVX4G5Ipcxfbp+/Wn52kXCZfrDUX1e7Amc1tG/tAgNgHdKCj7EZneP819\nRlrDYCRyYP5VAUvWTuujaQFJFXEdgAkWtkfeQBt9HMU2eSCj/SpdDPJpDFI2BKuz\n7z/MkFlhz8ywuFJDZ+O/lNiE9xeS2DEMXQ2Y7tR25EfeXJkSwkWkRiJoNMrtp2Hc\nN1dWsmReAH4NZKahsYL3JsKCzbSsgr/OW5SgyREJFGsTqTCQc7rPw8YsLizUbQID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMDkubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0wOS5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUlelU5h8KM7K0SC1Dwm6D4T5ZvBswDQYJKoZIhvcNAQEFBQADggEB\nADm1+g/0bCQST/RsDvEdy1VfdjLTX+ODy05PiGUy+GlhR2phHhbZ4vddtrV9FuIl\nx28aT8Xvmu47uQIgm26PAtiM1tZYV1JeWTP821NAKfVjl6QKyHnOSksKCC3yOlVk\nO2Vxsu0YyAl0aGvd6FqykxxDClUCSg1nboUhGyr6rgPVxv/+VbI9wNj8QocEDMC4\n55fjM0PeDjSTdjWUPyzX/VFhEtBYrFodS0b9rHWLM+yKKaDG0Gl9E5f9k1uEUNtr\nU83MU1NmV9lmNF1itMe+ujgc/6Af0/F0MTIulAtx1+ZMtIrw3k9at4Auz+urHU37\nRRQKVctmQVOlffVIDFzZgbA="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-09.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.rcplondon.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.rcplondon.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/rcplondon.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/rcplondon.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rcplondon.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Royal College of Physicians of London"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rcplondon.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.ifac.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kellyton Azevedo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cored@ifac.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.ifac.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID1DCCArwCAQAwDQYJKoZIhvcNAQEFBQAwga8xKTAnBgNVBAoTIElGQUMgLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkbyBBY3JlMQ4wDAYDVQQLEwVEU0dUSTEgMB4GCSqG\nSIb3DQEJARYRY29yZWRAaWZhYy5lZHUuYnIxEzARBgNVBAcTClJpbyBCcmFuY28x\nDTALBgNVBAgTBEFjcmUxCzAJBgNVBAYTAkJSMR8wHQYDVQQDExZzaGliYm9sZXRo\nLmlmYWMuZWR1LmJyMB4XDTE1MTAwNjIwNTUyOVoXDTE4MTAwNTIwNTUyOVowga8x\nKTAnBgNVBAoTIElGQUMgLSBJbnN0aXR1dG8gRmVkZXJhbCBkbyBBY3JlMQ4wDAYD\nVQQLEwVEU0dUSTEgMB4GCSqGSIb3DQEJARYRY29yZWRAaWZhYy5lZHUuYnIxEzAR\nBgNVBAcTClJpbyBCcmFuY28xDTALBgNVBAgTBEFjcmUxCzAJBgNVBAYTAkJSMR8w\nHQYDVQQDExZzaGliYm9sZXRoLmlmYWMuZWR1LmJyMIIBIjANBgkqhkiG9w0BAQEF\nAAOCAQ8AMIIBCgKCAQEA4IsqgsWcWHB9bzA2eBTmpB1q1rPh9gtJsBLT5iLkaDm3\nu60f94zj2aUAKkibZJTUfzdwqS4FfYa5I4OFJeBjgB7i7OeHk8GpVd3ZhTEGeQ3t\nBcqoEfYvGjUBd7IWECFwqrzHm+uDNyg62O3UlZjeHeIQ5nIIkXVZg6DRdR0ExTNI\nFWca/Mej0M0ChvZ6TAMfSAL60DUK4rE20399txo/vml/IwG/9GmqymJwsO27m2fT\nqYJGIcnM+/xddmlhNmrdpa7uWSS8K10gV4DX3JEeXAQAuf3bmeAG51Kbh/qAs9dX\nZ/CQd08wBHDIY06yIW3cMEIxGtnxvBfgVc1MIiNOLwIDAQABMA0GCSqGSIb3DQEB\nBQUAA4IBAQAwG40LnqlODWjBoNtt20Ds8rO9NOaOsngoVYdfZ5/1qogsdfAl+br2\n06GrsPgnbN0dfES2pVOuUDUa3eDmpv5ugBZOSZF6m0Zdm0vRgOtlLDABiFHYOtm1\neK20dlzVLCearR72mRnJxQhB+p6hFLJoCdJk+OnrvMDr9qz4v+G2wPp19xMxLe97\nZpc18pLXEiGimtu1mtMwJWFiEPyYnRp8ls0PwAhDMy/ZwdGJ29xtnl9DLfTuBx5c\nilBQMwsWRA4QgnDig1I1Lf2dhEQC6ccEez6yOMSpkH/1Dy95S9G85svsuF2PWRtP\nBN+Ko78mWuJWJz4hCcf0LfkUuWTZHuiu"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.ifac.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.ifac.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.ifac.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.ifac.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.ifac.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.ifac.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.ifac.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.ifac.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifac.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifac.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFAC - Instituto Federal do Acre"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFAC - Instituto Federal do Acre"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFAC - Instituto Federal do Acre"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFAC - Instituto Federal do Acre"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID1DCCArwCAQAwDQYJKoZIhvcNAQEFBQAwga8xKTAnBgNVBAoTIElGQUMgLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkbyBBY3JlMQ4wDAYDVQQLEwVEU0dUSTEgMB4GCSqG\nSIb3DQEJARYRY29yZWRAaWZhYy5lZHUuYnIxEzARBgNVBAcTClJpbyBCcmFuY28x\nDTALBgNVBAgTBEFjcmUxCzAJBgNVBAYTAkJSMR8wHQYDVQQDExZzaGliYm9sZXRo\nLmlmYWMuZWR1LmJyMB4XDTE1MTAwNjIwNTUyOVoXDTE4MTAwNTIwNTUyOVowga8x\nKTAnBgNVBAoTIElGQUMgLSBJbnN0aXR1dG8gRmVkZXJhbCBkbyBBY3JlMQ4wDAYD\nVQQLEwVEU0dUSTEgMB4GCSqGSIb3DQEJARYRY29yZWRAaWZhYy5lZHUuYnIxEzAR\nBgNVBAcTClJpbyBCcmFuY28xDTALBgNVBAgTBEFjcmUxCzAJBgNVBAYTAkJSMR8w\nHQYDVQQDExZzaGliYm9sZXRoLmlmYWMuZWR1LmJyMIIBIjANBgkqhkiG9w0BAQEF\nAAOCAQ8AMIIBCgKCAQEA4IsqgsWcWHB9bzA2eBTmpB1q1rPh9gtJsBLT5iLkaDm3\nu60f94zj2aUAKkibZJTUfzdwqS4FfYa5I4OFJeBjgB7i7OeHk8GpVd3ZhTEGeQ3t\nBcqoEfYvGjUBd7IWECFwqrzHm+uDNyg62O3UlZjeHeIQ5nIIkXVZg6DRdR0ExTNI\nFWca/Mej0M0ChvZ6TAMfSAL60DUK4rE20399txo/vml/IwG/9GmqymJwsO27m2fT\nqYJGIcnM+/xddmlhNmrdpa7uWSS8K10gV4DX3JEeXAQAuf3bmeAG51Kbh/qAs9dX\nZ/CQd08wBHDIY06yIW3cMEIxGtnxvBfgVc1MIiNOLwIDAQABMA0GCSqGSIb3DQEB\nBQUAA4IBAQAwG40LnqlODWjBoNtt20Ds8rO9NOaOsngoVYdfZ5/1qogsdfAl+br2\n06GrsPgnbN0dfES2pVOuUDUa3eDmpv5ugBZOSZF6m0Zdm0vRgOtlLDABiFHYOtm1\neK20dlzVLCearR72mRnJxQhB+p6hFLJoCdJk+OnrvMDr9qz4v+G2wPp19xMxLe97\nZpc18pLXEiGimtu1mtMwJWFiEPyYnRp8ls0PwAhDMy/ZwdGJ29xtnl9DLfTuBx5c\nilBQMwsWRA4QgnDig1I1Lf2dhEQC6ccEez6yOMSpkH/1Dy95S9G85svsuF2PWRtP\nBN+Ko78mWuJWJz4hCcf0LfkUuWTZHuiu"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFAC - Instituto Federal do Acre"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFAC - Instituto Federal do Acre"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifac.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifac.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFAC - Instituto Federal do Acre"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFAC - Instituto Federal do Acre"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://akka-adm.uu.se/shibboleth",
    {
      "entity_id": "https://akka-adm.uu.se/shibboleth",
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 18 4714400"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT Servicedesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@uu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Uppsala universitet"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Uppsala University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uu.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Uppsala universitet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://akka-adm.uu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://akka-adm.uu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://akka-adm.uu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://akka-adm.uu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://akka.uadm.uu.se"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://akka.uadm.uu.se"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Authentication Control - Directory Administration"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Autentisering Kontroll - Katalogadministration"
                  }
                ],
                "logo": [
                  {
                    "text": "https://weblogin.uu.se/idp/UUlogin/img/logga-50.png",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "https://weblogin.uu.se/idp/UUlogin/img/logga-50.png",
                    "lang": "sv",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Uppsala University AKKA"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Uppsala universitets AKKA"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE8TCCAtmgAwIBAgIJAI1GQ30Oxl5yMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\n\t\tBAMTDmFra2EtYWRtLnV1LnNlMB4XDTE0MTIwMTE0NTYxOVoXDTI0MTEyODE0NTYx\n\t\tOVowGTEXMBUGA1UEAxMOYWtrYS1hZG0udXUuc2UwggIiMA0GCSqGSIb3DQEBAQUA\n\t\tA4ICDwAwggIKAoICAQDasvdLAV6nGnaz8CHzDdne7zx2xOGFq8d7tsAMAHb9hRWf\n\t\t6z1UicnDPZ0CYVvw7KAFX9ZwUAXzNjG8OYYwf0kFiteaQVWRAe0nxgmNiUALtiQ2\n\t\tMqE2un7I34Oe7fJJiOdeH4dc8ojNgEbOg2iYhHeZQ3suAj3Q/X00c41b/oqsI8Kw\n\t\tXJSYqjJuhpDXUH9S854LU4via9a8fSDJm5rJus0dFEqwxMnV9zhivBK4h8y1imML\n\t\tCStFmTV0PYuO3fvNksl1DOxszSu7CbePjd8I/HhrP1NXdSma4SIA4yRkFXdszqeu\n\t\tZO94y7GOD37RTq7OLtFl0BjVU2Nyh/bPVg3++hpoBUQgCfJR9tIubDG/Gbt/2xKN\n\t\t9Trx81xdyAJG8PJyZPpXf9m3guXUYucrLYOVGyNQtmX9sO3W0O6x1S1bXUfFXQKD\n\t\tmkIa0g5FMe3pKlofbW8Jte+/Vt9wc/S7xsWIeu/imWPempIe1aoAm3LF+NLanLL/\n\t\tUvh5AuOpZBydjf4xRtlcBII2YlRXb7CkZMJ5MtZWDLQvZnARoFmn+lSRVZds2PDB\n\t\tdkLvM8eNVBK4xKpx/A8QY1aY8rB0zkv+bn61Jb3/Agl1Fzvk9EKoMkqnZT7TzBc0\n\t\tG9Qxz0ZKh3PpY4e2F1N1frO6dSfR1f16jw2nT/c5S6a5QdkkLgEEWZUG7cKTuQID\n\t\tAQABozwwOjAZBgNVHREEEjAQgg5ha2thLWFkbS51dS5zZTAdBgNVHQ4EFgQU7OoY\n\t\tncjP0tZ+I98M2ElTKiERix0wDQYJKoZIhvcNAQEFBQADggIBAD6Jn9oHlZ6Y3cM9\n\t\tbBVkyi5As36MZPJ/T8exSdaAtyLiwxxgUDlfyphl3iWed44tfrEje4x3Lw7LLjPP\n\t\tiEvT2FEswmYUmaukzg8Dr2hTjYVH7EbbRfp7DnxEBCjMtaQdDJ1FQ7J5GiVxVJUc\n\t\tSdYLboCIqEnOqo+UBS+RnoYPLxaJFxkL/FaXBWlmsQ+IG6czLXmxqz+6+J3NFuMr\n\t\thGriPrKioG+Eo1CRHDFNh8+4slQJgFph/+xF3yeRjCUvkwaUewhSYEo81uj3PmZp\n\t\tTXuoleUEs2uDAJaHSnLcm5lQMkTUqw9kBxFlQBY1QSniJ9xmn0KzUjCDbzYx1Z8L\n\t\tzBK4tbogzkXfN38yRH9Ugy1eVckKMfs7JtaMn/8+faujPR+drbvor9wd9QZjG4ln\n\t\tseQwlGOrp7H/L+XsWWBxA70xSifdwAgc6eEXDbShwr1nXiK3nVAJPCyfKsPVGjhq\n\t\tKx9SM9iF2qTkIIirDbOs97aQfWEYifDzd1Pa9YNIXBfukiFV0DQRqquDi9wwJ2la\n\t\twQxuvWJn1uxYorjqziZmk8AKBb8eujRzAhBQ0m/ABKs65/e9jP9OkYUnkrDczKKy\n\t\t1gRrBL6ykWQYLq7cADDmRnaebfQ05flzrTUmY3yA+VT+dXMCRFRCR8ko2PU2G2S5\n\t\tlEhvUG971lBpFbEUfV+hyAu+keKI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://akka-adm.uu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://akka-adm.uu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://akka-adm.uu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://msjc.instructure.com/saml2",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "http://msjc.instructure.com/saml2",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Instructure, Inc"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.instructure.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Instructure, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://msjc.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://msjc.beta.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://msjc.test.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.canvaslms.com/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://canvas.instructure.com/images/canvas/header_canvas_logo@2x.png",
                    "lang": "en",
                    "height": "220",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "220"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.canvaslms.com/policies/privacy-policy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "OEI - Mt. San Jacinto College - Canvas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE8TCCA9mgAwIBAgIJAOBms/PYWcPLMA0GCSqGSIb3DQEBCwUAMIGrMQswCQYD\nVQQGEwJVUzENMAsGA1UECBMEVXRhaDEXMBUGA1UEBxMOU2FsdCBMYWtlIENpdHkx\nGTAXBgNVBAoTEEluc3RydWN0dXJlLCBJbmMxEzARBgNVBAsTCk9wZXJhdGlvbnMx\nIDAeBgNVBAMTF0NhbnZhcyBTQU1MIENlcnRpZmljYXRlMSIwIAYJKoZIhvcNAQkB\nFhNvcHNAaW5zdHJ1Y3R1cmUuY29tMB4XDTE1MDQxNTAxMDAwMFoXDTE3MDQyMjAx\nMDAwMFowgasxCzAJBgNVBAYTAlVTMQ0wCwYDVQQIEwRVdGFoMRcwFQYDVQQHEw5T\nYWx0IExha2UgQ2l0eTEZMBcGA1UEChMQSW5zdHJ1Y3R1cmUsIEluYzETMBEGA1UE\nCxMKT3BlcmF0aW9uczEgMB4GA1UEAxMXQ2FudmFzIFNBTUwgQ2VydGlmaWNhdGUx\nIjAgBgkqhkiG9w0BCQEWE29wc0BpbnN0cnVjdHVyZS5jb20wggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDckDPQGWedlVGC2Z9fn1wNFmN+0IPNi6OSE1nM\nvoTWx2oZlQepaAu4zI5QqOfnV0rW2V1volpoJbu0WelH0DkGzdOEQdWJjAs3nRBf\ny0evxtpg0tK5kIvGsnN6YcD41YmkfWzvwbMf0cEq1Y0wCmymF6XzOUUE4zsi0nhP\nm2Z7WiuongDQdR01UsDN13YcpD/i1JXr3YtkNnJ/a1Kc9OXNycI8M5NVo5QQgdx/\nQ7zAmTk8p9E0ZRthdOQ/PBicWx39mNmBij5KpqCWlHu3NWdgcG8KXSv5atXU8Crd\nTRJ3aGIEN9vBYIHe8MHGCzs1QlRfJmXFMkeUSOTnJJx78rMDAgMBAAGjggEUMIIB\nEDAdBgNVHQ4EFgQUo0WWVlJ1SxZOs11L85ZAuZGyuzEwgeAGA1UdIwSB2DCB1YAU\no0WWVlJ1SxZOs11L85ZAuZGyuzGhgbGkga4wgasxCzAJBgNVBAYTAlVTMQ0wCwYD\nVQQIEwRVdGFoMRcwFQYDVQQHEw5TYWx0IExha2UgQ2l0eTEZMBcGA1UEChMQSW5z\ndHJ1Y3R1cmUsIEluYzETMBEGA1UECxMKT3BlcmF0aW9uczEgMB4GA1UEAxMXQ2Fu\ndmFzIFNBTUwgQ2VydGlmaWNhdGUxIjAgBgkqhkiG9w0BCQEWE29wc0BpbnN0cnVj\ndHVyZS5jb22CCQDgZrPz2FnDyzAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUA\nA4IBAQBV3EmmnzYqYQ5fXNZymG2WaspEW0NeFMhDXa3p3AMIQJbnnU14lR7bqIvf\n/bLW1YE0fw1kSzsw8VrkQp7k1U+kaYA3i5/FQBy2WtqUCVq2GXZA2gs5YD4nvJB/\nF57E//0kEhbATZH9+wJqDkqyIgsrSIlJjiXDth1BppGK8weboPtr9sWV24Ui0+ls\nw16XTsGlnRRO19g+gXKOZp5ApXkDrB+HwZQvZxiCuSgvJlcBzMdxVvWSL+vPtg8Y\nshIKzobIhaQ2MzXHLcxrDhW10YFPwDXh8Tfn5iU9ONsaJivuvVhtDYZD1ZzSoPpm\nq4vYqxxY/6rFJhrCtnlLepSaxlXM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://msjc.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://msjc.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://msjc.beta.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://msjc.beta.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://msjc.test.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://msjc.test.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "OEI - Mt. San Jacinto College - Canvas"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-p11.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-p11.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p11.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p11.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p11.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p11.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p11.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-p11.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-p11.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;p11"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;p11"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-p11.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-p11.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIJAIGzLoUyGaUSMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2xhZG9rMy1wMTEubGFkb2sudW11LnNlMB4XDTE1MDIwOTEyMTQ0NloXDTI1\nMDIwNjEyMTQ0NlowIjEgMB4GA1UEAxMXbGFkb2szLXAxMS5sYWRvay51bXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDXrk4wWzmcoNkKapnM/ojB\nGxDDn+BLaMUo6I65qRTsPirYzgUFJFkBOBVRVWokjyH++eBxXnEPtztf+qUxRkEW\nfIkDByWswJUQitbkN7xrL8My7PVMOojqVb8StXQ+yGQ7PCnTFJeQBpMHHBH9Ezso\ngOd2kChhBGkoulpRipDiU/EnqBrwY0ir2IFrfjvUP3wnUup4Poh1jUZNV5tU0/4Z\nvrjWuYeiJaoOUEFm55AonZ3GZ9gG9k5751B7wJ9lO6GsJJghTcdsxSDDz5uI1jvq\nt+SzvVQYKsGARU5zm+D1fEOAOoMrPOWZXYH0w5F7yOJ7P5cGGGgxWI174VPAjZqn\nAgMBAAGjbTBrMEoGA1UdEQRDMEGCF2xhZG9rMy1wMTEubGFkb2sudW11LnNlhiZo\ndHRwczovL2xhZG9rMy1wMTEubGFkb2sudW11LnNlL2d1aS1zcDAdBgNVHQ4EFgQU\nFzZ4hVFC9OqvX4dokSsmMRQsumswDQYJKoZIhvcNAQEFBQADggEBAKw1aLZSTXaR\n1n/+QvXUmGbGiA91vbO5m6paDKXgGA6mauqxsTOVcjXF88hmPk/sb4gTt3e7+xz1\nakyY+3knvrBlKIL3y7UW/pgwxOSJ6IjN8kus0vffljDCYmdUOXewGlA5XU5krAlz\n3GwZ+hJRP+onain7JsmUlqDW6AodAP7MWON5MtuxSUaz2L68V/HVeeo15yPAALk1\nvOgvT0+gFRQbjAZ6DGJ7e73AQydtfi69jUhRvpKk06L/026riDxOD/1ipCVbZdQ/\nHqwJ5D+Iif4elek44cMW3Jy6RM0LFYFkO79NvUoMFBCFySaM0MJEyYbtXSMw904x\n+vRTRgK1Kdo="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-p11.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p11.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p11.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p11.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p11.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p11.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p11.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-p11.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-p11.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-p11.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/cas.cbs.dk/saml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/cas.cbs.dk/saml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2013-08-09T09:53:44Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/cas.cbs.dk/saml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cbs.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Copenhagen Business School"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Copenhagen Business School"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "cbs.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC5jCCAc4CAQcwDQYJKoZIhvcNAQELBQAwOTE3MDUGA1UEAwwuaHR0cHM6Ly9j\nYXMuY2JzLmRrL3NhbWwvc2FtbDIvaWRwL21ldGFkYXRhLnBocDAeFw0xNTAxMDEw\nMDAwMDBaFw0yNTEyMzEyMzU5NTlaMDkxNzA1BgNVBAMMLmh0dHBzOi8vY2FzLmNi\ncy5kay9zYW1sL3NhbWwyL2lkcC9tZXRhZGF0YS5waHAwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQDHiAwKahBTuI4Z+IJ1rgOeEiCCy3bR9QIe3BpCsejF\nCU5rSzkWANqVuc1PDfp0JdIZhrPXsmDJQMmidPCGPIDQKo+bk+af3+EUFS/I/+35\nsSBX2vf+h1DHvZV9jsznmpSVjp7HZ/WoPWBykWBJO0AOVmzB5zlaqkS36J76+wxe\nrwdpuExVnYSNd73S+AyT/EZ+tXAO+6lQ8FL/YMlJnUkSaSqLSHFy01D2qBNmYRwB\npCS6/dUZyxi0t5j8ghKUD4BHOZVavn65J62cJdXiOcMRyUAIp57GXQrL63KtrjIc\nXddq+CZyZ5t37EdUOIz42joFcy73MFOntynlKEvOw1BJAgMBAAEwDQYJKoZIhvcN\nAQELBQADggEBAAT0qOocn1guY58XBu4c5HlKuYT6ZMQbwCykSOPVArlcuY3ShS1w\nL/0ZKyzRXgT9wm4G+8h+w+ikJI8lxAgsP8PIoA2mrlL+JNOcybFhX6X+1nR3B9n0\nsDi+zbR90rmTW6LrjIlzYxocRs3CgOK+mF0v16WQT1qH50VzKAHnDL+kOUUm0oXh\n9fGXhvGXSmrbRjc3prTcHPJ3KLE2PFMErS4IXMqJcprDoKhT5xOZGlPqv+o4Gywe\nCjj3WKu9uCIkm2kJ4nqqXBuxmWIoRc/Ela6EFqVumg6XkIrP2ILJgVjgNtNMA8Da\nZd682vK8XDpmc0mzv5AP2Bncmy2W1upHBNE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Copenhagen Business School"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Copenhagen Business School"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cbs.dk/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cbs.dk/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Copenhagen Business School"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Copenhagen Business School"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.hrc.ac.uk/idp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Featherstone"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dfeatherstone@hrc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Denis"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Featherstone"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dfeatherstone@hrc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Denis"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.hrc.ac.uk/idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-10-01T15:04:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVAOg3Fb090dB9p32MB4EgjYEXyiOxMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCQxIjAgBgNVBAMTGWZlZGVyYXRlZGFjY2Vzcy5ocmMuYWMudWswHhcNMTMw\n\t\t\t\t\t\tNzA2MDcyMjMxWhcNMzMwNzA2MDcyMjMxWjAkMSIwIAYDVQQDExlmZWRlcmF0ZWRh\n\t\t\t\t\t\tY2Nlc3MuaHJjLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tkoOul030k6LhcQ2zW3YErb4osJQwvj7gskGciL2HdKH/BKI1EFOqfayB3QKS7cJ6\n\t\t\t\t\t\tekdeHdkhhwamDnXGW2IZO3xaeGXiebT9vy/m3bi3VScUZsydhCC5vZ6vKJHqA2aN\n\t\t\t\t\t\tqWPH6uNqS9D9X+BXQ1Yaa0zaB671M1gbZ9TwCP473+jtBjRh3b5LaNh41MbOJ4xk\n\t\t\t\t\t\t7UyQvG1Q2tiO1+0OfBnjen3cKnL2u8HrKXq0aZFV1FXmL/S/C7RSlXp3+FX3+VZa\n\t\t\t\t\t\tPn/jlBBQHn7j8hEoQ3KkrnO7PFIiD4szmm40ubKk9m1iR3JKu8wsP/wkFll1MCxq\n\t\t\t\t\t\t3QDeoo8c6I/RHgIa7zzHgQIDAQABo3kwdzBWBgNVHREETzBNghlmZWRlcmF0ZWRh\n\t\t\t\t\t\tY2Nlc3MuaHJjLmFjLnVrhjBodHRwczovL2ZlZGVyYXRlZGFjY2Vzcy5ocmMuYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFB7hyBviehtzOyJTo/85hiqrmtaS\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQCPwEmDe/HVq9orxzy9lS7qYg4tte2dqJHpsLD+\n\t\t\t\t\t\tAxcI5Uamg1/7IbuG5P6r9gPgdVzB1qo5DWaXbJSo8wY+003v2kvdXYK2x0/85DZ4\n\t\t\t\t\t\tdtkftolCrgwGJqeEePUV4TWCoihdSjaqr7/0Qe27nZi83hNjy3OipfMm/lDZQDgB\n\t\t\t\t\t\t3mIg0IbbBXVh4BjnnaJZqGj7qqhCJduCaU0hUK1cvb31Po/Ub+8fqmobstCFxcw4\n\t\t\t\t\t\t6YExHZsPvcbWhVk8bZEn1bBKjXlozIL46pATE/ApTj955UAocZs/0HeTbPTszOjM\n\t\t\t\t\t\t2+lio+vkIsRiGCzd1QgB/JmMbZ3I0016UR31P7+M5AaOiJ0s"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hrc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://federatedaccess.hrc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://federatedaccess.hrc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federatedaccess.hrc.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federatedaccess.hrc.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://federatedaccess.hrc.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://federatedaccess.hrc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federatedaccess.hrc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://federatedaccess.hrc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federatedaccess.hrc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://federatedaccess.hrc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://federatedaccess.hrc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hrc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVAOg3Fb090dB9p32MB4EgjYEXyiOxMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCQxIjAgBgNVBAMTGWZlZGVyYXRlZGFjY2Vzcy5ocmMuYWMudWswHhcNMTMw\n\t\t\t\t\t\tNzA2MDcyMjMxWhcNMzMwNzA2MDcyMjMxWjAkMSIwIAYDVQQDExlmZWRlcmF0ZWRh\n\t\t\t\t\t\tY2Nlc3MuaHJjLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tkoOul030k6LhcQ2zW3YErb4osJQwvj7gskGciL2HdKH/BKI1EFOqfayB3QKS7cJ6\n\t\t\t\t\t\tekdeHdkhhwamDnXGW2IZO3xaeGXiebT9vy/m3bi3VScUZsydhCC5vZ6vKJHqA2aN\n\t\t\t\t\t\tqWPH6uNqS9D9X+BXQ1Yaa0zaB671M1gbZ9TwCP473+jtBjRh3b5LaNh41MbOJ4xk\n\t\t\t\t\t\t7UyQvG1Q2tiO1+0OfBnjen3cKnL2u8HrKXq0aZFV1FXmL/S/C7RSlXp3+FX3+VZa\n\t\t\t\t\t\tPn/jlBBQHn7j8hEoQ3KkrnO7PFIiD4szmm40ubKk9m1iR3JKu8wsP/wkFll1MCxq\n\t\t\t\t\t\t3QDeoo8c6I/RHgIa7zzHgQIDAQABo3kwdzBWBgNVHREETzBNghlmZWRlcmF0ZWRh\n\t\t\t\t\t\tY2Nlc3MuaHJjLmFjLnVrhjBodHRwczovL2ZlZGVyYXRlZGFjY2Vzcy5ocmMuYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFB7hyBviehtzOyJTo/85hiqrmtaS\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQCPwEmDe/HVq9orxzy9lS7qYg4tte2dqJHpsLD+\n\t\t\t\t\t\tAxcI5Uamg1/7IbuG5P6r9gPgdVzB1qo5DWaXbJSo8wY+003v2kvdXYK2x0/85DZ4\n\t\t\t\t\t\tdtkftolCrgwGJqeEePUV4TWCoihdSjaqr7/0Qe27nZi83hNjy3OipfMm/lDZQDgB\n\t\t\t\t\t\t3mIg0IbbBXVh4BjnnaJZqGj7qqhCJduCaU0hUK1cvb31Po/Ub+8fqmobstCFxcw4\n\t\t\t\t\t\t6YExHZsPvcbWhVk8bZEn1bBKjXlozIL46pATE/ApTj955UAocZs/0HeTbPTszOjM\n\t\t\t\t\t\t2+lio+vkIsRiGCzd1QgB/JmMbZ3I0016UR31P7+M5AaOiJ0s"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hertford Regional College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hrc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hertford Regional College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibsles.brunel.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fraser"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alex.fraser@brunel.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fraser"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alex.fraser@brunel.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibsles.brunel.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIJAPWdUCwLL6STMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\n\t\t\t\t\t\tBAMTFXNoaWJzbGVzLmJydW5lbC5hYy51azAeFw0xMjA2MDExMTMwMDFaFw0yMjA2\n\t\t\t\t\t\tMDExMTMwMDFaMCAxHjAcBgNVBAMTFXNoaWJzbGVzLmJydW5lbC5hYy51azCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANeoXX34/IQVQfUnXhGeOIv+casO\n\t\t\t\t\t\t4UTpWfR7m1jGvZwH29IDkD/yp1smabJz4uxHaMfgeN3KdjOThvkblPvElwuddnX0\n\t\t\t\t\t\tql6+zeJ0W/QaNU0dxgGzrUnaUcVsqmBH3onrR63dr94opNzYDw2SIV1HAhiUKCIM\n\t\t\t\t\t\tA5zOAIEMTfSiS8xLxgQ8zR13tLPsq8TdRPoHDdqpbQFZOhxCD804NN3MvsN0LUnP\n\t\t\t\t\t\tVvJ939m3aUpZbwjLlQsMgRBdkV7WfUxGggCfGgLMfuT8IoN555b0NzzsHdjIdCzi\n\t\t\t\t\t\tjjpogH7HZYeIRn//qWCwz0Ulg6d/wpzyWW/YQhlkXiiP+LCRWbPtIBr4bskCAwEA\n\t\t\t\t\t\tAaNxMG8wTgYDVR0RBEcwRYIVc2hpYnNsZXMuYnJ1bmVsLmFjLnVrhixodHRwczov\n\t\t\t\t\t\tL3NoaWJzbGVzLmJydW5lbC5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n\t\t\t\t\t\tXp7b4ZI5lsrpyW2A+MmkBO+D/70wDQYJKoZIhvcNAQEFBQADggEBALimmRmPVvsh\n\t\t\t\t\t\tgn3C/lssDcncpnnrNjhuMgjCkeO2Vh9bvDW4WDRgvNPsR2WXoRGFrFYB8DExh6Lk\n\t\t\t\t\t\t+J92k7BKQtPriDYh+NtYxqc9z1pJxp0AIzh9DohkyY0QXllLjJ+GM5ddt0iRMAvJ\n\t\t\t\t\t\t3tPbv2Kk6sZYIa2bgmQJiyjnDLFKHjihJk8cLzbWQ84NMZJmDyub+SpoEcFEcaZ7\n\t\t\t\t\t\t0s54t2iEQpQ9z0JCYwZSE6JcBB0uxqxLEO79a2VJFTeQlf/u/0Urd6kVpprqh8rZ\n\t\t\t\t\t\t84p18Y4QJKlwEQhkkqg8PykdSAHzaIDTN9N6qJjfdFSKLp0DRHWpeDqnbhlc2+8H\n\t\t\t\t\t\tNySru11ACLA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brunel.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibsles.brunel.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibsles.brunel.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibsles.brunel.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibsles.brunel.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibsles.brunel.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibsles.brunel.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibsles.brunel.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibsles.brunel.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brunel.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIJAPWdUCwLL6STMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\n\t\t\t\t\t\tBAMTFXNoaWJzbGVzLmJydW5lbC5hYy51azAeFw0xMjA2MDExMTMwMDFaFw0yMjA2\n\t\t\t\t\t\tMDExMTMwMDFaMCAxHjAcBgNVBAMTFXNoaWJzbGVzLmJydW5lbC5hYy51azCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANeoXX34/IQVQfUnXhGeOIv+casO\n\t\t\t\t\t\t4UTpWfR7m1jGvZwH29IDkD/yp1smabJz4uxHaMfgeN3KdjOThvkblPvElwuddnX0\n\t\t\t\t\t\tql6+zeJ0W/QaNU0dxgGzrUnaUcVsqmBH3onrR63dr94opNzYDw2SIV1HAhiUKCIM\n\t\t\t\t\t\tA5zOAIEMTfSiS8xLxgQ8zR13tLPsq8TdRPoHDdqpbQFZOhxCD804NN3MvsN0LUnP\n\t\t\t\t\t\tVvJ939m3aUpZbwjLlQsMgRBdkV7WfUxGggCfGgLMfuT8IoN555b0NzzsHdjIdCzi\n\t\t\t\t\t\tjjpogH7HZYeIRn//qWCwz0Ulg6d/wpzyWW/YQhlkXiiP+LCRWbPtIBr4bskCAwEA\n\t\t\t\t\t\tAaNxMG8wTgYDVR0RBEcwRYIVc2hpYnNsZXMuYnJ1bmVsLmFjLnVrhixodHRwczov\n\t\t\t\t\t\tL3NoaWJzbGVzLmJydW5lbC5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n\t\t\t\t\t\tXp7b4ZI5lsrpyW2A+MmkBO+D/70wDQYJKoZIhvcNAQEFBQADggEBALimmRmPVvsh\n\t\t\t\t\t\tgn3C/lssDcncpnnrNjhuMgjCkeO2Vh9bvDW4WDRgvNPsR2WXoRGFrFYB8DExh6Lk\n\t\t\t\t\t\t+J92k7BKQtPriDYh+NtYxqc9z1pJxp0AIzh9DohkyY0QXllLjJ+GM5ddt0iRMAvJ\n\t\t\t\t\t\t3tPbv2Kk6sZYIa2bgmQJiyjnDLFKHjihJk8cLzbWQ84NMZJmDyub+SpoEcFEcaZ7\n\t\t\t\t\t\t0s54t2iEQpQ9z0JCYwZSE6JcBB0uxqxLEO79a2VJFTeQlf/u/0Urd6kVpprqh8rZ\n\t\t\t\t\t\t84p18Y4QJKlwEQhkkqg8PykdSAHzaIDTN9N6qJjfdFSKLp0DRHWpeDqnbhlc2+8H\n\t\t\t\t\t\tNySru11ACLA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Brunel University (Old)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.brunel.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Brunel University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://srv-fii.insa-toulouse.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support-federation@insa-toulouse.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://srv-fii.insa-toulouse.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-02-24T14:12:00Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://srv-fii.insa-toulouse.fr/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://srv-fii.insa-toulouse.fr/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://srv-fii.insa-toulouse.fr/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://srv-fii.insa-toulouse.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://srv-fii.insa-toulouse.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://srv-fii.insa-toulouse.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "insa-toulouse.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.insa-toulouse.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "People from INSA Toulouse"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Les gens de l'INSA de Toulouse"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INSA de Toulouse"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INSA de Toulouse"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIVAIc+7dsfBy6txSFiZjLaZo7oHPHjMA0GCSqGSIb3DQEB\nBQUAMCMxITAfBgNVBAMTGHNydi1maWkuaW5zYS10b3Vsb3VzZS5mcjAeFw0xNDAz\nMTEwOTIyNDNaFw0zNDAzMTEwOTIyNDNaMCMxITAfBgNVBAMTGHNydi1maWkuaW5z\nYS10b3Vsb3VzZS5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK74\nhluqPdWzcHqS+sJ7gMMK/AaaY5OTqquhY3ut8EdnWOhLrpdJUmAP67NrCsX7vnlj\nOJJvsPwITMeeuZxYPohw7+0/y/VVjluVM9u0r6QPkNYbUO4HAjZf6JOeSORtD6iq\nJCuHdURPtdx+AALX+1aM/EaX+w9dsq/xDR0aPluAyb8zHT9WYX2C8bFxGqZfayF7\n55F0fJY4YsI2WD0AnG6/DAH1/MpgW/x3rXYE3ofA1aHJTG9m2rhM5a6c2mQ1lsB0\nL4ThOBOeDm+/GPc7HsB3EwK3SJKQEPIZFpHl2HOiAbmp8ZuA9bIjvjFk+2aaJOla\nUVKxNJeBA29jlsdxnzkCAwEAAaN3MHUwVAYDVR0RBE0wS4IYc3J2LWZpaS5pbnNh\nLXRvdWxvdXNlLmZyhi9odHRwczovL3Nydi1maWkuaW5zYS10b3Vsb3VzZS5mci9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUQFnEXfdD1G/V0Zf4ArD2VSGlkcAwDQYJ\nKoZIhvcNAQEFBQADggEBAFmmxVsYiBe4u4MwR/vTomhTH6Y6rUTsbi55CBZJo0ki\nvDEeRGdAG/odez6Gx3HvfNQdGAkkXoVqzPM72suXTe3QbNwQ6p6Kfw3vlOb8Bxu+\nL4oGvqtYyKdsmZaOq8uHFSE7pmz5u86npm+5WF2EIISiNgh7V15avMGrXE3fQ+0C\nsSAKnwk3ZDiTJMkOC8JKJSxyHKmdG7tiqdhIxOoGnEa/oPdWgsVTV63xEVXfDHh3\nvVTEoXVyPovJRJieZVJDz0BmEE88Q/pDCAuhUQOCdeC0DX0uN8WrL9oI9WuGbzeD\ndQvqnCF/78eNFMZHSDdbRWgVyZp20ytlaxRlw1cKQ5w="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INSA de Toulouse"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.insa-toulouse.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INSA de Toulouse"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.centralsussex.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.centralsussex.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/centralsussex.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/centralsussex.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "centralsussex.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Central Sussex College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.centralsussex.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.iuav.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ghezzo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pier@iuav.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Piergiorgio"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@iuav.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.iuav.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2010-07-01T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAOjXzyapswcd6xsf69yjpd4te2HWMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2lkcC5pdWF2Lml0MB4XDTA5MTEzMDAwMTg0OVoXDTI5\nMTEzMDAwMTg0OVowFjEUMBIGA1UEAxMLaWRwLml1YXYuaXQwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCYSifc+LKcPDkWNaSMzsNea55hJnc78G3p0p4I\niaN79ZcmSMbYDigT7uCN0jqJQhhPu42Bs3zJnwVJhVR8Ag0qIojNMHfsD9p5kZzp\nj2TZ+bcREYQGIsqXy8XfP5UVrw8sV1KN+Xc+2iwNZ3fC7N1JMpDwUTphhHGw1mF3\nk18DjNlO18AiXMvog0FbrvfsqYw9D5vsMfyVnQDw+OX9tMoOLZExZTbEt+bGzjv6\ngStOQADpRKlELSMRWsu09aup+YPDrYTvmIY2LaVtbQidi7fA/tJwr94EKrsdDp+7\nOjsPK45SBRjGdwhdEnnR3pSN3k8jX+7UngY7BPtzEmEblInzAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2lkcC5pdWF2Lml0hiJodHRwczovL2lkcC5pdWF2Lml0L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBQYUwByp5fGRll5VxLUjI76AmM8sjANBgkqhkiG\n9w0BAQUFAAOCAQEAW71PMrdGAbPyJowc6isgMKRAaOesZAn0PiZBG4zB1xZzeJ9S\nWqtCGAunE7Eas7YLFIiAHg+ddonZQUyJHUQPKB9ml7XfAgLUVeT+gPJs2TuL00aj\ncLzbQ/PAYKLAUbZBmDuaSsuV/CyTivBakD6I2p6MxN84GLEmBf/27LYDGbtTOS+i\nUfwqWE4i9xF85M+YZJxfoWHGh+C3L2nuTKuZkZHSVKqpTdoYN47ciumatANtH+H0\nuqj/sHDHt3o0KgBhWw4+MJFAelDhald9bb9/V2E3vZDuV8RSVn1kDIzStdarkhtW\ndgmwVYFjA3Uc77ULxhwfAy4wsbDrXopR4Hxfsg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iuav.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.iuav.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.iuav.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "response_location": "https://idp.iuav.it/idp/profile/SAML2/Redirect/SLO",
              "location": "https://idp.iuav.it/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "response_location": "https://idp.iuav.it/idp/profile/SAML2/POST/SLO",
              "location": "https://idp.iuav.it/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.iuav.it/idp/profile:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.iuav.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.iuav.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.iuav.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.iuav.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.iuav.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iuav.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.iuav.it/idem.html"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.iuav.it/English-Ve/About-Iuav/Iuav-profi/index.htm"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for University IUAV Venezia users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti di Universit\u00e0 IUAV di Venezia"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University IUAV Venezia"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 IUAV di Venezia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAOjXzyapswcd6xsf69yjpd4te2HWMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2lkcC5pdWF2Lml0MB4XDTA5MTEzMDAwMTg0OVoXDTI5\nMTEzMDAwMTg0OVowFjEUMBIGA1UEAxMLaWRwLml1YXYuaXQwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCYSifc+LKcPDkWNaSMzsNea55hJnc78G3p0p4I\niaN79ZcmSMbYDigT7uCN0jqJQhhPu42Bs3zJnwVJhVR8Ag0qIojNMHfsD9p5kZzp\nj2TZ+bcREYQGIsqXy8XfP5UVrw8sV1KN+Xc+2iwNZ3fC7N1JMpDwUTphhHGw1mF3\nk18DjNlO18AiXMvog0FbrvfsqYw9D5vsMfyVnQDw+OX9tMoOLZExZTbEt+bGzjv6\ngStOQADpRKlELSMRWsu09aup+YPDrYTvmIY2LaVtbQidi7fA/tJwr94EKrsdDp+7\nOjsPK45SBRjGdwhdEnnR3pSN3k8jX+7UngY7BPtzEmEblInzAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2lkcC5pdWF2Lml0hiJodHRwczovL2lkcC5pdWF2Lml0L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBQYUwByp5fGRll5VxLUjI76AmM8sjANBgkqhkiG\n9w0BAQUFAAOCAQEAW71PMrdGAbPyJowc6isgMKRAaOesZAn0PiZBG4zB1xZzeJ9S\nWqtCGAunE7Eas7YLFIiAHg+ddonZQUyJHUQPKB9ml7XfAgLUVeT+gPJs2TuL00aj\ncLzbQ/PAYKLAUbZBmDuaSsuV/CyTivBakD6I2p6MxN84GLEmBf/27LYDGbtTOS+i\nUfwqWE4i9xF85M+YZJxfoWHGh+C3L2nuTKuZkZHSVKqpTdoYN47ciumatANtH+H0\nuqj/sHDHt3o0KgBhWw4+MJFAelDhald9bb9/V2E3vZDuV8RSVn1kDIzStdarkhtW\ndgmwVYFjA3Uc77ULxhwfAy4wsbDrXopR4Hxfsg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 IUAV di Venezia"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University IUAV Venezia"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iuav.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iuav.it/English-Ve/About-Iuav/Iuav-profi/index.htm"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 IUAV di Venezia"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University IUAV Venezia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.nvt.resultat.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.nvt.resultat.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.nvt.resultat.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.nvt.resultat.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.nvt.resultat.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.nvt.resultat.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.nvt.resultat.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.nvt.resultat.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.nvt.resultat.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemstod f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.nvt.resultat.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.nvt.resultat.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.nvt.resultat.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.nvt.resultat.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.nvt.resultat.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIJAOBmjGBKkXmJMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\nBAMTGXd3dy5udnQucmVzdWx0YXQubGFkb2suc2UwHhcNMTUwNTI2MTEyNDQ4WhcN\nMjUwNTIzMTEyNDQ4WjAkMSIwIAYDVQQDExl3d3cubnZ0LnJlc3VsdGF0LmxhZG9r\nLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsXGFrAEbujHONith\nsv099ChkLXB5Z4JxVLdI85QuNFg+gB3Ts+uVYArd70POCEAk1pHQW0FImuC+vjBb\nU3yHNCuoa/+eZj4rS/KxdAkMKiyG3JpjcSEN3XnyUnFCUvY0j3sUlvn/s1mzUH2l\nP2pWAL6jufF5heRuJ8P13L2qErvgEYpfdx4tq7sHaLNip7eV76+PKuFQRcbbqcJG\nzJe8C1q5AEZnMriKaunsQZafBbjNkBzo/465dzj9HzcrLdMTSyCSEvfxVs+4xLdu\nqC0EAgRFZkp+G1li8TNb+c/RqFpKQlV0exC9iqa70oLB9w0ILQHP66arcZ2ssp8X\n8qPD8wIDAQABo3EwbzBOBgNVHREERzBFghl3d3cubnZ0LnJlc3VsdGF0LmxhZG9r\nLnNlhihodHRwczovL3d3dy5udnQucmVzdWx0YXQubGFkb2suc2UvZ3VpLXNwMB0G\nA1UdDgQWBBRxB1TSvrBmJ6MkVkL8f+tdJDt5BjANBgkqhkiG9w0BAQUFAAOCAQEA\nTrF0gNXSuKBVwhviRdC8oidwFawFVjutQIUVI7Djhr0pccurVJ8RaGsG5eFo9FN6\njP8/MFzDA7OH1CLnuzkY7tgCg8aZ2VrvzAIX04xRtou4RkKaxTvFCk7tLiFl5ZqF\n7zILdc9qpOYVUV4cBH+rTT2MjV5HDaW4H2ESVnUKnYjxnylifR/lSRJpxSrrdJYY\nCoNyDjHVtvFxodx6VJOAjQHCC5f+bANAi9rRD0R3SFnwq5cMJapCjWwGAhgmNsgv\nN69OreDS1oYSb4phj9p+O9ujTbaiVoCzG3xZHLS18ND8/pt6JQfVoGEhqj/JfVtK\nJD1lKrYfwjzdJZKXxLSpeQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.nvt.resultat.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.nvt.resultat.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.nvt.resultat.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.nvt.resultat.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.nvt.resultat.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.nvt.resultat.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.nvt.resultat.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.nvt.resultat.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.nvt.resultat.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.nvt.resultat.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://login.ufrgs.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Everton Foscarini"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "foscarini@cpd.ufrgs.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.ufrgs.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID/jCCAuYCAQAwDQYJKoZIhvcNAQEFBQAwgcQxMjAwBgNVBAoTKVVuaXZlcnNp\nZGFkZSBGZWRlcmFsIGRvIFJpbyBHcmFuZGUgZG8gU3VsMQwwCgYDVQQLEwNDUEQx\nJzAlBgkqhkiG9w0BCQEWGHJ1aS5yaWJlaXJvQGNwZC51ZnJncy5icjEVMBMGA1UE\nBxMMUG9ydG8gQWxlZ3JlMRowGAYDVQQIExFSaW8gR3JhbmRlIGRvIFN1bDELMAkG\nA1UEBhMCQlIxFzAVBgNVBAMTDmxvZ2luLnVmcmdzLmJyMB4XDTE2MDMyMzIxMzcz\nOVoXDTE5MDMyMzIxMzczOVowgcQxMjAwBgNVBAoTKVVuaXZlcnNpZGFkZSBGZWRl\ncmFsIGRvIFJpbyBHcmFuZGUgZG8gU3VsMQwwCgYDVQQLEwNDUEQxJzAlBgkqhkiG\n9w0BCQEWGHJ1aS5yaWJlaXJvQGNwZC51ZnJncy5icjEVMBMGA1UEBxMMUG9ydG8g\nQWxlZ3JlMRowGAYDVQQIExFSaW8gR3JhbmRlIGRvIFN1bDELMAkGA1UEBhMCQlIx\nFzAVBgNVBAMTDmxvZ2luLnVmcmdzLmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEA28lpEXWrRpcro36kwHsH8A+1kugDsTrAOiGi0GGa5rps1/SRrM3x\nvYJ1BB3qRe1npWsJ125uYZ6lj0EyOE/5yGMfpryKfq0fhsXE4UIlih08Qr+52AUw\nF1aZZPrSmrTg+0milZ7fWO4iiivtDANiEaFNlDP11ypNuoEjRlv5NFbf6NwcwIlx\nW0plyz06eUjXP/9wr0BX1cdkd7EJRj+IjYWIp6OeMy1j/1MNp7iwrCBJgY6aW2Ir\nMTshZU9vrjAG2r04fksEkp3yHAXEYKnFA1BPdNz6E2GPHCzIQi17PlhrIRFnxy4E\nSfaNDsPDbPeI5FvKmJAHMIFOO0tHpaND+QIDAQABMA0GCSqGSIb3DQEBBQUAA4IB\nAQBnKJ9c4Rhroc5I7TM1THvQh65JIynlnXjW3Y8xvq213mpHj9N40KANXZ/nzIKC\nhrxmuFJzQ58ylEq5OHy8yylPp8vGOqv7ATpckbh5wiTtfO6SYyX7dPdApxSXBQ6T\nE5pd4xhILcoBmaM3BhF/g/sBJbpXetKnsAYIQ4dANJI1l/xcOdPCB7qppkgEvrRP\nh6eGFBJcSELUyVd+D4NE5H0m7SkuOkSkqg+3XcljYfjJbMFNLqcTJdE77RKpKggW\nvRvJ63diY18yTbcJJbacsuwUnY8tgbnWaxgHtZzaHBiJqJIh7vZLAoQxyUMoENof\nd/IbBMgj8Fg+rkrDM0GRRlHh"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufrgs.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.ufrgs.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.ufrgs.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.ufrgs.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.ufrgs.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.ufrgs.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.ufrgs.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.ufrgs.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.ufrgs.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufrgs.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufrgs.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufrgs.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFRGS - Universidade Federal do Rio Grande do Sul"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFRGS - Universidade Federal do Rio Grande do Sul"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFRGS - Universidade Federal do Rio Grande do Sul"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFRGS - Universidade Federal do Rio Grande do Sul"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID/jCCAuYCAQAwDQYJKoZIhvcNAQEFBQAwgcQxMjAwBgNVBAoTKVVuaXZlcnNp\nZGFkZSBGZWRlcmFsIGRvIFJpbyBHcmFuZGUgZG8gU3VsMQwwCgYDVQQLEwNDUEQx\nJzAlBgkqhkiG9w0BCQEWGHJ1aS5yaWJlaXJvQGNwZC51ZnJncy5icjEVMBMGA1UE\nBxMMUG9ydG8gQWxlZ3JlMRowGAYDVQQIExFSaW8gR3JhbmRlIGRvIFN1bDELMAkG\nA1UEBhMCQlIxFzAVBgNVBAMTDmxvZ2luLnVmcmdzLmJyMB4XDTE2MDMyMzIxMzcz\nOVoXDTE5MDMyMzIxMzczOVowgcQxMjAwBgNVBAoTKVVuaXZlcnNpZGFkZSBGZWRl\ncmFsIGRvIFJpbyBHcmFuZGUgZG8gU3VsMQwwCgYDVQQLEwNDUEQxJzAlBgkqhkiG\n9w0BCQEWGHJ1aS5yaWJlaXJvQGNwZC51ZnJncy5icjEVMBMGA1UEBxMMUG9ydG8g\nQWxlZ3JlMRowGAYDVQQIExFSaW8gR3JhbmRlIGRvIFN1bDELMAkGA1UEBhMCQlIx\nFzAVBgNVBAMTDmxvZ2luLnVmcmdzLmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEA28lpEXWrRpcro36kwHsH8A+1kugDsTrAOiGi0GGa5rps1/SRrM3x\nvYJ1BB3qRe1npWsJ125uYZ6lj0EyOE/5yGMfpryKfq0fhsXE4UIlih08Qr+52AUw\nF1aZZPrSmrTg+0milZ7fWO4iiivtDANiEaFNlDP11ypNuoEjRlv5NFbf6NwcwIlx\nW0plyz06eUjXP/9wr0BX1cdkd7EJRj+IjYWIp6OeMy1j/1MNp7iwrCBJgY6aW2Ir\nMTshZU9vrjAG2r04fksEkp3yHAXEYKnFA1BPdNz6E2GPHCzIQi17PlhrIRFnxy4E\nSfaNDsPDbPeI5FvKmJAHMIFOO0tHpaND+QIDAQABMA0GCSqGSIb3DQEBBQUAA4IB\nAQBnKJ9c4Rhroc5I7TM1THvQh65JIynlnXjW3Y8xvq213mpHj9N40KANXZ/nzIKC\nhrxmuFJzQ58ylEq5OHy8yylPp8vGOqv7ATpckbh5wiTtfO6SYyX7dPdApxSXBQ6T\nE5pd4xhILcoBmaM3BhF/g/sBJbpXetKnsAYIQ4dANJI1l/xcOdPCB7qppkgEvrRP\nh6eGFBJcSELUyVd+D4NE5H0m7SkuOkSkqg+3XcljYfjJbMFNLqcTJdE77RKpKggW\nvRvJ63diY18yTbcJJbacsuwUnY8tgbnWaxgHtZzaHBiJqJIh7vZLAoQxyUMoENof\nd/IbBMgj8Fg+rkrDM0GRRlHh"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFRGS - Universidade Federal do Rio Grande do Sul"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFRGS - Universidade Federal do Rio Grande do Sul"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufrgs.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufrgs.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFRGS - Universidade Federal do Rio Grande do Sul"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFRGS - Universidade Federal do Rio Grande do Sul"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth2sp-test.sams2.oup.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ShibbolethSupport@oup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ShibbolethSupport@oup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth2sp-test.sams2.oup.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-03-18T15:49:21Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "OUP SAMS2 test Shibboleth 2 SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Oxford"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp-test.sams2.oup.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp-test.sams2.oup.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp-test.sams2.oup.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp-test.sams2.oup.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp-test.sams2.oup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth2sp-test.sams2.oup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth2sp-test.sams2.oup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID6DCCAtCgAwIBAgIJANEE6ny6uMMRMA0GCSqGSIb3DQEBBQUAMHAxCzAJBgNV\n\t\t\t\t\t\tBAYTAlVLMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIwEAYD\n\t\t\t\t\t\tVQQKEwlzZW1hbnRpY28xKTAnBgNVBAMTIHNoaWJib2xldGgyc3AtdGVzdC5zYW1z\n\t\t\t\t\t\tMi5vdXAuY29tMB4XDTE2MDMxNTE1MzYxMVoXDTM2MDMxMDE1MzYxMVowcDELMAkG\n\t\t\t\t\t\tA1UEBhMCVUsxDzANBgNVBAgTBlN1c3NleDERMA8GA1UEBxMIQnJpZ2h0b24xEjAQ\n\t\t\t\t\t\tBgNVBAoTCXNlbWFudGljbzEpMCcGA1UEAxMgc2hpYmJvbGV0aDJzcC10ZXN0LnNh\n\t\t\t\t\t\tbXMyLm91cC5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCzKaMT\n\t\t\t\t\t\tbS0KiQLkgAL7xkQzCcwQo07G4XQre2+XPaHa+6sYkjzsFzJ7e0Ze0rwDm2O4zM5W\n\t\t\t\t\t\tO96xfKSdNpLPCKQadGTBb9mM2mZW71cCHy9M77l7gd9fUVUBc87K6id8wraRVa2u\n\t\t\t\t\t\t6vpxs5zwW9j7Gbv5XMFnDBFfXDLo13y7A0mQVTnu0g1gHc7RSLK34FW1Cv9frBJw\n\t\t\t\t\t\tYgzVebtpqLKufcZlnUKsniZPH9bRbyMQT+ZTOS1yOQj0JL4zSRGfFKZpKGMEdDPw\n\t\t\t\t\t\t4/mZ6CtDG9Cifqv8JEeVgAtqFH4eGSkjwKe4P+o1vZYLYazyu72gBG5TI8vn3z6s\n\t\t\t\t\t\toP8msbk13vQmkHbHAgMBAAGjgYQwgYEwYAYDVR0RBFkwV4Igc2hpYmJvbGV0aDJz\n\t\t\t\t\t\tcC10ZXN0LnNhbXMyLm91cC5jb22GM2h0dHBzOi8vc2hpYmJvbGV0aDJzcC10ZXN0\n\t\t\t\t\t\tLnNhbXMyLm91cC5jb20vc2hpYmJvbGV0aDAdBgNVHQ4EFgQUDz7rrZNE624AivNV\n\t\t\t\t\t\tDq1QoiPfUu8wDQYJKoZIhvcNAQEFBQADggEBAIDklJiPGaTvX9RnL255TUvGoJUo\n\t\t\t\t\t\t02jdqlMkK7BL+cFRlhS9C9GYaOMRQSIbwPD8eU7U2vqsS3Zz2bTLTL+oOn6Yvif1\n\t\t\t\t\t\tZD3PjuaBpES/SGqMXInrugn8d7tBkMdSaNo5KJw4mJ9rROOVF7OtSY+fucHkIA4G\n\t\t\t\t\t\tjQnBG9kpb6bqvSp6bohBEN2FwK76Imgkxv89jW0eLhx4R1IxTxGx9VqW+12hPEsc\n\t\t\t\t\t\t/fcE+OPO0R3z4fEP9zYI58KoazgI7QwYCyObT117ACShSVXbwtHzVa+wabUBU7r7\n\t\t\t\t\t\tcxQkl4oHEJe5OMQLLIlOkRgAFVe8e3UsWhSICCOSwB8SgQVHxrrJJ1UnOxw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp-test.sams2.oup.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp-test.sams2.oup.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp-test.sams2.oup.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp-test.sams2.oup.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp-test.sams2.oup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth2sp-test.sams2.oup.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp-test.sams2.oup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth2sp-test.sams2.oup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth2sp-test.sams2.oup.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth2sp-test.sams2.oup.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ufpr.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Antonio Rodrigues Barros"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "antonio@ufpr.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ufpr.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC1jCCAb4CAQAwDQYJKoZIhvcNAQEFBQAwMTEMMAoGA1UECxMDQ0NFMQswCQYD\nVQQGEwJCUjEUMBIGA1UEAxMLaWRwLnVmcHIuYnIwHhcNMTUwMzEwMTcyMjA5WhcN\nMjAwMzA4MTcyMjA5WjAxMQwwCgYDVQQLEwNDQ0UxCzAJBgNVBAYTAkJSMRQwEgYD\nVQQDEwtpZHAudWZwci5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAOFIgUDLLgOWy8WFpJ3WvcKJSOn/+STEWV95ma2PmAsa6lOT59AXXyPvUagrg7C8\nvzZQj8pgTkx7a2W54Qm8ETF3v1vLh8EwTpIAN0dz1K7XDWVy2fizoySj27GP1Zxu\nsF+dxt2PzRPpbzwQMf5XviiIIQSXEEt8E55ckK4yNz25JpqxsgxYwr7sTFWXPt3y\nWXu6a/kBfzi2mrxYORz7t9w/36nkYy1xOt08q8vYK9IWaufP558pvpw05PQHTnwP\n64c9vQ9qwDr7Eek7dXelJtJ1x/wiqW8kq+grx1yHipDq5kP5HPyu7Fo+kEdwl1mT\nqGTSBz7trGMRaj/z0Ilq4nMCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAcMCPPhKd\nhmAOGj9QRCYyF1pAImTtH/UyJv5wlgnJ+V2AOysRbac7eyISNZVPUSnXjHXGvQ7X\nVUvMBdH6xPoCn/3irC2d6+3poHiqfyuHsS5EnysRp+BdjDCDQ1+ZuJUZzPUTek1D\nt9yL1cQhxctQuSl6EiHmGBR1BMY7jyAbhFGoVI3uyhDw2SWPbZHPhcAcuQZm15z0\nWwp77PxzLvmp1vfitkhd+WxJBrjqN07J6e5UC8sfW3vLrZANxj5OLs4dVbV2JK5L\nP/B3aKMyKpyAUfaY9Hqh3tWcQj+4LTlL5TdvPMRPlYu0P4cx92BIXXKqPeE3isNI\ndjSyCxyE2TdK8Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufpr.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ufpr.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ufpr.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ufpr.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ufpr.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ufpr.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ufpr.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ufpr.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ufpr.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufpr.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufpr.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufpr.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFPR - Universidade Federal do Parana"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFPR - Universidade Federal do Parana"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFPR - Universidade Federal do Parana"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFPR - Universidade Federal do Parana"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC1jCCAb4CAQAwDQYJKoZIhvcNAQEFBQAwMTEMMAoGA1UECxMDQ0NFMQswCQYD\nVQQGEwJCUjEUMBIGA1UEAxMLaWRwLnVmcHIuYnIwHhcNMTUwMzEwMTcyMjA5WhcN\nMjAwMzA4MTcyMjA5WjAxMQwwCgYDVQQLEwNDQ0UxCzAJBgNVBAYTAkJSMRQwEgYD\nVQQDEwtpZHAudWZwci5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAOFIgUDLLgOWy8WFpJ3WvcKJSOn/+STEWV95ma2PmAsa6lOT59AXXyPvUagrg7C8\nvzZQj8pgTkx7a2W54Qm8ETF3v1vLh8EwTpIAN0dz1K7XDWVy2fizoySj27GP1Zxu\nsF+dxt2PzRPpbzwQMf5XviiIIQSXEEt8E55ckK4yNz25JpqxsgxYwr7sTFWXPt3y\nWXu6a/kBfzi2mrxYORz7t9w/36nkYy1xOt08q8vYK9IWaufP558pvpw05PQHTnwP\n64c9vQ9qwDr7Eek7dXelJtJ1x/wiqW8kq+grx1yHipDq5kP5HPyu7Fo+kEdwl1mT\nqGTSBz7trGMRaj/z0Ilq4nMCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAcMCPPhKd\nhmAOGj9QRCYyF1pAImTtH/UyJv5wlgnJ+V2AOysRbac7eyISNZVPUSnXjHXGvQ7X\nVUvMBdH6xPoCn/3irC2d6+3poHiqfyuHsS5EnysRp+BdjDCDQ1+ZuJUZzPUTek1D\nt9yL1cQhxctQuSl6EiHmGBR1BMY7jyAbhFGoVI3uyhDw2SWPbZHPhcAcuQZm15z0\nWwp77PxzLvmp1vfitkhd+WxJBrjqN07J6e5UC8sfW3vLrZANxj5OLs4dVbV2JK5L\nP/B3aKMyKpyAUfaY9Hqh3tWcQj+4LTlL5TdvPMRPlYu0P4cx92BIXXKqPeE3isNI\ndjSyCxyE2TdK8Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFPR - Universidade Federal do Parana"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFPR - Universidade Federal do Parana"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufpr.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufpr.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFPR - Universidade Federal do Parana"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFPR - Universidade Federal do Parana"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ccm.copac.jisc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:help.copac@jisc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Copac Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mimas-shib-tech@listserv.manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mimas Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ccm.copac.jisc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-11-30T15:08:18Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Copac Collection Management"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://jisc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Jisc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ccm.copac.jisc.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ccm.copac.jisc.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ccm.copac.jisc.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ccm.copac.jisc.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ccm.copac.jisc.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ccm.copac.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ccm.copac.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID/zCCAuegAwIBAgIJAIacduR/myAPMA0GCSqGSIb3DQEBBQUAMHUxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRMwEQYDVQQIEwpNYW5jaGVzdGVyMRMwEQYDVQQHEwpNYW5jaGVzdGVy\n\t\t\t\t\t\tMQ0wCwYDVQQKEwRKaXNjMQ4wDAYDVQQLEwVNaW1hczEdMBsGA1UEAxMUY2NtLmNv\n\t\t\t\t\t\tcGFjLmppc2MuYWMudWswHhcNMTUxMDA2MDkyODE3WhcNMjUxMDAzMDkyODE3WjB1\n\t\t\t\t\t\tMQswCQYDVQQGEwJHQjETMBEGA1UECBMKTWFuY2hlc3RlcjETMBEGA1UEBxMKTWFu\n\t\t\t\t\t\tY2hlc3RlcjENMAsGA1UEChMESmlzYzEOMAwGA1UECxMFTWltYXMxHTAbBgNVBAMT\n\t\t\t\t\t\tFGNjbS5jb3BhYy5qaXNjLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEApIKiUbQ1UcbvNo+b6XCsSe9s3WiZ9heGvdvFrQHn0U/YsR1k1oMd+2tX\n\t\t\t\t\t\tN9vEse6KYOs6M9ecw/U6e98xkWaFQnhLogxlwmsQNllnN1h3SM9Tk7KBQzUdeqQ2\n\t\t\t\t\t\tiGSeX1gjd11HSaevSLzt9NstipOvWh9Ur/bPbLtjQJVLbwhCgCSqjBHY9oPgfich\n\t\t\t\t\t\tbvfOp9Ahp0ckszpQC8osM5Q+gdsyxtlGmYsqm9eHiKXCWo3/2BnDmqxfWrVBLcyf\n\t\t\t\t\t\t8EEC4qN+FSQJl/qo1EHYGsvpxbXdvo7w7AZNV0AacmRT3Hs5Oosgpdj3SDSxBi7Q\n\t\t\t\t\t\t9vXc8u5pMUuCoFaFq+pV5aJrkZ515wIDAQABo4GRMIGOMAkGA1UdEwQCMAAwCwYD\n\t\t\t\t\t\tVR0PBAQDAgSwMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAfBgNVHREE\n\t\t\t\t\t\tGDAWghRjY20uY29wYWMuamlzYy5hYy51azA0BgNVHRIELTArgSltaW1hcy1zaGli\n\t\t\t\t\t\tLXRlY2hAbGlzdHNlcnYubWFuY2hlc3Rlci5hYy51azANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAdiuss1LqfQjW3b+p1udno7kpGrNMy7njdR6+kzAZhLMZosnXzC40myLD8QIO\n\t\t\t\t\t\ttoESjy3njFKjn39koYfWKPOcUPlHhOMDXZ/l1uyeyjYpNjGNyYSE/noHEh+Dq8La\n\t\t\t\t\t\tEv1APgkhr2szIY0n0j9TdaFZAOIsaOsZvWsnK3n3zr7LbduLPUR46Kq6kC3c7nQX\n\t\t\t\t\t\tn1Ig511IcUV8B/hysTz2xC1SQOYIz+jexv3/2jy/MaPdgenuoB86eFZzquKe5kJx\n\t\t\t\t\t\tofe54k1GZFVi8fyZYgs7M4qoMOhaUtjnTQoSnonVnL7rRNERcIB40oCdaoSEENoF\n\t\t\t\t\t\t6hbD0ku+eQC/qqz1h3WEtOymjg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ccm.copac.jisc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ccm.copac.jisc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ccm.copac.jisc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ccm.copac.jisc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ccm.copac.jisc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ccm.copac.jisc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.ujf-grenoble.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "disi-agalan@ujf-grenoble.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.ujf-grenoble.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-09-13T14:58:07Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.ujf-grenoble.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.ujf-grenoble.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.ujf-grenoble.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ujf-grenoble.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ujf-grenoble.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Grenoble 1 - Joseph Fourier"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Grenoble 1 - Joseph Fourier"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUIBrWKHsL8z9pJuwM6Xugq6gtHv0wDQYJKoZIhvcNAQEF\nBQAwJTEjMCEGA1UEAxMac2hpYmJvbGV0aC51amYtZ3Jlbm9ibGUuZnIwHhcNMTIw\nNTMwMTM1OTEwWhcNMzIwNTMwMTM1OTEwWjAlMSMwIQYDVQQDExpzaGliYm9sZXRo\nLnVqZi1ncmVub2JsZS5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAMKh7FBSR/eSLc6z91Pnqz9DwOsoTcYsmk7vMR5pzzma04GnURN9m4wdLXXXthpT\nwsLsm6X3IajdWwPcychQX+QXjFVu9SwujThoTVKEKHQNQeLcd5d7diiE9NyCnL4n\ndT2TCMetnw7mZi9hjQNzqglecS6hYfz9AbPjE6nBrCMolp93fMW2+DNUx8LjsfhY\ntrmbX8302s9oEXbOgawV/4aqrDuRlXUKtCQoHhNZDlaXwRIbEljHvQ+e4RNz1OcA\nWIsARWe7H1WEow3q+SbIRFSYURRqpnA7I98Iee6jk4KrGVSmlzQHpnxYJ2lPVMnG\n9l0VGLuWBE1JLzD9tKnmrPkCAwEAAaN7MHkwWAYDVR0RBFEwT4Iac2hpYmJvbGV0\naC51amYtZ3Jlbm9ibGUuZnKGMWh0dHBzOi8vc2hpYmJvbGV0aC51amYtZ3Jlbm9i\nbGUuZnIvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFMI3jVWm2/k0WcsNlvWwLwUo\n/OsaMA0GCSqGSIb3DQEBBQUAA4IBAQCGC1Rg9cMwkd7AojNiF8YZ0UBY1cK208ik\nAcP7bhMUTIo2OxlhEDqGa8y0wCr2GFOJXutgR0HED33N+VfzvV2lhPJf3hEg6yFa\ngBnVXFgNP7+m+wjJ8l//EX2x8XGefCEobUFXP1g2xurqfr5Wvm7BlN2dKhhEVn3d\n/Jm1bb3fZT1CM1ryggYtQLnNNlcJYyYDbqPshKA5LIXn3PlSyxC7QtqY3PRgag68\nk1xooEqccP2ldz2s7hAinmiTCGC3nKoSJUpFAkUUo3hEulRnd4KdIqV0Bat0I/qt\nY8dlCvdx5k6fUjl8mF/ZLzQs6uX9XwCwlb60AKwi9uFRJpFzCX9e"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Grenoble 1 - Joseph Fourier"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ujf-grenoble.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Grenoble 1 - Joseph Fourier"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://fsso.springer.com",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:onlineservice@springer.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Springer Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:caspersupport@springer.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Casper Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://fsso.springer.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-09-24T13:02:11Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SpringerLink and Springer for R&D (live)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://link.springer.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Springer-Verlag London Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "response_location": "https://fsso.springer.com/federation/SPSloRedirect/metaAlias/SpringerServiceProvider",
              "location": "https://fsso.springer.com/federation/SPSloRedirect/metaAlias/SpringerServiceProvider",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "response_location": "https://fsso.springer.com/federation/SPSloPOST/metaAlias/SpringerServiceProvider",
              "location": "https://fsso.springer.com/federation/SPSloPOST/metaAlias/SpringerServiceProvider",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://fsso.springer.com/federation/SPSloSoap/metaAlias/SpringerServiceProvider",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SpringerLink and Springer for R&D offer researchers access to millions of scientific documents."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SpringerLink and Springer for R&D"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFCjCCA/KgAwIBAgIQLjTwCOU9tS/TtpogR6vgozANBgkqhkiG9w0BAQUFADCB\n\t\t\t\t\t\ttTELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMR8wHQYDVQQL\n\t\t\t\t\t\tExZWZXJpU2lnbiBUcnVzdCBOZXR3b3JrMTswOQYDVQQLEzJUZXJtcyBvZiB1c2Ug\n\t\t\t\t\t\tYXQgaHR0cHM6Ly93d3cudmVyaXNpZ24uY29tL3JwYSAoYykxMDEvMC0GA1UEAxMm\n\t\t\t\t\t\tVmVyaVNpZ24gQ2xhc3MgMyBTZWN1cmUgU2VydmVyIENBIC0gRzMwHhcNMTQwODE5\n\t\t\t\t\t\tMDAwMDAwWhcNMTcwODE0MjM1OTU5WjBeMQswCQYDVQQGEwJHQjEPMA0GA1UECBMG\n\t\t\t\t\t\tTG9uZG9uMQ8wDQYDVQQHFAZMb25kb24xETAPBgNVBAoUCFNwcmluZ2VyMRowGAYD\n\t\t\t\t\t\tVQQDFBFmc3NvLnNwcmluZ2VyLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\n\t\t\t\t\t\tAQoCggEBAK2hLMYUogo2xzXswFPraYX07zwDLpetg/Fev9O8EmYjdBMoX18P857n\n\t\t\t\t\t\tFTsyOEi9L3KaUlXQ7IaX6LWHWC19m0BTbXjdCBy8tqzuS6ZX7sFZ6WMEHtkYCeCV\n\t\t\t\t\t\t0ThN1BG1KG3fZ4W045Ys+/f25zXXyO123wkxa7Qx/xSJM/zNP3mKLReww68RL98q\n\t\t\t\t\t\tHbNjkDoQ2YP9R6YzAuPCZukw8UkbhK0STJqzRn3VcBXvCVKCdYAKD4U7uRWsssUu\n\t\t\t\t\t\tYDJU329KJv4LasZBwZ4TCIdKQh317wRXFw0BKFVL1AVb/0Hs9YEyuHfB5qVXC8+7\n\t\t\t\t\t\tfAjC3nmSxK7f9Jk/nnHdV14704zAH9UCAwEAAaOCAWowggFmMBwGA1UdEQQVMBOC\n\t\t\t\t\t\tEWZzc28uc3ByaW5nZXIuY29tMAkGA1UdEwQCMAAwDgYDVR0PAQH/BAQDAgWgMCsG\n\t\t\t\t\t\tA1UdHwQkMCIwIKAeoByGGmh0dHA6Ly9zZC5zeW1jYi5jb20vc2QuY3JsMGUGA1Ud\n\t\t\t\t\t\tIAReMFwwWgYKYIZIAYb4RQEHNjBMMCMGCCsGAQUFBwIBFhdodHRwczovL2Quc3lt\n\t\t\t\t\t\tY2IuY29tL2NwczAlBggrBgEFBQcCAjAZFhdodHRwczovL2Quc3ltY2IuY29tL3Jw\n\t\t\t\t\t\tYTAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwHwYDVR0jBBgwFoAUDURc\n\t\t\t\t\t\tFlNEwYJ+HSCrJfQBY9i+eaUwVwYIKwYBBQUHAQEESzBJMB8GCCsGAQUFBzABhhNo\n\t\t\t\t\t\tdHRwOi8vc2Quc3ltY2QuY29tMCYGCCsGAQUFBzAChhpodHRwOi8vc2Quc3ltY2Iu\n\t\t\t\t\t\tY29tL3NkLmNydDANBgkqhkiG9w0BAQUFAAOCAQEAN0E+lQkTOxlaKMAyBWN3EwBt\n\t\t\t\t\t\t/YeVGMW3L7BEqXnczaUdFWDrx6do0QacO0JAzzl1GR4qBa1OxZ/ciQSK+tLeyxN1\n\t\t\t\t\t\tpPy054DP0jPzUsD/GV4LzxuUR5kai8lN0TLaUCAotaSIS5mqWfBnqv6mCfCOrTj+\n\t\t\t\t\t\tajZ6OJCB/FyTrpLkSx0+ERwxQcVY2bNToqSKkj2rI82FAzWXLO1Gy7AI8MVk9f2A\n\t\t\t\t\t\th984zlHxUYlsiOJEnD+dv7prP1fvSFnbjvk5aOLfPb3vm6xyuf10Ed91+bSkQC3A\n\t\t\t\t\t\txAg9HHHsfCPTG31sKeOQb6/m0I+Bl2Hupnqbv01S40s+byHF5EGeZhNKrQleWg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "key_size": {
                    "__class__": "http://www.w3.org/2001/04/xmlenc#&KeySize",
                    "text": "128"
                  },
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFCjCCA/KgAwIBAgIQLjTwCOU9tS/TtpogR6vgozANBgkqhkiG9w0BAQUFADCB\n\t\t\t\t\t\ttTELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMR8wHQYDVQQL\n\t\t\t\t\t\tExZWZXJpU2lnbiBUcnVzdCBOZXR3b3JrMTswOQYDVQQLEzJUZXJtcyBvZiB1c2Ug\n\t\t\t\t\t\tYXQgaHR0cHM6Ly93d3cudmVyaXNpZ24uY29tL3JwYSAoYykxMDEvMC0GA1UEAxMm\n\t\t\t\t\t\tVmVyaVNpZ24gQ2xhc3MgMyBTZWN1cmUgU2VydmVyIENBIC0gRzMwHhcNMTQwODE5\n\t\t\t\t\t\tMDAwMDAwWhcNMTcwODE0MjM1OTU5WjBeMQswCQYDVQQGEwJHQjEPMA0GA1UECBMG\n\t\t\t\t\t\tTG9uZG9uMQ8wDQYDVQQHFAZMb25kb24xETAPBgNVBAoUCFNwcmluZ2VyMRowGAYD\n\t\t\t\t\t\tVQQDFBFmc3NvLnNwcmluZ2VyLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\n\t\t\t\t\t\tAQoCggEBAK2hLMYUogo2xzXswFPraYX07zwDLpetg/Fev9O8EmYjdBMoX18P857n\n\t\t\t\t\t\tFTsyOEi9L3KaUlXQ7IaX6LWHWC19m0BTbXjdCBy8tqzuS6ZX7sFZ6WMEHtkYCeCV\n\t\t\t\t\t\t0ThN1BG1KG3fZ4W045Ys+/f25zXXyO123wkxa7Qx/xSJM/zNP3mKLReww68RL98q\n\t\t\t\t\t\tHbNjkDoQ2YP9R6YzAuPCZukw8UkbhK0STJqzRn3VcBXvCVKCdYAKD4U7uRWsssUu\n\t\t\t\t\t\tYDJU329KJv4LasZBwZ4TCIdKQh317wRXFw0BKFVL1AVb/0Hs9YEyuHfB5qVXC8+7\n\t\t\t\t\t\tfAjC3nmSxK7f9Jk/nnHdV14704zAH9UCAwEAAaOCAWowggFmMBwGA1UdEQQVMBOC\n\t\t\t\t\t\tEWZzc28uc3ByaW5nZXIuY29tMAkGA1UdEwQCMAAwDgYDVR0PAQH/BAQDAgWgMCsG\n\t\t\t\t\t\tA1UdHwQkMCIwIKAeoByGGmh0dHA6Ly9zZC5zeW1jYi5jb20vc2QuY3JsMGUGA1Ud\n\t\t\t\t\t\tIAReMFwwWgYKYIZIAYb4RQEHNjBMMCMGCCsGAQUFBwIBFhdodHRwczovL2Quc3lt\n\t\t\t\t\t\tY2IuY29tL2NwczAlBggrBgEFBQcCAjAZFhdodHRwczovL2Quc3ltY2IuY29tL3Jw\n\t\t\t\t\t\tYTAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwHwYDVR0jBBgwFoAUDURc\n\t\t\t\t\t\tFlNEwYJ+HSCrJfQBY9i+eaUwVwYIKwYBBQUHAQEESzBJMB8GCCsGAQUFBzABhhNo\n\t\t\t\t\t\tdHRwOi8vc2Quc3ltY2QuY29tMCYGCCsGAQUFBzAChhpodHRwOi8vc2Quc3ltY2Iu\n\t\t\t\t\t\tY29tL3NkLmNydDANBgkqhkiG9w0BAQUFAAOCAQEAN0E+lQkTOxlaKMAyBWN3EwBt\n\t\t\t\t\t\t/YeVGMW3L7BEqXnczaUdFWDrx6do0QacO0JAzzl1GR4qBa1OxZ/ciQSK+tLeyxN1\n\t\t\t\t\t\tpPy054DP0jPzUsD/GV4LzxuUR5kai8lN0TLaUCAotaSIS5mqWfBnqv6mCfCOrTj+\n\t\t\t\t\t\tajZ6OJCB/FyTrpLkSx0+ERwxQcVY2bNToqSKkj2rI82FAzWXLO1Gy7AI8MVk9f2A\n\t\t\t\t\t\th984zlHxUYlsiOJEnD+dv7prP1fvSFnbjvk5aOLfPb3vm6xyuf10Ed91+bSkQC3A\n\t\t\t\t\t\txAg9HHHsfCPTG31sKeOQb6/m0I+Bl2Hupnqbv01S40s+byHF5EGeZhNKrQleWg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "response_location": "https://fsso.springer.com/federation/SPMniRedirect/metaAlias/SpringerServiceProvider",
              "location": "https://fsso.springer.com/federation/SPMniRedirect/metaAlias/SpringerServiceProvider",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "response_location": "https://fsso.springer.com/federation/SPMniPOST/metaAlias/SpringerServiceProvider",
              "location": "https://fsso.springer.com/federation/SPMniPOST/metaAlias/SpringerServiceProvider",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "response_location": "https://fsso.springer.com/federation/SPMniSoap/metaAlias/SpringerServiceProvider",
              "location": "https://fsso.springer.com/federation/SPMniSoap/metaAlias/SpringerServiceProvider",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://fsso.springer.com/federation/Consumer/metaAlias/SpringerServiceProvider",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://fsso.springer.com/federation/Consumer/metaAlias/SpringerServiceProvider",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://fsso.springer.com/federation/Consumer/ECP/metaAlias/SpringerServiceProvider",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.swindon-college.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@swindon-college.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Computer Services Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@swindon.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IDP Admins"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.swindon-college.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-04-25T16:02:25Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVALJupNJrLD9f0qZUHM/Xl8rlpql8MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCQxIjAgBgNVBAMTGWlkcC5zd2luZG9uLWNvbGxlZ2UuYWMudWswHhcNMTIw\n\t\t\t\t\t\tMzEzMDk0NTM3WhcNMzIwMzEzMDk0NTM3WjAkMSIwIAYDVQQDExlpZHAuc3dpbmRv\n\t\t\t\t\t\tbi1jb2xsZWdlLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tpLADxySQUYQAqTPNDee8t0Nxr4LUjG89PJO/3z22vTT+LW9P2Q1RvA31GVuYYcDz\n\t\t\t\t\t\tVXwhHP/u7ySSASfZ1HyohubyJnx0VNriEh9gCZUXndCCUifFLqGng3Zs4KtITHSx\n\t\t\t\t\t\tNpWv1JQ5GCLRXorN5qkVsnB5hXZ4RMLVA8bPierzzYZxHXtMEieDxIfWyUDGjVbA\n\t\t\t\t\t\tqrfZg05SWFagA/+NvMrozUXj5q3IUbxi3NdVMSuaAkMmkLK5gXDdsDY0lTpTL7P0\n\t\t\t\t\t\txtbO4pYKrfMavPfnj/yS9KQ30XZFoZeKvWnzUEZb9nFw1oiUN9UrHBiBVU4s0mgu\n\t\t\t\t\t\tGNjAf7RB20658r7cKRVITwIDAQABo3kwdzBWBgNVHREETzBNghlpZHAuc3dpbmRv\n\t\t\t\t\t\tbi1jb2xsZWdlLmFjLnVrhjBodHRwczovL2lkcC5zd2luZG9uLWNvbGxlZ2UuYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFP6Yp/0hH7uIYFCI3vZIoxKQpgxe\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQBxK5J1DbN+OFP49i1Bhh6iLe/Lipa/UMv8BRI2\n\t\t\t\t\t\tlQ7AGzUjI/7FR4CYz7m/jcO9GsZyFeTgtoUmtsCj6YQohEgm4lgYFD5MhGOuAOLp\n\t\t\t\t\t\tFRgsbEMl5mzNd9TIPaAxUy+2prml7bKc/gMMAxxLBswPpvEkZa0FOLsRW4a/cdEm\n\t\t\t\t\t\tao5hW+LPBpQlLQZgyzYytj/jB6ljfLV7QXbeGACBJKeZL7Ang/yl6ZCtQW1EbofU\n\t\t\t\t\t\tL5TwUarch4qcWhlgoOXHypMC4SlzWT6yLOzOC2hg+e/0PLMENqU8Z2SrERRKYVlv\n\t\t\t\t\t\tEVsYTrzNM4kJzpBen+xuMmmnajrIEneDpaX9x1neqDj7QEfr"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "swindon-college.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.swindon-college.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.swindon-college.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.swindon-college.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.swindon-college.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.swindon-college.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.swindon-college.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.swindon-college.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.swindon-college.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "swindon-college.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVALJupNJrLD9f0qZUHM/Xl8rlpql8MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCQxIjAgBgNVBAMTGWlkcC5zd2luZG9uLWNvbGxlZ2UuYWMudWswHhcNMTIw\n\t\t\t\t\t\tMzEzMDk0NTM3WhcNMzIwMzEzMDk0NTM3WjAkMSIwIAYDVQQDExlpZHAuc3dpbmRv\n\t\t\t\t\t\tbi1jb2xsZWdlLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tpLADxySQUYQAqTPNDee8t0Nxr4LUjG89PJO/3z22vTT+LW9P2Q1RvA31GVuYYcDz\n\t\t\t\t\t\tVXwhHP/u7ySSASfZ1HyohubyJnx0VNriEh9gCZUXndCCUifFLqGng3Zs4KtITHSx\n\t\t\t\t\t\tNpWv1JQ5GCLRXorN5qkVsnB5hXZ4RMLVA8bPierzzYZxHXtMEieDxIfWyUDGjVbA\n\t\t\t\t\t\tqrfZg05SWFagA/+NvMrozUXj5q3IUbxi3NdVMSuaAkMmkLK5gXDdsDY0lTpTL7P0\n\t\t\t\t\t\txtbO4pYKrfMavPfnj/yS9KQ30XZFoZeKvWnzUEZb9nFw1oiUN9UrHBiBVU4s0mgu\n\t\t\t\t\t\tGNjAf7RB20658r7cKRVITwIDAQABo3kwdzBWBgNVHREETzBNghlpZHAuc3dpbmRv\n\t\t\t\t\t\tbi1jb2xsZWdlLmFjLnVrhjBodHRwczovL2lkcC5zd2luZG9uLWNvbGxlZ2UuYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFP6Yp/0hH7uIYFCI3vZIoxKQpgxe\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQBxK5J1DbN+OFP49i1Bhh6iLe/Lipa/UMv8BRI2\n\t\t\t\t\t\tlQ7AGzUjI/7FR4CYz7m/jcO9GsZyFeTgtoUmtsCj6YQohEgm4lgYFD5MhGOuAOLp\n\t\t\t\t\t\tFRgsbEMl5mzNd9TIPaAxUy+2prml7bKc/gMMAxxLBswPpvEkZa0FOLsRW4a/cdEm\n\t\t\t\t\t\tao5hW+LPBpQlLQZgyzYytj/jB6ljfLV7QXbeGACBJKeZL7Ang/yl6ZCtQW1EbofU\n\t\t\t\t\t\tL5TwUarch4qcWhlgoOXHypMC4SlzWT6yLOzOC2hg+e/0PLMENqU8Z2SrERRKYVlv\n\t\t\t\t\t\tEVsYTrzNM4kJzpBen+xuMmmnajrIEneDpaX9x1neqDj7QEfr"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swindon College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.swindon-college.ac.uk/campus-info/computer-services/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Swindon College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.ubu.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.ubu.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Membership Solutions Limited: University of Bristol Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ubu.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ubu.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ubu.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.ubu.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ubu.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ubu.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.ubu.org.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ubu.org.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ubu.org.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.ubu.org.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ubu.org.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.ubu.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.ubu.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ubu.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.ubu.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ubu.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.ubu.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-11.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-11.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-11.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-11.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-11.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-11.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-11.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-11.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-11.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;11"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;11"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-11.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-11.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAPXOQ3De2DJrMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0xMS5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTQ0MzI4WhcNMjQx\nMDA0MTQ0MzI4WjAhMR8wHQYDVQQDExZsYWRvazMtMTEubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzEpHxy43dFJEhLjih5/bKj+r\nRrtc4rujDCdbyvsTnzKej/pWPKUg5lWvlvnAjoQutVFLYQ5o5xD+SJJCW9kMyz7d\nvcyOHnFd7a+ZZFFjeNF54VR2JW0M3D/yLT6GftIEp1yHxKZkX4pzZCjHyZOJYXQX\n1mbZ8F0XwMXxGK/y6qhMjc94jY9GVj7ktnCaX15uKnEqQPgN6oKz9QQoPxE6K/Dl\nu95CHpesk/0RGotMj+oEXJWLA4J36wivjZ/+nus+KNhGo/It7cCRU52HzhOL+/bD\nJJyLFEGOSHVm9SPGZnyZZAEs2Bq9Ihcerp0JuGF0HzeEoDZhZ3sVT/7i9rHs2wID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMTEubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0xMS5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQU+C4kgbF74Jw5rlzvpqwTLSmnueMwDQYJKoZIhvcNAQEFBQADggEB\nAHCwnhYWbLeVM+Opyt1DIj0hsSU4Iz+WqgmLQ2RvRq8zPGcSLQNH65n1WBCYNFu/\nTy0bKpFEZFoagFyn4ba0Bi5A7ItnuyPJ+OWfxbntpSLOZOlulEDLvGmXyHgWjQC3\n2vuurpdqFtoufy7XEPy9LnJNQ5u9cTnp8YVW44UvxO4UJdQoEQWSM/Apk6GX7BQq\nBp6/gQwrw9NniXTkbPUQghgiBe5iTB1nq6/0hx9zunm19FR/oCsgF4eYbdn67pvu\n99hHPNUGBlXVpBhYSXQ3yjgn107oE2EMYijPxxKjp0+Tkt+DAusj8S7+j/WHzJqA\ndabCeN+PQJ8+6s9gO04gD/Q="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-11.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-11.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-11.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-11.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-11.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-11.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-11.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-11.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-11.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-11.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ipm.weill.cornell.edu/federated-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lih3001@med.cornell.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Linda Huang"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "als2076@med.cornell.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alexandros Sigaras"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lih3001@med.cornell.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Linda Huang"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lih3001@med.cornell.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Linda Huang"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ipm.weill.cornell.edu/federated-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Weill Cornell Medical College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.med.cornell.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Weill Cornell Medical College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://pmkb-local.weill.cornell.edu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://pmkb-local.weill.cornell.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://ipm.weill.cornell.edu/about/about-institute"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Weill Cornell Institute for Precision Medicine"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6zCCAdOgAwIBAgIJAPqg8605cVWPMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDGMzZTUxNjk5OTIwZTAeFw0xNjAyMjUyMDM4NDJaFw0yNjAyMjIyMDM4NDJa\nMBcxFTATBgNVBAMTDGMzZTUxNjk5OTIwZTCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAOC9K7UVdQnOLMD+T/LFT+Rn084+16TbS+SxupqDiwDdpFgcy0Uh\n45kEEHsGMLw+AjkfVqq7Ni6SW66qmcG0rJVtRScF/TAQFrBVotxNAqsdEphhzyy1\n0iu9VfKNBkZ41lhgIwX92wjcZibsaRKYsnOgnnrQ24pIUx7NI2B+dCPY2AW8nvOx\nzZHvMdP4k39psVcQgnZ07H6vChYDg2d/58tAjyqB/6mxM1zgUCNmIdMfQK0k40yk\n1Ea7oZAayBXrBy2Ik0HGBXpFn2To4w9pU7W3XCLlzJO7ryoCjCdvtjA4/85TUtA0\n53Jomrqz52XsYGNGwrTf8DFPTDMwO3Ussr8CAwEAAaM6MDgwFwYDVR0RBBAwDoIM\nYzNlNTE2OTk5MjBlMB0GA1UdDgQWBBTO4An8KxCRMlWyY4FpLgUHN7I+XzANBgkq\nhkiG9w0BAQUFAAOCAQEA1nBRHvVb23X9A8AqAD/lwgipivrZFzlXdD6bgrDvPLwZ\nCYTEXXt4Gi15kB7dUkY+aWBjSInB1EobikE5fwAOh7hpXBreKwYHIFWmjgWPCmKx\nuMEg1eXrrJbt2WgkP7woViJvkRmmkweuBkA3EEd7198jx8wxDZiqWBDOk1VzAIBv\n1WN4rqlxXAaNQatzxVa9bgSFjHZD7ByaxGNp/Dy9cNIpln9dQsy8HR6D6QFXRlvh\nxPFX7aGmryJwMudoa1LAFIosj1Q3rEBLKVYhhqUQ4ZXUtgSzvi0baN8v8LV17i3w\nYgcqnuA/snTukkLF/01orTzUp2MzQu8XI/qSfUv/Gg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pmkb-local.weill.cornell.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Weill Cornell Institute for Precision Medicine"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://elixir.mf.uni-lj.si/sp/20150622",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "\u0160uput"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dusan.suput@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Du\u0161an"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:elixir@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sen\u010dar"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:damijan.sencar@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Damijan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hudomalj"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:emil.hudomalj@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Emil"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lesko\u0161ek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:brane.leskosek@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Branimir"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pesko"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jure.pesko@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jure"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sen\u010dar"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:damijan.sencar@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Damijan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://elixir.mf.uni-lj.si/sp/20150622",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_general.pdf"
              },
              {
                "lang": "sl",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_splosni_pogoji.pdf"
              }
            ],
            "registration_instant": "2015-06-24T09:06:08Z",
            "registration_authority": "http://aai.arnes.si",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Univerza v Ljubljani Medicinska fakulteta"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Univerza v Ljubljani Medicinska fakulteta"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://elixir.mf-uni-lj.si"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://elixir.mf-uni-lj.si"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Univerza v Ljubljani Medicinska fakulteta"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Univerza v Ljubljani Medicinska fakulteta"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://elixir.mf-uni-lj.si"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://elixir.mf-uni-lj.si"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ELIXIR eLearning platform"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ELIXIR eLearning platform"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "93",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "150"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ELIXIR eLearning platform"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ELIXIR eLearning platform"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "elixir.mf.uni-lj.si"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=elixir.mf.uni-lj.si,L=Ljubljana,C=SI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://elixir.mf.uni-lj.si/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ELIXIR eLearning platform"
                },
                {
                  "lang": "sl",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ELIXIR eLearning platform"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "ELIXIR eLearning platform"
                },
                {
                  "lang": "sl",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "ELIXIR eLearning platform"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "name": "sn",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name": "givenName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name": "mail",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name": "eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.gsu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rreddish@gsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ron Reddish"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "burke@gsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Joel Burke"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mullins@gsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeremy Mullins"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.gsu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.gsu.edu:9443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.gsu.edu:9443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDiDCCAnACCQCrY2VVpigyOTANBgkqhkiG9w0BAQUFADCBhTELMAkGA1UEBhMC\nVVMxEDAOBgNVBAgMB0dlb3JnaWExEDAOBgNVBAcMB0F0bGFudGExDDAKBgNVBAoM\nA0dTVTENMAsGA1UECwwESVMmVDEUMBIGA1UEAwwLaWRwLmdzdS5lZHUxHzAdBgkq\nhkiG9w0BCQEWEHJyZWRkaXNoQGdzdS5lZHUwHhcNMTMwODEyMTYzMzEyWhcNMjMw\nODEyMTYzMzEyWjCBhTELMAkGA1UEBhMCVVMxEDAOBgNVBAgMB0dlb3JnaWExEDAO\nBgNVBAcMB0F0bGFudGExDDAKBgNVBAoMA0dTVTENMAsGA1UECwwESVMmVDEUMBIG\nA1UEAwwLaWRwLmdzdS5lZHUxHzAdBgkqhkiG9w0BCQEWEHJyZWRkaXNoQGdzdS5l\nZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCi46F3cO420nIJduG7\nbz9n2uBJQyyulhsMQ1NkV1AyZgjXhPWOf1eH8UgP1Z1w4qZiCEJZ2ESkmpGLOvCv\nXZOoF7Re+IZ+RcfNvTIkrsYmUi7QJMUdsmHojnFbgrygc/liFen50x3lB7YWz2hg\nOh82QJ1LGeNLDy2UWXjBOsNQgZ0kLXBIoqRaGFoj7+DxsrPheaXnFGLEIQo0NHRt\nZMJWOkDoLwadWBEprMcTiEgBQhyTDjinA1c9smZ8xHxhyUY/b8X6uLlPfQSTR2H3\n/bP3DdvUtjawOBD0fTGyaHHyVgKh9VHoprjpFzghPn2oS3/FNO1S8japHQYcQ4Yw\nZ2IJAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAEx2wJjdE2IR2j4ak4iHKvnEFBwP\nBERQgwVN3Hg652gZBEo0rjRWE2gojCf1Aw8cgi1qGH5mRys3I837WwBuQBRd9Q+E\naoV966qWrbAkWUPpE0XXquXcCheSJIN3OzlHZesynoeFeFLRGLp4xYfSwAqQuIHt\nbjfhewGhe4cfwJlWByoS9RDQUVrHGl6MgMvk/l2wXIFn4I+6DqJYsHAWl/e1m9Zh\ntN0DE2kMdJnP9uo3P2zbnx1OjnhEKq8USicqfJ0WURaAf3pvB2CQlfHJpLyTk4su\nMaNh4Mq+DwonONJ2IrxNOVDGr1OizMya+fiAPFA2l+XvfveCYE4qgQrBubA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDiDCCAnACCQDgmtUnSYaEQzANBgkqhkiG9w0BAQUFADCBhTELMAkGA1UEBhMC\nVVMxEDAOBgNVBAgMB0dlb3JnaWExEDAOBgNVBAcMB0F0bGFudGExDDAKBgNVBAoM\nA0dTVTENMAsGA1UECwwESVMmVDEUMBIGA1UEAwwLaWRwLmdzdS5lZHUxHzAdBgkq\nhkiG9w0BCQEWEHJyZWRkaXNoQGdzdS5lZHUwHhcNMTIwODIzMTgyNjQxWhcNMTMw\nODIzMTgyNjQxWjCBhTELMAkGA1UEBhMCVVMxEDAOBgNVBAgMB0dlb3JnaWExEDAO\nBgNVBAcMB0F0bGFudGExDDAKBgNVBAoMA0dTVTENMAsGA1UECwwESVMmVDEUMBIG\nA1UEAwwLaWRwLmdzdS5lZHUxHzAdBgkqhkiG9w0BCQEWEHJyZWRkaXNoQGdzdS5l\nZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC+iygvUXA1CzRqsw7P\nN9cFg/9h/Gw8TNlj/XR9Sv2RlEUdnuSNTMgF6lF7lbU5eqfjEG4aKyP2aI6Krdl7\nlqqYrXCY3WOrnHo8SfNUsdbdT8tmm46ye4n2S0dDVII0RuJ5POKdtSjhKF2TZWlo\nlk6DyltMAq6803bdWStsZN0L/sQyaqmLkWLIH7S0FCsus7ypS2EA4IjcZVbuWoy0\nughOCRqmJCzLEkFaTysMzrVgSrAjT4WHrFFfBV9gBdalrJ9Kmqhr1BlUWOJmFLah\nTOW8Q81034cAApmY6DkiWVO69+IzUWxhsjrXk9Lt0tem4ovr/yMPdtxYJgsDJgAA\nTtDtAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAENAbC841AsHB1tQ1VjltsH4uWct\nwoTLcdkuX4owoYLlddpG1IUk0iCr9ugjk2WIAK+kFbJzxB9IvXPYuWn9GQlWjlug\nLnLL6XizmhPUuHpAAkjM48RgJkxZkBlKdy+JyUK9Wz9syXx5SisfDBXadL4QsKx2\nXz3sw2sFRwZfMd1Ir2BFufxHwyR1wDMISkLW4KIh2Y/A4T5PJnyr1gvqCuGFBmVa\nbnsCGHbhR1ukH8bdVEe3cfowAMDJEJHVZGEJYruqe0hjIa/ZDKXFWaDuyaknM5OD\nBCoW3mMYc0Wvo936Rx/CEhxnkL8hh/p+qdyWRZOJy3H1eHEP91+c5Uy+T7U="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gsu.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.gsu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.gsu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.gsu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.gsu.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.gsu.edu:9443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.gsu.edu:9443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gsu.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Georgia State University is located in the heart of downtown Atlanta. Georgia State is one of the country's leading urban research universities."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Georgia State University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDiDCCAnACCQCrY2VVpigyOTANBgkqhkiG9w0BAQUFADCBhTELMAkGA1UEBhMC\nVVMxEDAOBgNVBAgMB0dlb3JnaWExEDAOBgNVBAcMB0F0bGFudGExDDAKBgNVBAoM\nA0dTVTENMAsGA1UECwwESVMmVDEUMBIGA1UEAwwLaWRwLmdzdS5lZHUxHzAdBgkq\nhkiG9w0BCQEWEHJyZWRkaXNoQGdzdS5lZHUwHhcNMTMwODEyMTYzMzEyWhcNMjMw\nODEyMTYzMzEyWjCBhTELMAkGA1UEBhMCVVMxEDAOBgNVBAgMB0dlb3JnaWExEDAO\nBgNVBAcMB0F0bGFudGExDDAKBgNVBAoMA0dTVTENMAsGA1UECwwESVMmVDEUMBIG\nA1UEAwwLaWRwLmdzdS5lZHUxHzAdBgkqhkiG9w0BCQEWEHJyZWRkaXNoQGdzdS5l\nZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCi46F3cO420nIJduG7\nbz9n2uBJQyyulhsMQ1NkV1AyZgjXhPWOf1eH8UgP1Z1w4qZiCEJZ2ESkmpGLOvCv\nXZOoF7Re+IZ+RcfNvTIkrsYmUi7QJMUdsmHojnFbgrygc/liFen50x3lB7YWz2hg\nOh82QJ1LGeNLDy2UWXjBOsNQgZ0kLXBIoqRaGFoj7+DxsrPheaXnFGLEIQo0NHRt\nZMJWOkDoLwadWBEprMcTiEgBQhyTDjinA1c9smZ8xHxhyUY/b8X6uLlPfQSTR2H3\n/bP3DdvUtjawOBD0fTGyaHHyVgKh9VHoprjpFzghPn2oS3/FNO1S8japHQYcQ4Yw\nZ2IJAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAEx2wJjdE2IR2j4ak4iHKvnEFBwP\nBERQgwVN3Hg652gZBEo0rjRWE2gojCf1Aw8cgi1qGH5mRys3I837WwBuQBRd9Q+E\naoV966qWrbAkWUPpE0XXquXcCheSJIN3OzlHZesynoeFeFLRGLp4xYfSwAqQuIHt\nbjfhewGhe4cfwJlWByoS9RDQUVrHGl6MgMvk/l2wXIFn4I+6DqJYsHAWl/e1m9Zh\ntN0DE2kMdJnP9uo3P2zbnx1OjnhEKq8USicqfJ0WURaAf3pvB2CQlfHJpLyTk4su\nMaNh4Mq+DwonONJ2IrxNOVDGr1OizMya+fiAPFA2l+XvfveCYE4qgQrBubA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDiDCCAnACCQDgmtUnSYaEQzANBgkqhkiG9w0BAQUFADCBhTELMAkGA1UEBhMC\nVVMxEDAOBgNVBAgMB0dlb3JnaWExEDAOBgNVBAcMB0F0bGFudGExDDAKBgNVBAoM\nA0dTVTENMAsGA1UECwwESVMmVDEUMBIGA1UEAwwLaWRwLmdzdS5lZHUxHzAdBgkq\nhkiG9w0BCQEWEHJyZWRkaXNoQGdzdS5lZHUwHhcNMTIwODIzMTgyNjQxWhcNMTMw\nODIzMTgyNjQxWjCBhTELMAkGA1UEBhMCVVMxEDAOBgNVBAgMB0dlb3JnaWExEDAO\nBgNVBAcMB0F0bGFudGExDDAKBgNVBAoMA0dTVTENMAsGA1UECwwESVMmVDEUMBIG\nA1UEAwwLaWRwLmdzdS5lZHUxHzAdBgkqhkiG9w0BCQEWEHJyZWRkaXNoQGdzdS5l\nZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC+iygvUXA1CzRqsw7P\nN9cFg/9h/Gw8TNlj/XR9Sv2RlEUdnuSNTMgF6lF7lbU5eqfjEG4aKyP2aI6Krdl7\nlqqYrXCY3WOrnHo8SfNUsdbdT8tmm46ye4n2S0dDVII0RuJ5POKdtSjhKF2TZWlo\nlk6DyltMAq6803bdWStsZN0L/sQyaqmLkWLIH7S0FCsus7ypS2EA4IjcZVbuWoy0\nughOCRqmJCzLEkFaTysMzrVgSrAjT4WHrFFfBV9gBdalrJ9Kmqhr1BlUWOJmFLah\nTOW8Q81034cAApmY6DkiWVO69+IzUWxhsjrXk9Lt0tem4ovr/yMPdtxYJgsDJgAA\nTtDtAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAENAbC841AsHB1tQ1VjltsH4uWct\nwoTLcdkuX4owoYLlddpG1IUk0iCr9ugjk2WIAK+kFbJzxB9IvXPYuWn9GQlWjlug\nLnLL6XizmhPUuHpAAkjM48RgJkxZkBlKdy+JyUK9Wz9syXx5SisfDBXadL4QsKx2\nXz3sw2sFRwZfMd1Ir2BFufxHwyR1wDMISkLW4KIh2Y/A4T5PJnyr1gvqCuGFBmVa\nbnsCGHbhR1ukH8bdVEe3cfowAMDJEJHVZGEJYruqe0hjIa/ZDKXFWaDuyaknM5OD\nBCoW3mMYc0Wvo936Rx/CEhxnkL8hh/p+qdyWRZOJy3H1eHEP91+c5Uy+T7U="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idp.gsu.edu/identity/feedback.htm"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Georgia State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gsu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Georgia State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://alnbmth.sisoshibboleth.co.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Info"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Oates"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://alnbmth.sisoshibboleth.co.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-06-05T14:29:18Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SiSo Bournemouth University ~ ALNBmth, Online Resource Booking"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.siso.uk.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "TechEthika Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://alnbmth.siso.co/sso/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://alnbmth.siso.co/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://alnbmth.siso.co/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SiSo Bournemouth University ~ ALNBmth, Online Resource Booking"
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth.siso.co/siso-logo60x60.jpg",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SiSo Bournemouth University ~ ALNBmth, Online Resource Booking"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAOSUhyDXVj7AMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB3Npc28uY28wHhcNMTMwMTA3MTYzMTIxWhcNMjMwMTA1MTYzMTIxWjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdzaXNvLmNvMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\txDnj9YFJVXclawo/8rs1aWYAgk6rKi8A/Cyycq0mW5yOKLLh8MUIgDeOGL7bLl7p\n\t\t\t\t\t\tMBeZM4ILlNaeJhICWm1tuLB6SYzREnXwpO7+lvx13xsRHW2TjCPGV3yUgz55vRYj\n\t\t\t\t\t\tbseFrwFHJ8IrL24UTLcpX/R//9cMkZpSqM+77Hn22dxbYvGUOQCHOQzL78AO91qz\n\t\t\t\t\t\tdUaxKzYWyWM7w2U4APP41Zvd0flyUtRZXp8W+WwlUDffFoNndsjR4L/9wuXvOcrH\n\t\t\t\t\t\t+VZtMLy60+cB9bpvVlaQVlt+1stEABdMVvuGNkJ9wIjRjP2b9OLUI76QmgwIDtdE\n\t\t\t\t\t\t5BS0Bv0Puz66L96r2MunRQIDAQABozUwMzASBgNVHREECzAJggdzaXNvLmNvMB0G\n\t\t\t\t\t\tA1UdDgQWBBRRosxNbUQXXwtWDl/kYMScRImh5TANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tgrfjza9Btcz+9WvzcjDTZ+KSrWWvrthA3zc6Q+C/MIBG8CCuxMO+uwFBnXIopGlX\n\t\t\t\t\t\tbLa/QtVLjOugsnizFxjaEFTG4jGndtPJ8+9V8Eja5RlOazuM2LT738+Um8/1Frhr\n\t\t\t\t\t\tGXa0Hdv9ZWEbIhil65fFqZNOmOteja6xxAQ9NgGG/XUnTVTbr7msihEAYTTcS40/\n\t\t\t\t\t\tGSYpT9nQwiryfSWDNJ17Zyl44389kSw+FCUsu8Ns9VSDEDWr/R+97ZMcjN6hAfJL\n\t\t\t\t\t\tdji3X1aaAC/JbnJl/v+yR1TH/sdHyObVaM7FToUGKiyjX9VpfOe64d0hjogzEr0x\n\t\t\t\t\t\tfirJubLNu96jbGctasqcpQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://alnbmth.siso.co/sso/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://alnbmth.siso.co/sso/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://alnbmth.siso.co/sso/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://alnbmth.siso.co/sso/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://alnbmth.siso.co/sso/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://alnbmth.siso.co/sso/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://sso.sunderland.ac.uk/auth/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lundell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ian.lundell@sunderland.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Webb"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rachel.webb@sunderland.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rachel"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wilkinson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:laura.wilkinson@sunderland.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Laura"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Frost"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ian.frost@sunderland.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sweeting"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:scott.sweeting@sunderland.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Scott"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hale"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dean.hale@sunderland.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dean"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Khan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:adil.khan@sunderland.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adil"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dixon"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:daniel.dixon@sunderland.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Daniel"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Frost"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ian.frost@sunderland.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://sso.sunderland.ac.uk/auth/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso.sunderland.ac.uk/auth/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.sunderland.ac.uk/auth/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sunderland.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVjCCAj6gAwIBAgIILQ5N0azZci0wDQYJKoZIhvcNAQEFBQAwQjEhMB8GA1UE\n\t\t\t\t\t\tCgwYVW5pdmVyc2l0eSBvZiBTdW5kZXJsYW5kMR0wGwYDVQQDDBRzc28uc3VuZGVy\n\t\t\t\t\t\tbGFuZC5hYy51azAeFw0xNDA2MTcwNzQ0NDJaFw0yNDA2MTcwNzQ0NDJaMEIxITAf\n\t\t\t\t\t\tBgNVBAoMGFVuaXZlcnNpdHkgb2YgU3VuZGVybGFuZDEdMBsGA1UEAwwUc3NvLnN1\n\t\t\t\t\t\tbmRlcmxhbmQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDR\n\t\t\t\t\t\t+uVqAlnBPfii2qWCgu96Pvd+68pdoAH7WgsFtfn1zdyQK9X+WT7CT4RzNXQ/nEi1\n\t\t\t\t\t\tn6r5D+xE57dknzCj/cgI465605GmckfcsyQbI4d4tJUMwIS6DKTr5YBV4wSOWXl1\n\t\t\t\t\t\t+Ksws+ew7V/GOAh9EJIOiijq3E/e8R+O+pgH0Rvmpugyi+Nj3afppkSsIbLO0apL\n\t\t\t\t\t\t94Cy1dIqxqQejrZnL8pMbdpELq9W8sDMTWsGjvLoRj2q3QYUN7217sf/pD4+5Noy\n\t\t\t\t\t\tsVDEuE4UKZJfuXAAwL73JZmUjraGGqBFJj6Xt8ymTNrCCQO0MA7uuFC/sE+CIDeR\n\t\t\t\t\t\tL9w/ofKvcmq2SZdb2mGHAgMBAAGjUDBOMB0GA1UdDgQWBBSYfGXJCjojjLJ4r4gr\n\t\t\t\t\t\tSSL9uGflzDAfBgNVHSMEGDAWgBSYfGXJCjojjLJ4r4grSSL9uGflzDAMBgNVHRME\n\t\t\t\t\t\tBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAfRpGz0INl+VKylH9UTb1+GmyEIzlX\n\t\t\t\t\t\tRpWjTgKDGW2hvK07fH3ABGa28XUX3yVah1vXzOmfvQ9/f7l2tA5OaJzWHCXijANN\n\t\t\t\t\t\tnkcCKJZSB2AFSkdL+jpXWbrVClomKIJfFLN1CzPvPJ3Ls9P/Xm0AZGFTZF3fM6ZH\n\t\t\t\t\t\tWoaJAKOIUzfARiIRBoIf6y8EEpa3ZdcgPlRwAlHtKMxnUHrdomtBdDSz8WNqHPVF\n\t\t\t\t\t\tUF4nDkcqtwcThIfvtOrNtEG0rwb9ENXL1VNiP1cJZHqyttTQY+vC8quwhnsGeJzk\n\t\t\t\t\t\taQg21GPVp0vGTWHkB+0uti2fwkky/onzGlsYr8IfXu0Yw3tBwQy8kHn+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVjCCAj6gAwIBAgIILQ5N0azZci0wDQYJKoZIhvcNAQEFBQAwQjEhMB8GA1UE\n\t\t\t\t\t\tCgwYVW5pdmVyc2l0eSBvZiBTdW5kZXJsYW5kMR0wGwYDVQQDDBRzc28uc3VuZGVy\n\t\t\t\t\t\tbGFuZC5hYy51azAeFw0xNDA2MTcwNzQ0NDJaFw0yNDA2MTcwNzQ0NDJaMEIxITAf\n\t\t\t\t\t\tBgNVBAoMGFVuaXZlcnNpdHkgb2YgU3VuZGVybGFuZDEdMBsGA1UEAwwUc3NvLnN1\n\t\t\t\t\t\tbmRlcmxhbmQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDR\n\t\t\t\t\t\t+uVqAlnBPfii2qWCgu96Pvd+68pdoAH7WgsFtfn1zdyQK9X+WT7CT4RzNXQ/nEi1\n\t\t\t\t\t\tn6r5D+xE57dknzCj/cgI465605GmckfcsyQbI4d4tJUMwIS6DKTr5YBV4wSOWXl1\n\t\t\t\t\t\t+Ksws+ew7V/GOAh9EJIOiijq3E/e8R+O+pgH0Rvmpugyi+Nj3afppkSsIbLO0apL\n\t\t\t\t\t\t94Cy1dIqxqQejrZnL8pMbdpELq9W8sDMTWsGjvLoRj2q3QYUN7217sf/pD4+5Noy\n\t\t\t\t\t\tsVDEuE4UKZJfuXAAwL73JZmUjraGGqBFJj6Xt8ymTNrCCQO0MA7uuFC/sE+CIDeR\n\t\t\t\t\t\tL9w/ofKvcmq2SZdb2mGHAgMBAAGjUDBOMB0GA1UdDgQWBBSYfGXJCjojjLJ4r4gr\n\t\t\t\t\t\tSSL9uGflzDAfBgNVHSMEGDAWgBSYfGXJCjojjLJ4r4grSSL9uGflzDAMBgNVHRME\n\t\t\t\t\t\tBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAfRpGz0INl+VKylH9UTb1+GmyEIzlX\n\t\t\t\t\t\tRpWjTgKDGW2hvK07fH3ABGa28XUX3yVah1vXzOmfvQ9/f7l2tA5OaJzWHCXijANN\n\t\t\t\t\t\tnkcCKJZSB2AFSkdL+jpXWbrVClomKIJfFLN1CzPvPJ3Ls9P/Xm0AZGFTZF3fM6ZH\n\t\t\t\t\t\tWoaJAKOIUzfARiIRBoIf6y8EEpa3ZdcgPlRwAlHtKMxnUHrdomtBdDSz8WNqHPVF\n\t\t\t\t\t\tUF4nDkcqtwcThIfvtOrNtEG0rwb9ENXL1VNiP1cJZHqyttTQY+vC8quwhnsGeJzk\n\t\t\t\t\t\taQg21GPVp0vGTWHkB+0uti2fwkky/onzGlsYr8IfXu0Yw3tBwQy8kHn+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Sunderland"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sunderland.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Sunderland"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.inra.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "iris@jouy.inra.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.inra.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-03-17T16:49:46Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.inra.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.inra.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.inra.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "inra.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.jouy.inra.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INRA - Institut National de la Recherche Agronomique"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INRA - Institut National de la Recherche Agronomique"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEJDCCAwygAwIBAgIJAOpqYvYKPY5EMA0GCSqGSIb3DQEBBQUAMGkxCzAJBgNV\nBAYTAkZSMRMwEQYDVQQIEwpTb21lLVN0YXRlMQ0wCwYDVQQKEwRJTlJBMRQwEgYD\nVQQDEwtpZHAuaW5yYS5mcjEgMB4GCSqGSIb3DQEJARYRaXJpc0Bqb3V5LmlucmEu\nZnIwHhcNMTIxMTEzMTQ0MDM2WhcNMzcwNzMwMTQ0MDM2WjBpMQswCQYDVQQGEwJG\nUjETMBEGA1UECBMKU29tZS1TdGF0ZTENMAsGA1UEChMESU5SQTEUMBIGA1UEAxML\naWRwLmlucmEuZnIxIDAeBgkqhkiG9w0BCQEWEWlyaXNAam91eS5pbnJhLmZyMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1JTdk4XTqBi1r68i3u0qYR8P\n4NynVg2F7SoCLDf9ZXrpxMiyik135988ch/8mqyJK451klfCoLTgZfu1YfPQtU4x\nb463LyxSDX0SCnK4XQIBD7W6E+MysAa/hghTs1xamoNZOxZVXGSeRS6iLIZgaMfa\nO4+T/rWciwFJonESjtY2cw6HSx0OSR5lE/Lv/JDnfDMfpyF0dY4hNT8EWFzwwqMv\nq9TyeareTYMI4kd6+rw1bbX1HOWURNTFH3j+bnUx/uH3UMhywueuQTgYdR1wA/+X\n1lGsPy9k9uBQNMhJICL63O8wOLdDxuGWGjKUUF3eOv2W53zm0vA9vPkcnSqayQID\nAQABo4HOMIHLMB0GA1UdDgQWBBQuFYdp2C5bNykoCJKU6Zvck9npFjCBmwYDVR0j\nBIGTMIGQgBQuFYdp2C5bNykoCJKU6Zvck9npFqFtpGswaTELMAkGA1UEBhMCRlIx\nEzARBgNVBAgTClNvbWUtU3RhdGUxDTALBgNVBAoTBElOUkExFDASBgNVBAMTC2lk\ncC5pbnJhLmZyMSAwHgYJKoZIhvcNAQkBFhFpcmlzQGpvdXkuaW5yYS5mcoIJAOpq\nYvYKPY5EMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBACVWt4h6qZXm\ngGA+rFStbfxgVX+S749r9CuN+iwKObnwxI93SiiwNnb2PKO9OStTc8urvfNsgy8O\nvWGAZclkl2aeesV3r5oZxj26Jui2csSAh9SN0qozuTGStVxi7mCw4g+eT757IZs2\nFE2UnVn3QV2keLIsfk6excx9DcdomHhhaZXnqF/o8w8WUWRR8+RgoT8b2S1NjM63\nlJSyrOoagLkgU/k4XV81/NE+fWiQvNQl1GmcvtrN1UZmuza3g/miWRHxf6PgCC/M\nZbGGM6SI8RhHkV9rmtvlCAbI4nwkIxYP+RX7me4vueKiUCiuod40PJlRQ0D8Wrr7\nUCoh/SWrQNc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INRA - Institut National de la Recherche Agronomique"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jouy.inra.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INRA - Institut National de la Recherche Agronomique"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://confluence.it.su.se/Shibboleth.sso",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://confluence.it.su.se/Shibboleth.sso",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://confluence.it.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://confluence.it.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://confluence.it.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://confluence.it.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://confluence.it.su.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://confluence.it.su.se/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://confluence.it.su.se/Shibboleth.sso/WAYF/wavelan",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Confluence at Stockholm University"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Confluence vid Stockholms universitet"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "confluence-prod-app1"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAIF9hDgxtaCJMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFGNvbmZsdWVuY2UtcHJvZC1hcHAxMB4XDTEwMDgxNzEyNDg1OFoXDTIwMDgx\nNDEyNDg1OFowHzEdMBsGA1UEAxMUY29uZmx1ZW5jZS1wcm9kLWFwcDEwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDTnCJFt8KxDiKGg8q4R98rpkGrGe8F\nIxSZX/rYsbOShpAS4BybJIBsYPcU+DbWC3YXyYfC+iI1lYczw2hhfiENmrv7KEdB\nhHxA6+hCuDuPcH44EjQ/mT0Hx/SWdBSglzcQRnPHKCdedlJhdsV3gDeWTV2EYgrT\nGOB/k9pfDr2T6nvMnI1aPj33esHKfeVLqNALDRQuFyo7vEU5pejlarjIG7F+2KES\nMVunVGglxJTWvTT1FNqxuAR9j04p8XcMLj6NU20W9C2WaRPHC80crKLgBqcuymAY\nk2swFURnV5ubBRtWY/tIjMoYNeWgadsaKJFy2x7hJruM3qxUhT+LhRR9AgMBAAGj\nQjBAMB8GA1UdEQQYMBaCFGNvbmZsdWVuY2UtcHJvZC1hcHAxMB0GA1UdDgQWBBQR\nM1tnhL0IxstpiHXStoO0Ghr6YTANBgkqhkiG9w0BAQUFAAOCAQEA0DES8eLg3jwz\ntj0RkUS2IU574YX5B7WA/ZokuKVWnsZlhkVTQxzn1xvirV+wWhSf0mHQzSMfEEbR\nGtattonij6QCTKIDC9Whay+xjZRKag49yu/GEzyPYx6vU8mn0C3xvSlZPAyzwLU3\ng4cLnO3NPUpsArNLkWBT5KZ9t7ms85fkwgYLVhOJVavbDbfvslx4R6Cuf1w6kyxa\nUaa6b/2SBvN9dsAzmri0E4IEP21lWe9+k42cYuCbrJIQMJ3x7M+uvzi3JJB4s6ze\nqVpQDZd93P9YLQGNulZ1J4JdseJC6nAeXZY+iAiEBCyhx0+NQnlt+BZt7m76yNYi\n01e+X7VXbQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=confluence-prod-app1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "confluence-prod-app1"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAIF9hDgxtaCJMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFGNvbmZsdWVuY2UtcHJvZC1hcHAxMB4XDTEwMDgxNzEyNDg1OFoXDTIwMDgx\nNDEyNDg1OFowHzEdMBsGA1UEAxMUY29uZmx1ZW5jZS1wcm9kLWFwcDEwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDTnCJFt8KxDiKGg8q4R98rpkGrGe8F\nIxSZX/rYsbOShpAS4BybJIBsYPcU+DbWC3YXyYfC+iI1lYczw2hhfiENmrv7KEdB\nhHxA6+hCuDuPcH44EjQ/mT0Hx/SWdBSglzcQRnPHKCdedlJhdsV3gDeWTV2EYgrT\nGOB/k9pfDr2T6nvMnI1aPj33esHKfeVLqNALDRQuFyo7vEU5pejlarjIG7F+2KES\nMVunVGglxJTWvTT1FNqxuAR9j04p8XcMLj6NU20W9C2WaRPHC80crKLgBqcuymAY\nk2swFURnV5ubBRtWY/tIjMoYNeWgadsaKJFy2x7hJruM3qxUhT+LhRR9AgMBAAGj\nQjBAMB8GA1UdEQQYMBaCFGNvbmZsdWVuY2UtcHJvZC1hcHAxMB0GA1UdDgQWBBQR\nM1tnhL0IxstpiHXStoO0Ghr6YTANBgkqhkiG9w0BAQUFAAOCAQEA0DES8eLg3jwz\ntj0RkUS2IU574YX5B7WA/ZokuKVWnsZlhkVTQxzn1xvirV+wWhSf0mHQzSMfEEbR\nGtattonij6QCTKIDC9Whay+xjZRKag49yu/GEzyPYx6vU8mn0C3xvSlZPAyzwLU3\ng4cLnO3NPUpsArNLkWBT5KZ9t7ms85fkwgYLVhOJVavbDbfvslx4R6Cuf1w6kyxa\nUaa6b/2SBvN9dsAzmri0E4IEP21lWe9+k42cYuCbrJIQMJ3x7M+uvzi3JJB4s6ze\nqVpQDZd93P9YLQGNulZ1J4JdseJC6nAeXZY+iAiEBCyhx0+NQnlt+BZt7m76yNYi\n01e+X7VXbQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=confluence-prod-app1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://confluence.it.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://confluence.it.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://confluence.it.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://confluence.it.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://confluence.it.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://confluence.it.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://confluence.it.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://confluence.it.su.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://confluence.it.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://confluence.it.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://connect.ct.infn.it/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rocca"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:connect-support@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Carlo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rocca"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:connect-support@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Carlo"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://connect.ct.infn.it/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2015-06-12T06:20:52Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Adobe Connect erogato da INFN Catania"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Adobe Connect provided by INFN Catania"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ct.infn.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ct.infn.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INFN Catania"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INFN Catania"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://connect.ct.infn.it/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://connect.ct.infn.it/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect.ct.infn.it/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect.ct.infn.it/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://connect.ct.infn.it/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://connect.ct.infn.it/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://connect.ct.infn.it/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://connect.ct.infn.it/fedDocs/service.html"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is a web conferencing service that offers immersive online meeting experiences, from small group collaboration to large scale webinars, and includes an e-learning management system"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Si tratta di un servizio di web conferencing che permette di realizzare meeting on-line con una esperienze immersive completa, sia per piccoli gruppi che per webinar su larga scala, e include un sistema di gestione di e-learning"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://connect.ct.infn.it/fedDocs/privacy-policy.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Adobe Connect provided by INFN Catania"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Adobe Connect erogato da INFN Catania"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEnjCCA4agAwIBAgIQR8HgFoEMcUI/Kf1rkIpd1DANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMjAeFw0xNDExMjUwMDAwMDBaFw0xNzExMjQyMzU5NTlaMEAxITAfBgNVBAsT\nGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEbMBkGA1UEAxMSY29ubmVjdC5jdC5p\nbmZuLml0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAp+bwrXD1pEdX\n5+2zu5Rx7ty41z1iYC9Ezddz44UfLblteqI2JJyXeykVtXS5c+EHg6Bjgs7EE5Y8\n1p5ET56va0Q08nkcYz6strIxPb4fkoaRbIe+1r0RlFxYkd/DqX8LT98xH6AsrYwi\nRhZ4i9ODH93z+NFzw0LrSNhBy1g+Ul1JZ8UiWnU03JGDHhExoYWBYlnaQrYNBIMQ\niYt71elmORtnIJ4fKYoldwn4Wpu1umVd3Ywl9gXY/5MbF2G3u111gcj6dmrTozRb\n9ZcBBKvKumIlV6VcJYIt/C7Ia/aMIMzYTNbbgzq1hDMCT8utidE8MJxaAHEdOdiY\nkEE3l/VQZQIDAQABo4IBbjCCAWowHwYDVR0jBBgwFoAUW9CKHJoyW+C13ZZUG+GG\nKLD9tr0wHQYDVR0OBBYEFLvgAqEwKqOEH2MEM3NJCIM+ATL/MA4GA1UdDwEB/wQE\nAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcD\nAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAx\nMC+gLaArhilodHRwOi8vY3JsLnVzZXJ0cnVzdC5jb20vVEVSRU5BU1NMQ0EyLmNy\nbDBsBggrBgEFBQcBAQRgMF4wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudXNlcnRy\ndXN0LmNvbS9URVJFTkFTU0xDQTIuY3J0MCUGCCsGAQUFBzABhhlodHRwOi8vb2Nz\ncC51c2VydHJ1c3QuY29tMB0GA1UdEQQWMBSCEmNvbm5lY3QuY3QuaW5mbi5pdDAN\nBgkqhkiG9w0BAQsFAAOCAQEAS51Poo7JRQ11Mh4Byz9VoWDFi/KW4qSkmzLlwV1h\nqIuxrhzfM2Creo045ACB/Kt9kLSQy4eZORY2tFxigO6QUo34/WXHaKSivwfiLD7L\nQ8U8vVLPF7oURSiEi562vIHSAujkrlXjV5b+In8KRGaeNz7YWtb/D2d9E3Dhwcug\nTesm0DeA0lm/aXcgFBZkHlsv5cPjekHgNeucbNTWKvOw7SwF9rOwTtWgzVIbStpr\nUGAX0hfjfN0nh1VTB3uTzyA2bzdRgxZV+p7BRQIUc8wEaQOh5Xo9sc0eH8yNC06P\nTxwDvoKovgJyNC9DFgoVlWUxQNcW/HBYsGSDjT1xgWkyXw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect.ct.infn.it/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://connect.ct.infn.it/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect.ct.infn.it/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://connect.ct.infn.it/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://connect.ct.infn.it/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://connect.ct.infn.it/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Adobe Connect provided by INFN Catania"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Adobe Connect erogato da INFN Catania"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This is a web conferencing service that offers immersive online meeting experiences, from small group collaboration to large scale webinars, and includes an e-learning management system"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Si tratta di un servizio di web conferencing che permette di realizzare meeting on-line con una esperienze immersive completa, sia per piccoli gruppi che per webinar su larga scala, e include un sistema di gestione di e-learning"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idemidp.unipmn.it/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "FulvioScorza"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rete@unipmn.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idemidp.unipmn.it/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2015-01-20T14:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idemidp.unipmn.it/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idemidp.unipmn.it/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unipmn.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idemidp.unipmn.it/simplesaml/pagina.html"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idemidp.unipmn.it/simplesaml/pagina.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Piemonte Orientale"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universita degli studi del Piemonte Orientale"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for Piemonte Orientale university users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider per gli utenti dell Universita degli studi del Piemonte orientale"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idemidp.unipmn.it/simplesaml/logobaseupo129x60.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "129"
                  },
                  {
                    "text": "https://idemidp.unipmn.it/simplesaml/logobaseupo34x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "34"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://idemidp.unipmn.it/simplesaml/pagina.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://idemidp.unipmn.it/simplesaml/pagina.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEOTCCAyGgAwIBAgIJAPHensWnKvc4MA0GCSqGSIb3DQEBBQUAMIGyMQswCQYD\nVQQGEwJJVDEOMAwGA1UECAwFSXRhbHkxFDASBgNVBAcMC0FsZXNzYW5kcmlhMSow\nKAYDVQQKDCF1bml2ZXJzaXRhIGRlbCBwaWVtb250ZSBvcmllbnRhbGUxFjAUBgNV\nBAsMDXVmZmljaW8gcmVmb3MxGjAYBgNVBAMMEWlkZW1pZHAudW5pcG1uLml0MR0w\nGwYJKoZIhvcNAQkBFg5yZXRlQHVuaXBtbi5pdDAeFw0xNDA5MDIwOTM1MzFaFw00\nNDA4MjUwOTM1MzFaMIGyMQswCQYDVQQGEwJJVDEOMAwGA1UECAwFSXRhbHkxFDAS\nBgNVBAcMC0FsZXNzYW5kcmlhMSowKAYDVQQKDCF1bml2ZXJzaXRhIGRlbCBwaWVt\nb250ZSBvcmllbnRhbGUxFjAUBgNVBAsMDXVmZmljaW8gcmVmb3MxGjAYBgNVBAMM\nEWlkZW1pZHAudW5pcG1uLml0MR0wGwYJKoZIhvcNAQkBFg5yZXRlQHVuaXBtbi5p\ndDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALzKLUEUSuClrvGdFqdn\njAhBqxjjecka5KyBUY92QwqY0FSRzG14PN62ZHEghdLvZ8MBLrEuMUHfENNY1xFB\nk0rqydhooZmk6fW56WF3DGdFTkm7IvIxsqqTcxR2V1I2R10QHIaDYgx/fNE7VSd6\n7n7eP7PhwIslSDFcxq45M+ETa8VZ0q1256w7XyUsZFRSBZtrz+bY4hVf6pNpTLkk\nRRU0cbf2U2KmcNP8T05ax1PSupJX+RU6yMVvgXMQh86s6h8sKcD13oOj1OeM7CI1\ngH92uKM4HzxD7wmiFRlwPabCjPUZzBDggMgeOL96heJK8EtBH/yERq8CDvW0OYaR\nAtUCAwEAAaNQME4wHQYDVR0OBBYEFDbNfOhxDESf0UuXY6AarCfFlzvqMB8GA1Ud\nIwQYMBaAFDbNfOhxDESf0UuXY6AarCfFlzvqMAwGA1UdEwQFMAMBAf8wDQYJKoZI\nhvcNAQEFBQADggEBAFFI0ONX+syhY0MtoUrf5WPa8pmRFSxzjW0X/FB8kmGxfQ/w\n1P/ocgLffsjR32FEueGnWvBhSnsdxeMEhEjnMcCtqYm4g5+lbddpD11FyaDBXOeb\nAS0NPOsaEToivw/303/fepy9jv1+VGKOrDUJNwL4txEp8q7QD+9VrtRC2nPHnZeW\nBjwLPcfjJenFfLGcer9rguP1ca5QD10FPr3gFUBJl77E2ii1LfIRZ1+Ch+h3t8b8\nXzIpMr9KOQzrPy5rn5TVW66UWusGJZB9pHVK6mJroUQ2snSghcGWLczvgNcIWjW9\nYcakJXMzsLy+YtFi6nau47S1TJCnJPCFoWvElYQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEOTCCAyGgAwIBAgIJAPHensWnKvc4MA0GCSqGSIb3DQEBBQUAMIGyMQswCQYD\nVQQGEwJJVDEOMAwGA1UECAwFSXRhbHkxFDASBgNVBAcMC0FsZXNzYW5kcmlhMSow\nKAYDVQQKDCF1bml2ZXJzaXRhIGRlbCBwaWVtb250ZSBvcmllbnRhbGUxFjAUBgNV\nBAsMDXVmZmljaW8gcmVmb3MxGjAYBgNVBAMMEWlkZW1pZHAudW5pcG1uLml0MR0w\nGwYJKoZIhvcNAQkBFg5yZXRlQHVuaXBtbi5pdDAeFw0xNDA5MDIwOTM1MzFaFw00\nNDA4MjUwOTM1MzFaMIGyMQswCQYDVQQGEwJJVDEOMAwGA1UECAwFSXRhbHkxFDAS\nBgNVBAcMC0FsZXNzYW5kcmlhMSowKAYDVQQKDCF1bml2ZXJzaXRhIGRlbCBwaWVt\nb250ZSBvcmllbnRhbGUxFjAUBgNVBAsMDXVmZmljaW8gcmVmb3MxGjAYBgNVBAMM\nEWlkZW1pZHAudW5pcG1uLml0MR0wGwYJKoZIhvcNAQkBFg5yZXRlQHVuaXBtbi5p\ndDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALzKLUEUSuClrvGdFqdn\njAhBqxjjecka5KyBUY92QwqY0FSRzG14PN62ZHEghdLvZ8MBLrEuMUHfENNY1xFB\nk0rqydhooZmk6fW56WF3DGdFTkm7IvIxsqqTcxR2V1I2R10QHIaDYgx/fNE7VSd6\n7n7eP7PhwIslSDFcxq45M+ETa8VZ0q1256w7XyUsZFRSBZtrz+bY4hVf6pNpTLkk\nRRU0cbf2U2KmcNP8T05ax1PSupJX+RU6yMVvgXMQh86s6h8sKcD13oOj1OeM7CI1\ngH92uKM4HzxD7wmiFRlwPabCjPUZzBDggMgeOL96heJK8EtBH/yERq8CDvW0OYaR\nAtUCAwEAAaNQME4wHQYDVR0OBBYEFDbNfOhxDESf0UuXY6AarCfFlzvqMB8GA1Ud\nIwQYMBaAFDbNfOhxDESf0UuXY6AarCfFlzvqMAwGA1UdEwQFMAMBAf8wDQYJKoZI\nhvcNAQEFBQADggEBAFFI0ONX+syhY0MtoUrf5WPa8pmRFSxzjW0X/FB8kmGxfQ/w\n1P/ocgLffsjR32FEueGnWvBhSnsdxeMEhEjnMcCtqYm4g5+lbddpD11FyaDBXOeb\nAS0NPOsaEToivw/303/fepy9jv1+VGKOrDUJNwL4txEp8q7QD+9VrtRC2nPHnZeW\nBjwLPcfjJenFfLGcer9rguP1ca5QD10FPr3gFUBJl77E2ii1LfIRZ1+Ch+h3t8b8\nXzIpMr9KOQzrPy5rn5TVW66UWusGJZB9pHVK6mJroUQ2snSghcGWLczvgNcIWjW9\nYcakJXMzsLy+YtFi6nau47S1TJCnJPCFoWvElYQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universita degli studi del Piemonte Orientale"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Piemonte Orientale"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.unipmn.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.unipmn.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universita degli studi del Piemonte Orientale"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Piemonte Orientale"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://auth.centrale-marseille.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp@centrale-marseille.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://auth.centrale-marseille.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-03-18T19:08:09Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.centrale-marseille.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.centrale-marseille.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://auth.centrale-marseille.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "centrale-marseille.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.centrale-marseille.fr/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "centrale marseille's accounts"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "comptes centrale marseille"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAIAAACQkWg2AAAACXBIWXMAAABIAAAASABGyWs+AAAACXZwQWcAAAAQAAAAEABcxq3DAAAAOklEQVQoz2OM2vmMgRTARJLqAdSw1E1yqZvkADmJBc0lWLnRu55TyQa4SRCzkQ0eKE9jum0gnESyBgDIag8jNxmXrAAAACV0RVh0ZGF0ZTpjcmVhdGUAMjAxNS0wNy0yMFQxMDo0ODo1MyswMjowMELyvfEAAAAldEVYdGRhdGU6bW9kaWZ5ADIwMTUtMDctMjBUMTA6NDg6NTMrMDI6MDAzrwVNAAAAAElFTkSuQmCC",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Centrale de Marseille"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Centrale de Marseille"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIVAIXPHZ3UF1uopseaVJtC6GfpVUo7MA0GCSqGSIb3DQEB\nBQUAMCUxIzAhBgNVBAMMGmF1dGguY2VudHJhbGUtbWFyc2VpbGxlLmZyMB4XDTE1\nMDMxNjIwNTQyOFoXDTM1MDMxNjIwNTQyOFowJTEjMCEGA1UEAwwaYXV0aC5jZW50\ncmFsZS1tYXJzZWlsbGUuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQCIi4zEBXUYAS9Ti7HQojxfj7lHM1bCRoT8lgLALEWSwNTCVCkzQl+DS0FPDZ0v\n8a9FaT1HjfocwZ1XdwoDxDCrqQFwxRA30iM6/uuh9/0HVZCFhQK2/Ikn1Pj6MLIF\nF/pLQWYSdUJurfRjf3St97Rbaq9ONiMXyNR2l2WZEG49cg1DfGA5+lP+uU5F5zSs\nrUzrJpPuf4T2AQSnki++OeyGM1/tY4/NjswbSZlTzmPicFulrRXj4tNi7bOX6yzi\nJGb/ziQHVqDU4vQQcE1R6KOWZuGhvlZSzGZeh1J2WlaqgyH9IeeknriOFqw3LcOR\ntZV9FqbuYNOFw9/EIxBS79NtAgMBAAGjezB5MB0GA1UdDgQWBBSeGwSZ7BVXmyys\nYKVg8WZHfkxurDBYBgNVHREEUTBPghphdXRoLmNlbnRyYWxlLW1hcnNlaWxsZS5m\ncoYxaHR0cHM6Ly9hdXRoLmNlbnRyYWxlLW1hcnNlaWxsZS5mci9pZHAvc2hpYmJv\nbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAMs7S8ihpctE3q4ALf/iKvFNEfDxEggwu\nQ7N4uEG5HWiBBlalVagxWnXf3pJDd4ol/S5evquXaqede0q4Fdc3dg29v/sI319R\nn2z8hBEohWeBs/o4LuIsfkyyvRJTT6JzJJIcoxYthk6vt5KOAKQD9Q1YWihw6mfr\niLV1efef406mrFp+fI/wlk4gj+h35b0Y0lBIah8z09mo8rwiXwOQc9k6rOc5PQOQ\nx1SkY7gFvgEwa1vQqKLuP+nIdkl93oZKD7mqLSIbR6bB4DM4bzD0W1Qw1yPvTGgs\nc9UsyilhfC2LFkhv/O9OaTuk0Wy9R+P5q6J0ma7UyWfq8Rc1fxZZIA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ecole Centrale de Marseille"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.centrale-marseille.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ecole Centrale de Marseille"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp-staf-prod.cineca.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tecnical Staff"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@cineca.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-staf-prod.cineca.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2011-05-25T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEezCCA2OgAwIBAgIQHvkLjPc6sKc/y3ML5fDtCjANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDgyOTAwMDAwMFoXDTE2MDgyODIzNTk1OVowRTEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMSAwHgYDVQQDExdpZHAtc3RhZi1w\ncm9kLmNpbmVjYS5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL1o\nS5a3gDgHXWvpiXSIMP27bxsuFk4+C1zWUAP1OA8ryPf4RI1PfWzqSCosY4BJv43a\nOe3nvkKJ5bZN2bAD8+Swd87ErVglHIopx4eUdjDeKGl9QvOzWLVnbP7EWxQtr8UO\n4chaywyiixUSZ95yf2dY/5x3bhiong46mFPBj7aUYw5WBgPy9DgVYYF/i3DRSUMp\nmEtYFNGTOGRkqDosTN4zF+tksQUcOJGwZ+AYtb0tjgefPJ18wYi/UQWYaDgW9Tuv\nFgw2BPn7iC7gj0cUgGrT8JtAH9wZsrUvJHSPGmnu2moKHrLFwol36wD/FxJPCbTo\n5T/+PXuSePY4/7j62MUCAwEAAaOCAXQwggFwMB8GA1UdIwQYMBaAFAy9k2gM896r\no0lrKzdXR+qQ47ntMB0GA1UdDgQWBBSZiwnGwfISVNpZA5rwwrXyP9a2azAOBgNV\nHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYI\nKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYD\nVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFT\nU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0\nLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0\ncDovL29jc3AudGNzLnRlcmVuYS5vcmcwIgYDVR0RBBswGYIXaWRwLXN0YWYtcHJv\nZC5jaW5lY2EuaXQwDQYJKoZIhvcNAQEFBQADggEBAAfichwgOLLw/LMdKky6/k9+\nszwlUqnZ9T7ReNXmK+csh2ZaXp3BTIDPsA6W51biiWvTT15jcIlsMKGPdQVIUfwQ\ns1Ad7XP/21AWj6PC7MuBxBxRdSjPp6/dg2dx7gNyR3o1H37MlueD6c2N0A6lGcxJ\nN26ippAsHEIFeKPqHFiWH+qaKdxLDN/rY86QSmJiv8k03qJc8kFE7mGL42ZPxmB2\nU4h397kwgoSX2U9JmMp9IMdhI3osgFEX02Hfjiqb31kjwF/H8jNIdSbkJvWOdGL+\nPXnuP6cpOu/jRJmIlE28j4zIeBBNNB86tTBwAVYaJSM4QdcGW9JaNO6WNZC7rUw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cineca.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-is.cineca.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-is.cineca.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-is.cineca.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-is.cineca.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-is.cineca.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-is.cineca.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-is.cineca.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-is.cineca.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cineca.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.cineca.it/content/idem"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.cineca.it/content/idem"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CINECA"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CINECA"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for CINECA users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider per gli utenti CINECA"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp-is.cineca.it/idp/images/cineca-logo-16.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp-is.cineca.it/idp/images/cineca-logo-16.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp-is.cineca.it/idp/images/cineca-logo-60.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  },
                  {
                    "text": "https://idp-is.cineca.it/idp/images/cineca-logo-60.png",
                    "lang": "it",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.cineca.it/content/idem"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.cineca.it/content/idem"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEezCCA2OgAwIBAgIQHvkLjPc6sKc/y3ML5fDtCjANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDgyOTAwMDAwMFoXDTE2MDgyODIzNTk1OVowRTEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMSAwHgYDVQQDExdpZHAtc3RhZi1w\ncm9kLmNpbmVjYS5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL1o\nS5a3gDgHXWvpiXSIMP27bxsuFk4+C1zWUAP1OA8ryPf4RI1PfWzqSCosY4BJv43a\nOe3nvkKJ5bZN2bAD8+Swd87ErVglHIopx4eUdjDeKGl9QvOzWLVnbP7EWxQtr8UO\n4chaywyiixUSZ95yf2dY/5x3bhiong46mFPBj7aUYw5WBgPy9DgVYYF/i3DRSUMp\nmEtYFNGTOGRkqDosTN4zF+tksQUcOJGwZ+AYtb0tjgefPJ18wYi/UQWYaDgW9Tuv\nFgw2BPn7iC7gj0cUgGrT8JtAH9wZsrUvJHSPGmnu2moKHrLFwol36wD/FxJPCbTo\n5T/+PXuSePY4/7j62MUCAwEAAaOCAXQwggFwMB8GA1UdIwQYMBaAFAy9k2gM896r\no0lrKzdXR+qQ47ntMB0GA1UdDgQWBBSZiwnGwfISVNpZA5rwwrXyP9a2azAOBgNV\nHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYI\nKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYD\nVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFT\nU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0\nLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0\ncDovL29jc3AudGNzLnRlcmVuYS5vcmcwIgYDVR0RBBswGYIXaWRwLXN0YWYtcHJv\nZC5jaW5lY2EuaXQwDQYJKoZIhvcNAQEFBQADggEBAAfichwgOLLw/LMdKky6/k9+\nszwlUqnZ9T7ReNXmK+csh2ZaXp3BTIDPsA6W51biiWvTT15jcIlsMKGPdQVIUfwQ\ns1Ad7XP/21AWj6PC7MuBxBxRdSjPp6/dg2dx7gNyR3o1H37MlueD6c2N0A6lGcxJ\nN26ippAsHEIFeKPqHFiWH+qaKdxLDN/rY86QSmJiv8k03qJc8kFE7mGL42ZPxmB2\nU4h397kwgoSX2U9JmMp9IMdhI3osgFEX02Hfjiqb31kjwF/H8jNIdSbkJvWOdGL+\nPXnuP6cpOu/jRJmIlE28j4zIeBBNNB86tTBwAVYaJSM4QdcGW9JaNO6WNZC7rUw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CINECA Consorzio Interuniversitario"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CINECA Inter-University Consortium"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cineca.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cineca.it/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CINECA"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CINECA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp-staging.shibboleth.ox.ac.uk/shibboleth-idp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:iam@it.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Identity and Access Management"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:iam@it.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Identity and Access Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-staging.shibboleth.ox.ac.uk/shibboleth-idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-01-20T09:42:30Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-staging.shibboleth.ox.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-staging.shibboleth.ox.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-staging.shibboleth.ox.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-staging.shibboleth.ox.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-staging.shibboleth.ox.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-staging.shibboleth.ox.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ox.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDajCCAlKgAwIBAgIVAIAtmK4I7O7bvf0RPA0ZNHo2hkSAMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMCoxKDAmBgNVBAMMH2lkcC1zdGFnaW5nLnNoaWJib2xldGgub3guYWMudWsw\n\t\t\t\t\t\tHhcNMTYwMTE0MTczMTAyWhcNMzYwMTE0MTczMTAyWjAqMSgwJgYDVQQDDB9pZHAt\n\t\t\t\t\t\tc3RhZ2luZy5zaGliYm9sZXRoLm94LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAlzER+bRzfZzTQ8dJKKfyBC6niOcIMI8fpEK3MDOFRaNjmrrm\n\t\t\t\t\t\tZShSh0ea/a0XcuK2KE1nJbqBdDYnLps120T/qCUd21dqL+z62HPMjSOddJvj5TNa\n\t\t\t\t\t\tvylmkLQHNxhbzdqY6IghQWUIvbNKujQMe632ZIR3mx6t/yAXG9H4r1/0vzbcDGS+\n\t\t\t\t\t\tqtGIgOlnxTxS8RFfw4dKV8FdaeljvlmL8nqHMhdmR7SEjnZ0m08v20kmKG6Siu2f\n\t\t\t\t\t\tQD0/B3s23rz/M7e6z4mGc1OrSUzmuPZHnyY8A6eLZbYMbd7RCO34gs1TXVGTEY/t\n\t\t\t\t\t\tAnfcZF3sqk1PPpVn4MQAJrcunx06TAzqlvhQTwIDAQABo4GGMIGDMB0GA1UdDgQW\n\t\t\t\t\t\tBBSWC0uobK7TWktESwIkRr0J2+tltDBiBgNVHREEWzBZgh9pZHAtc3RhZ2luZy5z\n\t\t\t\t\t\taGliYm9sZXRoLm94LmFjLnVrhjZodHRwczovL2lkcC1zdGFnaW5nLnNoaWJib2xl\n\t\t\t\t\t\tdGgub3guYWMudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAD1u\n\t\t\t\t\t\tAItT11Prv9vZFYJeLgaMKwcFifjuBgbTW1e/6Z56LtsnRCVYeoaAL0isxkNuRpLg\n\t\t\t\t\t\t25aFKkN+iU1TIuD8Qd2j36EtVA8CqVH2iybnwLky2jWZh75dbYyOCvp0YUSCPBPJ\n\t\t\t\t\t\tOIVmhxVH5trGgcn6mWvKBqlOwxRzPi5xPV/WzQvRwb18VMKPHTgfgVMO8By/dxYV\n\t\t\t\t\t\tz7bXOSrQjLP60GNEg1ruVkYIMQCp2kAukFU61xmOhDX2u/2cUhOLchU6WGX2NkOV\n\t\t\t\t\t\tsfemgQTqBY1Rk1/XM+fn4aKWfsbmvAJilAD46sUZtiBvUNlMLwAb9j49t0aITeNz\n\t\t\t\t\t\tCjMKBIk+697oQF/5Zhw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDaDCCAlCgAwIBAgITekZgmzIaNoFuS/6wcr6UR9MwiDANBgkqhkiG9w0BAQsF\n\t\t\t\t\t\tADAqMSgwJgYDVQQDDB9pZHAtc3RhZ2luZy5zaGliYm9sZXRoLm94LmFjLnVrMB4X\n\t\t\t\t\t\tDTE2MDExNDE3MzA1NFoXDTM2MDExNDE3MzA1NFowKjEoMCYGA1UEAwwfaWRwLXN0\n\t\t\t\t\t\tYWdpbmcuc2hpYmJvbGV0aC5veC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBAI+WPG01l8PhqRj4EpKqLOCs5PIsWMhrjSEUtK7Q2TV5vbsmtEFm\n\t\t\t\t\t\tyivfgB3ZQeUedxhMY5gD7wHbVzRf/bUmxz+I2orfOpBsaDxh6TH1J7NIbDXUyK+J\n\t\t\t\t\t\ttF0jirsCWjYHZ1gGj/OshWjCQvWP4qX4e4pYmIdyTJJpIi2KIRwxh7KVAedFbdT+\n\t\t\t\t\t\tdqgOnaygrjZ6jV49RyJ+FLUU1E+g61jL4bIl4fsipLm/zy4N6+qo85BV2JFLd/xU\n\t\t\t\t\t\tLaTBO9IhxYxsU0Qo2GMzGD+XE2o5+w42QUfBYRd8xEVQkNbxTwxzTV+gcMpbfRys\n\t\t\t\t\t\tYNCMmVmSb3zGMyZNUJOeatVYV04GAxcEcdUCAwEAAaOBhjCBgzAdBgNVHQ4EFgQU\n\t\t\t\t\t\t4pAfbU3vAHNn9RLiF+8p5f8aEwkwYgYDVR0RBFswWYIfaWRwLXN0YWdpbmcuc2hp\n\t\t\t\t\t\tYmJvbGV0aC5veC5hYy51a4Y2aHR0cHM6Ly9pZHAtc3RhZ2luZy5zaGliYm9sZXRo\n\t\t\t\t\t\tLm94LmFjLnVrL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQCFuOAP\n\t\t\t\t\t\ta1jPW7sQIL536NCD9t/m3rBNk6xIIkgTDVbTOU/xpj6JsEOm3WiO/ukRPfDybYNJ\n\t\t\t\t\t\tQ9rHqSvM6/IB/Ao0cdgnMbTf5yoYhBy7F5HXv7NXyYHZ/tTnIIr/fLZpzXnjb6PQ\n\t\t\t\t\t\tLSJi70+wK0TdTLA5eHXW04h8h12Tt/aRHZ76rP+F/JykrLX2okgP1FQAc5JOYtDC\n\t\t\t\t\t\tbQjgdqBZIu75bAIOOGPEHtwD9glkbpP3prJZo6Ib9kxXEA3C3FRgXSOL8bC18lx3\n\t\t\t\t\t\tsqFWVybrxsBpkuXMazAh7vzbszSc5PRDllivVZCEVzzj3+uNR6s1GwBcDvOQzvJs\n\t\t\t\t\t\txMLJFJJld3a0yB22"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDajCCAlKgAwIBAgIVAPRlUe+MIjGNcHPwwfonzqdE0uphMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMCoxKDAmBgNVBAMMH2lkcC1zdGFnaW5nLnNoaWJib2xldGgub3guYWMudWsw\n\t\t\t\t\t\tHhcNMTYwMTE0MTczMDU0WhcNMzYwMTE0MTczMDU0WjAqMSgwJgYDVQQDDB9pZHAt\n\t\t\t\t\t\tc3RhZ2luZy5zaGliYm9sZXRoLm94LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAiLVYz2X2tTa7+ujJmdeI2Hg2hDmEejDV2MzXGJgVkyQ/mt08\n\t\t\t\t\t\t8a2cEK+4SkSDSwYtQG1ru0yn5OjB38HTcFpUbxGpMl/1WOIPGxHYb55p+d0DR0q6\n\t\t\t\t\t\t+08y1vlwT5h4RVFaFj+Tx0LmDcip5kxYzPkmItiunKsMOsxDgnuC1yFxT/UFors+\n\t\t\t\t\t\tZWsb8wkbk2OX0K3jHbD3Hbm7bqmKOIp5NsmZaSbXUOw3FIxnPZwX+oZLerU7LRgd\n\t\t\t\t\t\tdHrLdtf8Q5FUCuVPESjTyGw/k62LlTJRcCUXrlJ3K2mZZET3M+Xl+B/jl4NVBp4v\n\t\t\t\t\t\tNPmpKuRlwNejIKKHy0Cb5utpJCPg5JHVa6qESwIDAQABo4GGMIGDMB0GA1UdDgQW\n\t\t\t\t\t\tBBQm5+FRSx0Sid4vbNqz8nzNjRLV3TBiBgNVHREEWzBZgh9pZHAtc3RhZ2luZy5z\n\t\t\t\t\t\taGliYm9sZXRoLm94LmFjLnVrhjZodHRwczovL2lkcC1zdGFnaW5nLnNoaWJib2xl\n\t\t\t\t\t\tdGgub3guYWMudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBACPw\n\t\t\t\t\t\t86BQmyOetDs77HbNi8ixLchm29yxdvpSTwJeyjtGo2y6puW0lZQm4P4hEQSHHnLj\n\t\t\t\t\t\twQpgq8XbQkep3ZOBObeVAbfrjSr0jL+ZCIogUveEpsIFwJRvamEZX679gzw0sRgK\n\t\t\t\t\t\tC+CqY2raoShDE+tlrfjOTGEULJ3icNvrvy+babwlKQDKxUVu4mROwoet7tIe4jm6\n\t\t\t\t\t\tVzgVIhY7jGZH59TvcN32ddAlYbzlqxbP+89yzOY4jUPDpUym41m1CUc2a4ne7e1u\n\t\t\t\t\t\tlOakNEYy9WRL8/SBEMSQdlAs5vKh6nvlOdX9cYLGJEQ/BpRPB40O6eqbcFbIhJSk\n\t\t\t\t\t\tUf13ppG6F4RF0QOHD3Y="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Oxford, Staging IdP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://it.ox.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Oxford"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://testgih.pingpong.net/Shibboleth.sso/Metadata",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://testgih.pingpong.net/Shibboleth.sso/Metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://testgih.pingpong.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://testgih.pingpong.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://testgih.pingpong.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://testgih.pingpong.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://testgih.pingpong.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "test: L\u00e4rplattformen PING PONG vid Gymnastik- och idrottsh\u00f6gskolan."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "test: The learning platform PING PONG at The Swedish School of Sport and Health Sciences."
                  }
                ],
                "logo": [
                  {
                    "text": "https://testgih.pingpong.net/login/pingpong-logo-168x50.png",
                    "height": "168",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "https://testgih.pingpong.net/login/pingpong-logo-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TEST-PING PONG vid GIH"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TEST-PING PONG at GIH"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://testgih.pingpong.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "krusbar.pingpong.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAMVvfL7J0nz+MA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFGtydXNiYXIucGluZ3BvbmcubmV0MB4XDTEyMDYyODE1MDYzMFoXDTIyMDYy\nNjE1MDYzMFowHzEdMBsGA1UEAxMUa3J1c2Jhci5waW5ncG9uZy5uZXQwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCvh+Jg4oen/vUUGtx9eAaYY5rXtTFl\n1nMfq5x3XghdSV8uPg4bQ6VXw/9fZVTnAO3iFrF1LrfjuZWhZN2iL40nXfM1isSR\nmDZDF7CgqwsnoaVodgS/OyL9Q9iGOaXrM2lrN4ucuFAZcd3MUIrZjyBp3jtWkuTp\nT1VHnicxVWbT8VsjrWAdj1MUFv2IeWPP1it+4dwUDZrLqKhRWnFAo8zGHXiyO+aw\nU1Qb/52EShNykDHWBbtzgadLhPQzWQy5E457wvNVFbad0cc29vASufbIhzBGE/U3\nDdVI6jphpn5QMZfHhl9BLoqr9MJh1F1BRlL+HOcLXbQqg0JD/d1d7XAjAgMBAAGj\nQjBAMB8GA1UdEQQYMBaCFGtydXNiYXIucGluZ3BvbmcubmV0MB0GA1UdDgQWBBQd\nqBIVHafXKIz/Jr3tdLtcKbzR8zANBgkqhkiG9w0BAQUFAAOCAQEAKYOuyj800ABK\nR99elNxsDEddcjmIJQbO5tAosETGVlyqqdWL2D1rtSw0CTQiaba5Ae/TcgR/fnOv\n1g3uBZA26iQPbzsKGKYsB21aUEPJO0ZVhTdcid1tS672fOIZf1Y8+hmNh1psAurp\nDNOpoBNLoM8S8P95Q7hM6xLM76D1R61q4kO3np/YLYwNQSsHnHddu8/9oJu5j7oV\nKGPGrSczPfxG4plIUxm5tzNkHqNyYQttKrXGqdtCdkwjtYxS48G/ba1XkR/+baMf\nD8OuFV1n1oNCM9fqRzlCOyA7ISZyMlfiMCP3HXs53AcrRAnUKYwkP6Q4dIPS3C4Y\nLaCAPwuThQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=krusbar.pingpong.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://testgih.pingpong.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://auth.ut.ee/idp/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "eenet@eenet.ee"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TAAT"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://auth.ut.ee/idp/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://taat.edu.ee/main/documents/?lang=en"
              }
            ],
            "registration_authority": "http://taat.edu.ee",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.ut.ee/idp/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "want_authn_requests_signed": "true",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.ut.ee/idp/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ut.ee"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "ru",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u0422\u0430\u0440\u0442\u0443\u0441\u043a\u0438\u0439 \u0443\u043d\u0438\u0432\u0435\u0440\u0441\u0438\u0442\u0435\u0442"
          },
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Tarton yliopisto"
          },
          {
            "lang": "et",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Tartu \u00dclikool"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Tartu"
          }
        ],
        "organization_url": [
          {
            "lang": "et",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ut.ee/et/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ut.ee/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "et",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Tartu \u00dclikool"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Tartu"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.fanshawec.ca/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Technical contact"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pgilbert@fanshawec.ca"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.fanshawec.ca/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.canarie.ca/templates/services/docs/CAF_join_en.pdf"
              }
            ],
            "registration_instant": "2012-08-28T00:00:00Z",
            "registration_authority": "http://www.canarie.ca",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUCXF2tM/DJVzBFEwQQH2q5KLdt3UwDQYJKoZIhvcNAQEF BQAwHTEbMBkGA1UEAxMSbG9naW4uZmFuc2hhd2VjLmNhMB4XDTEzMTEwODE4Mzc0 MloXDTMzMTEwODE4Mzc0MlowHTEbMBkGA1UEAxMSbG9naW4uZmFuc2hhd2VjLmNh MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAiuS4iCDj0Nr7+o+sY+5N CZ1sx6RLgx00FlwQep1t8D8Aszrt+5dF2YzwhHYS80NtlB+aGjoK/Qfd2hPi7PXL CtZ7fCFJu2hEW3Nsit4zWeT6rwtivzXdVU8hzJ+IE71OzY0fhN+8TByzdxCzG2qp q77lxYvtk/HBQ7P3PnWSblEdiMD3x9hLGRpojPBtvMkFwBi28q+lkb8tIHHOPnNX 8dA3j455JUZw0Tt7GFDqi9/Ists7v5sGUT3u3A3+CB4TP8G8Y23XIdj085erMZHQ fOkxb0mMYSvXYRwZ8BAog9rp8EjiiOSr7/U3r4VLqWeMFtalNOAGm0DD9W0/g/Ym 9wIDAQABo2swaTBIBgNVHREEQTA/ghJsb2dpbi5mYW5zaGF3ZWMuY2GGKWh0dHBz Oi8vbG9naW4uZmFuc2hhd2VjLmNhL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQl f5iwDg4cIOa6dyG4kxa5k4QE0jANBgkqhkiG9w0BAQUFAAOCAQEAKudffW4nWF+/ 3GDt54Jbq5DWogflPP9KhZMYy3L/G241zXvqqu/OyM+dw8qx9p5YCgvhGYBJJ+b7 n63f9QhK0y0K+r7sgy+Mce3Ceo33e0sglP9orY/xSu7iryQnVnNtRI/UFdOvEPc8 JPvaf+yKHnAkpzyWYI8FZragWJXpa2MVzTTKqqEdYsMES5NQ5U7Zv5A/tY/D90Cx 3R5IaWcxDxVgOZziRniD8XD5EWmAMLhl4emeWQXyfI6LuhL4pTaaR1XUxaouCkj2 K2PKk+T/tJ7BHzT8hbdIlYt08yDPLB6nwvEMRNGoy5yn5zDFFMzxV0DS043+xfCJ 2oLUUamGDQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "true",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "(.*\\.|)fanshawec.ca"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.fanshawec.ca:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.fanshawec.ca:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.fanshawec.ca/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.fanshawec.ca/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.fanshawec.ca:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.fanshawec.ca/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.fanshawec.ca/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.fanshawec.ca/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.fanshawec.ca/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.fanshawec.ca:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.fanshawec.ca:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fanshawec.ca"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.fanshawec.ca/"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.fanshawec.ca/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Fanshawe College"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Fanshawe College"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Fanshawe College"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Fanshawe College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUCXF2tM/DJVzBFEwQQH2q5KLdt3UwDQYJKoZIhvcNAQEF BQAwHTEbMBkGA1UEAxMSbG9naW4uZmFuc2hhd2VjLmNhMB4XDTEzMTEwODE4Mzc0 MloXDTMzMTEwODE4Mzc0MlowHTEbMBkGA1UEAxMSbG9naW4uZmFuc2hhd2VjLmNh MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAiuS4iCDj0Nr7+o+sY+5N CZ1sx6RLgx00FlwQep1t8D8Aszrt+5dF2YzwhHYS80NtlB+aGjoK/Qfd2hPi7PXL CtZ7fCFJu2hEW3Nsit4zWeT6rwtivzXdVU8hzJ+IE71OzY0fhN+8TByzdxCzG2qp q77lxYvtk/HBQ7P3PnWSblEdiMD3x9hLGRpojPBtvMkFwBi28q+lkb8tIHHOPnNX 8dA3j455JUZw0Tt7GFDqi9/Ists7v5sGUT3u3A3+CB4TP8G8Y23XIdj085erMZHQ fOkxb0mMYSvXYRwZ8BAog9rp8EjiiOSr7/U3r4VLqWeMFtalNOAGm0DD9W0/g/Ym 9wIDAQABo2swaTBIBgNVHREEQTA/ghJsb2dpbi5mYW5zaGF3ZWMuY2GGKWh0dHBz Oi8vbG9naW4uZmFuc2hhd2VjLmNhL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQl f5iwDg4cIOa6dyG4kxa5k4QE0jANBgkqhkiG9w0BAQUFAAOCAQEAKudffW4nWF+/ 3GDt54Jbq5DWogflPP9KhZMYy3L/G241zXvqqu/OyM+dw8qx9p5YCgvhGYBJJ+b7 n63f9QhK0y0K+r7sgy+Mce3Ceo33e0sglP9orY/xSu7iryQnVnNtRI/UFdOvEPc8 JPvaf+yKHnAkpzyWYI8FZragWJXpa2MVzTTKqqEdYsMES5NQ5U7Zv5A/tY/D90Cx 3R5IaWcxDxVgOZziRniD8XD5EWmAMLhl4emeWQXyfI6LuhL4pTaaR1XUxaouCkj2 K2PKk+T/tJ7BHzT8hbdIlYt08yDPLB6nwvEMRNGoy5yn5zDFFMzxV0DS043+xfCJ 2oLUUamGDQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Fanshawe College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://fanshawec.ca"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Fanshawe College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www4.genuinetext.com/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www4.genuinetext.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www4.genuinetext.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www4.genuinetext.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www4.genuinetext.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www4.genuinetext.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www4.genuinetext.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www4.genuinetext.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www4.genuinetext.com"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAKekqkqvTaFGMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFHd3dzQuZ2VudWluZXRleHQuY29tMB4XDTEwMTEwMTEzMzMyM1oXDTIwMTAy\nOTEzMzMyM1owHzEdMBsGA1UEAxMUd3d3NC5nZW51aW5ldGV4dC5jb20wggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDADxHC/Xm6WdlyLSPS754suXc2FSqo\nxnfXXhnAE7ZfhVhD8PIanswRPq5YCAZm3MVBZUsV5cI/nlXNBOuyiv4+P5KG2fIi\nMIEaDoWSa9UCnQ8xr/nF1towuhlTkJ5FX/n8P3jIw6/crilOzD+HmL94iiCSAG87\njU/H7fhnm10KMjfPpMthD7PxQLU0u8J+dJ0kfzRzsv+ico7v4yzTSZUOVkLiYl2z\nhw4WKWz6px2sdNpBkBGjw+BuOpVyuTHZTw8Wf/b4FWhY4WvIBM6FonH7bvIYUdgz\nsgYJEW/cYPiP590QKOQX4yPv8UWZT7QqimI5r7UVZAlwmU/nnswnIg0VAgMBAAGj\nQjBAMB8GA1UdEQQYMBaCFHd3dzQuZ2VudWluZXRleHQuY29tMB0GA1UdDgQWBBSG\n3sJULU8LbAUhqhTxd0Lej7QzGzANBgkqhkiG9w0BAQUFAAOCAQEAl+pmNhY8cPox\nx7vEvy0q1VXWbuu3BMauQs53Zv6NpLmmcXpGaPfNAKpKduYUHBCqUHeQBDyFppdz\nM/YhperS0/zQu9nwi5MKINx1/+hUG7g8WbR7FzlMAVuYByMDJSi3Ofiz57PHmjPr\neCulUcFlFMsSpozk2vuTt5Mou92Cxv+JHvh5rvdjQf68xr1K7rS/n40igixsUwh7\nB1WDIB8S6ng+7XqUxnVH1XXfZI9JslSp1f2eNFx/3ajYGotewmVquDS5Jg6IYSJL\nkIbZGzwQ9C6RneoNDIirnfYZogu3XFNwix8uFTvl9EI4rxvJZjH5WFWr/1rWcmgo\niMZC8zXUhA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www4.genuinetext.com"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www4.genuinetext.com"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAKekqkqvTaFGMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFHd3dzQuZ2VudWluZXRleHQuY29tMB4XDTEwMTEwMTEzMzMyM1oXDTIwMTAy\nOTEzMzMyM1owHzEdMBsGA1UEAxMUd3d3NC5nZW51aW5ldGV4dC5jb20wggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDADxHC/Xm6WdlyLSPS754suXc2FSqo\nxnfXXhnAE7ZfhVhD8PIanswRPq5YCAZm3MVBZUsV5cI/nlXNBOuyiv4+P5KG2fIi\nMIEaDoWSa9UCnQ8xr/nF1towuhlTkJ5FX/n8P3jIw6/crilOzD+HmL94iiCSAG87\njU/H7fhnm10KMjfPpMthD7PxQLU0u8J+dJ0kfzRzsv+ico7v4yzTSZUOVkLiYl2z\nhw4WKWz6px2sdNpBkBGjw+BuOpVyuTHZTw8Wf/b4FWhY4WvIBM6FonH7bvIYUdgz\nsgYJEW/cYPiP590QKOQX4yPv8UWZT7QqimI5r7UVZAlwmU/nnswnIg0VAgMBAAGj\nQjBAMB8GA1UdEQQYMBaCFHd3dzQuZ2VudWluZXRleHQuY29tMB0GA1UdDgQWBBSG\n3sJULU8LbAUhqhTxd0Lej7QzGzANBgkqhkiG9w0BAQUFAAOCAQEAl+pmNhY8cPox\nx7vEvy0q1VXWbuu3BMauQs53Zv6NpLmmcXpGaPfNAKpKduYUHBCqUHeQBDyFppdz\nM/YhperS0/zQu9nwi5MKINx1/+hUG7g8WbR7FzlMAVuYByMDJSi3Ofiz57PHmjPr\neCulUcFlFMsSpozk2vuTt5Mou92Cxv+JHvh5rvdjQf68xr1K7rS/n40igixsUwh7\nB1WDIB8S6ng+7XqUxnVH1XXfZI9JslSp1f2eNFx/3ajYGotewmVquDS5Jg6IYSJL\nkIbZGzwQ9C6RneoNDIirnfYZogu3XFNwix8uFTvl9EI4rxvJZjH5WFWr/1rWcmgo\niMZC8zXUhA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www4.genuinetext.com"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www4.genuinetext.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www4.genuinetext.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www4.genuinetext.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www4.genuinetext.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www4.genuinetext.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www4.genuinetext.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www4.genuinetext.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www4.genuinetext.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www4.genuinetext.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www4.genuinetext.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://randevu.lab.vvc.niif.hu/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NIIFI AAI"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@niif.hu"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NIIFI AAI"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@niif.hu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NIIFI AAI"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@niif.hu"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://randevu.lab.vvc.niif.hu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-edugain"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:geant:niif.hu:eduid.hu:entity-attributes:processing-info",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "hu",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://metadata.eduid.hu/registration_policy_1_0.txt"
              }
            ],
            "registration_instant": "2013-08-01T07:17:19.807Z",
            "registration_authority": "http://eduid.hu",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NIIF - Nemzeti Inform\u00e1ci\u00f3s Infrastrukt\u00fara Fejleszt\u00e9si Int\u00e9zet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NIIF Institute - National Information Infrastructure Development"
          }
        ],
        "organization_url": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.niif.hu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.niif.hu/en"
          }
        ],
        "organization_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NIIF - Nemzeti Inform\u00e1ci\u00f3s Infrastrukt\u00fara Fejleszt\u00e9si Int\u00e9zet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NIIF Institute - National Information Infrastructure Development"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://randevu.lab.vvc.niif.hu/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://randevu.lab.vvc.niif.hu/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://randevu.lab.vvc.niif.hu/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://randevu.lab.vvc.niif.hu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://randevu.lab.vvc.niif.hu"
                  }
                ],
                "description": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Jitsi-meet alap\u00fa XMPP, WebRTC, Selective Forwaring Unit technol\u00f3gia teszt"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Jitsi-meet"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://randevu.lab.vvc.niif.hu/privacy.html"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://randevu.lab.vvc.niif.hu/privacy.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "randevu beta webkonferencia szolg\u00e1ltat\u00e1s"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Jitsi-meet"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "randevu.lab.vvc.niif.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://randevu.lab.vvc.niif.hu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://randevu.lab.vvc.niif.hu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://randevu.lab.vvc.niif.hu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://randevu.lab.vvc.niif.hu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "hu",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "randevu beta webkonferencia szolg\u00e1ltat\u00e1s"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Jitsi-meet"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://qmul.simitive.com",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Latham"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:adrian.latham@simitive.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adrian"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Latham"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:adrian.latham@simitive.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adrian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://qmul.simitive.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-06-13T14:35:35Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "QMUL Simitive"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.simitive.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Simitive Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://qmul.simitive.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://qmul.simitive.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://qmul.simitive.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://qmul.simitive.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://qmul.simitive.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "authn_requests_signed": "1",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://qmul.simitive.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://qmul.simitive.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSzCCAjOgAwIBAgIJAIWe2hAWoGqQMA0GCSqGSIb3DQEBBQUAMC4xLDAqBgNV\n\t\t\t\t\t\tBAMTI2hvc3QtOTUtMTU0LTI1NC0xMjcucnNjbGllbnRkbnMuY29tMB4XDTE0MDYx\n\t\t\t\t\t\tMzE0MTUxNFoXDTI0MDYxMDE0MTUxNFowLjEsMCoGA1UEAxMjaG9zdC05NS0xNTQt\n\t\t\t\t\t\tMjU0LTEyNy5yc2NsaWVudGRucy5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQCzdKvT4GTJO7A71YpcNcqOsCuBviRZeKiNTcCSYluuzje0N/pUe1F8\n\t\t\t\t\t\tufP1DZqHYIrSAW3mg0cJYqD1X5bgtCU8EOIsaTZQTtPjT3ed5VgSON6Lg/S6FjE3\n\t\t\t\t\t\tXuJ1m7JLrMRmvnkIaPFgU5zum4FehgxqyQDFKQRZx93BtsKP+evPyHtlT0Em239I\n\t\t\t\t\t\tDShp4FQtIBKxPf7OxmIpQna+zU4rSayVZOU258MHkwtY6cKQjryrZCpHFVcr188q\n\t\t\t\t\t\tMBF5x+64lxNfdP5xkQ7X9hW/bmAQiUMzlF7MImCko4vvnMl9zY6duqZ0bTJwmLjk\n\t\t\t\t\t\tBccJ3+omtIm2ngVIJiY3CKdst19uYKkNAgMBAAGjbDBqMEkGA1UdEQRCMECCI2hv\n\t\t\t\t\t\tc3QtOTUtMTU0LTI1NC0xMjcucnNjbGllbnRkbnMuY29thhlodHRwczovL3FtdWwu\n\t\t\t\t\t\tc2ltaXRpdmUuY29tMB0GA1UdDgQWBBRPeM2+fxZB7bvxwd2ptFgsyF0JPDANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAY9B4aw4BHYBO1OCD7A5+7w45WU9G72QywKOzmXT0aAtW\n\t\t\t\t\t\tjq/43SGIiH2R186dmyz4OTiwNau7XBfxYBfPtadkiGtKPJNUce1kSXzjKb+N541P\n\t\t\t\t\t\thGBs643+UQgKqOlxa7UM475DW2fNRV7J0Bru6TCcNlsxOUo9zxI7n1ce3eaiyT5i\n\t\t\t\t\t\t7tjzB4+FQ+VGdIgmenNgv1HJZmQn3crXtTWYIyhLHy+J63mEoxRUQobPXf0W0XAk\n\t\t\t\t\t\t+m7n4+GXiN0LMzp39ylHlZ3PQv3iCO+V+fAvnZuPZGhFZa7JBJnzQewQG9rx0JhJ\n\t\t\t\t\t\tpYtepKaoxPC3ztnljHK7wrYiuT313JFBFOgkT2HSgw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://qmul.simitive.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://qmul.simitive.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://qmul.simitive.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://qmul.simitive.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://qmul.simitive.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://qmul.simitive.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol"
        }
      ]
    }
  ],
  [
    "https://aai.arnes.si/test/edugain",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Podpora"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aaa-podpora@arnes.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAA"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@arnes.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Arnes"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Arnes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:arnes@arnes.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Arnes"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://aai.arnes.si/test/edugain",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_general.pdf"
              },
              {
                "lang": "sl",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_splosni_pogoji.pdf"
              }
            ],
            "registration_instant": "2014-11-05T13:11:06Z",
            "registration_authority": "http://aai.arnes.si",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ARNES"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ARNES"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://aai.arnes.si"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://aai.arnes.si"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ARNES"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ARNES"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai.arnes.si/test/edugain/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai.arnes.si/test/edugain/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai.arnes.si/test/edugain/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://aai.arnes.si/test/edugain/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai.arnes.si/test/edugain/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://aai.arnes.si/test/edugain/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://aai.arnes.si/test/edugain/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://aai.arnes.si"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://aai.arnes.si"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Aplication for testing IdP eduGAIN compatibility"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Aplikacija za preizku\u0161anje kompatibilnosti IdP-jev vklju\u010denih v eduGAIN"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "28",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "128"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ArnesAAI IdP eduGAIN test"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ArnesAAI IdP eduGAIN test"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ArnesAAI eduGAIN test, ArnesAAI eduGAIN compatibility test"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ArnesAAI eduGAIN test, ArnesAAI eduGAIN compatibility test,L=Ljubljana,C=SI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai.arnes.si/test/edugain/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aai.arnes.si/test/edugain/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://aai.arnes.si/test/edugain/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://aai.arnes.si/test/edugain/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ArnesAAI IdP eduGAIN test"
                },
                {
                  "lang": "sl",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ArnesAAI IdP eduGAIN test"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Aplication for testing IdP eduGAIN compatibility"
                },
                {
                  "lang": "sl",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Aplikacija za preizku\u0161anje kompatibilnosti IdP-jev vklju\u010denih v eduGAIN"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "commonName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "rfc822Mailbox",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganizationType",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.cvt.resultat.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.cvt.resultat.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cvt.resultat.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.cvt.resultat.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cvt.resultat.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cvt.resultat.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cvt.resultat.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.cvt.resultat.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.cvt.resultat.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.cvt.resultat.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.cvt.resultat.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.cvt.resultat.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.cvt.resultat.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.cvt.resultat.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIJANRWEklIQkJdMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\nBAMTGXd3dy5jdnQucmVzdWx0YXQubGFkb2suc2UwHhcNMTUwNjAxMTMwNzQ2WhcN\nMjUwNTI5MTMwNzQ2WjAkMSIwIAYDVQQDExl3d3cuY3Z0LnJlc3VsdGF0LmxhZG9r\nLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA6BhXUfBLo/bFi1Uc\naoc7ZzOhXTbELdSZ6uX+ta9Ka8g2E+KfaN6DkdvaHpGo1gySk4PZRUjXSV6iCDVe\nYLdaXxLTd5xCmlIGwXJjf9cnXkxf3NjCI1MKX1XrD8allnDx9shubn95Jb9up5VN\nrpjCPkGFdlGxXlHxrxEgCGAvb+OaGBM1W3Yxqd0F7svvPz7URfQN+lNNi3859Fpj\nGVEYiWaC3kpPuaDyaBLHTJzWI7XVmWvefscn3FBPaSJhkUBTD916OsVt0reh3Vpk\nT39elsIgPgFZnXnjy2q4c9oCagoVzgRy2F4YkS0KP4AAUsGfMallyELVR8UkjXy4\nKSS9RwIDAQABo3EwbzBOBgNVHREERzBFghl3d3cuY3Z0LnJlc3VsdGF0LmxhZG9r\nLnNlhihodHRwczovL3d3dy5jdnQucmVzdWx0YXQubGFkb2suc2UvZ3VpLXNwMB0G\nA1UdDgQWBBSdSVS95edPqMh1SEt3xrvXvFrJ3DANBgkqhkiG9w0BAQUFAAOCAQEA\noazABzdDThU4urpnGYY9HgjCR+/X/RHBuZ3mKbw/xT8BSZyOjFEHVy3VCeYq6cSg\nl9mvej26ZJQOtJ1CyM5S0yuH1/nNqDYf2d/0gSI1xki+pW8rvRmjc8n6ytD/Ogmm\nuYO2XZSSrtyn2nzzsK/ggB5EYhva39eYSjZs7A+I3Bqr02WAxvHHmiAFjbwqWXah\n8cyb0W0g2LGY3OxDnL6/WdPtf7SlkG0SlYIzyYuUxwVyxE6fmmbh3vtAz31HPSv6\nNKGLr/S1a0KWFVvdPW6eJygzGFRvNKySQMrK68iqT0WNhUCm96GTZK9UgD6M9eyv\ne5qdCpfQZSj3HagN3WLoqA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.cvt.resultat.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cvt.resultat.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.cvt.resultat.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cvt.resultat.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cvt.resultat.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cvt.resultat.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cvt.resultat.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.cvt.resultat.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.cvt.resultat.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.cvt.resultat.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://luvit.education.lu.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sidika.basic@ced.lu.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sidika Basic"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://luvit.education.lu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "http://luvit.education.lu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "http://luvit.education.lu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://luvit.education.lu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "http://luvit.education.lu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "http://luvit.education.lu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "http://luvit.education.lu.se/Shibboleth.sso/Login-lu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "http://luvit.education.lu.se/Shibboleth.sso/Login-swamid",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Milj\u00f6n \u00e4r utformad f\u00f6r s\u00e5v\u00e4l kursdeltagare som utbildare och administrat\u00f6rer f\u00f6r att kunna skapa, hantera, f\u00e5 tillg\u00e5ng till, administrera och deltaga i n\u00e4tbaserade kurser eller n\u00e4tbaserade aktiviteter i blandade kurser."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The environment is created for course participants as well as for educators and administrators in order to create, manage, overview, obtain, administrate and participate in online courses or in online course activities in mixed courses."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lunds universitet LUVIT"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lund University LUVIT"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "uwap122.uw.lu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJALDUiCW01jNBMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEHV3YXAxMjIudXcubHUuc2UwHhcNMTUwNjEyMDU1ODQ5WhcNMjUwNjA5MDU1\nODQ5WjAbMRkwFwYDVQQDExB1d2FwMTIyLnV3Lmx1LnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAyIAAztvo5p1DLnAblJ7n2PVyA+zPuriChIeyguRF\nzHXXqWET0CrWeAmIHVS22WYT7cbVlnS0Y+82NOf0tJOaFO5EmTseozQzGHL5Dc4F\ndHFO92oo2YOLimXuuuTS8gCaTcbsFrKoLBcQHXCu8lHyMWE/zoRZJkqxRJCg0Mmu\n55jUaxUG5FSdw0kS5Td1GRALUEBzzvsS+LlLJEM7gK3cHs23qwng7mqiK2d/oSAR\nxzwHeaQqGFEBCKl3S4PHGweV8BdJVOeJzKSC7L7ND3BGWUqXq1j2XA2otRU2MZIc\niHG0++I4ERw621OfYHduEqK7x9IcQVQWreCNEsTN3qkhFQIDAQABoz4wPDAbBgNV\nHREEFDASghB1d2FwMTIyLnV3Lmx1LnNlMB0GA1UdDgQWBBTuH02zf7l0oxRIzwqK\nRRDjwhC2ojANBgkqhkiG9w0BAQUFAAOCAQEAgiBlVk4LQDwbQ5skBi3tKk7FXK96\nyLiDgA4gR9XqD0Hq/l29Qzhya5mv3FBC9sgtV3ZJC9oH8H/jm4UuURg6iqKL7vmr\nwEGqG95E9xL2p6Jkcpi0CdjyUvkPcULlAKu/IRfRs/E1j/KtzacYEeQ3cDYD1d9F\nXvFIh3QzDURHqWL+ELZXMDSJYfjQe+7jP2w+Vu/TbF39otuREtJmYwcLOBxRvJYk\n6x3/BMwjSRXpDBttsVAClDS+Wm0A5jr5eCg7OoWNzdze74zGQpP4U7tWKZHT5bA4\nOTMXxdAawBca6aO1CpUMAwipgLVKJyNkmxV7+aPSdkp/U466LROEWhraZg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=uwap122.uw.lu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "http://luvit.education.lu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "http://luvit.education.lu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://luvit.education.lu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "http://luvit.education.lu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://luvit.education.lu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "http://luvit.education.lu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "http://luvit.education.lu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "http://luvit.education.lu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "http://luvit.education.lu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://fedidp.uh.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "KMartin@central.uh.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Keith Martin"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "snguye2@central.uh.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sonny Nguyen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "snguye2@central.uh.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sonny Nguyen"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "bwalker@central.uh.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brian Walker"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://fedidp.uh.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.uh.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.uh.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uh.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uh.edu/infotech/policies/Incommon%20Federation%20POP.pdf"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Houston"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Metropolitan campus with the feel of a large traditional campus, located in Houston, TX, the 4th largest city in the U.S.\u2014and growing"
                  }
                ],
                "logo": [
                  {
                    "text": "https://ssl.uh.edu/ecomm/images/uh_primary.png",
                    "lang": "en",
                    "height": "150",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "461"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.uh.edu/policies/privacy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVALfBIWfg5HK1/7UKfPr/TAgkWLYUMA0GCSqGSIb3DQEB\nBQUAMBgxFjAUBgNVBAMTDXNoaWIuZS51aC5lZHUwHhcNMTQwMjI0MjE0MjAwWhcN\nMzQwMjI0MjE0MjAwWjAYMRYwFAYDVQQDEw1zaGliLmUudWguZWR1MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuEPXRUJ1TZCdDA41O4deaxJ79jTbyxsM\nsl8VbII9FJhuRVMatGgqJR0jnS0SS/96xrllMDQfF35w4YuwQDshBYPiJUJv9+Gf\n5dXsdfMg9ZHmIwTKOuP12cF2yCMrEq6MUy5ypW+RDBfz5JrcauO/kmq18wkDIVcX\nt/5WNkJT1eQCx/TMtqXYCSyg6542kZNpz84ju86SZpXTXbdsdGLv7RnCm8RWa7zY\n0YVjaT3lQDgGdwucrqMFVcxpiXWH/7OLkQtjYyGocLXJXvUPcJiULms2emYi7SPN\nHAbcxnu5jUE376+/otwcHnVIaIFgizRuHHjScHNZiLTrct0J5ekuAwIDAQABo2Ew\nXzA+BgNVHREENzA1gg1zaGliLmUudWguZWR1hiRodHRwczovL3NoaWIuZS51aC5l\nZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFNKpoXlY9yOdiCeVEcb4ZtGUhJpd\nMA0GCSqGSIb3DQEBBQUAA4IBAQBcBF0kx6ef8u1vsI0KwkMUvKL9ukHT+hjHXkCF\nUra6sjEQBHE1ts9B0AyO91KbY4NCG+DQ77sPnrWbw9vyQnW7dlcIHFv255WiPz8h\n2C3tz0idz4zOjWLjwdVJGAuf3HhcH6q7LzbAw/UBwV0GHl7C/LOJaWg21REiBhob\nvfPFIo2xM4wGm+zlBv9lNRKwgMKOn4JNJ0GuyC2cD0QuGhsjqhVpo9L8Xm1f83xM\neaFxzRHv3G0p9zvkUirifFVbXiv4zCMkFczLoJ+nKrb3OmVAUMD/HeLL71pvSx0u\nR3kPsBq/2En2dZQ8fv7e7kpzqmawQ5unCFX/ZfRnf5XeMKov"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "error_url": "https://ssl.uh.edu/password"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Houston"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uh.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Houston"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://samltest.swamid.se/sfs/sp.xml",
    {
      "entity_id": "https://samltest.swamid.se/sfs/sp.xml",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish Academic Identity Federation (SWAMID)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.swamid.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SWAMID"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://samltest.swamid.se/disco",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFcTCCBFmgAwIBAgIQIu7k1beHBKgWb27d90Ad9jANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQwODAwMDAwMFoXDTE3MDQwNzIzNTk1OVowQDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRswGQYDVQQDExJzYW1sdGVzdC5z\nd2FtaWQuc2UwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCcJfNqCJmM\nCWZ9+h9MAT9WbT/e+eRpGE9H8eucnnq4weTeFbT+2Ma15hY8hI6gP4GsDIZsaxTu\nDGgIYXctfnl9MTz+9rlANOo8Wjuz6CJ2trJ6BdhPvkoITuSqmIWkFbmP7/0NGkoG\n167CGp/Eq5yZnUOdiKXquH2S5OCw3mB4HGpjUk7T13cN0jOOPiK2cQhUTuUUMaVO\nei0QblIfK/+9fusfYOjd5uzNg1QZ9FvvbB/wTw4Z11eGcZWKpAprIrbx6iw119eL\nU7dvJhgA96VJmesDQejf96Xtpn7bCbxdyBqw2AtooamyrVjnAeQ8NDXW7td9MUuM\n4/yhN9H+fHTVJNs8dCX5FKayw5YoxF8eTMjRk0ObICMrLl8M/EiOG9Eqfc3TPGTF\ndn81sOGc3WzifRyG5fXUx/Xw9vXVkRAkVO6T4n6OUQxn2be9hwXR7yFw9tTplPIl\ndabhc7iWU7NgEBcBI3RWCcRNv0OVsXIMDeGZ64SOm4mpKbXMVebsnSLXxV69T1l4\nM8EegMpraRWHrbtF27FkKZPZgCbNaQbfW4vtJoN9rN07Flz8GLr200WXAepXT14L\ndGwXqjx6Cu2oilkl2OoNWQbRg3dvn1j6XqnRLbio4bvuiCYYEPpjuWcHOs/GwMnz\npml7EL51yz9PTwNZTQXsLH/xKlzWf1BuBQIDAQABo4IBbzCCAWswHwYDVR0jBBgw\nFoAUDL2TaAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFG40O0IHvLK2kXS6s4hN\nCq0DTtPLMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQG\nCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgG\nBmeBDAECATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEu\nb3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKG\nKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsG\nAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJz\nYW1sdGVzdC5zd2FtaWQuc2UwDQYJKoZIhvcNAQEFBQADggEBAHnWOLDwhrYWfd7q\n2fwTaiRP/x/tVPocNgi/wgwo6oZzC1Ru/HPjfUmnj11zkOOHeF8cf2BT2diRptPi\nqDc+7HN8GrM87+Deqvjj4pw7j4hwMpcfNd2AzqW4nPmw4LgiRehITtUtMxL9mkDh\neN0pgldD544xQRUdxYmD9nUWiIaTmuxNqusKkqUTD/kO41i+BxIeaWiXsw6IC7o6\nkPPUQHr1h2na805Kjoy5ML8K2EO+kcvFqfo42gtwa7mN38hKB+jbKF5VqqmoSb4m\nln/3lobOqcV8rrFKjvnjC6iNTbdpQ65o8CoOcfzhWmb/7RxkZ4a9fyzxVS8fMAi6\nu3Qzm3Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFcTCCBFmgAwIBAgIQIu7k1beHBKgWb27d90Ad9jANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQwODAwMDAwMFoXDTE3MDQwNzIzNTk1OVowQDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRswGQYDVQQDExJzYW1sdGVzdC5z\nd2FtaWQuc2UwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCcJfNqCJmM\nCWZ9+h9MAT9WbT/e+eRpGE9H8eucnnq4weTeFbT+2Ma15hY8hI6gP4GsDIZsaxTu\nDGgIYXctfnl9MTz+9rlANOo8Wjuz6CJ2trJ6BdhPvkoITuSqmIWkFbmP7/0NGkoG\n167CGp/Eq5yZnUOdiKXquH2S5OCw3mB4HGpjUk7T13cN0jOOPiK2cQhUTuUUMaVO\nei0QblIfK/+9fusfYOjd5uzNg1QZ9FvvbB/wTw4Z11eGcZWKpAprIrbx6iw119eL\nU7dvJhgA96VJmesDQejf96Xtpn7bCbxdyBqw2AtooamyrVjnAeQ8NDXW7td9MUuM\n4/yhN9H+fHTVJNs8dCX5FKayw5YoxF8eTMjRk0ObICMrLl8M/EiOG9Eqfc3TPGTF\ndn81sOGc3WzifRyG5fXUx/Xw9vXVkRAkVO6T4n6OUQxn2be9hwXR7yFw9tTplPIl\ndabhc7iWU7NgEBcBI3RWCcRNv0OVsXIMDeGZ64SOm4mpKbXMVebsnSLXxV69T1l4\nM8EegMpraRWHrbtF27FkKZPZgCbNaQbfW4vtJoN9rN07Flz8GLr200WXAepXT14L\ndGwXqjx6Cu2oilkl2OoNWQbRg3dvn1j6XqnRLbio4bvuiCYYEPpjuWcHOs/GwMnz\npml7EL51yz9PTwNZTQXsLH/xKlzWf1BuBQIDAQABo4IBbzCCAWswHwYDVR0jBBgw\nFoAUDL2TaAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFG40O0IHvLK2kXS6s4hN\nCq0DTtPLMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQG\nCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgG\nBmeBDAECATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEu\nb3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKG\nKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsG\nAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJz\nYW1sdGVzdC5zd2FtaWQuc2UwDQYJKoZIhvcNAQEFBQADggEBAHnWOLDwhrYWfd7q\n2fwTaiRP/x/tVPocNgi/wgwo6oZzC1Ru/HPjfUmnj11zkOOHeF8cf2BT2diRptPi\nqDc+7HN8GrM87+Deqvjj4pw7j4hwMpcfNd2AzqW4nPmw4LgiRehITtUtMxL9mkDh\neN0pgldD544xQRUdxYmD9nUWiIaTmuxNqusKkqUTD/kO41i+BxIeaWiXsw6IC7o6\nkPPUQHr1h2na805Kjoy5ML8K2EO+kcvFqfo42gtwa7mN38hKB+jbKF5VqqmoSb4m\nln/3lobOqcV8rrFKjvnjC6iNTbdpQ65o8CoOcfzhWmb/7RxkZ4a9fyzxVS8fMAi6\nu3Qzm3Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://samltest.swamid.se/acs/sfs/redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://samltest.swamid.se/acs/sfs/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.demontfortstudents.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.demontfortstudents.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-01-21T11:30:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "De Montfort Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.demontfortstudents.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.demontfortstudents.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.demontfortstudents.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.demontfortstudents.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.demontfortstudents.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.demontfortstudents.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.demontfortstudents.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.demontfortstudents.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.demontfortstudents.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.demontfortstudents.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.demontfortstudents.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.demontfortstudents.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.demontfortstudents.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.demontfortstudents.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.demontfortstudents.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.demontfortstudents.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.demontfortstudents.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://portal.mdh.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://portal.mdh.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://portal.mdh.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://portal.mdh.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://portal.mdh.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://portal.mdh.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://portal.mdh.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://portal.mdh.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.mdh.se/student/service/studentportalen-1.260?l=sv_SE"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.mdh.se/student/service/studentportalen-1.260?l=en_UK"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Denna applikation anv\u00e4nds f\u00f6r att registrera sig p\u00e5 kurs p\u00e5 MDH."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service is used for registering at course at MDH."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.mdh.se/gemensamt/webbplatsen/juridisk-information-1.205?l=sv_SE"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.mdh.se/gemensamt/webbplatsen/juridisk-information-1.205?l=en_UK"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Studentportal MDH"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Student portal MDH"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "v-portila.ita.mdh.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+zCCAeOgAwIBAgIBADANBgkqhkiG9w0BAQUFADAfMR0wGwYDVQQDExR2LXBv\ncnRpbGEuaXRhLm1kaC5zZTAeFw0xMDA3MDEyMzIzNTBaFw0yMDA2MjgyMzIzNTBa\nMB8xHTAbBgNVBAMTFHYtcG9ydGlsYS5pdGEubWRoLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAl1TuX2zjSyC3YD4Y2+09x8Ur20kl4YdjZRR6bwNa\nbPXAA3OnShY5cUvy4E6lBRepoCMCXoKYptcqGt0+zxtHYcYuSnWLs/Z0BevURIQW\nexo1CF2vI2xssmxxEDoXoB39moRkqjfRHaDqq4INw+2/a823lSqit+e1OOBYML7O\nUyP+wJLtDzo7MbKXlV0hi7iMQVtXJaqPPvrNrRivCkC0dHBg77RCK9Dw1pNmirvt\nmlvMEkzAOBVUKmaXBcH0NvvRHVaMIxYKDlDHI5q0J8GqTVyVvVtHRMZToB5x+5h1\nqQHVsEvXYWH1CHM9jRsMnYx7b2/GR7eBtzh30DsXaPaI2wIDAQABo0IwQDAfBgNV\nHREEGDAWghR2LXBvcnRpbGEuaXRhLm1kaC5zZTAdBgNVHQ4EFgQU8vkDhvnqzteG\nBBZeQrlIsl7PdFUwDQYJKoZIhvcNAQEFBQADggEBAAXe9EMJcx4J6tBAkU8yKDfX\nxLPT4vqGdClX6Qz6FxpErbFvNt4MUuHHnDjwMqrEB1u0OF5huMMFMMx5gpHEJpw5\nzZqkpPGKmUjDCynPCCh3zNClMOjf1NKzLfLmo4osJMSftPE0O6x3G7oDfKwck80G\nbKEjtT8vAK0IpDaKe3p5dq2lLNtfwecGyx8//pfyWgRABuJxbnrtJrENOjET45ns\nlkNHmBszvmK5Ed6NDhPnepjCOkXlHqg73CCx3E6+exvUCJ2700RntZIT8UFKu1K6\n7IwuqV1dJoBbpIG+G9/qOzGuo09N5tDfiZvjQ10D3dubNLbH9I+FdtMPeZj8KtM="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=v-portila.ita.mdh.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "v-portila.ita.mdh.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+zCCAeOgAwIBAgIBADANBgkqhkiG9w0BAQUFADAfMR0wGwYDVQQDExR2LXBv\ncnRpbGEuaXRhLm1kaC5zZTAeFw0xMDA3MDEyMzIzNTBaFw0yMDA2MjgyMzIzNTBa\nMB8xHTAbBgNVBAMTFHYtcG9ydGlsYS5pdGEubWRoLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAl1TuX2zjSyC3YD4Y2+09x8Ur20kl4YdjZRR6bwNa\nbPXAA3OnShY5cUvy4E6lBRepoCMCXoKYptcqGt0+zxtHYcYuSnWLs/Z0BevURIQW\nexo1CF2vI2xssmxxEDoXoB39moRkqjfRHaDqq4INw+2/a823lSqit+e1OOBYML7O\nUyP+wJLtDzo7MbKXlV0hi7iMQVtXJaqPPvrNrRivCkC0dHBg77RCK9Dw1pNmirvt\nmlvMEkzAOBVUKmaXBcH0NvvRHVaMIxYKDlDHI5q0J8GqTVyVvVtHRMZToB5x+5h1\nqQHVsEvXYWH1CHM9jRsMnYx7b2/GR7eBtzh30DsXaPaI2wIDAQABo0IwQDAfBgNV\nHREEGDAWghR2LXBvcnRpbGEuaXRhLm1kaC5zZTAdBgNVHQ4EFgQU8vkDhvnqzteG\nBBZeQrlIsl7PdFUwDQYJKoZIhvcNAQEFBQADggEBAAXe9EMJcx4J6tBAkU8yKDfX\nxLPT4vqGdClX6Qz6FxpErbFvNt4MUuHHnDjwMqrEB1u0OF5huMMFMMx5gpHEJpw5\nzZqkpPGKmUjDCynPCCh3zNClMOjf1NKzLfLmo4osJMSftPE0O6x3G7oDfKwck80G\nbKEjtT8vAK0IpDaKe3p5dq2lLNtfwecGyx8//pfyWgRABuJxbnrtJrENOjET45ns\nlkNHmBszvmK5Ed6NDhPnepjCOkXlHqg73CCx3E6+exvUCJ2700RntZIT8UFKu1K6\n7IwuqV1dJoBbpIG+G9/qOzGuo09N5tDfiZvjQ10D3dubNLbH9I+FdtMPeZj8KtM="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=v-portila.ita.mdh.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://portal.mdh.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://portal.mdh.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://portal.mdh.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://portal.mdh.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://portal.mdh.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://portal.mdh.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://portal.mdh.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://portal.mdh.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://portal.mdh.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://portal.mdh.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://access.research.cchmc.org/fed/idp/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "nicholas.hunt@cchmc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nicholas Hunt"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://access.research.cchmc.org/fed/idp/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://access.research.cchmc.org/fed/idp/soap",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFPTCCBCWgAwIBAgIETBdK3DANBgkqhkiG9w0BAQUFADCBvjELMAkGA1UEBhMCVVMxFjAUBgNV\nBAoTDUVudHJ1c3QsIEluYy4xOTA3BgNVBAsTMHd3dy5lbnRydXN0Lm5ldC9ycGEgaXMgaW5jb3Jw\nb3JhdGVkIGJ5IHJlZmVyZW5jZTEfMB0GA1UECxMWKGMpIDIwMDkgRW50cnVzdCwgSW5jLjE7MDkG\nA1UEAxMyRW50cnVzdCBDb2RlIFNpZ25pbmcgQ2VydGlmaWNhdGlvbiBBdXRob3JpdHkgLSBMMUQw\nHhcNMTMwNjEwMTk0NDI1WhcNMTQwNjMwMDc0NDM2WjCBnzELMAkGA1UEBhMCVVMxDTALBgNVBAgT\nBE9oaW8xEzARBgNVBAcTCkNpbmNpbm5hdGkxNTAzBgNVBAoTLENpbmNpbm5hdGkgQ2hpbGRyZW5z\nIEhvc3BpdGFsIE1lZGljYWwgQ2VudGVyMTUwMwYDVQQDEyxDaW5jaW5uYXRpIENoaWxkcmVucyBI\nb3NwaXRhbCBNZWRpY2FsIENlbnRlcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIRO\nzOV9JMKwCjIsTFSaYEEorabOzaZXQJnzvZp2zgyYus89/vQXumsvr0PAPFmtgu+WbrR0OHFdp1me\n/att8Lkutfw+nin/YXYfSp+H7l39XCleOYXX3XQixPfcby+Bp9jAjEakOoPAr4KQERpXee1GwLLk\nG5qNRVn+H3seajrofshWc7dU6cgP+6+9dpQ9NVFdl2zaOsqE77uEFNqHzKZtuNykPTABqWikGupW\nxmNAlJAuD7kdgQHBz3hffZYOwzu/kh/pY6XpsTqD3tPayjhvL3oGcOxzXeeS6Ch03TdIjhM4pHuT\n8dz7Pyn0YsjjPhVDbzKdYrqojGExORmkcTMCAwEAAaOCAV4wggFaMA4GA1UdDwEB/wQEAwIHgDAf\nBgNVHSUEGDAWBggrBgEFBQcDAwYKKwYBBAGCNz0BATBkBggrBgEFBQcBAQRYMFYwIwYIKwYBBQUH\nMAGGF2h0dHA6Ly9vY3NwLmVudHJ1c3QubmV0MC8GCCsGAQUFBzAChiNodHRwOi8vYWlhLmVudHJ1\nc3QubmV0L2wxZC0yMDQ4LmNlcjAzBgNVHR8ELDAqMCigJqAkhiJodHRwOi8vY3JsLmVudHJ1c3Qu\nbmV0L2xldmVsMWQuY3JsMEEGA1UdIAQ6MDgwNgYKYIZIAYb6bAoBAzAoMCYGCCsGAQUFBwIBFhpo\ndHRwOi8vd3d3LmVudHJ1c3QubmV0L3JwYTAfBgNVHSMEGDAWgBSnsarEtgbt3cqfiJSWgtXnQ0HR\nJTAdBgNVHQ4EFgQU2Asl48HJ2O4g7gNaVe8GdHpnVrYwCQYDVR0TBAIwADANBgkqhkiG9w0BAQUF\nAAOCAQEADtUd+I+2XSN7Lxb/0lp8ARaL00kiHvHqpVq+LHY0/f8kzS+7SD96u6PclSiRebKfbDDp\nexYh1IUbjEzZOLisbPTNbs18Pt+kbSaiJ1DK+iqLpCKKhdoL+jjwNw2BvwOrpmL5PA1gGrot8GSh\ng1DuDcr7unOCmg0fsAKPcf+hOIw1cVR1Mi/li8+NRaX1AmXrWysFaHz/C9F6NCXbZpmjjRZlWRfr\noVfuotaTX1W6FtNXZvxdKJ9ykGe/3fIO6kx82ny3eIvRBQsoMXHJYiLpCCIUtnKryMJGRtlJEisp\ndC3e/ZXZOOacpIz/UiVsFps47ssasggHSCoxYljjm33nFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cchmc.org"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://access.research.cchmc.org/fed/idp/samlv20",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://access.research.cchmc.org/fed/idp/samlv20",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://access.research.cchmc.org/fed/idp/samlv20",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://access.research.cchmc.org/fed/idp/soap",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cchmc.org"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CCHMC Research IdP"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Cincinnati Children's Hospital Medical Center"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFPTCCBCWgAwIBAgIETBdK3DANBgkqhkiG9w0BAQUFADCBvjELMAkGA1UEBhMCVVMxFjAUBgNV\nBAoTDUVudHJ1c3QsIEluYy4xOTA3BgNVBAsTMHd3dy5lbnRydXN0Lm5ldC9ycGEgaXMgaW5jb3Jw\nb3JhdGVkIGJ5IHJlZmVyZW5jZTEfMB0GA1UECxMWKGMpIDIwMDkgRW50cnVzdCwgSW5jLjE7MDkG\nA1UEAxMyRW50cnVzdCBDb2RlIFNpZ25pbmcgQ2VydGlmaWNhdGlvbiBBdXRob3JpdHkgLSBMMUQw\nHhcNMTMwNjEwMTk0NDI1WhcNMTQwNjMwMDc0NDM2WjCBnzELMAkGA1UEBhMCVVMxDTALBgNVBAgT\nBE9oaW8xEzARBgNVBAcTCkNpbmNpbm5hdGkxNTAzBgNVBAoTLENpbmNpbm5hdGkgQ2hpbGRyZW5z\nIEhvc3BpdGFsIE1lZGljYWwgQ2VudGVyMTUwMwYDVQQDEyxDaW5jaW5uYXRpIENoaWxkcmVucyBI\nb3NwaXRhbCBNZWRpY2FsIENlbnRlcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIRO\nzOV9JMKwCjIsTFSaYEEorabOzaZXQJnzvZp2zgyYus89/vQXumsvr0PAPFmtgu+WbrR0OHFdp1me\n/att8Lkutfw+nin/YXYfSp+H7l39XCleOYXX3XQixPfcby+Bp9jAjEakOoPAr4KQERpXee1GwLLk\nG5qNRVn+H3seajrofshWc7dU6cgP+6+9dpQ9NVFdl2zaOsqE77uEFNqHzKZtuNykPTABqWikGupW\nxmNAlJAuD7kdgQHBz3hffZYOwzu/kh/pY6XpsTqD3tPayjhvL3oGcOxzXeeS6Ch03TdIjhM4pHuT\n8dz7Pyn0YsjjPhVDbzKdYrqojGExORmkcTMCAwEAAaOCAV4wggFaMA4GA1UdDwEB/wQEAwIHgDAf\nBgNVHSUEGDAWBggrBgEFBQcDAwYKKwYBBAGCNz0BATBkBggrBgEFBQcBAQRYMFYwIwYIKwYBBQUH\nMAGGF2h0dHA6Ly9vY3NwLmVudHJ1c3QubmV0MC8GCCsGAQUFBzAChiNodHRwOi8vYWlhLmVudHJ1\nc3QubmV0L2wxZC0yMDQ4LmNlcjAzBgNVHR8ELDAqMCigJqAkhiJodHRwOi8vY3JsLmVudHJ1c3Qu\nbmV0L2xldmVsMWQuY3JsMEEGA1UdIAQ6MDgwNgYKYIZIAYb6bAoBAzAoMCYGCCsGAQUFBwIBFhpo\ndHRwOi8vd3d3LmVudHJ1c3QubmV0L3JwYTAfBgNVHSMEGDAWgBSnsarEtgbt3cqfiJSWgtXnQ0HR\nJTAdBgNVHQ4EFgQU2Asl48HJ2O4g7gNaVe8GdHpnVrYwCQYDVR0TBAIwADANBgkqhkiG9w0BAQUF\nAAOCAQEADtUd+I+2XSN7Lxb/0lp8ARaL00kiHvHqpVq+LHY0/f8kzS+7SD96u6PclSiRebKfbDDp\nexYh1IUbjEzZOLisbPTNbs18Pt+kbSaiJ1DK+iqLpCKKhdoL+jjwNw2BvwOrpmL5PA1gGrot8GSh\ng1DuDcr7unOCmg0fsAKPcf+hOIw1cVR1Mi/li8+NRaX1AmXrWysFaHz/C9F6NCXbZpmjjRZlWRfr\noVfuotaTX1W6FtNXZvxdKJ9ykGe/3fIO6kx82ny3eIvRBQsoMXHJYiLpCCIUtnKryMJGRtlJEisp\ndC3e/ZXZOOacpIz/UiVsFps47ssasggHSCoxYljjm33nFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://login.research.cchmc.org/pub/apperror.aspx"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cincinnati Children's Hospital Medical Center"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cincinnatichildrens.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cincinnati Children's Hospital Medical Center"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://connect.funet.fi/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://connect.funet.fi/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://connect.funet.fi/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://connect.funet.fi/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect.funet.fi/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect.funet.fi/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "FUNET E-Meeting Service"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "FUNET E-Meeting Service (Adobe Connect)"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://connect.funet.fi/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://connect.funet.fi/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://connect.funet.fi/Shibboleth.sso/DS/haka.funet.fi",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "connect.funet.fi"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAKZpZsXKkzHCMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGNvbm5lY3QuZnVuZXQuZmkwHhcNMTIwMjE2MTE0NTMwWhcNMTUwMjE1MTE0\nNTMwWjAbMRkwFwYDVQQDExBjb25uZWN0LmZ1bmV0LmZpMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA9qHZQfn+2SyyuRhpm+wnEIxXj4eZjNkfQvy/hSih\nfDvnx5QpNerbXt+SIy2YQHmFhn5N5Hdn1onPf91IzshAQVXacIdzqFEXdwl2k4M9\nBw7FiObtFokW4ukEZTEnDPhwTu89oaVuXLLsGt9tCiNBKaSniip4HpMMBEK41jU4\nwzmm+LSQF8xYl+AgagZaydHCVSIQC1PnXqPR1dcnoBzP2t01YqWCfCyxHjHVBYtk\njrXpse9rb0pj1xlurvG1lveqeAStM8AkXiP2gSBQpv88y/YU6UgT1eOLsI65Ox2w\nZWTd36jYbUxHOsRAsZxSy0IokvGIHDK6ykjU9wLthwWXYwIDAQABoz4wPDAbBgNV\nHREEFDASghBjb25uZWN0LmZ1bmV0LmZpMB0GA1UdDgQWBBRxLCa7bCuoP7HKshs5\nFyw8ab6LXzANBgkqhkiG9w0BAQUFAAOCAQEAxw74TU9pNDmMVFq7AXkvHOlnKM9q\nl7c5F7D/KVXOrigwiIn0xwj+kr4ElZp1qrVLgC+fEHk9C2uKR9iJiR1z2SnOEn1U\nTeFtpdM7HaGBivCjsX5d1zMiTILSNkU7u+cJPH9EASOnTjSIbktDfHLApZ+t9yfg\nNPPGeZN6Q8qZuKoJBi7obLAsWbcTSxgIBrYK4G0BS9Hiy3W4gp1gqTflpYx0YBHv\nrNvLo5T1BgsjLc1kQsoAAn8pUP8GHb1KSJ0SY2IKV+k9oWEF3Nd1n/+43bPB666B\nEMBSvHkNXEFDf/FDbw4kjn5ie1pmF4qu+jHVHyB4y4Roz0QFoYIeOWaRMw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=connect.funet.fi"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "connect.funet.fi"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAKZpZsXKkzHCMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGNvbm5lY3QuZnVuZXQuZmkwHhcNMTIwMjE2MTE0NTMwWhcNMTUwMjE1MTE0\nNTMwWjAbMRkwFwYDVQQDExBjb25uZWN0LmZ1bmV0LmZpMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA9qHZQfn+2SyyuRhpm+wnEIxXj4eZjNkfQvy/hSih\nfDvnx5QpNerbXt+SIy2YQHmFhn5N5Hdn1onPf91IzshAQVXacIdzqFEXdwl2k4M9\nBw7FiObtFokW4ukEZTEnDPhwTu89oaVuXLLsGt9tCiNBKaSniip4HpMMBEK41jU4\nwzmm+LSQF8xYl+AgagZaydHCVSIQC1PnXqPR1dcnoBzP2t01YqWCfCyxHjHVBYtk\njrXpse9rb0pj1xlurvG1lveqeAStM8AkXiP2gSBQpv88y/YU6UgT1eOLsI65Ox2w\nZWTd36jYbUxHOsRAsZxSy0IokvGIHDK6ykjU9wLthwWXYwIDAQABoz4wPDAbBgNV\nHREEFDASghBjb25uZWN0LmZ1bmV0LmZpMB0GA1UdDgQWBBRxLCa7bCuoP7HKshs5\nFyw8ab6LXzANBgkqhkiG9w0BAQUFAAOCAQEAxw74TU9pNDmMVFq7AXkvHOlnKM9q\nl7c5F7D/KVXOrigwiIn0xwj+kr4ElZp1qrVLgC+fEHk9C2uKR9iJiR1z2SnOEn1U\nTeFtpdM7HaGBivCjsX5d1zMiTILSNkU7u+cJPH9EASOnTjSIbktDfHLApZ+t9yfg\nNPPGeZN6Q8qZuKoJBi7obLAsWbcTSxgIBrYK4G0BS9Hiy3W4gp1gqTflpYx0YBHv\nrNvLo5T1BgsjLc1kQsoAAn8pUP8GHb1KSJ0SY2IKV+k9oWEF3Nd1n/+43bPB666B\nEMBSvHkNXEFDf/FDbw4kjn5ie1pmF4qu+jHVHyB4y4Roz0QFoYIeOWaRMw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=connect.funet.fi"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://connect.funet.fi/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://connect.funet.fi/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect.funet.fi/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect.funet.fi/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect.funet.fi/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://connect.funet.fi/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect.funet.fi/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://connect.funet.fi/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://connect.funet.fi/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://connect.funet.fi/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.warkscol.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mitchell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rmitchell@warkscol.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rob"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mitchell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rmitchell@warkscol.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rob"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.warkscol.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-04-27T17:45:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYDCCAkgCCQD/4wYFNpyojzANBgkqhkiG9w0BAQUFADByMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEVMBMGA1UECBMMV2Fyd2lja3NoaXJlMRAwDgYDVQQHEwdXYXJ3aWNrMR0wGwYD\n\t\t\t\t\t\tVQQKExRXYXJ3aWNrc2hpcmUgQ29sbGVnZTEbMBkGA1UEAxMSaWRwLndhcmtzY29s\n\t\t\t\t\t\tLmFjLnVrMB4XDTE0MDUwMTEzMTMxMFoXDTM0MDQyNjEzMTMxMFowcjELMAkGA1UE\n\t\t\t\t\t\tBhMCR0IxFTATBgNVBAgTDFdhcndpY2tzaGlyZTEQMA4GA1UEBxMHV2Fyd2ljazEd\n\t\t\t\t\t\tMBsGA1UEChMUV2Fyd2lja3NoaXJlIENvbGxlZ2UxGzAZBgNVBAMTEmlkcC53YXJr\n\t\t\t\t\t\tc2NvbC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALhK7iVu\n\t\t\t\t\t\tA691GNEVeV8hM4gdlUNDpZzGQUgUsekgjc+75zkpUMrkCPuSlJeIoegK524HMDGl\n\t\t\t\t\t\t/J4tHGS8NtQwnaG/bigbWu3BOXR7bKwHOHpMhIek1V8BXOhBadfnp7IS234e4h/L\n\t\t\t\t\t\tyreSdxsJdaPKiT8+Orxlu5nmOUN8cLhR7FWZm6TZjN8uEObKTd/QxW0y9PiZFuyY\n\t\t\t\t\t\tVO/P2yv5QmHTuC81eKI3bRIQeLo/Lb/ixKdsihsJ/AqfjCpTUo0OdV9yawIPfEpu\n\t\t\t\t\t\tcOoWvaWGWAi2P8sM/0VfyIM1Hv2OReMef8sCS/MmSxV7LbEGk2GWSWXl2XwiJXov\n\t\t\t\t\t\tKcr/t3HI+s1OGi0CAwEAATANBgkqhkiG9w0BAQUFAAOCAQEArSIfclS/osh3HZT8\n\t\t\t\t\t\tY9pU4rTBpY+5xmYdLZjGaTk4DYJJFOU79IF/CdRMVwjSkspNiQT5lBvps9zB7/NQ\n\t\t\t\t\t\tw2gZHlixBj9dKRNUwYEjSCX03LXb4lBF4T81DSL9PcdbGfvgDVfk9TcZNX9KA0Bd\n\t\t\t\t\t\t2GhMub8+MRrSsrvX4wLyUeNqlA4Hb7RT4Y584iO58+hOL9qwDPskqUPSp1wXeBsJ\n\t\t\t\t\t\toPn7U2TcWMwsP66fOo2fO7Xdt8iyeeZyDLBvFul2e3NXMjNlr5v3nyUze3iLer1m\n\t\t\t\t\t\tufX7okaOmCXfK/slbpd8nhkch7kFhWd2BF3RRRsihBB6VKvKYldfNmUZ7QT3sCNv\n\t\t\t\t\t\tpouvTA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "warkscol.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.warkscol.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.warkscol.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib-login.warkscol.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-login.warkscol.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib-login.warkscol.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-login.warkscol.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.warkscol.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.warkscol.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "warkscol.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYDCCAkgCCQD/4wYFNpyojzANBgkqhkiG9w0BAQUFADByMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEVMBMGA1UECBMMV2Fyd2lja3NoaXJlMRAwDgYDVQQHEwdXYXJ3aWNrMR0wGwYD\n\t\t\t\t\t\tVQQKExRXYXJ3aWNrc2hpcmUgQ29sbGVnZTEbMBkGA1UEAxMSaWRwLndhcmtzY29s\n\t\t\t\t\t\tLmFjLnVrMB4XDTE0MDUwMTEzMTMxMFoXDTM0MDQyNjEzMTMxMFowcjELMAkGA1UE\n\t\t\t\t\t\tBhMCR0IxFTATBgNVBAgTDFdhcndpY2tzaGlyZTEQMA4GA1UEBxMHV2Fyd2ljazEd\n\t\t\t\t\t\tMBsGA1UEChMUV2Fyd2lja3NoaXJlIENvbGxlZ2UxGzAZBgNVBAMTEmlkcC53YXJr\n\t\t\t\t\t\tc2NvbC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALhK7iVu\n\t\t\t\t\t\tA691GNEVeV8hM4gdlUNDpZzGQUgUsekgjc+75zkpUMrkCPuSlJeIoegK524HMDGl\n\t\t\t\t\t\t/J4tHGS8NtQwnaG/bigbWu3BOXR7bKwHOHpMhIek1V8BXOhBadfnp7IS234e4h/L\n\t\t\t\t\t\tyreSdxsJdaPKiT8+Orxlu5nmOUN8cLhR7FWZm6TZjN8uEObKTd/QxW0y9PiZFuyY\n\t\t\t\t\t\tVO/P2yv5QmHTuC81eKI3bRIQeLo/Lb/ixKdsihsJ/AqfjCpTUo0OdV9yawIPfEpu\n\t\t\t\t\t\tcOoWvaWGWAi2P8sM/0VfyIM1Hv2OReMef8sCS/MmSxV7LbEGk2GWSWXl2XwiJXov\n\t\t\t\t\t\tKcr/t3HI+s1OGi0CAwEAATANBgkqhkiG9w0BAQUFAAOCAQEArSIfclS/osh3HZT8\n\t\t\t\t\t\tY9pU4rTBpY+5xmYdLZjGaTk4DYJJFOU79IF/CdRMVwjSkspNiQT5lBvps9zB7/NQ\n\t\t\t\t\t\tw2gZHlixBj9dKRNUwYEjSCX03LXb4lBF4T81DSL9PcdbGfvgDVfk9TcZNX9KA0Bd\n\t\t\t\t\t\t2GhMub8+MRrSsrvX4wLyUeNqlA4Hb7RT4Y584iO58+hOL9qwDPskqUPSp1wXeBsJ\n\t\t\t\t\t\toPn7U2TcWMwsP66fOo2fO7Xdt8iyeeZyDLBvFul2e3NXMjNlr5v3nyUze3iLer1m\n\t\t\t\t\t\tufX7okaOmCXfK/slbpd8nhkch7kFhWd2BF3RRRsihBB6VKvKYldfNmUZ7QT3sCNv\n\t\t\t\t\t\tpouvTA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Warwickshire College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.warkscol.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Warwickshire College, Royal Leamington Spa, Rugby and Moreton Morrell"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.du.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 23 778891"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT-avdelningen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shib-admin@du.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Dalarna University"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 23 778891"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT-avdelningen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shib-admin@du.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Dalarna University"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 23 778888"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "H\u00f6gskolan Dalarna Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@du.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Dalarna University"
          }
        }
      ],
      "entity_id": "https://login.du.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oasis:names:tc:SAML:attribute:assurance-certification",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAPJo+xMJRgt7yTXfyDqsZSyRFE0zMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2xvZ2luLmR1LnNlMB4XDTExMDIwNDEzMzg1MloXDTMx\nMDIwNDEzMzg1MlowFjEUMBIGA1UEAxMLbG9naW4uZHUuc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCKFHqKqppmo8B66lFgTbIQDdDNqlBpsrhjZx4m\nl4ay7TR/Q9JhxJCpsg3fttFyYbG6pl4PViMMt6jagpYYMBlBBKGUDefAT95oAcBN\neRlkTxXfXG4XCS1phIIc6H9Kt8HwFadqLIgx+9ICCuyTZicPIwnUBt+TS4A+hz6k\n8KA87QWvnhteMHpu4UjIL8YRUAdNbFbRV9AuOmaR9HP11yueQd3B+5XnTt8x+JaO\nyWgsbUvBeGKIXPtGm70UgXeBi32vr6LtP5s2ijtj4zORMh5dxAkrjE0hO96E3D6Y\nriLlccqVMGTYhweDuIE4HJA+sY8vFXxSTsL193erJ6ooBUWxAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2xvZ2luLmR1LnNlhiJodHRwczovL2xvZ2luLmR1LnNlL2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBTYD58W7KLBxdd1F6vo5xlukwwdOTANBgkqhkiG\n9w0BAQUFAAOCAQEAXZRof2FZml44oPJ+2GkhIIK0U2t143xH4Z4J2iPbTjQyNfeo\neusGj+AvLkdkHLisqz8HTQC93sSYwPrQ1PMrqwAmnJZkhcySTto15Rgi5yNWsUFU\nE5RfYEcGj1P2R+uxUpCZ3qf9usCpGf5ao5rCoOjxtxGyv3PqDFTBwkjheuASpsug\nKnPqLMWV0RL1gmJhfAoCbhm+rM8FZZLXloDuV+Xzb0OmjruPupqtTJpHVBkaQ3OI\n2FIPaCf07HjPPcy4s9mQJGq9TEBKJ+WWwoT5ZvhYErkO7m2iQNsXUqCk/dt2Tp7e\nGqI848rh0Iif5MpxnsYQ/mxwDirbsler7jpF0Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "du.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.du.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.du.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.du.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.du.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.du.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.du.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.du.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.du.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "du.se"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r anst\u00e4llda och studenter vid H\u00f6gskolan Dalarna."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for employees and students at Dalarna University."
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.du.se/duse-logo-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://login.du.se/duse-logo-sv.png",
                    "lang": "sv",
                    "height": "350",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "146"
                  },
                  {
                    "text": "https://login.du.se/duse-logo-en.png",
                    "lang": "en",
                    "height": "350",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "146"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "H\u00f6gskolan Dalarna"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Dalarna University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "du.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:60.6137,15.6536"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.243.32.0/19"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAPJo+xMJRgt7yTXfyDqsZSyRFE0zMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2xvZ2luLmR1LnNlMB4XDTExMDIwNDEzMzg1MloXDTMx\nMDIwNDEzMzg1MlowFjEUMBIGA1UEAxMLbG9naW4uZHUuc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCKFHqKqppmo8B66lFgTbIQDdDNqlBpsrhjZx4m\nl4ay7TR/Q9JhxJCpsg3fttFyYbG6pl4PViMMt6jagpYYMBlBBKGUDefAT95oAcBN\neRlkTxXfXG4XCS1phIIc6H9Kt8HwFadqLIgx+9ICCuyTZicPIwnUBt+TS4A+hz6k\n8KA87QWvnhteMHpu4UjIL8YRUAdNbFbRV9AuOmaR9HP11yueQd3B+5XnTt8x+JaO\nyWgsbUvBeGKIXPtGm70UgXeBi32vr6LtP5s2ijtj4zORMh5dxAkrjE0hO96E3D6Y\nriLlccqVMGTYhweDuIE4HJA+sY8vFXxSTsL193erJ6ooBUWxAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2xvZ2luLmR1LnNlhiJodHRwczovL2xvZ2luLmR1LnNlL2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBTYD58W7KLBxdd1F6vo5xlukwwdOTANBgkqhkiG\n9w0BAQUFAAOCAQEAXZRof2FZml44oPJ+2GkhIIK0U2t143xH4Z4J2iPbTjQyNfeo\neusGj+AvLkdkHLisqz8HTQC93sSYwPrQ1PMrqwAmnJZkhcySTto15Rgi5yNWsUFU\nE5RfYEcGj1P2R+uxUpCZ3qf9usCpGf5ao5rCoOjxtxGyv3PqDFTBwkjheuASpsug\nKnPqLMWV0RL1gmJhfAoCbhm+rM8FZZLXloDuV+Xzb0OmjruPupqtTJpHVBkaQ3OI\n2FIPaCf07HjPPcy4s9mQJGq9TEBKJ+WWwoT5ZvhYErkO7m2iQNsXUqCk/dt2Tp7e\nGqI848rh0Iif5MpxnsYQ/mxwDirbsler7jpF0Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "H\u00f6gskolan Dalarna"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Dalarna University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.du.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "DU"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.nordu.net/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "noc@nordu.net"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:noc@nordu.net"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "NORDUnet"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:noc@nordu.net"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "NORDUnet"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NUNOC"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:noc@nordu.net"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "NORDUnet"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.nordu.net/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUbYzFMX2BKRKmZwRSWg0HZ3/MQQwwDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNaWRwLm5vcmR1Lm5ldDAeFw0wOTA5MDMxOTI4NDlaFw0y\nOTA5MDMxOTI4NDlaMBgxFjAUBgNVBAMTDWlkcC5ub3JkdS5uZXQwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCSypIpdblxznunPXiwKCqwOYmj99u5S9f7\nRTR+s8EDs01uwJ8buJs0MId+s96mD8MIkobE4iwn/B6xlafbMr3/BF+XxxH8Q5WX\nBf3aQV3ohBqur6+mRQ2C+EenzPMGHmV/FCz0cbmTsIAQHZ9Vy16H+x5uWOBVd44i\nCMLM+fgjKyYcpcEUJP9Jkn/+d36L3mdXbyqAQS2UPN+S1g37xrgR2kWW+s1lMEiR\nM/f5L+PuA3l5DxIBmK0tFo+ZPLxbr6OBWOdH6EUbfdkvfciFCVNbWBGRW5MC2aru\nATCdtf/Vev3OngUYBGSR/94eTgMcs3Oww/ppxRS6dzntGnnCT1sPAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDWlkcC5ub3JkdS5uZXSGJGh0dHBzOi8vaWRwLm5vcmR1Lm5l\ndC9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUwPXuksUpm5OdopeWHdoRcs6wCu0w\nDQYJKoZIhvcNAQEFBQADggEBAHiPOKmhiLnx8ecuQHmwmh4DUZvarhZXNtgxyasU\nbZAfPoZn8YiELiqYQoA/j+hoAfWcCEafMgjm8nkQO9aad1cwpGY66SIRKPAKBgsW\nnOugnrREWwYl1tXG3VWYzpgygycziYzkmwc4ysHQATKjCYdulA1tZ09YiAnZOIzY\nQ93/gA7X177nVKnAbmSkY1Nap4/rbkHIvQqk8RPSYs5AwasThkEFVk4OQpPtoTOn\naOBLkJxpXY7rZDixrz59ny629qmOOakSCsuVkNwDPmbLQy9dKmHXTcge2xP0mDK7\nJiNCTXH29oP8kWBEBVaDxrDIrfDv53VjURS+KXqpBLjsuVE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nordu.net"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.nordu.net:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nordu.net:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.nordu.net/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.nordu.net/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.nordu.net/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.nordu.net/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.nordu.net:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nordu.net:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nordu.net"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "NORDUnet A/S Identitetsutf\u00e4rdare anv\u00e4nds av anst\u00e4llda och g\u00e4ster vid NORDUnet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The NORDUnet A/S Identity Provider is used by employees and guests of NORDUnet."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.nordu.net/resources/NORDUnet2.jpg",
                    "height": "46",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "203"
                  },
                  {
                    "text": "https://www.nordu.net/resources/NORDUnet2.jpg",
                    "lang": "sv",
                    "height": "46",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "203"
                  },
                  {
                    "text": "https://www.nordu.net/resources/NORDUnet2.jpg",
                    "lang": "en",
                    "height": "46",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "203"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NORDUnet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NORDUnet"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "nordu.net"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUbYzFMX2BKRKmZwRSWg0HZ3/MQQwwDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNaWRwLm5vcmR1Lm5ldDAeFw0wOTA5MDMxOTI4NDlaFw0y\nOTA5MDMxOTI4NDlaMBgxFjAUBgNVBAMTDWlkcC5ub3JkdS5uZXQwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCSypIpdblxznunPXiwKCqwOYmj99u5S9f7\nRTR+s8EDs01uwJ8buJs0MId+s96mD8MIkobE4iwn/B6xlafbMr3/BF+XxxH8Q5WX\nBf3aQV3ohBqur6+mRQ2C+EenzPMGHmV/FCz0cbmTsIAQHZ9Vy16H+x5uWOBVd44i\nCMLM+fgjKyYcpcEUJP9Jkn/+d36L3mdXbyqAQS2UPN+S1g37xrgR2kWW+s1lMEiR\nM/f5L+PuA3l5DxIBmK0tFo+ZPLxbr6OBWOdH6EUbfdkvfciFCVNbWBGRW5MC2aru\nATCdtf/Vev3OngUYBGSR/94eTgMcs3Oww/ppxRS6dzntGnnCT1sPAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDWlkcC5ub3JkdS5uZXSGJGh0dHBzOi8vaWRwLm5vcmR1Lm5l\ndC9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUwPXuksUpm5OdopeWHdoRcs6wCu0w\nDQYJKoZIhvcNAQEFBQADggEBAHiPOKmhiLnx8ecuQHmwmh4DUZvarhZXNtgxyasU\nbZAfPoZn8YiELiqYQoA/j+hoAfWcCEafMgjm8nkQO9aad1cwpGY66SIRKPAKBgsW\nnOugnrREWwYl1tXG3VWYzpgygycziYzkmwc4ysHQATKjCYdulA1tZ09YiAnZOIzY\nQ93/gA7X177nVKnAbmSkY1Nap4/rbkHIvQqk8RPSYs5AwasThkEFVk4OQpPtoTOn\naOBLkJxpXY7rZDixrz59ny629qmOOakSCsuVkNwDPmbLQy9dKmHXTcge2xP0mDK7\nJiNCTXH29oP8kWBEBVaDxrDIrfDv53VjURS+KXqpBLjsuVE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://el-shib.redbridge-college.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Calcanis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ccalcanis@redbridge-college.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Costas"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Calcanis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ccalcanis@redbridge-college.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Costas"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rix"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SRix@redbridge-college.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://el-shib.redbridge-college.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE9TCCA92gAwIBAgIUagM7HIObwsBc6vG5npewc1u5v4cwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwTTELMAkGA1UEBhMCQk0xGTAXBgNVBAoTEFF1b1ZhZGlzIExpbWl0ZWQxIzAh\n\t\t\t\t\t\tBgNVBAMTGlF1b1ZhZGlzIEdsb2JhbCBTU0wgSUNBIEcyMB4XDTE1MDkwODE0NDk0\n\t\t\t\t\t\tNVoXDTE4MDkwODE0NDk0MlowdTELMAkGA1UEBhMCR0IxDjAMBgNVBAgTBUVzc2V4\n\t\t\t\t\t\tMRAwDgYDVQQHEwdST01GT1JEMRowGAYDVQQKExFSZWRicmlkZ2UgQ29sbGVnZTEo\n\t\t\t\t\t\tMCYGA1UEAxMfZWwtc2hpYi5yZWRicmlkZ2UtY29sbGVnZS5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMdTpjzblIBIPOjdndi8VlztmlSqEuuZ\n\t\t\t\t\t\tz8SpTUUTsvdQY38lMSo4csothgJ3f2kZy1WAWLl+8JMwafwb/TIA3qr3flU7lY7P\n\t\t\t\t\t\tEOX4mVJfw37baxrPsXbMVmT8KKoDjA4a8p1cF7vEMXZoNLOf3JSdBKirdUqr2GXI\n\t\t\t\t\t\tOMT//ZGLvMi5HHVJVr06OPoq0nhjfdnKrXxGhubyXNvS7JvAEpG5hPhSyYJIcwNN\n\t\t\t\t\t\tYt/KYlDVKYg+rq1+xMKWe2Tum7gbR4zmI9SY/lM3a/0wEdCChUDydPdNDwKXzLi0\n\t\t\t\t\t\tRQCqQXUW/bRkvdG3SP1zyxrp1FCIIpzTN8wHYpMb59yNAZZgABRPgY8CAwEAAaOC\n\t\t\t\t\t\tAaMwggGfMHMGCCsGAQUFBwEBBGcwZTAqBggrBgEFBQcwAYYeaHR0cDovL29jc3Au\n\t\t\t\t\t\tcXVvdmFkaXNnbG9iYWwuY29tMDcGCCsGAQUFBzAChitodHRwOi8vdHJ1c3QucXVv\n\t\t\t\t\t\tdmFkaXNnbG9iYWwuY29tL3F2c3NsZzIuY3J0MCoGA1UdEQQjMCGCH2VsLXNoaWIu\n\t\t\t\t\t\tcmVkYnJpZGdlLWNvbGxlZ2UuYWMudWswUQYDVR0gBEowSDBGBgwrBgEEAb5YAAJk\n\t\t\t\t\t\tAQEwNjA0BggrBgEFBQcCARYoaHR0cDovL3d3dy5xdW92YWRpc2dsb2JhbC5jb20v\n\t\t\t\t\t\tcmVwb3NpdG9yeTAOBgNVHQ8BAf8EBAMCBaAwHQYDVR0lBBYwFAYIKwYBBQUHAwEG\n\t\t\t\t\t\tCCsGAQUFBwMCMB8GA1UdIwQYMBaAFJEZYq1bF6cw+/DeOSWxvYy5uFEnMDoGA1Ud\n\t\t\t\t\t\tHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwucXVvdmFkaXNnbG9iYWwuY29tL3F2c3Ns\n\t\t\t\t\t\tZzIuY3JsMB0GA1UdDgQWBBReigpWOKm7kmbecl3kbYHHmDYV2jANBgkqhkiG9w0B\n\t\t\t\t\t\tAQsFAAOCAQEAyeqcraJy5YqVouvgEtoMq5XAZFubSHBJIVphFk5FxRDmQlV9JVtK\n\t\t\t\t\t\tYHMjBsS3EtjmamuOiEzzlQU8MTGgPguM8ZbBk1RcaNu6NtOCltvsBmKJiu+5AGGt\n\t\t\t\t\t\txFwQUzuf2tFSYJeFopw4Xm1Min3RoOYUJoJSur929Is+yCzETPl37CYUaFGvyi41\n\t\t\t\t\t\tDYGhDdUM7bgnCdwz5i8W13grJUGFAZ7DB/OslRZoI2V561ouAZniHqXmB/JYjCYu\n\t\t\t\t\t\tigMV2oGL+OhHTWGj9vmEepjs+fV31OgQsYSsDiWjUPiVFR0qhdzVuMeoZ4j1EEkO\n\t\t\t\t\t\tqNW7y+yIK2juWVtby4S8n7fOcXfOL1m8WA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "redbridge-college.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://el-shib.redbridge-college.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://el-shib.redbridge-college.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://el-shib.redbridge-college.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://el-shib.redbridge-college.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://el-shib.redbridge-college.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://el-shib.redbridge-college.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://el-shib.redbridge-college.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://el-shib.redbridge-college.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "redbridge-college.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE9TCCA92gAwIBAgIUagM7HIObwsBc6vG5npewc1u5v4cwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwTTELMAkGA1UEBhMCQk0xGTAXBgNVBAoTEFF1b1ZhZGlzIExpbWl0ZWQxIzAh\n\t\t\t\t\t\tBgNVBAMTGlF1b1ZhZGlzIEdsb2JhbCBTU0wgSUNBIEcyMB4XDTE1MDkwODE0NDk0\n\t\t\t\t\t\tNVoXDTE4MDkwODE0NDk0MlowdTELMAkGA1UEBhMCR0IxDjAMBgNVBAgTBUVzc2V4\n\t\t\t\t\t\tMRAwDgYDVQQHEwdST01GT1JEMRowGAYDVQQKExFSZWRicmlkZ2UgQ29sbGVnZTEo\n\t\t\t\t\t\tMCYGA1UEAxMfZWwtc2hpYi5yZWRicmlkZ2UtY29sbGVnZS5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMdTpjzblIBIPOjdndi8VlztmlSqEuuZ\n\t\t\t\t\t\tz8SpTUUTsvdQY38lMSo4csothgJ3f2kZy1WAWLl+8JMwafwb/TIA3qr3flU7lY7P\n\t\t\t\t\t\tEOX4mVJfw37baxrPsXbMVmT8KKoDjA4a8p1cF7vEMXZoNLOf3JSdBKirdUqr2GXI\n\t\t\t\t\t\tOMT//ZGLvMi5HHVJVr06OPoq0nhjfdnKrXxGhubyXNvS7JvAEpG5hPhSyYJIcwNN\n\t\t\t\t\t\tYt/KYlDVKYg+rq1+xMKWe2Tum7gbR4zmI9SY/lM3a/0wEdCChUDydPdNDwKXzLi0\n\t\t\t\t\t\tRQCqQXUW/bRkvdG3SP1zyxrp1FCIIpzTN8wHYpMb59yNAZZgABRPgY8CAwEAAaOC\n\t\t\t\t\t\tAaMwggGfMHMGCCsGAQUFBwEBBGcwZTAqBggrBgEFBQcwAYYeaHR0cDovL29jc3Au\n\t\t\t\t\t\tcXVvdmFkaXNnbG9iYWwuY29tMDcGCCsGAQUFBzAChitodHRwOi8vdHJ1c3QucXVv\n\t\t\t\t\t\tdmFkaXNnbG9iYWwuY29tL3F2c3NsZzIuY3J0MCoGA1UdEQQjMCGCH2VsLXNoaWIu\n\t\t\t\t\t\tcmVkYnJpZGdlLWNvbGxlZ2UuYWMudWswUQYDVR0gBEowSDBGBgwrBgEEAb5YAAJk\n\t\t\t\t\t\tAQEwNjA0BggrBgEFBQcCARYoaHR0cDovL3d3dy5xdW92YWRpc2dsb2JhbC5jb20v\n\t\t\t\t\t\tcmVwb3NpdG9yeTAOBgNVHQ8BAf8EBAMCBaAwHQYDVR0lBBYwFAYIKwYBBQUHAwEG\n\t\t\t\t\t\tCCsGAQUFBwMCMB8GA1UdIwQYMBaAFJEZYq1bF6cw+/DeOSWxvYy5uFEnMDoGA1Ud\n\t\t\t\t\t\tHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwucXVvdmFkaXNnbG9iYWwuY29tL3F2c3Ns\n\t\t\t\t\t\tZzIuY3JsMB0GA1UdDgQWBBReigpWOKm7kmbecl3kbYHHmDYV2jANBgkqhkiG9w0B\n\t\t\t\t\t\tAQsFAAOCAQEAyeqcraJy5YqVouvgEtoMq5XAZFubSHBJIVphFk5FxRDmQlV9JVtK\n\t\t\t\t\t\tYHMjBsS3EtjmamuOiEzzlQU8MTGgPguM8ZbBk1RcaNu6NtOCltvsBmKJiu+5AGGt\n\t\t\t\t\t\txFwQUzuf2tFSYJeFopw4Xm1Min3RoOYUJoJSur929Is+yCzETPl37CYUaFGvyi41\n\t\t\t\t\t\tDYGhDdUM7bgnCdwz5i8W13grJUGFAZ7DB/OslRZoI2V561ouAZniHqXmB/JYjCYu\n\t\t\t\t\t\tigMV2oGL+OhHTWGj9vmEepjs+fV31OgQsYSsDiWjUPiVFR0qhdzVuMeoZ4j1EEkO\n\t\t\t\t\t\tqNW7y+yIK2juWVtby4S8n7fOcXfOL1m8WA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Redbridge College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.redbridge-college.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Redbridge College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth2sp.gar.semcs.net/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pallant"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:gsupport@gardners.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pallant"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:gsupport@gardners.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth2sp.gar.semcs.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-05-28T10:24:56Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "VLebooks.com"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vlebooks.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Little Group Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.gar.semcs.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.gar.semcs.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.gar.semcs.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.gar.semcs.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.gar.semcs.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth2sp.gar.semcs.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth2sp.gar.semcs.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDzjCCAzegAwIBAgIDEAAjMA0GCSqGSIb3DQEBBAUAMG8xCzAJBgNVBAYTAlVL\n\t\t\t\t\t\tMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIwEAYDVQQKEwlz\n\t\t\t\t\t\tZW1hbnRpY28xKDAmBgNVBAMTH3NlbWFudGljbyBDZXJ0aWZpY2F0ZSBBdXRob3Jp\n\t\t\t\t\t\tdHkwHhcNMTIwNDIwMTM1MjI5WhcNMTcwNDE5MTM1MjI5WjBrMQswCQYDVQQGEwJV\n\t\t\t\t\t\tSzEPMA0GA1UECBMGU3Vzc2V4MREwDwYDVQQHEwhCcmlnaHRvbjESMBAGA1UEChMJ\n\t\t\t\t\t\tc2VtYW50aWNvMSQwIgYDVQQDExtzaGliYm9sZXRoMnNwLmdhci5zZW1jcy5uZXQw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDdJq+9YYHBJSKcQ26wtmpE\n\t\t\t\t\t\thsXw0R2I+9H9WSzo6ERHWulIEv7ttLeE6c3kaZ2n0lI9LQJ2AY1FrHh5tuf7gNCG\n\t\t\t\t\t\t2RuCOn3i5TMKOw1V3t6PST+iobyoHm/sVH5g83gsnWdy4wMQr35u/0ltPpx5prEd\n\t\t\t\t\t\tiTLDBechElt+xSBmwab5FK+MDqd9cjYsg8JSw4bdwA9sXmODhARJTt4tq8lM4okO\n\t\t\t\t\t\tXJv9Wxs1YChFDfp8IxCbPt6POqwSsRzQkUEOmXslZXFAliClL1MN0PrEIzjHX37+\n\t\t\t\t\t\tVuUJiClGh0xIk8Q5W8zQmSt7aFDXz0Sd5iMTAFt4uD3euQKSj1h3zlKra7/tDKIF\n\t\t\t\t\t\tAgMBAAGjgfcwgfQwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBH\n\t\t\t\t\t\tZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFKMVuS23Tsl/+3uAUf2T1db7\n\t\t\t\t\t\t/LWdMIGZBgNVHSMEgZEwgY6AFAIbTpo38I1qaERGxh1E/rqyXr45oXOkcTBvMQsw\n\t\t\t\t\t\tCQYDVQQGEwJVSzEPMA0GA1UECBMGU3Vzc2V4MREwDwYDVQQHEwhCcmlnaHRvbjES\n\t\t\t\t\t\tMBAGA1UEChMJc2VtYW50aWNvMSgwJgYDVQQDEx9zZW1hbnRpY28gQ2VydGlmaWNh\n\t\t\t\t\t\tdGUgQXV0aG9yaXR5ggEAMA0GCSqGSIb3DQEBBAUAA4GBAHV2kw0DugD5tIFjK8Nz\n\t\t\t\t\t\tzc07Blr0nhVACm9y3rE+qThIW9N36HG9QiFbMjNECctggBtR/3Ne81wMqJF4V2fT\n\t\t\t\t\t\tO37Rw5jvRqdt0E37hhYtiWVCQPPKYtuHpQ9Jiz/8nEiH2Ozpq3CHC8VDb3D5qbZm\n\t\t\t\t\t\tx5OFM73HnkJd1Zy08T41rQ9l"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.gar.semcs.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.gar.semcs.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.gar.semcs.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.gar.semcs.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.gar.semcs.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth2sp.gar.semcs.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.gar.semcs.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth2sp.gar.semcs.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth2sp.gar.semcs.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth2sp.gar.semcs.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://student.cvt.grayzone.ladok.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://student.cvt.grayzone.ladok.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.cvt.grayzone.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.cvt.grayzone.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.cvt.grayzone.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.cvt.grayzone.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.cvt.grayzone.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://student.cvt.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://student.cvt.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://student.cvt.grayzone.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok student.cvt.grayzone.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok student.cvt.grayzone.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://student.cvt.grayzone.ladok.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "student.cvt.grayzone.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIJAOpgFVuQUtH6MA0GCSqGSIb3DQEBCwUAMCgxJjAkBgNV\nBAMTHXN0dWRlbnQuY3Z0LmdyYXl6b25lLmxhZG9rLnNlMB4XDTE2MDMyMzA4Mzgw\nMVoXDTI2MDMyMTA4MzgwMVowKDEmMCQGA1UEAxMdc3R1ZGVudC5jdnQuZ3JheXpv\nbmUubGFkb2suc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDH+h1/\nBrzmj+s08QwYM4l5O0818VgVL2c/V9BT4vEtB0KBcHg6ZJ6BDTNbW23MlEi3lhIx\n/x37n8itZoaN5oXpr1skEPhtEE7aeCclMhPE/o7N1VaFC0XJODqQ8Je6Z1lrCC9y\nCGW8/UaG4vNm5dMe2fJRUnsUi2eXvNUHW38lY6Qy5h7fu1v0/3xOc4bmz15gno7L\nLV6XgHTrlQ0AUqksZXwjjWROT+gg2XY/iW4agpd2ToTmA8w/4a3i9c+AD9XDXIiP\nl8dAE9eoGi3oFcw6xMZcDgEnZ2SRXdl47Xv3v1KnHaebcpdh4GntjQ3KfQwZ0K3V\neBkHZKkC66Tplq5bAgMBAAGjeTB3MFYGA1UdEQRPME2CHXN0dWRlbnQuY3Z0Lmdy\nYXl6b25lLmxhZG9rLnNlhixodHRwczovL3N0dWRlbnQuY3Z0LmdyYXl6b25lLmxh\nZG9rLnNlL2d1aS1zcDAdBgNVHQ4EFgQUJ6BsYHxsMlx/dFr2rU1C8IF6zpUwDQYJ\nKoZIhvcNAQELBQADggEBADUU/h/13o5Rx3dQ20A/QePdoDYOSGSg7uuIvu+clP/q\nYofp52zdyBy8xvDXJHjSuxLQUCSBMDGcUpiQBLdgT5AMoO634HXMbNx9Wg/u80Q4\nwJVVNLthWkr6yoW4f3uMYPlvKv6uxZDsjpFVcDmrJEG/isTcM2hKnLIRkqhfz0R0\nhM4d4hmp66jbA+rR4quZc06JDk9GQtfHKpd0e/E2m1icZ0iXNQoR3nWhy43w8/1F\nQ6FEQILyrefMbTyzMrZLAwVrrdUj4CGKUT5trlYz+7oxmfIdevj3BoxeJJCbUIRS\nEaa85NvpzKUAXe6s3r7I7NqyPBiZqlys09ihK5QDjG8="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=student.cvt.grayzone.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.cvt.grayzone.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.cvt.grayzone.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.cvt.grayzone.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.cvt.grayzone.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.cvt.grayzone.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.cvt.grayzone.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://student.cvt.grayzone.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://student.cvt.grayzone.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://student.cvt.grayzone.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://its-pd0243.its.umu.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://its-pd0243.its.umu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/SU",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/KI",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/Loginy",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/Loginx",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Utveckling av fr\u00e4mst Servicedesk och ADFS"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Development of Servicedesk application and ADFS"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Utvecklarmaskin f\u00f6r Olov H\u00f6glund, ITS, Ume\u00e5 universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Development workstation for Olov Hoglund, ITS, Umea University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "its-pd0243.its.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID+zCCAuOgAwIBAgIJAO0C37kikt+EMA0GCSqGSIb3DQEBBQUAMIGTMQswCQYD\nVQQGEwJTRTEVMBMGA1UECAwMVmFzdGVyYm90dGVuMQ0wCwYDVQQHDARVbWVhMQww\nCgYDVQQKDANJVFMxDDAKBgNVBAsMA0lUUzEeMBwGA1UEAwwVaXRzLXBkMDI0My5p\ndHMudW11LnNlMSIwIAYJKoZIhvcNAQkBFhNvbG92LmhvZ2x1bmRAdW11LnNlMB4X\nDTE0MDgyMDA2MDM1MFoXDTE3MDcwMzA2MDM1MFowgZMxCzAJBgNVBAYTAlNFMRUw\nEwYDVQQIDAxWYXN0ZXJib3R0ZW4xDTALBgNVBAcMBFVtZWExDDAKBgNVBAoMA0lU\nUzEMMAoGA1UECwwDSVRTMR4wHAYDVQQDDBVpdHMtcGQwMjQzLml0cy51bXUuc2Ux\nIjAgBgkqhkiG9w0BCQEWE29sb3YuaG9nbHVuZEB1bXUuc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDEJjAAtMcLWFzkaxFLzzaLuq9ofPdVV5myt33h\n+QJw2NSdZ20okuDJSqZPl1bvaDjMDpUXr0ZcJOG8yfACONCTsQ0tT7gaVsnKnZzL\nNSGAF9y0LoK3fiHfYpBE68zPidBS68i7x6fIvATUtEkm8YfbCLTTFqJ/+7ubexDg\nvHVutOBcLrWp2vuX68t6C6Ci/9+SJLLJ7MBahBQqBA+5HRB6MEPAslhUsDmUOtCN\n9HmMJLAAbNVSSDdca2uHWCyj5lQ0vQtApQ4QJEhoPm1q4FTC+abjresUzKmdRSog\nOqQNTGcAxfxiwcFhRH1Ev9h3MxdqoIKTV2ciWgBzVii0UOafAgMBAAGjUDBOMB0G\nA1UdDgQWBBQmbF7b9TbjNUQEw4YyGmGKfxB2HzAfBgNVHSMEGDAWgBQmbF7b9Tbj\nNUQEw4YyGmGKfxB2HzAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQA7\nSWzr3GMHqSRTaJQ++9ZpgmjcYEd3N7T1LFt1PlPy/sjpCwR4Y7BxFzjxR+4drtOs\ng8ZNYb1j1jx0OI1argiL6fHqvqfVGzihEPxdWEY83ewkZoUd+kGP5fCtRqTnjoAO\n6c22xEHvEvH2tpDeS9voRd/X+6i2pU0S2G/8fwhI5Mo81nC8I6JukdbR10Z2eldM\nH6CiTAXVx8zGKI9/1w0paMJyUVhHD+pYTebZrQd7CbZ/F5P8EhP7s8lUb5BtlCuD\nWzpbQSb/6vmdDbH3lTuWCMMrYZXYmS1QCcLVd1G2VaUhb2ThAC+6PMWQB0OggOax\n79H2Yw28W8Q9+HnLTqe2"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=olov.hoglund@umu.se,CN=its-pd0243.its.umu.se,OU=ITS,O=ITS,L=Umea,ST=Vasterbotten,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://its-pd0243.its.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.its.msstate.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@msstate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSU ITS Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ns@its.msstate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSU ITS Network Services"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "timothy.griffin@msstate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Timothy Griffin"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.its.msstate.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.its.msstate.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.its.msstate.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.its.msstate.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.its.msstate.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.its.msstate.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.its.msstate.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "msstate.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mississippi State University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIVANqzVBR0Ub2osTQEQ2V2uRrFt0GPMA0GCSqGSIb3DQEB\nBQUAMCUxIzAhBgNVBAMTGnNoaWJib2xldGguaXRzLm1zc3RhdGUuZWR1MB4XDTEz\nMDExNTE3MTU0MFoXDTMzMDExNTE3MTU0MFowJTEjMCEGA1UEAxMac2hpYmJvbGV0\naC5pdHMubXNzdGF0ZS5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQCyvEFOnNepgD7v2ksAAsWXzY0M6s8nVe8SCt1wWDkK+XtdTVguj2ddZIQlzjkH\nJkepcXA9x5Gnd/1lzOnVFYUSBGcsnMNDmiKxOPxIOHFOzAybNeYQD4ulR0HKyxWd\nHVH/y7G5AXcZaRPuYT1e2z5xXVl3JGZHTqt6pqQy00NwL3xi1sTv9FqD20r3JcEH\njG1m2S/VO8SFu3cVgrfcA9J9BbKFc4FJvrPDLP8ds8/gqchqF5L7sWyybJC6VbEP\nqqiK//h38QqVr/hsuVLRgJNF2PrksxCaCbsA0Q+cSumBDOEQDgX3V6SOyFGx0oJs\n1BBlQBFdaZBRQQpQQaYVfIfVAgMBAAGjezB5MFgGA1UdEQRRME+CGnNoaWJib2xl\ndGguaXRzLm1zc3RhdGUuZWR1hjFodHRwczovL3NoaWJib2xldGguaXRzLm1zc3Rh\ndGUuZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTJyRHIMBZd5g8w0YzhKEBA\njGoJCjANBgkqhkiG9w0BAQUFAAOCAQEAdStvD4PVUxs4VUgBjHbPKXoYQQVS/2Q7\nz7Vm4pPhZPK6m82kIfSfaHp1LbfrERPN04hNWIlFW4oj/QbSPuBDMlaCabXuoVH9\nXiVr8cDW2f66FuDeSZrVYvltQqZQDUPsys15UUAZNFEb0EQhKgHHECA1CnW9A9QM\nwqjNtO9uC2kPB65jwrfvR4Eujy6e/wmYtdDgBOdOyjp0rDsNahJTHIyC1kzmZlPK\nHw4g1sKAIewhtdzA1GPcBp4kuEf8aibTacVSgcihfol036K/BdzBQoQRKGhxD2Kv\nUohgYrFSnjdlhb1yEAXtpAsc8HTum2zkA4NGo3R+9J8rXL6lS6oozA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mississippi State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.msstate.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Mississippi State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://arts.idm.oclc.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Akkineni"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ezproxy@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Vasu"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Akkineni"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ezproxy@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Vasu"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://arts.idm.oclc.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-07-30T17:57:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of the Arts, London hosted EZproxy"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oclc.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "OCLC (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID6zCCAtOgAwIBAgIBAzANBgkqhkiG9w0BAQUFADBcMRwwGgYDVQQDFBMqLmFy\n\t\t\t\t\t\tdHMuaWRtLm9jbGMub3JnMQswCQYDVQQGEwJVSzENMAsGA1UEChMET0NMQzEgMB4G\n\t\t\t\t\t\tCSqGSIb3DQEJARYRYWtraW5lbnZAb2NsYy5vcmcwHhcNMTQwNTA4MjA1NjIwWhcN\n\t\t\t\t\t\tMjQwNTA3MjA1NjIwWjBcMRwwGgYDVQQDFBMqLmFydHMuaWRtLm9jbGMub3JnMQsw\n\t\t\t\t\t\tCQYDVQQGEwJVSzENMAsGA1UEChMET0NMQzEgMB4GCSqGSIb3DQEJARYRYWtraW5l\n\t\t\t\t\t\tbnZAb2NsYy5vcmcwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCxhYmM\n\t\t\t\t\t\tPDckQ2CMHBBJrHdBjDAsWnPgCA6g86v7Qizdq5ujo7zQEpmP83jQYVAo93g4dxT0\n\t\t\t\t\t\tv0KH7uvfZ3eHJtLAjFBY4BCKCfWQ9b2zINAd4V/Aay0e99e3+cGd/XKi4/sf+mh6\n\t\t\t\t\t\tQrHErw5TFGLKfassMrFWSyhxzH7pWL+DW6fDV1fdjH0LhbyrZF0UNeLTc/4+Y2e+\n\t\t\t\t\t\tr1hV+BS2NUGSEXZPfWDR3/+1J5VgBLrEV1QyqMJtJIB3M9TIJGLnVyX8oIjN1MTP\n\t\t\t\t\t\thl8418xabyz8S+vkwCDhDfPWNQ+czGkPHNs0920wh+MpUKwyoH5VDidDTHCTEcDY\n\t\t\t\t\t\tcetXuGrggUZ/iJoZAgMBAAGjgbcwgbQwHQYDVR0OBBYEFBuFHyLKMAenvRmdB0Zy\n\t\t\t\t\t\tmLXvygvgMIGEBgNVHSMEfTB7gBQbhR8iyjAHp70ZnQdGcpi178oL4KFgpF4wXDEc\n\t\t\t\t\t\tMBoGA1UEAxQTKi5hcnRzLmlkbS5vY2xjLm9yZzELMAkGA1UEBhMCVUsxDTALBgNV\n\t\t\t\t\t\tBAoTBE9DTEMxIDAeBgkqhkiG9w0BCQEWEWFra2luZW52QG9jbGMub3JnggEDMAwG\n\t\t\t\t\t\tA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAD6KWro7Cu4sxiXwRawL2LGf\n\t\t\t\t\t\tbArwdzRjO61AlIXg+8XOvYq1BBxjqsP5r1aLlj9y/vAZGSPQQfLpz/omoU3vIu0o\n\t\t\t\t\t\t59wlCvcH84ZZOnYUCCmZVoQe9LfYGprh9Gl2aESEwdxwilDjrqfuKMPgBD0DBQxc\n\t\t\t\t\t\tvQQLWqSYZy3vAh6p+2Ul2rh0/Ue2sOjaUqAfrLhE7m+j7lxbBg70x45ckgW4gQBK\n\t\t\t\t\t\tUVS0Rdy9MIWHbFmfvEjVZnirY746qWAGoSy1xn0H8V141ELqW9oe+Sjvc08HgzQ0\n\t\t\t\t\t\t1VqrWlvm0Q4K50yGzWMyoFLb/QJfj0sbC0Sb/9w7LlHUj9b//QQ6qeEL4j1Qkdw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://login.arts.idm.oclc.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.arts.idm.oclc.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.arts.idm.oclc.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.arts.idm.oclc.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayf.akademiaarhus.dk/simplesaml-eaa/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayf.akademiaarhus.dk/simplesaml-eaa/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2015-06-14T14:44:25Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayf.akademiaarhus.dk/simplesaml-eaa/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "erhvervsakademiaarhus.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Erhvervsakademi Aarhus"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Business Academy Aarhus"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "erhvervsakademiaarhus.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEDCCAfgCAQcwDQYJKoZIhvcNAQELBQAwTjFMMEoGA1UEAwxDaHR0cHM6Ly93\nYXlmLmFrYWRlbWlhYXJodXMuZGsvc2ltcGxlc2FtbC1lYWEvc2FtbDIvaWRwL21l\ndGFkYXRhLnBocDAeFw0xNTAxMDEwMDAwMDBaFw0yNTEyMzEyMzU5NTlaME4xTDBK\nBgNVBAMMQ2h0dHBzOi8vd2F5Zi5ha2FkZW1pYWFyaHVzLmRrL3NpbXBsZXNhbWwt\nZWFhL3NhbWwyL2lkcC9tZXRhZGF0YS5waHAwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQDHiAwKahBTuI4Z+IJ1rgOeEiCCy3bR9QIe3BpCsejFCU5rSzkW\nANqVuc1PDfp0JdIZhrPXsmDJQMmidPCGPIDQKo+bk+af3+EUFS/I/+35sSBX2vf+\nh1DHvZV9jsznmpSVjp7HZ/WoPWBykWBJO0AOVmzB5zlaqkS36J76+wxerwdpuExV\nnYSNd73S+AyT/EZ+tXAO+6lQ8FL/YMlJnUkSaSqLSHFy01D2qBNmYRwBpCS6/dUZ\nyxi0t5j8ghKUD4BHOZVavn65J62cJdXiOcMRyUAIp57GXQrL63KtrjIcXddq+CZy\nZ5t37EdUOIz42joFcy73MFOntynlKEvOw1BJAgMBAAEwDQYJKoZIhvcNAQELBQAD\nggEBALNRxgXj157kbsaXgCJAJiLeEujm+f4ISKt4/s9CGHANaKOjH4ZnjABS2/cb\neLDxUGByE6g5RrX1LoF9etchQkeqX5tZPAiM0CEpYWKsmzDQ9d/EMKQl15mi8m3A\ntefAOT55SYuQwcznxF+Q4AYuaoePuaZk9snq/H1n718pNe6iCg6Big9+nB3vGvyV\nVO3JXZA/IjUtIWaBxX0wR6vfbblwKV6ogh76RKUckf40KeLLl2vMSuW/hEL6lN4Q\nDdbjKB6UO7mTuqPKUxkGG2oviO3YApEyi1jggBDOeblg450UyjsTJcivVg2prmgB\n5GuMfc4nu4mQairTeApR3+mF2SA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Erhvervsakademi Aarhus"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Business Academy Aarhus"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eaaa.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eaaa.dk/subsites/international"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Erhvervsakademi Aarhus"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Business Academy Aarhus"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://staging.jorum.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@jorum.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jorum Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mimas-shib-tech@listserv.manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mimas Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://staging.jorum.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-02-04T15:33:29Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The University of Manchester: Jorum Staging"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://mimas.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Manchester"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://staging.jorum.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vm-jorum.ds.man.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://staging.resourceshare.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://webstaging.jorum.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "4"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://staging.jorum.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vm-jorum.ds.man.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://staging.resourceshare.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://webstaging.jorum.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://staging.jorum.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://vm-jorum.ds.man.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://staging.resourceshare.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://webstaging.jorum.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "4"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIJAMvDRTJflddLMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\n\t\t\t\t\t\tBAMTE3N0YWdpbmcuam9ydW0uYWMudWswHhcNMTMwMjAxMTE0MjMyWhcNMjMwMTMw\n\t\t\t\t\t\tMTE0MjMyWjAeMRwwGgYDVQQDExNzdGFnaW5nLmpvcnVtLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAshCDHUltlUA+s2SyenjOhv25bLCgF0e/\n\t\t\t\t\t\t6akdpCN65otOt5+naesfGFdZslcQ/CCqAe1i5tFCmBZ8eNSGt75pcmoqkzDPhpBN\n\t\t\t\t\t\tmOsxaJjdwxHrnQWbFOXr+A10GPsdne0WfdBF/id4ZSPEHAeFPbqXtAP7cV1xQO6p\n\t\t\t\t\t\tPq7KVotO6vZZCDvqQlqnMXNuet3uVAYy9KZUCaJc2BqgN/PqZPGuFh05yUTDxpU+\n\t\t\t\t\t\tNheOQB6G8uJOxeQMgzlda7DGpmyCJ/WQ2AfsFI5j5LFDd1bOF10D+CyWOwduieEX\n\t\t\t\t\t\t1qNqbEEydR+CfFigLa2lHyOKTrz2S1O3pGo3Gv06ucLHbd+z3yDzDQIDAQABo2kw\n\t\t\t\t\t\tZzBGBgNVHREEPzA9ghNzdGFnaW5nLmpvcnVtLmFjLnVrhiZodHRwczovL3N0YWdp\n\t\t\t\t\t\tbmcuam9ydW0uYWMudWsvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUUC/AOy7IH6iDm768\n\t\t\t\t\t\t7bNBfNwPApgwDQYJKoZIhvcNAQEFBQADggEBAKtuA1eo/6O9HtcgSN6ykYW/HVIM\n\t\t\t\t\t\tUvIXjowkbDvTBfF4az9ywZ2fgBMoJwTXUSGR4cRW5E8jlKexloFvfaoFMKNnN/C9\n\t\t\t\t\t\tevebn4ffrjrfYh9RjsBl1vA6eingNUxUSfMNxsf2evGalI/x243F5XarJYDhbafL\n\t\t\t\t\t\tU/UTjsVhMGOOVZopa3ibB9dCDw0152WL70p8i1CD5BdMuqEPxoMnDctaJ+4WXuyP\n\t\t\t\t\t\tA21yBq6YB6zqgnzFWuIGyb+2nluyUEi3NG0Qg6w6sv9ouZl+LM1kUmfyFYHOogJZ\n\t\t\t\t\t\tXEkxDTRCPMvlCw7I3BmOYjXH2WiVhzM8ytwkOdu12ZtJGSUqFoUhE1YNUdo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://staging.jorum.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://staging.jorum.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://staging.jorum.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://staging.jorum.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://staging.jorum.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://staging.jorum.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vm-jorum.ds.man.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vm-jorum.ds.man.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vm-jorum.ds.man.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vm-jorum.ds.man.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vm-jorum.ds.man.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vm-jorum.ds.man.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://staging.resourceshare.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://staging.resourceshare.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://staging.resourceshare.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://staging.resourceshare.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://staging.resourceshare.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://staging.resourceshare.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "18"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webstaging.jorum.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "19"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://webstaging.jorum.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "20"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://webstaging.jorum.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "21"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://webstaging.jorum.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "22"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://webstaging.jorum.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "23"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://webstaging.jorum.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "24"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idpunict.unict.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-idem@unict.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idpunict.unict.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2014-01-27T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAN3muNVpnUKhVVYLS4LTiTLhtjaeMA0GCSqGSIb3DQEB\nBQUAMBwxGjAYBgNVBAMTEWlkcHVuaWN0LnVuaWN0Lml0MB4XDTEzMDYxMjA4Mzgx\nMFoXDTMzMDYxMjA4MzgxMFowHDEaMBgGA1UEAxMRaWRwdW5pY3QudW5pY3QuaXQw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDRcO4zsz2CKoLSYLkq2aNx\nL/jolby6jN7FfDfNZ0W/tfMot029Hnz7Euj73+4+4i5XzuVwIFBEDA9VYGYbI0mr\nE0NhPWnE1AQa90Vr2P2mFql30I3Dcl7J6S8saLuhOzD74hKXI5IbS6FqziiQwyXj\nieeySXDlbpuAX4Tcfw7onVam5MN9RKpROi9AVT37UPZLMKX7SEK3DJ7/4ERoQp3q\nf2FEQyoy/Q92ssUQgbQ96/7d91qw36wEu9Y8hSP8FRchVTCRHGnEv4IBhU+PnAPz\nw3k2ragDFtwACmgoWliOi0HpI0rSHkxX8jIboWuSHdUQNMEEi1cywPMvfNrEe5Cd\nAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEWlkcHVuaWN0LnVuaWN0Lml0hihodHRwczov\nL2lkcHVuaWN0LnVuaWN0Lml0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQGpdyP\nso1uajvYMo3tDLyvhbL3kDANBgkqhkiG9w0BAQUFAAOCAQEAq4v0tIwHi/N5dGVt\new6eRGofDAdj6F8QEwQsMwBruYO3lnteVBFNTeZ5igR6PuHTzOnOIM7v98/9T0oS\naoCED1LzHKCQaRu0WCpHGjOceJ5YtmCg9R8WCoBG5A2ND3vMllJvEGQTLLcTS7ve\ngI+pG7Fb79xuhASYkARXZ7nU5Xep2dc+a+rtSX5MTvRwczx7HdqxERQUDn7+qKWv\nV5i2qJtpsBkgwbQjpfjs5ReIMxl4QhEbnshqKNJVUf8IsTGGmYLuj2Sn/t29K6sC\n8rUp8lyUvZ8nyy/IRvMb+fFmx4/KUicxeUfqmbbwCZXdMtciGfSHVXLyhhs0xAAH\n/xmo2Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unict.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idpunict.unict.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idpunict.unict.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idpunict.unict.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idpunict.unict.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idpunict.unict.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idpunict.unict.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idpunict.unict.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idpunict.unict.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unict.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unict.it/content/descrizione-del-servizio-idem"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unict.it/content/descrizione-del-servizio-idem"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for University of Catania users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider per gli utenti dell'Universit\u00e0 degli Studi di Catania"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.unict.it/content/descrizione-del-servizio-idem"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.unict.it/content/descrizione-del-servizio-idem"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Catania"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 degli Studi di Catania"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAN3muNVpnUKhVVYLS4LTiTLhtjaeMA0GCSqGSIb3DQEB\nBQUAMBwxGjAYBgNVBAMTEWlkcHVuaWN0LnVuaWN0Lml0MB4XDTEzMDYxMjA4Mzgx\nMFoXDTMzMDYxMjA4MzgxMFowHDEaMBgGA1UEAxMRaWRwdW5pY3QudW5pY3QuaXQw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDRcO4zsz2CKoLSYLkq2aNx\nL/jolby6jN7FfDfNZ0W/tfMot029Hnz7Euj73+4+4i5XzuVwIFBEDA9VYGYbI0mr\nE0NhPWnE1AQa90Vr2P2mFql30I3Dcl7J6S8saLuhOzD74hKXI5IbS6FqziiQwyXj\nieeySXDlbpuAX4Tcfw7onVam5MN9RKpROi9AVT37UPZLMKX7SEK3DJ7/4ERoQp3q\nf2FEQyoy/Q92ssUQgbQ96/7d91qw36wEu9Y8hSP8FRchVTCRHGnEv4IBhU+PnAPz\nw3k2ragDFtwACmgoWliOi0HpI0rSHkxX8jIboWuSHdUQNMEEi1cywPMvfNrEe5Cd\nAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEWlkcHVuaWN0LnVuaWN0Lml0hihodHRwczov\nL2lkcHVuaWN0LnVuaWN0Lml0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQGpdyP\nso1uajvYMo3tDLyvhbL3kDANBgkqhkiG9w0BAQUFAAOCAQEAq4v0tIwHi/N5dGVt\new6eRGofDAdj6F8QEwQsMwBruYO3lnteVBFNTeZ5igR6PuHTzOnOIM7v98/9T0oS\naoCED1LzHKCQaRu0WCpHGjOceJ5YtmCg9R8WCoBG5A2ND3vMllJvEGQTLLcTS7ve\ngI+pG7Fb79xuhASYkARXZ7nU5Xep2dc+a+rtSX5MTvRwczx7HdqxERQUDn7+qKWv\nV5i2qJtpsBkgwbQjpfjs5ReIMxl4QhEbnshqKNJVUf8IsTGGmYLuj2Sn/t29K6sC\n8rUp8lyUvZ8nyy/IRvMb+fFmx4/KUicxeUfqmbbwCZXdMtciGfSHVXLyhhs0xAAH\n/xmo2Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Catania"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 degli Studi di Catania"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unict.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unict.it/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Catania"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli Studi di Catania"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.rememberingscotlandatwar.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Carlos"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jon@screenmedia.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jon"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Carlos"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jon@screenmedia.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.rememberingscotlandatwar.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2010-02-08T15:58:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Remembering Scotland at War"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.museumsgalleriesscotland.org.uk/who-we-are/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Screenmedia Design Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.rememberingscotlandatwar.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.rememberingscotlandatwar.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.rememberingscotlandatwar.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.rememberingscotlandatwar.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.rememberingscotlandatwar.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.rememberingscotlandatwar.org.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIJALeFq3bo7Ze3MA0GCSqGSIb3DQEBBQUAMCsxKTAnBgNV\n\t\t\t\t\t\tBAMTIGRzdnIwMDg4MDguc2NyZWVubWVkaWFob3N0LmNvLnVrMB4XDTEwMDIwMjEx\n\t\t\t\t\t\tMDQ1NFoXDTIwMDEzMTExMDQ1NFowKzEpMCcGA1UEAxMgZHN2cjAwODgwOC5zY3Jl\n\t\t\t\t\t\tZW5tZWRpYWhvc3QuY28udWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCunuAbL1nB1VndiIfV9Hb3Y03c0PCbeKLPhKOQ5rH+An2g/hJbkBF0BWYmn5+E\n\t\t\t\t\t\t2rPO4wEm+bFp517Rf30uBGTF4wQH7gx2n7PxVglF59jtlz4baMA3oB+1GJsEyWxS\n\t\t\t\t\t\tzKMZLOPsVF4N1bn2TdoGDgWFjoEQ48U0lcRdpizoqrH6/0NzLZNrRdJD8VF58wt2\n\t\t\t\t\t\tZ4qIHpg7yTVn4b8XXjwmgAG6HdvGYjYVegZ6MeEyKBLmiSRvhNuvMqdDCOJ8faBn\n\t\t\t\t\t\tp0KlFV3dEdozo8cUdRkaE0ymcrJWxGJqVYIklf+lZM/MkEPg6c6YKNr45bXggAPT\n\t\t\t\t\t\tk5dvuO3usoRBsCILY+RimGD/AgMBAAGjTjBMMCsGA1UdEQQkMCKCIGRzdnIwMDg4\n\t\t\t\t\t\tMDguc2NyZWVubWVkaWFob3N0LmNvLnVrMB0GA1UdDgQWBBSDyYRWFylm8mEJiCCT\n\t\t\t\t\t\tEdrvtk+jszANBgkqhkiG9w0BAQUFAAOCAQEAZpGY80g01GaQsb4vZK4AtugiMRkd\n\t\t\t\t\t\tBadzM+Na1TGytZJCCo9ykYCnNZ6DawCgDYzgQNoyp4Ys+h7SzmI8XN4zyXY5dWJv\n\t\t\t\t\t\t7varqf1JScLFBkrMHeYVJu+RkWvXZX/JKJwA2Dq21nk2JD+A5VELZLpqMb9+pfw5\n\t\t\t\t\t\t3V8GlKep4X0lkbg/bAvXp5VESrT/Rp9x1LYSd5Wzd5mZFxL+ZeRPZ96k/4rcDvNN\n\t\t\t\t\t\t0XUC+VnGeOSn+62j3HOjkFpSxSA3tj2en+dO7IjMtNWHQhtxm8R81do8n+DFMk03\n\t\t\t\t\t\tzwQe2dDHy9r0Ggxc22wJ2gbPmb+jMME2uJvNZyFpl05VI7CCd0V0o7MRAg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIJALeFq3bo7Ze3MA0GCSqGSIb3DQEBBQUAMCsxKTAnBgNV\n\t\t\t\t\t\tBAMTIGRzdnIwMDg4MDguc2NyZWVubWVkaWFob3N0LmNvLnVrMB4XDTEwMDIwMjEx\n\t\t\t\t\t\tMDQ1NFoXDTIwMDEzMTExMDQ1NFowKzEpMCcGA1UEAxMgZHN2cjAwODgwOC5zY3Jl\n\t\t\t\t\t\tZW5tZWRpYWhvc3QuY28udWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCunuAbL1nB1VndiIfV9Hb3Y03c0PCbeKLPhKOQ5rH+An2g/hJbkBF0BWYmn5+E\n\t\t\t\t\t\t2rPO4wEm+bFp517Rf30uBGTF4wQH7gx2n7PxVglF59jtlz4baMA3oB+1GJsEyWxS\n\t\t\t\t\t\tzKMZLOPsVF4N1bn2TdoGDgWFjoEQ48U0lcRdpizoqrH6/0NzLZNrRdJD8VF58wt2\n\t\t\t\t\t\tZ4qIHpg7yTVn4b8XXjwmgAG6HdvGYjYVegZ6MeEyKBLmiSRvhNuvMqdDCOJ8faBn\n\t\t\t\t\t\tp0KlFV3dEdozo8cUdRkaE0ymcrJWxGJqVYIklf+lZM/MkEPg6c6YKNr45bXggAPT\n\t\t\t\t\t\tk5dvuO3usoRBsCILY+RimGD/AgMBAAGjTjBMMCsGA1UdEQQkMCKCIGRzdnIwMDg4\n\t\t\t\t\t\tMDguc2NyZWVubWVkaWFob3N0LmNvLnVrMB0GA1UdDgQWBBSDyYRWFylm8mEJiCCT\n\t\t\t\t\t\tEdrvtk+jszANBgkqhkiG9w0BAQUFAAOCAQEAZpGY80g01GaQsb4vZK4AtugiMRkd\n\t\t\t\t\t\tBadzM+Na1TGytZJCCo9ykYCnNZ6DawCgDYzgQNoyp4Ys+h7SzmI8XN4zyXY5dWJv\n\t\t\t\t\t\t7varqf1JScLFBkrMHeYVJu+RkWvXZX/JKJwA2Dq21nk2JD+A5VELZLpqMb9+pfw5\n\t\t\t\t\t\t3V8GlKep4X0lkbg/bAvXp5VESrT/Rp9x1LYSd5Wzd5mZFxL+ZeRPZ96k/4rcDvNN\n\t\t\t\t\t\t0XUC+VnGeOSn+62j3HOjkFpSxSA3tj2en+dO7IjMtNWHQhtxm8R81do8n+DFMk03\n\t\t\t\t\t\tzwQe2dDHy9r0Ggxc22wJ2gbPmb+jMME2uJvNZyFpl05VI7CCd0V0o7MRAg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.rememberingscotlandatwar.org.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.rememberingscotlandatwar.org.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.rememberingscotlandatwar.org.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.rememberingscotlandatwar.org.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.rememberingscotlandatwar.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.rememberingscotlandatwar.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.rememberingscotlandatwar.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.rememberingscotlandatwar.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.rememberingscotlandatwar.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.rememberingscotlandatwar.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://urz-cf9dev.urz.unibas.ch/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-its@unibas.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ITS"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "WApp"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:wapp-its@unibas.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ITS"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "WSyM"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:wsym-its@unibas.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ITS"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://urz-cf9dev.urz.unibas.ch/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2015-10-29T14:44:09Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "friendly_name": "swissEduPersonHomeOrganization",
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "unibas.ch"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:2.16.756.1.2.5.1.1.4",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "friendly_name": "swissEduPersonHomeOrganizationType",
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "university"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:2.16.756.1.2.5.1.1.5",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e4t Basel"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Basel"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de B\u00e2le"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unibas.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unibas.ch/"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unibas.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "unibas.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "urz-cf9dev.urz.unibas.ch"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "urz-cf9dev.urz.unibas.ch"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIJAM7GrNjzVwKBMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\nBAMTGHVyei1jZjlkZXYudXJ6LnVuaWJhcy5jaDAeFw0xNTAzMDIxMjQ4NTFaFw0x\nODAzMDExMjQ4NTFaMCMxITAfBgNVBAMTGHVyei1jZjlkZXYudXJ6LnVuaWJhcy5j\naDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANBPXsyUicAMoiWU08nj\nMubK48Hs/2IS+hMscaDzJ+/l4mPfqXpL3JnU+P1u/r3wrPmC7ZeONAkBQtVglgaM\nHJ1+SMyKjIqospS0UtBFctx15PuctNXelrUW4vA9pbLaTj7BY12fUhH7WNuaZMmc\nzx1RmMj+QFWGa0GHMUu/eSZH3HiqN6pf316+GGLvBEol4UgtTQwtj4rNK1Vgybgm\nN7B9GD5U8O2YUAtbJP2cno0P3PFgM0rsGUkBSSjAJkVs0FlesgREE50qUVaZHr/A\nx8K0C4vWSnDiZksm3fHr39+Rdk1BMgFyjePVgtZy2+QZ9QfGkKUaoK7LOQkoNMzR\nR70CAwEAAaNzMHEwUAYDVR0RBEkwR4IYdXJ6LWNmOWRldi51cnoudW5pYmFzLmNo\nhitodHRwczovL3Vyei1jZjlkZXYudXJ6LnVuaWJhcy5jaC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBT7LurvBcztRlOIRW5hS8ePdMtOwDANBgkqhkiG9w0BAQUFAAOCAQEA\ny1/VULSh0WAnG9pFNr46JDdrEcoactiK7TnmF6u4uTF/p6bq4sCo/mVHhGsEwlnZ\n7sOFIdSCnk02lk9xBQVgTCBNjRbYjnrb6WMdtJzCBxlJSC10qOboejc3AU0ccvsa\nWh151b3OLDgtXKzVd3/kOE10Nj+35uQKEQVLG3OdGXaB1nB0gn4/OBkgcErhyWMz\ngVBOKbQBqFA4kFy2pmi1P2WJ6ZlWQhYsw85FmLaLdZYxL5uau0iXLz03fSaJoQ2T\nIrXMRU8/Na6KDEGsbSSUGDeWYrFB3dgyL1f6/rsr4pWFmGz4yzN1Ay3YCaZSTFpF\naSLed9e+X5BTJyKEWbheQg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lernkartentest.unibas.ch/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://movotest.unibas.ch/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://urz-cf9dev.urz.unibas.ch/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://urz-cf9dev.urz.unibas.ch/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lernkartentest.unibas.ch/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://movotest.unibas.ch/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://urz-cf9dev.urz.unibas.ch/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://lernkartentest.unibas.ch/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://movotest.unibas.ch/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://urz-cf9dev.urz.unibas.ch/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://urz-cf9dev.urz.unibas.ch/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://urz-cf9dev.urz.unibas.ch/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "urz-cf9dev.urz.unibas.ch"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "urz-cf9dev.urz.unibas.ch"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganizationType",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "preferredLanguage",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.39",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://joaodebarro.iffarroupilha.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Everton Fava"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "everton.fava@iffarroupilha.edub.r"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://joaodebarro.iffarroupilha.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEPDCCAyQCAQAwDQYJKoZIhvcNAQEFBQAwgeMxNjA0BgNVBAoTLUlGRmFycm91\ncGlsaGEgLSBJbnN0aXR1dG8gRmVkZXJhbCBGYXJyb3VwaWxoYTENMAsGA1UECxME\nQ0dUSTEwMC4GCSqGSIb3DQEJARYhZXZlcnRvbi5mYXZhQGlmZmFycm91cGlsaGEu\nZWR1Yi5yMRQwEgYDVQQHEwtTYW50YSBNYXJpYTEaMBgGA1UECBMRUmlvIEdyYW5k\nZSBkbyBTdWwxCzAJBgNVBAYTAkJSMSkwJwYDVQQDEyBqb2FvZG9iYXJyby5pZmZh\ncnJvdXBpbGhhLmVkdS5icjAeFw0xNDA5MTAxMjAzMzJaFw0xNzA5MDkxMjAzMzJa\nMIHjMTYwNAYDVQQKEy1JRkZhcnJvdXBpbGhhIC0gSW5zdGl0dXRvIEZlZGVyYWwg\nRmFycm91cGlsaGExDTALBgNVBAsTBENHVEkxMDAuBgkqhkiG9w0BCQEWIWV2ZXJ0\nb24uZmF2YUBpZmZhcnJvdXBpbGhhLmVkdWIucjEUMBIGA1UEBxMLU2FudGEgTWFy\naWExGjAYBgNVBAgTEVJpbyBHcmFuZGUgZG8gU3VsMQswCQYDVQQGEwJCUjEpMCcG\nA1UEAxMgam9hb2RvYmFycm8uaWZmYXJyb3VwaWxoYS5lZHUuYnIwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCjbxzJf9stIGm23HODfY3e2Qgf5TP4pv4f\npn2oss8MkC99Rm2XPKcui4ny8H5QJoxHU7L059QST5LdKmUKPWX/ormEqUp9pgSL\nk3V5FChn6P/G636wk8Q4b7zPtk4V5R2crxXXt2jxo3Xhb8PLAm4ypN8uUeDgTj4J\nwgRd3KDJt7fFnAXAouT1l4e0a0LELiuI8kjvGyKcGNV+8opQg2S8/+R9qAh07fKL\nV//OVmoPVWnSJmZBHCoH8AcbghazA7mY3YJVnPZdZC4WwAP7u58pRSKkt0OnXnpF\nSWuviPcoIFLbV5JtgZuyxMzq5wwXniienr18Uv0CBpK0PciRnKtTAgMBAAEwDQYJ\nKoZIhvcNAQEFBQADggEBABzAstXEYvu0dkoQvxEhhOh3kBPm8OurJpiGzGQDKX/G\nVDhgLOI+V/3UjYPTcBEMDJsjWE9Q86tjfyEXl+L3WNg2tDscxTi0hXrn9HtKeFdl\nEqn7o0P0Zy+Ck28whDSlAKtIsoupQvhvDfE6zVltnk7Y6BtBS6IMbLVtOEC83ayc\nu4j17sJlJYYOO++rnuIMpOk6AArPrZCTBgIM1YGGAVC23z5M4KF25L02p/JvzcCH\nBB5WV7TdBFR34zcIEGOr4l8afrmCKZJw4zqLP7HxMwfVQL+bJw/aVx4owdFh/VEr\n7kc9bN7ChGuVCbg9lLSKtVhDRKDWyuIUt/ioaVOWP8s="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://joaodebarro.iffarroupilha.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://joaodebarro.iffarroupilha.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://joaodebarro.iffarroupilha.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://joaodebarro.iffarroupilha.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://joaodebarro.iffarroupilha.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://joaodebarro.iffarroupilha.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://joaodebarro.iffarroupilha.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://joaodebarro.iffarroupilha.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.iffarroupilha.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.iffarroupilha.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFFarroupilha - Instituto Federal Farroupilha"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFFarroupilha - Instituto Federal Farroupilha"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFFarroupilha - Instituto Federal Farroupilha"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFFarroupilha - Instituto Federal Farroupilha"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEPDCCAyQCAQAwDQYJKoZIhvcNAQEFBQAwgeMxNjA0BgNVBAoTLUlGRmFycm91\ncGlsaGEgLSBJbnN0aXR1dG8gRmVkZXJhbCBGYXJyb3VwaWxoYTENMAsGA1UECxME\nQ0dUSTEwMC4GCSqGSIb3DQEJARYhZXZlcnRvbi5mYXZhQGlmZmFycm91cGlsaGEu\nZWR1Yi5yMRQwEgYDVQQHEwtTYW50YSBNYXJpYTEaMBgGA1UECBMRUmlvIEdyYW5k\nZSBkbyBTdWwxCzAJBgNVBAYTAkJSMSkwJwYDVQQDEyBqb2FvZG9iYXJyby5pZmZh\ncnJvdXBpbGhhLmVkdS5icjAeFw0xNDA5MTAxMjAzMzJaFw0xNzA5MDkxMjAzMzJa\nMIHjMTYwNAYDVQQKEy1JRkZhcnJvdXBpbGhhIC0gSW5zdGl0dXRvIEZlZGVyYWwg\nRmFycm91cGlsaGExDTALBgNVBAsTBENHVEkxMDAuBgkqhkiG9w0BCQEWIWV2ZXJ0\nb24uZmF2YUBpZmZhcnJvdXBpbGhhLmVkdWIucjEUMBIGA1UEBxMLU2FudGEgTWFy\naWExGjAYBgNVBAgTEVJpbyBHcmFuZGUgZG8gU3VsMQswCQYDVQQGEwJCUjEpMCcG\nA1UEAxMgam9hb2RvYmFycm8uaWZmYXJyb3VwaWxoYS5lZHUuYnIwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCjbxzJf9stIGm23HODfY3e2Qgf5TP4pv4f\npn2oss8MkC99Rm2XPKcui4ny8H5QJoxHU7L059QST5LdKmUKPWX/ormEqUp9pgSL\nk3V5FChn6P/G636wk8Q4b7zPtk4V5R2crxXXt2jxo3Xhb8PLAm4ypN8uUeDgTj4J\nwgRd3KDJt7fFnAXAouT1l4e0a0LELiuI8kjvGyKcGNV+8opQg2S8/+R9qAh07fKL\nV//OVmoPVWnSJmZBHCoH8AcbghazA7mY3YJVnPZdZC4WwAP7u58pRSKkt0OnXnpF\nSWuviPcoIFLbV5JtgZuyxMzq5wwXniienr18Uv0CBpK0PciRnKtTAgMBAAEwDQYJ\nKoZIhvcNAQEFBQADggEBABzAstXEYvu0dkoQvxEhhOh3kBPm8OurJpiGzGQDKX/G\nVDhgLOI+V/3UjYPTcBEMDJsjWE9Q86tjfyEXl+L3WNg2tDscxTi0hXrn9HtKeFdl\nEqn7o0P0Zy+Ck28whDSlAKtIsoupQvhvDfE6zVltnk7Y6BtBS6IMbLVtOEC83ayc\nu4j17sJlJYYOO++rnuIMpOk6AArPrZCTBgIM1YGGAVC23z5M4KF25L02p/JvzcCH\nBB5WV7TdBFR34zcIEGOr4l8afrmCKZJw4zqLP7HxMwfVQL+bJw/aVx4owdFh/VEr\n7kc9bN7ChGuVCbg9lLSKtVhDRKDWyuIUt/ioaVOWP8s="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFFarroupilha - Instituto Federal Farroupilha"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFFarroupilha - Instituto Federal Farroupilha"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iffarroupilha.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iffarroupilha.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFFarroupilha - Instituto Federal Farroupilha"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFFarroupilha - Instituto Federal Farroupilha"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.uoregon.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noreenh@uoregon.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Noreen Hogan"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "middleware@uoregon.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rob Chevalier"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.uoregon.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.uoregon.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.uoregon.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQjCCAiqgAwIBAgITFP1Rwp3clPykVwEUThiy/rAHejANBgkqhkiG9w0BAQUF\nADAhMR8wHQYDVQQDExZzaGliYm9sZXRoLnVvcmVnb24uZWR1MB4XDTA4MDgyMTE3\nMDc1OFoXDTI4MDgyMTE3MDc1OFowITEfMB0GA1UEAxMWc2hpYmJvbGV0aC51b3Jl\nZ29uLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMteVz2c/MiM\nsfGzE40vUED14ud3FeW9GI3cP57J2zBqAqjYhpNj30MV1BysTOJOGJj2tw8AA1pS\nV/FCMEqq6jrQxVtb8gcBML2gQMhJoiy6EHB5hXZSXBzfizrjoz7/DaaB3ECpMecH\n9ZzUmG84ZCiSXKoc4unTuJW+pMGbwTbG6gikxdUuQo3Aq03zJU0shOl7jK32NgPK\nsmQ8cQomcKVwYuep2i8JvEL/N7NH4ERJafEYA7/kVS4Qe4UmjLG3aJ9XjVagnjnR\nS+8sTNk2MGJZLubY1C8atcQLxVhO4oqkTe32ogiv/lloPHD2Mi7aztE94wLpNcjs\nycupoUurNIcCAwEAAaNzMHEwUAYDVR0RBEkwR4IWc2hpYmJvbGV0aC51b3JlZ29u\nLmVkdYYtaHR0cHM6Ly9zaGliYm9sZXRoLnVvcmVnb24uZWR1L2lkcC9zaGliYm9s\nZXRoMB0GA1UdDgQWBBQColYoD3sV0YAk4Ir4jFYkYOBITjANBgkqhkiG9w0BAQUF\nAAOCAQEAl31lJSmErQH4KnFZbukNAhYesZc8M/M0vNi4fLrJm1SlKunYof6fykpB\nLdvlamuJd1eoV0ltCeR52meq+ej1BdFj/hyZcM66hglH5UY4LaeejG31zJplw5o7\n7ohjKy09RmIaiMX0rlutX14IYgEtRXrFGuYFJYiXpK6qiwC/ikjBU3Yjj0Y9B5/K\n5k29STlxFRsKiE511gGeO0Xkcxj4c7Dy3KfwW5wooNiBcL6hCIu+FUUC649WpkNG\nN5GXH191Krz58J6/VJJBsz6T3anUiK6NxxX+/T3fb1FDmR+isSsAJfbFwSpXA1sM\ngVS2dGCBxZlwSzi9cmvk13sneid0+Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uoregon.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.uoregon.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.uoregon.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.uoregon.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.uoregon.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.uoregon.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.uoregon.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uoregon.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Oregon's Shibboleth Identity Provider"
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth.uoregon.edu/images/Large_UO_Logo.jpg",
                    "lang": "en",
                    "height": "239",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "200"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Oregon"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQjCCAiqgAwIBAgITFP1Rwp3clPykVwEUThiy/rAHejANBgkqhkiG9w0BAQUF\nADAhMR8wHQYDVQQDExZzaGliYm9sZXRoLnVvcmVnb24uZWR1MB4XDTA4MDgyMTE3\nMDc1OFoXDTI4MDgyMTE3MDc1OFowITEfMB0GA1UEAxMWc2hpYmJvbGV0aC51b3Jl\nZ29uLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMteVz2c/MiM\nsfGzE40vUED14ud3FeW9GI3cP57J2zBqAqjYhpNj30MV1BysTOJOGJj2tw8AA1pS\nV/FCMEqq6jrQxVtb8gcBML2gQMhJoiy6EHB5hXZSXBzfizrjoz7/DaaB3ECpMecH\n9ZzUmG84ZCiSXKoc4unTuJW+pMGbwTbG6gikxdUuQo3Aq03zJU0shOl7jK32NgPK\nsmQ8cQomcKVwYuep2i8JvEL/N7NH4ERJafEYA7/kVS4Qe4UmjLG3aJ9XjVagnjnR\nS+8sTNk2MGJZLubY1C8atcQLxVhO4oqkTe32ogiv/lloPHD2Mi7aztE94wLpNcjs\nycupoUurNIcCAwEAAaNzMHEwUAYDVR0RBEkwR4IWc2hpYmJvbGV0aC51b3JlZ29u\nLmVkdYYtaHR0cHM6Ly9zaGliYm9sZXRoLnVvcmVnb24uZWR1L2lkcC9zaGliYm9s\nZXRoMB0GA1UdDgQWBBQColYoD3sV0YAk4Ir4jFYkYOBITjANBgkqhkiG9w0BAQUF\nAAOCAQEAl31lJSmErQH4KnFZbukNAhYesZc8M/M0vNi4fLrJm1SlKunYof6fykpB\nLdvlamuJd1eoV0ltCeR52meq+ej1BdFj/hyZcM66hglH5UY4LaeejG31zJplw5o7\n7ohjKy09RmIaiMX0rlutX14IYgEtRXrFGuYFJYiXpK6qiwC/ikjBU3Yjj0Y9B5/K\n5k29STlxFRsKiE511gGeO0Xkcxj4c7Dy3KfwW5wooNiBcL6hCIu+FUUC649WpkNG\nN5GXH191Krz58J6/VJJBsz6T3anUiK6NxxX+/T3fb1FDmR+isSsAJfbFwSpXA1sM\ngVS2dGCBxZlwSzi9cmvk13sneid0+Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Oregon"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uoregon.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Oregon"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.ulster.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@ulster.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ISD Service desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Vitty"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul@ulster.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Carolan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:barney@ulster.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Barney"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.ulster.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-09-29T15:21:15Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUDpGkh/duNiN6+rhYKO7+e0H+z0owDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHDEaMBgGA1UEAxMRc2hpYi51bHN0ZXIuYWMudWswHhcNMTQwOTI5MTMxMDQw\n\t\t\t\t\t\tWhcNMzQwOTI5MTMxMDQwWjAcMRowGAYDVQQDExFzaGliLnVsc3Rlci5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIzQ0qaikQBm8TZ4mHIlwkqF\n\t\t\t\t\t\tmc0XXnZoH1mBi1nU/jK0ofWvDzr13EueVf+kkIwdq1NcGhy4Q45tPpCJ/ut+Hx1Y\n\t\t\t\t\t\tui51P952G6gkZaa70FaW0y6x98Lo9MnJEazdBYH8tXNmDBOaUV+r6FvSWkCA+943\n\t\t\t\t\t\tPDrRLbdVXr3SvwNAMY0sjbqAoaqQ34jyR5vwICvQvm2kgZnO/b2pWBIcnUUihRl/\n\t\t\t\t\t\tC23Lhzc2h4XzLoo05mxUqkZwTWoZG3LvayctaN3/4wQD6OMFg50JvK25JoKLBiFw\n\t\t\t\t\t\tywvcDl3s0lWaPy2D6k1qtNiSXkNmQKNdTqnZ1P55U41jnhruP2bstMFdfMCRtaUC\n\t\t\t\t\t\tAwEAAaNpMGcwRgYDVR0RBD8wPYIRc2hpYi51bHN0ZXIuYWMudWuGKGh0dHBzOi8v\n\t\t\t\t\t\tc2hpYi51bHN0ZXIuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFMlgjh3c\n\t\t\t\t\t\trPcwJ+B2l9Oe56HULqhaMA0GCSqGSIb3DQEBBQUAA4IBAQAede2459De5mPMtedE\n\t\t\t\t\t\thGfrQtgggyPWJqsu+nvWhHpDQAJ2Rcq+dvMmMmCWpdWjhUiTQ1AQnWbuhKmMsker\n\t\t\t\t\t\tsWZZIQ7WqcFwSMNS8OQyyO+OqDxJaoyu2qRS39URPMgKwWPtHOeYp93zfEdE5cGA\n\t\t\t\t\t\tkWw4oPABOL0VlWRoVlGFOGxiyvTuq0DOPC9M50ICx/suLNyuidxyK35XGCUzjn6c\n\t\t\t\t\t\tMkaQH8OymowRW981IQbhbtM6IWY9ATbrmw7+YJwstcEaQN6LvUhkUESTrdCKPobT\n\t\t\t\t\t\thmWzROvxEEf88wjO6qxxJCahd+tcJ7k8ef5q/5xinQwuwIW3ln8CGcPXEfJiYnHo\n\t\t\t\t\t\tk4aR"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ulster.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.ulster.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.ulster.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.ulster.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.ulster.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.ulster.ac.uk/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.ulster.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.ulster.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.ulster.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.ulster.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.ulster.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.ulster.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ulster.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUDpGkh/duNiN6+rhYKO7+e0H+z0owDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHDEaMBgGA1UEAxMRc2hpYi51bHN0ZXIuYWMudWswHhcNMTQwOTI5MTMxMDQw\n\t\t\t\t\t\tWhcNMzQwOTI5MTMxMDQwWjAcMRowGAYDVQQDExFzaGliLnVsc3Rlci5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIzQ0qaikQBm8TZ4mHIlwkqF\n\t\t\t\t\t\tmc0XXnZoH1mBi1nU/jK0ofWvDzr13EueVf+kkIwdq1NcGhy4Q45tPpCJ/ut+Hx1Y\n\t\t\t\t\t\tui51P952G6gkZaa70FaW0y6x98Lo9MnJEazdBYH8tXNmDBOaUV+r6FvSWkCA+943\n\t\t\t\t\t\tPDrRLbdVXr3SvwNAMY0sjbqAoaqQ34jyR5vwICvQvm2kgZnO/b2pWBIcnUUihRl/\n\t\t\t\t\t\tC23Lhzc2h4XzLoo05mxUqkZwTWoZG3LvayctaN3/4wQD6OMFg50JvK25JoKLBiFw\n\t\t\t\t\t\tywvcDl3s0lWaPy2D6k1qtNiSXkNmQKNdTqnZ1P55U41jnhruP2bstMFdfMCRtaUC\n\t\t\t\t\t\tAwEAAaNpMGcwRgYDVR0RBD8wPYIRc2hpYi51bHN0ZXIuYWMudWuGKGh0dHBzOi8v\n\t\t\t\t\t\tc2hpYi51bHN0ZXIuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFMlgjh3c\n\t\t\t\t\t\trPcwJ+B2l9Oe56HULqhaMA0GCSqGSIb3DQEBBQUAA4IBAQAede2459De5mPMtedE\n\t\t\t\t\t\thGfrQtgggyPWJqsu+nvWhHpDQAJ2Rcq+dvMmMmCWpdWjhUiTQ1AQnWbuhKmMsker\n\t\t\t\t\t\tsWZZIQ7WqcFwSMNS8OQyyO+OqDxJaoyu2qRS39URPMgKwWPtHOeYp93zfEdE5cGA\n\t\t\t\t\t\tkWw4oPABOL0VlWRoVlGFOGxiyvTuq0DOPC9M50ICx/suLNyuidxyK35XGCUzjn6c\n\t\t\t\t\t\tMkaQH8OymowRW981IQbhbtM6IWY9ATbrmw7+YJwstcEaQN6LvUhkUESTrdCKPobT\n\t\t\t\t\t\thmWzROvxEEf88wjO6qxxJCahd+tcJ7k8ef5q/5xinQwuwIW3ln8CGcPXEfJiYnHo\n\t\t\t\t\t\tk4aR"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Ulster - Shibboleth"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ulster.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Ulster"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.utia.cas.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Van\u00ed\u010dek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vanicekp@utia.cas.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.utia.cas.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2014-03-07T08:48:51Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/avcr"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAPWAIIDpvyOIAKgxvS8uAGvErbFIMA0GCSqGSIb3DQEB\nBQUAMBoxGDAWBgNVBAMTD2lkcC51dGlhLmNhcy5jejAeFw0xNDAxMjExMzQ5MzFa\nFw0zNDAxMjExMzQ5MzFaMBoxGDAWBgNVBAMTD2lkcC51dGlhLmNhcy5jejCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIMlroofDB1hzFwO3vg/GyYuWHzq\nltlkURfEPJOAnKG/W2ax+ljT+4OvFochFR3Tn2z9k9BzjK2TNbK4SSHnojSn/7ml\nUEe5GcSqUzWRz7N6IPWqq95bpHAjttP9GChbwn9TWbiim+rom7azfJ5GMNpECE6x\nJ6hnZLLqe9tH3MRjHq/g1EgoYwkRN4p+GH50zpPfZmqdChoxN4+ipiwodGHUGLbK\nqjrCkusd3nx9hjkZNsB9Xwcws4HJhnfKmUaRXccBeXI+93rOVTVgRdzC4AoV18xZ\nDT4mZJHi0rAr+S8k/qHpYapp4BJX8FlGxzfUM/KtJft6aupc2KkacFeJzXkCAwEA\nAaNlMGMwQgYDVR0RBDswOYIPaWRwLnV0aWEuY2FzLmN6hiZodHRwczovL2lkcC51\ndGlhLmNhcy5jei9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQULF0CAFze9Eoavjce\nJ1fkA5ZwtzEwDQYJKoZIhvcNAQEFBQADggEBAEdPs/pVXrBbxB8Gs7V3a9gGn7Va\n4svNZ7mosAAWvlXPLGKzdmp8GdqH1UNjNZouxSXJDVC4sbOKcFiyu7gr+Bc+SbhH\nvd5/D4EzzaF5LrfCcy4z0z/Z2GmoejJUkysYTnvfDJwUk57JKfeF7JP0WTxtGwBX\nus9wwyhp00Lvq91NAddg0YCHgYkNNJ+nEqinRTUHtF1/NM0kOxj5Bldl+Ea5ofMi\n4xHhOx6IKjHfhU+xSBtA5JalGefjXT8reS2EPc8NY8YQE7fxytldlc3C4nkLilwp\np6lZaMAngitaUamaZdgJTVokp6H6D9o6qommaXW6BFw0RskMVAO4QKWnanc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utia.cas.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.utia.cas.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.utia.cas.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.utia.cas.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.utia.cas.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.utia.cas.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.utia.cas.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.utia.cas.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.utia.cas.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.utia.cas.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.utia.cas.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.utia.cas.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utia.cas.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.utia.cas.cz/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.utia.cas.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider UTIA AV CR employees."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance \u00daTIA AV \u010cR"
                  }
                ],
                "logo": [
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-utia-44.png",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "74"
                  },
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-utia-411.png",
                    "height": "411",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "960"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Information Theory and Automation AS CR"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u00dastav teorie informace a automatizace AV \u010cR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAPWAIIDpvyOIAKgxvS8uAGvErbFIMA0GCSqGSIb3DQEB\nBQUAMBoxGDAWBgNVBAMTD2lkcC51dGlhLmNhcy5jejAeFw0xNDAxMjExMzQ5MzFa\nFw0zNDAxMjExMzQ5MzFaMBoxGDAWBgNVBAMTD2lkcC51dGlhLmNhcy5jejCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIMlroofDB1hzFwO3vg/GyYuWHzq\nltlkURfEPJOAnKG/W2ax+ljT+4OvFochFR3Tn2z9k9BzjK2TNbK4SSHnojSn/7ml\nUEe5GcSqUzWRz7N6IPWqq95bpHAjttP9GChbwn9TWbiim+rom7azfJ5GMNpECE6x\nJ6hnZLLqe9tH3MRjHq/g1EgoYwkRN4p+GH50zpPfZmqdChoxN4+ipiwodGHUGLbK\nqjrCkusd3nx9hjkZNsB9Xwcws4HJhnfKmUaRXccBeXI+93rOVTVgRdzC4AoV18xZ\nDT4mZJHi0rAr+S8k/qHpYapp4BJX8FlGxzfUM/KtJft6aupc2KkacFeJzXkCAwEA\nAaNlMGMwQgYDVR0RBDswOYIPaWRwLnV0aWEuY2FzLmN6hiZodHRwczovL2lkcC51\ndGlhLmNhcy5jei9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQULF0CAFze9Eoavjce\nJ1fkA5ZwtzEwDQYJKoZIhvcNAQEFBQADggEBAEdPs/pVXrBbxB8Gs7V3a9gGn7Va\n4svNZ7mosAAWvlXPLGKzdmp8GdqH1UNjNZouxSXJDVC4sbOKcFiyu7gr+Bc+SbhH\nvd5/D4EzzaF5LrfCcy4z0z/Z2GmoejJUkysYTnvfDJwUk57JKfeF7JP0WTxtGwBX\nus9wwyhp00Lvq91NAddg0YCHgYkNNJ+nEqinRTUHtF1/NM0kOxj5Bldl+Ea5ofMi\n4xHhOx6IKjHfhU+xSBtA5JalGefjXT8reS2EPc8NY8YQE7fxytldlc3C4nkLilwp\np6lZaMAngitaUamaZdgJTVokp6H6D9o6qommaXW6BFw0RskMVAO4QKWnanc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Information Theory and Automation, Public Research Institution"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u00dastav teorie informace a automatizace AV \u010cR, v.v.i."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utia.cas.cz/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utia.cas.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Information Theory and Automation"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u00dastav teorie informace a automatizace AV \u010cR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.hughbaird.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Billington"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:john.billington@hughbaird.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Billington"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:john.billington@hughbaird.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.hughbaird.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-01-10T11:25:59Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.hughbaird.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.hughbaird.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hughbaird.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIIX17eEDuOAj8wDQYJKoZIhvcNAQEFBQAwOzEbMBkGA1UE\n\t\t\t\t\t\tCgwSSHVnaCBCYWlyZCBDb2xsZWdlMRwwGgYDVQQDDBNpZHAuaHVnaGJhaXJkLmFj\n\t\t\t\t\t\tLnVrMB4XDTEzMDgwODExMTEwMloXDTIzMDgwODExMTEwMlowOzEbMBkGA1UECgwS\n\t\t\t\t\t\tSHVnaCBCYWlyZCBDb2xsZWdlMRwwGgYDVQQDDBNpZHAuaHVnaGJhaXJkLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsuUznKj9CgzG9HW/AY+K\n\t\t\t\t\t\thCfi5qxt1ttqKDe5geSym5DSi6oIFbNyEfYSxvpGKIFUweYKAbWYbWAa+dxJ5iHf\n\t\t\t\t\t\tahZr1odOtyBh2XZCHZ4q4LLPeIpfpk3vNPH7GDdWjI2LXEet+/7J8x4jzXrFvJ1O\n\t\t\t\t\t\t7AX/T5lswOyeEKVIzgXK5Z5wK6K4U9NnMEBGfDtTgOzOYcRsJDlJScEnrdMaSO3E\n\t\t\t\t\t\tfU54JKVq56ozyzZ/LGGCmtylFuz1vX9ZoL5rP5zErYMND6m7xka0U9XKVLTz1rbA\n\t\t\t\t\t\t5zDrV+eMI2QYJ7zIPPJA1QDZY5/DUo495l93GWm0nov/cIflF5Q0V8Jdb6zvv92q\n\t\t\t\t\t\tUwIDAQABo1AwTjAdBgNVHQ4EFgQUVN73EI9lBXn223EfNEMOX/UmSikwHwYDVR0j\n\t\t\t\t\t\tBBgwFoAUVN73EI9lBXn223EfNEMOX/UmSikwDAYDVR0TBAUwAwEB/zANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAqzbMViMYly/u3VNWF3xVfadZFpPuea3AsjD8P/ibJ+AK2rJE\n\t\t\t\t\t\t40KhEFuBpkTdCAmBuXMLqHl1Wpkm1dA1JFyZFYKD2Llt2mn6aTY6XmTuZfp4xJdt\n\t\t\t\t\t\tiz6Hi+mzKB5oClIeY7Ba0m3KVQCwuoYvIgsJ7Phs9QzdtGDDJMpx/oc9DGbGzcmx\n\t\t\t\t\t\tM9A6/TMn/ECbGDZX9AAWY1Q06bGQtqOJOUEJcEj51jFMpuN2EJdfkr6tEYYTIjsd\n\t\t\t\t\t\tjr+w28z0m4rA2ed7r3vvuceGFkOlSy+zp5DR3Nr6hGMCfDSuxVbJOuNpp/VzYyq/\n\t\t\t\t\t\tsL1NJoJ0e626msAaAaxLyxiHxQ9bJI/Uu0We2Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIIX17eEDuOAj8wDQYJKoZIhvcNAQEFBQAwOzEbMBkGA1UE\n\t\t\t\t\t\tCgwSSHVnaCBCYWlyZCBDb2xsZWdlMRwwGgYDVQQDDBNpZHAuaHVnaGJhaXJkLmFj\n\t\t\t\t\t\tLnVrMB4XDTEzMDgwODExMTEwMloXDTIzMDgwODExMTEwMlowOzEbMBkGA1UECgwS\n\t\t\t\t\t\tSHVnaCBCYWlyZCBDb2xsZWdlMRwwGgYDVQQDDBNpZHAuaHVnaGJhaXJkLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsuUznKj9CgzG9HW/AY+K\n\t\t\t\t\t\thCfi5qxt1ttqKDe5geSym5DSi6oIFbNyEfYSxvpGKIFUweYKAbWYbWAa+dxJ5iHf\n\t\t\t\t\t\tahZr1odOtyBh2XZCHZ4q4LLPeIpfpk3vNPH7GDdWjI2LXEet+/7J8x4jzXrFvJ1O\n\t\t\t\t\t\t7AX/T5lswOyeEKVIzgXK5Z5wK6K4U9NnMEBGfDtTgOzOYcRsJDlJScEnrdMaSO3E\n\t\t\t\t\t\tfU54JKVq56ozyzZ/LGGCmtylFuz1vX9ZoL5rP5zErYMND6m7xka0U9XKVLTz1rbA\n\t\t\t\t\t\t5zDrV+eMI2QYJ7zIPPJA1QDZY5/DUo495l93GWm0nov/cIflF5Q0V8Jdb6zvv92q\n\t\t\t\t\t\tUwIDAQABo1AwTjAdBgNVHQ4EFgQUVN73EI9lBXn223EfNEMOX/UmSikwHwYDVR0j\n\t\t\t\t\t\tBBgwFoAUVN73EI9lBXn223EfNEMOX/UmSikwDAYDVR0TBAUwAwEB/zANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAqzbMViMYly/u3VNWF3xVfadZFpPuea3AsjD8P/ibJ+AK2rJE\n\t\t\t\t\t\t40KhEFuBpkTdCAmBuXMLqHl1Wpkm1dA1JFyZFYKD2Llt2mn6aTY6XmTuZfp4xJdt\n\t\t\t\t\t\tiz6Hi+mzKB5oClIeY7Ba0m3KVQCwuoYvIgsJ7Phs9QzdtGDDJMpx/oc9DGbGzcmx\n\t\t\t\t\t\tM9A6/TMn/ECbGDZX9AAWY1Q06bGQtqOJOUEJcEj51jFMpuN2EJdfkr6tEYYTIjsd\n\t\t\t\t\t\tjr+w28z0m4rA2ed7r3vvuceGFkOlSy+zp5DR3Nr6hGMCfDSuxVbJOuNpp/VzYyq/\n\t\t\t\t\t\tsL1NJoJ0e626msAaAaxLyxiHxQ9bJI/Uu0We2Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hugh Baird College (Test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hughbaird.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hugh Baird College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://fedauth.colorado.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@colorado.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marwan Shaher"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@colorado.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kerry Havens"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@colorado.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pregash Devasagayam"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@colorado.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Service Center"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://fedauth.colorado.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://fedauth.colorado.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://fedauth.colorado.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://fedauth.colorado.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://fedauth.colorado.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://fedauth.colorado.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "colorado.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.colorado.edu/oit/webaccess"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The University of Colorado at Boulder's Identity Provider"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.colorado.edu/oit/webaccess"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Colorado at Boulder"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUISKLp/LUBR62UD3eacuMlgyq1mEwDQYJKoZIhvcNAQEF\nBQAwHzEdMBsGA1UEAxMUZmVkYXV0aC5jb2xvcmFkby5lZHUwHhcNMTEwNDA3MjEx\nOTI3WhcNMzEwNDA3MjExOTI3WjAfMR0wGwYDVQQDExRmZWRhdXRoLmNvbG9yYWRv\nLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKKfxWBCz6RGXDaM\n+Td/GX14ozBjZgctgcOOduUWf1Y6awzXJgRlC7k4LGCJZscZLsuZgfzdO6qTxDwk\nBbk6UiwUn+dHng6DNBNpuCkUdoCEv6F5gUzZG+aR1NBWk+n565c/u/OAZKt/TgQz\nni+zSKGR78DVu/FMrgEtFL37mGjy3qcHe9c/y4fVh+TuFpZOvK5TTMsy/OI0Jx2q\ntLL/At7Od5oWEm32UH7NtZl5qBg36SYHcDYeVkaCyCoQrFw03W3i+2Q5PUo5FwG6\nGpeAoZEn1pU1iQ4rowdgafHH8xAg7boLdsax6J02pMem732e7VXUk9pkaDewUfSl\nOwU391kCAwEAAaNvMG0wTAYDVR0RBEUwQ4IUZmVkYXV0aC5jb2xvcmFkby5lZHWG\nK2h0dHBzOi8vZmVkYXV0aC5jb2xvcmFkby5lZHUvaWRwL3NoaWJib2xldGgwHQYD\nVR0OBBYEFLtp54NAL/CFuBokXwZxmltg52+6MA0GCSqGSIb3DQEBBQUAA4IBAQBJ\nKfBAodCf7pfUUBo/y2htFEUEc1EVyyzLardzvxncQBY76KLQKzynkXdzynmtWWdX\nERDsBWyM5idtMwanSXZhLBxKZ0BLx0whe0QrP26bFjD3hDc54jxWucfK7gbVkaG+\n0U07hjYazpz6YuAXQ/n4+McCnqw5vI7aEreIWH6ky5kU3+KkNuEBsuOfsPCpfhHG\nd/zUrol9WKi0oBE/3A3WluEsKobPTI+Df3UOQbWnujwquIWpR7PYqotR2BYrAuPI\n2ijwqoxQck0dHwpdffo+4STtjJN1LMGDAOgVBZEBX5HQkgt5Z9fxKHw1ok0ygPyD\naE45z9S0D3Rt1IJs3AeI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Colorado at Boulder"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.colorado.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Colorado at Boulder"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.qatar-weill.cornell.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "saa2012@qatar-med.cornell.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sam Agnew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ama2027@qatar-med.cornell.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ala' Aljaser"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ade2003@qatar-med.cornell.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam Elrowmeim"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.qatar-weill.cornell.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.qatar-weill.cornell.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.qatar-weill.cornell.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.qatar-weill.cornell.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.qatar-weill.cornell.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.qatar-weill.cornell.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "qatar-weill.cornell.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Weill Cornell Medical College in Qatar"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkCgAwIBAgIVAOjd1DnJt9+wai5RSTs4dU7Z3uVDMA0GCSqGSIb3DQEB\nBQUAMCYxJDAiBgNVBAMTG2lkcC5xYXRhci13ZWlsbC5jb3JuZWxsLmVkdTAeFw0x\nNDA2MDMwNzI3NTdaFw0zNDA2MDMwNzI3NTdaMCYxJDAiBgNVBAMTG2lkcC5xYXRh\nci13ZWlsbC5jb3JuZWxsLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\nggEBANP9iD4QkVd280O25P9msXPV1fG4Tw2RnrVXwHpIYaOncoLJMyV4SMuuarB1\nPg2zC3uswMzM1xp5iY56UYCSU4QkPY+NzYoBLC7di3dioQsYIYBtHh39B92be8ur\noLFQrTA8YYH6SllQjKbX6dXAUrkb7qhy1p/h2K9Go9YQIsmgPTune4yycfJAOU7Q\nJcrlFfhl2qeRSDQ+nK/QasYk3+zfuQ3FI3gpANsbyMlVWJnd+75otbizQsnhdATP\nxgZ+JWENLZ2YV5G0tstNCaqm+lSI5FZELAdl6vA0DnH0AZDhUlKM4IrPxbxtD9GU\nepD1RO/C5aGnjbHiiCMtZI1a1+8CAwEAAaN9MHswWgYDVR0RBFMwUYIbaWRwLnFh\ndGFyLXdlaWxsLmNvcm5lbGwuZWR1hjJodHRwczovL2lkcC5xYXRhci13ZWlsbC5j\nb3JuZWxsLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU8m1MSVMJCE8xgnT1\nU9ltWX5HcyYwDQYJKoZIhvcNAQEFBQADggEBAKqChi5QJ/KNcqu/4MxaDkxRyUqG\nsz1VdX3DIHhb0+Ol6ZfU1OJey+pwqZjo6pTfJB1GGCKYeDsiYZavgAwf/vhUdNk6\nIZss1WV4OOw+Bp1zkonLqRR/poXV5RR3Me+SuSwYi4U3UIY1lngN4NP9JXzLqOyN\nCS2nRgHvacwUcMn4jubuUxNFfGk2rrZ+32v+KKfcJP6tIh/u7IbMmQ0VQhEYOai6\nmgJ6/63J0fFOShYaGfVzsJk4VtKoO1VeF80vDTWcQ65sCT0vHG79MMizEX5N+9fQ\nULb3rAmKgl6xBpBfo+sBJMTbsZsIG/ev/mSRyHhKra1GIAA4GTcBYaeOOt8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Weill Cornell Medical College in Qatar"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qatar-med.cornell.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Weill Cornell Medical College in Qatar"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://beta.hp.pub2web.ingenta.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@numeriquepremium.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ghadiyali"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:openathens@publishingtechnology.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hatim"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://beta.hp.pub2web.ingenta.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-03-18T12:18:54Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NUM\u00c9RIQUE PREMIUM"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://beta.hp.pub2web.ingenta.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Publishing Technology plc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDiDCCAnCgAwIBAgIEUxEfCDANBgkqhkiG9w0BAQUFADCBhTELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFDASBgNVBAgTC094Zm9yZHNoaXJlMQ8wDQYDVQQHEwZPeGZvcmQxHjAcBgNV\n\t\t\t\t\t\tBAoTFVB1Ymxpc2hpbmcgVGVjaG5vbG9neTEPMA0GA1UECxMGT25saW5lMR4wHAYD\n\t\t\t\t\t\tVQQDExVQdWJsaXNoaW5nIFRlY2hub2xvZ3kwHhcNMTQwMjI4MjM0MzA0WhcNMTcw\n\t\t\t\t\t\tMjI3MjM0MzA0WjCBhTELMAkGA1UEBhMCR0IxFDASBgNVBAgTC094Zm9yZHNoaXJl\n\t\t\t\t\t\tMQ8wDQYDVQQHEwZPeGZvcmQxHjAcBgNVBAoTFVB1Ymxpc2hpbmcgVGVjaG5vbG9n\n\t\t\t\t\t\teTEPMA0GA1UECxMGT25saW5lMR4wHAYDVQQDExVQdWJsaXNoaW5nIFRlY2hub2xv\n\t\t\t\t\t\tZ3kwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCtKdKPdmVZXkJajIXP\n\t\t\t\t\t\toD1MM4HDgaXr6DWwK3MCvhwAG4X7jXeP4TZ3UPM9VqAk1BywDFJ4ZKVvkVMJaavp\n\t\t\t\t\t\t6CUcidSkba9FXEoxbcRmLinw9CIDyqrczOtTrh8Y0VlVUJWus2QCDZDjSghN6ZyF\n\t\t\t\t\t\tR6tu9skOgnNTmlM7wZ6OH8wvOgSMgoLHsswqpWb7ZgujYxMXejrZgSGbezYyqD8b\n\t\t\t\t\t\t4VEgbrwB4pGpZHmH9BQ3ozNIcDm/g5XTGm86useupVepZ8NOqfV9NkmAYI0r81L8\n\t\t\t\t\t\tHsNvWFAtM2gifJLt64rBFgdGZYhKAb3Kr9DlmbarSwwG5gF+R5hdCzXX2z/y7tIC\n\t\t\t\t\t\t2nYjAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAGClcTLi5SJ1ia2FLgQcUy4vFeKx\n\t\t\t\t\t\t/VmKPKWHFctm46dEccIAvHOOC3zCXOOHfCRZrR/pMVCfE9UnzvPIl1fRtm79SuxX\n\t\t\t\t\t\tFjEs7GhibW9ALm1Yh2YVnGGaq7U1aO4kU3MJ9SBwZT4uXhbGRNdnUyyjPxQ7jrfO\n\t\t\t\t\t\tR0GLxZfF8MvKnosafmF3d4ivcP/xzgmVtBG9WRZHASHfIfB8qAZXBLOLuDvDFVC6\n\t\t\t\t\t\t29SPjnnodhSdRI0xaxAKOR0t1I0ljwDWroMrmDgVbAzdO4YaebiEj32qXoc8qF93\n\t\t\t\t\t\tBx+vY4qK5b2wm4W9P5WUTb2rM/ujSu26EkUZlP6uamM5xHaEBGAm2bixC9Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDiDCCAnCgAwIBAgIEUxEfCDANBgkqhkiG9w0BAQUFADCBhTELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFDASBgNVBAgTC094Zm9yZHNoaXJlMQ8wDQYDVQQHEwZPeGZvcmQxHjAcBgNV\n\t\t\t\t\t\tBAoTFVB1Ymxpc2hpbmcgVGVjaG5vbG9neTEPMA0GA1UECxMGT25saW5lMR4wHAYD\n\t\t\t\t\t\tVQQDExVQdWJsaXNoaW5nIFRlY2hub2xvZ3kwHhcNMTQwMjI4MjM0MzA0WhcNMTcw\n\t\t\t\t\t\tMjI3MjM0MzA0WjCBhTELMAkGA1UEBhMCR0IxFDASBgNVBAgTC094Zm9yZHNoaXJl\n\t\t\t\t\t\tMQ8wDQYDVQQHEwZPeGZvcmQxHjAcBgNVBAoTFVB1Ymxpc2hpbmcgVGVjaG5vbG9n\n\t\t\t\t\t\teTEPMA0GA1UECxMGT25saW5lMR4wHAYDVQQDExVQdWJsaXNoaW5nIFRlY2hub2xv\n\t\t\t\t\t\tZ3kwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCtKdKPdmVZXkJajIXP\n\t\t\t\t\t\toD1MM4HDgaXr6DWwK3MCvhwAG4X7jXeP4TZ3UPM9VqAk1BywDFJ4ZKVvkVMJaavp\n\t\t\t\t\t\t6CUcidSkba9FXEoxbcRmLinw9CIDyqrczOtTrh8Y0VlVUJWus2QCDZDjSghN6ZyF\n\t\t\t\t\t\tR6tu9skOgnNTmlM7wZ6OH8wvOgSMgoLHsswqpWb7ZgujYxMXejrZgSGbezYyqD8b\n\t\t\t\t\t\t4VEgbrwB4pGpZHmH9BQ3ozNIcDm/g5XTGm86useupVepZ8NOqfV9NkmAYI0r81L8\n\t\t\t\t\t\tHsNvWFAtM2gifJLt64rBFgdGZYhKAb3Kr9DlmbarSwwG5gF+R5hdCzXX2z/y7tIC\n\t\t\t\t\t\t2nYjAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAGClcTLi5SJ1ia2FLgQcUy4vFeKx\n\t\t\t\t\t\t/VmKPKWHFctm46dEccIAvHOOC3zCXOOHfCRZrR/pMVCfE9UnzvPIl1fRtm79SuxX\n\t\t\t\t\t\tFjEs7GhibW9ALm1Yh2YVnGGaq7U1aO4kU3MJ9SBwZT4uXhbGRNdnUyyjPxQ7jrfO\n\t\t\t\t\t\tR0GLxZfF8MvKnosafmF3d4ivcP/xzgmVtBG9WRZHASHfIfB8qAZXBLOLuDvDFVC6\n\t\t\t\t\t\t29SPjnnodhSdRI0xaxAKOR0t1I0ljwDWroMrmDgVbAzdO4YaebiEj32qXoc8qF93\n\t\t\t\t\t\tBx+vY4qK5b2wm4W9P5WUTb2rM/ujSu26EkUZlP6uamM5xHaEBGAm2bixC9Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://beta.hp.pub2web.ingenta.com/session/shib",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://beta.hp.pub2web.ingenta.com/session/shib",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://saml.hhs.nl/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://saml.hhs.nl/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-06-01T15:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/31c58f27e40bd14fe7f81df7725e9a66",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Haagse Hogeschool"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Haagse Hogeschool"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/hhs.png",
                    "height": "22",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Haagse Hogeschool"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The Hague University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Haagse Hogeschool"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dehaagsehogeschool.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Haagse Hogeschool"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://repo.clarino.uib.no/shibboleth/sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gjesdal"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:oyvind.gjesdal@uib.no"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Oyvind Liland"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "de Smedt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:clarino@uib.no"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Koenraad"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Al Ruwehy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hemed.ruwehy@uib.no"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hemed"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://repo.clarino.uib.no/shibboleth/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-11-19T14:56:48Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://clarin.eu/category/clarin-member"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://repo.clarino.uib.no/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://repo.clarino.uib.no/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://repo.clarino.uib.no/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://repo.clarino.uib.no/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://repo.clarino.uib.no/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://repo.clarino.uib.no/xmlui/page/about"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CLARINO Bergen Langzeitarchiv"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CLARINO Bergen Repository"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Norwegische Forschungsinfrastruktur f\u00fcr Sprachdaten und Dienste im Rahmen der CLARIN-Initiative."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The CLARINO Bergen Repository for language resources at the University of Bergen"
                  }
                ],
                "logo": [
                  {
                    "text": "https://repo.clarino.uib.no/xmlui/themes/CLARINO/images/favicon.ico",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://clarino.uib.no/images/clarino_duo-180.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "180"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://repo.clarino.uib.no/xmlui/privacypolicy.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "repo.clarino.uib.no"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJAP5/Ri7rxa/LMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE3JlcG8uY2xhcmluby51aWIubm8wHhcNMTQxMjE4MDkwNTE1WhcNMjQxMjE1\nMDkwNTE1WjAeMRwwGgYDVQQDExNyZXBvLmNsYXJpbm8udWliLm5vMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2OVEwzYCig35Ii37Buky/t7KWlNUEkGP\nE2WbfBiSPM2Iw+FIYGrpZ8KIt6qloN19vKwy8m53Asbba477R8CEx0zNQEHPfq35\nvPDxDj2xLN+xvRuk6s6KbZ2eKvV6Vov2vDtOt7kw8gDFUOJd+SdOe+ROdiuV/DbO\njpwsW68GdDpLWHmKSqXqk8fwCdoc0Imwic5sSfc2LPjAqu95aIb7CiAh8sOg26XK\nik6Fjibj48l3aVxtIMGJf30JtS1SqnKgqmQoO6opBGnaCF4huNa44JYUSF5CQZ3c\n4nRxupv2tp696H7lLH3XOI81dsrAVXEwt1q2D8FzNlT+U0AeFaRhbwIDAQABo0Ew\nPzAeBgNVHREEFzAVghNyZXBvLmNsYXJpbm8udWliLm5vMB0GA1UdDgQWBBQaN4I1\nA6h9Jlo90nhGCWfw3EpT4jANBgkqhkiG9w0BAQUFAAOCAQEADsJ1zgUqZqgnq4gU\nz/z3N+5bieEYEZUJnaQ78a3erdYYLETE/PBrN0QUIGR3M2DhjCi0s00QuVFa1JqX\nIK3dR4ndo5Yv4hV/fVhDIZ4mVIUQPBcTRk1om9/gl1fdmRD+YpvhUSzvheLRBsQO\nyz2syxGRIPwu6LexWb8YbZtcvtWU4ZGwm91KXDerV8J05m4X5rv4HZi0MAS349Vz\ntNRgm6CrMBfiQUxQw5Gqsiuyf3rpzQLslEWEmP4AuoiUvlXiWqW+fDKhDhj2vlc8\n0jOCrQaG00xvCbXSg91K+Xxj1kXjArfX4R7aB1TquBqLoFbPo0lNooYBECv+bN2q\nrYzidg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=repo.clarino.uib.no"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://repo.clarino.uib.no/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://repo.clarino.uib.no/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://repo.clarino.uib.no/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://repo.clarino.uib.no/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://repo.clarino.uib.no/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://repo.clarino.uib.no/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CLARINO Bergen Langzeitarchiv"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CLARINO Bergen Repository"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Norwegische Forschungsinfrastruktur f\u00fcr Sprachdaten und Dienste im Rahmen der CLARIN-Initiative."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The CLARINO Bergen Repository for language resources at the University of Bergen"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "o",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "ou",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.11",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://itacare.bahiana.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Claudio Santos"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "nti-claudiosantos@bahiana.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://itacare.bahiana.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEZDCCA0wCAQAwDQYJKoZIhvcNAQEFBQAwgfcxPTA7BgNVBAoUNEVCTVNQIC0g\nRXNjb2xhIEJhaGlhbmEgZGUgTWVkaWNpbmEgZSBTYcO6ZGUgUMO6YmxpY2ExNDAy\nBgNVBAsUK05USSAtIE7DumNsZW8gZGUgVGVjbm9sb2dpYSBkYSBJbmZvcm1hw6fD\no28xLzAtBgkqhkiG9w0BCQEWIG50aS1jbGF1ZGlvc2FudG9zQGJhaGlhbmEuZWR1\nLmJyMREwDwYDVQQHEwhTYWx2YWRvcjEOMAwGA1UECBMFQmFoaWExCzAJBgNVBAYT\nAkJSMR8wHQYDVQQDExZpdGFjYXJlLmJhaGlhbmEuZWR1LmJyMB4XDTE0MDQyOTIz\nNDgwMloXDTE5MDQyODIzNDgwMlowgfcxPTA7BgNVBAoUNEVCTVNQIC0gRXNjb2xh\nIEJhaGlhbmEgZGUgTWVkaWNpbmEgZSBTYcO6ZGUgUMO6YmxpY2ExNDAyBgNVBAsU\nK05USSAtIE7DumNsZW8gZGUgVGVjbm9sb2dpYSBkYSBJbmZvcm1hw6fDo28xLzAt\nBgkqhkiG9w0BCQEWIG50aS1jbGF1ZGlvc2FudG9zQGJhaGlhbmEuZWR1LmJyMREw\nDwYDVQQHEwhTYWx2YWRvcjEOMAwGA1UECBMFQmFoaWExCzAJBgNVBAYTAkJSMR8w\nHQYDVQQDExZpdGFjYXJlLmJhaGlhbmEuZWR1LmJyMIIBIjANBgkqhkiG9w0BAQEF\nAAOCAQ8AMIIBCgKCAQEArfqLewyUzBJPl5bZ5wEkkGRTPti74wbKnaAPLgzhLtPD\ntqICjgEVituk3ZSaEi3S9z6XUKLS32zOv0+U2aD1+IefqGrEOEyBbEPQJ7+gr4Zi\nZ13qHrjNWJ5a9b7UVNTD+6r0HWD1SPzW+lWzEaQzsV4WyBUo2l5b7Ik2hPWGn+UR\nSTLduCX3Pb9UOTmwGikTN+uhKiyvhYMVkVVI1AV8byR0kXjbpzaOss0MgldLCqZL\n8NA/yF4XULGoUKb4DnH7i2ljgC3inay2oOdwRF1UYhI+lYaWq0bgxu+aDPRbQePZ\n/qOEl6Fg/p6I9mCN5boSalR1c2paAWXjQFIb1yzooQIDAQABMA0GCSqGSIb3DQEB\nBQUAA4IBAQCgIsNDggjacZw0Q/ngHibIkh9B1GzvRXR74eG42/Lsdfyr9VEe+foh\nE8YVGgT0PDJF/TU8a9IK/j5HLMUnwCEiEEA5yt5RjC3QmIlKVkBD19/2EwJ0m9y+\n4xPQ977AsGpdh1IgtwgFGDKe0ZuVMyOJkWBx0VDdROP14215yTMhTgho9BnfAWcL\ndB9LD1cUTQOHl3pALNiJEUoalHigtqsPtZx1ld1qskHvvv/6WhObJBh0DbSXJtak\nqz1SUhwFk05GOst5iQ3sVVkZdS78DpDCuNPGEdj9YDPZVsdd9CepbgkWV29AX/yB\no4OFX+ZHPirEOF/8flK2xmI8xJ7blH+6"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://itacare.bahiana.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://itacare.bahiana.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://itacare.bahiana.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://itacare.bahiana.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://itacare.bahiana.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://itacare.bahiana.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://itacare.bahiana.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://itacare.bahiana.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.bahiana.edu.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.bahiana.edu.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "EBMSP - Escola Bahiana de Medicina e Saude Publica"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "EBMSP - Escola Bahiana de Medicina e Saude Publica"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EBMSP - Escola Bahiana de Medicina e Saude Publica"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EBMSP - Escola Bahiana de Medicina e Saude Publica"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEZDCCA0wCAQAwDQYJKoZIhvcNAQEFBQAwgfcxPTA7BgNVBAoUNEVCTVNQIC0g\nRXNjb2xhIEJhaGlhbmEgZGUgTWVkaWNpbmEgZSBTYcO6ZGUgUMO6YmxpY2ExNDAy\nBgNVBAsUK05USSAtIE7DumNsZW8gZGUgVGVjbm9sb2dpYSBkYSBJbmZvcm1hw6fD\no28xLzAtBgkqhkiG9w0BCQEWIG50aS1jbGF1ZGlvc2FudG9zQGJhaGlhbmEuZWR1\nLmJyMREwDwYDVQQHEwhTYWx2YWRvcjEOMAwGA1UECBMFQmFoaWExCzAJBgNVBAYT\nAkJSMR8wHQYDVQQDExZpdGFjYXJlLmJhaGlhbmEuZWR1LmJyMB4XDTE0MDQyOTIz\nNDgwMloXDTE5MDQyODIzNDgwMlowgfcxPTA7BgNVBAoUNEVCTVNQIC0gRXNjb2xh\nIEJhaGlhbmEgZGUgTWVkaWNpbmEgZSBTYcO6ZGUgUMO6YmxpY2ExNDAyBgNVBAsU\nK05USSAtIE7DumNsZW8gZGUgVGVjbm9sb2dpYSBkYSBJbmZvcm1hw6fDo28xLzAt\nBgkqhkiG9w0BCQEWIG50aS1jbGF1ZGlvc2FudG9zQGJhaGlhbmEuZWR1LmJyMREw\nDwYDVQQHEwhTYWx2YWRvcjEOMAwGA1UECBMFQmFoaWExCzAJBgNVBAYTAkJSMR8w\nHQYDVQQDExZpdGFjYXJlLmJhaGlhbmEuZWR1LmJyMIIBIjANBgkqhkiG9w0BAQEF\nAAOCAQ8AMIIBCgKCAQEArfqLewyUzBJPl5bZ5wEkkGRTPti74wbKnaAPLgzhLtPD\ntqICjgEVituk3ZSaEi3S9z6XUKLS32zOv0+U2aD1+IefqGrEOEyBbEPQJ7+gr4Zi\nZ13qHrjNWJ5a9b7UVNTD+6r0HWD1SPzW+lWzEaQzsV4WyBUo2l5b7Ik2hPWGn+UR\nSTLduCX3Pb9UOTmwGikTN+uhKiyvhYMVkVVI1AV8byR0kXjbpzaOss0MgldLCqZL\n8NA/yF4XULGoUKb4DnH7i2ljgC3inay2oOdwRF1UYhI+lYaWq0bgxu+aDPRbQePZ\n/qOEl6Fg/p6I9mCN5boSalR1c2paAWXjQFIb1yzooQIDAQABMA0GCSqGSIb3DQEB\nBQUAA4IBAQCgIsNDggjacZw0Q/ngHibIkh9B1GzvRXR74eG42/Lsdfyr9VEe+foh\nE8YVGgT0PDJF/TU8a9IK/j5HLMUnwCEiEEA5yt5RjC3QmIlKVkBD19/2EwJ0m9y+\n4xPQ977AsGpdh1IgtwgFGDKe0ZuVMyOJkWBx0VDdROP14215yTMhTgho9BnfAWcL\ndB9LD1cUTQOHl3pALNiJEUoalHigtqsPtZx1ld1qskHvvv/6WhObJBh0DbSXJtak\nqz1SUhwFk05GOst5iQ3sVVkZdS78DpDCuNPGEdj9YDPZVsdd9CepbgkWV29AX/yB\no4OFX+ZHPirEOF/8flK2xmI8xJ7blH+6"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EBMSP - Escola Bahiana de Medicina e Saude Publica"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EBMSP - Escola Bahiana de Medicina e Saude Publica"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bahiana.edu.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bahiana.edu.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "EBMSP - Escola Bahiana de Medicina e Saude Publica"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "EBMSP - Escola Bahiana de Medicina e Saude Publica"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.scc.kit.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Simon"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:simon@kit.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Labitzke"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:labitzke@kit.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sebastian"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Servicedesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@scc.kit.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SCC"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.scc.kit.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2010-03-15T10:30:11Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://aai.dfn.de/category/bwidm-member"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.scc.kit.edu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF6TCCBNGgAwIBAgIHGJJryAQp3DANBgkqhkiG9w0BAQsFADCBvzELMAkGA1UE\nBhMCREUxGzAZBgNVBAgTEkJhZGVuLVd1ZXJ0dGVtYmVyZzESMBAGA1UEBxMJS2Fy\nbHNydWhlMSowKAYDVQQKEyFLYXJsc3J1aGUgSW5zdGl0dXRlIG9mIFRlY2hub2xv\nZ3kxJzAlBgNVBAsTHlN0ZWluYnVjaCBDZW50cmUgZm9yIENvbXB1dGluZzEPMA0G\nA1UEAxMGS0lULUNBMRkwFwYJKoZIhvcNAQkBFgpjYUBraXQuZWR1MB4XDTE0MTEy\nNDA4MzcxMloXDTE3MTEyMzA4MzcxMlowgYQxCzAJBgNVBAYTAkRFMRswGQYDVQQI\nExJCYWRlbi1XdWVydHRlbWJlcmcxEjAQBgNVBAcTCUthcmxzcnVoZTEqMCgGA1UE\nChMhS2FybHNydWhlIEluc3RpdHV0ZSBvZiBUZWNobm9sb2d5MRgwFgYDVQQDEw9p\nZHAuc2NjLmtpdC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC6\nSHeWNp6zK1meHCSku8F6Rs84KD5YambNl7LzwA1ZyVhi37WUHXVOwzqTVJy546ch\nfJbnj1KdEVMXEd0J9wsxkOBWv99y8l9GQgzUBI0foAqSs6AQgjtmhSuAHG8UN1W8\nD54hTZcoIO6woH1L+Q8Se8X9P6O6JTaEY1xVKWfnc34mMAZ6FYNKclTG9usp4Tk5\nEVDF3rIrI1kAJ28nbm1S3CfW0w8P/HoN9/l26vs2zGaZiSGcdd+ybTd8zzyUQjh+\nEf+K7tvB6dAjEdJ/9Eles0qVubR4M9mw/wxZvuuPvDbKdAmMub1ssdaaA1AnbENd\nH0CecJNRV32EhR3xrxb1AgMBAAGjggIhMIICHTBPBgNVHSAESDBGMBEGDysGAQQB\nga0hgiwBAQQDAzARBg8rBgEEAYGtIYIsAgEEAwEwDwYNKwYBBAGBrSGCLAEBBDAN\nBgsrBgEEAYGtIYIsHjAJBgNVHRMEAjAAMAsGA1UdDwQEAwIE8DATBgNVHSUEDDAK\nBggrBgEFBQcDATAdBgNVHQ4EFgQUN64AGeNb/L86LwUaKdRer24/bF4wHwYDVR0j\nBBgwFoAUH3Rl9JodevYx6d9hG3MrDW3QM0kwGgYDVR0RBBMwEYIPaWRwLnNjYy5r\naXQuZWR1MHcGA1UdHwRwMG4wNaAzoDGGL2h0dHA6Ly9jZHAxLnBjYS5kZm4uZGUv\na2l0LWNhL3B1Yi9jcmwvY2FjcmwuY3JsMDWgM6Axhi9odHRwOi8vY2RwMi5wY2Eu\nZGZuLmRlL2tpdC1jYS9wdWIvY3JsL2NhY3JsLmNybDCBxwYIKwYBBQUHAQEEgbow\ngbcwMwYIKwYBBQUHMAGGJ2h0dHA6Ly9vY3NwLnBjYS5kZm4uZGUvT0NTUC1TZXJ2\nZXIvT0NTUDA/BggrBgEFBQcwAoYzaHR0cDovL2NkcDEucGNhLmRmbi5kZS9raXQt\nY2EvcHViL2NhY2VydC9jYWNlcnQuY3J0MD8GCCsGAQUFBzAChjNodHRwOi8vY2Rw\nMi5wY2EuZGZuLmRlL2tpdC1jYS9wdWIvY2FjZXJ0L2NhY2VydC5jcnQwDQYJKoZI\nhvcNAQELBQADggEBABB39faqcheKsMJKV7+AXlPHnwZNU08qsJljqAWZiJYR9oBA\nu/4CtsIBiP3ze7N8yqD0QSGS1vgUZAhUfK+lVqJJ489NEPZJ+BXNKzyeDuBA8mDf\nOYnlKhPiKVdWNIZGRYMg0QucuomhNF6I1rqUti3f0DB0KRhsGAZ6x9I3XYf13Ysd\nuk6L8FgX8L8oIsCafeAx9d2J/DozuHzpl1sAozMbjko6oFQS+jefrshY/8sOrC2Z\n/Qu/RelkUt/17g7WYLHI2CQ/TWjYDe+tPKaLoCrUqNV1Se3pm/f0lcsOrOdNJXp/\nDDtygfMFcJ7uU7YOIBUyd7s1m23ZZzi6HkTPEtM="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.scc.kit.edu,O=Karlsruhe Institute of Technology,L=Karlsruhe,ST=Baden-Wuerttemberg,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kit.edu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "student.kit.edu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "partner.kit.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.scc.kit.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.scc.kit.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.scc.kit.edu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.scc.kit.edu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.scc.kit.edu/idp/profile/SAML2/POST-SimpleSign/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.scc.kit.edu/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.scc.kit.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.scc.kit.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.scc.kit.edu/idp/profile/SAML2/POST-Simple-Sign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.scc.kit.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.scc.kit.edu/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.scc.kit.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.scc.kit.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kit.edu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "student.kit.edu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "partner.kit.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.scc.kit.edu/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.scc.kit.edu/"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Karlsruher Institut f\u00fcr Technologie - Universit\u00e4t des Landes Baden-W\u00fcrttemberg und nationales Forschungszentrum in der Helmholtz-Gemeinschaft"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Karlsruhe Institute of Technology - University of the State of Baden-Wuerttemberg and National Research Center of the Helmholtz Association"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.scc.kit.edu/logo/kit-logo-small.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.scc.kit.edu/logo/kit-logo.png",
                    "height": "120",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "260"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Karlsruher Institut f\u00fcr Technologie (KIT)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Karlsruhe Institute of Technology (KIT)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.scc.kit.edu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF6TCCBNGgAwIBAgIHGJJryAQp3DANBgkqhkiG9w0BAQsFADCBvzELMAkGA1UE\nBhMCREUxGzAZBgNVBAgTEkJhZGVuLVd1ZXJ0dGVtYmVyZzESMBAGA1UEBxMJS2Fy\nbHNydWhlMSowKAYDVQQKEyFLYXJsc3J1aGUgSW5zdGl0dXRlIG9mIFRlY2hub2xv\nZ3kxJzAlBgNVBAsTHlN0ZWluYnVjaCBDZW50cmUgZm9yIENvbXB1dGluZzEPMA0G\nA1UEAxMGS0lULUNBMRkwFwYJKoZIhvcNAQkBFgpjYUBraXQuZWR1MB4XDTE0MTEy\nNDA4MzcxMloXDTE3MTEyMzA4MzcxMlowgYQxCzAJBgNVBAYTAkRFMRswGQYDVQQI\nExJCYWRlbi1XdWVydHRlbWJlcmcxEjAQBgNVBAcTCUthcmxzcnVoZTEqMCgGA1UE\nChMhS2FybHNydWhlIEluc3RpdHV0ZSBvZiBUZWNobm9sb2d5MRgwFgYDVQQDEw9p\nZHAuc2NjLmtpdC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC6\nSHeWNp6zK1meHCSku8F6Rs84KD5YambNl7LzwA1ZyVhi37WUHXVOwzqTVJy546ch\nfJbnj1KdEVMXEd0J9wsxkOBWv99y8l9GQgzUBI0foAqSs6AQgjtmhSuAHG8UN1W8\nD54hTZcoIO6woH1L+Q8Se8X9P6O6JTaEY1xVKWfnc34mMAZ6FYNKclTG9usp4Tk5\nEVDF3rIrI1kAJ28nbm1S3CfW0w8P/HoN9/l26vs2zGaZiSGcdd+ybTd8zzyUQjh+\nEf+K7tvB6dAjEdJ/9Eles0qVubR4M9mw/wxZvuuPvDbKdAmMub1ssdaaA1AnbENd\nH0CecJNRV32EhR3xrxb1AgMBAAGjggIhMIICHTBPBgNVHSAESDBGMBEGDysGAQQB\nga0hgiwBAQQDAzARBg8rBgEEAYGtIYIsAgEEAwEwDwYNKwYBBAGBrSGCLAEBBDAN\nBgsrBgEEAYGtIYIsHjAJBgNVHRMEAjAAMAsGA1UdDwQEAwIE8DATBgNVHSUEDDAK\nBggrBgEFBQcDATAdBgNVHQ4EFgQUN64AGeNb/L86LwUaKdRer24/bF4wHwYDVR0j\nBBgwFoAUH3Rl9JodevYx6d9hG3MrDW3QM0kwGgYDVR0RBBMwEYIPaWRwLnNjYy5r\naXQuZWR1MHcGA1UdHwRwMG4wNaAzoDGGL2h0dHA6Ly9jZHAxLnBjYS5kZm4uZGUv\na2l0LWNhL3B1Yi9jcmwvY2FjcmwuY3JsMDWgM6Axhi9odHRwOi8vY2RwMi5wY2Eu\nZGZuLmRlL2tpdC1jYS9wdWIvY3JsL2NhY3JsLmNybDCBxwYIKwYBBQUHAQEEgbow\ngbcwMwYIKwYBBQUHMAGGJ2h0dHA6Ly9vY3NwLnBjYS5kZm4uZGUvT0NTUC1TZXJ2\nZXIvT0NTUDA/BggrBgEFBQcwAoYzaHR0cDovL2NkcDEucGNhLmRmbi5kZS9raXQt\nY2EvcHViL2NhY2VydC9jYWNlcnQuY3J0MD8GCCsGAQUFBzAChjNodHRwOi8vY2Rw\nMi5wY2EuZGZuLmRlL2tpdC1jYS9wdWIvY2FjZXJ0L2NhY2VydC5jcnQwDQYJKoZI\nhvcNAQELBQADggEBABB39faqcheKsMJKV7+AXlPHnwZNU08qsJljqAWZiJYR9oBA\nu/4CtsIBiP3ze7N8yqD0QSGS1vgUZAhUfK+lVqJJ489NEPZJ+BXNKzyeDuBA8mDf\nOYnlKhPiKVdWNIZGRYMg0QucuomhNF6I1rqUti3f0DB0KRhsGAZ6x9I3XYf13Ysd\nuk6L8FgX8L8oIsCafeAx9d2J/DozuHzpl1sAozMbjko6oFQS+jefrshY/8sOrC2Z\n/Qu/RelkUt/17g7WYLHI2CQ/TWjYDe+tPKaLoCrUqNV1Se3pm/f0lcsOrOdNJXp/\nDDtygfMFcJ7uU7YOIBUyd7s1m23ZZzi6HkTPEtM="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.scc.kit.edu,O=Karlsruhe Institute of Technology,L=Karlsruhe,ST=Baden-Wuerttemberg,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Karlsruher Institut f\u00fcr Technologie (KIT)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Karlsruhe Institute of Technology (KIT)"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.scc.kit.edu/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.scc.kit.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e148"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e148"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.keynote.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sole"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ssole@keynote.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shaun"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Shah"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ashah@mintel.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ameet"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.keynote.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-05-15T09:50:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Key Note: Market Intelligence"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.keynote.co.uk/GlobalFrame.htm"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Key Note Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGDzCCBPegAwIBAgIQJh9i1AJonsnAFcGwgs/cvzANBgkqhkiG9w0BAQUFADCB\n\t\t\t\t\t\ttTELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMR8wHQYDVQQL\n\t\t\t\t\t\tExZWZXJpU2lnbiBUcnVzdCBOZXR3b3JrMTswOQYDVQQLEzJUZXJtcyBvZiB1c2Ug\n\t\t\t\t\t\tYXQgaHR0cHM6Ly93d3cudmVyaXNpZ24uY29tL3JwYSAoYykxMDEvMC0GA1UEAxMm\n\t\t\t\t\t\tVmVyaVNpZ24gQ2xhc3MgMyBTZWN1cmUgU2VydmVyIENBIC0gRzMwHhcNMTIwNDE2\n\t\t\t\t\t\tMDAwMDAwWhcNMTgwNDE3MjM1OTU5WjCB+TELMAkGA1UEBhMCR0IxEjAQBgNVBAgT\n\t\t\t\t\t\tCU1pZGRsZXNleDEQMA4GA1UEBxQHSGFtcHRvbjERMA8GA1UEChQIS2V5IE5vdGUx\n\t\t\t\t\t\tETAPBgNVBAsUCEtleSBOb3RlMTUwMwYDVQQLFCxUZXJtcyBvZiB1c2UgYXQgd3d3\n\t\t\t\t\t\tLnZlcmlzaWduLmNvLnVrL3JwYSAoYykwNTEiMCAGA1UECxMZQXV0aGVudGljYXRl\n\t\t\t\t\t\tZCBieSBWZXJpU2lnbjEnMCUGA1UECxMeTWVtYmVyLCBWZXJpU2lnbiBUcnVzdCBO\n\t\t\t\t\t\tZXR3b3JrMRowGAYDVQQDFBF3d3cua2V5bm90ZS5jby51azCCASIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEBBQADggEPADCCAQoCggEBANjKlKP40hmfmHrQdPo2rI+zJUl9eMvL5qNzLgAN\n\t\t\t\t\t\tQnOgojsZFwpQ3UJxIcm8Od2eIWd1xJne5ijHaeTniBxeJOj2PfDVzFxuvPWXcMYs\n\t\t\t\t\t\twusvAOgEcSDjhe2Qk4hBY0dd1T0IvU+8zRK6I+lGfZGkP7kNc+jq6ATyxXB3ayb1\n\t\t\t\t\t\t1/3yCljsnj27CH5hrym8IA7MCOZhYFXux66LGhT0c4WpKICIGapM6NLDDRI+zqQO\n\t\t\t\t\t\tC7JUh/7bteC332DJlpp/hEedtcytwdznAsfuFYAqLW0m2C1+F0m42hRYRsdK/8BE\n\t\t\t\t\t\twZVvmVEtQ5nD0PhWJle+p5qY2vOsnCoux4w2d8vMnCVQWSECAwEAAaOCAdMwggHP\n\t\t\t\t\t\tMAkGA1UdEwQCMAAwCwYDVR0PBAQDAgWgMEUGA1UdHwQ+MDwwOqA4oDaGNGh0dHA6\n\t\t\t\t\t\tLy9TVlJTZWN1cmUtRzMtY3JsLnZlcmlzaWduLmNvbS9TVlJTZWN1cmVHMy5jcmww\n\t\t\t\t\t\tRgYDVR0gBD8wPTA7BgtghkgBhvhFAQcXAzAsMCoGCCsGAQUFBwIBFh5odHRwczov\n\t\t\t\t\t\tL3d3dy52ZXJpc2lnbi5jby51ay9ycGEwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsG\n\t\t\t\t\t\tAQUFBwMCMB8GA1UdIwQYMBaAFA1EXBZTRMGCfh0gqyX0AWPYvnmlMHYGCCsGAQUF\n\t\t\t\t\t\tBwEBBGowaDAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AudmVyaXNpZ24uY29tMEAG\n\t\t\t\t\t\tCCsGAQUFBzAChjRodHRwOi8vU1ZSU2VjdXJlLUczLWFpYS52ZXJpc2lnbi5jb20v\n\t\t\t\t\t\tU1ZSU2VjdXJlRzMuY2VyMG4GCCsGAQUFBwEMBGIwYKFeoFwwWjBYMFYWCWltYWdl\n\t\t\t\t\t\tL2dpZjAhMB8wBwYFKw4DAhoEFEtruSiWBgy70FI4mymsSweLIQUYMCYWJGh0dHA6\n\t\t\t\t\t\tLy9sb2dvLnZlcmlzaWduLmNvbS92c2xvZ28xLmdpZjANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAVwvsWtkpYSAGQkJ2TV0wfnFg+tMRCSu3nB4KEYCremLxItsnnGuyDLb8/EYT\n\t\t\t\t\t\tMfwdr26NKunr+50Ry85EwmAPeYbx6NY9kLb2s/XyujeGHQaDOQTXMRtXvEYoJ5vw\n\t\t\t\t\t\tlNqMPy5O1Ih3W4TJi+CeX2TVaX4PNS2PKv6GKfIKZC0aWP6ZSurvyBUoI5jaMcoj\n\t\t\t\t\t\t0/2IqQ9HIxlRdTEIXGuvPfCMzQmQ48RmLHw3ImTb91JkQM31/FwsiIidjWkkgq5M\n\t\t\t\t\t\t5z9CF7Rt++PysgVB2M6swP3qVegOAFnkHGvuQExRS3dSQK4wUYXwKUoeXKBfTE60\n\t\t\t\t\t\tiIcX2da2+HnwyJ4195yPUocmnA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGDzCCBPegAwIBAgIQJh9i1AJonsnAFcGwgs/cvzANBgkqhkiG9w0BAQUFADCB\n\t\t\t\t\t\ttTELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMR8wHQYDVQQL\n\t\t\t\t\t\tExZWZXJpU2lnbiBUcnVzdCBOZXR3b3JrMTswOQYDVQQLEzJUZXJtcyBvZiB1c2Ug\n\t\t\t\t\t\tYXQgaHR0cHM6Ly93d3cudmVyaXNpZ24uY29tL3JwYSAoYykxMDEvMC0GA1UEAxMm\n\t\t\t\t\t\tVmVyaVNpZ24gQ2xhc3MgMyBTZWN1cmUgU2VydmVyIENBIC0gRzMwHhcNMTIwNDE2\n\t\t\t\t\t\tMDAwMDAwWhcNMTgwNDE3MjM1OTU5WjCB+TELMAkGA1UEBhMCR0IxEjAQBgNVBAgT\n\t\t\t\t\t\tCU1pZGRsZXNleDEQMA4GA1UEBxQHSGFtcHRvbjERMA8GA1UEChQIS2V5IE5vdGUx\n\t\t\t\t\t\tETAPBgNVBAsUCEtleSBOb3RlMTUwMwYDVQQLFCxUZXJtcyBvZiB1c2UgYXQgd3d3\n\t\t\t\t\t\tLnZlcmlzaWduLmNvLnVrL3JwYSAoYykwNTEiMCAGA1UECxMZQXV0aGVudGljYXRl\n\t\t\t\t\t\tZCBieSBWZXJpU2lnbjEnMCUGA1UECxMeTWVtYmVyLCBWZXJpU2lnbiBUcnVzdCBO\n\t\t\t\t\t\tZXR3b3JrMRowGAYDVQQDFBF3d3cua2V5bm90ZS5jby51azCCASIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEBBQADggEPADCCAQoCggEBANjKlKP40hmfmHrQdPo2rI+zJUl9eMvL5qNzLgAN\n\t\t\t\t\t\tQnOgojsZFwpQ3UJxIcm8Od2eIWd1xJne5ijHaeTniBxeJOj2PfDVzFxuvPWXcMYs\n\t\t\t\t\t\twusvAOgEcSDjhe2Qk4hBY0dd1T0IvU+8zRK6I+lGfZGkP7kNc+jq6ATyxXB3ayb1\n\t\t\t\t\t\t1/3yCljsnj27CH5hrym8IA7MCOZhYFXux66LGhT0c4WpKICIGapM6NLDDRI+zqQO\n\t\t\t\t\t\tC7JUh/7bteC332DJlpp/hEedtcytwdznAsfuFYAqLW0m2C1+F0m42hRYRsdK/8BE\n\t\t\t\t\t\twZVvmVEtQ5nD0PhWJle+p5qY2vOsnCoux4w2d8vMnCVQWSECAwEAAaOCAdMwggHP\n\t\t\t\t\t\tMAkGA1UdEwQCMAAwCwYDVR0PBAQDAgWgMEUGA1UdHwQ+MDwwOqA4oDaGNGh0dHA6\n\t\t\t\t\t\tLy9TVlJTZWN1cmUtRzMtY3JsLnZlcmlzaWduLmNvbS9TVlJTZWN1cmVHMy5jcmww\n\t\t\t\t\t\tRgYDVR0gBD8wPTA7BgtghkgBhvhFAQcXAzAsMCoGCCsGAQUFBwIBFh5odHRwczov\n\t\t\t\t\t\tL3d3dy52ZXJpc2lnbi5jby51ay9ycGEwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsG\n\t\t\t\t\t\tAQUFBwMCMB8GA1UdIwQYMBaAFA1EXBZTRMGCfh0gqyX0AWPYvnmlMHYGCCsGAQUF\n\t\t\t\t\t\tBwEBBGowaDAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AudmVyaXNpZ24uY29tMEAG\n\t\t\t\t\t\tCCsGAQUFBzAChjRodHRwOi8vU1ZSU2VjdXJlLUczLWFpYS52ZXJpc2lnbi5jb20v\n\t\t\t\t\t\tU1ZSU2VjdXJlRzMuY2VyMG4GCCsGAQUFBwEMBGIwYKFeoFwwWjBYMFYWCWltYWdl\n\t\t\t\t\t\tL2dpZjAhMB8wBwYFKw4DAhoEFEtruSiWBgy70FI4mymsSweLIQUYMCYWJGh0dHA6\n\t\t\t\t\t\tLy9sb2dvLnZlcmlzaWduLmNvbS92c2xvZ28xLmdpZjANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAVwvsWtkpYSAGQkJ2TV0wfnFg+tMRCSu3nB4KEYCremLxItsnnGuyDLb8/EYT\n\t\t\t\t\t\tMfwdr26NKunr+50Ry85EwmAPeYbx6NY9kLb2s/XyujeGHQaDOQTXMRtXvEYoJ5vw\n\t\t\t\t\t\tlNqMPy5O1Ih3W4TJi+CeX2TVaX4PNS2PKv6GKfIKZC0aWP6ZSurvyBUoI5jaMcoj\n\t\t\t\t\t\t0/2IqQ9HIxlRdTEIXGuvPfCMzQmQ48RmLHw3ImTb91JkQM31/FwsiIidjWkkgq5M\n\t\t\t\t\t\t5z9CF7Rt++PysgVB2M6swP3qVegOAFnkHGvuQExRS3dSQK4wUYXwKUoeXKBfTE60\n\t\t\t\t\t\tiIcX2da2+HnwyJ4195yPUocmnA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://www.keynote.co.uk/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.keynote.co.uk/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.keynote.co.uk/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.keynote.co.uk/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://federacao.uvanet.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pedro Roger Magalhaes Vasconcelos"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "roger@uvanet.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federacao.uvanet.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEGjCCAwICAQAwDQYJKoZIhvcNAQEFBQAwgdIxMzAxBgNVBAoTKlVWQSAtIFVu\naXZlcnNpZGFkZSBFc3RhZHVhbCBWYWxlIGRvIEFjYXJhdTExMC8GA1UECxMoTlRJ\nIC0gTnVjbGVvIGRlIFRlY25vbG9naWEgZGEgSW5mb3JtYWNhbzEcMBoGCSqGSIb3\nDQEJARYNbmV0QHV2YW5ldC5icjEPMA0GA1UEBxMGU29icmFsMQ4wDAYDVQQIEwVD\nZWFyYTELMAkGA1UEBhMCQlIxHDAaBgNVBAMTE2ZlZGVyYWNhby51dmFuZXQuYnIw\nHhcNMTUwMzEyMTMwNDEwWhcNMjAwMzEwMTMwNDEwWjCB0jEzMDEGA1UEChMqVVZB\nIC0gVW5pdmVyc2lkYWRlIEVzdGFkdWFsIFZhbGUgZG8gQWNhcmF1MTEwLwYDVQQL\nEyhOVEkgLSBOdWNsZW8gZGUgVGVjbm9sb2dpYSBkYSBJbmZvcm1hY2FvMRwwGgYJ\nKoZIhvcNAQkBFg1uZXRAdXZhbmV0LmJyMQ8wDQYDVQQHEwZTb2JyYWwxDjAMBgNV\nBAgTBUNlYXJhMQswCQYDVQQGEwJCUjEcMBoGA1UEAxMTZmVkZXJhY2FvLnV2YW5l\ndC5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANf14teRlGxARJy4\nxAUTpiaD1fwn9br3YvfOdqBZ+fPtFYj8CmgBlfauRVl9irPrFgbUfIsZckl+EY8f\nXgipRAkQAEAqZn7pNXQBuEXA4QaUVl6mqrqPM/gjNE3QZ5iObqXgdpF9ppKgeNnb\nZhOJNsM6IJNYly/DiVXsRTCo/O2gssnD2Wz09jsTSCKucniL8WhbcuSSzJKfS7sV\nRRyIsOY8sRWL2JSHPIVb/BgZhKKQQfcjWjLH7CNzr0/tXWX7cEr/pUGKLUdXhAps\nhNAA5eUKj2b+n6Kck07oT+SDyq2amK3ofV6vymoOk3uJeVLw2+dfrdIcEarqbDro\n9qNTX8UCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEADuOfAc0Gkul/Xb0J2P1LVxmu\nnmdnhkqrwOmMmv7RGGqhg/9bH5KegefafBJHsiQ7riaQS4k60TdVTnibp7RS+oJ6\nQq1HONm6AVDjsAfBGqW5Gq+eEkFY7p53AY0/J9Wkr02z5F/S/84LRVzyurNKYPg3\nvwErvtUmZbGU6bODq04rhx0uQc6kncNv0Tmpe+XNXGyoBVnpxBK7Gek+iMG5wDSF\nqBKXGALpFR7EnmewvoPr4Cj/GSpeZ/+L7XKgkrry2AT8FyXH5M3CZo0gpd/w7Jp5\noScsaEokLv5uon1tBZ/ckGAFyXCOnnYQx8jCzTcUBI9cDbrBaiVRQs2ct7fiGg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uvanet.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://federacao.uvanet.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://federacao.uvanet.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://federacao.uvanet.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federacao.uvanet.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://federacao.uvanet.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federacao.uvanet.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://federacao.uvanet.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://federacao.uvanet.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uvanet.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uvanet.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uvanet.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UVA - Universidade Estadual Vale do Acarau"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UVA - Universidade Estadual Vale do Acarau"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UVA - Universidade Estadual Vale do Acarau"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UVA - Universidade Estadual Vale do Acarau"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEGjCCAwICAQAwDQYJKoZIhvcNAQEFBQAwgdIxMzAxBgNVBAoTKlVWQSAtIFVu\naXZlcnNpZGFkZSBFc3RhZHVhbCBWYWxlIGRvIEFjYXJhdTExMC8GA1UECxMoTlRJ\nIC0gTnVjbGVvIGRlIFRlY25vbG9naWEgZGEgSW5mb3JtYWNhbzEcMBoGCSqGSIb3\nDQEJARYNbmV0QHV2YW5ldC5icjEPMA0GA1UEBxMGU29icmFsMQ4wDAYDVQQIEwVD\nZWFyYTELMAkGA1UEBhMCQlIxHDAaBgNVBAMTE2ZlZGVyYWNhby51dmFuZXQuYnIw\nHhcNMTUwMzEyMTMwNDEwWhcNMjAwMzEwMTMwNDEwWjCB0jEzMDEGA1UEChMqVVZB\nIC0gVW5pdmVyc2lkYWRlIEVzdGFkdWFsIFZhbGUgZG8gQWNhcmF1MTEwLwYDVQQL\nEyhOVEkgLSBOdWNsZW8gZGUgVGVjbm9sb2dpYSBkYSBJbmZvcm1hY2FvMRwwGgYJ\nKoZIhvcNAQkBFg1uZXRAdXZhbmV0LmJyMQ8wDQYDVQQHEwZTb2JyYWwxDjAMBgNV\nBAgTBUNlYXJhMQswCQYDVQQGEwJCUjEcMBoGA1UEAxMTZmVkZXJhY2FvLnV2YW5l\ndC5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANf14teRlGxARJy4\nxAUTpiaD1fwn9br3YvfOdqBZ+fPtFYj8CmgBlfauRVl9irPrFgbUfIsZckl+EY8f\nXgipRAkQAEAqZn7pNXQBuEXA4QaUVl6mqrqPM/gjNE3QZ5iObqXgdpF9ppKgeNnb\nZhOJNsM6IJNYly/DiVXsRTCo/O2gssnD2Wz09jsTSCKucniL8WhbcuSSzJKfS7sV\nRRyIsOY8sRWL2JSHPIVb/BgZhKKQQfcjWjLH7CNzr0/tXWX7cEr/pUGKLUdXhAps\nhNAA5eUKj2b+n6Kck07oT+SDyq2amK3ofV6vymoOk3uJeVLw2+dfrdIcEarqbDro\n9qNTX8UCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEADuOfAc0Gkul/Xb0J2P1LVxmu\nnmdnhkqrwOmMmv7RGGqhg/9bH5KegefafBJHsiQ7riaQS4k60TdVTnibp7RS+oJ6\nQq1HONm6AVDjsAfBGqW5Gq+eEkFY7p53AY0/J9Wkr02z5F/S/84LRVzyurNKYPg3\nvwErvtUmZbGU6bODq04rhx0uQc6kncNv0Tmpe+XNXGyoBVnpxBK7Gek+iMG5wDSF\nqBKXGALpFR7EnmewvoPr4Cj/GSpeZ/+L7XKgkrry2AT8FyXH5M3CZo0gpd/w7Jp5\noScsaEokLv5uon1tBZ/ckGAFyXCOnnYQx8jCzTcUBI9cDbrBaiVRQs2ct7fiGg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UVA - Universidade Estadual Vale do Acarau"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UVA - Universidade Estadual Vale do Acarau"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uvanet.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uvanet.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UVA - Universidade Estadual Vale do Acarau"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UVA - Universidade Estadual Vale do Acarau"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://logout.uwasa.fi/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kinnunen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:authadm@uwasa.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sami"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kinnunen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:skk@uwasa.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sami"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://logout.uwasa.fi/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.csc.fi/english/institutions/haka/instructions/join/eduGAINRegistrationStatement/"
              }
            ],
            "registration_authority": "http://www.csc.fi/haka",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://logout.uwasa.fi/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "student.uwasa.fi"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uwasa.fi"
              },
              {
                "display_name": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Vaasan yliopisto"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Vaasa"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Vasa Universitet"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "uwasa.fi"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEmDCCA4CgAwIBAgIQQ5ujEn6A97wMBYf7wCeq2TANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMjAeFw0xNDEwMjEwMDAwMDBaFw0xNzExMTQyMzU5NTlaMD0xITAfBgNVBAsT\nGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEYMBYGA1UEAxMPbG9nb3V0LnV3YXNh\nLmZpMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA7/bXKuhTHYn3F5KR\nbV8p0HYCsFVL8qFbZQ2dWTEUGdo8TsFHHJDtd3zdyBH1G90vJhMErfESRX10Za3D\npdY2FmrujdrYMnC1ehTmOkmbfj+48F7vdGeAEZgR4lDRGG7gFwrya0TdnOJqtgqa\njDo0hBz1efTIoFijRwvV3rV0COi2DlOsQTyn9s4gIETCmBxQua/a1AvUJ5ZGdyue\nV4GX3SpWAC+4mVATaFhs9a2phFnpdgv9PZ+k4TI/4jdIsF6POU85ysDUqgXL3C5O\n8WfEFdAH6utWVpOF/Vp9xvI1/LY024U1zPXPRyghwhkV1CnSQIfd8aXFmeqOkoTR\n4ALaNwIDAQABo4IBazCCAWcwHwYDVR0jBBgwFoAUW9CKHJoyW+C13ZZUG+GGKLD9\ntr0wHQYDVR0OBBYEFBb2Xwqc+A65TiHhvkiWdjkTUI0HMA4GA1UdDwEB/wQEAwIF\noDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAi\nBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAxMC+g\nLaArhilodHRwOi8vY3JsLnVzZXJ0cnVzdC5jb20vVEVSRU5BU1NMQ0EyLmNybDBs\nBggrBgEFBQcBAQRgMF4wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudXNlcnRydXN0\nLmNvbS9URVJFTkFTU0xDQTIuY3J0MCUGCCsGAQUFBzABhhlodHRwOi8vb2NzcC51\nc2VydHJ1c3QuY29tMBoGA1UdEQQTMBGCD2xvZ291dC51d2FzYS5maTANBgkqhkiG\n9w0BAQsFAAOCAQEAfqqvlPEDeZ6j/8lMXNMsAZQiDJlbfvxBwj9pSwaCEQ69hZyp\nStSyQwXJWN1EpRzQw23Dn4j0+qgxvyVX/o5rPObIezoCbXBqP5fK0pXuHMkGrDco\n+4pLXY/xDE5sbGszDu9yy1uKlfUBbvCU2KmTpUqAJ1IAu5P6d+705PFYSJGUdBiL\n6x7F70/NW4zXPigoPlExAgMMroLu+S5eJOroW7XXvpytIal1e0VsWwciPQ17BOfh\nONX9QOl1soU728FwQYCE1dOGmflU0MRBTCkgZQ6CFyXB5u41LQE5gb0S4nLCzD5Y\nyWnv/dMB+aZQxAaxuHvLIP8NFFGK50CgD63Osw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Vaasan yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Vaasa"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Vasa Universitet"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uwasa.fi/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uwasa.fi/"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uwasa.fi/"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Vaasan yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Vaasa"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Vasa Universitet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.rsc.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ict@rsc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ICT Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ict@rsc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ICT Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.rsc.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-08-20T11:51:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Royal Society of Chemistry"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rsc.org/aboutus/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Royal Society of Chemistry"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.rsc.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.rsc.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.rsc.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.rsc.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.rsc.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib.rsc.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shib.rsc.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6zCCAdOgAwIBAgIJAI2c7IusuZ5TMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\n\t\t\t\t\t\tBAMTDHNoaWIucnNjLm9yZzAeFw0xMDA3MjcxMTA3MzlaFw0yMDA3MjQxMTA3Mzla\n\t\t\t\t\t\tMBcxFTATBgNVBAMTDHNoaWIucnNjLm9yZzCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBAMZz+1jRYCDUqaGAKnq3AH6BAdsUjMW+saQwgx8bEjEa5kQ0NSHw\n\t\t\t\t\t\t7g3RyE6qNB6BVRoeveqTaR97haz2K02ujOKLJpCRQvZ8qT3/KdnrjRhTfekhGV/F\n\t\t\t\t\t\tPLk1sUu32B4VLXY82hqHjaRBNteF+3Ez2/kFOD8VO82woiN2P9s2HhKSqXsM9rDB\n\t\t\t\t\t\tEJNKva0oFUyDrvcmGyU5hebbAO6aJSkjC2ZZ+oRTbc7jVfSvYxJFejMQRe+3vApj\n\t\t\t\t\t\tWcE1rSqiVA9D5m1zy8q+pYMgyWUgm2tPK46s+xq8QsSguimNhlrAaWkUtXaGmyPo\n\t\t\t\t\t\tygZBl83B4BiSIVkXVp6pVRhBF6tVp6a7n4kCAwEAAaM6MDgwFwYDVR0RBBAwDoIM\n\t\t\t\t\t\tc2hpYi5yc2Mub3JnMB0GA1UdDgQWBBSg4xxfMjUKAHXCOPIEKfl+m56MUDANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAZuQxsfshqIs1QF9EK+lblk0K8GLOpC9bUgGbM0xO+qk7\n\t\t\t\t\t\t2VYpi1DjmCLMemfPSqopr0X68jrnd/K5SLv5GUKy2tpJyndVBQcOGYjUtanIUtiB\n\t\t\t\t\t\tDirWlDDT+Ru5J94mc+aEeyrWH6slRrONqYgEOuKOzD8pDgS7fcThTZBnqo/ywE5a\n\t\t\t\t\t\thYnP/EZ3wPhR+HudHbRcaFguVSAe+9hu7lqpPOUsmmZIAcUkPq78sckMhVohpyy/\n\t\t\t\t\t\t0FenvgTlpbL0eKdn0WkkyPrcakFZk9d3l5aiKxcffteu1G/V5AyQiL2ZkI/hhU5V\n\t\t\t\t\t\t8WXqr8jwzK1gLwel29uXXyVjCDSVfSWSSHBHqhn9/g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.rsc.org/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.rsc.org/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.rsc.org/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.rsc.org/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.rsc.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.rsc.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.rsc.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shib.rsc.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shib.rsc.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shib.rsc.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ludwig.lub.lu.se/sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sherohman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Dave.Sherohman@ub.lu.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dave"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ludwig.lub.lu.se/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://login.ludwig.lub.lu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.ludwig.lub.lu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.ludwig.lub.lu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.ludwig.lub.lu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIELzCCAxegAwIBAgIBCjANBgkqhkiG9w0BAQsFADByMR8wHQYDVQQDExZsb2dp \nbi5sdWR3aWcubHViLmx1LnNlMQswCQYDVQQGEwJTRTEgMB4GA1UEChMXTHVuZCBV \nbml2ZXJzaXR5IExpYnJhcnkxIDAeBgkqhkiG9w0BCQEWEWJkLXRlY2hAbHViLmx1 \nLnNlMB4XDTE2MDMxMTEwMjQ1MloXDTI2MDMxMTEwMjQ1MlowcjEfMB0GA1UEAxMW \nbG9naW4ubHVkd2lnLmx1Yi5sdS5zZTELMAkGA1UEBhMCU0UxIDAeBgNVBAoTF0x1 \nbmQgVW5pdmVyc2l0eSBMaWJyYXJ5MSAwHgYJKoZIhvcNAQkBFhFiZC10ZWNoQGx1 \nYi5sdS5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANbtlQy0oz8q \nNww17ENNGmVYRsb6t/J6fS1MQXs3b45A1WVf7JqMX1cZq3BTXE8T2BfI63uLnaNA \nDk/inDB1blc0VAVdOQcVZLfxN5C86oWPqwULTCTOpW83kqRwJtSB0v+ZymtKNe7+ \nSuDC6YTbNZr/9MOOcKRAd2cfmWVSw3YCGN9VR24lwulF4vSbrdJ9lR1D//2GvMp6 \n7Z0cRS5mmMmN/ECn89ul54ibc9DahAkvdfNyQVpUQOL/prgQ9Xk8iLivpmrXTB+k \naw7wgxkmZIu3SoI6/W7x8pNs05HNeVBG4r3umWe2cksBH/vInkFZmmFMI1vXLnvO \nJtC0QIVhofkCAwEAAaOBzzCBzDAdBgNVHQ4EFgQUMrJawJ0MOb8YyuQtzyimB4aD \n8V4wgZwGA1UdIwSBlDCBkYAUMrJawJ0MOb8YyuQtzyimB4aD8V6hdqR0MHIxHzAd \nBgNVBAMTFmxvZ2luLmx1ZHdpZy5sdWIubHUuc2UxCzAJBgNVBAYTAlNFMSAwHgYD \nVQQKExdMdW5kIFVuaXZlcnNpdHkgTGlicmFyeTEgMB4GCSqGSIb3DQEJARYRYmQt \ndGVjaEBsdWIubHUuc2WCAQowDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOC \nAQEAGpbuRSJ65+ylxc6Tirz4qyXYiETnwsNYmisEhUTVgj8nUpaZ/VQvMb5+SqMi \nhzwd9pH6nVwDI43/Qit7mv1GlYpWNzBAQjIUUtVUZQxu23Qxoyf0+7qbhV6G8zus \nMNSrt8XvMgJujzkmli5L6HF7MT2n11OJA/tylYrNwrzO0qGVBynaWq1/Ot78szaM \ntr/UTvbd5SgRSrJO0B568oyG+52yJOZPd3DH1MfqoEu4vxUfpgxr/HaiOUf7jhnl \nHlE3GhfD6xYLE1DVbCmqzrnz4epcjc/5w0zd67HEJ0FTBxGGQvsExlvaA37vCKUZ \n4K9qsJYiUEcXZyd8AUYh4x1ypg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://login.ludwig.lub.lu.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universitetsbiblioteket vid Lunds universitets EZproxy"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lund University Library Proxy"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://identity.unife.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lugli"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:michele.lugli@unife.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michele"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ardizzoni"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:enrico.ardizzoni@unife.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Enrico"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:reti.sistemi@unife.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://identity.unife.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2010-03-05T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUDWEaqSaZUTmDi7c3RlBaYiGftv0wDQYJKoZIhvcNAQEF\nBQAwHDEaMBgGA1UEAxMRaWRlbnRpdHkudW5pZmUuaXQwHhcNMDkwNzI5MTEwNTIw\nWhcNMjkwNzI5MTEwNTIwWjAcMRowGAYDVQQDExFpZGVudGl0eS51bmlmZS5pdDCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIuX3iSXtW169zLcTcysXr9e\n25aIejzGKV1IDrJBbJq2uKe4nZ3GGxlqtGRSJafP1RtemUbJ6LU0hxkHvsa6aCfT\n4UcRWEADvcDLa/KGih65D1GkY7oKA3ByAS7e2QgpoaEYy5U8Qb6vu7/+bTl6oKbe\nqrtGQmPwexue4zRjNmq3LOyTSsaQzF/Z9j5STbm2uiwMZ0vErhvCg8eX+Lmaq3Sh\nRCan/C8kcaXrTQlxb0BDcORmXnod8C4ga7Rg4JIdncNTFji32bF0mKWS2rmXBK+4\nR1GHOh7oExCsGk2fUN5435A0Umg065UxeeUdgKnIykPCjSmMx8WgMPk5KI0cxUUC\nAwEAAaNpMGcwRgYDVR0RBD8wPYIRaWRlbnRpdHkudW5pZmUuaXSGKGh0dHBzOi8v\naWRlbnRpdHkudW5pZmUuaXQvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFCjBKR23\nA353XL6vQpwmLg5C301wMA0GCSqGSIb3DQEBBQUAA4IBAQB7g5t/5SuRdF+WPqnj\nIsmWerN+wALIsmFpq+AAqSSTA5a+9SXxczO/Ui6y+/zE714UiE0CCAeYmJztBDtA\nBwQx/dj8QgX80/++MIB+5obKRFRztpuwChGHAStxY4vNF9Lnc+urdi3hSMVn+rZS\n34ONTWpp+DkiXajfsNRaN4w1egn3cWFquIlQAHr21OcZCbDuCO6p7UVnkdM8unGV\nNBtU+t32f6cR3HVdjUqH3LCigvGsh/viXYXYg7QRoj3fNM93EAIwakh4784E6plK\nN1yMa0xze5ryRX4S7pHiaSQRiKNb8xIPgzOaaAQFTm8O9UcdF7xPuoWePXE1lvUR\nVgF8"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unife.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://identity.unife.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://identity.unife.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://identity.unife.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://identity.unife.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://identity.unife.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://identity.unife.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://identity.unife.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://identity.unife.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unife.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.unife.it/areainformatica/idem"
                  }
                ],
                "description": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti UniFe"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for UniFe users"
                  }
                ],
                "logo": [
                  {
                    "text": "https://identity.unife.it/idp/images/unife_logo_16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://identity.unife.it/idp/images/unife_logo_50x50.png",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "https://identity.unife.it/idp/images/unife_logo_80x80.png",
                    "height": "80",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://identity.unife.it/idp/images/unife_logo_320x240.png",
                    "height": "240",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "320"
                  }
                ],
                "display_name": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 di Ferrara"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Ferrara"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUDWEaqSaZUTmDi7c3RlBaYiGftv0wDQYJKoZIhvcNAQEF\nBQAwHDEaMBgGA1UEAxMRaWRlbnRpdHkudW5pZmUuaXQwHhcNMDkwNzI5MTEwNTIw\nWhcNMjkwNzI5MTEwNTIwWjAcMRowGAYDVQQDExFpZGVudGl0eS51bmlmZS5pdDCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIuX3iSXtW169zLcTcysXr9e\n25aIejzGKV1IDrJBbJq2uKe4nZ3GGxlqtGRSJafP1RtemUbJ6LU0hxkHvsa6aCfT\n4UcRWEADvcDLa/KGih65D1GkY7oKA3ByAS7e2QgpoaEYy5U8Qb6vu7/+bTl6oKbe\nqrtGQmPwexue4zRjNmq3LOyTSsaQzF/Z9j5STbm2uiwMZ0vErhvCg8eX+Lmaq3Sh\nRCan/C8kcaXrTQlxb0BDcORmXnod8C4ga7Rg4JIdncNTFji32bF0mKWS2rmXBK+4\nR1GHOh7oExCsGk2fUN5435A0Umg065UxeeUdgKnIykPCjSmMx8WgMPk5KI0cxUUC\nAwEAAaNpMGcwRgYDVR0RBD8wPYIRaWRlbnRpdHkudW5pZmUuaXSGKGh0dHBzOi8v\naWRlbnRpdHkudW5pZmUuaXQvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFCjBKR23\nA353XL6vQpwmLg5C301wMA0GCSqGSIb3DQEBBQUAA4IBAQB7g5t/5SuRdF+WPqnj\nIsmWerN+wALIsmFpq+AAqSSTA5a+9SXxczO/Ui6y+/zE714UiE0CCAeYmJztBDtA\nBwQx/dj8QgX80/++MIB+5obKRFRztpuwChGHAStxY4vNF9Lnc+urdi3hSMVn+rZS\n34ONTWpp+DkiXajfsNRaN4w1egn3cWFquIlQAHr21OcZCbDuCO6p7UVnkdM8unGV\nNBtU+t32f6cR3HVdjUqH3LCigvGsh/viXYXYg7QRoj3fNM93EAIwakh4784E6plK\nN1yMa0xze5ryRX4S7pHiaSQRiKNb8xIPgzOaaAQFTm8O9UcdF7xPuoWePXE1lvUR\nVgF8"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 di Ferrara"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Ferrara"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unife.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unife.it/unife-en"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli Studi di Ferrara"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Ferrara"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://birk.wayf.dk/birk.php/sso.eamv.dk/adfs/services/trust",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://birk.wayf.dk/birk.php/sso.eamv.dk/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2015-06-14T14:51:55Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/sso.eamv.dk/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eamv.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Erhvervsakademi MidtVest"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Erhvervsakademi MidtVest"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "eamv.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC1jCCAb4CAQcwDQYJKoZIhvcNAQELBQAwMTEvMC0GA1UEAwwmaHR0cDovL3Nz\nby5lYW12LmRrL2FkZnMvc2VydmljZXMvdHJ1c3QwHhcNMTUwMTAxMDAwMDAwWhcN\nMjUxMjMxMjM1OTU5WjAxMS8wLQYDVQQDDCZodHRwOi8vc3NvLmVhbXYuZGsvYWRm\ncy9zZXJ2aWNlcy90cnVzdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAMeIDApqEFO4jhn4gnWuA54SIILLdtH1Ah7cGkKx6MUJTmtLORYA2pW5zU8N+nQl\n0hmGs9eyYMlAyaJ08IY8gNAqj5uT5p/f4RQVL8j/7fmxIFfa9/6HUMe9lX2OzOea\nlJWOnsdn9ag9YHKRYEk7QA5WbMHnOVqqRLfonvr7DF6vB2m4TFWdhI13vdL4DJP8\nRn61cA77qVDwUv9gyUmdSRJpKotIcXLTUPaoE2ZhHAGkJLr91RnLGLS3mPyCEpQP\ngEc5lVq+frknrZwl1eI5wxHJQAinnsZdCsvrcq2uMhxd12r4JnJnm3fsR1Q4jPja\nOgVzLvcwU6e3KeUoS87DUEkCAwEAATANBgkqhkiG9w0BAQsFAAOCAQEAVJMwXUSY\nxDcWQrwEHt6FEjDYOtmquq/n711CnmPRBBJwLOpUAEs2iMU0tnYqjAbsMej+UwgC\n5JrFuILzOIUw+cEkOmI+LRvz5rmR4eNfqJAB4jeWJ2l9h8kZmR9p2vhz4lJRyOIH\nJpojtOgOdcX6XoIRHx8LFOKqpdiOnrY7R8g+3n71fPMgmFbcq1cLhJi9q0UfYrOH\n2Zgryg2mK2EaqXR9gA6IQEqh/CQOCqKJLty+8qlJa+tNvf/14I2ks7xLDK2cJt3S\nLn/ONijLVQn5Rye1eqh1FviwAs2lc0HV5MQpKMd6u/Jfvvg3cGBMhmXoO95IsUd1\nmZA0QGYfa1EL1Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Erhvervsakademi MidtVest"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Erhvervsakademi MidtVest"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://eamv.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://eamv.dk"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Erhvervsakademi MidtVest"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Erhvervsakademi MidtVest"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.cirencester.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Forsdike"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:matt.forsdike@cirencester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matt"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Forsdike"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:matt.forsdike@cirencester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matt"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cirencester.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-07-22T15:23:18Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.cirencester.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cirencester.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cirencester.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTjCCAjagAwIBAgIIRKejSpcxL9UwDQYJKoZIhvcNAQEFBQAwPjEcMBoGA1UE\n\t\t\t\t\t\tCgwTQ2lyZW5jZXN0ZXIgQ29sbGVnZTEeMBwGA1UEAwwVaWRwLmNpcmVuY2VzdGVy\n\t\t\t\t\t\tLmFjLnVrMB4XDTE0MDcyMTA5NTIwNFoXDTI0MDcyMTA5NTIwNFowPjEcMBoGA1UE\n\t\t\t\t\t\tCgwTQ2lyZW5jZXN0ZXIgQ29sbGVnZTEeMBwGA1UEAwwVaWRwLmNpcmVuY2VzdGVy\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqBjd6qPpatXK\n\t\t\t\t\t\trzW4mAym0qYPqX4p7ZNX5LynuSpZupD+p1apZmRJDIPLQZUfIV5k6b0hvu+jPFCo\n\t\t\t\t\t\tChQC74PBjEh+WdWDoG/l3Ab1w81GA5MjKIi3kvd98eAuBRdDp7kTy8xU8HeMZ/Jb\n\t\t\t\t\t\tgjgHgkvJIOhA7KAEuEn3iz8DF+sAhtzNYO/2YXlULo+qdqSPKu/exsddEiSOlrxv\n\t\t\t\t\t\tB2ocRmcxjstHHWbl709CoxP3Uf6tmc8uQKTnqNF/abYQBofx1rEk2DIT6x+Qnlj9\n\t\t\t\t\t\tMBpxme2BlRY2QFYsWQBgaMgUiaxHXFYmBAA2B4+JbJIMbXx+OLHguAyv8srAb0TV\n\t\t\t\t\t\tnHLOWLgOxQIDAQABo1AwTjAdBgNVHQ4EFgQU2MzRSQipMAAPr5CCC2qd8JujL9Uw\n\t\t\t\t\t\tHwYDVR0jBBgwFoAU2MzRSQipMAAPr5CCC2qd8JujL9UwDAYDVR0TBAUwAwEB/zAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEALLzd9/KWXmLO2bLM0bxMC3/xmGxMJFbcS3F+Bf/u\n\t\t\t\t\t\tXRFDiZDWvOa4bS01h95kGcR1geN2Ag0414B1nF8jHvQ+px7+bjzJgakGeUtgbo2W\n\t\t\t\t\t\tkyY++i1YitrgSbBp5m50a1kBh/gRhBsFx9qU14XEft11f1Eht5Q2L52B6S89HB8I\n\t\t\t\t\t\tSzbB/2SijZht33CJYqDVG9SKLhoVI27MCRVNUlmXFFvUXi05KFDbmtadPkSAR5R0\n\t\t\t\t\t\txXole5MprQ9wmqmmf5lMO/Q/lDJKgS05SPkfCH6qXTbWr7UTruSVJGbg5ZQxyMak\n\t\t\t\t\t\tDy5B9h6OWZR1PUUJlALjWmBQaZKFTBhHgACu0br2JUgSqw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTjCCAjagAwIBAgIIRKejSpcxL9UwDQYJKoZIhvcNAQEFBQAwPjEcMBoGA1UE\n\t\t\t\t\t\tCgwTQ2lyZW5jZXN0ZXIgQ29sbGVnZTEeMBwGA1UEAwwVaWRwLmNpcmVuY2VzdGVy\n\t\t\t\t\t\tLmFjLnVrMB4XDTE0MDcyMTA5NTIwNFoXDTI0MDcyMTA5NTIwNFowPjEcMBoGA1UE\n\t\t\t\t\t\tCgwTQ2lyZW5jZXN0ZXIgQ29sbGVnZTEeMBwGA1UEAwwVaWRwLmNpcmVuY2VzdGVy\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqBjd6qPpatXK\n\t\t\t\t\t\trzW4mAym0qYPqX4p7ZNX5LynuSpZupD+p1apZmRJDIPLQZUfIV5k6b0hvu+jPFCo\n\t\t\t\t\t\tChQC74PBjEh+WdWDoG/l3Ab1w81GA5MjKIi3kvd98eAuBRdDp7kTy8xU8HeMZ/Jb\n\t\t\t\t\t\tgjgHgkvJIOhA7KAEuEn3iz8DF+sAhtzNYO/2YXlULo+qdqSPKu/exsddEiSOlrxv\n\t\t\t\t\t\tB2ocRmcxjstHHWbl709CoxP3Uf6tmc8uQKTnqNF/abYQBofx1rEk2DIT6x+Qnlj9\n\t\t\t\t\t\tMBpxme2BlRY2QFYsWQBgaMgUiaxHXFYmBAA2B4+JbJIMbXx+OLHguAyv8srAb0TV\n\t\t\t\t\t\tnHLOWLgOxQIDAQABo1AwTjAdBgNVHQ4EFgQU2MzRSQipMAAPr5CCC2qd8JujL9Uw\n\t\t\t\t\t\tHwYDVR0jBBgwFoAU2MzRSQipMAAPr5CCC2qd8JujL9UwDAYDVR0TBAUwAwEB/zAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEALLzd9/KWXmLO2bLM0bxMC3/xmGxMJFbcS3F+Bf/u\n\t\t\t\t\t\tXRFDiZDWvOa4bS01h95kGcR1geN2Ag0414B1nF8jHvQ+px7+bjzJgakGeUtgbo2W\n\t\t\t\t\t\tkyY++i1YitrgSbBp5m50a1kBh/gRhBsFx9qU14XEft11f1Eht5Q2L52B6S89HB8I\n\t\t\t\t\t\tSzbB/2SijZht33CJYqDVG9SKLhoVI27MCRVNUlmXFFvUXi05KFDbmtadPkSAR5R0\n\t\t\t\t\t\txXole5MprQ9wmqmmf5lMO/Q/lDJKgS05SPkfCH6qXTbWr7UTruSVJGbg5ZQxyMak\n\t\t\t\t\t\tDy5B9h6OWZR1PUUJlALjWmBQaZKFTBhHgACu0br2JUgSqw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cirencester Sixth Form College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cirencester.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cirencester College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp2.gru.edu:8443/nidp/saml2/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dhowser@gru.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Doogie Howser"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dblair@gru.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Danny Blair"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp2.gru.edu:8443/nidp/saml2/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.gru.edu:8443/nidp/saml2/slo",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2.gru.edu:8443/nidp/saml2/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.gru.edu:8443/nidp/saml2/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.gru.edu:8443/nidp/saml2/soap",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.gru.edu:8443/nidp/saml2/spsoap",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gru.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Georgia Regents University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGpDCCBYygAwIBAgIQDnlMzdtA7AtWaWmu4CUqHzANBgkqhkiG9w0BAQUFADBmMQswCQYDVQQG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"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFKDCCBBCgAwIBAgIkAhwR/6b9LHsJhchf/U62SIos3yjxeaQepg3W+ThWAgIWC6J5MA0GCSqG\nSIb3DQEBBQUAMDQxGjAYBgNVBAsTEU9yZ2FuaXphdGlvbmFsIENBMRYwFAYDVQQKFA1uYW1faWRz\nM190cmVlMB4XDTE0MDcyMDE0NDg1MFoXDTI0MDcyMDE0NDg1MFowQDEVMBMGA1UEAxMMdGVzdC1z\naWduaW5nMRYwFAYDVQQLEw1hY2Nlc3NNYW5hZ2VyMQ8wDQYDVQQKEwZub3ZlbGwwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDHCv4366UBN985Gd6N8kvQYAcGudsyIU028OQi4snM+LCS\nZHY6TqW/OYxDQ05zBpJR1EIxBWHV7FDV/PKPpGbc/pb4j/L88dU8T7b7o0+aTIjdormnnCkIz/jM\nhpazu/GD21RtEL7/DY1t/DKholPOTLMJ8eVQsjFuHFwJWWsuu7pt2e3/NwBcz4wrZVDz/7ugCd0g\nD7U+ogTiI9SSEfNGNYip9oTRDQmL/dEPDLuUgPTq0cRCluIOXI/JwEm0GC7h9KdhEEvn+5EXRkv8\nYgn2Hk71S8TsVW+VXJPUtZEj+gOd+GaEpA7tItl08Y9I96H11qqHdLKl5aPDnwp/3sf1AgMBAAGj\nggIUMIICEDAdBgNVHQ4EFgQU1upj1Ecop5UfpwsitEW/C8wK8HowHwYDVR0jBBgwFoAUzcbO+8jk\nGKaWpNswReA8nDxE07owggHMBgtghkgBhvg3AQkEAQSCAbswggG3BAIBAAEB/xMdTm92ZWxsIFNl\nY3VyaXR5IEF0dHJpYnV0ZSh0bSkWQ2h0dHA6Ly9kZXZlbG9wZXIubm92ZWxsLmNvbS9yZXBvc2l0\nb3J5L2F0dHJpYnV0ZXMvY2VydGF0dHJzX3YxMC5odG0wggFIoBoBAQAwCDAGAgEBAgFGMAgwBgIB\nAQIBCgIBaaEaAQEAMAgwBgIBAQIBADAIMAYCAQECAQACAQCiBgIBFwEB/6OCAQSgWAIBAgICAP8C\nAQADDQCAAAAAAAAAAAAAAAADCQCAAAAAAAAAADAYMBACAQACCH//////////AQEAAgQG8N9IMBgw\nEAIBAAIIf/////////8BAQACBAbw30ihWAIBAgICAP8CAQADDQBAAAAAAAAAAAAAAAADCQBAAAAA\nAAAAADAYMBACAQACCH//////////AQEAAgQR/6b9MBgwEAIBAAIIf/////////8BAQACBBH/pv2i\nTjBMAgECAgEAAgIA/wMNAIAAAAAAAAAAAAAAAAMJAIAAAAAAAAAAMBIwEAIBAAIIf/////////8B\nAQAwEjAQAgEAAgh//////////wEBADANBgkqhkiG9w0BAQUFAAOCAQEAdHQUFXUQmzNThUMHD4la\negh/h3pVHZtzOTVBZTf3AveGTiQknXhJBcipXR3CMZeP2PtTSVMl3/khKuASCJ8usFN9l/AOYOHl\nQDrouIzAFHrZodzzDS0ON4BXoh4guQgDvMCM+8dsBpcs37dnVzNRiRlkvomHjX5PyBFTGGN6beRc\noJwXy2BWfVrnVxbKi0TwLFy50Dl9yZZiXBwPTS69p3eEFHr+/06bdOce9Udvr7wszrppZ6TKYZ5c\npDORgv1sOCLPJx9QBBpvZGcqkgCgr7aOmUhDGQKjkY0nZccr/KZKNCsvK365gVXzm1U0rhBXYgfH\n/HVKXx18VMnABE/LWQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Georgia Regents University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gru.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Augusta University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.treloar.org.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Overt Software"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Overt Software"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.treloar.org.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-02-13T12:44:41Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjACCQCcvr4PTH7CrzANBgkqhkiG9w0BAQUFADBmMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjESMBAGA1UECAwJSGFtcHNoaXJlMQ4wDAYDVQQHDAVBbHRvbjEWMBQGA1UECgwN\n\t\t\t\t\t\tVHJlbG9hciBUcnVzdDEbMBkGA1UEAwwSaWRwLnRyZWxvYXIub3JnLnVrMB4XDTEz\n\t\t\t\t\t\tMDIxMjA4MzcyNFoXDTMzMDIwNzA4MzcyNFowZjELMAkGA1UEBhMCR0IxEjAQBgNV\n\t\t\t\t\t\tBAgMCUhhbXBzaGlyZTEOMAwGA1UEBwwFQWx0b24xFjAUBgNVBAoMDVRyZWxvYXIg\n\t\t\t\t\t\tVHJ1c3QxGzAZBgNVBAMMEmlkcC50cmVsb2FyLm9yZy51azCCASIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEBBQADggEPADCCAQoCggEBALqJjfQAve2KE7DDgIOPkvSo8sNdrb3njZx1K2pk\n\t\t\t\t\t\tNQCoeo9rWaLMQMpzXBCUiSb3De5bDTgob5PL8HlNWNg3bDoD1s27MTaX7PVuy7gi\n\t\t\t\t\t\tuqrybbLftyaQSnCWuR7WNBQ4LuTMQ8ZaeS3bF1T5Gm3Pi969w2cmEhZOtxVzFELV\n\t\t\t\t\t\tNauQggXYZnZ8o15XvG0xCsim9S7U6wt9/1sndhATdkZ+H4KXfYsrWnYtiluMVO9T\n\t\t\t\t\t\tmzJUh7ZjLJqwaaWFaKJZE35tCgDEuNWdfOlw+2QbxCyGHBxH9mxEN1hEQej3ik/X\n\t\t\t\t\t\tmP0j9a1q0OZQCwaB5FpNp4wbOV48s7dOzRDVAU1uHLvxvh8CAwEAATANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEATC0F3HDRn0eYLwJHJfJIx7nU6VM7Ve+kkffRYR4LTB9JAZBb\n\t\t\t\t\t\tfMPjWhI2sHJRfgkLHthcO8rcfe3p5Zd3xIg6DZtQHm97rr5+iBAakzvhkQHD9s+A\n\t\t\t\t\t\tlUboeBwa9eEKu9UnpW4MAouDBy7XggaXNDj8n43s8RNW2awutCD57x8uyXlh+QnM\n\t\t\t\t\t\twr0C6lZjSkH22zeM1qgnYwxojYmFhuTyDDjTk9ue6wtp6pQO0M7/fRZyLAqD1JYY\n\t\t\t\t\t\tUqFi0xw+GHyhgvqkcJ+dCRyi3BBD12URWsVCL4Yeyl6BeD7prS6Lh+nVzWX812yY\n\t\t\t\t\t\t0zSsNXVMidAIgjgaNV0kJgK3D9QF2IVjRA0Atw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "treloar.org.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.treloar.org.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.treloar.org.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.treloar.org.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.treloar.org.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.treloar.org.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.treloar.org.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.treloar.org.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.treloar.org.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "treloar.org.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjACCQCcvr4PTH7CrzANBgkqhkiG9w0BAQUFADBmMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjESMBAGA1UECAwJSGFtcHNoaXJlMQ4wDAYDVQQHDAVBbHRvbjEWMBQGA1UECgwN\n\t\t\t\t\t\tVHJlbG9hciBUcnVzdDEbMBkGA1UEAwwSaWRwLnRyZWxvYXIub3JnLnVrMB4XDTEz\n\t\t\t\t\t\tMDIxMjA4MzcyNFoXDTMzMDIwNzA4MzcyNFowZjELMAkGA1UEBhMCR0IxEjAQBgNV\n\t\t\t\t\t\tBAgMCUhhbXBzaGlyZTEOMAwGA1UEBwwFQWx0b24xFjAUBgNVBAoMDVRyZWxvYXIg\n\t\t\t\t\t\tVHJ1c3QxGzAZBgNVBAMMEmlkcC50cmVsb2FyLm9yZy51azCCASIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEBBQADggEPADCCAQoCggEBALqJjfQAve2KE7DDgIOPkvSo8sNdrb3njZx1K2pk\n\t\t\t\t\t\tNQCoeo9rWaLMQMpzXBCUiSb3De5bDTgob5PL8HlNWNg3bDoD1s27MTaX7PVuy7gi\n\t\t\t\t\t\tuqrybbLftyaQSnCWuR7WNBQ4LuTMQ8ZaeS3bF1T5Gm3Pi969w2cmEhZOtxVzFELV\n\t\t\t\t\t\tNauQggXYZnZ8o15XvG0xCsim9S7U6wt9/1sndhATdkZ+H4KXfYsrWnYtiluMVO9T\n\t\t\t\t\t\tmzJUh7ZjLJqwaaWFaKJZE35tCgDEuNWdfOlw+2QbxCyGHBxH9mxEN1hEQej3ik/X\n\t\t\t\t\t\tmP0j9a1q0OZQCwaB5FpNp4wbOV48s7dOzRDVAU1uHLvxvh8CAwEAATANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEATC0F3HDRn0eYLwJHJfJIx7nU6VM7Ve+kkffRYR4LTB9JAZBb\n\t\t\t\t\t\tfMPjWhI2sHJRfgkLHthcO8rcfe3p5Zd3xIg6DZtQHm97rr5+iBAakzvhkQHD9s+A\n\t\t\t\t\t\tlUboeBwa9eEKu9UnpW4MAouDBy7XggaXNDj8n43s8RNW2awutCD57x8uyXlh+QnM\n\t\t\t\t\t\twr0C6lZjSkH22zeM1qgnYwxojYmFhuTyDDjTk9ue6wtp6pQO0M7/fRZyLAqD1JYY\n\t\t\t\t\t\tUqFi0xw+GHyhgvqkcJ+dCRyi3BBD12URWsVCL4Yeyl6BeD7prS6Lh+nVzWX812yY\n\t\t\t\t\t\t0zSsNXVMidAIgjgaNV0kJgK3D9QF2IVjRA0Atw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Treloar's"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.treloar.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Treloar Trust"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth2sp.tf.semcs.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@tandfonline.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TandF Online Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Golding"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:eproductsopssupport@informa.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Joanne"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth2sp.tf.semcs.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-08-23T15:07:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Semantico Limited: Taylor and Francis"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.taylorandfrancisgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Semantico Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.tf.semcs.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.tf.semcs.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.tf.semcs.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.tf.semcs.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.tf.semcs.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth2sp.tf.semcs.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDzTCCAzagAwIBAgIDEAAKMA0GCSqGSIb3DQEBBAUAMG8xCzAJBgNVBAYTAlVL\n\t\t\t\t\t\tMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIwEAYDVQQKEwlz\n\t\t\t\t\t\tZW1hbnRpY28xKDAmBgNVBAMTH3NlbWFudGljbyBDZXJ0aWZpY2F0ZSBBdXRob3Jp\n\t\t\t\t\t\tdHkwHhcNMTIwMjE2MTI1MjA3WhcNMTcwMjE0MTI1MjA3WjBqMQswCQYDVQQGEwJV\n\t\t\t\t\t\tSzEPMA0GA1UECBMGU3Vzc2V4MREwDwYDVQQHEwhCcmlnaHRvbjESMBAGA1UEChMJ\n\t\t\t\t\t\tc2VtYW50aWNvMSMwIQYDVQQDExpzaGliYm9sZXRoMnNwLnRmLnNlbWNzLm5ldDCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALlHB2zAGe9ctjQQJMRQ5EGr\n\t\t\t\t\t\tjbe3RucMOl2TTv2XxD3QRkPltjR/loYX9+Elz+YXVHqUmJmkhK/7K3sbM+8dPtwr\n\t\t\t\t\t\tkMbWJ7I6peKmOF0fFx5KY0hWAiXC+oPpBBBItpNETnNGQUJPsTh7EeK6Qh8a5oAe\n\t\t\t\t\t\t7qp2i3PdH2kKb54NTeUjmeXDCq3sVo9KScjbcQx2FHdVXWX6VzO4gLQ+GoPP9ZK1\n\t\t\t\t\t\tU3hQ7OMW3d3B2WQFQZB9awkqWpWcsWPr+xYY7noxvu5+raYUgy+ks4usWM8va+bU\n\t\t\t\t\t\tMRLDxCfY0lV/rpxEvrq30gi1GmDNt/XvZXOqS6VL8m1vPhzchscavOZ/CfW2+ykC\n\t\t\t\t\t\tAwEAAaOB9zCB9DAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdl\n\t\t\t\t\t\tbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQU98wmnF2Ul7kw8GGRolQKie7T\n\t\t\t\t\t\teKcwgZkGA1UdIwSBkTCBjoAUAhtOmjfwjWpoREbGHUT+urJevjmhc6RxMG8xCzAJ\n\t\t\t\t\t\tBgNVBAYTAlVLMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIw\n\t\t\t\t\t\tEAYDVQQKEwlzZW1hbnRpY28xKDAmBgNVBAMTH3NlbWFudGljbyBDZXJ0aWZpY2F0\n\t\t\t\t\t\tZSBBdXRob3JpdHmCAQAwDQYJKoZIhvcNAQEEBQADgYEAOjfVqx8vLDf9nQv1XKXK\n\t\t\t\t\t\tl+HFoV80S0R0abpO7IEELQENa8GWPIJyVHHVjESHXYDF63/SgnHJXAMl1afR7t8R\n\t\t\t\t\t\tjpfkkHBvE7wePMvargxjK/IzU8Q627GESWcLk4Z2oGcYo4DDQLJMim3iklcl2PJt\n\t\t\t\t\t\tv8IZHuUqZxTbUnnNWkrb8Kc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDzTCCAzagAwIBAgIDEAAKMA0GCSqGSIb3DQEBBAUAMG8xCzAJBgNVBAYTAlVL\n\t\t\t\t\t\tMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIwEAYDVQQKEwlz\n\t\t\t\t\t\tZW1hbnRpY28xKDAmBgNVBAMTH3NlbWFudGljbyBDZXJ0aWZpY2F0ZSBBdXRob3Jp\n\t\t\t\t\t\tdHkwHhcNMTIwMjE2MTI1MjA3WhcNMTcwMjE0MTI1MjA3WjBqMQswCQYDVQQGEwJV\n\t\t\t\t\t\tSzEPMA0GA1UECBMGU3Vzc2V4MREwDwYDVQQHEwhCcmlnaHRvbjESMBAGA1UEChMJ\n\t\t\t\t\t\tc2VtYW50aWNvMSMwIQYDVQQDExpzaGliYm9sZXRoMnNwLnRmLnNlbWNzLm5ldDCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALlHB2zAGe9ctjQQJMRQ5EGr\n\t\t\t\t\t\tjbe3RucMOl2TTv2XxD3QRkPltjR/loYX9+Elz+YXVHqUmJmkhK/7K3sbM+8dPtwr\n\t\t\t\t\t\tkMbWJ7I6peKmOF0fFx5KY0hWAiXC+oPpBBBItpNETnNGQUJPsTh7EeK6Qh8a5oAe\n\t\t\t\t\t\t7qp2i3PdH2kKb54NTeUjmeXDCq3sVo9KScjbcQx2FHdVXWX6VzO4gLQ+GoPP9ZK1\n\t\t\t\t\t\tU3hQ7OMW3d3B2WQFQZB9awkqWpWcsWPr+xYY7noxvu5+raYUgy+ks4usWM8va+bU\n\t\t\t\t\t\tMRLDxCfY0lV/rpxEvrq30gi1GmDNt/XvZXOqS6VL8m1vPhzchscavOZ/CfW2+ykC\n\t\t\t\t\t\tAwEAAaOB9zCB9DAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdl\n\t\t\t\t\t\tbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQU98wmnF2Ul7kw8GGRolQKie7T\n\t\t\t\t\t\teKcwgZkGA1UdIwSBkTCBjoAUAhtOmjfwjWpoREbGHUT+urJevjmhc6RxMG8xCzAJ\n\t\t\t\t\t\tBgNVBAYTAlVLMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIw\n\t\t\t\t\t\tEAYDVQQKEwlzZW1hbnRpY28xKDAmBgNVBAMTH3NlbWFudGljbyBDZXJ0aWZpY2F0\n\t\t\t\t\t\tZSBBdXRob3JpdHmCAQAwDQYJKoZIhvcNAQEEBQADgYEAOjfVqx8vLDf9nQv1XKXK\n\t\t\t\t\t\tl+HFoV80S0R0abpO7IEELQENa8GWPIJyVHHVjESHXYDF63/SgnHJXAMl1afR7t8R\n\t\t\t\t\t\tjpfkkHBvE7wePMvargxjK/IzU8Q627GESWcLk4Z2oGcYo4DDQLJMim3iklcl2PJt\n\t\t\t\t\t\tv8IZHuUqZxTbUnnNWkrb8Kc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.tf.semcs.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.tf.semcs.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.tf.semcs.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.tf.semcs.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.tf.semcs.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth2sp.tf.semcs.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.tf.semcs.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth2sp.tf.semcs.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth2sp.tf.semcs.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth2sp.tf.semcs.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://registry.icer.niaid.nih.gov/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-support@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Technical Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-support@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-support@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Technical Support"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-admin@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Administrative Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://registry.icer.niaid.nih.gov/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "National Institutes of Health"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nih.gov/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National Institutes of Health"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://registration.scienceforum.sc/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://registration.scienceforum.sc/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://registration.icer.niaid.nih.gov/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://scienceforum.sc/registry.html"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "A collaboration management platform designed for virtual organizations."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://scienceforum.sc/privacy.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NIAID ICER Collaboration Manager"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFdzCCA1+gAwIBAgIJAMDh5yvo5rhOMA0GCSqGSIb3DQEBDQUAMFIxJDAiBgNV\nBAMMG3JlZ2lzdHJ5LmljZXIubmlhaWQubmloLmdvdjEqMCgGCSqGSIb3DQEJARYb\naWNlci12cm8tYWRtaW5AbGlzdC5uaWguZ292MB4XDTE2MDEwODE4MjY1MFoXDTI2\nMDEwNTE4MjY1MFowUjEkMCIGA1UEAwwbcmVnaXN0cnkuaWNlci5uaWFpZC5uaWgu\nZ292MSowKAYJKoZIhvcNAQkBFhtpY2VyLXZyby1hZG1pbkBsaXN0Lm5paC5nb3Yw\nggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQDGy167DCe1JrPybgf4uRuZ\nKYtRiAitvBCm7Fm78cDRQuNnqRXLzXBUlYdTXSBEa3hNoswJBaayFjhOqw0yt/B+\noBAfFfe9s4i3zU0J7Fe0hbUxtmpIMGhbw0Q20KCo60ryA7B9z+1fwje5Yg44TIwN\nR/P26ddEf2W4JuWsx78IK8dzwGPVw/8AQP2R3QZ7/S3EqrWQZq8B3Q/y/DkW+HFm\nWVys4IF72uaMl9WDZ/wcV3gsS8drxTrXwW01sXGKZrp9F+uucKltap24xcJMRLE4\nuQy9PLFA9jIBav0GBnlhClVzilZKghwbjFSHMrx611MkBaVq94NJhOnmxF/wHOpn\n71m90kjwSXwGGZgulYX6SVKVyqZSp9eNGbr4R//cwUqG+yrzG1U99FrA5HLeIJur\nQMS9R2IRsURg6ebH5n2utHLLPw2kheOcTYm3L8lg3Mi+gxudZFTrd+RO0mZLteQ6\n6mBeSmqEGGm+vboBOKOx+Nh43tToMpZUh5dIPscPfLBP1IvmFnW8TkffWZLvLDVT\ndBZgsunafHlqAvmQMk5Z8V68BNd2W08Fkz+YhRaJAIMcx789csRopjDcp10YMbgR\nk4pB5eyPqffxNg+1aJuaM0KL0TUTMdXOXZWcC/LTCxaOZb5zxRtYtgikVb8cvcr+\nX89C6W7RXqr5Riw8HnQgQQIDAQABo1AwTjAdBgNVHQ4EFgQUhEXi0rmuN6WKWRlb\nEf/yeu1Vt60wHwYDVR0jBBgwFoAUhEXi0rmuN6WKWRlbEf/yeu1Vt60wDAYDVR0T\nBAUwAwEB/zANBgkqhkiG9w0BAQ0FAAOCAgEAcJgy2qTzx0GTIrx7vEs5ZY4+thtx\n3eKWiucQpbGHcVCe3rSwaNSRvyz16HQDg7RB4hdXGz1lj+jvcqhTQXMTYslGwAtl\nv4JwIZSv/cwybjMG5AO42HmNwRCUTt5XbF5fyYQnjH/2yfPul21q0VQR88v2BKOq\nIDBBL7Z5TWl17S19kV/EgJL4Mn7z35q9bLs8ioehCAl/D1lScKtgGlcGTJwHKsRV\nHQmQgU8aLahZMnpKzWijn+sodE9S+zP2NSKSP/EiaQt3CMtm2EbDOGBSNHF8Xgu4\nOVVd/2Zrle5tXxb6MZ55p941i/JZRV8kzPipGVZ7SuBYGLeBe5idIOvOUYL85EfW\n/CgesuUNtCzcWcEEQITgp/398QxaCV8bACJnSHFSUZqqrzDEy7ZVcZkYMQnbAnuT\nhkj95vcLdj4Ff76XolOXRjrWGQilVs5Cc3PQhUdmEnCEBMlGmtXH6qGGxmQw3f1t\nRbxwYaBumkQHhLB6kcj0qs+UY0rjnSSb46dooVv89uvdU5NskeRrzUPX6PHF8ZnN\nVUdNkk3QJpJZT0l8ZWZ81HQxprOvEIlWpf6IJvTpP5FhcSKnr7jTQZQIy/VGj0rF\nb2SeLnJHEgFeFqyTlQabwARTqLUDCozkEmnV9fDIYJ1HjRy0IqwHiC35kkNHQdC6\nVLgD+AE4OEIwN+k="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://registration.scienceforum.sc/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://registration.scienceforum.sc/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://registration.scienceforum.sc/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://registration.scienceforum.sc/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "NIAID ICER Collaboration Manager"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "A collaboration management platform designed for virtual organizations."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://its-pd0001.ad.umu.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://its-pd0001.ad.umu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Utveckling av fr\u00e4mst Wisum, Servicedesk och Sakai"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Development of Wisum, Servicedesk and Sakai"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Utvecklarmaskin f\u00f6r Tommy Larsson, ITS, Ume\u00e5 universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Development workstate for Tommy Larss, ITS, Ume\u00e5 University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/KTH",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/UMU",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/ADFSTEST",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "its-pd0001.ad.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID+zCCAuOgAwIBAgIJAKPbW1ypIusOMA0GCSqGSIb3DQEBBQUAMIGTMQswCQYD\nVQQGEwJTRTEVMBMGA1UECAwMVmFzdGVyYm90dGVuMQ0wCwYDVQQHDARVbWVhMQww\nCgYDVQQKDANJVFMxDDAKBgNVBAsMA0lUUzEdMBsGA1UEAwwUaXRzLXBkMDAwMS5h\nZC51bXUuc2UxIzAhBgkqhkiG9w0BCQEWFHRvbW15LmxhcnNzb25AdW11LnNlMB4X\nDTE0MDMxODE0MzExNFoXDTE3MDEyOTE0MzExNFowgZMxCzAJBgNVBAYTAlNFMRUw\nEwYDVQQIDAxWYXN0ZXJib3R0ZW4xDTALBgNVBAcMBFVtZWExDDAKBgNVBAoMA0lU\nUzEMMAoGA1UECwwDSVRTMR0wGwYDVQQDDBRpdHMtcGQwMDAxLmFkLnVtdS5zZTEj\nMCEGCSqGSIb3DQEJARYUdG9tbXkubGFyc3NvbkB1bXUuc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDiw8RQIeAq8SJUObzI3Bu9Dn8bRRXtJu9MGuvJ\naZ/wM1X8vQ5Fk0WS90H/KYLCccRQGBH1VFMaS4eisNCVYNEMqv7Ru0H+SeAb5FbK\nUdmRcEPrTRIRVXX4TsxOhNKdvayKNJAqbItl/hnkBewDlWtbRjXXMJ3lxKNqjwYy\n7OSaYHKnHNer5CDf7c0vOcgCe6UlcGNr6WaJFPLJCw1PmRssGcNqr0STGYjDKK28\nlhX2iNwi6EdXfOpeUiZAxfVv8PBHDd7P2TVKQCbb9dV8goJtGvNE5rfWozWu5vfC\nj+vnXPm1C5b0FH7JswwJ4pABFJOi8GACnzI3FRHNkFYsciEBAgMBAAGjUDBOMB0G\nA1UdDgQWBBSuMS+XaurelGEYjr4KGqHRcX5zqTAfBgNVHSMEGDAWgBSuMS+Xaure\nlGEYjr4KGqHRcX5zqTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAh\n8LjMlEsd8rW/QY/Ct4idR/xkpqr9ZL77I2dP33Rf7KWmT0wA19XYQ0oQjQ1i/PG1\nrbAz5FzPwRhwnFKVf1qSnShXTpnIbVhSlEle6koZ0at3kzpJfRYmbnJHqSfuKbQw\nlxLc1UntmTXp8mDEH9UgOm49+VLfzdXrUwIV33yL+/z9uKqM1/moNrFo4kAD7NbZ\nWC/LBix0rbTW+p4pO7yGKV211XfQPfb+bGYfwiMji1um1jdlQCLHJexkMssCvNwv\nKYxBkgitKMxkEQUyT7VDiNBq6Pk32mH71aw5ApIdnv0wrNi4JDA/v5/wTbiFJty+\n42KAUCmS/mctLCZKYuA2"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=tommy.larsson@umu.se,CN=its-pd0001.ad.umu.se,OU=ITS,O=ITS,L=Umea,ST=Vasterbotten,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://its-pd0001.ad.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://grouper-test.its.uu.se/shibboleth",
    {
      "entity_id": "https://grouper-test.its.uu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://grouper-test.its.uu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://grouper-test.its.uu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://grouper-test.its.uu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://grouper-test.its.uu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://grouper-test.its.uu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://grouper-test.its.uu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Uppsala universitets IT-avdelnings interna Grouper f\u00f6r test"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The internal test Grouper for the IT Department at Uppsala University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UU TEST GROUPER"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UU TEST GROUPER"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "lagopus.its.uu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+jCCAeKgAwIBAgIJAJwLNDNAvdwVMA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\nBAMTEWxhZ29wdXMuaXRzLnV1LnNlMB4XDTEyMDIyMjExMTgwNFoXDTIyMDIxOTEx\nMTgwNFowHDEaMBgGA1UEAxMRbGFnb3B1cy5pdHMudXUuc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDIc2xP8hCNliluyW/3kFHw8/EYMmGu4FvKFbCh\n33+QDDdZWQIDyZUo/GIw/DdRdkDaRaQ2JgF1zofooPlkYrqd5cBaoxc+oEet1MB+\nJ70hvt+83IuzVdp4VNxAiGy9L5aAfnXdsYV2AHZisoHKyeAX2XNlUC4VA9dKBWJC\nO2dUjDCxZ52R6E8P0CCZ5zKUA6i/nVJzpjklaQDT67Fyb0p14Aqzw4092ykUXbys\nKOFZ11QmuzTN0r3+jTsUHICakgsSyUNTnwQKNfE8TAHj+WPFhfzTKMcSWEpYI7Rj\nFfkNFSMem7oV26V7RuE3KoXTtrCXlFBzt3014mQWEb5+ve7hAgMBAAGjPzA9MBwG\nA1UdEQQVMBOCEWxhZ29wdXMuaXRzLnV1LnNlMB0GA1UdDgQWBBSzeuO1UGd9noyM\nfwfJ93JJacVEaTANBgkqhkiG9w0BAQUFAAOCAQEAWhy3C+EjI2SqeftECTKBZb1D\nC6DInq/e0nB9Y9cvKHxzZdX9TKDcfozjBw91B+1GhEMZIuIPS8fPMpwLc3OOX0lf\nKS/zEjUbl47rWlpYMApXopQGR718vuOeqFh25s6goFD4axlS4Be1YHr66JCTuKs6\n6XqCqzPvKgI6DWqu6Qi0aLBuZUuZGfotLRBLPQtjzWiDsBzRLNa89majbg7drwgj\noQFShIE1qtNWMZ7gYnXyPXDuE8ru8W2i/NrytzLHJN/NzEOBid4VzRHG+XAO4+bK\nJkes+PA+V+YNBFaZc6S+0YsiqsedpDewqW0HB/SzVIgIiiBRCu/4lfR9eqWbVA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=lagopus.its.uu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://grouper-test.its.uu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://grouper-test.its.uu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://grouper-test.its.uu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://grouper-test.its.uu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://identity.mdh.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 21 101499"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Peter Falck"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:peter.falck@mdh.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "M\u00e4lardalen University"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 21 101499"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "MDH Drift"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:drift.ita@mdh.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "M\u00e4lardalen University"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 16 101550"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk MDH"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@mdh.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "M\u00e4lardalen University"
          }
        }
      ],
      "entity_id": "https://identity.mdh.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAIPxTFqNFghYnsNGOQDHDvRnU53tMA0GCSqGSIb3DQEB\nBQUAMBoxGDAWBgNVBAMTD2lkZW50aXR5Lm1kaC5zZTAeFw0wOTA5MDIxMzE5MDRa\nFw0yOTA5MDIxMzE5MDRaMBoxGDAWBgNVBAMTD2lkZW50aXR5Lm1kaC5zZTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALBpGX8JJ+RvjMMMD3q/j01q58p8\nz0R9tuklMD5smW+Tz0JgiG3KDnynWvcYyg3s9DevNRUMmsQqzDBko771ecyhqkHy\nSoCkfVNJ9k7RaQmoaglSGZlR5N9lgcysHNA8qVqJYpUpsSFuQckr1dzS3RjngcTM\nICcuBjy/JviV8fKzYzF0v7F9HW+BEuJXHH6lhqhDIuI4R4n7I9/lYYxJWvQZVelJ\nF6/Z+RnbqaSzViq1qcMe5AWcnZgC85i0KiIcnaKiImNRJbVrVUN+eniQSj9ROJyf\nuk7Ldhpg8gvqsaUVd2drDY43XymAu7XFVnBBX340JKgb7F8wxpvIK6Gh6ZMCAwEA\nAaNlMGMwQgYDVR0RBDswOYIPaWRlbnRpdHkubWRoLnNlhiZodHRwczovL2lkZW50\naXR5Lm1kaC5zZS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU/qdjANz6BbQi/0eQ\nPgsaI1I0V4MwDQYJKoZIhvcNAQEFBQADggEBAG3OEKV7S8aojN/D7UOqURiCRrjC\nDk6wEnMLX6uIYAFCv6jc5QdkMWaaDBR0tgGhmgzRZOGnl9pvzT1AjMIhvMu2/luI\nb2oawOhycFG1rECJCpDi+gLDGhxzbQY/E9VIz+AcBAxglBFbDqqIynhFs+GZn+fv\nP7nZB2+XoE3sf8xqd2a9xO7vy1r17Q7bx8PzwklL9GdFppuRnimioYoF3atEQM6R\n7UwSK+MqY42FI27aHfIMAN7ccEun9HViAHU9HT/tng0kSydoF9VOvTI657LX7vpb\n0hhoH3UMUkrHgTwtNYpylgL6YEy/GtQHimQGN/O6aAQt1ZIyXKnuQufcnNk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mdh.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://identity.mdh.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://identity.mdh.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://identity.mdh.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://identity.mdh.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://identity.mdh.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://identity.mdh.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://identity.mdh.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://identity.mdh.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mdh.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mdh.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mdh.se"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r anst\u00e4llda och studenter vid M\u00e4lardalens h\u00f6gskola."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The M\u00e4lardalen University Identity Provider is used by employees and students at the university."
                  }
                ],
                "logo": [
                  {
                    "text": "https://identity.mdh.se/img/logo-sv.png",
                    "height": "117",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "216"
                  },
                  {
                    "text": "https://identity.mdh.se/img/logo-sv.png",
                    "lang": "sv",
                    "height": "117",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "216"
                  },
                  {
                    "text": "https://identity.mdh.se/img/logo-en.png",
                    "lang": "en",
                    "height": "117",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "216"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "M\u00e4lardalens H\u00f6gskola"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "M\u00e4lardalen University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "mdh.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:59.6186,16.5407"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:59.3716,16.5085"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAIPxTFqNFghYnsNGOQDHDvRnU53tMA0GCSqGSIb3DQEB\nBQUAMBoxGDAWBgNVBAMTD2lkZW50aXR5Lm1kaC5zZTAeFw0wOTA5MDIxMzE5MDRa\nFw0yOTA5MDIxMzE5MDRaMBoxGDAWBgNVBAMTD2lkZW50aXR5Lm1kaC5zZTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALBpGX8JJ+RvjMMMD3q/j01q58p8\nz0R9tuklMD5smW+Tz0JgiG3KDnynWvcYyg3s9DevNRUMmsQqzDBko771ecyhqkHy\nSoCkfVNJ9k7RaQmoaglSGZlR5N9lgcysHNA8qVqJYpUpsSFuQckr1dzS3RjngcTM\nICcuBjy/JviV8fKzYzF0v7F9HW+BEuJXHH6lhqhDIuI4R4n7I9/lYYxJWvQZVelJ\nF6/Z+RnbqaSzViq1qcMe5AWcnZgC85i0KiIcnaKiImNRJbVrVUN+eniQSj9ROJyf\nuk7Ldhpg8gvqsaUVd2drDY43XymAu7XFVnBBX340JKgb7F8wxpvIK6Gh6ZMCAwEA\nAaNlMGMwQgYDVR0RBDswOYIPaWRlbnRpdHkubWRoLnNlhiZodHRwczovL2lkZW50\naXR5Lm1kaC5zZS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU/qdjANz6BbQi/0eQ\nPgsaI1I0V4MwDQYJKoZIhvcNAQEFBQADggEBAG3OEKV7S8aojN/D7UOqURiCRrjC\nDk6wEnMLX6uIYAFCv6jc5QdkMWaaDBR0tgGhmgzRZOGnl9pvzT1AjMIhvMu2/luI\nb2oawOhycFG1rECJCpDi+gLDGhxzbQY/E9VIz+AcBAxglBFbDqqIynhFs+GZn+fv\nP7nZB2+XoE3sf8xqd2a9xO7vy1r17Q7bx8PzwklL9GdFppuRnimioYoF3atEQM6R\n7UwSK+MqY42FI27aHfIMAN7ccEun9HViAHU9HT/tng0kSydoF9VOvTI657LX7vpb\n0hhoH3UMUkrHgTwtNYpylgL6YEy/GtQHimQGN/O6aAQt1ZIyXKnuQufcnNk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "M\u00e4lardalens H\u00f6gskola"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "M\u00e4lardalen University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mdh.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "MDH"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://engine.t.eduteams.org/authentication/sp/metadata",
    {
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-03-20T09:40:32Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tech Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tech@eduteams.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "eduTEAMs Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "eduTEAMs"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@eduteams.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Enduser Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "eduTEAMs"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "admin@eduteams.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Admin Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://engine.t.eduteams.org/authentication/sp/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "eduTEAMs is een dienst voor het aanmaken en beheren van groepen. De dienst is vrij beschikbaar voor alle gebruikers van Identity Providers in de eduGAIN community"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "eduTEAMs is a service for creating and managing groups that can be used for Autherization. This TEST instance is only available to specific Identity Providers."
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.t.eduteams.org/media/eduteams_logo_250x250.jpg",
                    "height": "250",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "250"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.eduteams.org/privacypolicy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "eduTEAMs (Test)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "eduTEAMs (Test)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "want_assertions_signed": "true",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://engine.t.eduteams.org/authentication/sp/consume-assertion",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "nl",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "eduTEAMs (Test)"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "eduTEAMs (Test)"
                }
              ],
              "service_description": [
                {
                  "lang": "nl",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "eduTEAMs is een dienst voor het aanmaken en beheren van groepen. De dienst is vrij beschikbaar voor alle gebruikers van Identity Providers in de eduGAIN community. Dit is een TEST instance en is alleen beschikbaar voor specifieke Identity providers."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "eduTEAMs is a service for creating and managing groups that can be used for Autherization. This TEST instance is only available to specific Identity Providers."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://samlviewer.cf.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idman@cardiff.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Identity Management"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smart"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:smartp@cardiff.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Philip"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://samlviewer.cf.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-05-15T09:55:20Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cardiff University: SAML Viewer"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cardiff.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cardiff University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://samlviewer.cf.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://samlviewer.cf.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://samlviewer.cf.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://samlviewer.cf.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://samlviewer.cf.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://samlviewer.cf.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://samlviewer.cf.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJAItfjPqmm9zNMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\n\t\t\t\t\t\tBAMTE3NhbWx2aWV3ZXIuY2YuYWMudWswHhcNMTIwNTEyMTI0ODUzWhcNMjIwNTEw\n\t\t\t\t\t\tMTI0ODUzWjAeMRwwGgYDVQQDExNzYW1sdmlld2VyLmNmLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA41cEtiZIZyvzKrakm60sIuweLpKd4xDx\n\t\t\t\t\t\tvINqrj2C0zh8Gd9OeTElNSsHvJIKMezm1CnTBvWcd0F0tK9Mz0DADQLwcDVG+KuU\n\t\t\t\t\t\tyNHAMp94uTCKz5eqCLLl7M+A0fX7E1DugtnqI8qClpOxs3D7WJijKfy6yUz0q2ac\n\t\t\t\t\t\ta5uXGueKC47EHUrU1TsavzpQjNSAMC4L2J7dS4HAIt36T7Lo61+HRrdDC2Jh0fVq\n\t\t\t\t\t\tMC9a+Qt2C5pusWHv9zi4YXTicoAhByZ/Trz/ijU+LhZpQ3m3hpKDx6SEgCnHTSRk\n\t\t\t\t\t\t/d8cDFr0Npa7njU7mKYq8ago2/nBMZCBiguWSLwr9c6L+SaEDqcaVQIDAQABo0Ew\n\t\t\t\t\t\tPzAeBgNVHREEFzAVghNzYW1sdmlld2VyLmNmLmFjLnVrMB0GA1UdDgQWBBSDis4a\n\t\t\t\t\t\tNupQl7nNT9JwJ5E2m0HmczANBgkqhkiG9w0BAQUFAAOCAQEAd4fBqInXGnQ7Kdf8\n\t\t\t\t\t\tyqdauBjEjVJASJ6N9GB86tBXbtVM0+iIJvDOmpLW6s2Ovq+/DkXvroDAUu/G7Rre\n\t\t\t\t\t\tZSxpgN5oz6XwSiMDxeJGPgSF35/c/Q5A/fKiq4b/mKWllUVhX9UqRa5LiJbllmdq\n\t\t\t\t\t\tBIVHSoP90oksNnRHSsBbQXvqaoVZgFNgCDX6c/NYmX+CwQB4vMnSKTWN0EoCcZI+\n\t\t\t\t\t\tuZB7Oj929YrcQ17FRcBp7KLu6jPQEqUpqiwmRTy1KEvUT48h33zw+6dfgnmlqvpA\n\t\t\t\t\t\tgDjmryhzc9dI92jTLhORxBe7IIEYYFFBHt5w/jkj0ByL+ocWimhzW88rk+gayroy\n\t\t\t\t\t\tT3DN4A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://samlviewer.cf.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://samlviewer.cf.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://samlviewer.cf.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://samlviewer.cf.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://samlviewer.cf.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://samlviewer.cf.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Cardiff University SAML Viewer"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This service provider allows you to see the attributes the attributes released to it by your Identity Provider."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonTargetedID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonEntitlement",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonNickname",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonNickname",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonNickname",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.2",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonOrgDN",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonOrgDN",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonOrgDN",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonOrgUnitDN",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonOrgUnitDN",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonOrgUnitDN",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrimaryAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrimaryAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrimaryAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.5",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrimaryOrgUnitDN",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrimaryOrgUnitDN",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrimaryOrgUnitDN",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.8",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAssurance",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonAssurance",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAssurance",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.11",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:cn",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "description",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:description",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "description",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.13",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:displayName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "facsimileTelephoneNumber",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:facsimileTelephoneNumber",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "facsimileTelephoneNumber",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.23",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:givenName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "initials",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:initials",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "initials",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.43",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "l",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:l",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "l",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:mail",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "manager",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:manager",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "manager",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "o",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:o",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "o",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "ou",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:ou",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "ou",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.11",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "ou",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:ou",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "ou",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.11",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "postalCode",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:postalCode",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "postalCode",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.17",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "postofficeBox",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:postOfficeBox",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "postOfficeBox",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.18",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "preferredLanguage",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:preferredLanguage",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "preferredLanguage",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.39",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "seeAlso",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:seeAlso",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "seeAlso",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.34",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:sn",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "st",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:st",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "st",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.8",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "street",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:street",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "street",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "telephoneNumber",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:telephoneNumber",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "telephoneNumber",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.20",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "title",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:title",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "title",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.12",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "carLicense",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:carLicense",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "carLicense",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "departmentNumber",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:departmentNumber",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "departmentNumber",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.2",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "employeeNumber",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:employeeNumber",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "employeeNumber",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.2.840.113556.1.2.610",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "employeeType",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:employeeType",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "employeeType",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.2.840.113556.1.2.613",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "businessCategory",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:businessCategory",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "businessCategory",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.15",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "physicalDeliveryOfficeName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:physicalDeliveryOfficeName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "physicalDeliveryOfficeName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.19",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "uid",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:uid",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "uid",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "memberOf",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.5.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth-sp.pre.proquest.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tsupport@proquest.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ProQuest Technical Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Nair"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:anil.nair@proquest.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Anil"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth-sp.pre.proquest.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-07-21T14:13:24Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ProQuest Pre-Production Test"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.proquest.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Proquest Information and Learning Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-sp.pre.proquest.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth-sp.pre.proquest.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth-sp.pre.proquest.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth-sp.pre.proquest.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-sp.pre.proquest.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth-sp.pre.proquest.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJTCCAg2gAwIBAgIJALnScQHvrMirMA0GCSqGSIb3DQEBBQUAMCkxJzAlBgNV\n\t\t\t\t\t\tBAMMHnNoaWJib2xldGgtc3AucHJlLnByb3F1ZXN0LmNvbTAeFw0xNDA0MzAxNjM3\n\t\t\t\t\t\tNThaFw0xNzA0MjkxNjM3NThaMCkxJzAlBgNVBAMMHnNoaWJib2xldGgtc3AucHJl\n\t\t\t\t\t\tLnByb3F1ZXN0LmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMu2\n\t\t\t\t\t\tulnDhrfoKBQQbuEz/DLnadTAPbH6mjwEN1WL3wwzsbT9tBvbgUkeJVek3IzrcQyY\n\t\t\t\t\t\twNupltjdz1oy+D8SEeZl3k7FNl++OOWbYeoJC2x+H4DlN9JJKAc3BHjWWqxgsg/q\n\t\t\t\t\t\tyA90PqgnLx92Ssrg3Q1A7wEtX2Og7KRZvduo7Ku+xwZaKUHSOldk/us9EydhyPXX\n\t\t\t\t\t\t8mq4f8+VfsdHxEG8snu8XUaldH8m155dnh14JqgeK9Fhwd50uXbrMsRuRuoy6nTD\n\t\t\t\t\t\tOI2tkuHK31wlsDuJe7MskWmHTuF2U58dG4K7EoWEkPxJhddFFGlEWL3Zx9ZMncmb\n\t\t\t\t\t\tH4a0EjLSv4sVs865dYcCAwEAAaNQME4wHQYDVR0OBBYEFMHUep80KowQJBTazxKk\n\t\t\t\t\t\thIM2iDwYMB8GA1UdIwQYMBaAFMHUep80KowQJBTazxKkhIM2iDwYMAwGA1UdEwQF\n\t\t\t\t\t\tMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAIMGnbKNiy6Pt/ODzEQH2cmNzHVLIjsk\n\t\t\t\t\t\tRHjBtRtCFaPaicReEVfb4TsC5BIUcocizp/ik+cicggvvbmsDhygbugA+iXo2edH\n\t\t\t\t\t\t4u40jaPWUfSdhPJkUeU/R8s+5NPXrI3IVyHhc+oYeDIHTFOulXqICtymxidq54ci\n\t\t\t\t\t\tnVpwM/ENfcMy0H4azdwnzuvUnJcane6w7tBryN0nitUrL0/g1CM4/jw1x+hpZBUf\n\t\t\t\t\t\tJP7HaWe7IriI2oWnBx5h9LcxFco6dRhVOVJ63duuPh32pNeRvNRCk4+KwTuEy9Z7\n\t\t\t\t\t\t21I9IB6pfRoS4k/s/rB2Zt3JLJHgsZpRFhaqEmMTnKWi9xn2tdFd2gw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-sp.pre.proquest.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth-sp.pre.proquest.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth-sp.pre.proquest.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth-sp.pre.proquest.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth-sp.pre.proquest.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth-sp.pre.proquest.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth-sp.pre.proquest.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth-sp.pre.proquest.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth-sp.pre.proquest.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth-sp.pre.proquest.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://myid.vsc.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rick.blood@vsc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard Blood"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "john.schrader@vsc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Schrader"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://myid.vsc.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://myid.vsc.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://myid.vsc.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://myid.vsc.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://myid.vsc.edu/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUD6kNBlkvLeU+Ol2757c+7bZtM+owDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMbXlpZC52c2MuZWR1MB4XDTExMDMwODE4Mzk0NFoXDTMx\nMDMwODE4Mzk0NFowFzEVMBMGA1UEAxMMbXlpZC52c2MuZWR1MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAjh2UuMgWBZd1oChzFEAL9rnhrNGkCkFLfd/t\noXVdsfB3/lDMohSlVQx03w5NU6bBVdp5r2/1g9lLt/HjV5iWmseBHcYDNKWwZJPH\n8wyQcVhdE5l+lK96WT6NhLja3IF80FnnSAS4W5HzJZ/oDbmzOptFQ44FpW3Cc1+D\n4+/amvGi/X2ZskbKEJps72w5kwwdX+nkmVNS8yHxl1piaH9EpCDOC1Q6dvpLKW+5\nbP+ma9VCknf4DczevKwl9D34VjEwqhgzUzj1XT9epFt5TwS7twZ4ah+KRLJY0+TS\nLod76ZIBXYWYUBzIY8ApGxSQdwe39caDCvQPT5FC2hdG4wNSkQIDAQABo18wXTA8\nBgNVHREENTAzggxteWlkLnZzYy5lZHWGI2h0dHBzOi8vbXlpZC52c2MuZWR1L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBS5IqaDTgcD2zkQ/40nLl8VXF949TANBgkq\nhkiG9w0BAQUFAAOCAQEAEge54ojY4avoyKVObeH4W4rz1WnaZCnJTQZBg5L+HDFm\nkvCp5ZpDMX0SvhxSfzImkP1EJuIlFszenvOpre5yzAmKLOCQKlaZYVxmMUVluB3c\njC2Adkr9u5/y7vPDSH2padWGJP93Lk47t4/Wm0jHiBfEbzyx1F7UyLBaHm8Loqg9\n5dxdgKh8HQyuYqZNVlQezI5yIpQ+WLS1+Sa3eL8d34W1BM9pH+KNFwStDGTz61ns\nRyWSF4HaRliCJYEx5UlVZInGVkbyfqqZ0CSuABmOQ9qRwMnChkZEmIDZXqKk+N3f\nzaSlyhw6JsSB9BNAjScXmtSxUEZPmEmocxbfadzWAw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vsc.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Vermont State Colleges"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Vermont State Colleges"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vsc.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Vermont State Colleges"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://talkbank.talkbank.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:FranklinChen@cmu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Franklin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "MacWhinney"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:macw@cmu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brian"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://talkbank.talkbank.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-05-15T09:52:13Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://clarin.eu/category/clarin-member"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://talkbank.talkbank.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://talkbank.talkbank.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://talkbank.talkbank.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://talkbank.talkbank.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://talkbank.talkbank.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Transcript Korpora Gespr\u00e4chs Wechselwirkungen mit \u00e4lteren Kindern und Erwachsenen."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Transcript corpora of conversational interactions involving older children and adults."
                  }
                ],
                "logo": [
                  {
                    "text": "https://talkbank.talkbank.org/images/clarin16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "25"
                  },
                  {
                    "text": "https://talkbank.talkbank.org/images/clarin80.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "92"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://talkbank.org/share/irb/options.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TalkBank"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TalkBank"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "talkbank.talkbank.org"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJAIzKsiKO/JQPMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\nBAMTFXRhbGtiYW5rLnRhbGtiYW5rLm9yZzAeFw0xNDAzMTgxOTEzMDlaFw0yNDAz\nMTUxOTEzMDlaMCAxHjAcBgNVBAMTFXRhbGtiYW5rLnRhbGtiYW5rLm9yZzCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALno8eiR+W6+ZX3Yn5g7QNWUYues\n0NwWPwTcKCaMYB8GZFhPwKTTfju2oXdyTBGZZCIqIM5Wfrg9UMfdh3j1zrC3loj7\nHx5HwY+i/+Tx/s/UAW9njBbnrRM4f/4xKRfCeiaeQo+RedrcNZADkaE1uy+EhRh3\nxVpZZHkIKWekGk1jh8NsW8QnRBTA1GLd9BZBDaVvaBpnEW5IwqeN0iJSy7WwcwC6\nqLfDqLUFaC2OI2fi+RtV4Vfs1Oq30ZbLHZG9+MFCPpqkGxEbyUgohcfGCKoz8/vW\nfk6MgiaiGqJ0/K3AaCCJz+1zFUmq1hf5aSsVu/lvBMzAH+77QDQNKyZSxNMCAwEA\nAaNDMEEwIAYDVR0RBBkwF4IVdGFsa2JhbmsudGFsa2Jhbmsub3JnMB0GA1UdDgQW\nBBQgweM96szLBSev8r+xBdkfzq2pXTANBgkqhkiG9w0BAQUFAAOCAQEAemzcmcrh\n5EWY2BXLmyMrdl4h5GnVtANr1hcKP7RfX0+EaWXlgPBTml4W8TIzegvyv6MuIIXU\nRB2b1VWOo9NY0zSbbazP2x6wcqgM0Imzpac+FWeGgh+D3j4mWC5NZYezZ8ahsvjq\nsCAq1dYlkAIj/34KLLhZLuZYceQXOW9KiossZEyp/6u4yzndgMmGqtK9TZnitAio\nM7H5R35g3WcjoBPdGHTSValup4MaMhz3dbLzS+X4s97XjIYVuaJFags+JZz+79b6\nxPttj9gCJKXC12f60rCBFakal1AEmL9GnYf2jyKaxkot5rxU053SU5ahhUAJpCoU\nnqtFHmhEv2mrhA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=talkbank.talkbank.org"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://talkbank.talkbank.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://talkbank.talkbank.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://talkbank.talkbank.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://talkbank.talkbank.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://talkbank.talkbank.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://talkbank.talkbank.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "TalkBank"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "TalkBank"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Transcript Korpora Gespr\u00e4chs Wechselwirkungen mit \u00e4lteren Kindern und Erwachsenen."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Transcript corpora of conversational interactions involving older children and adults."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cts-dev.ngs.ac.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@grid-support.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tariq"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:suleman.tariq@stfc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Suleman"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cts-dev.ngs.ac.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-08-13T15:41:55Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CTS development"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.stfc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Science and Technology Facilities Council"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cts-dev.ngs.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cts-dev.ngs.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cts-dev.ngs.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cts-dev.ngs.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cts-dev.ngs.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://cts-dev.ngs.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Development SP for NES SARoNGS server."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CTS development"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "1",
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+jCCAeKgAwIBAgIJALEcGlMiED8+MA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\n\t\t\t\t\t\tBAMTEWN0cy1kZXYubmdzLmFjLnVrMB4XDTEyMDgxNTE0MjM1MVoXDTIyMDgxMzE0\n\t\t\t\t\t\tMjM1MVowHDEaMBgGA1UEAxMRY3RzLWRldi5uZ3MuYWMudWswggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDUdK6J5wg+5C3XYk84xtApr1yJtuCx4n6mcX0O\n\t\t\t\t\t\t6VHocCab3ROfBhzZZIzzG88n5cE80bhLO+bPPGTv6RQGRz/zyH++S7halU+MUj6Y\n\t\t\t\t\t\tS3S1E5z6EYPM2FuoY4O4PiKZbLsPAvBSRcPy9R32ZKDLi9/Wxu0AudB0Pueft0o2\n\t\t\t\t\t\t4GmEwGQoEU1zcBnm5UTQkK8BFciPHGsnsRBnLjUbMDPYqOzvcMEfeyZ4TbVnyrFV\n\t\t\t\t\t\tzjNSIIQAhoGOXcumy/TzWE3ItQOMKwpgFpJAu0ESH6+L4u7tzZh/YI55LSEIeWdT\n\t\t\t\t\t\t5LWv73sD7qsmMrsaLywriBYqscQ+w0sXjRAwRHIwpFFz/I21AgMBAAGjPzA9MBwG\n\t\t\t\t\t\tA1UdEQQVMBOCEWN0cy1kZXYubmdzLmFjLnVrMB0GA1UdDgQWBBRnwG5eWrKe/lPu\n\t\t\t\t\t\tHZ4m4O7meVYuHjANBgkqhkiG9w0BAQUFAAOCAQEAQbFdqMTEPK1BXxPinmL7a+PY\n\t\t\t\t\t\tMVNBX7GEFJtA5+pLDlFW1LONdaiWT+6DwjGhy5W8zNNAJA/HXnpVetU9JfAZq0Mj\n\t\t\t\t\t\t8aHTadN84/xwzvYxparP7jA/lThYpFzEVm7IPZ09xHDR/FiH2oA9R4h3zD6gvBJD\n\t\t\t\t\t\tmpR0lnz7iXjMB5vq1Hz1tHddkaX+ffp6cltDwRrOYzvYeuCXk6jkZHx5C/tBfB9r\n\t\t\t\t\t\tYmAXwx0UJskbUvEL2EtPQBNcJUt0Xrs+P0HXxwA4uDQOBX5K/NhAhhz5A9n02l8r\n\t\t\t\t\t\tDeRgH/OFbPn1DgrOvHjHOdgKHNxXPzW4BRhl9jaPwofj6qysJ183Wr7GLmTOlA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cts-dev.ngs.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cts-dev.ngs.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cts-dev.ngs.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://cts-dev.ngs.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://cts-dev.ngs.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://cts-dev.ngs.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.nvt.ar.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.nvt.ar.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.nvt.ar.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.nvt.ar.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.nvt.ar.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.nvt.ar.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.nvt.ar.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.nvt.ar.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.nvt.ar.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.nvt.ar.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.nvt.ar.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.nvt.ar.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.nvt.ar.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.nvt.ar.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIJALCnTLXPBNhAMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE3d3dy5udnQuYXIubGFkb2suc2UwHhcNMTUwMzA2MTE1NDA5WhcNMjUwMzAz\nMTE1NDA5WjAeMRwwGgYDVQQDExN3d3cubnZ0LmFyLmxhZG9rLnNlMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA9Q2Ye1QrDRI1u0GJhrLG0j8i6tapcRiJ\nnBALGpG8dXh04apN8WJ1mTLGeW0VHvgYeardInfzXxheZTh89nFE9wADDxPxkmF9\nZHvCkiGMOM1wejcIupyT/InZ8OIrh9mcuuK1MjJ0W5awOiBi+c+ibZwDhCtutzE/\nRIbWbNIXsLu8tl0dTXn+npDaa4PuYlfBHnrEKitA/B2y72JfSZqtn4JUdPa2ZoY4\n90g4UiZAJLB+U/uqigR9YdneCTA4caQAreIfwG50HVs4gYw9upn7pqkcLxafOUtq\neYwI6hgK5ovvfSy5j0LGZ3jxuetH7Mpv8+BQgb4oaXpiNvkRm9SpZQIDAQABo2Uw\nYzBCBgNVHREEOzA5ghN3d3cubnZ0LmFyLmxhZG9rLnNlhiJodHRwczovL3d3dy5u\ndnQuYXIubGFkb2suc2UvZ3VpLXNwMB0GA1UdDgQWBBQ9SlTHCjEmb88tAkrYc0Qd\nUyMntDANBgkqhkiG9w0BAQUFAAOCAQEA5yJcv3VDqI2NAxCRjUUw0zXZvaJoXbYf\naGcw+v9JoLQRXZFdR5FQ6e3Fl21BMFMbzVNHkcAaLJN2pL9qMf7QUcOd3CyuUKgd\nJnd4HTYWJTjXB4J5B3cXZrfHd8pXuA6cM+McpTnF9lvBmxgRb/H9NF8rqkbHgD8c\nW3tputjUxL+Vnw9R+znIPD526wQaloaTGoejqfgl9EA0kVxOMObER6yQ0sj9xsl5\nlysGQwo1+xp0n4fB3zmXRPTUwnw6qxS81mVpW0uQFb0pxUeLcbf5PwKvL0vVGzJT\nJRxZMVwXFUuyy6QeZ//MHqoNR07si2v6641PxjQHTNTpskU/bJ4jAA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.nvt.ar.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.nvt.ar.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.nvt.ar.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.nvt.ar.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.nvt.ar.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.nvt.ar.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.nvt.ar.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.nvt.ar.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.nvt.ar.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.nvt.ar.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.altoncollege.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hines-Dedman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:guy.hines-dedman@altoncollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Guy"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hines-Dedman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:guy.hines-dedman@altoncollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Guy"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.altoncollege.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-02-25T10:39:55Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjgCCQC9aDsLCT+yJTANBgkqhkiG9w0BAQUFADBqMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjESMBAGA1UECAwJSGFtcHNoaXJlMQ4wDAYDVQQHDAVBbHRvbjEWMBQGA1UECgwN\n\t\t\t\t\t\tQWx0b24gQ29sbGVnZTEfMB0GA1UEAwwWaWRwLmFsdG9uY29sbGVnZS5hYy51azAe\n\t\t\t\t\t\tFw0xMzAyMTkxNzI0MjRaFw0zMzAyMTQxNzI0MjRaMGoxCzAJBgNVBAYTAkdCMRIw\n\t\t\t\t\t\tEAYDVQQIDAlIYW1wc2hpcmUxDjAMBgNVBAcMBUFsdG9uMRYwFAYDVQQKDA1BbHRv\n\t\t\t\t\t\tbiBDb2xsZWdlMR8wHQYDVQQDDBZpZHAuYWx0b25jb2xsZWdlLmFjLnVrMIIBIjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0QQESMIq4pyRj3urGeRTqGCnKkqI\n\t\t\t\t\t\totYZ90HBsx9qQM2WB5/7VjyFdP8SHj9gZXeLODaZQpKHcP/QUPjJkQb8PGLc1C5r\n\t\t\t\t\t\tTLMN4KcQlNUOHJf7ss60JfVs9YAUC6ClMyY/jB/FTD4o0bAjAbkWt3Bgd6Hd89XC\n\t\t\t\t\t\txhZA/oRJ+fYEciD6SwctjIWKRA4s6/+QLy/ON1YugiQNTwa2dhDrx1n4pedE1eVN\n\t\t\t\t\t\tMpOnkeHHU57ri98ta+KvzayPYSBoC0m+vG8ChxDySdsBsRUBxxU+OUVYRyatgklc\n\t\t\t\t\t\tFyRx2jIblObP7/MDHsKDtrOj6hhoVqY+QDlIGIo0+FeP4cUMcShCWMDp/wIDAQAB\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQApabwAaLn7eBgnFmqTd4VeOcFVN4N4nmNkXcrq\n\t\t\t\t\t\tYlFfcZEGxH0S8chY5wUg49DwzJlSbOsOBV+xTqeE1wBaEKO+oMRi1iP2eSKucAp7\n\t\t\t\t\t\tryH8LDb0Wa6BO80rjG1P0lfYlldDmPGycIF2qhHPIiuKSBxdCptKyHGDBk6kgAnk\n\t\t\t\t\t\tUtX3A3o6EO/So2nHKr4niblixFI/pkBfbMbln3Yv/ExIpi/TX9r4p/YeJHiSnbGA\n\t\t\t\t\t\t9HL3TJh7T9W2wwiXCPBrbBXgsMEJbqBD8IqmduocWIEmoS42u/NRDqm2Pd0Xo6ek\n\t\t\t\t\t\tX3N5HAhy6iR2no15bK6N+a+qaju+C9vIQyHuWCAf3xfr8loi"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "altoncollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.altoncollege.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.altoncollege.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.altoncollege.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.altoncollege.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.altoncollege.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.altoncollege.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.altoncollege.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.altoncollege.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "altoncollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjgCCQC9aDsLCT+yJTANBgkqhkiG9w0BAQUFADBqMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjESMBAGA1UECAwJSGFtcHNoaXJlMQ4wDAYDVQQHDAVBbHRvbjEWMBQGA1UECgwN\n\t\t\t\t\t\tQWx0b24gQ29sbGVnZTEfMB0GA1UEAwwWaWRwLmFsdG9uY29sbGVnZS5hYy51azAe\n\t\t\t\t\t\tFw0xMzAyMTkxNzI0MjRaFw0zMzAyMTQxNzI0MjRaMGoxCzAJBgNVBAYTAkdCMRIw\n\t\t\t\t\t\tEAYDVQQIDAlIYW1wc2hpcmUxDjAMBgNVBAcMBUFsdG9uMRYwFAYDVQQKDA1BbHRv\n\t\t\t\t\t\tbiBDb2xsZWdlMR8wHQYDVQQDDBZpZHAuYWx0b25jb2xsZWdlLmFjLnVrMIIBIjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0QQESMIq4pyRj3urGeRTqGCnKkqI\n\t\t\t\t\t\totYZ90HBsx9qQM2WB5/7VjyFdP8SHj9gZXeLODaZQpKHcP/QUPjJkQb8PGLc1C5r\n\t\t\t\t\t\tTLMN4KcQlNUOHJf7ss60JfVs9YAUC6ClMyY/jB/FTD4o0bAjAbkWt3Bgd6Hd89XC\n\t\t\t\t\t\txhZA/oRJ+fYEciD6SwctjIWKRA4s6/+QLy/ON1YugiQNTwa2dhDrx1n4pedE1eVN\n\t\t\t\t\t\tMpOnkeHHU57ri98ta+KvzayPYSBoC0m+vG8ChxDySdsBsRUBxxU+OUVYRyatgklc\n\t\t\t\t\t\tFyRx2jIblObP7/MDHsKDtrOj6hhoVqY+QDlIGIo0+FeP4cUMcShCWMDp/wIDAQAB\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQApabwAaLn7eBgnFmqTd4VeOcFVN4N4nmNkXcrq\n\t\t\t\t\t\tYlFfcZEGxH0S8chY5wUg49DwzJlSbOsOBV+xTqeE1wBaEKO+oMRi1iP2eSKucAp7\n\t\t\t\t\t\tryH8LDb0Wa6BO80rjG1P0lfYlldDmPGycIF2qhHPIiuKSBxdCptKyHGDBk6kgAnk\n\t\t\t\t\t\tUtX3A3o6EO/So2nHKr4niblixFI/pkBfbMbln3Yv/ExIpi/TX9r4p/YeJHiSnbGA\n\t\t\t\t\t\t9HL3TJh7T9W2wwiXCPBrbBXgsMEJbqBD8IqmduocWIEmoS42u/NRDqm2Pd0Xo6ek\n\t\t\t\t\t\tX3N5HAhy6iR2no15bK6N+a+qaju+C9vIQyHuWCAf3xfr8loi"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Alton College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.altoncollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Alton College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.teipir.gr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Avgerinou"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "xristina@teipir.gr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Christina"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@teipir.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Technological Educational Institute of Piraeus Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.teipir.gr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEZzCCA0+gAwIBAgIQeIOp00euUnoH7TSY6j9/TDANBgkqhkiG9w0BAQUFADA2\n                            MQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n                            U1NMIENBMB4XDTEzMDYwNTAwMDAwMFoXDTE2MDYwNDIzNTk1OVowOzEhMB8GA1UE\n                            CxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRYwFAYDVQQDEw1pZHAudGVpcGly\n                            LmdyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoCSBB7C9YPdEv5VP\n                            BAzm/uJNbkQbumXzbT40r/tw/vQC+lKwLeuCTthH093OmzmuiWqrfguGGDAuEdbK\n                            qS93u63Zm4eLhaMRvQBU3TgrZlwpdWEmPQmrM8YeBf5i2Oa8HuIVr2UHHRze2TXn\n                            CsRE8c9HQl6J1J/E6PX8/jA6bzCuP5VXifKFSuTIw0f9J8dRfKh5i90qGPMPTThW\n                            bbJXDKkLm0a+kwAjtpzccJ3P9XPciWv53855jK/wl7PrnYl376W6xJozuEmYGTRD\n                            Iun9muqhz89dWO4W9SMnRXXg5Cl6G5Ay17SEmX16DF9CiOJ4We/ij2PM6kKY/nst\n                            uvAsgwIDAQABo4IBajCCAWYwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH6pDj\n                            ue0wHQYDVR0OBBYEFOqFlGOIjhxOGDe4fLw8Wsf5BfqbMA4GA1UdDwEB/wQEAwIF\n                            oDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAi\n                            BgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAxMC+g\n                            LaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNybDBt\n                            BggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVu\n                            YS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8vb2NzcC50\n                            Y3MudGVyZW5hLm9yZzAYBgNVHREEETAPgg1pZHAudGVpcGlyLmdyMA0GCSqGSIb3\n                            DQEBBQUAA4IBAQC5/sKffeIG/38kVzhSpa6eA84z9mibqMx/ZPmXi7COKd7qKIrS\n                            ztJEuuWSnPbbyQWrPTtURP0A3b/KgyXRXyKKPeBNUCQzGpMZaCn6zH8uaRutgwoi\n                            OcnGOrGUHZDM8Nh20syhOeJVtldCFBnBklPU0ZKj1yW3I6MitgNLegHw0mkTfVV3\n                            hHbRO/Eq0A8zB3SPFJdZwIr9hXmUDZ0au5wphyMHr8PsIromdng9iK98BhPLRtXD\n                            VN8zaPiZhqYc5v5inUcXsY66dHRQVmo8WeBf47tWka6FeKnxvdPJA8euG0ZmNEtt\n                            o75PCMgbJ2on+1RDqRfAB1iHjM+BSVS2+Hlz"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "teipir.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.teipir.gr:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.teipir.gr:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.teipir.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.teipir.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.teipir.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.teipir.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.teipir.gr:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.teipir.gr:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "teipir.gr"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.teipir.gr/"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.teipir.gr/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.teipir.gr/idp/images/dummylogo.png",
                    "height": "83",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "81"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Piraeus University of Applied Sciences"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u0391\u03bd\u03ce\u03c4\u03b1\u03c4\u03bf \u0395\u03ba\u03c0\u03b1\u03b9\u03b4\u03b5\u03c5\u03c4\u03b9\u03ba\u03cc \u038a\u03b4\u03c1\u03c5\u03bc\u03b1 \u03a0\u03b5\u03b9\u03c1\u03b1\u03b9\u03ac \u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03b9\u03ba\u03bf\u03cd \u03a4\u03bf\u03bc\u03ad\u03b1"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "noc.teipir.gr"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:37.978971,23.674666"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.251.64.0/19"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEZzCCA0+gAwIBAgIQeIOp00euUnoH7TSY6j9/TDANBgkqhkiG9w0BAQUFADA2\n                            MQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n                            U1NMIENBMB4XDTEzMDYwNTAwMDAwMFoXDTE2MDYwNDIzNTk1OVowOzEhMB8GA1UE\n                            CxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRYwFAYDVQQDEw1pZHAudGVpcGly\n                            LmdyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoCSBB7C9YPdEv5VP\n                            BAzm/uJNbkQbumXzbT40r/tw/vQC+lKwLeuCTthH093OmzmuiWqrfguGGDAuEdbK\n                            qS93u63Zm4eLhaMRvQBU3TgrZlwpdWEmPQmrM8YeBf5i2Oa8HuIVr2UHHRze2TXn\n                            CsRE8c9HQl6J1J/E6PX8/jA6bzCuP5VXifKFSuTIw0f9J8dRfKh5i90qGPMPTThW\n                            bbJXDKkLm0a+kwAjtpzccJ3P9XPciWv53855jK/wl7PrnYl376W6xJozuEmYGTRD\n                            Iun9muqhz89dWO4W9SMnRXXg5Cl6G5Ay17SEmX16DF9CiOJ4We/ij2PM6kKY/nst\n                            uvAsgwIDAQABo4IBajCCAWYwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH6pDj\n                            ue0wHQYDVR0OBBYEFOqFlGOIjhxOGDe4fLw8Wsf5BfqbMA4GA1UdDwEB/wQEAwIF\n                            oDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAi\n                            BgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAxMC+g\n                            LaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNybDBt\n                            BggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVu\n                            YS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8vb2NzcC50\n                            Y3MudGVyZW5hLm9yZzAYBgNVHREEETAPgg1pZHAudGVpcGlyLmdyMA0GCSqGSIb3\n                            DQEBBQUAA4IBAQC5/sKffeIG/38kVzhSpa6eA84z9mibqMx/ZPmXi7COKd7qKIrS\n                            ztJEuuWSnPbbyQWrPTtURP0A3b/KgyXRXyKKPeBNUCQzGpMZaCn6zH8uaRutgwoi\n                            OcnGOrGUHZDM8Nh20syhOeJVtldCFBnBklPU0ZKj1yW3I6MitgNLegHw0mkTfVV3\n                            hHbRO/Eq0A8zB3SPFJdZwIr9hXmUDZ0au5wphyMHr8PsIromdng9iK98BhPLRtXD\n                            VN8zaPiZhqYc5v5inUcXsY66dHRQVmo8WeBf47tWka6FeKnxvdPJA8euG0ZmNEtt\n                            o75PCMgbJ2on+1RDqRfAB1iHjM+BSVS2+Hlz"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Technological Educational Institute of Piraeus"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03b9\u03ba\u03cc \u0395\u03ba\u03c0\u03b1\u03b9\u03b4\u03b5\u03c5\u03c4\u03b9\u03ba\u03cc \u038a\u03b4\u03c1\u03c5\u03bc\u03b1 \u03a0\u03b5\u03b9\u03c1\u03b1\u03b9\u03ac"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.teipir.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.teipir.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Technological Educational Institute of Piraeus"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03b9\u03ba\u03cc \u0395\u03ba\u03c0\u03b1\u03b9\u03b4\u03b5\u03c5\u03c4\u03b9\u03ba\u03cc \u038a\u03b4\u03c1\u03c5\u03bc\u03b1 \u03a0\u03b5\u03b9\u03c1\u03b1\u03b9\u03ac"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.inalco.fr/idp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ldap-adm@inalco.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.inalco.fr/idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2010-11-10T14:15:50Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.inalco.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.inalco.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.inalco.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "inalco.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://inalco.fr/"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INALCO - Institut National des Langues et Civilisations Orientales"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INALCO - Institut National des Langues et Civilisations Orientales"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUXBzPfYV+3ru5apFeK1Xo5W/wdlowDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPbWxkYXAuaW5hbGNvLmZyMB4XDTEwMDkyODE0NTYxOFoX\nDTMwMDkyODE0NTYxOFowGjEYMBYGA1UEAxMPbWxkYXAuaW5hbGNvLmZyMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAjXFdyCRby1D4CFQW7ynaRKzJCyzz\nnRsnF2qPnGuMExCzuWUM5gBqVAjdI+AZXutcXcxkJq71TC22erYIlAob5A8nWTT5\nrR/dUtVRwawP/4jv9CqKiRC86zeNRFuUgYd0+Wkrn/RADV0wyfeSaT0KHoqwOu4d\niRlks9CMns7/eFLmGsYQcEMHlw9nGTYpx94IClua3/prJjkc45iCYuoWXnGCLq2j\nMoJDcw3I5u3tSUfzCbp81lWn06oYBIVuzzcZuLRsd0smB41pabVYcS+bbG0yWA4b\nxIn4ZPQ1vja6YpIix6YZmpcCD6hs02xYfm6sWq/BnNS1vtMD1RjmSJhx4QIDAQAB\no2UwYzBCBgNVHREEOzA5gg9tbGRhcC5pbmFsY28uZnKGJmh0dHBzOi8vbWxkYXAu\naW5hbGNvLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSVnWnWMca1OUkx11t9\nLRaeLMgTWzANBgkqhkiG9w0BAQUFAAOCAQEAfmv+9vLBGqsioIPqwy7pTT54CsbR\njdvs5Ud7EhkLYDa+EelzwrgmE4z92mmmTFKUixlj070ncHZJjwjdfbDGwcQ/aKT2\ncd597hjiVBd85/biLQ3yTBkzJx2UiXm/Wj2qfyHoJDH9UfcLZOorR8R0b1ObSbHY\n2EsElJHCh/SrRniERFdJdQ1fzTukaSPa6zu/lLO40gYHu13qenRjMgMn9W85g7V8\ne6Kt16MbjbkcX6m9uYJo9HiN5hJ+pP0fV4q8kj2YxAK/av/v0Qp5iXJfBH9QecSK\nBdKgqhQ4XdLkP9D+5i10GGHVDJL3NYCpNbAqNmHeTJGjc+aSG6XpBZPcVw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INALCO - Institut National des Langues et Civilisations Orientales"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://inalco.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INALCO - Institut National des Langues et Civilisations Orientales"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp1.glyndwr.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Williams"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:a.d.williams@glyndwr.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alwyn"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Williams"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:a.d.williams@glyndwr.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alwyn"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp1.glyndwr.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-11-06T12:40:49Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUW2tXeH8370JdIqiuEuyPXsvnn1IwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHTEbMBkGA1UEAwwSaWRwMS5nbHluZHdyLmFjLnVrMB4XDTE0MTEwMzExNDUy\n\t\t\t\t\t\tNVoXDTM0MTEwMzExNDUyNVowHTEbMBkGA1UEAwwSaWRwMS5nbHluZHdyLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAs107XEU+w72wOCggvYWv\n\t\t\t\t\t\tHnvIjLwochbb1TQEjD76H+OXZQFFE5if39WkfeIgM+NumYc1SCZhHO7ssT2ArxpT\n\t\t\t\t\t\tx3pwNYoj3mMtarXj5uF8In5nybRtNKFcug2nLaBsa+Svj77n73681Gx/VVx+tTkF\n\t\t\t\t\t\tySeQ4AHxkDncG4gUp0GKXWuCVSsQdXGOoljxp/aWkTlaZKJQfvDiURD8ysLBc8XF\n\t\t\t\t\t\t4s0YE4GtrWMM/SbSysad1Wk0sI7afL+1iCf+UdiuRa8HrRI0kuc/Z7ajCBBaWn4w\n\t\t\t\t\t\t11zac9qrLztQ4bKTp+5z025F9HGM9iXAe39AxeGHdurTPr8Voz8/rGlelNnYh7JR\n\t\t\t\t\t\trwIDAQABo2swaTAdBgNVHQ4EFgQU1g7hguqPgn9Za9hlSXqXv3TVbpkwSAYDVR0R\n\t\t\t\t\t\tBEEwP4ISaWRwMS5nbHluZHdyLmFjLnVrhilodHRwczovL2lkcDEuZ2x5bmR3ci5h\n\t\t\t\t\t\tYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAKl23zJe5fEkR\n\t\t\t\t\t\t3wCSeBWSWXeSLNxB6nTL3I89uJ+1M3RNyR2t56Zqhx5g/7Iac4tbJs50FaUnGQ7x\n\t\t\t\t\t\tI0WXrKJ8jit0gKWMjDY36SlfXkIWtH2VtW4WvxChLxCVur7y4zcKDtXxCDJvYAVl\n\t\t\t\t\t\tW5Pe2l+xXc9nl2Pn17OA+idxL+asZ5tGuI3egcxNEfp4AuPYGnt9RhrhrOCo8Wv1\n\t\t\t\t\t\tlg4GojfVyaGPZ9bi0dTsCl5PyU5tmUMsUOpi8/SxrD+KMB4gU+4fottmPKnowz/o\n\t\t\t\t\t\tzKbCkLq1ncgsZ9wbFNI20qOQIXZ13Z6bfnslalxhqc+QNsIhnUSwep11XICn+YzV\n\t\t\t\t\t\tpBqIGwWXLw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "glyndwr.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.glyndwr.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.glyndwr.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp1.glyndwr.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp1.glyndwr.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.glyndwr.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp1.glyndwr.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp1.glyndwr.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp1.glyndwr.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp1.glyndwr.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.glyndwr.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.glyndwr.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "glyndwr.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUW2tXeH8370JdIqiuEuyPXsvnn1IwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHTEbMBkGA1UEAwwSaWRwMS5nbHluZHdyLmFjLnVrMB4XDTE0MTEwMzExNDUy\n\t\t\t\t\t\tNVoXDTM0MTEwMzExNDUyNVowHTEbMBkGA1UEAwwSaWRwMS5nbHluZHdyLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAs107XEU+w72wOCggvYWv\n\t\t\t\t\t\tHnvIjLwochbb1TQEjD76H+OXZQFFE5if39WkfeIgM+NumYc1SCZhHO7ssT2ArxpT\n\t\t\t\t\t\tx3pwNYoj3mMtarXj5uF8In5nybRtNKFcug2nLaBsa+Svj77n73681Gx/VVx+tTkF\n\t\t\t\t\t\tySeQ4AHxkDncG4gUp0GKXWuCVSsQdXGOoljxp/aWkTlaZKJQfvDiURD8ysLBc8XF\n\t\t\t\t\t\t4s0YE4GtrWMM/SbSysad1Wk0sI7afL+1iCf+UdiuRa8HrRI0kuc/Z7ajCBBaWn4w\n\t\t\t\t\t\t11zac9qrLztQ4bKTp+5z025F9HGM9iXAe39AxeGHdurTPr8Voz8/rGlelNnYh7JR\n\t\t\t\t\t\trwIDAQABo2swaTAdBgNVHQ4EFgQU1g7hguqPgn9Za9hlSXqXv3TVbpkwSAYDVR0R\n\t\t\t\t\t\tBEEwP4ISaWRwMS5nbHluZHdyLmFjLnVrhilodHRwczovL2lkcDEuZ2x5bmR3ci5h\n\t\t\t\t\t\tYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAKl23zJe5fEkR\n\t\t\t\t\t\t3wCSeBWSWXeSLNxB6nTL3I89uJ+1M3RNyR2t56Zqhx5g/7Iac4tbJs50FaUnGQ7x\n\t\t\t\t\t\tI0WXrKJ8jit0gKWMjDY36SlfXkIWtH2VtW4WvxChLxCVur7y4zcKDtXxCDJvYAVl\n\t\t\t\t\t\tW5Pe2l+xXc9nl2Pn17OA+idxL+asZ5tGuI3egcxNEfp4AuPYGnt9RhrhrOCo8Wv1\n\t\t\t\t\t\tlg4GojfVyaGPZ9bi0dTsCl5PyU5tmUMsUOpi8/SxrD+KMB4gU+4fottmPKnowz/o\n\t\t\t\t\t\tzKbCkLq1ncgsZ9wbFNI20qOQIXZ13Z6bfnslalxhqc+QNsIhnUSwep11XICn+YzV\n\t\t\t\t\t\tpBqIGwWXLw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Glyndwr University (Test Do not use)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.glyndwr.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Glyndwr University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://wiseflow.dk",
    {
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2013-02-20T13:26:24Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute_value": [
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "kalmar"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "denmark"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "iceland"
              }
            ],
            "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
            "name": "tags",
            "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tim@uniwise.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Administrator"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://wiseflow.dk",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://wiseflow.dk/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Form\u00e5let er at facilitere digital h\u008c\u00e5ndtering af skriftlige eksaminer."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The purpose is to facilitate digital management of written exams."
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WISEflow"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WISEflow"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE9TCCA92gAwIBAgISESH+ztqYjBHgq/wYQiZ/sorSMA0GCSqGSIb3DQEBCwUA MGAxCzAJBgNVBAYTAkJFMRkwFwYDVQQKExBHbG9iYWxTaWduIG52LXNhMTYwNAYD VQQDEy1HbG9iYWxTaWduIERvbWFpbiBWYWxpZGF0aW9uIENBIC0gU0hBMjU2IC0g RzIwHhcNMTQxMjIyMDc0MDU2WhcNMTgwMTMwMTI1MDEwWjA7MSEwHwYDVQQLExhE b21haW4gQ29udHJvbCBWYWxpZGF0ZWQxFjAUBgNVBAMMDSoud2lzZWZsb3cuZGsw ggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC6s0JtLsYVlJyk0wecpxSI 61QY+YJA9CWGHN4+ffPPHdxJHWLuM4CC63vQgw5TFGiOVW38R+FZXyUELOJsruEu P0hvgcsIEVRqJWp9vlAE1vMsHTC2mfGQGwcC2AbwcpPl2+CLBj6uKOcPWzR/N6S9 bUsokleeSnfltP5s7VQkFcjcPdbJQWnlRzTwKZTaOxLRfuTnJPGc8D92XWgpCK4u 4/pFQEIz00Uzw93ULbRK7tmKF+wyFEKf6FtX7YEO04lqqGpmsJ1daXNzS/izlTM/ 3Esf0m/SP7N/qNP3BFNv9Nx6i6D7ha/lkT044zBvZcf1+sqF62eRxY/h1247eGi5 AgMBAAGjggHMMIIByDAOBgNVHQ8BAf8EBAMCBaAwSQYDVR0gBEIwQDA+BgZngQwB AgEwNDAyBggrBgEFBQcCARYmaHR0cHM6Ly93d3cuZ2xvYmFsc2lnbi5jb20vcmVw b3NpdG9yeS8wJQYDVR0RBB4wHIINKi53aXNlZmxvdy5ka4ILd2lzZWZsb3cuZGsw CQYDVR0TBAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwQwYDVR0f BDwwOjA4oDagNIYyaHR0cDovL2NybC5nbG9iYWxzaWduLmNvbS9ncy9nc2RvbWFp bnZhbHNoYTJnMi5jcmwwgZQGCCsGAQUFBwEBBIGHMIGEMEcGCCsGAQUFBzAChjto dHRwOi8vc2VjdXJlLmdsb2JhbHNpZ24uY29tL2NhY2VydC9nc2RvbWFpbnZhbHNo YTJnMnIxLmNydDA5BggrBgEFBQcwAYYtaHR0cDovL29jc3AyLmdsb2JhbHNpZ24u Y29tL2dzZG9tYWludmFsc2hhMmcyMB0GA1UdDgQWBBQ1pHl1wFij/zbTH64lg9ff 53I8wDAfBgNVHSMEGDAWgBTqTnzUgC3lFYGGJoyCbcCYpM+XDzANBgkqhkiG9w0B AQsFAAOCAQEAPnLDCKrxHIjJsqIuGHexn9GOWpNV/N1A6iUZwEMO7T8u4DOWxWsL pPbnJb54YswMH6ylsrmgwok90iTRCLU4Ljz/ujDYU3v0HnKzyeZbQVsYJVoMbWpG b/3h9IVYawghnbM8F50XR+OQcbkqmv4xsBAQRNUZNLduhrzsrpdlOCU/5Zl++1dK P8Ktnx5hrXhnF3fEFKAYHRJ3ZcfqGwOLwkTQqaqtt57Cl7g3qiY7EyAVFrTB7siV 4q8FX/fOfFpZ5KuwFxieq09zhQyAkwDPBf36k9h6mn0Lfr8DNtcv2xsdG6SHvMbk 20HckFA3dxB/XORwDkHgEVHeiJqbJGZM4w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wiseflow.dk/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://wiseflow.dk/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wiseflow.dk/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Form\u00e5let er at facilitere digital h\u008c\u00e5ndtering af skriftlige eksaminer."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The purpose is to facilitate digital management of written exams."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "WISEflow"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "WISEflow"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrimaryAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.5",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "gn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "norEduPersonLIN",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.2428.90.1.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "preferredLanguage",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.39",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacPersonalUniqueID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.15",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.poliba.it/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem-support@poliba.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:luigi.gatto@poliba.it"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:giuseppe.lucatorto@poliba.it"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.poliba.it/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2015-09-01T08:06:49Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.poliba.it/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.poliba.it/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "poliba.it"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "studenti.poliba.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.poliba.it/ateneo/ideminfo"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.poliba.it/ateneo/ideminfo"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Politecnico di Bari"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Politecnico di Bari"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for the users of Politecnico di Bari"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti del Politecnico di Bari"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.poliba.it/logo80x60.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idp.poliba.it/logo80x60.png",
                    "lang": "it",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idp.poliba.it/logo16x16.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.poliba.it/logo16x16.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.poliba.it/ateneo/idemprivacy"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.poliba.it/ateneo/idemprivacy"
                  }
                ]
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:41.109481,16.878798"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEEzCCAvugAwIBAgIJAKbucxOGsbx5MA0GCSqGSIb3DQEBCwUAMIGfMQswCQYD\nVQQGEwJJVDEOMAwGA1UECAwFSXRhbHkxDTALBgNVBAcMBEJhcmkxHDAaBgNVBAoM\nE1BvbGl0ZWNuaWNvIGRpIEJhcmkxFDASBgNVBAsMC1NldHRvcmUgSUNUMRcwFQYD\nVQQDDA53d3c0LnBvbGliYS5pdDEkMCIGCSqGSIb3DQEJARYVbHVpZ2kuZ2F0dG9A\ncG9saWJhLml0MB4XDTE1MDgyMjE3Mjg0NloXDTQ1MDgxNDE3Mjg0NlowgZ8xCzAJ\nBgNVBAYTAklUMQ4wDAYDVQQIDAVJdGFseTENMAsGA1UEBwwEQmFyaTEcMBoGA1UE\nCgwTUG9saXRlY25pY28gZGkgQmFyaTEUMBIGA1UECwwLU2V0dG9yZSBJQ1QxFzAV\nBgNVBAMMDnd3dzQucG9saWJhLml0MSQwIgYJKoZIhvcNAQkBFhVsdWlnaS5nYXR0\nb0Bwb2xpYmEuaXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCrlko9\n49/dYS4bU1T718ZCj6LYl/NFy/7kSfqRFeqal0E8OaD02r/+z8LbZPinSOgrw2DP\neFXTZv04ZkkOu4dyQKqkOndOVo09VNjRsJS7YK/xHkpCUC260vIV0q1XrNzYaMJ/\nUu5g2xox2j3nkfyc8wdpQlUQ6j15mxDCAYUfCsMUmvdJ0850TaO2RLCH5gduuJiA\nD1c3YN/G94j9KY7jM8grYyf5A3SGp5n8281ZuKPGKY4TGrxUC46qkeQr4mK7HhJn\nlzDfABYRNjbuWe495XnMCnyJNS/7EylsJ+Cc+B3qEXg/ewdJKLrR3w+X4wgnW78S\nO69S3xYiT2VRde7VAgMBAAGjUDBOMB0GA1UdDgQWBBTdX5So6SB4K2IX59likNO8\n2/usIjAfBgNVHSMEGDAWgBTdX5So6SB4K2IX59likNO82/usIjAMBgNVHRMEBTAD\nAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQBZs5MMUimtJQKXrNDbOYsXg6yTUhvRQPLj\nkv2M3cH/8lhqnYpU9C3X4FrVPbxx5SxqBBTw8SOUAZfEAlvN+OJC1efq03VQmH3A\nM/GqgwM4ztNUIz1kWgDdIEkUZBEJ2BBN4VP0xH1s0f1gKFMxqOE4BwPNmU7ZFD4O\nQM7qOcq58voRCohpfUeVG6V3BkpKyx/VHFaJpkucI1U/Gw4S/6Slp4qLJ6eHIbQB\nbBEuc7suv0QEIC2VgbkdQ1muEZJfGPaxTYn00BZCPgUG2ka7hgRmKzNDdGjRe8YT\nICP6wM+pztMtIPWic53DejjEukR860nQx4/53saWj3RRjkuTouv2"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEEzCCAvugAwIBAgIJAKbucxOGsbx5MA0GCSqGSIb3DQEBCwUAMIGfMQswCQYD\nVQQGEwJJVDEOMAwGA1UECAwFSXRhbHkxDTALBgNVBAcMBEJhcmkxHDAaBgNVBAoM\nE1BvbGl0ZWNuaWNvIGRpIEJhcmkxFDASBgNVBAsMC1NldHRvcmUgSUNUMRcwFQYD\nVQQDDA53d3c0LnBvbGliYS5pdDEkMCIGCSqGSIb3DQEJARYVbHVpZ2kuZ2F0dG9A\ncG9saWJhLml0MB4XDTE1MDgyMjE3Mjg0NloXDTQ1MDgxNDE3Mjg0NlowgZ8xCzAJ\nBgNVBAYTAklUMQ4wDAYDVQQIDAVJdGFseTENMAsGA1UEBwwEQmFyaTEcMBoGA1UE\nCgwTUG9saXRlY25pY28gZGkgQmFyaTEUMBIGA1UECwwLU2V0dG9yZSBJQ1QxFzAV\nBgNVBAMMDnd3dzQucG9saWJhLml0MSQwIgYJKoZIhvcNAQkBFhVsdWlnaS5nYXR0\nb0Bwb2xpYmEuaXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCrlko9\n49/dYS4bU1T718ZCj6LYl/NFy/7kSfqRFeqal0E8OaD02r/+z8LbZPinSOgrw2DP\neFXTZv04ZkkOu4dyQKqkOndOVo09VNjRsJS7YK/xHkpCUC260vIV0q1XrNzYaMJ/\nUu5g2xox2j3nkfyc8wdpQlUQ6j15mxDCAYUfCsMUmvdJ0850TaO2RLCH5gduuJiA\nD1c3YN/G94j9KY7jM8grYyf5A3SGp5n8281ZuKPGKY4TGrxUC46qkeQr4mK7HhJn\nlzDfABYRNjbuWe495XnMCnyJNS/7EylsJ+Cc+B3qEXg/ewdJKLrR3w+X4wgnW78S\nO69S3xYiT2VRde7VAgMBAAGjUDBOMB0GA1UdDgQWBBTdX5So6SB4K2IX59likNO8\n2/usIjAfBgNVHSMEGDAWgBTdX5So6SB4K2IX59likNO82/usIjAMBgNVHRMEBTAD\nAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQBZs5MMUimtJQKXrNDbOYsXg6yTUhvRQPLj\nkv2M3cH/8lhqnYpU9C3X4FrVPbxx5SxqBBTw8SOUAZfEAlvN+OJC1efq03VQmH3A\nM/GqgwM4ztNUIz1kWgDdIEkUZBEJ2BBN4VP0xH1s0f1gKFMxqOE4BwPNmU7ZFD4O\nQM7qOcq58voRCohpfUeVG6V3BkpKyx/VHFaJpkucI1U/Gw4S/6Slp4qLJ6eHIbQB\nbBEuc7suv0QEIC2VgbkdQ1muEZJfGPaxTYn00BZCPgUG2ka7hgRmKzNDdGjRe8YT\nICP6wM+pztMtIPWic53DejjEukR860nQx4/53saWj3RRjkuTouv2"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Politecnico di Bari"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Politecnico di Bari"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.poliba.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.poliba.it"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Politecnico di Bari"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Politecnico di Bari"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.ate.grayzone.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.ate.grayzone.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ate.grayzone.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.ate.grayzone.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ate.grayzone.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ate.grayzone.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ate.grayzone.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.ate.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.ate.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.ate.grayzone.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.ate.grayzone.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.ate.grayzone.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.ate.grayzone.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.ate.grayzone.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIJAOFbsjIjhL4IMA0GCSqGSIb3DQEBCwUAMCQxIjAgBgNV\nBAMTGXd3dy5hdGUuZ3JheXpvbmUubGFkb2suc2UwHhcNMTYwMzE0MTEwNTQ2WhcN\nMjYwMzEyMTEwNTQ2WjAkMSIwIAYDVQQDExl3d3cuYXRlLmdyYXl6b25lLmxhZG9r\nLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0n8ApDyLZ58CJBtW\nWtNfahUCB04p4a6toTAn9J2aX20HACHeJiOhNANcUGKCA2FRiuc7CjjITHRdmbQU\nbfR0efJrYeUtoksnSXREfbaJDFQATPYpnq2BMB1HSna2Cfv5SToHTgFE/46hO9Zg\nuq57w0HxMO9pqNggNG7I5IEhUF5+xihhPXHar1mYpjp3+zOdr+XJrIZ3Tq1nQPFA\nZcKPSKFKfjA8lGqCImPCblPpg8Vgb7sPJiRHpVRpkLN9FSAGY1HW1gvtxFHe5TVy\nkgmrSbD07ejpIdOwIvt3mG5SpUmrt624TWqG/thU1zv3/PaiJ0i4zrPTZa5SNS8M\nGjnVpQIDAQABo3EwbzBOBgNVHREERzBFghl3d3cuYXRlLmdyYXl6b25lLmxhZG9r\nLnNlhihodHRwczovL3d3dy5hdGUuZ3JheXpvbmUubGFkb2suc2UvZ3VpLXNwMB0G\nA1UdDgQWBBS/KhR5h4DRaP0c+BZ8cDE8R8827zANBgkqhkiG9w0BAQsFAAOCAQEA\nHVLqnI/jDRO3StabYrvbavL23VbdKX/JDUV9vRam6uR+e6pbKb0xmP3F7P87WYIU\niJoJ3xR3NKfXsWVI4BCR0auhieCZcSbQumClfQuCy6fXxvpmmq4qIrlxdb6W6lz/\nC8vTQEetpqdtNG6IB62TfYPe9io7TnAgJpzWzZVxjp7UoXhK8vPyMK60Gah3iKxA\nsyYvZm/MaTEqMHF2oO64rqUoZuqRZCWE9VbbvNvN86pGnFWKgZRcBRpLWfSNAZHt\nAF5ZO1tO/syhzq3svhBKw43krQdg+z8EGBzqFTALxf+XE5JsNxLPO3APW9qEweX+\npSPgM5nsisjeJf8vs4ejpA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.ate.grayzone.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ate.grayzone.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.ate.grayzone.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ate.grayzone.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ate.grayzone.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ate.grayzone.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ate.grayzone.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.ate.grayzone.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.ate.grayzone.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.ate.grayzone.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib-sp-01.ads.ntu.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cross"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Richard.cross@ntu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hallam"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lee.hallam@ntu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lee"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib-sp-01.ads.ntu.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-19T10:36:28Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NTU Service Provider"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ntu.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Nottingham Trent University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-sp-01.ads.ntu.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-sp-01.ads.ntu.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-sp-01.ads.ntu.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib-sp-01.ads.ntu.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-sp-01.ads.ntu.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib-sp-01.ads.ntu.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAMQFC8lRUNLGMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHNoaWItc3AtMDEuYWRzLm50dS5hYy51azAeFw0xNjA0MDcxMjMyMTJaFw0y\n\t\t\t\t\t\tNjA0MDUxMjMyMTJaMCMxITAfBgNVBAMTGHNoaWItc3AtMDEuYWRzLm50dS5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM90EjoOe3tjpnHYBme4\n\t\t\t\t\t\tL7NQzeWTboNlYQlUPpSCCG63Tgzi5+A7mUz248MBNFsdrCUgQr70LFrBrsZiVQ/u\n\t\t\t\t\t\twR8QX8j8/72bNafpNwSos4F7JRq6noBYgLpNGa2ylL2kxZqS4sNkodNae7u9STsG\n\t\t\t\t\t\tvDy3AbikuTUPUG3sSgi49Um8IVETWuug/4hdHpCyqM0ARZm6IUGw29YHLWYLWwqM\n\t\t\t\t\t\tySTcv1CRClLw0UREaFs4tKFja3Qh/CVMJHbN6/ZSUW283N2BL9N5KdUGo/RyoVJl\n\t\t\t\t\t\tHFA5OYzTsKYgf4bws/m3KP3PUtWJ4mVtmtSIFPXfGdZepZ33IyjxqrgMzR3MoON6\n\t\t\t\t\t\tPHMCAwEAAaNGMEQwIwYDVR0RBBwwGoIYc2hpYi1zcC0wMS5hZHMubnR1LmFjLnVr\n\t\t\t\t\t\tMB0GA1UdDgQWBBQ9ZqVnb0Qe4uA1YGIBFNYh1VTV4zANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAU4t8ChDxT0ympq5MnHrZ25QVguB9gTeJmQR7PeFLiICgi+XRubh0I0cuHhR/\n\t\t\t\t\t\tpB8i0EOUU5o462caxI0qSnBUIiQzt7OTGD0ZErTtoQ+eE9ChIAnjNg9KhClSMG+e\n\t\t\t\t\t\tm1QDKhyaADfIhXsA8vg9a7rJrBD6dZa5kksGWxPyAzXUYqOSYJ7ftODHpLnF2fWO\n\t\t\t\t\t\tHiIRxOlAqKT7g6P/jFGQGkSIXV7gkDHm6IHWIYopsGsdYBEwOfqL8Gie47Jgb6X+\n\t\t\t\t\t\t/Og8wJO9K41UB7l4DjoBS8kgsIQrU1mjIsxWMruhzjWrPU6U9s4hcE4K5e7YbBCd\n\t\t\t\t\t\tyZT55jrZJ2bHpXQ3QjiNyjgtIw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-sp-01.ads.ntu.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib-sp-01.ads.ntu.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib-sp-01.ads.ntu.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shib-sp-01.ads.ntu.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shib-sp-01.ads.ntu.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shib-sp-01.ads.ntu.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://expert.uhrdemo.antagning.se/aws-sp-en",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al2"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://www.swamid.se/assurance-requirement",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://expert.uhrdemo.antagning.se/aws-sp-en",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://expert.uhrdemo.antagning.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://expert.uhrdemo.antagning.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://expert.uhrdemo.antagning.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://expert.uhrdemo.antagning.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://expert.uhrdemo.antagning.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://expert.uhrdemo.antagning.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "expert.uhrdemo.antagning.se"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://expert.uhrdemo.antagning.se/aws-sp-en"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRzCCAi+gAwIBAgIJAJfxsCaOWkxRMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\nBAMTG2V4cGVydC51aHJkZW1vLmFudGFnbmluZy5zZTAeFw0xNDEwMjAxMjUzMTha\nFw0yNDEwMTcxMjUzMThaMCYxJDAiBgNVBAMTG2V4cGVydC51aHJkZW1vLmFudGFn\nbmluZy5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANDwqlMZ9iz5\nVJANM6co6vl//O6rIjhm/dbqwqwPWRUQJEi9a3wp47tpCraKfAd2iIjsTa3+dvuc\njvIuxp355ZOe9wkXADkeqpdD3HqxgRMf31v1zxd6ABeaBmmFLihSTShmrf69wvTN\naaU2N0pXUCTM6prEQ/EOMvk7kxFJOTf2ciELWCGAO+bcLoTZ8pXnKZ1hze9vUGJy\n9SSAq4gDgzB2yKRV2UwXRCYUthcewb0RlejYtJkJlu21XzJKo5A+CIx7DEj66ZOG\nfk8OdrTVtKZTqzZD2yl7F82yIoo1UCFkVWSmUDj1ObXEzI5x940UoYr0twwQ5jMg\n/AmOdFBD/qkCAwEAAaN4MHYwVQYDVR0RBE4wTIIbZXhwZXJ0LnVocmRlbW8uYW50\nYWduaW5nLnNlhi1odHRwczovL2V4cGVydC51aHJkZW1vLmFudGFnbmluZy5zZS9h\nd3Mtc3AtZW4wHQYDVR0OBBYEFKCp9bZIbKEPAefJavvCWNo4ZbQDMA0GCSqGSIb3\nDQEBBQUAA4IBAQCa8NZ091egdPM83IaUIIBBCQjWWkynQWC5mANETQ3kkNOk0+Ex\nW+DnlOpzRUf0zgsDFnyaGxX2AUWwldzUPE1Sbx8iGxMrlvRFgsRIIhgvcs4g27Fz\nR9x/WVKJnAO3RIkIBmAcN/fpnoxNUiSnM3CumjuTWzOUPXlpRApoXvfLeBOdNljL\nuCP0zpdAAilt9SIJtPY16GGUxf3Q7MLtXM6wlMMwTwNFqybbLED1h5sWWzgy6f2L\no5gjWAsejZSBtsnrDMnIiVxmpC0lRAs01YZNzubAE/4nOgK0UkDcUvKRe71maUng\nt73BO6E9LjRk4iDy6Je9FYTwCAosy3V6dZxD"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=expert.uhrdemo.antagning.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://expert.uhrdemo.antagning.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://expert.uhrdemo.antagning.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://expert.uhrdemo.antagning.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://expert.uhrdemo.antagning.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://expert.uhrdemo.antagning.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://expert.uhrdemo.antagning.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://expert.uhrdemo.antagning.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://expert.uhrdemo.antagning.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://expert.uhrdemo.antagning.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayf.minibib.dk/fsv",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayf.minibib.dk/fsv",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2010-10-28T09:51:27Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayf.minibib.dk/fsv/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fsv.minibib.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Forsvarets Bibliotek"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Danish Defence Library"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "fsv.minibib.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICwDCCAagCAQcwDQYJKoZIhvcNAQELBQAwJjEkMCIGA1UEAwwbaHR0cHM6Ly93\nYXlmLm1pbmliaWIuZGsvZnN2MB4XDTE1MDEwMTAwMDAwMFoXDTI1MTIzMTIzNTk1\nOVowJjEkMCIGA1UEAwwbaHR0cHM6Ly93YXlmLm1pbmliaWIuZGsvZnN2MIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAx4gMCmoQU7iOGfiCda4DnhIggst2\n0fUCHtwaQrHoxQlOa0s5FgDalbnNTw36dCXSGYaz17JgyUDJonTwhjyA0CqPm5Pm\nn9/hFBUvyP/t+bEgV9r3/odQx72VfY7M55qUlY6ex2f1qD1gcpFgSTtADlZswec5\nWqpEt+ie+vsMXq8HabhMVZ2EjXe90vgMk/xGfrVwDvupUPBS/2DJSZ1JEmkqi0hx\nctNQ9qgTZmEcAaQkuv3VGcsYtLeY/IISlA+ARzmVWr5+uSetnCXV4jnDEclACKee\nxl0Ky+tyra4yHF3Xavgmcmebd+xHVDiM+No6BXMu9zBTp7cp5ShLzsNQSQIDAQAB\nMA0GCSqGSIb3DQEBCwUAA4IBAQCzm8tArdj5hPaX5D4YSQfelOgYx85np+xTsV2e\n9B61sXz6cmeJhhXG5kopY25z47llxJNLNhIwYLcR6NMIXx3K0xuKVnUo2U1c8BTk\nar4OyNyenIMyJBtsRzrxSiISOeGwCpmMT8Lv1pg0QD2lJzBHiJF1ERDhwyRdLr5c\nQfeNv2Ip3MTZrAfB+w+MwB9qBK7+pIH/5ycxrHCDEfdA8iwQM8PP3EVXyQLOsd3R\nRvRh8L5qAmqKILhYkC4VV72qKZGsvzyWeKC752MsncEQF+fFHftvLSCWrTxaLWZD\nG9baPBH3swAjkG8Aa/+wabJPIBCF5mR8nO9gQQk4wgs17mS6"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Forsvarets Bibliotek"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Danish Defence Library"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://forsvaret.dk/FAK/bibliotek/Pages/default.aspx"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://forsvaret.dk/FAK/eng/departments/library/Pages/default.aspx"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Forsvarets Bibliotek"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Danish Defence Library"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.mtholyoke.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jmaryott@mtholyoke.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeremy Maryott"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rpeterso@mtholyoke.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ron Peterson"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jmaryott@mtholyoke.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeremy Maryott"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.mtholyoke.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.mtholyoke.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.mtholyoke.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.mtholyoke.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.mtholyoke.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.mtholyoke.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mtholyoke.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mount Holyoke College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAJLHPh0wvbbq2rKg/fYPlc/eTL6CMA0GCSqGSIb3DQEB\nBQUAMBwxGjAYBgNVBAMTEWlkcC5tdGhvbHlva2UuZWR1MB4XDTExMDQwNjEzNDYz\nNFoXDTMxMDQwNjEzNDYzNFowHDEaMBgGA1UEAxMRaWRwLm10aG9seW9rZS5lZHUw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCg6TefcVZH73MAVG3ga4dT\n/voaUrbI6ns4+sK0oUcq+0MA4ENv2vzvNQUQbGnxaui2aKyXfAE40M7iyVqmP9i1\nR4iv1V9/HciiGJE9vN99D6WexJ7IN5OoOGucgvChqxYXw3L3xKijXpOsqreY0YWe\nRquJ1iKvaPXQUYgN/EoVeyoLQRnWPIWbs+HhKpgk7nyG8GioCu5FV8nGhiFw5686\n6dOhBV4nDgfjruj+7WHkbibTnig5DrGnGX6xBuJ4rAiqK8RsFo2FdN2IrD3jq8+l\ns/0VQWJRHIP3j3Ed2XdMmPHrAQzKiYXEPlhXLRhfZrOXmP/d6iudqZ35IKQBIFIn\nAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEWlkcC5tdGhvbHlva2UuZWR1hihodHRwczov\nL2lkcC5tdGhvbHlva2UuZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQ3cyqs\nmOkVuWW3TG37Pj91nh8QLTANBgkqhkiG9w0BAQUFAAOCAQEAPdlrDqY+t/4VRqp0\n7RrNLTj9hMv7uDSzYOVbdNTddeKHeICk099HdZOtFqOaRHweJThUf9R8UmJaVha8\nWCKKavsWd/UMwFjMRzbrQE7c0GxkzJ2dmqwRD7LS8flSy7MgnV8IUXGS2UCHC62P\nj4k1aL6a4WRJTbKFXDsygPui7Fq3lHu2Gak30seK80yKt0MiTA9YGPYYGjqfoG05\ncG0XRJrEP6HIdLq10N59R+sc38y3CkE0oIEQHRnXy4C6OJoM+JDou/86e/qJVbLg\nTimgEPq/+TG6lDTgqjFctblZ8vbJbJvYkAe+4fXrASxBJ7KPGRig7NtfV/Kcb34p\ncTHctQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mount Holyoke College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mtholyoke.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Mount Holyoke College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.cardiffmetsu.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.cardiffmetsu.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-06-12T14:11:52Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cardiff Met Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cardiffmetsu.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cardiffmetsu.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cardiffmetsu.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.cardiffmetsu.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cardiffmetsu.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cardiffmetsu.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.cardiffmetsu.co.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cardiffmetsu.co.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cardiffmetsu.co.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.cardiffmetsu.co.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cardiffmetsu.co.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.cardiffmetsu.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.cardiffmetsu.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cardiffmetsu.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.cardiffmetsu.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cardiffmetsu.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.cardiffmetsu.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://xenosmilus2.umdc.umu.se:8086/coc/sp.xml",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.edugain.org/dataprotection/coc-eu-01-draft"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://xenosmilus2.umdc.umu.se:8086/coc/sp.xml",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://xenosmilus2.umdc.umu.se:8086/disco",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICIzCCAYwCCQDFqR2p3amCSjANBgkqhkiG9w0BAQUFADBWMQswCQYDVQQGEwJT\nRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UECgwDVW1VMQwwCgYDVQQLDANJVFMxHDAa\nBgNVBAMME2xpbmdvbi5sYWRvay51bXUuc2UwHhcNMTMwNjE0MTY1MjAyWhcNMTQw\nNjE0MTY1MjAyWjBWMQswCQYDVQQGEwJTRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UE\nCgwDVW1VMQwwCgYDVQQLDANJVFMxHDAaBgNVBAMME2xpbmdvbi5sYWRvay51bXUu\nc2UwgZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGBAM8nCb97J2QNi/U+4EnR2vL/\nvGtUM44dyOrdQ4xdD/feHyu0kWoNal/8CXJTYtDVrbKMg90fakPfw6Lw5KxQTzGl\nR6qNRyuuMq7KIgRzlbZEWiAh1YKQMOn+C3qIM0HqkfjD/rnCokIpFhGFi+7886AD\nVNB5CnUQXrSTAkUJzVS7AgMBAAEwDQYJKoZIhvcNAQEFBQADgYEABfQAzyDkwIQZ\nHu3tPi7QvJbdTDH8F3q8iSQwOT7MvxmHmCO/DZFwYu5jjYg/FtBfpbh8mQTziCy8\nFyVMuMKNSZn2rEIJF1ghgQqtHwn08zsPPhD9XW0LXeP6Exl/xIguWJElU9JzmPU6\naZOix3ahmr0PwcIhFbWaZvsjL46MdHI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICIzCCAYwCCQDFqR2p3amCSjANBgkqhkiG9w0BAQUFADBWMQswCQYDVQQGEwJT\nRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UECgwDVW1VMQwwCgYDVQQLDANJVFMxHDAa\nBgNVBAMME2xpbmdvbi5sYWRvay51bXUuc2UwHhcNMTMwNjE0MTY1MjAyWhcNMTQw\nNjE0MTY1MjAyWjBWMQswCQYDVQQGEwJTRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UE\nCgwDVW1VMQwwCgYDVQQLDANJVFMxHDAaBgNVBAMME2xpbmdvbi5sYWRvay51bXUu\nc2UwgZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGBAM8nCb97J2QNi/U+4EnR2vL/\nvGtUM44dyOrdQ4xdD/feHyu0kWoNal/8CXJTYtDVrbKMg90fakPfw6Lw5KxQTzGl\nR6qNRyuuMq7KIgRzlbZEWiAh1YKQMOn+C3qIM0HqkfjD/rnCokIpFhGFi+7886AD\nVNB5CnUQXrSTAkUJzVS7AgMBAAEwDQYJKoZIhvcNAQEFBQADgYEABfQAzyDkwIQZ\nHu3tPi7QvJbdTDH8F3q8iSQwOT7MvxmHmCO/DZFwYu5jjYg/FtBfpbh8mQTziCy8\nFyVMuMKNSZn2rEIJF1ghgQqtHwn08zsPPhD9XW0LXeP6Exl/xIguWJElU9JzmPU6\naZOix3ahmr0PwcIhFbWaZvsjL46MdHI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://xenosmilus2.umdc.umu.se:8086/acs/coc/redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://xenosmilus2.umdc.umu.se:8086/acs/coc/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www3.eduid.cz/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tom\u00e1\u0161ek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jan.tomasek@cesnet.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Oppolzer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jan.oppolzer@cesnet.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www3.eduid.cz/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2014-02-03T10:42:36Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/sp-group/aa.cesnet.cz"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CESNET"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CESNET"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cesnet.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CESNET"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www3.eduid.cz/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www3.eduid.cz/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www3.eduid.cz/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www3.eduid.cz/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www3.eduid.cz/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www3.eduid.cz/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www3.eduid.cz/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.eduid.cz/en/index"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.eduid.cz"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Informational web of the eduID.cz federation. It brings informations to end users and to technical staff at end institutions."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Informa\u010dn\u00ed web projektu eduID.cz, kter\u00fd p\u0159in\u00e1\u0161\u00ed informace jak pro koncov\u00e9 u\u017eivatele tak pro spr\u00e1vce na jednotliv\u00fdch instituc\u00edch."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.eduid.cz/eduid-logo-150.png",
                    "height": "63",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "150"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "eduID.cz"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "eduID.cz"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www3.eduid.cz/shibboleth"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www3.eduid.cz"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEDCCAfigAwIBAgIJAIxP8cTUiGsTMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDXd3dzMuZWR1aWQuY3owHhcNMTQwMjAxMTc1ODA1WhcNMTcwMTMxMTc1ODA1\nWjAYMRYwFAYDVQQDEw13d3czLmVkdWlkLmN6MIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAyNfO9oxDUu8gABeGHQ6hvtQRYEsp5DnPy40Lugfetbr49eX2\ndemuocrQIMUY8i/r1wo+ZRhVtPKYj36/OGUrYh3nNpYsVKO3VIk1CNTWwuQi/wuH\nzH5RUAh0aHGIA4zGYOfUnaczACjxN5aKOuoVlXIJ7eMuVsKGfA8og+VO4A+lhY8B\npXgk13OuR73wSbbwROHwPQa58rjFir88Al70KycuYTv5F7WcTzBEy+ag6nAGz+fP\nDR9OKWfSepFNqom6PUAUCyXQdjn07sy2EnoE4BODKnX+yueXWaXk8DAwK7uUfk45\nNS7vJEToXCCDBqRJMncNzD9jngIp64SQFIMppwIDAQABo10wWzA6BgNVHREEMzAx\ngg13d3czLmVkdWlkLmN6hiBodHRwczovL3d3dzMuZWR1aWQuY3ovc2hpYmJvbGV0\naDAdBgNVHQ4EFgQUIzEka3BrLts+IxnQs5Vu9e1E3ucwDQYJKoZIhvcNAQEFBQAD\nggEBABCZ7nwiWmW6njEBHHabyX6FhaurJ73UlDO3JS7mUKjycFkA0HlabWWEeTON\njcdtHHOzxPodqNe2dtQKa/+fauvTsnKQkBj/f6ESGQAXySuKVgZUs3aXG7C86i01\nlYMJE03P1TwHX60felfwbR4xKRoypz9pOcmqdjxMOpb0+teajFjOShL/Lm0HQs4H\nFg9FttPBtPrn9khoZcIebOlktQATVCrazQKU0MK2smgxcqIWBoeanyhHuFbNxA/Q\n5FX1LepWs6GsCmK1qxhXj1JRBisqPEaGuauhp1CgtJJdwj5DJ3Fcw29mujFvdnln\nQioqbJmv4wcuTrPvTGy8h1+Q4iI="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www3.eduid.cz"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www3.eduid.cz/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www2.eduid.cz/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.eduid.cz/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://eduid.cz/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www3.eduid.cz/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www3.eduid.cz/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www3.eduid.cz/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www3.eduid.cz/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www3.eduid.cz/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www3.eduid.cz/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ifto.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ronaldo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "parente@ifto.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ifto.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0jCCAroCAQAwDQYJKoZIhvcNAQEFBQAwga4xLjAsBgNVBAoTJUlGVE8gLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkbyBUb2NhbnRpbnMxDDAKBgNVBAsTA0dUSTEiMCAG\nCSqGSIb3DQEJARYTcGFyZW50ZUBpZnRvLmVkdS5icjEPMA0GA1UEBxMGUGFsbWFz\nMRIwEAYDVQQIEwlUb2NhbnRpbnMxCzAJBgNVBAYTAkJSMRgwFgYDVQQDEw9pZHAu\naWZ0by5lZHUuYnIwHhcNMTUwNDE2MTUwNzEyWhcNMTgwNDE1MTUwNzEyWjCBrjEu\nMCwGA1UEChMlSUZUTyAtIEluc3RpdHV0byBGZWRlcmFsIGRvIFRvY2FudGluczEM\nMAoGA1UECxMDR1RJMSIwIAYJKoZIhvcNAQkBFhNwYXJlbnRlQGlmdG8uZWR1LmJy\nMQ8wDQYDVQQHEwZQYWxtYXMxEjAQBgNVBAgTCVRvY2FudGluczELMAkGA1UEBhMC\nQlIxGDAWBgNVBAMTD2lkcC5pZnRvLmVkdS5icjCCASIwDQYJKoZIhvcNAQEBBQAD\nggEPADCCAQoCggEBALL4yXMUcWh6FTF4lQk3AA6kuUlwHMhzXRNrD2hgzSZOFCfi\nsMgEGLE52GEZrtQyu/TTwwdsAd2wp8x3C24JOcJi+/aJ5uwhhORWlygmU7jH1A8D\nP7GI+Spv4lwjN2IDJbEFTkhQUO+TCFojxjfR9ogYl1agiI1IVaI1/GT3nBb2s4+d\nNxeR5sg2yuJKw8lvDQZhLiQpNJ4DdwtPhxYE81Q447tny0BloVjENt/0zgLaw5PY\nrW5AB2zwFni0ZayoalGd/X4OS013VlWXzzlNryHo3sHfbzdRIMQMjzHLwNDE0KUD\na/namLQn4JeAh7UPQejJ3NA86UUDoi9MYLjtEo0CAwEAATANBgkqhkiG9w0BAQUF\nAAOCAQEARD657xlPwu3TOncmCBNQGYLIXr1WfeZcLxbU2WAZZtA5Y/esTt58xlt8\nQllL0GOKrS/JBMl/6E0OP0tZWq5A+3ERxmgzxLSe33MJ8ywZRSTexqrCop3TYHs5\nezdOr4zxyZHX3300UVkP4nmtjGriRkcxpOKAo/T/DRLkFTeHsWufIkDSo4gaQpH9\np0i71SOGIoP04RQ6StU3DYC+Ug+CuRVrkPGe2nj9/xwfr6yQ57SOAaucmbxC3wLP\nbOyvYzQg+nOb31kvM2UosnGcpLcVHT6Tgupu5je2Hq8oTgOFPLufjqEIp735x/Yh\n6KX9jDqVrd3n8FtVU0WA7kZ5Lz+EnQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ifto.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ifto.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ifto.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ifto.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ifto.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ifto.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ifto.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ifto.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifto.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifto.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFTO - Instituto Federal do Tocantins"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFTO - Instituto Federal do Tocantins"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFTO - Instituto Federal do Tocantins"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFTO - Instituto Federal do Tocantins"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0jCCAroCAQAwDQYJKoZIhvcNAQEFBQAwga4xLjAsBgNVBAoTJUlGVE8gLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkbyBUb2NhbnRpbnMxDDAKBgNVBAsTA0dUSTEiMCAG\nCSqGSIb3DQEJARYTcGFyZW50ZUBpZnRvLmVkdS5icjEPMA0GA1UEBxMGUGFsbWFz\nMRIwEAYDVQQIEwlUb2NhbnRpbnMxCzAJBgNVBAYTAkJSMRgwFgYDVQQDEw9pZHAu\naWZ0by5lZHUuYnIwHhcNMTUwNDE2MTUwNzEyWhcNMTgwNDE1MTUwNzEyWjCBrjEu\nMCwGA1UEChMlSUZUTyAtIEluc3RpdHV0byBGZWRlcmFsIGRvIFRvY2FudGluczEM\nMAoGA1UECxMDR1RJMSIwIAYJKoZIhvcNAQkBFhNwYXJlbnRlQGlmdG8uZWR1LmJy\nMQ8wDQYDVQQHEwZQYWxtYXMxEjAQBgNVBAgTCVRvY2FudGluczELMAkGA1UEBhMC\nQlIxGDAWBgNVBAMTD2lkcC5pZnRvLmVkdS5icjCCASIwDQYJKoZIhvcNAQEBBQAD\nggEPADCCAQoCggEBALL4yXMUcWh6FTF4lQk3AA6kuUlwHMhzXRNrD2hgzSZOFCfi\nsMgEGLE52GEZrtQyu/TTwwdsAd2wp8x3C24JOcJi+/aJ5uwhhORWlygmU7jH1A8D\nP7GI+Spv4lwjN2IDJbEFTkhQUO+TCFojxjfR9ogYl1agiI1IVaI1/GT3nBb2s4+d\nNxeR5sg2yuJKw8lvDQZhLiQpNJ4DdwtPhxYE81Q447tny0BloVjENt/0zgLaw5PY\nrW5AB2zwFni0ZayoalGd/X4OS013VlWXzzlNryHo3sHfbzdRIMQMjzHLwNDE0KUD\na/namLQn4JeAh7UPQejJ3NA86UUDoi9MYLjtEo0CAwEAATANBgkqhkiG9w0BAQUF\nAAOCAQEARD657xlPwu3TOncmCBNQGYLIXr1WfeZcLxbU2WAZZtA5Y/esTt58xlt8\nQllL0GOKrS/JBMl/6E0OP0tZWq5A+3ERxmgzxLSe33MJ8ywZRSTexqrCop3TYHs5\nezdOr4zxyZHX3300UVkP4nmtjGriRkcxpOKAo/T/DRLkFTeHsWufIkDSo4gaQpH9\np0i71SOGIoP04RQ6StU3DYC+Ug+CuRVrkPGe2nj9/xwfr6yQ57SOAaucmbxC3wLP\nbOyvYzQg+nOb31kvM2UosnGcpLcVHT6Tgupu5je2Hq8oTgOFPLufjqEIp735x/Yh\n6KX9jDqVrd3n8FtVU0WA7kZ5Lz+EnQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFTO - Instituto Federal do Tocantins"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFTO - Instituto Federal do Tocantins"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifto.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifto.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFTO - Instituto Federal do Tocantins"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFTO - Instituto Federal do Tocantins"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://saml.lynda.com",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Flynn"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:miflynn@linkedin.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Flynn"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:miflynn@linkedin.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://saml.lynda.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-10-06T14:42:49Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "lynda.com, Inc."
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "lynda.com, Inc."
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lynda.com"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lynda.com"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e484"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e484"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://saml.lynda.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://saml.lynda.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://saml.lynda.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://saml.lynda.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "lynda.com ist eines der f\u00fchrenden Online-Learning-Unternehmen, das Nutzer dabei unterst\u00fctzt, pers\u00f6nliche F\u00e4higkeiten im Bereich Business, Software, Technologie und Kreativit\u00e4t zu entwickeln und pers\u00f6nliche und berufliche Ziele besser zu erreichen. Durch Abonnements f\u00fcr Einzelpersonen, Unternehmen, akademische und staatliche Einrichtungen haben Mitglieder Zugang zur lynda.com Videothek mit ansprechenden und hochwertigen Kursen, die von anerkannten Industrie-Experten unterrichtet werden. Das Unternehmen bietet auch Inhalte auf Deutsch, Franz\u00f6sisch und Spanisch unter dem Markennamen video2brain an."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "lynda.com is a leading online learning company that helps anyone learn business, software, technology and creative skills to achieve personal and professional goals. Through individual, corporate, academic and government subscriptions, members have access to the lynda.com video library of engaging, top-quality courses taught by recognized industry experts. The company also provides German, French and Spanish language content under the video2brain brand name."
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "lynda.com"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "lynda.com"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://saml.lynda.com"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDITCCAgmgAwIBAgIJAPS3fySJTyfaMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmh0dHBzOi8vc2FtbC5seW5kYS5jb20wHhcNMTUxMDA1MTcxNTA0WhcNMTgx\nMDA0MTcxNTA0WjAhMR8wHQYDVQQDExZodHRwczovL3NhbWwubHluZGEuY29tMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArljPwyk0t7fUrSYp7IcHBSI1\n29pQXs+eFnLUVvyXZ6X2ESoR1IC25P4ShlrmGHzkXrDY5RMDfZXxOlEQ3Z05gDHb\nLpDO+AxF1mzRZZjCP+XN1lgHeAue+14WRRQ4t55zsrnrwECBwj5A7PBat/8qVbqS\neKJCfV21bKOeBD2g4nA9f1lJSMnoZ3tzOlysDg2oIbWbYqkX1NvalPO9smdtnsOk\npb4RgGRx4f2iF5mg348n5s6napEid1578JI4QmEYdY+FMMpCK1xVwfconbKqP7BR\nWZh/JqpZjiem86Tv68LHReSIpySEnDQILDfvOi6n+OpiVwAnbnGrI4Q2OM3DpQID\nAQABo1wwWjA5BgNVHREEMjAwghZodHRwczovL3NhbWwubHluZGEuY29thhZodHRw\nczovL3NhbWwubHluZGEuY29tMB0GA1UdDgQWBBQuFJx7I6SR9oV6iuEqwJPd0mSE\n0jANBgkqhkiG9w0BAQUFAAOCAQEAq9XpSOuF67tPtTB+WKHegyYI0wZ3GoJxjYPz\nvEgv+LYSYutkDJG6M5HDkjtxn+SqIqBTr6AxGYdol8WPICgVAlj1LV36NHtE8TUi\n1gC7gzv/XxVPhLpEsyx2vcOgY/J5Nziu0epPg98GSvmplDG0Z6YuSa/zp7I1Z73r\n3Mu/W8FJJqoSZjil6BPnXv1dbjgOjg8Z7eQjqDwr2ki/td69pvvEyqIQ/0i/5C5w\n0k0LQi2tiJfdQN1LzTP/z7uglW9MXtsgWQgiY1fbMAU5PLdneI0GHwDUYbnizdk2\nYlDBz1PhAHejnP2Sx6tnjNQ36qgiwvybuEhFWs2/jSOM4SWhyg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=https://saml.lynda.com"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://saml.lynda.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://saml.lynda.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://saml.lynda.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://saml.lynda.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://saml.lynda.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://saml.lynda.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "lynda.com"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "lynda.com"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "lynda.com ist eines der f\u00fchrenden Online-Learning-Unternehmen, das Nutzer dabei unterst\u00fctzt, pers\u00f6nliche F\u00e4higkeiten im Bereich Business, Software, Technologie und Kreativit\u00e4t zu entwickeln und pers\u00f6nliche und berufliche Ziele besser zu erreichen. Durch Abonnements f\u00fcr Einzelpersonen, Unternehmen, akademische und staatliche Einrichtungen haben Mitglieder Zugang zur lynda.com Videothek mit ansprechenden und hochwertigen Kursen, die von anerkannten Industrie-Experten unterrichtet werden. Das Unternehmen bietet auch Inhalte auf Deutsch, Franz\u00f6sisch und Spanisch unter dem Markennamen video2brain an."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "lynda.com is a leading online learning company that helps anyone learn business, software, technology and creative skills to achieve personal and professional goals. Through individual, corporate, academic and government subscriptions, members have access to the lynda.com video library of engaging, top-quality courses taught by recognized industry experts. The company also provides German, French and Spanish language content under the video2brain brand name."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://gallus.scilifelab.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://gallus.scilifelab.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://gallus.scilifelab.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://gallus.scilifelab.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gallus.scilifelab.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://gallus.scilifelab.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://gallus.scilifelab.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://gallus.scilifelab.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://gallus.scilifelab.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://gallus.scilifelab.se/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://gallus.scilifelab.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://gallus.scilifelab.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "gallus.scilifelab.se"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "http://gallus.scilifelab.se/"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDITCCAgmgAwIBAgIJAMNm2ATTA3mgMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFGdhbGx1cy5zY2lsaWZlbGFiLnNlMB4XDTEyMDgwNjExNDIwN1oXDTIyMDgw\nNDExNDIwN1owHzEdMBsGA1UEAxMUZ2FsbHVzLnNjaWxpZmVsYWIuc2UwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDJ5UUWP6K/vHk6+uLJPsuNDRxvSi/C\nyjL6e8OevDofr5REK3Ttuhq+qvFwlSUDqHCzeGZxH819Xwok5gJasLf4KKlV6k6H\nuSaRN/njMDwBjloUyja1P/ja5LgFmzly4Pm3VnKIw4MTxeXlLRhEDOSDv303Wp6e\nZpS/vNDkkZbEYpM4iMh6FQM2sIb6EaHYXnicYd4k+1fnWiCiuydG23emvGHmT5Tn\nrOFYI1LSpLGBwkwlM1FDoPCufWYhweHg4LuiUPmbxlQEdJOqy6JrqvFYrYPRV3UR\ntE/OBJ2Ld8L07xlL0o7b8q9+2ccU2ad6XmEs29YsnaMOCvqCBs1GPgH5AgMBAAGj\nYDBeMD0GA1UdEQQ2MDSCFGdhbGx1cy5zY2lsaWZlbGFiLnNlhhxodHRwOi8vZ2Fs\nbHVzLnNjaWxpZmVsYWIuc2UvMB0GA1UdDgQWBBSvHdjNMd+O6sjfHQTrJmhBVxRh\nqzANBgkqhkiG9w0BAQUFAAOCAQEAgzfV6iPbPgfPuWa+/faIYEFV2eKtjzQb74f+\nFe9SYZtBlKtXIPo5oJCx22oh3sDcSJtklRrp+HtVY7Op1sHxaKhEOWjq5hJrrp+9\npRVTnJVCtaIUBcajWMwfG2O1H8Tkpetnj/8qLDaTW0Fd3pF9e4vsIAs66/knJ9bT\nwiCijozckPEz8KVGgW/4TLB8F8ErIHDWVFU4cSezFknpqfe/qPWnCA3E/JVrJhki\nyJdT9GhQ6NTeXbhHS6otn+MTJrWd1kB2hT417PEcHZQO4bbyMWZjsNFgd0haIcOh\nqR3yqb2bdeQUWqkU0/5RA1uDcK8D+f2xAC2npJVHTd1a+1rKgA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=gallus.scilifelab.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://gallus.scilifelab.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://gallus.scilifelab.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gallus.scilifelab.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://gallus.scilifelab.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gallus.scilifelab.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://gallus.scilifelab.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://gallus.scilifelab.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://gallus.scilifelab.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://gallus.scilifelab.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://gallus.scilifelab.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://dmp.cdlib.org",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "uc3@ucop.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UC Curation Center"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "uc3@ucop.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UC Curation Center"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ken.weiss@ucop.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ken Weiss"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dmp.cdlib.org",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of California - Office of the President"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ucop.edu/welcome.html"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of California - Office of the President"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dmp.cdlib.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dmptool.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.dmptool.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://v1.dmptool.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "4"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://v2.dmptool.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "5"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dmp2.cdlib.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "6"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://uc3-dmp2-prd.cdlib.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "7"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dmp-aws-prd.cdlib.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "8"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://dmptool.org/about"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DMP Tool"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Create, share, review, and publish Data Management Plans conforming to Institution and Funder requirements"
                  }
                ],
                "logo": [
                  {
                    "text": "https://dmp.cdlib.org/img/dmptool_logo.svg",
                    "lang": "en",
                    "height": "53",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "153"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://dmptool.org/privacy/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAP8nYUVoOwwuMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDWRtcC5jZGxpYi5vcmcwHhcNMTEwODI2MTU0NDM2WhcNMjEwODIzMTU0NDM2\nWjAYMRYwFAYDVQQDEw1kbXAuY2RsaWIub3JnMIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAv+SS70RQmx9eI6GAAPKhb7G79Oz6VM9zoCc2RMihR0PsXH+4\nH8jr0OrrTYXw6Bvoy4q+nYoE/O94L427ayngaxsZGG99LOkqOnNJqx8YyhcHU+2V\nzE1H1puwHGtHjC8HaG5RAE2u+GBdfRFo7YwDiWZcovnxw1ADXpAebIIM6R6jFaam\ndRVAJld1USuxwe+v4BxhaQ983VNlDWD7tB/ppBYFIxaxc5eRYQ5Xhdc/tFbO7/R+\n7mNv1zEyx4j1d397abzLiWyUAfLYT9AnYY+G6JiXxiQ1Keq3Twkg3XGp6zI70RZR\n+CERZwZdV7T87DlVTRH+SLhlyL98NM8ftn+fqQIDAQABo3kwdzAdBgNVHQ4EFgQU\nNLEE8UmJURVhhxGQ9wjQTaLqwDUwSAYDVR0jBEEwP4AUNLEE8UmJURVhhxGQ9wjQ\nTaLqwDWhHKQaMBgxFjAUBgNVBAMTDWRtcC5jZGxpYi5vcmeCCQD/J2FFaDsMLjAM\nBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBVMgL73mP25ZYAyPUZlI/Z\ncO90zkhwQcoTYtIpdS2KE+XvLpC9yYFk7Xz+IaCbU7KYey/ZpW7MUTvddoSzRPDS\nulbxSugdfV7QVrt9bzaHSe8w20yMaVtRWAN8E9mFJNwJ8VSptxacc0ZdScHfmc76\nHejyMr9it7EuvpsxFQqDbgHqeXhqwdXrLiwTjn75bhx9+uT251W1wYG4gQ3R6Zly\nGSxO/I6if4vmR2y2vdDtugBNlmkIMwcE1pHTWxN0gHIQnItco+nQVrTzYmIgHMwv\nIdAUy0C4K5PdSbV8IUX1OZkeZyiQCdMs74p3IvKE57weopAz5Kxhiq9FlMh/LTx3"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dmp.cdlib.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dmp.cdlib.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dmp.cdlib.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dmptool.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dmptool.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dmptool.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.dmptool.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.dmptool.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.dmptool.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://v1.dmptool.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://v1.dmptool.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://v1.dmptool.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://v2.dmptool.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://v2.dmptool.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://v2.dmptool.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dmp2.cdlib.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dmp2.cdlib.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dmp2.cdlib.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "18"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uc3-dmp2-prd.cdlib.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "19"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://uc3-dmp2-prd.cdlib.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "20"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dmp-aws-prd.cdlib.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "21"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dmp-aws-prd.cdlib.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "22"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "DMP Tool"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Create, share, review, and publish Data Management Plans conforming to Institution and Funder requirements"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://uk-bris-shibboleth.moveon4.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tabassum"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kamran@zeptosystems.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kamran"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Qazi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ziaqazi@zeptosystems.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Zia"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://uk-bris-shibboleth.moveon4.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-11-05T15:07:12Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "qsu-unisolution"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qs-unisolution.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "QS unisolution GmbH"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uk-bris-shibboleth.moveon4.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://uk-bris-shibboleth.moveon4.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uk-bris-shibboleth.moveon4.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uk-bris-shibboleth.moveon4.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uk-bris-shibboleth.moveon4.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://uk-bris-shibboleth.moveon4.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://uk-bris-shibboleth.moveon4.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "logo": [
                  {
                    "text": "https://static.moveon4.com/sso/images/logo.png",
                    "height": "29",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "189"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "qsu-unisolution"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFgTCCA2mgAwIBAgIJAPyfEjrHG6KuMA0GCSqGSIb3DQEBCwUAMFcxCzAJBgNV\n\t\t\t\t\t\tBAYTAkRFMRwwGgYDVQQKDBNRUyB1bmlzb2x1dGlvbiBHbWJIMSowKAYDVQQDDCF1\n\t\t\t\t\t\tay1icmlzdG9sLXNoaWJib2xldGgubW92ZW9uNC5jb20wHhcNMTQxMTA1MDY1MDM4\n\t\t\t\t\t\tWhcNMzQxMDMxMDY1MDM4WjBXMQswCQYDVQQGEwJERTEcMBoGA1UECgwTUVMgdW5p\n\t\t\t\t\t\tc29sdXRpb24gR21iSDEqMCgGA1UEAwwhdWstYnJpc3RvbC1zaGliYm9sZXRoLm1v\n\t\t\t\t\t\tdmVvbjQuY29tMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAy58jkooZ\n\t\t\t\t\t\t4lsnCxbii74W0dEtLU+6+DCRCtPyjKUpVG/dYTlj1WNASBiHWDKKYBk4L/SpkUik\n\t\t\t\t\t\tWWvOktHoXCz3KPU6VaqtB2Um2dSKpEQb7qhQjeK36LB6kq6opwKk2svIaxkT1E3j\n\t\t\t\t\t\tpc+o+toGxaLfoc9D11ZiwnWibaRZFvqWJ/cl0saNNzfdHjNIDJlNPZSfiXbGdGim\n\t\t\t\t\t\tjgzc7Q1cG8acwLBaEYfNScd/+zKob7Hh0QJqpvP9faLdgsbtz6/hgJdbzrnnuIw5\n\t\t\t\t\t\tWZijXpCkjbXV77JdoRRdTa7IotL6/p9/QgfoU21tjydql0RorjuhBV9xj4aEY0xo\n\t\t\t\t\t\tDm5hKpCb2NtxZU9FlyVEyYx+lrAkUHkrWTJuH6YlGref+TgXAyq3Pu1UcQfPxGv7\n\t\t\t\t\t\ttGv6Sr0lxPI+MwbXkY1KcmWYQvgsIthPcuHRoud9x4TOwY2trMKwq8KEYJPj7Hhg\n\t\t\t\t\t\tluoGOlLgLy9uE1rY8IrVMPta0jAWbVJ7087OnWS9bzBPPff+ThZVh3pOrIOW3ZDZ\n\t\t\t\t\t\tEEOe+FgaPKiuTyCT3rsKecmTOmMCXiFISWgq9x8VPxOIxJRL0ze7c1NlHuGU494K\n\t\t\t\t\t\tUjHj29M5cDmyVud3yJVDSr5kde5QvdVT2Rjid+8seaX0L0R+5BFc3VAjDRkRQlZM\n\t\t\t\t\t\t6/OHPHiN1yTZ3rvS9/Gmu0Gxaou8AF7DtBECAwEAAaNQME4wHQYDVR0OBBYEFD5O\n\t\t\t\t\t\tXi14slUrKao3oHh+fJfqknUEMB8GA1UdIwQYMBaAFD5OXi14slUrKao3oHh+fJfq\n\t\t\t\t\t\tknUEMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQELBQADggIBACotJj7JrPXhz//v\n\t\t\t\t\t\td7lW6LSVOFEbMJQ+faci4XIXg2Hp/imeAKNpbldokdYjHLbobC5OgPpwjGgb89K9\n\t\t\t\t\t\t9y0XUSmPucnKMFLFB6OLibMf1zCHel956wLJOrGGdoAy3hdhi/na2U02vtjexxGT\n\t\t\t\t\t\tIqbicXEmAcVCRve0TDSUU/yJ/Q9kjNEoOlyo1Sy3+4SeO7tuY6FRCM07WnucXzJL\n\t\t\t\t\t\tgNCrnqVxCTNa5ZhjP/Ppp2V3jIvcwvXg4TAtmKZBu6RhBSni4Ml4kTmiy2g9U8NP\n\t\t\t\t\t\t3j1zWY0V5QaZ8B+nbBjRxpthROM+qN0M0ILxw/ClKIECo4k2ScmP/Idx82bGmX3H\n\t\t\t\t\t\tkiyTX6+OoXY4uM3utyjDm3hTmz2w/Mwj+dZy5StmU7qxcjOIYlyrl7uRUyltW0c2\n\t\t\t\t\t\t3U5scKxzexpKZ7anUmxecAvV0D5jmJyBOoUIwS0NbOJmS3aWdhu2gjJIXJCFeHY4\n\t\t\t\t\t\twz3mDO5e3XWr7c8Rw3Mh15bWxVZyYv7TvdbuPmZyEHL4Tmq1vnzsFDOMdOQQNlS9\n\t\t\t\t\t\tkN8cbSNag89eDMLjs+0I64QRuC8zW7VzRw8/Jm/w4Th0ZNfF36dbmGe1Oa4YHKlq\n\t\t\t\t\t\taZmnja4uIchgKipEXlNaG1+HACmzj0SIKGpaBtiryIcogwbZoeCaxKp69YgyaQEk\n\t\t\t\t\t\tswIdKrlywppmFlZP04UczhynlNo3"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uk-bris-shibboleth.moveon4.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://uk-bris-shibboleth.moveon4.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uk-bris-shibboleth.moveon4.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://uk-bris-shibboleth.moveon4.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://uk-bris-shibboleth.moveon4.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://uk-bris-shibboleth.moveon4.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://aai.unil.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "AAI"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@unil.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Equipe"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41216922211"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "UNIL"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@unil.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "HelpDesk"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41216922233"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Roy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Alexandre.Roy@unil.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alexandre"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41216922193"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Greiner"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:christopher.greiner@unil.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Christopher"
          }
        }
      ],
      "entity_id": "https://aai.unil.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2016-02-04T11:19:19Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAMN83YPbe/AVMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC2FhaS51bmlsLmNoMB4XDTE0MDQxMDA2NTc0N1oXDTE3MDQwOTA2NTc0N1ow\nFjEUMBIGA1UEAxMLYWFpLnVuaWwuY2gwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQDS4Fn9ab7qC1kgxX8O4r8QcfDZG0T89Bu4qD9O8vD/1aPLo5ZqSjao\n1mrhiVbqGgLmPjbS/IsuCMRrUfDeQyBJGqZ8O5GOL6sL3eH5Qd2wZAdHcFZHWx7b\noCz1wXb1+a0bhTCaSE3UJpUqvo7bf/1ClBpzcJD1jSdt2sQt/U8bq0rb9vtnzLMc\nOM4wetmS8lS5WsJGuGqGrdsKb8SD4QAemaYjTYgY9yoXZh0ZYvdce0jImGMbOF43\n55LxIF6L89U+VFF7Z5KyrZQRCP5e9MinvMeShCtYiAJyBW9RMF4vEZuQBTgAjmvZ\n8xVVkwqsdpUnwmCsVV5ZeRtG7yqev+4LAgMBAAGjXTBbMDoGA1UdEQQzMDGCC2Fh\naS51bmlsLmNohiJodHRwczovL2FhaS51bmlsLmNoL2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBTX3RXRntMu7Rn62PNfGuvDMFJ4IzANBgkqhkiG9w0BAQUFAAOCAQEA\nhTRI7Gj5D+fEq59EnmD+vZa1MGGoftEdGWhVGmKA5Stki5hI4OtrogNG0H6TqlLx\ntzg7EXIsjR5sqifAx2nA+W+bWuQiAZPyqVbz4ttqSa63E6XJcfzT1HP7wJVUnkYn\nJyqeHAbvPrAQDsil2l/RHSfnFT4BiDi/g39nye15jUI1QZP1j43AIttSbsCUJf1O\n2XCs2/apHYzF4FF7Dqej35omJPm8sr4+ylZR6nSJKa1QDs7EjM2sCgd6oEeHipHn\nbQ7puHs24ooO2rLro9m3g8eIRPL9vY8eK4Za1FoMzuyeYRUMr29nybh93k74FPh7\nbixqHGtUL73JGpgPqlP05A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unil.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai.unil.ch:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai.unil.ch:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aai.unil.ch/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai.unil.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai.unil.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai.unil.ch:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unil.ch"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unil.ch"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unil.ch"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Lausanne"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Lausanne"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Universit\u00e9 de Lausanne"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Universit\u00e9 de Lausanne"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAbUlEQVQ4EWNkmHDpPwMFgIkCvWCtw8WA//m68KCAsUF0rJ4kWBxZDCQA44PYeMNgkaMISA1egNcAkE6YK3CZgteAuP1vGAi5Aq8Biy89x2UxXJwFxALZBAsYEBsZ4HIFTD3jaFLGn5CQAxMXGwBfgCBoMtEr2QAAAABJRU5ErkJggg==",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.unil.ch/ci/home/menuinst/documentation/reglements-et-directives.html"
                  }
                ]
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "unil.ch"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:46.521542,6.579157"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.222.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.224.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.217.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.218.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.220.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.0.144/28"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.214.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.216.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:620:600::/48"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.80.31.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.80.32.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.80.40.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.80.31.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.80.32.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.80.40.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.220.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.80.42.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "129.194.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.222.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.212.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.212.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.216.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "error_url": "http://www.unil.ch/ci/helpdesk",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAMN83YPbe/AVMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC2FhaS51bmlsLmNoMB4XDTE0MDQxMDA2NTc0N1oXDTE3MDQwOTA2NTc0N1ow\nFjEUMBIGA1UEAxMLYWFpLnVuaWwuY2gwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQDS4Fn9ab7qC1kgxX8O4r8QcfDZG0T89Bu4qD9O8vD/1aPLo5ZqSjao\n1mrhiVbqGgLmPjbS/IsuCMRrUfDeQyBJGqZ8O5GOL6sL3eH5Qd2wZAdHcFZHWx7b\noCz1wXb1+a0bhTCaSE3UJpUqvo7bf/1ClBpzcJD1jSdt2sQt/U8bq0rb9vtnzLMc\nOM4wetmS8lS5WsJGuGqGrdsKb8SD4QAemaYjTYgY9yoXZh0ZYvdce0jImGMbOF43\n55LxIF6L89U+VFF7Z5KyrZQRCP5e9MinvMeShCtYiAJyBW9RMF4vEZuQBTgAjmvZ\n8xVVkwqsdpUnwmCsVV5ZeRtG7yqev+4LAgMBAAGjXTBbMDoGA1UdEQQzMDGCC2Fh\naS51bmlsLmNohiJodHRwczovL2FhaS51bmlsLmNoL2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBTX3RXRntMu7Rn62PNfGuvDMFJ4IzANBgkqhkiG9w0BAQUFAAOCAQEA\nhTRI7Gj5D+fEq59EnmD+vZa1MGGoftEdGWhVGmKA5Stki5hI4OtrogNG0H6TqlLx\ntzg7EXIsjR5sqifAx2nA+W+bWuQiAZPyqVbz4ttqSa63E6XJcfzT1HP7wJVUnkYn\nJyqeHAbvPrAQDsil2l/RHSfnFT4BiDi/g39nye15jUI1QZP1j43AIttSbsCUJf1O\n2XCs2/apHYzF4FF7Dqej35omJPm8sr4+ylZR6nSJKa1QDs7EjM2sCgd6oEeHipHn\nbQ7puHs24ooO2rLro9m3g8eIRPL9vY8eK4Za1FoMzuyeYRUMr29nybh93k74FPh7\nbixqHGtUL73JGpgPqlP05A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Lausanne"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Lausanne"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unil.ch/"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unil.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "unil.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dlib-skaill.ucs.ed.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hopkins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sara.hopkins@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sara"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hopkins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sara.hopkins@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sara"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dlib-skaill.ucs.ed.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Edinburgh: SDSS Test SP (skaill)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ukfederation.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-skaill.ucs.ed.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dlib-skaill.ucs.ed.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dlib-skaill.ucs.ed.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dlib-skaill.ucs.ed.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-skaill.ucs.ed.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dlib-skaill.ucs.ed.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dlib-skaill.ucs.ed.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIJAO+Ojk6L2U0+MA0GCSqGSIb3DQEBBQUAMC8xLTArBgNV\n\t\t\t\t\t\tBAMTJGRsaWItc2thaWxsLmRsaWItc2thaWxsLnVjcy5lZC5hYy51azAeFw0xMDA4\n\t\t\t\t\t\tMTMxNjQ4MjZaFw0yMDA4MTAxNjQ4MjZaMC8xLTArBgNVBAMTJGRsaWItc2thaWxs\n\t\t\t\t\t\tLmRsaWItc2thaWxsLnVjcy5lZC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBAOMZKa9TKhbnao7zUzJOu+0+cjO1HmQrsSVAZhnKQD2q7GSWGejS\n\t\t\t\t\t\t3vGFxDxFM0PB2QW0hyOd4RUJdROOSRKdIZDuv+olP3Mk8u9Grv/sCs5Zbvk9/szf\n\t\t\t\t\t\tvj8GlmtPQyTiyKv0cv6wHLhN97e3/8Ym7WnL9JBIk2Ewa9xwRwJDCztMAE37MYQj\n\t\t\t\t\t\tD2op00+1yFUJXPS7d8TrG9qa4J/IC62oagSUQjUGyTgz0Ha3o2o19TysaSOZaInb\n\t\t\t\t\t\t6WPW09E1fKS3b3DTKF05zeKusGdNKaw7Vu3+m5Yy0Z2d++ZD4OmltOiYinOtzGst\n\t\t\t\t\t\tWlvtPt4+pJ+HPfs7onJrt93kJWJtysQAv3kCAwEAAaNSMFAwLwYDVR0RBCgwJoIk\n\t\t\t\t\t\tZGxpYi1za2FpbGwuZGxpYi1za2FpbGwudWNzLmVkLmFjLnVrMB0GA1UdDgQWBBRA\n\t\t\t\t\t\trA3D8Loi6/EquAcMTzOo2I070zANBgkqhkiG9w0BAQUFAAOCAQEA20QAK3hFCooX\n\t\t\t\t\t\trgMEsMqlNMek5P6t4I67RxHtXSUD5d7YvGNuWWJdoujSPrQcBvgg5xw+51kqKF3H\n\t\t\t\t\t\tRqfjilqH0x95gidhbp0W9hxGc8y4sHnJv9RIoVTloaDPp58FOa0sQFMv+Y6Ww6MI\n\t\t\t\t\t\tjwkUgdGZLby1uPays7JuG8Fknwkt9fGAqWtLLkuGZrFLeQb0/uCjC6fju76YuxpM\n\t\t\t\t\t\tZNkVBZ3rIai3bInXJybjkSJzm27lPMpQ+fAfwQmXrzHuhN9S3zI9/w0uDdXkvf8c\n\t\t\t\t\t\t0xZnbN4TYWgCB7krj2wrGg6YV3x8f9fGRFbH0EqIU63jGYuFP7rrlxv37ol+Zrrg\n\t\t\t\t\t\tmfQhxVldkQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dlib-skaill.ucs.ed.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dlib-skaill.ucs.ed.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dlib-skaill.ucs.ed.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dlib-skaill.ucs.ed.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dlib-skaill.ucs.ed.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dlib-skaill.ucs.ed.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp2.redclara.net/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "seg@redclara.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp2.redclara.net/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "es",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://cofre.reuna.cl/index.php/es/reglas-federacion"
              }
            ],
            "registration_instant": "2014-02-21T00:00:00Z",
            "registration_authority": "http://cofre.reuna.cl",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFJzCCBA+gAwIBAgIQAycc1VlqLQ1YMhUWYD69ajANBgkqhkiG9w0BAQsFADBN\nMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMRGlnaUNlcnQgSW5jMScwJQYDVQQDEx5E\naWdpQ2VydCBTSEEyIFNlY3VyZSBTZXJ2ZXIgQ0EwHhcNMTQxMTI4MDAwMDAwWhcN\nMTcxMjA2MTIwMDAwWjB1MQswCQYDVQQGEwJVWTETMBEGA1UEBxMKTW9udGV2aWRl\nbzE4MDYGA1UECgwvQ29vcGVyYWNpw7NuIExhdGlub2FtZXJpY2FuYSBkZSBSZWRl\ncyBBdmFuemFkYXMxFzAVBgNVBAMMDioucmVkY2xhcmEubmV0MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEA4ciHwzKgzkUxp9PSRy9gV4WfIAmIjugbR8f9\nRJD9GwoMPTA173v4Rzjbnl8h/3e+iDfdzetHRM+gkOXwPCaGFpBQa2EPnxtFaaH6\nl8xtfHlsl8D2lqRkOE2OjvP8GzgpT3ikMBXoNr4TL7RQqzinwYCCJzLMSflwNbtk\n/a04k3l9FyxJ4mqEFP6aUsPJA0YRLVrYOIyppRzcHbRng/pNPE0R+JhNC3Kx2SbJ\nUvKtjQfvMJCn2T2dn5hg5mFnyMl78pgmRjppgxWEWkti+4eZoLg0OwVEFyGEgmEU\namd6JmRZTDs04BtstymJNXdkTsCP7yk92lpAc9C3NZ3FvrR0eQIDAQABo4IB2TCC\nAdUwHwYDVR0jBBgwFoAUD4BhHIIxYdUvKOeNRji0LOHG2eIwHQYDVR0OBBYEFBFj\nG3+tyY7afXZLfXNuYoGnE0nEMCcGA1UdEQQgMB6CDioucmVkY2xhcmEubmV0ggxy\nZWRjbGFyYS5uZXQwDgYDVR0PAQH/BAQDAgWgMB0GA1UdJQQWMBQGCCsGAQUFBwMB\nBggrBgEFBQcDAjBrBgNVHR8EZDBiMC+gLaArhilodHRwOi8vY3JsMy5kaWdpY2Vy\ndC5jb20vc3NjYS1zaGEyLWczLmNybDAvoC2gK4YpaHR0cDovL2NybDQuZGlnaWNl\ncnQuY29tL3NzY2Etc2hhMi1nMy5jcmwwQgYDVR0gBDswOTA3BglghkgBhv1sAQEw\nKjAoBggrBgEFBQcCARYcaHR0cHM6Ly93d3cuZGlnaWNlcnQuY29tL0NQUzB8Bggr\nBgEFBQcBAQRwMG4wJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmRpZ2ljZXJ0LmNv\nbTBGBggrBgEFBQcwAoY6aHR0cDovL2NhY2VydHMuZGlnaWNlcnQuY29tL0RpZ2lD\nZXJ0U0hBMlNlY3VyZVNlcnZlckNBLmNydDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3\nDQEBCwUAA4IBAQB3WePP9QxLi7OdtCbfR6kqIPDvfVX3aMvJ3/LQW9GhugwkV+ay\n8GyG17Dbm6Y2YSn1vl36lf/Nas4Lxf5jaVKXXoPUfANaDlJkK3E+cMsh1xrs8Uef\nMgiRll8Q28jA1RH+vmA+hzHOhuNqM8xHl2c/9Eq7FmFYoP4A1Lo/N9dEHHlHhSkG\nI6kBgBW/MAPvSLLPWr4v0u+/ynH9v+PEo60skvnrQPH0wFPoyJd/zxOMaomleJEv\nyL8CtS8Jo8/gqJ76zITM2JD1Cd+NBrPLk41I/hcfQ7Eewb/lkKe8/tpNm3e3bXJG\ns5W/0Lq2GRjQh9nrDfVs2IuE1c5zeqToyp98"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "redclara.net"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.redclara.net:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.redclara.net:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp2.redclara.net/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.redclara.net/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp2.redclara.net/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2.redclara.net/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.redclara.net:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.redclara.net:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "redclara.net"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.redclara.net/index.php?lang=en"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.redclara.net/index.php?lang=es"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "RedCLARA - Latin American Cooperation of Advanced Networks"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "RedCLARA - Cooperaci\u00f3n Latino Americana de Redes Avanzadas"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RedCLARA"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RedCLARA"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFJzCCBA+gAwIBAgIQAycc1VlqLQ1YMhUWYD69ajANBgkqhkiG9w0BAQsFADBN\nMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMRGlnaUNlcnQgSW5jMScwJQYDVQQDEx5E\naWdpQ2VydCBTSEEyIFNlY3VyZSBTZXJ2ZXIgQ0EwHhcNMTQxMTI4MDAwMDAwWhcN\nMTcxMjA2MTIwMDAwWjB1MQswCQYDVQQGEwJVWTETMBEGA1UEBxMKTW9udGV2aWRl\nbzE4MDYGA1UECgwvQ29vcGVyYWNpw7NuIExhdGlub2FtZXJpY2FuYSBkZSBSZWRl\ncyBBdmFuemFkYXMxFzAVBgNVBAMMDioucmVkY2xhcmEubmV0MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEA4ciHwzKgzkUxp9PSRy9gV4WfIAmIjugbR8f9\nRJD9GwoMPTA173v4Rzjbnl8h/3e+iDfdzetHRM+gkOXwPCaGFpBQa2EPnxtFaaH6\nl8xtfHlsl8D2lqRkOE2OjvP8GzgpT3ikMBXoNr4TL7RQqzinwYCCJzLMSflwNbtk\n/a04k3l9FyxJ4mqEFP6aUsPJA0YRLVrYOIyppRzcHbRng/pNPE0R+JhNC3Kx2SbJ\nUvKtjQfvMJCn2T2dn5hg5mFnyMl78pgmRjppgxWEWkti+4eZoLg0OwVEFyGEgmEU\namd6JmRZTDs04BtstymJNXdkTsCP7yk92lpAc9C3NZ3FvrR0eQIDAQABo4IB2TCC\nAdUwHwYDVR0jBBgwFoAUD4BhHIIxYdUvKOeNRji0LOHG2eIwHQYDVR0OBBYEFBFj\nG3+tyY7afXZLfXNuYoGnE0nEMCcGA1UdEQQgMB6CDioucmVkY2xhcmEubmV0ggxy\nZWRjbGFyYS5uZXQwDgYDVR0PAQH/BAQDAgWgMB0GA1UdJQQWMBQGCCsGAQUFBwMB\nBggrBgEFBQcDAjBrBgNVHR8EZDBiMC+gLaArhilodHRwOi8vY3JsMy5kaWdpY2Vy\ndC5jb20vc3NjYS1zaGEyLWczLmNybDAvoC2gK4YpaHR0cDovL2NybDQuZGlnaWNl\ncnQuY29tL3NzY2Etc2hhMi1nMy5jcmwwQgYDVR0gBDswOTA3BglghkgBhv1sAQEw\nKjAoBggrBgEFBQcCARYcaHR0cHM6Ly93d3cuZGlnaWNlcnQuY29tL0NQUzB8Bggr\nBgEFBQcBAQRwMG4wJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmRpZ2ljZXJ0LmNv\nbTBGBggrBgEFBQcwAoY6aHR0cDovL2NhY2VydHMuZGlnaWNlcnQuY29tL0RpZ2lD\nZXJ0U0hBMlNlY3VyZVNlcnZlckNBLmNydDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3\nDQEBCwUAA4IBAQB3WePP9QxLi7OdtCbfR6kqIPDvfVX3aMvJ3/LQW9GhugwkV+ay\n8GyG17Dbm6Y2YSn1vl36lf/Nas4Lxf5jaVKXXoPUfANaDlJkK3E+cMsh1xrs8Uef\nMgiRll8Q28jA1RH+vmA+hzHOhuNqM8xHl2c/9Eq7FmFYoP4A1Lo/N9dEHHlHhSkG\nI6kBgBW/MAPvSLLPWr4v0u+/ynH9v+PEo60skvnrQPH0wFPoyJd/zxOMaomleJEv\nyL8CtS8Jo8/gqJ76zITM2JD1Cd+NBrPLk41I/hcfQ7Eewb/lkKe8/tpNm3e3bXJG\ns5W/0Lq2GRjQh9nrDfVs2IuE1c5zeqToyp98"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RedCLARA - Cooperacion Latino Americana de Redes Avanzadas"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "www.redclara.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RedCLARA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.dudleycol.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.dudleycol.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/dudleycol.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/dudleycol.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dudleycol.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Dudley College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dudleycol.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp3-test.is.ed.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS ITI Enterprise Services"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS ITI Enterprise Services"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp3-test.is.ed.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-02-18T15:16:05Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp3-test.is.ed.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp3-test.is.ed.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUC9RSZ16U7S2HCaW/X+yYUz+cBckwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwIDEeMBwGA1UEAwwVaWRwMy10ZXN0LmlzLmVkLmFjLnVrMB4XDTE1MDYyOTE1\n\t\t\t\t\t\tNDUwOVoXDTM1MDYyOTE1NDUwOVowIDEeMBwGA1UEAwwVaWRwMy10ZXN0LmlzLmVk\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsVIm6Z0yQ2dE\n\t\t\t\t\t\ti7dGlVrLODwOxA4aXLRhzqQgcmgelU9i2TGN2rbzwyVVLenBLwnFM6A4r7yUMKO+\n\t\t\t\t\t\tyDN+xlSUaAxv1aBF0CeOoF7pMKXiMJ5K/sNK0L938KFOUZzliMiJKgMw0pf3k6xm\n\t\t\t\t\t\t1oBeHthbV1dkBAmdcaMDnydAWpVx1ObSGTHUobyLbF6UF2VyCcUmrHWzZFv8ZOtA\n\t\t\t\t\t\tKkGkdbLFPxQ0nta3Iu1y5mz20aSn8iGaELi7BX+9FFjfkL67QKyRtpUxlelQOi+y\n\t\t\t\t\t\tF4DkW59EvGZ+Zvecgey90CAEegofrZgoLMXCW3IsJK2z2J8B04R4RZb+dbkQWilN\n\t\t\t\t\t\trAmAlBSeAwIDAQABo3EwbzAdBgNVHQ4EFgQUeZrdGuAp0orVwn7AnCzh4qH3bPEw\n\t\t\t\t\t\tTgYDVR0RBEcwRYIVaWRwMy10ZXN0LmlzLmVkLmFjLnVrhixodHRwczovL2lkcDMt\n\t\t\t\t\t\tdGVzdC5pcy5lZC5hYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOC\n\t\t\t\t\t\tAQEAhCGiWkXhI6Gaw1wsmuBlie3s/vDQSRpSsvXV5CLY5nWNKcPHT5QbUCGkLoHA\n\t\t\t\t\t\tZFfbghTZYi9DqPNc7LG5gbFAZkK9Ao40LcnIeeoHnX8/VWL9rWFv1KHngOZiWPZN\n\t\t\t\t\t\tmQ5avo+NjCF8FjyNPGJfF+kEXGF8L7kSY0ZHZr3z40rtQUhfRi8PuJIwnuUAAIGf\n\t\t\t\t\t\tfQ5c9D3d+CtRWZFPQ7k9Q7vqurscAPuFaGY4Iiq1ukkTwjgHxoGtAsaERNhEz3ec\n\t\t\t\t\t\tpYtZijPo2mE5m/mvPLCBJdMlCfZx95YNryTv7qyf+p53hXm+DCp+ClYk4Xr3FcDo\n\t\t\t\t\t\tSWGiXiIGBRVBJvfHk3t5caCrGA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ed.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp3-test.is.ed.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp3-test.is.ed.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp3-test.is.ed.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp3-test.is.ed.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp3-test.is.ed.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp3-test.is.ed.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ed.ac.uk"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This IdP is a v3 Development/Test IdP for the University of Edinburgh. It is not for use by end users."
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp3-test.is.ed.ac.uk/university.gif",
                    "height": "70",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "315"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Edinburgh v3 Development IdP (do not use!)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUC9RSZ16U7S2HCaW/X+yYUz+cBckwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwIDEeMBwGA1UEAwwVaWRwMy10ZXN0LmlzLmVkLmFjLnVrMB4XDTE1MDYyOTE1\n\t\t\t\t\t\tNDUwOVoXDTM1MDYyOTE1NDUwOVowIDEeMBwGA1UEAwwVaWRwMy10ZXN0LmlzLmVk\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsVIm6Z0yQ2dE\n\t\t\t\t\t\ti7dGlVrLODwOxA4aXLRhzqQgcmgelU9i2TGN2rbzwyVVLenBLwnFM6A4r7yUMKO+\n\t\t\t\t\t\tyDN+xlSUaAxv1aBF0CeOoF7pMKXiMJ5K/sNK0L938KFOUZzliMiJKgMw0pf3k6xm\n\t\t\t\t\t\t1oBeHthbV1dkBAmdcaMDnydAWpVx1ObSGTHUobyLbF6UF2VyCcUmrHWzZFv8ZOtA\n\t\t\t\t\t\tKkGkdbLFPxQ0nta3Iu1y5mz20aSn8iGaELi7BX+9FFjfkL67QKyRtpUxlelQOi+y\n\t\t\t\t\t\tF4DkW59EvGZ+Zvecgey90CAEegofrZgoLMXCW3IsJK2z2J8B04R4RZb+dbkQWilN\n\t\t\t\t\t\trAmAlBSeAwIDAQABo3EwbzAdBgNVHQ4EFgQUeZrdGuAp0orVwn7AnCzh4qH3bPEw\n\t\t\t\t\t\tTgYDVR0RBEcwRYIVaWRwMy10ZXN0LmlzLmVkLmFjLnVrhixodHRwczovL2lkcDMt\n\t\t\t\t\t\tdGVzdC5pcy5lZC5hYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOC\n\t\t\t\t\t\tAQEAhCGiWkXhI6Gaw1wsmuBlie3s/vDQSRpSsvXV5CLY5nWNKcPHT5QbUCGkLoHA\n\t\t\t\t\t\tZFfbghTZYi9DqPNc7LG5gbFAZkK9Ao40LcnIeeoHnX8/VWL9rWFv1KHngOZiWPZN\n\t\t\t\t\t\tmQ5avo+NjCF8FjyNPGJfF+kEXGF8L7kSY0ZHZr3z40rtQUhfRi8PuJIwnuUAAIGf\n\t\t\t\t\t\tfQ5c9D3d+CtRWZFPQ7k9Q7vqurscAPuFaGY4Iiq1ukkTwjgHxoGtAsaERNhEz3ec\n\t\t\t\t\t\tpYtZijPo2mE5m/mvPLCBJdMlCfZx95YNryTv7qyf+p53hXm+DCp+ClYk4Xr3FcDo\n\t\t\t\t\t\tSWGiXiIGBRVBJvfHk3t5caCrGA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Edinburgh v3 Development IdP (do not use!)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib-test.raven.cam.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:service-desk@uis.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "University Information Services' Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:raven-support@ucs.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Raven Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib-test.raven.cam.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_instant": "2012-05-31T14:51:11Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRjCCAi6gAwIBAgIJANGv1GtjrUKOMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\n\t\t\t\t\t\tBAMTGXNoaWItdGVzdC5yYXZlbi5jYW0uYWMudWswHhcNMTIxMjA0MTE1NjQ0WhcN\n\t\t\t\t\t\tMjIxMjAyMTE1NjQ0WjAkMSIwIAYDVQQDExlzaGliLXRlc3QucmF2ZW4uY2FtLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtJeHcwBjETJCV4XX\n\t\t\t\t\t\tP9xI6qFSpbDJ94veVlT11dN1opYY/3QC+6pa811/4wXeQ35e64U1UcqpzP0f1EFR\n\t\t\t\t\t\tMBxT22Wt3ASBpdp+2U+AEwOahfUI8uQDK2n3E67dQ1km76vhpxbX0CyZggnSkluN\n\t\t\t\t\t\tkOMLIJrZFr0gaI7/a08JoTzwn6pjFWklvMhPHpu2Wr5AodSY6+sljX4/nNKUxyHo\n\t\t\t\t\t\tWfwiZG50/u4f3PmFb0b2YIpjmdBIJQzaBbOHSjDUVpONRwz++rPr1DuXeWzmOHIK\n\t\t\t\t\t\thqGZzsk+TjbhZcA0mX26iaw59pNZq/y0W8IXSzHUGum19L6LWKwt61path7OdZTz\n\t\t\t\t\t\tsHD2twIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NM\n\t\t\t\t\t\tIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUYj7x7CBTsVBP86VAwrNz\n\t\t\t\t\t\tq/nvhRYwHwYDVR0jBBgwFoAUYj7x7CBTsVBP86VAwrNzq/nvhRYwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAKJEUuUYXss4j3cfFtz7fK8pQ7Xejnop18wBEThSyzJSjd7YEq6w\n\t\t\t\t\t\tZCdfGTzWjBmUXQWRijm9JX9f2sobXiUuwDvHK6N/1OM/7V2a0qPrdX53UMceVY0o\n\t\t\t\t\t\tM/x+HKKZ6svBXkj5VTovzPEUnPAl3m1JiZAffJtn7mz+wEPluJEcgqWWrwHjRJs8\n\t\t\t\t\t\tlzuR6fJ3PacP0Qcg2nBk9y9YxSrGKHFFZ6s8iszpnsVDzQPD3NZSuHTCbp2J7cz0\n\t\t\t\t\t\t/XyCLO75rEBXAmp8/L96QjlEUiQukScWn3jNRsI6lX9GypVZKBm/y5v5Tyj/x+i2\n\t\t\t\t\t\tSuQ4UiVzLdJ3C6y7SMog3XganjH9Qg6r6AA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cam.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eresources.lib.cam.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-test.raven.cam.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-test.raven.cam.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib-test.raven.cam.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-test.raven.cam.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib-test.raven.cam.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-test.raven.cam.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-test.raven.cam.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-test.raven.cam.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cam.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eresources.lib.cam.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://shib-test.raven.cam.ac.uk/test-idp-logo-80x60.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://shib-test.raven.cam.ac.uk/idp-logo-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Cambridge (test only)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "cam.ac.uk"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:52.208056,0.1225"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "128.232.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "129.169.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "131.111.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.18.195.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.60.80.0/20"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.63.252.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:630:200::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRjCCAi6gAwIBAgIJANGv1GtjrUKOMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\n\t\t\t\t\t\tBAMTGXNoaWItdGVzdC5yYXZlbi5jYW0uYWMudWswHhcNMTIxMjA0MTE1NjQ0WhcN\n\t\t\t\t\t\tMjIxMjAyMTE1NjQ0WjAkMSIwIAYDVQQDExlzaGliLXRlc3QucmF2ZW4uY2FtLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtJeHcwBjETJCV4XX\n\t\t\t\t\t\tP9xI6qFSpbDJ94veVlT11dN1opYY/3QC+6pa811/4wXeQ35e64U1UcqpzP0f1EFR\n\t\t\t\t\t\tMBxT22Wt3ASBpdp+2U+AEwOahfUI8uQDK2n3E67dQ1km76vhpxbX0CyZggnSkluN\n\t\t\t\t\t\tkOMLIJrZFr0gaI7/a08JoTzwn6pjFWklvMhPHpu2Wr5AodSY6+sljX4/nNKUxyHo\n\t\t\t\t\t\tWfwiZG50/u4f3PmFb0b2YIpjmdBIJQzaBbOHSjDUVpONRwz++rPr1DuXeWzmOHIK\n\t\t\t\t\t\thqGZzsk+TjbhZcA0mX26iaw59pNZq/y0W8IXSzHUGum19L6LWKwt61path7OdZTz\n\t\t\t\t\t\tsHD2twIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NM\n\t\t\t\t\t\tIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUYj7x7CBTsVBP86VAwrNz\n\t\t\t\t\t\tq/nvhRYwHwYDVR0jBBgwFoAUYj7x7CBTsVBP86VAwrNzq/nvhRYwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAKJEUuUYXss4j3cfFtz7fK8pQ7Xejnop18wBEThSyzJSjd7YEq6w\n\t\t\t\t\t\tZCdfGTzWjBmUXQWRijm9JX9f2sobXiUuwDvHK6N/1OM/7V2a0qPrdX53UMceVY0o\n\t\t\t\t\t\tM/x+HKKZ6svBXkj5VTovzPEUnPAl3m1JiZAffJtn7mz+wEPluJEcgqWWrwHjRJs8\n\t\t\t\t\t\tlzuR6fJ3PacP0Qcg2nBk9y9YxSrGKHFFZ6s8iszpnsVDzQPD3NZSuHTCbp2J7cz0\n\t\t\t\t\t\t/XyCLO75rEBXAmp8/L96QjlEUiQukScWn3jNRsI6lX9GypVZKBm/y5v5Tyj/x+i2\n\t\t\t\t\t\tSuQ4UiVzLdJ3C6y7SMog3XganjH9Qg6r6AA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Cambridge (test only)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cam.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Cambridge"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ruskin.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dewhurst"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:bdewhrst@ruskin.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bill"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dewhurst"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:bdewhrst@ruskin.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bill"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ruskin.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjQCCQCeO7iggJ8z5DANBgkqhkiG9w0BAQUFADBoMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEUMBIGA1UECBMLT3hmb3Jkc2hpcmUxDzANBgNVBAcTBk94Zm9yZDEXMBUGA1UE\n\t\t\t\t\t\tChMOUnVza2luIENvbGxlZ2UxGTAXBgNVBAMTEGlkcC5ydXNraW4uYWMudWswHhcN\n\t\t\t\t\t\tMTIwNzEwMDk1MzQ0WhcNMzIwNzA1MDk1MzQ0WjBoMQswCQYDVQQGEwJHQjEUMBIG\n\t\t\t\t\t\tA1UECBMLT3hmb3Jkc2hpcmUxDzANBgNVBAcTBk94Zm9yZDEXMBUGA1UEChMOUnVz\n\t\t\t\t\t\ta2luIENvbGxlZ2UxGTAXBgNVBAMTEGlkcC5ydXNraW4uYWMudWswggEiMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC6+fdNYJiZH+zIfW6xLXXv5JNd/uJP8JQh\n\t\t\t\t\t\tyfrPx2PmggxywfTrMKJdRPpKtAUqPXlSB7acLAjD0U3XErjzYttjt+qXJEU2YUks\n\t\t\t\t\t\tgvwd7lJiIQXW5cf3LU14YySLpCbh/8dNQ1cmmwjQpAYA+vpYjckdOtL0qkt/7qMV\n\t\t\t\t\t\t59crl8ZpMpXusWIq2aZLlHU+Gf21Ez18O+aCkSj4vpcjyFc75YPZFNvDkRdccTtg\n\t\t\t\t\t\tnHxMB3k2ddm8IGbK4VlWymZZWxyl+fNilP0Yqs0OFdCOO6Uo15N60CXw+LcfGhKh\n\t\t\t\t\t\thntFJ9+9Z4MEAxKQanezzF2C9VtSHuni1Q5CiQWLXMEgzshgkSO3AgMBAAEwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBAC/xMtV84acTdAf98Pw7W2IGdi3dUXErdQkkmGMPxC/v\n\t\t\t\t\t\tWJcHbF5+WMozmWSdvci6XhipnxiHWbepsTrpqX4hp83fBb/H7F2NxKHD9VQXLb9m\n\t\t\t\t\t\txn4sLVWIE/+JLYYGEMupR71JoPwqNEig2Of8H2Oe8/CNYS6IT0w+18ZbLKRfGEFV\n\t\t\t\t\t\tTUk4x96tPFm4+ARUZ8ZWeX2p8eCCicfm8UaShK8DQI3jELAkaSJvd1Pq5ZWrQxbj\n\t\t\t\t\t\t+ZwcGmKwLJavwEiBhafJxXrup5yvzIPOzW0skgpxK2jcfQqWO8I90dF7eqKDaUYW\n\t\t\t\t\t\t139vmCjkaZwlSi/F6jOBEEseHoL4lXr//gWKExA6bhk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ruskin.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ruskin.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ruskin.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ruskin.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ruskin.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ruskin.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ruskin.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ruskin.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ruskin.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ruskin.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjQCCQCeO7iggJ8z5DANBgkqhkiG9w0BAQUFADBoMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEUMBIGA1UECBMLT3hmb3Jkc2hpcmUxDzANBgNVBAcTBk94Zm9yZDEXMBUGA1UE\n\t\t\t\t\t\tChMOUnVza2luIENvbGxlZ2UxGTAXBgNVBAMTEGlkcC5ydXNraW4uYWMudWswHhcN\n\t\t\t\t\t\tMTIwNzEwMDk1MzQ0WhcNMzIwNzA1MDk1MzQ0WjBoMQswCQYDVQQGEwJHQjEUMBIG\n\t\t\t\t\t\tA1UECBMLT3hmb3Jkc2hpcmUxDzANBgNVBAcTBk94Zm9yZDEXMBUGA1UEChMOUnVz\n\t\t\t\t\t\ta2luIENvbGxlZ2UxGTAXBgNVBAMTEGlkcC5ydXNraW4uYWMudWswggEiMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC6+fdNYJiZH+zIfW6xLXXv5JNd/uJP8JQh\n\t\t\t\t\t\tyfrPx2PmggxywfTrMKJdRPpKtAUqPXlSB7acLAjD0U3XErjzYttjt+qXJEU2YUks\n\t\t\t\t\t\tgvwd7lJiIQXW5cf3LU14YySLpCbh/8dNQ1cmmwjQpAYA+vpYjckdOtL0qkt/7qMV\n\t\t\t\t\t\t59crl8ZpMpXusWIq2aZLlHU+Gf21Ez18O+aCkSj4vpcjyFc75YPZFNvDkRdccTtg\n\t\t\t\t\t\tnHxMB3k2ddm8IGbK4VlWymZZWxyl+fNilP0Yqs0OFdCOO6Uo15N60CXw+LcfGhKh\n\t\t\t\t\t\thntFJ9+9Z4MEAxKQanezzF2C9VtSHuni1Q5CiQWLXMEgzshgkSO3AgMBAAEwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBAC/xMtV84acTdAf98Pw7W2IGdi3dUXErdQkkmGMPxC/v\n\t\t\t\t\t\tWJcHbF5+WMozmWSdvci6XhipnxiHWbepsTrpqX4hp83fBb/H7F2NxKHD9VQXLb9m\n\t\t\t\t\t\txn4sLVWIE/+JLYYGEMupR71JoPwqNEig2Of8H2Oe8/CNYS6IT0w+18ZbLKRfGEFV\n\t\t\t\t\t\tTUk4x96tPFm4+ARUZ8ZWeX2p8eCCicfm8UaShK8DQI3jELAkaSJvd1Pq5ZWrQxbj\n\t\t\t\t\t\t+ZwcGmKwLJavwEiBhafJxXrup5yvzIPOzW0skgpxK2jcfQqWO8I90dF7eqKDaUYW\n\t\t\t\t\t\t139vmCjkaZwlSi/F6jOBEEseHoL4lXr//gWKExA6bhk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ruskin College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ruskin.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ruskin College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:ac.uk:sdss.ac.uk:provider:identity:dur.ac.uk",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itservicedesk@durham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Young"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.a.young@durham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:ac.uk:sdss.ac.uk:provider:identity:dur.ac.uk",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID9jCCAt6gAwIBAgIJAPxm6Cbnsa4zMA0GCSqGSIb3DQEBBQUAMHwxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRYwFAYDVQQIDA1Db3VudHkgRHVyaGFtMQ8wDQYDVQQHDAZEdXJoYW0x\n\t\t\t\t\t\tHTAbBgNVBAoMFFVuaXZlcnNpdHkgb2YgRHVyaGFtMQwwCgYDVQQLDANDSVMxFzAV\n\t\t\t\t\t\tBgNVBAMMDnNoaWIuZHVyLmFjLnVrMB4XDTEzMDMwNDExNTYyMloXDTIzMDMwNDEx\n\t\t\t\t\t\tNTYyMlowfDELMAkGA1UEBhMCR0IxFjAUBgNVBAgMDUNvdW50eSBEdXJoYW0xDzAN\n\t\t\t\t\t\tBgNVBAcMBkR1cmhhbTEdMBsGA1UECgwUVW5pdmVyc2l0eSBvZiBEdXJoYW0xDDAK\n\t\t\t\t\t\tBgNVBAsMA0NJUzEXMBUGA1UEAwwOc2hpYi5kdXIuYWMudWswggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDb3Inw3qmbQglj/PfdG0Gt4NLlgIF3VyMMKhkX\n\t\t\t\t\t\tKTgEZnEqMtz56yCrEQUv2q52+gEBHj5BC2I+tLH/D+hxeE2mscTsj5GYQEdXrZro\n\t\t\t\t\t\t8+hlAxD5ygHPYYA0vTUWXp1jy7Oa5jL9nzVFVCcxXowuEOezLFdDPR2+q99dz29O\n\t\t\t\t\t\tAz/9b6dVHb3IatG0ueDDNE+jtr+z7s67OEsgYL9cgkOs5bTbqZe6+BHs+MuRNYTI\n\t\t\t\t\t\t3FmwtVRwiGEITMbAe/BRyr6Oa04uzLBqH5Xgrl/N0cqwsjo+IR9QG1GoMwY1PYa4\n\t\t\t\t\t\toQKr5NXMfnjZ1fZnWwbiDnRpwvxzX8nDgPdNRrjqZGQzxLofAgMBAAGjezB5MAkG\n\t\t\t\t\t\tA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRp\n\t\t\t\t\t\tZmljYXRlMB0GA1UdDgQWBBTjOCzu4jEoqNnF741QhQ6iWPfeIzAfBgNVHSMEGDAW\n\t\t\t\t\t\tgBTjOCzu4jEoqNnF741QhQ6iWPfeIzANBgkqhkiG9w0BAQUFAAOCAQEA0Ayun4MT\n\t\t\t\t\t\t76SeQDaSUUJY6CSMgk65rX/U7Be3QgPLGkjnWS1jyuQ0iEMIbMINEQuqhLAhxmh1\n\t\t\t\t\t\tyGzwt4GOwqDO/HmzGbDA02coUENR58uwPXRwGjmNIW8k+BNOvfyh018rjM7dLxJU\n\t\t\t\t\t\tzxGW+ge+jbEjiGG/gVdarffIDjDmAONjmcdhrbunMCcL9xgH/2UDm/eowOr8TiBC\n\t\t\t\t\t\tdrL5y3PFQUwmcJwJx4hZs8GiTUtuEQa18vxYTM4tgKvOpey97hnhJxWOhk+kuH7v\n\t\t\t\t\t\t0pA98AVsugdhEPTTuW6EQSwKHKPWAqTE9D0hTr8frCdrSUIppziwK5Nlk5qXAn70\n\t\t\t\t\t\tCDgIrJGVkQXCNg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dur.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.dur.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.dur.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.dur.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.dur.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.dur.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.dur.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.dur.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.dur.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dur.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://shib.dur.ac.uk/idp/images/du90x101.png",
                    "height": "101",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "90"
                  },
                  {
                    "text": "https://shib.dur.ac.uk/idp/images/du16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Durham"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID9jCCAt6gAwIBAgIJAPxm6Cbnsa4zMA0GCSqGSIb3DQEBBQUAMHwxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRYwFAYDVQQIDA1Db3VudHkgRHVyaGFtMQ8wDQYDVQQHDAZEdXJoYW0x\n\t\t\t\t\t\tHTAbBgNVBAoMFFVuaXZlcnNpdHkgb2YgRHVyaGFtMQwwCgYDVQQLDANDSVMxFzAV\n\t\t\t\t\t\tBgNVBAMMDnNoaWIuZHVyLmFjLnVrMB4XDTEzMDMwNDExNTYyMloXDTIzMDMwNDEx\n\t\t\t\t\t\tNTYyMlowfDELMAkGA1UEBhMCR0IxFjAUBgNVBAgMDUNvdW50eSBEdXJoYW0xDzAN\n\t\t\t\t\t\tBgNVBAcMBkR1cmhhbTEdMBsGA1UECgwUVW5pdmVyc2l0eSBvZiBEdXJoYW0xDDAK\n\t\t\t\t\t\tBgNVBAsMA0NJUzEXMBUGA1UEAwwOc2hpYi5kdXIuYWMudWswggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDb3Inw3qmbQglj/PfdG0Gt4NLlgIF3VyMMKhkX\n\t\t\t\t\t\tKTgEZnEqMtz56yCrEQUv2q52+gEBHj5BC2I+tLH/D+hxeE2mscTsj5GYQEdXrZro\n\t\t\t\t\t\t8+hlAxD5ygHPYYA0vTUWXp1jy7Oa5jL9nzVFVCcxXowuEOezLFdDPR2+q99dz29O\n\t\t\t\t\t\tAz/9b6dVHb3IatG0ueDDNE+jtr+z7s67OEsgYL9cgkOs5bTbqZe6+BHs+MuRNYTI\n\t\t\t\t\t\t3FmwtVRwiGEITMbAe/BRyr6Oa04uzLBqH5Xgrl/N0cqwsjo+IR9QG1GoMwY1PYa4\n\t\t\t\t\t\toQKr5NXMfnjZ1fZnWwbiDnRpwvxzX8nDgPdNRrjqZGQzxLofAgMBAAGjezB5MAkG\n\t\t\t\t\t\tA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRp\n\t\t\t\t\t\tZmljYXRlMB0GA1UdDgQWBBTjOCzu4jEoqNnF741QhQ6iWPfeIzAfBgNVHSMEGDAW\n\t\t\t\t\t\tgBTjOCzu4jEoqNnF741QhQ6iWPfeIzANBgkqhkiG9w0BAQUFAAOCAQEA0Ayun4MT\n\t\t\t\t\t\t76SeQDaSUUJY6CSMgk65rX/U7Be3QgPLGkjnWS1jyuQ0iEMIbMINEQuqhLAhxmh1\n\t\t\t\t\t\tyGzwt4GOwqDO/HmzGbDA02coUENR58uwPXRwGjmNIW8k+BNOvfyh018rjM7dLxJU\n\t\t\t\t\t\tzxGW+ge+jbEjiGG/gVdarffIDjDmAONjmcdhrbunMCcL9xgH/2UDm/eowOr8TiBC\n\t\t\t\t\t\tdrL5y3PFQUwmcJwJx4hZs8GiTUtuEQa18vxYTM4tgKvOpey97hnhJxWOhk+kuH7v\n\t\t\t\t\t\t0pA98AVsugdhEPTTuW6EQSwKHKPWAqTE9D0hTr8frCdrSUIppziwK5Nlk5qXAn70\n\t\t\t\t\t\tCDgIrJGVkQXCNg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Durham"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dur.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Durham"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://test.scalable-learning.com",
    {
      "entity_id": "https://test.scalable-learning.com",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Scalable Learning"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "www.scalable-learning.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Scalable Learning"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.scalable-learning.com/home/about"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Scalable Learning"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Blended learning platform for interactive in-class and online education."
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Plattform f\u00f6r st\u00f6d av \"flipped classroom\" utbildning."
                  }
                ],
                "logo": [
                  {
                    "text": "https://test.scalable-learning.com/assets/logo-a66e557f3f93b4d5195033ba1a1527a3.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.scalable-learning.com/home/privacy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDjjCCAnYCCQCloAAdJBMwmDANBgkqhkiG9w0BAQsFADCBiDELMAkGA1UEBhMC\nU0UxEjAQBgNVBAgMCVNUT0NLSE9MTTESMBAGA1UEBwwJU1RPQ0tIT0xNMRowGAYD\nVQQKDBFTQ0FMQUJMRSBMRUFSTklORzEQMA4GA1UECwwHc2NhbGVhcjEjMCEGA1UE\nAwwadGVzdC5zY2FsYWJsZS1sZWFybmluZy5jb20wHhcNMTYwMjI1MTEyNzUxWhcN\nMTcwMjI0MTEyNzUxWjCBiDELMAkGA1UEBhMCU0UxEjAQBgNVBAgMCVNUT0NLSE9M\nTTESMBAGA1UEBwwJU1RPQ0tIT0xNMRowGAYDVQQKDBFTQ0FMQUJMRSBMRUFSTklO\nRzEQMA4GA1UECwwHc2NhbGVhcjEjMCEGA1UEAwwadGVzdC5zY2FsYWJsZS1sZWFy\nbmluZy5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDPYtv2obOV\nNRyVFwnXcl0pdqz8LHo/vkJGPHc8UHla8w+ceQQ7NZlmSeVOvXskStYwqh4HzAyk\nFmTb7hkCTP9yRnLrLTZUd6z2q0I0Skdo8A8r02mFfDPFin049/pqau9dlwbvLQyL\nIDcp2iqGeudpkikl7Gn7/zBkERCtwmiROAIs9B9m5VoAddLp/oVGnmErSPj0iVBu\nFB9kTiPoix5UFbTVGYhRFZiy6vFYfanBf9TucRpP8MicE3pLsYQ3IcIT9gcAtpyb\nY/GhHejXuxzEJ9QOkO1vRsL93ddxlAtWzewtBE8kKZYMbIkq5TyceQ1aTTVgKHqZ\n/pu/6E8ChiIJAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAB1TYuTkeR5OGmfugdw4\n9fB9hilkPpvTXDDLQUCR/QVNnfBORE+HUzCDp11TqT0TaRr4HV66rxH4FaJcn4qW\nYMYmDJ0oa7eLPvGIV5pRiDa4Cp5s+V61gNYIfGNHDS8BC3HouyiFW/owtQdOiNWE\nV/QqkTImxrx30CjnyNF5jttPEkAS4GGgo1O34IvEUXjE7Xe0CdlaQ9uRjNg8YxqI\npfmqBJSriM/SplXf72vjn9kg+fgsv8qp7yoj3pVt1o4Re8x3AvrF+sHd1m4J1BwA\nuU1mjJmnSIatkJ0UHoAPKlQrteJiiFL1yphWuTQnoRqUYsnxqIxA+vFOtrt9pQaM\nROE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.scalable-learning.com/saml/consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://sso.sandburg.edu/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rstevens@sandburg.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert W. Stevens"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rstevens@sandburg.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert W. Stevens"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "llee@sandburg.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Linda Lee"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://sso.sandburg.edu/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.sandburg.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIQPt0bxkiQr5BF6L3KT/y9lTANBgkqhkiG9w0BAQsFADAq\nMSgwJgYDVQQDEx9BREZTIFNpZ25pbmcgLSBzc28uc2FuZGJ1cmcuZWR1MB4XDTE0\nMDYwNjIwMzcxM1oXDTE3MDYwNTIwMzcxM1owKjEoMCYGA1UEAxMfQURGUyBTaWdu\naW5nIC0gc3NvLnNhbmRidXJnLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBAMqW/mUmJjFhq3kAzDacG8Q4z3ecotCJfs+sR/bZIb+N974+5urIO5aS\nxNcFCeBMbzrWwtDBpemoVAtTorN1vBNSIHAgBhRuHs7mVrx0e8IOoQ1yrxEWR6CB\nkng3CTaaEodj2ZWkcWsJ8Pa8hhx+4rNPItkVW0KTdhgSNN7Bo+h5p2QUq22iiLv9\nCvNM0iEC1ZpXchoUtjFdXxK9RrD3QN9rq3IW9WE9VMOCtb3zUxaQyxa67P7y3uOb\nFnAf1Y4SL3O0vIBpf3ku7tmBwpaZgKip1WftSRBkd5iKknFpMmr6CRtvf2xjy7MY\nkQ8Y1PrEsxPFaA50IPbJNZJC7YtEqmUCAwEAATANBgkqhkiG9w0BAQsFAAOCAQEA\nhRTR+0tt+vPT+iJ5ofhhdB02Jks0MUqWf8D77rRDUGyE9FbYSBpfyJQVh8cqvZK8\nLtmpKQEy/y7Tcyf3aT7dCIKkPo8aE66a9MCQu8OYi06U2afdzPbLWudh/ghoHtvM\nPV/4WPEVAWL7kxEB2GjmoOe/9PcrDsMrPYquUpOTWrdmIi5NH8D43Knn/I5g6SFD\nX4fEJaGeAhZjgOo/1x2hpavUnO7ypsTQOgkFbv2MDOeNhjkg0qggFlfintLAnhj8\nWO14ShXejUnH39hGHNJMTh81Pb45U4204XfQcGAt2amoD9VzMYNjyf0z/VbmsqML\nPm/hEI8PBxwYY7bgY1iVzQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sandburg.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.sandburg.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.sandburg.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIQPt0bxkiQr5BF6L3KT/y9lTANBgkqhkiG9w0BAQsFADAq\nMSgwJgYDVQQDEx9BREZTIFNpZ25pbmcgLSBzc28uc2FuZGJ1cmcuZWR1MB4XDTE0\nMDYwNjIwMzcxM1oXDTE3MDYwNTIwMzcxM1owKjEoMCYGA1UEAxMfQURGUyBTaWdu\naW5nIC0gc3NvLnNhbmRidXJnLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBAMqW/mUmJjFhq3kAzDacG8Q4z3ecotCJfs+sR/bZIb+N974+5urIO5aS\nxNcFCeBMbzrWwtDBpemoVAtTorN1vBNSIHAgBhRuHs7mVrx0e8IOoQ1yrxEWR6CB\nkng3CTaaEodj2ZWkcWsJ8Pa8hhx+4rNPItkVW0KTdhgSNN7Bo+h5p2QUq22iiLv9\nCvNM0iEC1ZpXchoUtjFdXxK9RrD3QN9rq3IW9WE9VMOCtb3zUxaQyxa67P7y3uOb\nFnAf1Y4SL3O0vIBpf3ku7tmBwpaZgKip1WftSRBkd5iKknFpMmr6CRtvf2xjy7MY\nkQ8Y1PrEsxPFaA50IPbJNZJC7YtEqmUCAwEAATANBgkqhkiG9w0BAQsFAAOCAQEA\nhRTR+0tt+vPT+iJ5ofhhdB02Jks0MUqWf8D77rRDUGyE9FbYSBpfyJQVh8cqvZK8\nLtmpKQEy/y7Tcyf3aT7dCIKkPo8aE66a9MCQu8OYi06U2afdzPbLWudh/ghoHtvM\nPV/4WPEVAWL7kxEB2GjmoOe/9PcrDsMrPYquUpOTWrdmIi5NH8D43Knn/I5g6SFD\nX4fEJaGeAhZjgOo/1x2hpavUnO7ypsTQOgkFbv2MDOeNhjkg0qggFlfintLAnhj8\nWO14ShXejUnH39hGHNJMTh81Pb45U4204XfQcGAt2amoD9VzMYNjyf0z/VbmsqML\nPm/hEI8PBxwYY7bgY1iVzQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sandburg.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.sandburg.edu/about-us/incommon-pop"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.sandburg.edu/incommon/InCommonLogo.png",
                    "lang": "en",
                    "height": "41",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "150"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.sandburg.edu/about-us/incommon-pop"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Carl Sandburg College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Carl Sandburg College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sandburg.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Carl Sandburg College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.unipv.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@unipv.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.unipv.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2010-04-28T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDujCCAqICCQCaKog9KThXSjANBgkqhkiG9w0BAQsFADCBnjELMAkGA1UEBhMC\nSVQxDjAMBgNVBAgTBUl0YWx5MQ4wDAYDVQQHEwVQYXZpYTEcMBoGA1UEChMTVW5p\ndmVyc2l0YSBkaSBQYXZpYTEcMBoGA1UECxMTVW5pdmVyc2l0YSBkaSBQYXZpYTEV\nMBMGA1UEAxMMaWRwLnVuaXB2Lml0MRwwGgYJKoZIhvcNAQkBFg1pZGVtQHVuaXB2\nLml0MB4XDTE2MDIyNDE1NTU0NFoXDTQ2MDIxNjE1NTU0NFowgZ4xCzAJBgNVBAYT\nAklUMQ4wDAYDVQQIEwVJdGFseTEOMAwGA1UEBxMFUGF2aWExHDAaBgNVBAoTE1Vu\naXZlcnNpdGEgZGkgUGF2aWExHDAaBgNVBAsTE1VuaXZlcnNpdGEgZGkgUGF2aWEx\nFTATBgNVBAMTDGlkcC51bmlwdi5pdDEcMBoGCSqGSIb3DQEJARYNaWRlbUB1bmlw\ndi5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOhUThDp4Mjef8q/\ngkNwI2ND7BKQDdWdAp7Zd6+p7Bieq7LEVhWvSa4lZcjUp21hoIFpOfXE33r0Dawm\nPkVHTolLsquyr5AsSUdx+OgXOVFmCJI6yR7SQEQIvPq9IrxKeX+ZPsZ/T9+Df9Nb\nefQ65gePBcRWQs5wG8hBPrjLk6RCBf0/6j8lsSjrYwrjDa3KwMkOGAx5zulPPaE9\nlS9Ucv56jbqJ4ObM78iFbfFuZ8au4M7SXlpvW1p+0kfWhlX/MWRkoQ7ZH6GWoCMR\ndF5E10KOekLxq+CnkpcohKaJHY1TakTvyKvF3XCwnfvEUniAIuW5sGDQ2q+Yuewi\nY7tvH/cCAwEAATANBgkqhkiG9w0BAQsFAAOCAQEAeFPCUt2yK8+WoBzbqJ4cbpcQ\njwd5UU5D16fQ4P74cyj07QfXyF0ADrzqUX8NFiKmfdPpwpZJMPNjoxzYLqd3KL5b\nieSa51VOA7YI8OrmzU9Kne44eIowC0NexwH2vr+CaqEktwMaqEt1fHHcHSOjeoVW\nU64XAuOKN9iAAb7vHEoU9QzYDb+zwXezx4BW1oR07M8OGdNq7muQ8Hd/7BumXv/u\nRJS/BmtNajeBB01paRuupxt5FhIDrUafxlV9ot3TcOYpC8QrkVSuhaeA/u3So1ZR\nobd7ED/DfZMAWgxHnwslh3ZvI+VT3X3NbKbvZIbLIvbKS1xsKbXLZxSRKJ5Ycg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unipv.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unipv.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unipv.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.unipv.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unipv.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.unipv.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unipv.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unipv.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unipv.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unipv.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unipv.it/idem"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unipv.it/idem"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Pavia"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 degli Studi di Pavia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider of the University of Pavia"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider per gli utenti dell'Universit\u00e0 di Pavia"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.unipv.it/LOGO16.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.unipv.it/LOGO16.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.unipv.it/LOGO_80.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idp.unipv.it/LOGO_80.png",
                    "lang": "it",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.unipv.eu/site/en/home/international-students/study-at-the-university-of-pavia/enroll-at-the-university-of-pavia/articolo4157.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.unipv.eu/site/home/matricole2013.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDujCCAqICCQCaKog9KThXSjANBgkqhkiG9w0BAQsFADCBnjELMAkGA1UEBhMC\nSVQxDjAMBgNVBAgTBUl0YWx5MQ4wDAYDVQQHEwVQYXZpYTEcMBoGA1UEChMTVW5p\ndmVyc2l0YSBkaSBQYXZpYTEcMBoGA1UECxMTVW5pdmVyc2l0YSBkaSBQYXZpYTEV\nMBMGA1UEAxMMaWRwLnVuaXB2Lml0MRwwGgYJKoZIhvcNAQkBFg1pZGVtQHVuaXB2\nLml0MB4XDTE2MDIyNDE1NTU0NFoXDTQ2MDIxNjE1NTU0NFowgZ4xCzAJBgNVBAYT\nAklUMQ4wDAYDVQQIEwVJdGFseTEOMAwGA1UEBxMFUGF2aWExHDAaBgNVBAoTE1Vu\naXZlcnNpdGEgZGkgUGF2aWExHDAaBgNVBAsTE1VuaXZlcnNpdGEgZGkgUGF2aWEx\nFTATBgNVBAMTDGlkcC51bmlwdi5pdDEcMBoGCSqGSIb3DQEJARYNaWRlbUB1bmlw\ndi5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOhUThDp4Mjef8q/\ngkNwI2ND7BKQDdWdAp7Zd6+p7Bieq7LEVhWvSa4lZcjUp21hoIFpOfXE33r0Dawm\nPkVHTolLsquyr5AsSUdx+OgXOVFmCJI6yR7SQEQIvPq9IrxKeX+ZPsZ/T9+Df9Nb\nefQ65gePBcRWQs5wG8hBPrjLk6RCBf0/6j8lsSjrYwrjDa3KwMkOGAx5zulPPaE9\nlS9Ucv56jbqJ4ObM78iFbfFuZ8au4M7SXlpvW1p+0kfWhlX/MWRkoQ7ZH6GWoCMR\ndF5E10KOekLxq+CnkpcohKaJHY1TakTvyKvF3XCwnfvEUniAIuW5sGDQ2q+Yuewi\nY7tvH/cCAwEAATANBgkqhkiG9w0BAQsFAAOCAQEAeFPCUt2yK8+WoBzbqJ4cbpcQ\njwd5UU5D16fQ4P74cyj07QfXyF0ADrzqUX8NFiKmfdPpwpZJMPNjoxzYLqd3KL5b\nieSa51VOA7YI8OrmzU9Kne44eIowC0NexwH2vr+CaqEktwMaqEt1fHHcHSOjeoVW\nU64XAuOKN9iAAb7vHEoU9QzYDb+zwXezx4BW1oR07M8OGdNq7muQ8Hd/7BumXv/u\nRJS/BmtNajeBB01paRuupxt5FhIDrUafxlV9ot3TcOYpC8QrkVSuhaeA/u3So1ZR\nobd7ED/DfZMAWgxHnwslh3ZvI+VT3X3NbKbvZIbLIvbKS1xsKbXLZxSRKJ5Ycg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Pavia"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 degli Studi di Pavia"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unipv.eu/site/en/home.html"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unipv.eu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Pavia"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli Studi di Pavia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://online.sagepub.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://online.sagepub.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-07-29T12:36:57Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SAGE Journals Online"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://online.sagepub.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HighWire Press, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.highwire.org/applications/sagepub/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.highwire.org/applications/sagepub/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIJAMTRVlqTJ11lMA0GCSqGSIb3DQEBBQUAMIG+MQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBD\n\t\t\t\t\t\taXR5MRcwFQYDVQQKEw5IaWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUx\n\t\t\t\t\t\tIDAeBgNVBAMTF3NoaWJib2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkB\n\t\t\t\t\t\tFiZzaGliYm9sZXRoLWFkbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTAeFw0xNDA0\n\t\t\t\t\t\tMTUxOTQzMDNaFw0yNDA0MTIxOTQzMDNaMIG+MQswCQYDVQQGEwJVUzETMBEGA1UE\n\t\t\t\t\t\tCBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBDaXR5MRcwFQYDVQQKEw5I\n\t\t\t\t\t\taWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUxIDAeBgNVBAMTF3NoaWJi\n\t\t\t\t\t\tb2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkBFiZzaGliYm9sZXRoLWFk\n\t\t\t\t\t\tbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALPB99M9iWjentrddY/rLgzKn1X0j4Ao191iyiowBBt/r/pmn2oz\n\t\t\t\t\t\tfrbONkkTVBB++mNtiufK6jyKnBM5mffPOkXHRo+K1DQec7TvpQ1PmLv/BpBgPrr9\n\t\t\t\t\t\tldViOSUnYJuB0IgJVV8oylgeH2Ay0XRkNPlBUjBA2fUPWVpXcvFe+aD2tLdVR9uO\n\t\t\t\t\t\tXvfTMxAEGqzxTU+OxO6pW2sBXNBmGvZQ0TRyovQh5+pTURY/lm0V/iWvRmRe51WE\n\t\t\t\t\t\tO/nhYyvRuMmNj8EL38o10S9TXuCkVzY00hK5cclaFge7gz/tfjmadVVcbe8xCVxc\n\t\t\t\t\t\tnb1lhmt1kH2XtKvU5hyZMTO+VUfXQvqcQyECAwEAAaN7MHkwCQYDVR0TBAIwADAs\n\t\t\t\t\t\tBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYD\n\t\t\t\t\t\tVR0OBBYEFJpUZq/XaW9/bPvjffkxX0IDvuPiMB8GA1UdIwQYMBaAFJpUZq/XaW9/\n\t\t\t\t\t\tbPvjffkxX0IDvuPiMA0GCSqGSIb3DQEBBQUAA4IBAQCq/FF56ZB1cL3KbniEJP99\n\t\t\t\t\t\tU9wTD6KpOrWxvqNbUSV1cefLf5cYHonOjy6oAJSSBSNuP7U5Q//0tXtkvlJoqGUY\n\t\t\t\t\t\tvqngmeg9wLZ/Fla3tXcDdTj0n1F+NZOx9vBDacIk0Ua4aHXDA4bdytzkV1QyZDRq\n\t\t\t\t\t\tQ8vq7RoQ8E5IF7Cll+kt2dZXQk8o6Qp3w2ppoMRtYdKOQassqn+V1MYcMPgdxZkS\n\t\t\t\t\t\tDrcgzktR/JMb5OmPrp4mSy1OWDGrFvUIigsLBPZV9tw1f7y42lnbmQas3RCS30yr\n\t\t\t\t\t\tCtUPT/PQDkCdBRViGmmMkYwjdaOTiHOJveWtrVXu8vLvO36pqFF4Kft0pgqlfvAE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.highwire.org/applications/sagepub/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.highwire.org/applications/sagepub/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.highwire.org/applications/sagepub/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.highwire.org/applications/sagepub/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://fam.carmel.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Burke"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kev@carmel.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kevin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Burke"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kev@carmel.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kevin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://fam.carmel.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-11-01T14:46:18Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAIqLMP1+YZiVFuSl3+ML0bJOAduCMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB8xHTAbBgNVBAMTFHNoaWJpZHAuY2FybWVsLmFjLnVrMB4XDTE0MDQzMDE1\n\t\t\t\t\t\tMTE1NloXDTM0MDQzMDE1MTE1NlowHzEdMBsGA1UEAxMUc2hpYmlkcC5jYXJtZWwu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCOeIdZOIToq8RS\n\t\t\t\t\t\t2E76IiVkssLXCGshL1IRzhwql+hB1tcDbyyQ86cKz8EbJcuoob+PO/z8G/oK3bmj\n\t\t\t\t\t\tCxqzK0tzlV9QxOykUVYJJMGiIl/hyvjURIrq6FN8TW22zmMOJcKbq3jSvNOy4z8p\n\t\t\t\t\t\tW2efstF5aI7hKh5hQ6t/HwIQrc5jvqbVSQIucfoC5LECE3MC00o0rOeCU9SphxRd\n\t\t\t\t\t\t6YgzqamXaxtwj0ON5RUL+CMF0s5rmFmNluaEypSwb7jtvIlS60EP5owBiimkWYp4\n\t\t\t\t\t\tU0hBey4VxGItqNQ/qQAQsLHzfS4IOyI1JpspcmfU8krltECZEV1DiSblrN2+Uwjy\n\t\t\t\t\t\t1njykW/nAgMBAAGjbzBtMEwGA1UdEQRFMEOCFHNoaWJpZHAuY2FybWVsLmFjLnVr\n\t\t\t\t\t\thitodHRwczovL3NoaWJpZHAuY2FybWVsLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0G\n\t\t\t\t\t\tA1UdDgQWBBQcbtOJdw/shpXLO82zmaTiYMOw0jANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tHO9dtyYWJuaFG/1EzSYcICuWD+1FvPvkWpc74PxXeii9GXlJm8T3YGlylsh9Hm+Q\n\t\t\t\t\t\tCtCgNo5nEX6cEFdBF0W4MLiAC60dUG9tFhxYfq0Eki2wGdYW6il4p6rqMriVVLHa\n\t\t\t\t\t\tYYVAPLqBmY+AFtmnkrv3AYLb7QxhGCuoTp6NGD1bghV33LL1JbmNzTSNhb+29AMf\n\t\t\t\t\t\t5vt3p/Xvx26NA4w+9mi1ALSUYiX5mYJ6BI7ZSmcRms46coPLhpSpKCATfXeMwgOO\n\t\t\t\t\t\tH6FIFa78iAxfsERmipMjp31yExWQ2jMfbQFMrMwocThoymgkjwX39KpLUGE6VkTN\n\t\t\t\t\t\tW23+BuUVpxDOnTQb4XrNbg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "carmel.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.carmel.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.carmel.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.carmel.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.carmel.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibidp.carmel.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.carmel.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.carmel.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.carmel.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "carmel.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAIqLMP1+YZiVFuSl3+ML0bJOAduCMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB8xHTAbBgNVBAMTFHNoaWJpZHAuY2FybWVsLmFjLnVrMB4XDTE0MDQzMDE1\n\t\t\t\t\t\tMTE1NloXDTM0MDQzMDE1MTE1NlowHzEdMBsGA1UEAxMUc2hpYmlkcC5jYXJtZWwu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCOeIdZOIToq8RS\n\t\t\t\t\t\t2E76IiVkssLXCGshL1IRzhwql+hB1tcDbyyQ86cKz8EbJcuoob+PO/z8G/oK3bmj\n\t\t\t\t\t\tCxqzK0tzlV9QxOykUVYJJMGiIl/hyvjURIrq6FN8TW22zmMOJcKbq3jSvNOy4z8p\n\t\t\t\t\t\tW2efstF5aI7hKh5hQ6t/HwIQrc5jvqbVSQIucfoC5LECE3MC00o0rOeCU9SphxRd\n\t\t\t\t\t\t6YgzqamXaxtwj0ON5RUL+CMF0s5rmFmNluaEypSwb7jtvIlS60EP5owBiimkWYp4\n\t\t\t\t\t\tU0hBey4VxGItqNQ/qQAQsLHzfS4IOyI1JpspcmfU8krltECZEV1DiSblrN2+Uwjy\n\t\t\t\t\t\t1njykW/nAgMBAAGjbzBtMEwGA1UdEQRFMEOCFHNoaWJpZHAuY2FybWVsLmFjLnVr\n\t\t\t\t\t\thitodHRwczovL3NoaWJpZHAuY2FybWVsLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0G\n\t\t\t\t\t\tA1UdDgQWBBQcbtOJdw/shpXLO82zmaTiYMOw0jANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tHO9dtyYWJuaFG/1EzSYcICuWD+1FvPvkWpc74PxXeii9GXlJm8T3YGlylsh9Hm+Q\n\t\t\t\t\t\tCtCgNo5nEX6cEFdBF0W4MLiAC60dUG9tFhxYfq0Eki2wGdYW6il4p6rqMriVVLHa\n\t\t\t\t\t\tYYVAPLqBmY+AFtmnkrv3AYLb7QxhGCuoTp6NGD1bghV33LL1JbmNzTSNhb+29AMf\n\t\t\t\t\t\t5vt3p/Xvx26NA4w+9mi1ALSUYiX5mYJ6BI7ZSmcRms46coPLhpSpKCATfXeMwgOO\n\t\t\t\t\t\tH6FIFa78iAxfsERmipMjp31yExWQ2jMfbQFMrMwocThoymgkjwX39KpLUGE6VkTN\n\t\t\t\t\t\tW23+BuUVpxDOnTQb4XrNbg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Carmel College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.carmel.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Carmel College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.shibboleth.stir.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:infocentre@stir.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Information Centre"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "White"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:michael.white@stir.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.shibboleth.stir.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUbZSEbusfMF9L8dG2tMTBbcHOLgkwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwIDEeMBwGA1UEAwwVc2hpYmJvbGV0aC5zdGlyLmFjLnVrMB4XDTE2MDMxMTEw\n\t\t\t\t\t\tMTA1OVoXDTM2MDMxMTEwMTA1OVowIDEeMBwGA1UEAwwVc2hpYmJvbGV0aC5zdGly\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAi5zAlq+Ag9fx\n\t\t\t\t\t\tPrYqWPjR1opvFW7W0q74TzsZVtTRzPbRX+JioOmtRZ/lUuAzg3AMN9uOdsLwIDC3\n\t\t\t\t\t\tTjMFqKma5nVr1DjaAiyXM1epg2KF9uvWeBVKHtf1K79P4YX89596x3Os+78xfOc1\n\t\t\t\t\t\tUqLHwonzrypW4DQ8LaUS29ps6DP53m7Ku4Zis40UDjDxAq1r1oUSrHQ0iotIP7C5\n\t\t\t\t\t\tsZgoDCiStMi0edOEZaz3VHE1TwZRU9lKxukTExukosnnuFnhTGnCx2m1BZZ1mr4W\n\t\t\t\t\t\tVczqClqPBDxtDFF4EMel3UHdoXryFivLugAfGfB/j985Gz4HLEFJbNHndxwPNMeO\n\t\t\t\t\t\ty36WfvwviQIDAQABo3EwbzAdBgNVHQ4EFgQUKuzqJFSHbDKuNmDOgQpxsPGvDQcw\n\t\t\t\t\t\tTgYDVR0RBEcwRYIVc2hpYmJvbGV0aC5zdGlyLmFjLnVrhixodHRwczovL3NoaWJi\n\t\t\t\t\t\tb2xldGguc3Rpci5hYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAfsXJth16cogV396hlFqSJNvn+9NyjxTYtmDCR31vgWFNiZbEpLchaB+TrJXp\n\t\t\t\t\t\tQhmpkIH7upZzm8xzziHpWBeCW8aTURtVpCZ6foXbB+rJ/2Gn9WulHN8pkI6eGYmp\n\t\t\t\t\t\tnSmmrt6omRjygxfYDqFQ4NaGt/Ol8IEvLqK4dH6KQipayg9V9fQYGyAvqtpRyQYS\n\t\t\t\t\t\tQIL5hfLciL/LW8PIYB0ubwzg6jJ9eRjQt/83v9Ex8/gx9KuafmGYsRM+PRJqqDN1\n\t\t\t\t\t\twEH5lnbR/BzHdUXSVBOEmF9tvzpSRwnvulmZ8qYpGucNdvtJ/+pCnxAmOmwdW2yb\n\t\t\t\t\t\tPo48+yaXB6j2o1B0bvfg74oZBw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stir.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.stir.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.stir.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.stir.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.stir.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.stir.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.stir.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.stir.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.stir.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stir.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUbZSEbusfMF9L8dG2tMTBbcHOLgkwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwIDEeMBwGA1UEAwwVc2hpYmJvbGV0aC5zdGlyLmFjLnVrMB4XDTE2MDMxMTEw\n\t\t\t\t\t\tMTA1OVoXDTM2MDMxMTEwMTA1OVowIDEeMBwGA1UEAwwVc2hpYmJvbGV0aC5zdGly\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAi5zAlq+Ag9fx\n\t\t\t\t\t\tPrYqWPjR1opvFW7W0q74TzsZVtTRzPbRX+JioOmtRZ/lUuAzg3AMN9uOdsLwIDC3\n\t\t\t\t\t\tTjMFqKma5nVr1DjaAiyXM1epg2KF9uvWeBVKHtf1K79P4YX89596x3Os+78xfOc1\n\t\t\t\t\t\tUqLHwonzrypW4DQ8LaUS29ps6DP53m7Ku4Zis40UDjDxAq1r1oUSrHQ0iotIP7C5\n\t\t\t\t\t\tsZgoDCiStMi0edOEZaz3VHE1TwZRU9lKxukTExukosnnuFnhTGnCx2m1BZZ1mr4W\n\t\t\t\t\t\tVczqClqPBDxtDFF4EMel3UHdoXryFivLugAfGfB/j985Gz4HLEFJbNHndxwPNMeO\n\t\t\t\t\t\ty36WfvwviQIDAQABo3EwbzAdBgNVHQ4EFgQUKuzqJFSHbDKuNmDOgQpxsPGvDQcw\n\t\t\t\t\t\tTgYDVR0RBEcwRYIVc2hpYmJvbGV0aC5zdGlyLmFjLnVrhixodHRwczovL3NoaWJi\n\t\t\t\t\t\tb2xldGguc3Rpci5hYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAfsXJth16cogV396hlFqSJNvn+9NyjxTYtmDCR31vgWFNiZbEpLchaB+TrJXp\n\t\t\t\t\t\tQhmpkIH7upZzm8xzziHpWBeCW8aTURtVpCZ6foXbB+rJ/2Gn9WulHN8pkI6eGYmp\n\t\t\t\t\t\tnSmmrt6omRjygxfYDqFQ4NaGt/Ol8IEvLqK4dH6KQipayg9V9fQYGyAvqtpRyQYS\n\t\t\t\t\t\tQIL5hfLciL/LW8PIYB0ubwzg6jJ9eRjQt/83v9Ex8/gx9KuafmGYsRM+PRJqqDN1\n\t\t\t\t\t\twEH5lnbR/BzHdUXSVBOEmF9tvzpSRwnvulmZ8qYpGucNdvtJ/+pCnxAmOmwdW2yb\n\t\t\t\t\t\tPo48+yaXB6j2o1B0bvfg74oZBw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Stirling"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.stir.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Stirling"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://test.shu.unidesk.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:IS.Helpdesk@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-certs@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Application Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test.shu.unidesk.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-05-03T13:52:51Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Edinburgh: Unidesk - Sheffield Hallam University (Test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.shu.unidesk.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://test.shu.unidesk.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.shu.unidesk.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.shu.unidesk.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.shu.unidesk.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.shu.unidesk.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAKOQZJ9XeRRZMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\n\t\t\t\t\t\tBAMTEnRlc3QudW5pZGVzay5hYy51azAeFw0xMjAzMjIxNjUwMTdaFw0yMjAzMjAx\n\t\t\t\t\t\tNjUwMTdaMB0xGzAZBgNVBAMTEnRlc3QudW5pZGVzay5hYy51azCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBAPweFLYNELDowDm8YWp8G8RKR0q+ufgUN7H7\n\t\t\t\t\t\th7RTesgxlO9T8wXLT1e4s1ruCVrYtkt8q3K+iXukZ+J5QD4lMtvWHfbpKJNddygG\n\t\t\t\t\t\tRkURpJQ7bY1rTdWA6jNi16TR+8M2ECIf4Q6CVukHHrX9PuZM+b7Ktg2gf3fmy7vQ\n\t\t\t\t\t\tMQ2/2Rp8/LKGKotVAoRYrNc8y3Y2PR9omsidxNGyyXxfD2OyTobuk1Ezb7Fk4Oq+\n\t\t\t\t\t\t4VmetrJ5CwFOwTBmFUgfaazuooEvGM7tA/jjRGDY5H+4oyVDK63Ktf59pwGln6Bo\n\t\t\t\t\t\tJyBfJIWYK/5w3psQJZCFyNgJ4WQSgxbAiORGQPZLfKxsvAaGD2UCAwEAAaNAMD4w\n\t\t\t\t\t\tHQYDVR0RBBYwFIISdGVzdC51bmlkZXNrLmFjLnVrMB0GA1UdDgQWBBRxsmQCxZXe\n\t\t\t\t\t\tbZvQMvehqWxt1yHYijANBgkqhkiG9w0BAQUFAAOCAQEAtOWghRw2KKVvYbX0sQEX\n\t\t\t\t\t\tVDYPpi4Q1q6b1vl/MK0WU+zWjOmuljIIw377NOuH+A8zwJF2maelKlEHFmlMg8nl\n\t\t\t\t\t\ta8MPTIQIhgJ3baXwfy5jvEIQrK++0LwaFiBdwg0dM3er6pyODVypn6oNpKY9gcFA\n\t\t\t\t\t\txCl05pTEBIWPAxFNcvYj/liPrDC8RcEBpnEiGZcJgvPGCulXV3O9FCRkoyTaVoUB\n\t\t\t\t\t\te42UmPVs7zqOGsBy6ZcHRGoD53VWtkvax8iBGBobK0fGICh6vyX7Qb6Me3r/7S1h\n\t\t\t\t\t\t6WUcF/Nm7P5V6V2an8MJPYyIVNn6QorTplFsBhK4/Wr+Xb4JIurIwCWDqbVIYo1j\n\t\t\t\t\t\tTA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.shu.unidesk.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://test.shu.unidesk.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.shu.unidesk.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://test.shu.unidesk.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://test.shu.unidesk.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://test.shu.unidesk.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.highwire.org/entity/lcgsl",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.highwire.org/entity/lcgsl",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-08-05T10:00:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lyell Collection: The Geological Society of London"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lyellcollection.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HighWire Press, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.highwire.org/applications/lcgsl/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.highwire.org/applications/lcgsl/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIJAMTRVlqTJ11lMA0GCSqGSIb3DQEBBQUAMIG+MQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBD\n\t\t\t\t\t\taXR5MRcwFQYDVQQKEw5IaWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUx\n\t\t\t\t\t\tIDAeBgNVBAMTF3NoaWJib2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkB\n\t\t\t\t\t\tFiZzaGliYm9sZXRoLWFkbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTAeFw0xNDA0\n\t\t\t\t\t\tMTUxOTQzMDNaFw0yNDA0MTIxOTQzMDNaMIG+MQswCQYDVQQGEwJVUzETMBEGA1UE\n\t\t\t\t\t\tCBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBDaXR5MRcwFQYDVQQKEw5I\n\t\t\t\t\t\taWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUxIDAeBgNVBAMTF3NoaWJi\n\t\t\t\t\t\tb2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkBFiZzaGliYm9sZXRoLWFk\n\t\t\t\t\t\tbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALPB99M9iWjentrddY/rLgzKn1X0j4Ao191iyiowBBt/r/pmn2oz\n\t\t\t\t\t\tfrbONkkTVBB++mNtiufK6jyKnBM5mffPOkXHRo+K1DQec7TvpQ1PmLv/BpBgPrr9\n\t\t\t\t\t\tldViOSUnYJuB0IgJVV8oylgeH2Ay0XRkNPlBUjBA2fUPWVpXcvFe+aD2tLdVR9uO\n\t\t\t\t\t\tXvfTMxAEGqzxTU+OxO6pW2sBXNBmGvZQ0TRyovQh5+pTURY/lm0V/iWvRmRe51WE\n\t\t\t\t\t\tO/nhYyvRuMmNj8EL38o10S9TXuCkVzY00hK5cclaFge7gz/tfjmadVVcbe8xCVxc\n\t\t\t\t\t\tnb1lhmt1kH2XtKvU5hyZMTO+VUfXQvqcQyECAwEAAaN7MHkwCQYDVR0TBAIwADAs\n\t\t\t\t\t\tBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYD\n\t\t\t\t\t\tVR0OBBYEFJpUZq/XaW9/bPvjffkxX0IDvuPiMB8GA1UdIwQYMBaAFJpUZq/XaW9/\n\t\t\t\t\t\tbPvjffkxX0IDvuPiMA0GCSqGSIb3DQEBBQUAA4IBAQCq/FF56ZB1cL3KbniEJP99\n\t\t\t\t\t\tU9wTD6KpOrWxvqNbUSV1cefLf5cYHonOjy6oAJSSBSNuP7U5Q//0tXtkvlJoqGUY\n\t\t\t\t\t\tvqngmeg9wLZ/Fla3tXcDdTj0n1F+NZOx9vBDacIk0Ua4aHXDA4bdytzkV1QyZDRq\n\t\t\t\t\t\tQ8vq7RoQ8E5IF7Cll+kt2dZXQk8o6Qp3w2ppoMRtYdKOQassqn+V1MYcMPgdxZkS\n\t\t\t\t\t\tDrcgzktR/JMb5OmPrp4mSy1OWDGrFvUIigsLBPZV9tw1f7y42lnbmQas3RCS30yr\n\t\t\t\t\t\tCtUPT/PQDkCdBRViGmmMkYwjdaOTiHOJveWtrVXu8vLvO36pqFF4Kft0pgqlfvAE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.highwire.org/applications/lcgsl/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.highwire.org/applications/lcgsl/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.highwire.org/applications/lcgsl/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.highwire.org/applications/lcgsl/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://etenta.math.su.se/shibboleth",
    {
      "entity_id": "https://etenta.math.su.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://etenta.math.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://etenta.math.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://etenta.math.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://etenta.math.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "etenta.math.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEcDCCA1igAwIBAgIQPeuEmtzAXHUS0vug+BLA6TANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEwMDExNTAwMDAwMFoXDTEzMDExNDIzNTk1OVowSjELMAkGA1UE\nBhMCU0UxHzAdBgNVBAoTFlN0b2NraG9sbXMgdW5pdmVyc2l0ZXQxGjAYBgNVBAMT\nEWV0ZW50YS5tYXRoLnN1LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAqTegRf6kffNbA8D4Lrij26Zu81qPigIokEhLdZrGsx5DEH5jsmoIrhoEZshV\nvBGwIJIA/IoxRZFEjcTWvaJcYG01oSr3/XBKeYjEVRSX3KxbcU5Dd2qN5YnvyxoW\noldlTmU22TuOovup0UjkKpQ7VPzgcMU3gQ6Cx0oUHJ0KAgI6yCMooX/cR0CCjfZ6\nXTPTqtnoSYr+j2ZWGNcHUBd0AFXu6fNBxmpy/HTNY+UVeaWF5shrg2tginZkQQ2m\n1R/RFiNxC5JPv5IBrZ8YkkvLOz7rQAkVCnXAVl7bp75qpxQ3R9mAJV4KpcFHY04e\n7plxQY1ISBvoqNPJkOIhDr/sdwIDAQABo4IBZDCCAWAwHwYDVR0jBBgwFoAUDL2T\naAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFEEgsYJkGCGrGtB3mPmAQMXlCOru\nMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUF\nBwMBBggrBgEFBQcDAjAYBgNVHSAEETAPMA0GCysGAQQBsjEBAgIdMDoGA1UdHwQz\nMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0Eu\nY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3Mu\ndGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9v\nY3NwLnRjcy50ZXJlbmEub3JnMBwGA1UdEQQVMBOCEWV0ZW50YS5tYXRoLnN1LnNl\nMA0GCSqGSIb3DQEBBQUAA4IBAQBSD+s+1zbkDWniGmAo0iqclGzJQU6UKqmZuIF/\n0dOT5vZ6XyyZfhRqVVAew9m+E7IUg9iZcpKF4XtL1awUR+3tAyFJs05WWX0dcIFk\nqgvOsb54NBLDwdmM1f0B5yedJVZ6VFf3pqig17V25phElY/ArJe4XyqOS0JnXrd5\nUayFwWyOsjbZ5W0YhKAi8CCOdjQkz01Es3PCo6c0AL3uKOUNvVVmF8Jrku6DPzT2\nm27FphoUCoQa8mZRcxd4h/fmEhQMg2ZTVbLz+jwjI865pueFODIgf/8IAfiTDM6y\nvC40Zznf98QP1QaaAJ1B90WydJegGcz28vmrn1SEIIlOtTic"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=etenta.math.su.se,O=Stockholms universitet,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "etenta.math.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEcDCCA1igAwIBAgIQPeuEmtzAXHUS0vug+BLA6TANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEwMDExNTAwMDAwMFoXDTEzMDExNDIzNTk1OVowSjELMAkGA1UE\nBhMCU0UxHzAdBgNVBAoTFlN0b2NraG9sbXMgdW5pdmVyc2l0ZXQxGjAYBgNVBAMT\nEWV0ZW50YS5tYXRoLnN1LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAqTegRf6kffNbA8D4Lrij26Zu81qPigIokEhLdZrGsx5DEH5jsmoIrhoEZshV\nvBGwIJIA/IoxRZFEjcTWvaJcYG01oSr3/XBKeYjEVRSX3KxbcU5Dd2qN5YnvyxoW\noldlTmU22TuOovup0UjkKpQ7VPzgcMU3gQ6Cx0oUHJ0KAgI6yCMooX/cR0CCjfZ6\nXTPTqtnoSYr+j2ZWGNcHUBd0AFXu6fNBxmpy/HTNY+UVeaWF5shrg2tginZkQQ2m\n1R/RFiNxC5JPv5IBrZ8YkkvLOz7rQAkVCnXAVl7bp75qpxQ3R9mAJV4KpcFHY04e\n7plxQY1ISBvoqNPJkOIhDr/sdwIDAQABo4IBZDCCAWAwHwYDVR0jBBgwFoAUDL2T\naAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFEEgsYJkGCGrGtB3mPmAQMXlCOru\nMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUF\nBwMBBggrBgEFBQcDAjAYBgNVHSAEETAPMA0GCysGAQQBsjEBAgIdMDoGA1UdHwQz\nMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0Eu\nY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3Mu\ndGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9v\nY3NwLnRjcy50ZXJlbmEub3JnMBwGA1UdEQQVMBOCEWV0ZW50YS5tYXRoLnN1LnNl\nMA0GCSqGSIb3DQEBBQUAA4IBAQBSD+s+1zbkDWniGmAo0iqclGzJQU6UKqmZuIF/\n0dOT5vZ6XyyZfhRqVVAew9m+E7IUg9iZcpKF4XtL1awUR+3tAyFJs05WWX0dcIFk\nqgvOsb54NBLDwdmM1f0B5yedJVZ6VFf3pqig17V25phElY/ArJe4XyqOS0JnXrd5\nUayFwWyOsjbZ5W0YhKAi8CCOdjQkz01Es3PCo6c0AL3uKOUNvVVmF8Jrku6DPzT2\nm27FphoUCoQa8mZRcxd4h/fmEhQMg2ZTVbLz+jwjI865pueFODIgf/8IAfiTDM6y\nvC40Zznf98QP1QaaAJ1B90WydJegGcz28vmrn1SEIIlOtTic"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=etenta.math.su.se,O=Stockholms universitet,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://etenta.math.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://etenta.math.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://etenta.math.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://etenta.math.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://etenta.math.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://etenta.math.su.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://etenta.math.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://etenta.math.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://etenta.math.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://etenta.math.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-09.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-09.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;09"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;09"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-09.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-09.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAKHAw32nqb4aMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wOS5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTQ0MzA5WhcNMjQx\nMDA0MTQ0MzA5WjAhMR8wHQYDVQQDExZsYWRvazMtMDkubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA4qCGNdWn1MRb1t4RmqEFKnRp\nZwc88GDSNVxdEHR6jRWUyPgugOa/s/b8Ef3J04ajiXdGJUjVkNaaoxOKgH7JNOW4\n29qfjzgKVX4G5Ipcxfbp+/Wn52kXCZfrDUX1e7Amc1tG/tAgNgHdKCj7EZneP819\nRlrDYCRyYP5VAUvWTuujaQFJFXEdgAkWtkfeQBt9HMU2eSCj/SpdDPJpDFI2BKuz\n7z/MkFlhz8ywuFJDZ+O/lNiE9xeS2DEMXQ2Y7tR25EfeXJkSwkWkRiJoNMrtp2Hc\nN1dWsmReAH4NZKahsYL3JsKCzbSsgr/OW5SgyREJFGsTqTCQc7rPw8YsLizUbQID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMDkubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0wOS5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUlelU5h8KM7K0SC1Dwm6D4T5ZvBswDQYJKoZIhvcNAQEFBQADggEB\nADm1+g/0bCQST/RsDvEdy1VfdjLTX+ODy05PiGUy+GlhR2phHhbZ4vddtrV9FuIl\nx28aT8Xvmu47uQIgm26PAtiM1tZYV1JeWTP821NAKfVjl6QKyHnOSksKCC3yOlVk\nO2Vxsu0YyAl0aGvd6FqykxxDClUCSg1nboUhGyr6rgPVxv/+VbI9wNj8QocEDMC4\n55fjM0PeDjSTdjWUPyzX/VFhEtBYrFodS0b9rHWLM+yKKaDG0Gl9E5f9k1uEUNtr\nU83MU1NmV9lmNF1itMe+ujgc/6Af0/F0MTIulAtx1+ZMtIrw3k9at4Auz+urHU37\nRRQKVctmQVOlffVIDFzZgbA="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-09.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-09.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://moodle.helsinki.fi/shibboleth",
    {
      "entity_id": "https://moodle.helsinki.fi/shibboleth",
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Schach"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:heiko.schach@helsinki.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Heiko"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Peltonen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:haka-hy@helsinki.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Janne"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Helsingin yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Helsinki"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Helsingfors universitet"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.helsinki.fi/yliopisto/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.helsinki.fi/yliopisto/"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.helsinki.fi/yliopisto/"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Helsingin yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Helsinki"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Helsingfors universitet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://moodle.helsinki.fi/Shibboleth.sso/HAKALogin",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Helsinki Moodle learning management system."
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Helsingin yliopiston Moodle-oppimisalusta."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://moodle.helsinki.fi/rekisteriseloste.htm"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Helsinki Moodle"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Helsingin yliopiston Moodle"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "kalmar"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "finland"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "tags",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFcTCCBFmgAwIBAgIQBs4LDAt4QhHxA6/9vcQV2jANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQwOTAwMDAwMFoXDTE3MDQwODIzNTk1OVowQDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRswGQYDVQQDExJtb29kbGUuaGVs\nc2lua2kuZmkwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQDRJht4CmQi\n9WWU+ep1UhI11GXJTUXY4PzukaXUtO4RbZAnvd0U4Xb5sPDNsCVSIASBX0fkbSZJ\nyQ8FY/PhRk2QIt+erjReWIWA6V3UY6kJIq9IrUh4Z06aGrLvkEjHFbI0VA/AZ/8T\n2BxJrMg3v9mT12B9ueDvybIc6IERiDctRrB+s5nPskvua/2oTq4hDM9mGYTN4ZLB\nfR2OViwPxsGi3V22+iLa66JCmIK8kCeekNhS7OsclWWzIfPpCW1azjUZ2HrRndoi\nA/zJSpmT1rxY8WTchr0xdPdgVDzDZSv/FhRDacbFIC99drSWmg4wiYLvIidDt/zu\ntRoJdUGYPxqljdsyHwftjqqy2YNSMrxD8LDsaF07RZYjpK9GLDXroJzEOhlAJu/c\nqd4+RO+LjF21TWTe4Kw9u4+VNvjrfFDvkj5QAPxti70nOzkqY9Y+T4h1UNkyr8u+\nEGjNLOIE41B5V5MhTkf9x6lQD9IkejHpZA2bP5dmUtBft72UCPCDm2YMkLeXfOI9\nCaBkxLzi4doXmNLjXVEtsVx3qkvyH595ACnSaS/kUfnbgjaMdz15dh7PUPz2OQAE\nP3VijjcTzls96u81aBfHOHY1khqEueKkehJLq7ZFLefy/hcnFDMXWNMSeQaiGDjO\nqMAYHGzjR94Uar2Jvxvwzg2dF3GznzLZeQIDAQABo4IBbzCCAWswHwYDVR0jBBgw\nFoAUDL2TaAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFB8kuozI2dNLBE+Oy8Ie\nRp4+GmUeMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQG\nCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgG\nBmeBDAECATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEu\nb3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKG\nKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsG\nAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJt\nb29kbGUuaGVsc2lua2kuZmkwDQYJKoZIhvcNAQEFBQADggEBAEkxmg/WVjzPKULi\n7OO3LiKrIgAhRchg8SGfngcgM6E2I8RoLS69/ZC0eWOubAZBJPfvCvaX5u3GWTWd\ndtHeCZWIKOhCFKMj079qWO27O67ys/E//vYakEnSxkpBkQ5u0tyolS7BFQcTWoPR\nBFc/Z+NaZhBmcm7tyFkQsrHTQZTq/s1Anxc7t3sXuUsFl4/LOEwiXkJYoxYOPE7t\nA0iMOwlhJ5VuCIEYZLJ1yA6AZCgJX8TgZvQEdsAxIA6VFJmXsJokBa/wDYQt5fPo\nkBViCHGTlh5cyshXEA2zL/Ywe8EjJkZCDWdoOC+r6CGtxjRxD7tvb/27+1dbYnI0\nRed7UuI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFnjCCBIagAwIBAgIQAa60w0P1Cl6irXa1E/4AGDANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMjAeFw0xNTAxMjEwMDAwMDBaFw0xODAxMjAyMzU5NTlaMEAxITAfBgNVBAsT\nGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEbMBkGA1UEAxMSbW9vZGxlLmhlbHNp\nbmtpLmZpMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAobGdkxFsFGHO\ncMRzBCX5AAPgOLEIx7ei40YzJyAAvBkG4TiQKqYk5KiMQESs0jhpl5SSbOzfHZn2\n8YTLrbxEH66hPeOKiY8bzVc95HILVRUCq9Cc1XraSFwUmjwAXTPD9BKbLOaygWy2\nZs/OvEZBikq8zWPumUCIIX/FXpmAQxcaWyDS6MG+Q6Qe6sVvuE4Qw9yp5qih7gxW\nKfnzBacZqkTS/2YncU5O+jp/hwq124lJyobDfkV5JHFpaVz35idS4wmymkBHMSfV\nW2Nx9JXzjeFgOzyHSR8qEBWNMLYZgupy5b/Bz1fgF1QrOeef578BrvceQJz3Wyc9\ndvdNn1YYDphvgcZ1GRHT06u93q9GFGUKOjaQvRt3OIWyMryU68cc/aP0E9+5Cum7\noF+zDXejLMuG3If8JGv6OQKa2K3D+NIz6VE0jXs3cmvhVqKCes0Pr59whRHEvYCZ\n53T3N9fGd2+foeWlBMl4SUjk+IYx1i1eNZah8KgF0yhGe4+8Rfd0MQWHmTi6z+bQ\nCL6gXDMyNAjYPVgSszSe+1iI09SxMf8J7vpbqtsMfS2d7jV9Nw4TkqdueSQv/ubl\n1IghNgesE6nCfcJjKvtcXM7OmCXGCS4Kzma9Xw7D00+iROat4iZiF+2leTxepQ4b\nyHU3gz295Zktf5mk1BUNXrM233t5TR0CAwEAAaOCAW4wggFqMB8GA1UdIwQYMBaA\nFFvQihyaMlvgtd2WVBvhhiiw/ba9MB0GA1UdDgQWBBR6HHOoJmR4av4M5Ksok4vc\naujrhzAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggr\nBgEFBQcDAQYIKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZn\ngQwBAgEwOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC51c2VydHJ1c3QuY29t\nL1RFUkVOQVNTTENBMi5jcmwwbAYIKwYBBQUHAQEEYDBeMDUGCCsGAQUFBzAChilo\ndHRwOi8vY3J0LnVzZXJ0cnVzdC5jb20vVEVSRU5BU1NMQ0EyLmNydDAlBggrBgEF\nBQcwAYYZaHR0cDovL29jc3AudXNlcnRydXN0LmNvbTAdBgNVHREEFjAUghJtb29k\nbGUuaGVsc2lua2kuZmkwDQYJKoZIhvcNAQELBQADggEBAD2az5Koj5AabmPO9Jko\nQmw7xLJ9LPk6gaDcEBjUHf6kLCMJYlGjYAarWFo9LhiKb1dTBgbZTnrH8wFcmv8u\nJM0y0t8czrJkqJZEnWLHsVd8O8uQQhzzXcsMn3ctyOM++Rv72QEE37PQUo71nXYY\nb37jsmY23HJG+9HtFQr+fVwicETIg0Fs0FLaC4b3s+IRgUptxTs2DiVsXcHANMEO\nxn3klzCrBAsMpyO2RdJPX8uubiYKxp53B75vv7z/RuTm/BzKvro/Ajx/oVpvhcL/\n3qVPNHOU1TApJjr/GRdrcJ9HsFx4hlsYBMwk2/pT791a92iCeDkzlUiCAUJIoC34\nMFo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://moodle.helsinki.fi/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "2",
              "location": "https://moodle.helsinki.fi/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "false"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Helsingin yliopiston Moodle-oppimisalusta."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "University of Helsinki's Moodle learning management system."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Helsingin yliopiston Moodle"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "University of Helsinki's Moodle"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "cn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacPersonalUniqueCode",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.14",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.normandie-univ.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "exploit@normandie-univ.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.normandie-univ.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-10-03T17:47:41Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.normandie-univ.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.normandie-univ.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.normandie-univ.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "normandie-univ.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.normandie-univ.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Normandie Universit\u00e9's IDP is only used by people of The Comue Normandie University and not by users members of Normandie Universit\u00e9"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "L'IDP Normandie Universit\u00e9 est utilis\u00e9 par les individus de la Comue Normandie Universit\u00e9 et non par les individus des \u00e9tablissements qui la composent."
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "12",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Normandie Universit\u00e9"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Normandie Universit\u00e9"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUfjtraZCnuk4ayIJfZ7jOPQ0/p80wDQYJKoZIhvcNAQEF\nBQAwHDEaMBgGA1UEAxMRaWRwcHAudW5yLXJ1bm4uZnIwHhcNMTMwMjIxMTQwODMw\nWhcNMzMwMjIxMTQwODMwWjAcMRowGAYDVQQDExFpZHBwcC51bnItcnVubi5mcjCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN2HpbBKeZVmYAS0cQ+9Sv6R\n0EqFnIcPr1gk3F3TSlOwKfptwg/YcC5i0sgQYeNCsVKeOclPPIS60eerF5RdiUbs\nWLKsrkHWja7virusalMVQZJA6o+A5zu3+y7BuZRi8/cEnpUjz3S5N1TarB9lYSsD\n/dxPB1bboefJbLfEQFAQc+SOobBineniffnGahR03jAoaJni9DUERtF8fSo4+s4m\n5I6MeiBV6GNfkGHamCtEdNQ/u0HjQYYv8+BB9SbYpEY4FvYq2oelE5ET01vxogQr\nZYkAcuOfZVWqNX2mH5aBZewDcaE0DTfMDd5WR9Wjvv7MRF3uTOIF1jLxks/5eIkC\nAwEAAaNpMGcwRgYDVR0RBD8wPYIRaWRwcHAudW5yLXJ1bm4uZnKGKGh0dHBzOi8v\naWRwcHAudW5yLXJ1bm4uZnIvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFP25fp7f\nnTtS3FfVhWpKfZa6X3BoMA0GCSqGSIb3DQEBBQUAA4IBAQBhqb/05bggrq/L5c1e\nLNnETROqzlxr47ECX/6vcOEov37EV2PCvIjMj1TOuEVSyy3LfOzYswy6d2fzG7Om\nNIXxg7m8CjccJ3F4H2Kp4pZDdqoI+O4oqGHLuqBAxF+B0qHlnGzL7OF6eIv3yCkR\n6uIuKyRiYpH1jAPbE1RHEzYHbB521IkdlCuoA3D41OmQzhVH48UEK+KUmqqTguEW\nyRCIhApqHi9Zy2lgW794ZMOtzPiNJ1Glj48RKGvexub/yT8ete5sk2hfDn06Z+ef\nGOF9hV4E1rvASF9pmubrSBzfuRDcwF7YEVvjUIdS0bdulO2oE+pmwowZkEEoTq9t\n7qXl"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Normandie Universit\u00e9"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.normandie-univ.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Normandie Universit\u00e9"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:umd.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dbarks@umd.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David Barks"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@umd.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Pfeifer"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@umd.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jyoti Sawhney"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@umd.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:umd.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.idm.umd.edu:8443/shibboleth-idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.idm.umd.edu:8443/shibboleth-idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDxjCCAq4CCQCYTHuI1qWbdjANBgkqhkiG9w0BAQUFADCBpDELMAkGA1UEBhMC\nVVMxETAPBgNVBAgTCE1hcnlsYW5kMRUwEwYDVQQHEwxDb2xsZWdlIFBhcmsxHzAd\nBgNVBAoTFlVuaXZlcnNpdHkgb2YgTWFyeWxhbmQxDDAKBgNVBAsTA09JVDEZMBcG\nA1UEAxMQc2hpYi5pZG0udW1kLmVkdTEhMB8GCSqGSIb3DQEJARYSc2hpYmJvbGV0\naEB1bWQuZWR1MB4XDTEwMDMwNTE0NTEyMloXDTIwMDMwMjE0NTEyMlowgaQxCzAJ\nBgNVBAYTAlVTMREwDwYDVQQIEwhNYXJ5bGFuZDEVMBMGA1UEBxMMQ29sbGVnZSBQ\nYXJrMR8wHQYDVQQKExZVbml2ZXJzaXR5IG9mIE1hcnlsYW5kMQwwCgYDVQQLEwNP\nSVQxGTAXBgNVBAMTEHNoaWIuaWRtLnVtZC5lZHUxITAfBgkqhkiG9w0BCQEWEnNo\naWJib2xldGhAdW1kLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nANM+uMY8XSu2qmJRm898y7AW1lqLDteJtzcCIsgssH66PNn24J+/RW6Z2TWbSQ4B\nOc3NwCdgBjglKq4f7dp1az8Jy1r8NIMhCy6JqwxjItpni/zTAfUlv9Dc6yshX1jN\n2swIM3ZafyGlK+xzXVz7lrlvsRLIkLetNqRcUnoY7UUjv1yXqku+EkFixdXPfyN7\nJDzVsl5urDsFQRuRypmA0geSkRpdmgCqDeZicjXVEoobbqg6xgw/0ZIIjYg1T47m\nHEs1P04VhwhPs3tP4Pg4MAwXFOq39hOwJCS6ojIKXBWN4h1VnEmc8ppq4I8T2en0\nwonw2JH8gu4Q3JmsUSPvaqMCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAzWhmDsXy\nqntYuXp0gY3dBuFgIHq+0nqo+s3yPfgi4Wj8IY0l4EXblhHHMHBWZyGA4uDo6MZs\n8yJxgjyvR0O98gzVxk2ZcNrtqYd59kBs88gH011ciJeeNmDBn/1DNrhn3xyKX8GI\nLhNGpiofYzOzHz4kYWLs/xl+0NN0yURVrE9dxunk35P07PwyNtZ68h3Qzr6g5CZ/\n9JcKwaPB71jYscdUvLGXPmKQ1ZfI1foFf3ZVbOxNI66GGlpJH1JdbneGvX6rkBmz\nILOzZbPBHBTjCBjCX+eq7CAvF3GJJD5VvXcGtZFcOEhgXSi/D6/SRSO133UoRYNT\ncorVUSTEZlJJNA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "umd.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.idm.umd.edu/shibboleth-idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.idm.umd.edu/shibboleth-idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.idm.umd.edu/shibboleth-idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.idm.umd.edu/shibboleth-idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDxjCCAq4CCQCYTHuI1qWbdjANBgkqhkiG9w0BAQUFADCBpDELMAkGA1UEBhMC\nVVMxETAPBgNVBAgTCE1hcnlsYW5kMRUwEwYDVQQHEwxDb2xsZWdlIFBhcmsxHzAd\nBgNVBAoTFlVuaXZlcnNpdHkgb2YgTWFyeWxhbmQxDDAKBgNVBAsTA09JVDEZMBcG\nA1UEAxMQc2hpYi5pZG0udW1kLmVkdTEhMB8GCSqGSIb3DQEJARYSc2hpYmJvbGV0\naEB1bWQuZWR1MB4XDTEwMDMwNTE0NTEyMloXDTIwMDMwMjE0NTEyMlowgaQxCzAJ\nBgNVBAYTAlVTMREwDwYDVQQIEwhNYXJ5bGFuZDEVMBMGA1UEBxMMQ29sbGVnZSBQ\nYXJrMR8wHQYDVQQKExZVbml2ZXJzaXR5IG9mIE1hcnlsYW5kMQwwCgYDVQQLEwNP\nSVQxGTAXBgNVBAMTEHNoaWIuaWRtLnVtZC5lZHUxITAfBgkqhkiG9w0BCQEWEnNo\naWJib2xldGhAdW1kLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nANM+uMY8XSu2qmJRm898y7AW1lqLDteJtzcCIsgssH66PNn24J+/RW6Z2TWbSQ4B\nOc3NwCdgBjglKq4f7dp1az8Jy1r8NIMhCy6JqwxjItpni/zTAfUlv9Dc6yshX1jN\n2swIM3ZafyGlK+xzXVz7lrlvsRLIkLetNqRcUnoY7UUjv1yXqku+EkFixdXPfyN7\nJDzVsl5urDsFQRuRypmA0geSkRpdmgCqDeZicjXVEoobbqg6xgw/0ZIIjYg1T47m\nHEs1P04VhwhPs3tP4Pg4MAwXFOq39hOwJCS6ojIKXBWN4h1VnEmc8ppq4I8T2en0\nwonw2JH8gu4Q3JmsUSPvaqMCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAzWhmDsXy\nqntYuXp0gY3dBuFgIHq+0nqo+s3yPfgi4Wj8IY0l4EXblhHHMHBWZyGA4uDo6MZs\n8yJxgjyvR0O98gzVxk2ZcNrtqYd59kBs88gH011ciJeeNmDBn/1DNrhn3xyKX8GI\nLhNGpiofYzOzHz4kYWLs/xl+0NN0yURVrE9dxunk35P07PwyNtZ68h3Qzr6g5CZ/\n9JcKwaPB71jYscdUvLGXPmKQ1ZfI1foFf3ZVbOxNI66GGlpJH1JdbneGvX6rkBmz\nILOzZbPBHBTjCBjCX+eq7CAvF3GJJD5VvXcGtZFcOEhgXSi/D6/SRSO133UoRYNT\ncorVUSTEZlJJNA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "umd.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.umd.edu"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Maryland College Park"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The University of Maryland, College Park is a public research university, the flagship campus of the University System of Maryland, and the original 1862 land-grant institution in the State."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.urhome.umd.edu/trademarks/marks/gr/webglobelg.gif",
                    "lang": "en",
                    "height": "115",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "115"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.nethics.umd.edu/aup/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Maryland College Park"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.umd.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Maryland College Park"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://login.nrg.eu/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://login.nrg.eu/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-09-16T08:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/341307fa6d9114669c896af91f70bb61",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Nuclear Research and Consultancy Group"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Nuclear Research and Consultancy Group"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/nrg.png",
                    "height": "87",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Nuclear Research and Consultancy Group"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Nuclear Research and Consultancy Group"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Nuclear Research and Consultancy Group"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nrg.eu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Nuclear Research and Consultancy Group"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.nwhc.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Overt Software Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Plowman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:garry.plowman@nwhc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Garry"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.nwhc.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-10-15T10:33:15Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAKUnamKmXgk/Lnzrnwf+feRMH4ddMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBkxFzAVBgNVBAMTDmlkcC5ud2hjLmFjLnVrMB4XDTEzMDgwNTEwMDExOVoX\n\t\t\t\t\t\tDTMzMDgwNTEwMDExOVowGTEXMBUGA1UEAxMOaWRwLm53aGMuYWMudWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCiXdo51PeQig41pAibbuK8eFwjkmWH\n\t\t\t\t\t\twwlJXw7EKABKtCmOpL00UEYy7qpKg8oHdX2VN9UssKX7PtFnDCMEcS1J7V5lbTCm\n\t\t\t\t\t\txOsTc26qIqoPyPY3z5qKETdv9jkl6UezHanB+kG6OOZxYNsZQVmElLsTIbxiW6gT\n\t\t\t\t\t\tcaGp6LotUxxNurn+kbX+EQas4B74IRrGtIhzG66xYFhQaBHqcsghcs4wQnxAz1hY\n\t\t\t\t\t\taLJ+dns79/BE/MLV+rOcuqKQuRWp4qBEDEbuVA8mQVhtBZmTbxrUCv81cl0tKCGZ\n\t\t\t\t\t\txlc1E3v6jAHGq6sVHJu342NRkW7FCICsKww3RqMUY90G/c1XaUfUAYsTAgMBAAGj\n\t\t\t\t\t\tYzBhMEAGA1UdEQQ5MDeCDmlkcC5ud2hjLmFjLnVrhiVodHRwczovL2lkcC5ud2hj\n\t\t\t\t\t\tLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSa5qcFRjhigspQsL6d5yEN\n\t\t\t\t\t\t3Q9YEjANBgkqhkiG9w0BAQUFAAOCAQEAhQxixhw6sfaHJtRPtYZ9hfhQSi/p0O3h\n\t\t\t\t\t\tPllwONLp9zTaUDvPyu5XQ+Oh0//hT8xAiyEDEYBp04/a1HAPFNYMr3uAaYSiXi0P\n\t\t\t\t\t\t26zIPlALtOTtF8wpdd88zX4LS567vKihExhZgnJjyLhOlisw4q6PH0FTq1ope8oN\n\t\t\t\t\t\tSyWYSxSOjXt4S2+vEJMztj7NNicN1Doa1DA5hqrqIhdP5vrcNgWdRztruJ8YBbsC\n\t\t\t\t\t\tNiuA0dJ/7ViPa01B7CdxRahAGUIc3VFLS3IA8JExlHuwyAy2YCQs7+W0ftZa1DID\n\t\t\t\t\t\tmyaovCB2VxASeOcSFk+AxnroXAhfkukp/5FM4lVI6rOAns40DaSHNw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nwhc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.nwhc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nwhc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.nwhc.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.nwhc.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nwhc.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.nwhc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.nwhc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.nwhc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.nwhc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.nwhc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nwhc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nwhc.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://www.nwhc.ac.uk/images/logo.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://www.nwhc.ac.uk/images/logo-icon.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "North Warwickshire & Hinckley College (Shibboleth)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAKUnamKmXgk/Lnzrnwf+feRMH4ddMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBkxFzAVBgNVBAMTDmlkcC5ud2hjLmFjLnVrMB4XDTEzMDgwNTEwMDExOVoX\n\t\t\t\t\t\tDTMzMDgwNTEwMDExOVowGTEXMBUGA1UEAxMOaWRwLm53aGMuYWMudWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCiXdo51PeQig41pAibbuK8eFwjkmWH\n\t\t\t\t\t\twwlJXw7EKABKtCmOpL00UEYy7qpKg8oHdX2VN9UssKX7PtFnDCMEcS1J7V5lbTCm\n\t\t\t\t\t\txOsTc26qIqoPyPY3z5qKETdv9jkl6UezHanB+kG6OOZxYNsZQVmElLsTIbxiW6gT\n\t\t\t\t\t\tcaGp6LotUxxNurn+kbX+EQas4B74IRrGtIhzG66xYFhQaBHqcsghcs4wQnxAz1hY\n\t\t\t\t\t\taLJ+dns79/BE/MLV+rOcuqKQuRWp4qBEDEbuVA8mQVhtBZmTbxrUCv81cl0tKCGZ\n\t\t\t\t\t\txlc1E3v6jAHGq6sVHJu342NRkW7FCICsKww3RqMUY90G/c1XaUfUAYsTAgMBAAGj\n\t\t\t\t\t\tYzBhMEAGA1UdEQQ5MDeCDmlkcC5ud2hjLmFjLnVrhiVodHRwczovL2lkcC5ud2hj\n\t\t\t\t\t\tLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSa5qcFRjhigspQsL6d5yEN\n\t\t\t\t\t\t3Q9YEjANBgkqhkiG9w0BAQUFAAOCAQEAhQxixhw6sfaHJtRPtYZ9hfhQSi/p0O3h\n\t\t\t\t\t\tPllwONLp9zTaUDvPyu5XQ+Oh0//hT8xAiyEDEYBp04/a1HAPFNYMr3uAaYSiXi0P\n\t\t\t\t\t\t26zIPlALtOTtF8wpdd88zX4LS567vKihExhZgnJjyLhOlisw4q6PH0FTq1ope8oN\n\t\t\t\t\t\tSyWYSxSOjXt4S2+vEJMztj7NNicN1Doa1DA5hqrqIhdP5vrcNgWdRztruJ8YBbsC\n\t\t\t\t\t\tNiuA0dJ/7ViPa01B7CdxRahAGUIc3VFLS3IA8JExlHuwyAy2YCQs7+W0ftZa1DID\n\t\t\t\t\t\tmyaovCB2VxASeOcSFk+AxnroXAhfkukp/5FM4lVI6rOAns40DaSHNw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "North Warwickshire & Hinckley College (Shibboleth)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nwhc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "North Warwickshire and Hinckley College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dev.aiwip.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Khazarchiev"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ruslan@aiwip.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ruslan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Khazarchiev"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ruslan@aiwip.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ruslan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dev.aiwip.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-09-29T11:08:20Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Aiwip (Beta)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://dev.aiwip.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Aiwip Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.aiwip.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev.aiwip.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.aiwip.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.aiwip.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.aiwip.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.aiwip.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Free printing for University students"
                  }
                ],
                "logo": [
                  {
                    "text": "https://dev.aiwip.com/static/images/logo2-dark.png",
                    "height": "135",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "90"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Aiwip (Beta)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDkjCCAnqgAwIBAgIJAMhB5Bq2iyR4MA0GCSqGSIb3DQEBCwUAMEoxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMQ8wDQYDVQQIDAZMb25kb24xEjAQBgNVBAoMCUFpd2lwIEx0ZDEWMBQG\n\t\t\t\t\t\tA1UEAwwNZGV2LmFpd2lwLmNvbTAeFw0xNTA5MTExNTE0MDJaFw0yNTA5MDgxNTE0\n\t\t\t\t\t\tMDJaMEoxCzAJBgNVBAYTAkdCMQ8wDQYDVQQIDAZMb25kb24xEjAQBgNVBAoMCUFp\n\t\t\t\t\t\td2lwIEx0ZDEWMBQGA1UEAwwNZGV2LmFpd2lwLmNvbTCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBAKeYBNoVDBp6PLICKD/TpMavGRrNFBkgOg2DTwGtEx81\n\t\t\t\t\t\tKGEzTiaZVHZGZSL1kYJCoNIVeZ9vWgn4HPbiLH7A5sWJ56vKUFV4w/Nik7Ldourm\n\t\t\t\t\t\tr1NRR2/5v3ZqpypZBlA9zCtnqXQ+b9g/JkmnAvcTv08LCIh/0fMt28KVDPydG06K\n\t\t\t\t\t\tbFMDHYLDmIvL7m3mkJNM9oVBLeDUmxZD/edcxOz8mOea7fxE9wcHRrBIP2JROoIZ\n\t\t\t\t\t\tsId6gR8Wd9SPP5L8QtmrDdYhdg60CShag7VmCdiWYUsiK+8WGPTsNgg/HWnm16Qu\n\t\t\t\t\t\t7VmftSOXYtzzOqjwbneHOZY61S6MTa5v3+LgGJ3KIikCAwEAAaN7MHkwCQYDVR0T\n\t\t\t\t\t\tBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNh\n\t\t\t\t\t\tdGUwHQYDVR0OBBYEFPRW8eJscxxfYpnPjyKNcS8EpzbZMB8GA1UdIwQYMBaAFPRW\n\t\t\t\t\t\t8eJscxxfYpnPjyKNcS8EpzbZMA0GCSqGSIb3DQEBCwUAA4IBAQAyGtVy8SQjIDzn\n\t\t\t\t\t\tzMcfUb7lVNQPrllcqZe/3Rw3LNE6ZK4/pa7h0pf3Nxshe9l7/1V3ltwmW7tNfIxI\n\t\t\t\t\t\tOBay2iKDqNvXiIzSESOuvtuUhx+QOk54VnDZNyZTIxG/oNGodsEb+DlCawzWEVou\n\t\t\t\t\t\tNIiLvKtWqOCmH3lSVbwoNafgEtR0kLXiIF8kc39SmoZkQbuXv/vn1HuaZGx/qyzq\n\t\t\t\t\t\tevUZK4V2B1H8xkcj+PuVjnq7yo59Z2hxBCrzdmtS4Ctuxr49OP5mjRobc+XAvtZG\n\t\t\t\t\t\tDfqRJcZIQ0IF5Fm5VTiWawxRo9AKLCLgeGnE9qoFUzkrdGRvWvPSbN09FPw64gAk\n\t\t\t\t\t\tZGK4Vav2"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.aiwip.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dev.aiwip.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.aiwip.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dev.aiwip.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dev.aiwip.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dev.aiwip.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cafe.uesc.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "UDO/COI"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "coi@uesc.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.uesc.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqYCAQAwDQYJKoZIhvcNAQEFBQAwgaQxMzAxBgNVBAoTKlVFU0MgLSBV\nTklWRVJTSURBREUgRVNUQURVQUwgREUgU0FOVEEgQ1JVWjEMMAoGA1UECxMDQ09J\nMRowGAYJKoZIhvcNAQkBFgtDT0lAVUVTQy5CUjEPMA0GA1UEBxMGSUxIRVVTMQ4w\nDAYDVQQIEwVCQUhJQTELMAkGA1UEBhMCQlIxFTATBgNVBAMTDGNhZmUudWVzYy5i\ncjAeFw0xNDA0MTAxMjAyMzRaFw0xOTA0MDkxMjAyMzRaMIGkMTMwMQYDVQQKEypV\nRVNDIC0gVU5JVkVSU0lEQURFIEVTVEFEVUFMIERFIFNBTlRBIENSVVoxDDAKBgNV\nBAsTA0NPSTEaMBgGCSqGSIb3DQEJARYLQ09JQFVFU0MuQlIxDzANBgNVBAcTBklM\nSEVVUzEOMAwGA1UECBMFQkFISUExCzAJBgNVBAYTAkJSMRUwEwYDVQQDEwxjYWZl\nLnVlc2MuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC72oVZgtPa\nvTAXBK6xUApNT4lZl9nN7GnX9MELpR6d9Nd9Hdh2HiK82IFucx1Ma6o48gp2IMoM\nCeMvP9gE+nNh8dTsV949z/EkesXTLqfSx8ZyZkAbULVeBkfjvZ8B4Tc8kFG0FVka\n3niIPQZNV+ojIWUkpCvFE8F5f1Fg/AuGPT7ClVTd/wmJnaCzVeBOv1igIcPIcyUB\nFcJ8pLOhFCP+YOrhen+XEO0B7kMVAfkwFzic7odExmiknQ311Sdt/QaPMF2EWZ7r\nQcBRayAbIx13GYbKiVNZDHv2jSbfrqjbrACLxP17IHtKTjAHTq9zUbtTiaGcwwL8\nF6hxMk3iZrsfAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBACAUW1b9UNotRq7BlSiy\nC4ATLQ4qidg/8vCZu1AqreLXU71C3SHnOFl+C+JhorczJyo4lLVJmoIZRvjmedZT\nRNpeSsT4NBPxFpfhjk+e5RbrQJFa2qw4AansX/ErUhvRDaI9yy5gE1YdiOeK58Pc\nYr8RJQdsCybLWTCSlVWJbRzvv05uUlJNnNSuxvYBeY727sDomtaj6WsPy99HPEY+\nr5nqp5LUU4AWUhpm8faNRFZia439GTSibCoICMRy4WBe1HvAi2ljKA4uRXKgJQsq\nVv4jw5WtdCEE2lDlRADuHz5lbijCzXEikhEBFAcDWGmdFTtXMvcAUqaCTVUkQDUE\n9N8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uesc.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.uesc.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.uesc.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.uesc.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.uesc.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.uesc.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.uesc.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.uesc.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.uesc.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uesc.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uesc.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uesc.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UESC - Universidade Estadual de Santa Cruz"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UESC - Universidade Estadual de Santa Cruz"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UESC - Universidade Estadual de Santa Cruz"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UESC - Universidade Estadual de Santa Cruz"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqYCAQAwDQYJKoZIhvcNAQEFBQAwgaQxMzAxBgNVBAoTKlVFU0MgLSBV\nTklWRVJTSURBREUgRVNUQURVQUwgREUgU0FOVEEgQ1JVWjEMMAoGA1UECxMDQ09J\nMRowGAYJKoZIhvcNAQkBFgtDT0lAVUVTQy5CUjEPMA0GA1UEBxMGSUxIRVVTMQ4w\nDAYDVQQIEwVCQUhJQTELMAkGA1UEBhMCQlIxFTATBgNVBAMTDGNhZmUudWVzYy5i\ncjAeFw0xNDA0MTAxMjAyMzRaFw0xOTA0MDkxMjAyMzRaMIGkMTMwMQYDVQQKEypV\nRVNDIC0gVU5JVkVSU0lEQURFIEVTVEFEVUFMIERFIFNBTlRBIENSVVoxDDAKBgNV\nBAsTA0NPSTEaMBgGCSqGSIb3DQEJARYLQ09JQFVFU0MuQlIxDzANBgNVBAcTBklM\nSEVVUzEOMAwGA1UECBMFQkFISUExCzAJBgNVBAYTAkJSMRUwEwYDVQQDEwxjYWZl\nLnVlc2MuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC72oVZgtPa\nvTAXBK6xUApNT4lZl9nN7GnX9MELpR6d9Nd9Hdh2HiK82IFucx1Ma6o48gp2IMoM\nCeMvP9gE+nNh8dTsV949z/EkesXTLqfSx8ZyZkAbULVeBkfjvZ8B4Tc8kFG0FVka\n3niIPQZNV+ojIWUkpCvFE8F5f1Fg/AuGPT7ClVTd/wmJnaCzVeBOv1igIcPIcyUB\nFcJ8pLOhFCP+YOrhen+XEO0B7kMVAfkwFzic7odExmiknQ311Sdt/QaPMF2EWZ7r\nQcBRayAbIx13GYbKiVNZDHv2jSbfrqjbrACLxP17IHtKTjAHTq9zUbtTiaGcwwL8\nF6hxMk3iZrsfAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBACAUW1b9UNotRq7BlSiy\nC4ATLQ4qidg/8vCZu1AqreLXU71C3SHnOFl+C+JhorczJyo4lLVJmoIZRvjmedZT\nRNpeSsT4NBPxFpfhjk+e5RbrQJFa2qw4AansX/ErUhvRDaI9yy5gE1YdiOeK58Pc\nYr8RJQdsCybLWTCSlVWJbRzvv05uUlJNnNSuxvYBeY727sDomtaj6WsPy99HPEY+\nr5nqp5LUU4AWUhpm8faNRFZia439GTSibCoICMRy4WBe1HvAi2ljKA4uRXKgJQsq\nVv4jw5WtdCEE2lDlRADuHz5lbijCzXEikhEBFAcDWGmdFTtXMvcAUqaCTVUkQDUE\n9N8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UESC - Universidade Estadual de Santa Cruz"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UESC - Universidade Estadual de Santa Cruz"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uesc.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uesc.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UESC - Universidade Estadual de Santa Cruz"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UESC - Universidade Estadual de Santa Cruz"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.lrz.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ebner"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth@lrz.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ralf"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ebner"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth@lrz.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ralf"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ebner"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth@lrz.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ralf"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.lrz.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2009-05-27T12:36:25Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "lrzidp.lrz.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGTzCCBTegAwIBAgIHGEI+4YLsVDANBgkqhkiG9w0BAQsFADCBnTELMAkGA1UE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\nRXNKbj96BedS8e05bbrOSj9H7/qX5osIxDaY+rr6g3HF+2c="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=lrzidp.lrz.de,OU=Leibniz-Rechenzentrum,O=Bayerische Akademie der Wissenschaften,L=Garching b. Muenchen,ST=Bayern,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "lrzidp.lrz.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGTzCCBTegAwIBAgIHGEI+4YLsVDANBgkqhkiG9w0BAQsFADCBnTELMAkGA1UE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\nRXNKbj96BedS8e05bbrOSj9H7/qX5osIxDaY+rr6g3HF+2c="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=lrzidp.lrz.de,OU=Leibniz-Rechenzentrum,O=Bayerische Akademie der Wissenschaften,L=Garching b. Muenchen,ST=Bayern,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lrz.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.lrz.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.lrz.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.lrz.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.lrz.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.lrz.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.lrz.de/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.lrz.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.lrz.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lrz.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.lrz.de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.lrz.de"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Der LRZ Identity Provider bedient Benutzer und Mitarbeiter des Leibniz-Rechenzentrums, insb. auch Supercomputing-Kunden"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The LRZ Identity Provider is used by staff members and users of Leibniz Supercomputing Centre, especially users of supercomputing systems."
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.lrz.de/idp/images/lrzlogo.png",
                    "height": "70",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "360"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Leibniz-Rechenzentrum (LRZ)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Leibniz Supercomputing Centre (LRZ)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "lrzidp.lrz.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGTzCCBTegAwIBAgIHGEI+4YLsVDANBgkqhkiG9w0BAQsFADCBnTELMAkGA1UE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\nRXNKbj96BedS8e05bbrOSj9H7/qX5osIxDaY+rr6g3HF+2c="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=lrzidp.lrz.de,OU=Leibniz-Rechenzentrum,O=Bayerische Akademie der Wissenschaften,L=Garching b. Muenchen,ST=Bayern,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "lrzidp.lrz.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGTzCCBTegAwIBAgIHGEI+4YLsVDANBgkqhkiG9w0BAQsFADCBnTELMAkGA1UE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\nRXNKbj96BedS8e05bbrOSj9H7/qX5osIxDaY+rr6g3HF+2c="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=lrzidp.lrz.de,OU=Leibniz-Rechenzentrum,O=Bayerische Akademie der Wissenschaften,L=Garching b. Muenchen,ST=Bayern,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Leibniz-Rechenzentrum der Bayerischen Akademie der Wissenschaften"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Leibniz Supercomputing Centre (LRZ) of the Bavarian Academy of Sciences and Humanities"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lrz.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lrz.de/english/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e38"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e38"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.dfn-cert.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Karlsen-Masur"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dfnpca@dfn-cert.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Reimer"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Karlsen-Masur"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dfnpca@dfn-cert.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Reimer"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.dfn-cert.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2009-05-26T08:35:12Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.dfn-cert.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFszCCBJugAwIBAgIHF2OR7ehZwzANBgkqhkiG9w0BAQsFADBYMQswCQYDVQQG\nEwJERTEfMB0GA1UEChMWREZOLUNFUlQgU2VydmljZXMgR21iSDEoMCYGA1UEAxMf\nREZOLUNFUlQgU2VydmljZXMgR21iSCBDQSAtIEcwMjAeFw0xNDA0MDgxNTIzMTBa\nFw0xOTAyMTMwMDAwMDBaMGwxCzAJBgNVBAYTAkRFMRAwDgYDVQQIEwdIYW1idXJn\nMRAwDgYDVQQHEwdIYW1idXJnMR8wHQYDVQQKExZERk4tQ0VSVCBTZXJ2aWNlcyBH\nbWJIMRgwFgYDVQQDEw9pZHAuZGZuLWNlcnQuZGUwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDGmE9dz1W6j62JiorQhJWhp5tVKpvt2YR3RbS4UWUQljBk\nOab9wFq8zsGgL94aZRWllmixsOJStEdi+TvyPhG6FOmR/ETXvvfPbho3FCZ/Sfip\nlbQnnqETSZfVW0UoP8Tr46zY+hZYMEoxfmH8rj72rSmCIrOLjgdIf5UZ0KNwLMvd\nywd0qXAjWOWDBWEVX/Ob4C5w+w2wWX6doHHSBWSifyCCyDgmacRWAnclNDj6LC5e\nJPQTBqJNf1CMqxduQELCPjOvJP7Sovf/BttiO4Jcp247dRdIWwef8/zSsRtWf6Ap\n61iNGsrCJBShu5ebfeFBhcpHljyCacj2KajrmpiTAgMBAAGjggJsMIICaDA5BgNV\nHSAEMjAwMBEGDysGAQQBga0hgiwBAQQDATARBg8rBgEEAYGtIYIsAgEEAwEwCAYG\nZ4EMAQICMAkGA1UdEwQCMAAwCwYDVR0PBAQDAgXgMB0GA1UdJQQWMBQGCCsGAQUF\nBwMCBggrBgEFBQcDATAdBgNVHQ4EFgQUmRPhL/ARwEPGWe/29pCd6OFlW8UwHwYD\nVR0jBBgwFoAUxovP+kT8OmpLaKvo5784I+W6CpYwGgYDVR0RBBMwEYIPaWRwLmRm\nbi1jZXJ0LmRlMIGjBgNVHR8EgZswgZgwSqBIoEaGRGh0dHA6Ly9jZHAxLnBjYS5k\nZm4uZGUvZGZuLWNlcnQtc2VydmljZXMtZ21iaC1jYS9wdWIvY3JsL2dfY2Fjcmwu\nY3JsMEqgSKBGhkRodHRwOi8vY2RwMi5wY2EuZGZuLmRlL2Rmbi1jZXJ0LXNlcnZp\nY2VzLWdtYmgtY2EvcHViL2NybC9nX2NhY3JsLmNybDCB8QYIKwYBBQUHAQEEgeQw\ngeEwMwYIKwYBBQUHMAGGJ2h0dHA6Ly9vY3NwLnBjYS5kZm4uZGUvT0NTUC1TZXJ2\nZXIvT0NTUDBUBggrBgEFBQcwAoZIaHR0cDovL2NkcDEucGNhLmRmbi5kZS9kZm4t\nY2VydC1zZXJ2aWNlcy1nbWJoLWNhL3B1Yi9jYWNlcnQvZ19jYWNlcnQuY3J0MFQG\nCCsGAQUFBzAChkhodHRwOi8vY2RwMi5wY2EuZGZuLmRlL2Rmbi1jZXJ0LXNlcnZp\nY2VzLWdtYmgtY2EvcHViL2NhY2VydC9nX2NhY2VydC5jcnQwDQYJKoZIhvcNAQEL\nBQADggEBAJwW/bCz/aJ0t1CU9CC52mjFS3hVzMkPCmToRpYuQDuITRjakMphjlVw\nD2b/utqr6RBB0x2ocQrUznqj4qIlT4AINihxn4sH5ATYGAqAfQ0dZ6IO4bDDHc6P\ndip93yux2f31NAcQCuew9kFdZOU76p/t15FaIFTJIFLKR7yQegFV5tI4IPTT9aLK\nTyC6KMj0jBoQs13PFTaQdc5/aFAq7qZfU73T09v/vMvXYToQjyrAZPoxHZv1P0GR\npiCOUUEOz3aTwZx19BPTfUlejSY4OBi3sYJy7rEORlEpWXwkHw6FAC4ePvquxva5\nPNajQeL3bxnnkz4YuncP/ay7SKMycRo="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.dfn-cert.de,O=DFN-CERT Services GmbH,L=Hamburg,ST=Hamburg,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.dfn-cert.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFszCCBJugAwIBAgIHF2OR7ehZwzANBgkqhkiG9w0BAQsFADBYMQswCQYDVQQG\nEwJERTEfMB0GA1UEChMWREZOLUNFUlQgU2VydmljZXMgR21iSDEoMCYGA1UEAxMf\nREZOLUNFUlQgU2VydmljZXMgR21iSCBDQSAtIEcwMjAeFw0xNDA0MDgxNTIzMTBa\nFw0xOTAyMTMwMDAwMDBaMGwxCzAJBgNVBAYTAkRFMRAwDgYDVQQIEwdIYW1idXJn\nMRAwDgYDVQQHEwdIYW1idXJnMR8wHQYDVQQKExZERk4tQ0VSVCBTZXJ2aWNlcyBH\nbWJIMRgwFgYDVQQDEw9pZHAuZGZuLWNlcnQuZGUwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDGmE9dz1W6j62JiorQhJWhp5tVKpvt2YR3RbS4UWUQljBk\nOab9wFq8zsGgL94aZRWllmixsOJStEdi+TvyPhG6FOmR/ETXvvfPbho3FCZ/Sfip\nlbQnnqETSZfVW0UoP8Tr46zY+hZYMEoxfmH8rj72rSmCIrOLjgdIf5UZ0KNwLMvd\nywd0qXAjWOWDBWEVX/Ob4C5w+w2wWX6doHHSBWSifyCCyDgmacRWAnclNDj6LC5e\nJPQTBqJNf1CMqxduQELCPjOvJP7Sovf/BttiO4Jcp247dRdIWwef8/zSsRtWf6Ap\n61iNGsrCJBShu5ebfeFBhcpHljyCacj2KajrmpiTAgMBAAGjggJsMIICaDA5BgNV\nHSAEMjAwMBEGDysGAQQBga0hgiwBAQQDATARBg8rBgEEAYGtIYIsAgEEAwEwCAYG\nZ4EMAQICMAkGA1UdEwQCMAAwCwYDVR0PBAQDAgXgMB0GA1UdJQQWMBQGCCsGAQUF\nBwMCBggrBgEFBQcDATAdBgNVHQ4EFgQUmRPhL/ARwEPGWe/29pCd6OFlW8UwHwYD\nVR0jBBgwFoAUxovP+kT8OmpLaKvo5784I+W6CpYwGgYDVR0RBBMwEYIPaWRwLmRm\nbi1jZXJ0LmRlMIGjBgNVHR8EgZswgZgwSqBIoEaGRGh0dHA6Ly9jZHAxLnBjYS5k\nZm4uZGUvZGZuLWNlcnQtc2VydmljZXMtZ21iaC1jYS9wdWIvY3JsL2dfY2Fjcmwu\nY3JsMEqgSKBGhkRodHRwOi8vY2RwMi5wY2EuZGZuLmRlL2Rmbi1jZXJ0LXNlcnZp\nY2VzLWdtYmgtY2EvcHViL2NybC9nX2NhY3JsLmNybDCB8QYIKwYBBQUHAQEEgeQw\ngeEwMwYIKwYBBQUHMAGGJ2h0dHA6Ly9vY3NwLnBjYS5kZm4uZGUvT0NTUC1TZXJ2\nZXIvT0NTUDBUBggrBgEFBQcwAoZIaHR0cDovL2NkcDEucGNhLmRmbi5kZS9kZm4t\nY2VydC1zZXJ2aWNlcy1nbWJoLWNhL3B1Yi9jYWNlcnQvZ19jYWNlcnQuY3J0MFQG\nCCsGAQUFBzAChkhodHRwOi8vY2RwMi5wY2EuZGZuLmRlL2Rmbi1jZXJ0LXNlcnZp\nY2VzLWdtYmgtY2EvcHViL2NhY2VydC9nX2NhY2VydC5jcnQwDQYJKoZIhvcNAQEL\nBQADggEBAJwW/bCz/aJ0t1CU9CC52mjFS3hVzMkPCmToRpYuQDuITRjakMphjlVw\nD2b/utqr6RBB0x2ocQrUznqj4qIlT4AINihxn4sH5ATYGAqAfQ0dZ6IO4bDDHc6P\ndip93yux2f31NAcQCuew9kFdZOU76p/t15FaIFTJIFLKR7yQegFV5tI4IPTT9aLK\nTyC6KMj0jBoQs13PFTaQdc5/aFAq7qZfU73T09v/vMvXYToQjyrAZPoxHZv1P0GR\npiCOUUEOz3aTwZx19BPTfUlejSY4OBi3sYJy7rEORlEpWXwkHw6FAC4ePvquxva5\nPNajQeL3bxnnkz4YuncP/ay7SKMycRo="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.dfn-cert.de,O=DFN-CERT Services GmbH,L=Hamburg,ST=Hamburg,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dfn-cert.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.dfn-cert.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.dfn-cert.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.dfn-cert.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.dfn-cert.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.dfn-cert.de/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.dfn-cert.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.dfn-cert.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.dfn-cert.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dfn-cert.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.dfn-cert.de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.dfn-cert.de"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity-Provider der DFN-CERT Services GmbH"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity-Provider der DFN-CERT Services GmbH"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DFN-CERT Services GmbH"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DFN-CERT Services GmbH"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.dfn-cert.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFszCCBJugAwIBAgIHF2OR7ehZwzANBgkqhkiG9w0BAQsFADBYMQswCQYDVQQG\nEwJERTEfMB0GA1UEChMWREZOLUNFUlQgU2VydmljZXMgR21iSDEoMCYGA1UEAxMf\nREZOLUNFUlQgU2VydmljZXMgR21iSCBDQSAtIEcwMjAeFw0xNDA0MDgxNTIzMTBa\nFw0xOTAyMTMwMDAwMDBaMGwxCzAJBgNVBAYTAkRFMRAwDgYDVQQIEwdIYW1idXJn\nMRAwDgYDVQQHEwdIYW1idXJnMR8wHQYDVQQKExZERk4tQ0VSVCBTZXJ2aWNlcyBH\nbWJIMRgwFgYDVQQDEw9pZHAuZGZuLWNlcnQuZGUwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDGmE9dz1W6j62JiorQhJWhp5tVKpvt2YR3RbS4UWUQljBk\nOab9wFq8zsGgL94aZRWllmixsOJStEdi+TvyPhG6FOmR/ETXvvfPbho3FCZ/Sfip\nlbQnnqETSZfVW0UoP8Tr46zY+hZYMEoxfmH8rj72rSmCIrOLjgdIf5UZ0KNwLMvd\nywd0qXAjWOWDBWEVX/Ob4C5w+w2wWX6doHHSBWSifyCCyDgmacRWAnclNDj6LC5e\nJPQTBqJNf1CMqxduQELCPjOvJP7Sovf/BttiO4Jcp247dRdIWwef8/zSsRtWf6Ap\n61iNGsrCJBShu5ebfeFBhcpHljyCacj2KajrmpiTAgMBAAGjggJsMIICaDA5BgNV\nHSAEMjAwMBEGDysGAQQBga0hgiwBAQQDATARBg8rBgEEAYGtIYIsAgEEAwEwCAYG\nZ4EMAQICMAkGA1UdEwQCMAAwCwYDVR0PBAQDAgXgMB0GA1UdJQQWMBQGCCsGAQUF\nBwMCBggrBgEFBQcDATAdBgNVHQ4EFgQUmRPhL/ARwEPGWe/29pCd6OFlW8UwHwYD\nVR0jBBgwFoAUxovP+kT8OmpLaKvo5784I+W6CpYwGgYDVR0RBBMwEYIPaWRwLmRm\nbi1jZXJ0LmRlMIGjBgNVHR8EgZswgZgwSqBIoEaGRGh0dHA6Ly9jZHAxLnBjYS5k\nZm4uZGUvZGZuLWNlcnQtc2VydmljZXMtZ21iaC1jYS9wdWIvY3JsL2dfY2Fjcmwu\nY3JsMEqgSKBGhkRodHRwOi8vY2RwMi5wY2EuZGZuLmRlL2Rmbi1jZXJ0LXNlcnZp\nY2VzLWdtYmgtY2EvcHViL2NybC9nX2NhY3JsLmNybDCB8QYIKwYBBQUHAQEEgeQw\ngeEwMwYIKwYBBQUHMAGGJ2h0dHA6Ly9vY3NwLnBjYS5kZm4uZGUvT0NTUC1TZXJ2\nZXIvT0NTUDBUBggrBgEFBQcwAoZIaHR0cDovL2NkcDEucGNhLmRmbi5kZS9kZm4t\nY2VydC1zZXJ2aWNlcy1nbWJoLWNhL3B1Yi9jYWNlcnQvZ19jYWNlcnQuY3J0MFQG\nCCsGAQUFBzAChkhodHRwOi8vY2RwMi5wY2EuZGZuLmRlL2Rmbi1jZXJ0LXNlcnZp\nY2VzLWdtYmgtY2EvcHViL2NhY2VydC9nX2NhY2VydC5jcnQwDQYJKoZIhvcNAQEL\nBQADggEBAJwW/bCz/aJ0t1CU9CC52mjFS3hVzMkPCmToRpYuQDuITRjakMphjlVw\nD2b/utqr6RBB0x2ocQrUznqj4qIlT4AINihxn4sH5ATYGAqAfQ0dZ6IO4bDDHc6P\ndip93yux2f31NAcQCuew9kFdZOU76p/t15FaIFTJIFLKR7yQegFV5tI4IPTT9aLK\nTyC6KMj0jBoQs13PFTaQdc5/aFAq7qZfU73T09v/vMvXYToQjyrAZPoxHZv1P0GR\npiCOUUEOz3aTwZx19BPTfUlejSY4OBi3sYJy7rEORlEpWXwkHw6FAC4ePvquxva5\nPNajQeL3bxnnkz4YuncP/ay7SKMycRo="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.dfn-cert.de,O=DFN-CERT Services GmbH,L=Hamburg,ST=Hamburg,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.dfn-cert.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFszCCBJugAwIBAgIHF2OR7ehZwzANBgkqhkiG9w0BAQsFADBYMQswCQYDVQQG\nEwJERTEfMB0GA1UEChMWREZOLUNFUlQgU2VydmljZXMgR21iSDEoMCYGA1UEAxMf\nREZOLUNFUlQgU2VydmljZXMgR21iSCBDQSAtIEcwMjAeFw0xNDA0MDgxNTIzMTBa\nFw0xOTAyMTMwMDAwMDBaMGwxCzAJBgNVBAYTAkRFMRAwDgYDVQQIEwdIYW1idXJn\nMRAwDgYDVQQHEwdIYW1idXJnMR8wHQYDVQQKExZERk4tQ0VSVCBTZXJ2aWNlcyBH\nbWJIMRgwFgYDVQQDEw9pZHAuZGZuLWNlcnQuZGUwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDGmE9dz1W6j62JiorQhJWhp5tVKpvt2YR3RbS4UWUQljBk\nOab9wFq8zsGgL94aZRWllmixsOJStEdi+TvyPhG6FOmR/ETXvvfPbho3FCZ/Sfip\nlbQnnqETSZfVW0UoP8Tr46zY+hZYMEoxfmH8rj72rSmCIrOLjgdIf5UZ0KNwLMvd\nywd0qXAjWOWDBWEVX/Ob4C5w+w2wWX6doHHSBWSifyCCyDgmacRWAnclNDj6LC5e\nJPQTBqJNf1CMqxduQELCPjOvJP7Sovf/BttiO4Jcp247dRdIWwef8/zSsRtWf6Ap\n61iNGsrCJBShu5ebfeFBhcpHljyCacj2KajrmpiTAgMBAAGjggJsMIICaDA5BgNV\nHSAEMjAwMBEGDysGAQQBga0hgiwBAQQDATARBg8rBgEEAYGtIYIsAgEEAwEwCAYG\nZ4EMAQICMAkGA1UdEwQCMAAwCwYDVR0PBAQDAgXgMB0GA1UdJQQWMBQGCCsGAQUF\nBwMCBggrBgEFBQcDATAdBgNVHQ4EFgQUmRPhL/ARwEPGWe/29pCd6OFlW8UwHwYD\nVR0jBBgwFoAUxovP+kT8OmpLaKvo5784I+W6CpYwGgYDVR0RBBMwEYIPaWRwLmRm\nbi1jZXJ0LmRlMIGjBgNVHR8EgZswgZgwSqBIoEaGRGh0dHA6Ly9jZHAxLnBjYS5k\nZm4uZGUvZGZuLWNlcnQtc2VydmljZXMtZ21iaC1jYS9wdWIvY3JsL2dfY2Fjcmwu\nY3JsMEqgSKBGhkRodHRwOi8vY2RwMi5wY2EuZGZuLmRlL2Rmbi1jZXJ0LXNlcnZp\nY2VzLWdtYmgtY2EvcHViL2NybC9nX2NhY3JsLmNybDCB8QYIKwYBBQUHAQEEgeQw\ngeEwMwYIKwYBBQUHMAGGJ2h0dHA6Ly9vY3NwLnBjYS5kZm4uZGUvT0NTUC1TZXJ2\nZXIvT0NTUDBUBggrBgEFBQcwAoZIaHR0cDovL2NkcDEucGNhLmRmbi5kZS9kZm4t\nY2VydC1zZXJ2aWNlcy1nbWJoLWNhL3B1Yi9jYWNlcnQvZ19jYWNlcnQuY3J0MFQG\nCCsGAQUFBzAChkhodHRwOi8vY2RwMi5wY2EuZGZuLmRlL2Rmbi1jZXJ0LXNlcnZp\nY2VzLWdtYmgtY2EvcHViL2NhY2VydC9nX2NhY2VydC5jcnQwDQYJKoZIhvcNAQEL\nBQADggEBAJwW/bCz/aJ0t1CU9CC52mjFS3hVzMkPCmToRpYuQDuITRjakMphjlVw\nD2b/utqr6RBB0x2ocQrUznqj4qIlT4AINihxn4sH5ATYGAqAfQ0dZ6IO4bDDHc6P\ndip93yux2f31NAcQCuew9kFdZOU76p/t15FaIFTJIFLKR7yQegFV5tI4IPTT9aLK\nTyC6KMj0jBoQs13PFTaQdc5/aFAq7qZfU73T09v/vMvXYToQjyrAZPoxHZv1P0GR\npiCOUUEOz3aTwZx19BPTfUlejSY4OBi3sYJy7rEORlEpWXwkHw6FAC4ePvquxva5\nPNajQeL3bxnnkz4YuncP/ay7SKMycRo="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.dfn-cert.de,O=DFN-CERT Services GmbH,L=Hamburg,ST=Hamburg,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "DFN-CERT Services GmbH"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "DFN-CERT Services GmbH"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dfn-cert.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dfn-cert.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e16"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e16"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://thinkit.oneteamlogic.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bennett"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nick.bennett@logicsoftware.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nick"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tucker"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ian.tucker@logicsoftware.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://thinkit.oneteamlogic.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-11-14T10:50:02Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MyConcern ThinkIt Demo Site"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oneteamlogic.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "One Team Logic Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://thinkit.oneteamlogic.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://thinkit.oneteamlogic.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://thinkit.oneteamlogic.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://thinkit.oneteamlogic.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://thinkit.oneteamlogic.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://thinkit.oneteamlogic.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The MyConcern ThinkIt Demo Site is used for demonstrations"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "MyConcern ThinkIt Demo Site"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIJAMwlTWVQn6vNMA0GCSqGSIb3DQEBBQUAMCoxKDAmBgNV\n\t\t\t\t\t\tBAMTH21jczAxLmRlbW9hZC5vbmV0ZWFtbG9naWMuY28udWswHhcNMTQxMTEyMTUz\n\t\t\t\t\t\tMDUwWhcNMjQxMTA5MTUzMDUwWjAqMSgwJgYDVQQDEx9tY3MwMS5kZW1vYWQub25l\n\t\t\t\t\t\tdGVhbWxvZ2ljLmNvLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tr1P9vVNqzEtb9Adrua0kwQ/eI++2FtfJPvxdUx7VZ/AihxkJ8bFdR4SCmPcCm2l6\n\t\t\t\t\t\tNIuX5RzpFW84p77G9tmpVqKHRDIgm3+zFHuJu+4HIYpNGrtSHr0URRdzLzkqgsYz\n\t\t\t\t\t\t2N1zkYdH20kMonR8H7DU9iJ+fuqiEmiUTuLjyFYJkDG5KvWseSK7ddrbOFRfj1+g\n\t\t\t\t\t\txFHg3G9dHSHXggaKXMJFS1jpZU0rRf1WLmRDxIwyAHjGCM6Jc1eHP6P+iXQaqNtn\n\t\t\t\t\t\tNCF7LSOOQ0pHLMxaGmEHFsA/gCqtQLsQ3Tz/FI/aD+gDqH7uddQZc7MwWYyVwk86\n\t\t\t\t\t\t45OYCIefIeg+cV33XFpNuQIDAQABo00wSzAqBgNVHREEIzAhgh9tY3MwMS5kZW1v\n\t\t\t\t\t\tYWQub25ldGVhbWxvZ2ljLmNvLnVrMB0GA1UdDgQWBBRxX7MmM9QRHXRlA9tBztn1\n\t\t\t\t\t\tFprx4jANBgkqhkiG9w0BAQUFAAOCAQEAM68P0rnO7aXyvV8X5AKMtHJqpat4equg\n\t\t\t\t\t\teseVbcQi3PbVPh5eJgZa8fUK4LU8qFSHbz78TmvVaTD2gOfNA9LfY+TMQMK+y16t\n\t\t\t\t\t\tBz694/fpbNY6ztfD/+Hsexk2X0zn9nXnf2qNQIbLIzau5u+oEYGgzxQkxaC2VeI0\n\t\t\t\t\t\tqy55H4npVR38eppq7qWkGZrlEGM8MnBrRNGqIBrHb4luiGcGwsB5K1G89SSdYJkG\n\t\t\t\t\t\tgmKz4CPKwjUCQW4MdGQoj8YWCj9Bs8brseOcDP8JGeYZau1VeiUR7ZPR/nOZFKc/\n\t\t\t\t\t\t+wLoAUq6JcuHgpkOdZm8cimD8N5DZAbauTyOqJB9pI7GYiWazj5GkA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://thinkit.oneteamlogic.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://thinkit.oneteamlogic.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://thinkit.oneteamlogic.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://thinkit.oneteamlogic.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://thinkit.oneteamlogic.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://thinkit.oneteamlogic.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.rediris.es/sir/bscidp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sir@rediris.es"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SIR helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.rediris.es/sir/bscidp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.rediris.es/sir/edugain/SIR_MRPS.pdf"
              }
            ],
            "registration_instant": "2012-10-09T13:08:24Z",
            "registration_authority": "http://www.rediris.es/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "response_location": "http://sir.rediris.es/bsc/saml2/idp/SingleLogoutService.php",
              "location": "http://sir.rediris.es/bsc/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "http://sir.rediris.es/bsc/shib13/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "http://sir.rediris.es/bsc/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Identity Provider of Barcelona Supercomputing Center"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "BSC - Barcelona Supercomputing Center"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bsc.es"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEeTCCA2GgAwIBAgIQCP9faAGj247/+QVzgpX08zANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDcwMTAwMDAwMFoXDTE2MDYzMDIzNTk1OVowRDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMR8wHQYDVQQDExZzYW1saWRwLnNp\nci5yZWRpcmlzLmVzMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA5tO6\ntYAdozpFMDwS7QH1qm7eECkY05lG1sp14vcVOdyN0mAf8oai+M8dCQ5iyMxD/RaG\noSmhXfHUvJ+0x8Cp/NHYbKr0cXskANcYTI0JFMFypn9Uac62CGxUYZRhHQ/2LxiE\nvzNgKrm2JiXCvOQbWrbg0sZDEsONv2G1Ln3fvOLiSiO1AjWLvOeYFPNgkNy5dxxt\n7ms7mZ0bFth6Cj38BBL0I1RebVnMgAKZWSgICUXDx35nkB+iLtidIykBgz92ZQ5h\nUrVNndP5+lraoMRuIewESSFt+LBYVeUZFTBGlupiUZ/bi7rhtIuhMM8ahaKIstbu\nIgfQBHPqRkkiiKOJawIDAQABo4IBczCCAW8wHwYDVR0jBBgwFoAUDL2TaAzz3quj\nSWsrN1dH6pDjue0wHQYDVR0OBBYEFARoBLDWcsveEZQhaMVIR9mmJkUkMA4GA1Ud\nDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggr\nBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNV\nHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNT\nTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQu\ndGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRw\nOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAhBgNVHREEGjAYghZzYW1saWRwLnNpci5y\nZWRpcmlzLmVzMA0GCSqGSIb3DQEBBQUAA4IBAQB0gmr232YgpUC4HkwAHXaH91Zx\n8ZrwiEc8c4jGLh5VsaO0OqMfUEIXMuqZ+P9JNWVwlc6VLtmsypqTuqb9a06DS88q\n2o5sAUpbXZwhArhQs1bQnu5HJ6S84Ajn+NfMOyaO7NF8Colq/9lf3DihkT0jlD7i\nPHPMw2zauvtR/WPwdPszgfIOV/vkJ0rq9AjOXxSX7V2jpkxISGW/m93iahwXEoVF\nc8VXQhNjEfcm6uawmISjsyp6ta/U3e/8GJka2csDrF/bfipMBDSdWcLMscpYO8cb\nDC0L6vehZJ+lPz3wPH6YJmlstICZUdJIgDV3TUhmji6NNKa4p6by34QdYcDH"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Barcelona Supercomputing Center"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Barcelona Supercomputing Center"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rediris.es/index.php.en"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rediris.es/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "BSC"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "BSC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.dante.net/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idp-support@geant.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "DANTE Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idp-support@geant.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "DANTE Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.dante.net/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-01-03T09:32:28Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDqjCCApICCQCOEbOuEI0OxzANBgkqhkiG9w0BAQUFADCBljELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFzAVBgNVBAgMDkNhbWJyaWRnZXNoaXJlMRIwEAYDVQQHDAlDYW1icmlkZ2Ux\n\t\t\t\t\t\tQjBABgNVBAoMOURlbGl2ZXJ5IG9mIEFkdmFuY2VkIE5ldHdvcmsgVGVjaG5vbG9n\n\t\t\t\t\t\teSB0byBFdXJvcGUgTGltaXRlZDEWMBQGA1UEAwwNaWRwLmRhbnRlLm5ldDAeFw0x\n\t\t\t\t\t\tMzEyMjMxMTEzMzlaFw0xNjEyMjIxMTEzMzlaMIGWMQswCQYDVQQGEwJHQjEXMBUG\n\t\t\t\t\t\tA1UECAwOQ2FtYnJpZGdlc2hpcmUxEjAQBgNVBAcMCUNhbWJyaWRnZTFCMEAGA1UE\n\t\t\t\t\t\tCgw5RGVsaXZlcnkgb2YgQWR2YW5jZWQgTmV0d29yayBUZWNobm9sb2d5IHRvIEV1\n\t\t\t\t\t\tcm9wZSBMaW1pdGVkMRYwFAYDVQQDDA1pZHAuZGFudGUubmV0MIIBIjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxOW6u4C7wEIQdogPpt/CNjn84HnsdJsadN0s\n\t\t\t\t\t\tXQQg+SzfJICuxXYGAMDV4k/W9wTGIodOM4Be7O7edGzOdw4RLSJq4vxW5yu4gOuJ\n\t\t\t\t\t\tyMSYPkEl8nwDOpU4uRTCh2wXE6xe8Eu2eUnXVu+puye4VdKRbQe4Ni1sWgupHO9O\n\t\t\t\t\t\t+9YWBYkwRN/Gqca9PrPr28nZ+XrX+S/NaSRNwjAHEORgFOUqdcPSztCqq8y2924F\n\t\t\t\t\t\tdU7PXE6Twh3qx0aEMfKyZGrheuHzSVwb6DC1TMTkY48onXflF84V1CYF9xXbLcSW\n\t\t\t\t\t\tTZlnzsOW5XbDlQHPEMqFzoyYxfa9zUyd3tNgomu4Ak1t/JO1OQIDAQABMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQCTMnPRHLCez8ElwBmqvQaEExeDh4DmPsSnv+M1DdrQ/Da5\n\t\t\t\t\t\tBx4xi1lMclBNDMRJ8jTcXDoJAvYkZYAGR1o+doJZrU5dv+JM4QWQsNLVwBJg8gSB\n\t\t\t\t\t\tITDrzrpwFUCwVLudO9w/6yDoTbKpyogeMffcGcmiGniKytpI0KK3FhmnFJs+E+0E\n\t\t\t\t\t\tIA9xqZmnx9NyC2BMTeQqqgKi7wM4Q9oIYk6sbm0a//tsryhXcAjX5GRndGfoKBhY\n\t\t\t\t\t\tGmwKzvlHvpu3bwazqP56S2ea/AzbBt7s3fsCWTEdWTsCR44JQwvdalxFCvNlEOf6\n\t\t\t\t\t\tEnuvw8UbosJkAsJVoee8FgQi1WZ/WcIkP0O1hCKz"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dante.net"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.dante.net:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.dante.net:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.dante.net/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.dante.net/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.dante.net:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.dante.net/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.dante.net/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.dante.net/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.dante.net/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.dante.net:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.dante.net:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dante.net"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "G\u00c9ANT plans, procures, builds and operates large scale, advanced high speed networks for global research and education."
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.dante.net/idp/images/geant_logo-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.dante.net/idp/images/geant_logo-80x60.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "G\u00c9ANT Staff Identity Provider"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "dante.net"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:52.191818,0.133772"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.63.90.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:630:280::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDqjCCApICCQCOEbOuEI0OxzANBgkqhkiG9w0BAQUFADCBljELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFzAVBgNVBAgMDkNhbWJyaWRnZXNoaXJlMRIwEAYDVQQHDAlDYW1icmlkZ2Ux\n\t\t\t\t\t\tQjBABgNVBAoMOURlbGl2ZXJ5IG9mIEFkdmFuY2VkIE5ldHdvcmsgVGVjaG5vbG9n\n\t\t\t\t\t\teSB0byBFdXJvcGUgTGltaXRlZDEWMBQGA1UEAwwNaWRwLmRhbnRlLm5ldDAeFw0x\n\t\t\t\t\t\tMzEyMjMxMTEzMzlaFw0xNjEyMjIxMTEzMzlaMIGWMQswCQYDVQQGEwJHQjEXMBUG\n\t\t\t\t\t\tA1UECAwOQ2FtYnJpZGdlc2hpcmUxEjAQBgNVBAcMCUNhbWJyaWRnZTFCMEAGA1UE\n\t\t\t\t\t\tCgw5RGVsaXZlcnkgb2YgQWR2YW5jZWQgTmV0d29yayBUZWNobm9sb2d5IHRvIEV1\n\t\t\t\t\t\tcm9wZSBMaW1pdGVkMRYwFAYDVQQDDA1pZHAuZGFudGUubmV0MIIBIjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxOW6u4C7wEIQdogPpt/CNjn84HnsdJsadN0s\n\t\t\t\t\t\tXQQg+SzfJICuxXYGAMDV4k/W9wTGIodOM4Be7O7edGzOdw4RLSJq4vxW5yu4gOuJ\n\t\t\t\t\t\tyMSYPkEl8nwDOpU4uRTCh2wXE6xe8Eu2eUnXVu+puye4VdKRbQe4Ni1sWgupHO9O\n\t\t\t\t\t\t+9YWBYkwRN/Gqca9PrPr28nZ+XrX+S/NaSRNwjAHEORgFOUqdcPSztCqq8y2924F\n\t\t\t\t\t\tdU7PXE6Twh3qx0aEMfKyZGrheuHzSVwb6DC1TMTkY48onXflF84V1CYF9xXbLcSW\n\t\t\t\t\t\tTZlnzsOW5XbDlQHPEMqFzoyYxfa9zUyd3tNgomu4Ak1t/JO1OQIDAQABMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQCTMnPRHLCez8ElwBmqvQaEExeDh4DmPsSnv+M1DdrQ/Da5\n\t\t\t\t\t\tBx4xi1lMclBNDMRJ8jTcXDoJAvYkZYAGR1o+doJZrU5dv+JM4QWQsNLVwBJg8gSB\n\t\t\t\t\t\tITDrzrpwFUCwVLudO9w/6yDoTbKpyogeMffcGcmiGniKytpI0KK3FhmnFJs+E+0E\n\t\t\t\t\t\tIA9xqZmnx9NyC2BMTeQqqgKi7wM4Q9oIYk6sbm0a//tsryhXcAjX5GRndGfoKBhY\n\t\t\t\t\t\tGmwKzvlHvpu3bwazqP56S2ea/AzbBt7s3fsCWTEdWTsCR44JQwvdalxFCvNlEOf6\n\t\t\t\t\t\tEnuvw8UbosJkAsJVoee8FgQi1WZ/WcIkP0O1hCKz"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "G\u00c9ANT Staff Identity Provider"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.geant.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "G\u00c9ANT Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth2sp.brill.test.semantico.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:brill-shibboleth-support@semantico.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:brill-shibboleth-support@semantico.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth2sp.brill.test.semantico.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Semantico Limited: Brill Test Shibboleth 2 SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.brill.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Semantico Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.brill.test.semantico.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.brill.test.semantico.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.brill.test.semantico.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.brill.test.semantico.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.brill.test.semantico.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEADCCAuigAwIBAgIJAJHnQHTfSIkVMA0GCSqGSIb3DQEBBQUAMHYxCzAJBgNV\n\t\t\t\t\t\tBAYTAlVLMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIwEAYD\n\t\t\t\t\t\tVQQKEwlzZW1hbnRpY28xLzAtBgNVBAMTJnNoaWJib2xldGgyc3AuYnJpbGwudGVz\n\t\t\t\t\t\tdC5zZW1hbnRpY28ubmV0MB4XDTE1MDcwNzE1Mjc0OVoXDTM1MDcwMjE1Mjc0OVow\n\t\t\t\t\t\tdjELMAkGA1UEBhMCVUsxDzANBgNVBAgTBlN1c3NleDERMA8GA1UEBxMIQnJpZ2h0\n\t\t\t\t\t\tb24xEjAQBgNVBAoTCXNlbWFudGljbzEvMC0GA1UEAxMmc2hpYmJvbGV0aDJzcC5i\n\t\t\t\t\t\tcmlsbC50ZXN0LnNlbWFudGljby5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQCpbkZr9C5pTKHeSBhXOdlyq0cj1H7HnJaeFqfNTIsSTeGBz9YQOQj1\n\t\t\t\t\t\tYDpUFvNMz68i9Tr2PmipA9YdpCyx6WacZ97gcicacHQR8bvR40xpdxICKSPbk4q5\n\t\t\t\t\t\t04Lcqk7oWmEqwTKq1HHTZ4beJ+J4nZvuJp6OEsYWlgo0GAppYXomufaIiKgKcMTE\n\t\t\t\t\t\t1o+RmzAqC1NhTGt9bhmu4miGL/E5gF1Ee09rT+CyPy2uU5FfERc9iYbRU1y2nlYa\n\t\t\t\t\t\tl9lGuNKKgCR/i4X6o5N41wbAhC7qVyOgdnC3URIXY6kDxXZXxRJ43CqiN6K7fzXr\n\t\t\t\t\t\tPnbCaIjdcvZNenqIWXmeZZazDhQS0+PrAgMBAAGjgZAwgY0wbAYDVR0RBGUwY4Im\n\t\t\t\t\t\tc2hpYmJvbGV0aDJzcC5icmlsbC50ZXN0LnNlbWFudGljby5uZXSGOWh0dHBzOi8v\n\t\t\t\t\t\tc2hpYmJvbGV0aDJzcC5icmlsbC50ZXN0LnNlbWFudGljby5uZXQvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQUQYXkdOeISwzSlep0EN4KZMtWxzgwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAInyZ2x2Zsnl1/GiTYRZVuQvCXiTkb8qgZPfikCC3j+WWXo3F1vh30frNWrJ\n\t\t\t\t\t\tl/y58imdgq52tNgXlJzzjMWMMGdeDqcCmhEl+G/BzFMcxzR3IJiqasj7uWYe6RLT\n\t\t\t\t\t\tF0CLUN5ireWRoDC7qgCsNw/jdSHA9V0svY6A2zEu/4slg32P3QjXzygHCNNOBPFF\n\t\t\t\t\t\tF1RetJItbWNbQNG7+bZOKHtBzheAiBc0o7i7ewRtk7oJ8TCOsTSV7auJQ9XfjcHc\n\t\t\t\t\t\tYewH2BVJfIHcvb0og5JuID8n6pK5dk3Oto7JfrfFBMud5HXQyiJQBFG3XImvCKyA\n\t\t\t\t\t\tapRzo7PMQM8MkzJRll+WaeTncU4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.brill.test.semantico.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.brill.test.semantico.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.brill.test.semantico.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.brill.test.semantico.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.brill.test.semantico.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth2sp.brill.test.semantico.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.brill.test.semantico.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth2sp.brill.test.semantico.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth2sp.brill.test.semantico.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth2sp.brill.test.semantico.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://uraccess.se/shibboleth-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://uraccess.se/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uraccess.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://uraccess.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uraccess.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uraccess.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uraccess.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://uraccess.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "vm-uraccess-01.hig.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJAPUsAkPRkfQcMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\nBAMTFXZtLXVyYWNjZXNzLTAxLmhpZy5zZTAeFw0xMjEyMjgxNDA2NDZaFw0yMjEy\nMjYxNDA2NDZaMCAxHjAcBgNVBAMTFXZtLXVyYWNjZXNzLTAxLmhpZy5zZTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALZi4a5TDF3axO1a4SVbIV/yMJuh\nFA5dgRAbepHRugRnkeBrYuJZD5Nw9EDFrZzJBWUTuPwxIngZfsAUtdTKnvzjDtks\n1Zp7ZXl5EqayQ0pM5DMoTf2mJOXaduB1oqR6BJQVK1zgm7/pSeYmp4kwWsChBXKs\nE+qF26/ioxCQZ9lYm0hZB6gaDSIANr9hd3JAwWkDD1iGs3NErfS09TEmzYjxeRlf\nvn36fEm9yO1Kc0ZLfQNOSF240+QN7bxISnPAH+V/Bhxes7vXsMa25LUhkTCxuZte\nuFdeucgrS9B0kdRA1anuWUdfZLA2Zc/RQBsy6A+IHfv9n6z1jkLidJ+M8KkCAwEA\nAaNDMEEwIAYDVR0RBBkwF4IVdm0tdXJhY2Nlc3MtMDEuaGlnLnNlMB0GA1UdDgQW\nBBR4inZYnfGemGRVjiQcUPD0tgLCtTANBgkqhkiG9w0BAQUFAAOCAQEAjd8rcbPm\n1SYlzcKAjyBmxk4rGrw/xC34Q8wPdjSkCWuLSEHnHWZ8zligSG18NYnIAnF2HNcZ\nxDlKdNzUDfTLl6DO5Sj/14cp3KRCEguBBpA5mB1B0V1utNxDSSqmSETMIDfevDG+\nbHjvO72YCMTVdrTETXcEqQief7YOl23gNcA+UFBpJVy32Z1Ys2f/TDUO4zA7EIxO\n5wOyJXko37s+7C2zwiv58MNt4kXp7wfu8yLdwdUx26BSG/r4b6eFl3FOHM/4B/tO\nu+7JsZjXP5N3EUSAg15/2ohUY/eiLIpt2Rwnu4uscUN6P9hW5dL2ma0ooT9rrqxy\nKZxzSTvKUlilgw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=vm-uraccess-01.hig.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "vm-uraccess-01.hig.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJAPUsAkPRkfQcMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\nBAMTFXZtLXVyYWNjZXNzLTAxLmhpZy5zZTAeFw0xMjEyMjgxNDA2NDZaFw0yMjEy\nMjYxNDA2NDZaMCAxHjAcBgNVBAMTFXZtLXVyYWNjZXNzLTAxLmhpZy5zZTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALZi4a5TDF3axO1a4SVbIV/yMJuh\nFA5dgRAbepHRugRnkeBrYuJZD5Nw9EDFrZzJBWUTuPwxIngZfsAUtdTKnvzjDtks\n1Zp7ZXl5EqayQ0pM5DMoTf2mJOXaduB1oqR6BJQVK1zgm7/pSeYmp4kwWsChBXKs\nE+qF26/ioxCQZ9lYm0hZB6gaDSIANr9hd3JAwWkDD1iGs3NErfS09TEmzYjxeRlf\nvn36fEm9yO1Kc0ZLfQNOSF240+QN7bxISnPAH+V/Bhxes7vXsMa25LUhkTCxuZte\nuFdeucgrS9B0kdRA1anuWUdfZLA2Zc/RQBsy6A+IHfv9n6z1jkLidJ+M8KkCAwEA\nAaNDMEEwIAYDVR0RBBkwF4IVdm0tdXJhY2Nlc3MtMDEuaGlnLnNlMB0GA1UdDgQW\nBBR4inZYnfGemGRVjiQcUPD0tgLCtTANBgkqhkiG9w0BAQUFAAOCAQEAjd8rcbPm\n1SYlzcKAjyBmxk4rGrw/xC34Q8wPdjSkCWuLSEHnHWZ8zligSG18NYnIAnF2HNcZ\nxDlKdNzUDfTLl6DO5Sj/14cp3KRCEguBBpA5mB1B0V1utNxDSSqmSETMIDfevDG+\nbHjvO72YCMTVdrTETXcEqQief7YOl23gNcA+UFBpJVy32Z1Ys2f/TDUO4zA7EIxO\n5wOyJXko37s+7C2zwiv58MNt4kXp7wfu8yLdwdUx26BSG/r4b6eFl3FOHM/4B/tO\nu+7JsZjXP5N3EUSAg15/2ohUY/eiLIpt2Rwnu4uscUN6P9hW5dL2ma0ooT9rrqxy\nKZxzSTvKUlilgw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=vm-uraccess-01.hig.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uraccess.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://uraccess.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uraccess.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uraccess.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uraccess.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://uraccess.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uraccess.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://uraccess.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://uraccess.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://uraccess.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://nerckwshibba.nerc.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:library@nerc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Library"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:IST_ID_Support@nerc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IST ID Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://nerckwshibba.nerc.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-05-14T15:50:25Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEQDCCAyigAwIBAgIJAPRnCt9s8k0UMA0GCSqGSIb3DQEBBQUAMIGgMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjETMBEGA1UECAwKU29tZS1TdGF0ZTETMBEGA1UEBwwKTm90dGluZ2hh\n\t\t\t\t\t\tbTENMAsGA1UECgwETkVSQzEMMAoGA1UECwwDSVNUMSAwHgYDVQQDDBduZXJja3dz\n\t\t\t\t\t\taGliYmEubmVyYy5hYy51azEoMCYGCSqGSIb3DQEJARYZaXN0X2lkX3N1cHBvcnRA\n\t\t\t\t\t\tbmVyYy5hYy51azAeFw0xMzAyMTMxMTI4NTJaFw0yMzAyMTExMTI4NTJaMIGgMQsw\n\t\t\t\t\t\tCQYDVQQGEwJHQjETMBEGA1UECAwKU29tZS1TdGF0ZTETMBEGA1UEBwwKTm90dGlu\n\t\t\t\t\t\tZ2hhbTENMAsGA1UECgwETkVSQzEMMAoGA1UECwwDSVNUMSAwHgYDVQQDDBduZXJj\n\t\t\t\t\t\ta3dzaGliYmEubmVyYy5hYy51azEoMCYGCSqGSIb3DQEJARYZaXN0X2lkX3N1cHBv\n\t\t\t\t\t\tcnRAbmVyYy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALBM\n\t\t\t\t\t\tzJ+uj+q3UWvsNeEmNq3/OYAxNMCxLaZWZbDtt2gQDBpB2GJBZHIl4GEMTda6w2j6\n\t\t\t\t\t\t34lhz0mZsOXSpE18Tdvp177L3k/h9b0sH2k43I3gq4+mFl6wxPQ8F/wR08dEaz6k\n\t\t\t\t\t\twMfv3ntfF1Y7bLedyw5M94qRUv7rcI/9iFOfyhnpnwCIo2usiIrjkKFUc/gRvkXH\n\t\t\t\t\t\tA9PCkz0+PyPi5HrmrkMaRjxkx25PsKuxbxbplM0Z9wxsCpO6KM/kwxLroYLQh0oJ\n\t\t\t\t\t\tHngCvCuNmVPH4YjCQXh5KVNRx/Wc/F0C9qvFd4aZzgC9Ms8Wmj2FIfTABtyr0u9D\n\t\t\t\t\t\tZhm3G9422dhg6EgZg+sCAwEAAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0E\n\t\t\t\t\t\tHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFCGcQ2SN\n\t\t\t\t\t\tNR/KKBotn3XrDl2OH91cMB8GA1UdIwQYMBaAFCGcQ2SNNR/KKBotn3XrDl2OH91c\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQArZkQSlvSTa9oSr1XJXdDrW3Inf0YlA6D6w9ZC\n\t\t\t\t\t\tHY9vG4FylgXNq/VRKzugFa/esvTNN0xaEciidPqvpaF/JyxCNWFui5X+GWGDt7zi\n\t\t\t\t\t\tvEP34+fzlmhMZu3Jjhu2O/YS9BOQWqCwD8J/KftAbPeSbwB1dWUOnwnlC8X2BfOA\n\t\t\t\t\t\tUTWhDsoVipIEPLnhvSVzDJvSzygzN2BnHMFyaaqHAthaLoyn7BV/SFtk7VaFK7OQ\n\t\t\t\t\t\tMNCj7q1pYJzzTNe0WDOQWGm2/4DpepjWguQSsSuxWieHjJGqkrEsM9HHjd+UtXed\n\t\t\t\t\t\tbvci5wxhP0WyevQbQynrHliiIuFQdbG3GK+/VGF4S2r5wA3I"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "antarctic.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "birdisland.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cambridge.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ernestshackleton.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "halley.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "jamesclark.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "jamesclarkross.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "medicalunit.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "portlockroy.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rothera.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "signy.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "southgeorgia.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "belfast.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cardiff.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edinburgh.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eskdalemuir.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "exeter.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "exhibitionroad.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gilmerton.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hartland.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "keyworth.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "loanhead.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "montserrat.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "murchisonhouse.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wallingford.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ccms.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "plymouth.ccms.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "banchory.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bangor.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dorset.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edinburgh.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lancaster.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "merlewood.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "monkswood.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oxford.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "polaris.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wallingford.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "windermere.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eastkilbride.cs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dml.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oban.dml.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "essc.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "essc.essc.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "faam.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "faam.faam.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ios.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nationaloceanographycentre.ios.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sscnorthstarhouse.ios.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ite.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "banchory.ite.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "monkswood.ite.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mba.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "plymouth.mba.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "noc.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nationaloceanographycentre.noc.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rsumariners.noc.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rsunationaloceanographycentre.noc.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "southamptonuniversity.noc.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nocentre.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "xx.nocentre.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nrcl.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nercradiocarbonlaboratory.nrcl.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pml.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "plymouth.pml.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pol.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "liverpool.pol.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rcuk.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "researchcouncils.rcuk.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "saphos.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "plymouth.saphos.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "smru.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "standrews.smru.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cranfieldfaam.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eastkilbridercl.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edinburgh.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "herstmonceuxnsgf.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "itsskeyworth.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "itsspolarishouse.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "itsswallingford.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "keyworth.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kidlingtonarsf.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "murchisonhouse.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nationaloceanographycentre.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oxfordgecafsipo.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "polarishouse.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "universityofeastanglia.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wallingford.so.idp.nerc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://nerckwshibba.nerc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nerckwshibba.nerc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://nerckwshibba.nerc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nerckwshibba.nerc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://nerckwshibba.nerc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nerckwshibba.nerc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://nerckwshibba.nerc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nerckwshibba.nerc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "antarctic.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "birdisland.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cambridge.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ernestshackleton.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "halley.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "jamesclark.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "jamesclarkross.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "medicalunit.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "portlockroy.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rothera.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "signy.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "southgeorgia.bas.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "belfast.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cardiff.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edinburgh.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eskdalemuir.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "exeter.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "exhibitionroad.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gilmerton.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hartland.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "keyworth.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "loanhead.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "montserrat.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "murchisonhouse.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wallingford.bgs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ccms.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "plymouth.ccms.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "banchory.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bangor.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dorset.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edinburgh.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lancaster.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "merlewood.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "monkswood.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oxford.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "polaris.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wallingford.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "windermere.ceh.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eastkilbride.cs.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dml.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oban.dml.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "essc.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "essc.essc.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "faam.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "faam.faam.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ios.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nationaloceanographycentre.ios.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sscnorthstarhouse.ios.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ite.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "banchory.ite.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "monkswood.ite.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mba.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "plymouth.mba.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "noc.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nationaloceanographycentre.noc.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rsumariners.noc.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rsunationaloceanographycentre.noc.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "southamptonuniversity.noc.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nocentre.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "xx.nocentre.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nrcl.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nercradiocarbonlaboratory.nrcl.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pml.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "plymouth.pml.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pol.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "liverpool.pol.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rcuk.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "researchcouncils.rcuk.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "saphos.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "plymouth.saphos.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "smru.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "standrews.smru.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cranfieldfaam.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eastkilbridercl.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edinburgh.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "herstmonceuxnsgf.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "itsskeyworth.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "itsspolarishouse.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "itsswallingford.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "keyworth.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kidlingtonarsf.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "murchisonhouse.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nationaloceanographycentre.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oxfordgecafsipo.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "polarishouse.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "universityofeastanglia.so.idp.nerc.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wallingford.so.idp.nerc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEQDCCAyigAwIBAgIJAPRnCt9s8k0UMA0GCSqGSIb3DQEBBQUAMIGgMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjETMBEGA1UECAwKU29tZS1TdGF0ZTETMBEGA1UEBwwKTm90dGluZ2hh\n\t\t\t\t\t\tbTENMAsGA1UECgwETkVSQzEMMAoGA1UECwwDSVNUMSAwHgYDVQQDDBduZXJja3dz\n\t\t\t\t\t\taGliYmEubmVyYy5hYy51azEoMCYGCSqGSIb3DQEJARYZaXN0X2lkX3N1cHBvcnRA\n\t\t\t\t\t\tbmVyYy5hYy51azAeFw0xMzAyMTMxMTI4NTJaFw0yMzAyMTExMTI4NTJaMIGgMQsw\n\t\t\t\t\t\tCQYDVQQGEwJHQjETMBEGA1UECAwKU29tZS1TdGF0ZTETMBEGA1UEBwwKTm90dGlu\n\t\t\t\t\t\tZ2hhbTENMAsGA1UECgwETkVSQzEMMAoGA1UECwwDSVNUMSAwHgYDVQQDDBduZXJj\n\t\t\t\t\t\ta3dzaGliYmEubmVyYy5hYy51azEoMCYGCSqGSIb3DQEJARYZaXN0X2lkX3N1cHBv\n\t\t\t\t\t\tcnRAbmVyYy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALBM\n\t\t\t\t\t\tzJ+uj+q3UWvsNeEmNq3/OYAxNMCxLaZWZbDtt2gQDBpB2GJBZHIl4GEMTda6w2j6\n\t\t\t\t\t\t34lhz0mZsOXSpE18Tdvp177L3k/h9b0sH2k43I3gq4+mFl6wxPQ8F/wR08dEaz6k\n\t\t\t\t\t\twMfv3ntfF1Y7bLedyw5M94qRUv7rcI/9iFOfyhnpnwCIo2usiIrjkKFUc/gRvkXH\n\t\t\t\t\t\tA9PCkz0+PyPi5HrmrkMaRjxkx25PsKuxbxbplM0Z9wxsCpO6KM/kwxLroYLQh0oJ\n\t\t\t\t\t\tHngCvCuNmVPH4YjCQXh5KVNRx/Wc/F0C9qvFd4aZzgC9Ms8Wmj2FIfTABtyr0u9D\n\t\t\t\t\t\tZhm3G9422dhg6EgZg+sCAwEAAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0E\n\t\t\t\t\t\tHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFCGcQ2SN\n\t\t\t\t\t\tNR/KKBotn3XrDl2OH91cMB8GA1UdIwQYMBaAFCGcQ2SNNR/KKBotn3XrDl2OH91c\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQArZkQSlvSTa9oSr1XJXdDrW3Inf0YlA6D6w9ZC\n\t\t\t\t\t\tHY9vG4FylgXNq/VRKzugFa/esvTNN0xaEciidPqvpaF/JyxCNWFui5X+GWGDt7zi\n\t\t\t\t\t\tvEP34+fzlmhMZu3Jjhu2O/YS9BOQWqCwD8J/KftAbPeSbwB1dWUOnwnlC8X2BfOA\n\t\t\t\t\t\tUTWhDsoVipIEPLnhvSVzDJvSzygzN2BnHMFyaaqHAthaLoyn7BV/SFtk7VaFK7OQ\n\t\t\t\t\t\tMNCj7q1pYJzzTNe0WDOQWGm2/4DpepjWguQSsSuxWieHjJGqkrEsM9HHjd+UtXed\n\t\t\t\t\t\tbvci5wxhP0WyevQbQynrHliiIuFQdbG3GK+/VGF4S2r5wA3I"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NERC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nerc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Natural Environment Research Council"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.lshtm.ac.uk/shibboleth-xfr",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Manning"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:christopher.manning@lshtm.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Christopher"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Whitbread"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steven.whitbread@lshtm.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.lshtm.ac.uk/shibboleth-xfr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGMjCCBBqgAwIBAgIJAMDPoGjJOgX6MA0GCSqGSIb3DQEBBQUAMIGZMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEPMA0GA1UECBMGTG9uZG9uMQ8wDQYDVQQHEwZMb25kb24xNzA1BgNV\n\t\t\t\t\t\tBAoTLkxvbmRvbiBTY2hvb2wgb2YgSHlnaWVuZSBhbmQgVHJvcGljYWwgTWVkaWNp\n\t\t\t\t\t\tbmUxFDASBgNVBAsTC0lUIFNlcnZpY2VzMRkwFwYDVQQDExBpZHAyLmxzaHRtLmFj\n\t\t\t\t\t\tLnVrMB4XDTEyMTEyMTEwMDQ0N1oXDTIyMTExOTEwMDQ0N1owgZkxCzAJBgNVBAYT\n\t\t\t\t\t\tAkdCMQ8wDQYDVQQIEwZMb25kb24xDzANBgNVBAcTBkxvbmRvbjE3MDUGA1UEChMu\n\t\t\t\t\t\tTG9uZG9uIFNjaG9vbCBvZiBIeWdpZW5lIGFuZCBUcm9waWNhbCBNZWRpY2luZTEU\n\t\t\t\t\t\tMBIGA1UECxMLSVQgU2VydmljZXMxGTAXBgNVBAMTEGlkcDIubHNodG0uYWMudWsw\n\t\t\t\t\t\tggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQC5wsziZNYSjQ6zZruTNpCa\n\t\t\t\t\t\tTg/mA8we3vEAMzb8oNoqfoevqwMop2biprlaJk7E9kVmu1ZO2t6vTPucBfb/Oqyo\n\t\t\t\t\t\tGzRnKlyVGxfCe/yrQ557z3y99xS5jGzu7kOoInpAp9q6tqrqns1A3OEeJSuJ1MJ8\n\t\t\t\t\t\tED053xEiSeL0+jSzkXkZVMCXu2p6kJsW5nT3qhqVrXiaGiB02TAOQMs0mmA8aS1h\n\t\t\t\t\t\tj0bU5gFxKxazt1WYpFW82bSlSd2fz9pOmGklmW5JZxb4Zw8MFbiRfQ1LPwFgZH6E\n\t\t\t\t\t\t+WJqdPb5fehXkklll9o4xO64bXlGfaRl0+5QGtbnqpix37QaDuQRi+NLUkA2wR2L\n\t\t\t\t\t\t/rFJvo6uKsAdTuixfU/gNs0CCqVGi2C0/sQaTsE2Ct8H7BYEmrhqHs4VDzvcDq1L\n\t\t\t\t\t\t2LqMvc4KEEd/Cp6EavaRKI7Edtu4OFUgAgECfbv0C7oouqSHR6X4ciDFfSWk7i92\n\t\t\t\t\t\t3h5tMHX3wfUHJR/YI/mvguDo61wjnpbwgeAV4rNLsdBUOs5AQTCPUDAuyMepm81t\n\t\t\t\t\t\tIQRT/XsNuKv4f9y4ORSpBZ/KspE9P5TklIMDuSvZKS8FZQ5ve4UQeUoer7Bn55ot\n\t\t\t\t\t\tvFTxRrioFUBsmR/5yAsZLJnSU7z09wv3SG1Lj6O79Q9HoJ5M7rKap3+yFkfFqxSP\n\t\t\t\t\t\tKH7JJd9yDiYVaA0f1R1VfQIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIB\n\t\t\t\t\t\tDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUJTj9\n\t\t\t\t\t\tQFp335nQW77uAnSfAmeytCowHwYDVR0jBBgwFoAUJTj9QFp335nQW77uAnSfAmey\n\t\t\t\t\t\ttCowDQYJKoZIhvcNAQEFBQADggIBALR0fEhYAGrXCqw9r2IjsXG0h4Kqv298t7Wd\n\t\t\t\t\t\tfV5Qal71yD2vqVgZBjyoUt6FwQ0GPKhMc/q7Ooy8lfo8NSvZV983MSyWe519xTJ4\n\t\t\t\t\t\tvtPJtKHd2WKYacrdRFPZJYjtTR4CwMXtwxsB2xJrpaJa/sSyRHvE4+PuUBYOj42t\n\t\t\t\t\t\tk6MOk3t1GKfaoYOmJBd2teVym9K5bRqGk6WgnKg+jzPDXJy3+kKvZMZKsv7aYafu\n\t\t\t\t\t\tm2PFoRJu1Nm+6jjTy33SVH3ZS4oydL+uZWfwKvQEqbLOGdRJTZYlDJR2mz6zISbf\n\t\t\t\t\t\t1+LjnK1aqDETq+loatD4gntbpwoMTBMceoDVyRmlPkuFDF31lzkwyAlE5yFmhC9q\n\t\t\t\t\t\tmUNMvsbtYJe546ftf+fyRW/PnZaBRqY1Hkk5lBU4BIgt+gk9jqiAae+DvQ4dikLP\n\t\t\t\t\t\tDWDef3bPLitQA/e/F5YmYq61L7TeIdIiDtD42y5qUW7x+pMTd042EpmoWL9XbdMe\n\t\t\t\t\t\ttvHx33GTkXDFqg88t/lPD8nN9evHWcPvUL1YS3AvJJ9u1Ttiq+agvGDxClgqa2i/\n\t\t\t\t\t\tVZd/+nl8pnTI4n7VsiMMSFnBra1FQFoTwvaAHBotttYutz+jPAo/jQRaD+AqAqj3\n\t\t\t\t\t\tC+Ar+eubE63of1BjM7tWtOldASsG/Kwoq5dNqCWjqmoL3EbLr1hx65qAaRR0XbtB\n\t\t\t\t\t\trDHM7cXn"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lshtm.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.lshtm.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.lshtm.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp2.lshtm.ac.uk/shibboleth-idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.lshtm.ac.uk/shibboleth-idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp2.lshtm.ac.uk/shibboleth-idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2.lshtm.ac.uk/shibboleth-idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.lshtm.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.lshtm.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lshtm.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGMjCCBBqgAwIBAgIJAMDPoGjJOgX6MA0GCSqGSIb3DQEBBQUAMIGZMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEPMA0GA1UECBMGTG9uZG9uMQ8wDQYDVQQHEwZMb25kb24xNzA1BgNV\n\t\t\t\t\t\tBAoTLkxvbmRvbiBTY2hvb2wgb2YgSHlnaWVuZSBhbmQgVHJvcGljYWwgTWVkaWNp\n\t\t\t\t\t\tbmUxFDASBgNVBAsTC0lUIFNlcnZpY2VzMRkwFwYDVQQDExBpZHAyLmxzaHRtLmFj\n\t\t\t\t\t\tLnVrMB4XDTEyMTEyMTEwMDQ0N1oXDTIyMTExOTEwMDQ0N1owgZkxCzAJBgNVBAYT\n\t\t\t\t\t\tAkdCMQ8wDQYDVQQIEwZMb25kb24xDzANBgNVBAcTBkxvbmRvbjE3MDUGA1UEChMu\n\t\t\t\t\t\tTG9uZG9uIFNjaG9vbCBvZiBIeWdpZW5lIGFuZCBUcm9waWNhbCBNZWRpY2luZTEU\n\t\t\t\t\t\tMBIGA1UECxMLSVQgU2VydmljZXMxGTAXBgNVBAMTEGlkcDIubHNodG0uYWMudWsw\n\t\t\t\t\t\tggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQC5wsziZNYSjQ6zZruTNpCa\n\t\t\t\t\t\tTg/mA8we3vEAMzb8oNoqfoevqwMop2biprlaJk7E9kVmu1ZO2t6vTPucBfb/Oqyo\n\t\t\t\t\t\tGzRnKlyVGxfCe/yrQ557z3y99xS5jGzu7kOoInpAp9q6tqrqns1A3OEeJSuJ1MJ8\n\t\t\t\t\t\tED053xEiSeL0+jSzkXkZVMCXu2p6kJsW5nT3qhqVrXiaGiB02TAOQMs0mmA8aS1h\n\t\t\t\t\t\tj0bU5gFxKxazt1WYpFW82bSlSd2fz9pOmGklmW5JZxb4Zw8MFbiRfQ1LPwFgZH6E\n\t\t\t\t\t\t+WJqdPb5fehXkklll9o4xO64bXlGfaRl0+5QGtbnqpix37QaDuQRi+NLUkA2wR2L\n\t\t\t\t\t\t/rFJvo6uKsAdTuixfU/gNs0CCqVGi2C0/sQaTsE2Ct8H7BYEmrhqHs4VDzvcDq1L\n\t\t\t\t\t\t2LqMvc4KEEd/Cp6EavaRKI7Edtu4OFUgAgECfbv0C7oouqSHR6X4ciDFfSWk7i92\n\t\t\t\t\t\t3h5tMHX3wfUHJR/YI/mvguDo61wjnpbwgeAV4rNLsdBUOs5AQTCPUDAuyMepm81t\n\t\t\t\t\t\tIQRT/XsNuKv4f9y4ORSpBZ/KspE9P5TklIMDuSvZKS8FZQ5ve4UQeUoer7Bn55ot\n\t\t\t\t\t\tvFTxRrioFUBsmR/5yAsZLJnSU7z09wv3SG1Lj6O79Q9HoJ5M7rKap3+yFkfFqxSP\n\t\t\t\t\t\tKH7JJd9yDiYVaA0f1R1VfQIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIB\n\t\t\t\t\t\tDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUJTj9\n\t\t\t\t\t\tQFp335nQW77uAnSfAmeytCowHwYDVR0jBBgwFoAUJTj9QFp335nQW77uAnSfAmey\n\t\t\t\t\t\ttCowDQYJKoZIhvcNAQEFBQADggIBALR0fEhYAGrXCqw9r2IjsXG0h4Kqv298t7Wd\n\t\t\t\t\t\tfV5Qal71yD2vqVgZBjyoUt6FwQ0GPKhMc/q7Ooy8lfo8NSvZV983MSyWe519xTJ4\n\t\t\t\t\t\tvtPJtKHd2WKYacrdRFPZJYjtTR4CwMXtwxsB2xJrpaJa/sSyRHvE4+PuUBYOj42t\n\t\t\t\t\t\tk6MOk3t1GKfaoYOmJBd2teVym9K5bRqGk6WgnKg+jzPDXJy3+kKvZMZKsv7aYafu\n\t\t\t\t\t\tm2PFoRJu1Nm+6jjTy33SVH3ZS4oydL+uZWfwKvQEqbLOGdRJTZYlDJR2mz6zISbf\n\t\t\t\t\t\t1+LjnK1aqDETq+loatD4gntbpwoMTBMceoDVyRmlPkuFDF31lzkwyAlE5yFmhC9q\n\t\t\t\t\t\tmUNMvsbtYJe546ftf+fyRW/PnZaBRqY1Hkk5lBU4BIgt+gk9jqiAae+DvQ4dikLP\n\t\t\t\t\t\tDWDef3bPLitQA/e/F5YmYq61L7TeIdIiDtD42y5qUW7x+pMTd042EpmoWL9XbdMe\n\t\t\t\t\t\ttvHx33GTkXDFqg88t/lPD8nN9evHWcPvUL1YS3AvJJ9u1Ttiq+agvGDxClgqa2i/\n\t\t\t\t\t\tVZd/+nl8pnTI4n7VsiMMSFnBra1FQFoTwvaAHBotttYutz+jPAo/jQRaD+AqAqj3\n\t\t\t\t\t\tC+Ar+eubE63of1BjM7tWtOldASsG/Kwoq5dNqCWjqmoL3EbLr1hx65qAaRR0XbtB\n\t\t\t\t\t\trDHM7cXn"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "London School of Hygiene and Tropical Medicine (test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lshtm.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "London School of Hygiene and Tropical Medicine"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://testgag.it.ki.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://testgag.it.ki.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://testgag.it.ki.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://testgag.it.ki.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://testgag.it.ki.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://testgag.it.ki.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://testgag.it.ki.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://testgag.it.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://testgag.it.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "testgag"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAI3dJm1l0MPyMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\nBAMTB3Rlc3RnYWcwHhcNMTMwMTExMTI1MDE5WhcNMjMwMTA5MTI1MDE5WjASMRAw\nDgYDVQQDEwd0ZXN0Z2FnMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\nsaStaMXWwBLjgdSvc9snMbM9KfhmNoWPVNRAYO1gUmBrX5p1XK6JFxkqIRpwEZ/t\nhqowU//tIOXKjipMa7hkX9k+n/jP5Cy/4EVHkczW9iYf/qaCC4L/0DZOYXxXmJTH\n718wgG2QQwbXNBgEPldCVqs3Vr74F0uryI222Qk8Iyei4psi9P5Eng68N3+kB5T2\nF+MnwjyCU9MXOD0s76genwJ+Kat8uZWLb/uX/Xw3UMr/QHdRlBrD8kuXR037mfIf\ne3aE0oBYKgWYUbUFsPjWdWOPs4GhtgN7Xz/UBXVOKDm7ovQpmSYB4BSFj2da3Wqw\nchIq046RECnOJr94HaU9+QIDAQABozUwMzASBgNVHREECzAJggd0ZXN0Z2FnMB0G\nA1UdDgQWBBQ1FMmD2kBlT1fLG1WiGNTqKXN+tTANBgkqhkiG9w0BAQUFAAOCAQEA\nmj0wtGNPs+RQnVB8wX40A9eHeE5VhjjTME787giTg6jeQNN5LYySlY35sNBPzRaw\nW53kUdaH2ZSRyr74W9ZZci9o1bNIzvxZUEn4hLsa6HQoGLxRopGXJvNC5+hEli/9\naYN28/iDO1t+nO7krxcPH61sBAEnKq9OJM9oQrWol3lGEkeWhq6Evcdd0Fx5l2E7\nzo0PZj6BRUxSCIa8c1pJLtQhimhPb5CuamnOir5Ae6FrxSmqdbA9CBT9MXioBcUC\nQXyxky4ZRxRwrSEEgAnSMnEVxO6Q0kbyQImZXy7fTe3PninA9t0jy/p7b6qNqsMH\nJDXzgzqNBDH+pyHcbSmlcA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=testgag"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://testgag.it.ki.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://testgag.it.ki.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://testgag.it.ki.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://testgag.it.ki.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://testgag.it.ki.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://testgag.it.ki.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://oala.trinitylaban.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Speller"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:e.speller@trinitylaban.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Edith"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Department"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it@trinitylaban.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://oala.trinitylaban.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-04-05T18:33:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://oala.trinitylaban.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://oala.trinitylaban.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kcc.tcm.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://oala.trinitylaban.ac.uk/oala/images/tlsqtr60px.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  },
                  {
                    "text": "https://oala.trinitylaban.ac.uk/oala/images/tlfavicon.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Trinity Laban"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIRAOP4a2rGltT7syLTMWMP0yMwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xNDAzMTEwMDAwMDBaFw0xNzAzMTAyMzU5NTlaMEUxITAfBgNV\n\t\t\t\t\t\tBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEgMB4GA1UEAxMXb2FsYS50cmlu\n\t\t\t\t\t\taXR5bGFiYW4uYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC8\n\t\t\t\t\t\tfS+Lxi6rqfi+4r69jVE3cZB4Xgi/URiCP2UbOHnoYjeRCy+ePHchk31oebEfF6kq\n\t\t\t\t\t\tg/PcrAsmgNCgQ0XUesiZPGTZDPUrmsZAzX6ExMxTPiNXeQtnbbVRdIee/16duWoX\n\t\t\t\t\t\tF2T6vfYvyisZgkI8FGVWcUY6HOnXEKCFTtzznX4pkv/FpnTlB9Z4DEuAHWnAJUfz\n\t\t\t\t\t\tdzUO1941DE5MEi4/29Y1aoj0QdliLy5qTGB0AKO7OjYWjfx6XcwqYKhYVcDAwiBK\n\t\t\t\t\t\tq5LoiH/P6CKwYs4iea0ZFT3F6CSOyN0nmiOH/WzT853wiAqLptO/oun8FeDXz5kr\n\t\t\t\t\t\tbkBJX8ODB6ChlLd0FEJnAgMBAAGjggF0MIIBcDAfBgNVHSMEGDAWgBQMvZNoDPPe\n\t\t\t\t\t\tq6NJays3V0fqkOO57TAdBgNVHQ4EFgQU2kzdewE+omvtXAoSGI0rZxkquW0wDgYD\n\t\t\t\t\t\tVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEG\n\t\t\t\t\t\tCCsGAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoG\n\t\t\t\t\t\tA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5B\n\t\t\t\t\t\tU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2Ny\n\t\t\t\t\t\tdC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0\n\t\t\t\t\t\tdHA6Ly9vY3NwLnRjcy50ZXJlbmEub3JnMCIGA1UdEQQbMBmCF29hbGEudHJpbml0\n\t\t\t\t\t\teWxhYmFuLmFjLnVrMA0GCSqGSIb3DQEBBQUAA4IBAQAO0EL0yO9As2ommUEfYOiM\n\t\t\t\t\t\tusV7rpBuxj8wQdETSk+MFeXC5DmGn5K31g6QSeKABgxl3f5mwugs/6oP0XN9356W\n\t\t\t\t\t\tb8EQHmldHx+Rgba2RjSSW7BPhMMXWD0fWOt4wQmHvDk4KHazg/r/kmuHBlQJjHEQ\n\t\t\t\t\t\tpqHqnF2Z/6dd8RF5gnVplUfuv4iAwHMNYanvOPzjKEBu5Ah6ONV0b6MqAKibPKbW\n\t\t\t\t\t\tm7UM5Kv5sjA8xs+7duWvSyTsalpM5+GchHQhurcdqlagdHiN5zRpCGXKAs0nWuFc\n\t\t\t\t\t\tpbL9oxrAy7Tm9MbUIs951lYcX+K93CT+CTeDBMeulw5d8x1buwmZS5Axsig7jO2g"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Trinity Laban"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.trinitylaban.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Trinity Laban Conservatoire Of Music And Dance Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://student.ate.grayzone.ladok.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://student.ate.grayzone.ladok.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://student.ate.grayzone.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok student.ate.grayzone.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok student.ate.grayzone.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://student.ate.grayzone.ladok.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "student.ate.grayzone.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWzCCAkOgAwIBAgIJAORuSk6Eq23DMA0GCSqGSIb3DQEBCwUAMCgxJjAkBgNV\nBAMTHXN0dWRlbnQuYXRlLmdyYXl6b25lLmxhZG9rLnNlMB4XDTE2MDQyNzEyNDYy\nNloXDTI2MDQyNTEyNDYyNlowKDEmMCQGA1UEAxMdc3R1ZGVudC5hdGUuZ3JheXpv\nbmUubGFkb2suc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDj+yBp\nXsiSe6jC2u+BctNk+VZTAsjnP6xPzoal/D35zX9SI5f9U+NObVjzsyPg3rJ+FOaj\nxLIr+gfuF9yOb8TMAjwDP119OIBBTW0zg+Qwh6LCbumP3TrtxqzcpBWIrAfpB2lf\nZsNqO9AAjFLvw502G/NHYAFVIfIG4+4+U8ZvG8Vf24LrWRv6QNasYAUVAtnyXMX0\nMQ7j3DR5APlMlX8v/v2/hM7sulQYWG/B3dJtraOnJS0ChOi+qTIrel9qPkubSyAE\nJG5fu61RPQCqKZ8zrc03Pb0UwsHI+fuH1rqXW79JweIYlIaQZnDnX7VyH1fY13rA\nym3GLSX6zETGzvk7AgMBAAGjgYcwgYQwYwYDVR0RBFwwWoIdc3R1ZGVudC5hdGUu\nZ3JheXpvbmUubGFkb2suc2WGOWh0dHBzOi8vc3R1ZGVudC5hdGUuZ3JheXpvbmUu\nbGFkb2suc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAdBgNVHQ4EFgQUcGYd638GO6By\nzxxRpJGgVd9/vS4wDQYJKoZIhvcNAQELBQADggEBADJsf5USxqSPcLxW8sXYRFmA\ny6clwJouncFvwm68R9vyRGVgVcj3CiZdLWwfCeEOgdQlosuNCH2iWxsqfOS8cXr3\n6qxY2fV6mPBKKZ5g1sjFOFY7c9jGmxk2wsWOwH8hKwpKp7jCH4wKC4UV5jeE6gxx\nnsJx+NtDQJf52Apw+StEyXWRdkXdsJqSJxi0ceeYsD5i+WQ4pl3asaHYbezokfv7\nI19MAsA3MUnDVe/RlhjZ4xc6qnWlR5CjDkLhx5YGUSWVflnD+e8jeKmC58ya1PBM\nmp4NftTztxnmXF+uwS5Yvi3egqAlAoGb1xO4omwJ3qlVbWdDXY4SwnMcGebOeac="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=student.ate.grayzone.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://student.ate.grayzone.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://demo-dcs.cla.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dev@cloudspringtech.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dev Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dev@cloudspringtech.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dev Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://demo-dcs.cla.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-02-05T12:53:23Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Digital Content Store"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://cla.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Copyright Licensing Agency Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://demo-dcs.cla.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://demo-dcs.cla.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://demo-dcs.cla.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://demo-dcs.cla.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://demo-dcs.cla.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://demo-dcs.cla.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://demo-dcs.cla.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3zCCAcegAwIBAgIJANN7j8TZENUbMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\n\t\t\t\t\t\tBAMTCG5zMzczMTUzMB4XDTE1MDQyNzEzNDMzOVoXDTI1MDQyNDEzNDMzOVowEzER\n\t\t\t\t\t\tMA8GA1UEAxMIbnMzNzMxNTMwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDe0s9fwQ9v4NajnGwDJkesWo7Py4ufH/5qJsYUPcForz10FATKQtlGZZvb1Gzq\n\t\t\t\t\t\t1TaenINx4QqSjUjdyVUN3N25LWCVXW7IKmL+cxJPXx0R8Nng86ZCtYmA1epphESy\n\t\t\t\t\t\tPTXHLDOst7B4LdtxdlfqMaSr7xRo+1tBvY4G3Lqpt2l085R13XSvVfpbevQZSD4p\n\t\t\t\t\t\tnqi9vAiFUM4NDvycm0Yil/dPk4fGWlpMNT01JR50rpFnntJJVfab7I9Qf5cxboBw\n\t\t\t\t\t\t5mOPwqA8w4BI4o1gFqeH/vBXwrbA8zX9Ehgkfn1Rl8Aa0ZSMgoNjhzzwwLvjAuxT\n\t\t\t\t\t\tbWxPlVUwr7soX+RK9JRRgEMbAgMBAAGjNjA0MBMGA1UdEQQMMAqCCG5zMzczMTUz\n\t\t\t\t\t\tMB0GA1UdDgQWBBSp4HYFPmzOFP8q8RG2pBi0PerD3TANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAU9s2EhAdQudGpXpw6Ozw4tmEvg1IKDbUxUNEKkfUMOnlqPIeYvYhk5LN5ttD\n\t\t\t\t\t\tYTBcGaA8tIh5UIlQpNUh2Eb89FgZ2UqNgyx9OGMaiP7nl5ZV8HHckiTcrFKOnG6X\n\t\t\t\t\t\t+nuyOTeIYjgvpldbLZxRMlCt5fSQzqwwYX6SyK6PWsqQTZhvzpwdpbGrUj4mKEcV\n\t\t\t\t\t\tvs9mlOgKFkqvzXLr+I4D8XVYbIxBCeh7X82ooPv4r6d7kzJJo9pRf+qi0RNKJmWZ\n\t\t\t\t\t\tvI2el1erTkBgTf/qHvtskD/N1KTxz9oZV/bTpkype7gRaya8jguEmXqz0fyt9ohB\n\t\t\t\t\t\tkep+2TUr/H4eYqGM0KNkWWD8FA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://demo-dcs.cla.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://demo-dcs.cla.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://demo-dcs.cla.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://demo-dcs.cla.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://demo-dcs.cla.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://demo-dcs.cla.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://accesnoto.deboecksuperieur.com",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "David Daenekint"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "David.Daenekint@deboeck.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Roland Leijten"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "role@threeships.nl"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://accesnoto.deboecksuperieur.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-12-09T14:12:55Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/elearning"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/local"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "DE BOECK SUPERIEUR"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://deboeck.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "DE BOECK SUPERIEUR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://accesnoto.deboecksuperieur.com"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Environment on which Noto and NotoBib customers can use educational resources of De Boeck Sup\u00e9rieur"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Environnement sur lequel les clients de Noto et NotoBib peuvent utiliser les ressources \u00e9ducatives de De Boeck Sup\u00e9rieur"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "De Boeck Sup\u00e9rieur License Desk"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "De Boeck Sup\u00e9rieur License Desk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRzCCAjOgAwIBAgIQcCffsQu+QppGk8fmt9tu8zAJBgUrDgMCHQUAMDAxLjAs\nBgNVBAMTJWh0dHA6Ly9hY2Nlc25vdG8uZGVib2Vja3N1cGVyaWV1ci5jb20wHhcN\nMTQxMjA5MTIzNTUwWhcNMzkxMjMxMjM1OTU5WjAwMS4wLAYDVQQDEyVodHRwOi8v\nYWNjZXNub3RvLmRlYm9lY2tzdXBlcmlldXIuY29tMIIBIjANBgkqhkiG9w0BAQEF\nAAOCAQ8AMIIBCgKCAQEAsM8i9y0yvzOg2yXRsWRNI40R190pMoTeRhVzgTN1fsqJ\nv4J4HjvPfhR3njwpYejcsbBnxgs1G/CqIUjqAcJ3J4QluT3a9jNrXCZcdwR5eiUk\nfHciFJvH0tjA0/JkWRRfWGUI58bn5y+z5lgXsLuk6dDoKQczzlof/EBke4qbZP4j\nWISy+DCL1PurXCbVgr4oUZG/aXF4yYZwIaOPGDDe2wfpEpB/5SSSHr1SATmO33Rm\nw3cLnLjAU42reiuyoA68FlakbNoa7Am57QGmsyw/GL9g4c/1cmmioUHXodgsNwHv\nAd0WZQ2DPMwZUFTTTL6SDw/L4a5YXfGEQJVFYO1inQIDAQABo2UwYzBhBgNVHQEE\nWjBYgBBcuwvkChnCuDGzSDS1bwoUoTIwMDEuMCwGA1UEAxMlaHR0cDovL2FjY2Vz\nbm90by5kZWJvZWNrc3VwZXJpZXVyLmNvbYIQcCffsQu+QppGk8fmt9tu8zAJBgUr\nDgMCHQUAA4IBAQCRN4UHa2BT1eCNp2DEItK6fo6hy01olz6rdod7n1otcE2ZpBXa\nSdPoUsCLChLct/kc3G7UDjN+RGPU9lbkbBeRXGM6Bh1x2WCI06yMbvTn19amhtLb\njddJYUKpfyObtw0xzVUtcyMu61Zs//nWPmj84A+JALic8ayN9UfKTP9q1KK/GZwc\nAUgH/i8Unj7LErN6gpwIJhh1fT7Y2o91XHMX6rIWSiz6sPX0uGzbmKTNoWpTEQ1p\naYokMrO/zaJasorhJxzIsEBAeu5j6fgK0EDZfm6t1LJlRN95kXYOPEL4MDvMjWBn\nkb+1yGp1iVZqYSoJbQciM6hqlGjMEm4kllZC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRzCCAjOgAwIBAgIQcCffsQu+QppGk8fmt9tu8zAJBgUrDgMCHQUAMDAxLjAs\nBgNVBAMTJWh0dHA6Ly9hY2Nlc25vdG8uZGVib2Vja3N1cGVyaWV1ci5jb20wHhcN\nMTQxMjA5MTIzNTUwWhcNMzkxMjMxMjM1OTU5WjAwMS4wLAYDVQQDEyVodHRwOi8v\nYWNjZXNub3RvLmRlYm9lY2tzdXBlcmlldXIuY29tMIIBIjANBgkqhkiG9w0BAQEF\nAAOCAQ8AMIIBCgKCAQEAsM8i9y0yvzOg2yXRsWRNI40R190pMoTeRhVzgTN1fsqJ\nv4J4HjvPfhR3njwpYejcsbBnxgs1G/CqIUjqAcJ3J4QluT3a9jNrXCZcdwR5eiUk\nfHciFJvH0tjA0/JkWRRfWGUI58bn5y+z5lgXsLuk6dDoKQczzlof/EBke4qbZP4j\nWISy+DCL1PurXCbVgr4oUZG/aXF4yYZwIaOPGDDe2wfpEpB/5SSSHr1SATmO33Rm\nw3cLnLjAU42reiuyoA68FlakbNoa7Am57QGmsyw/GL9g4c/1cmmioUHXodgsNwHv\nAd0WZQ2DPMwZUFTTTL6SDw/L4a5YXfGEQJVFYO1inQIDAQABo2UwYzBhBgNVHQEE\nWjBYgBBcuwvkChnCuDGzSDS1bwoUoTIwMDEuMCwGA1UEAxMlaHR0cDovL2FjY2Vz\nbm90by5kZWJvZWNrc3VwZXJpZXVyLmNvbYIQcCffsQu+QppGk8fmt9tu8zAJBgUr\nDgMCHQUAA4IBAQCRN4UHa2BT1eCNp2DEItK6fo6hy01olz6rdod7n1otcE2ZpBXa\nSdPoUsCLChLct/kc3G7UDjN+RGPU9lbkbBeRXGM6Bh1x2WCI06yMbvTn19amhtLb\njddJYUKpfyObtw0xzVUtcyMu61Zs//nWPmj84A+JALic8ayN9UfKTP9q1KK/GZwc\nAUgH/i8Unj7LErN6gpwIJhh1fT7Y2o91XHMX6rIWSiz6sPX0uGzbmKTNoWpTEQ1p\naYokMrO/zaJasorhJxzIsEBAeu5j6fgK0EDZfm6t1LJlRN95kXYOPEL4MDvMjWBn\nkb+1yGp1iVZqYSoJbQciM6hqlGjMEm4kllZC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "http://accesnoto.deboecksuperieur.com/Security/Renater/AssertionConsumerService.aspx",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "De Boeck Sup\u00e9rieur License Desk"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "De Boeck Sup\u00e9rieur License Desk"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Environnement sur lequel les clients de Noto et NotoBib peuvent utiliser les ressources \u00e9ducatives de De Boeck Sup\u00e9rieur"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Environment on which Noto and NotoBib customers can use educational resources of De Boeck Sup\u00e9rieur"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://lma-idp.lanet.lv",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ITserviss"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itserviss@lanet.lv"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://lma-idp.lanet.lv",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://laife.lanet.lv/wiki/Latvian-Academic-Identity-Federation-Policy.pdf"
              }
            ],
            "registration_instant": "2013-10-10T10:10:10Z",
            "registration_authority": "http://laife.lanet.lv/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lma-idp.lanet.lv/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lma-idp.lanet.lv/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:56.950974,24.116292"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Art Academy of Latvia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Art Academy of Latvia - LMA IDP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://laife.lanet.lv/"
          },
          {
            "lang": "lv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lma.lv/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LAIFE - LMA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.sae.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:eptech@sae.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "HelpDesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Yauger"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jyauger@sae.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jim"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.sae.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-05-14T09:58:53Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SAE Digital Library"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sae.org/about/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SAE International"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.sae.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.sae.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.sae.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.sae.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.sae.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sp.sae.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Subscription-based access to aerospace and automotive technical information from SAE International"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.sae.org/images/design13/sae-international.png",
                    "height": "67",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "106"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SAE Digital Library"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC5TCCAc2gAwIBAgIJAMzQRYYPKgNmMA0GCSqGSIb3DQEBBQUAMBUxEzARBgNV\n\t\t\t\t\t\tBAMTCnNwLnNhZS5vcmcwHhcNMTQwNTA4MTg1ODAyWhcNMjQwNTA1MTg1ODAyWjAV\n\t\t\t\t\t\tMRMwEQYDVQQDEwpzcC5zYWUub3JnMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAwFM+ZGsgDIBo8K5978MlaXxqFBHhNVp1EcI9irg627zjSQxc58G4U1H2\n\t\t\t\t\t\t3kvm4ku04jon3/4jBtfmBTZOtWbdOjTKcbEgwmINlH2Jauy3S2M4XmxM3Q5PU412\n\t\t\t\t\t\tLKe6zZE7jpjJ1lRzHDKtFyujKoIUAiGYjuCJN+XxQJIdIci7mwpnrIJeu+bbbDfX\n\t\t\t\t\t\tgGjUHQnVXI/OOxb+lfzp/dc6feYQL/RGammPm+sZpsIjtSBuNQkTlJZOZylFMtqb\n\t\t\t\t\t\tO/IoQuMEiRmqb2OAAv+ePnQf7lnS14sLu4nhXrBgCEn1K+Lql/Vkk3I1NKQRDGwA\n\t\t\t\t\t\t8TkLBm8tQRBZNtLMWatCJZ3b9MIrEwIDAQABozgwNjAVBgNVHREEDjAMggpzcC5z\n\t\t\t\t\t\tYWUub3JnMB0GA1UdDgQWBBRZD8PzLLNGYvb95Q+GmvZonJ73fzANBgkqhkiG9w0B\n\t\t\t\t\t\tAQUFAAOCAQEACkDp1AnogySx14XbKgPuD4L1II4SOiNZZIPtzpTY+oKJYBI/ftRY\n\t\t\t\t\t\tjO1WDh0kG9vr/OUCVPCrJ5Dzf8Vq2VgBkYbkJHt15bkYRb0RTOl3CQEH14gLXpbf\n\t\t\t\t\t\tyhY+SiW+b9UpRYfYX5r9zE78Ksb4yNLVztvrs+KtfLO6D6lZzVMTVHeGt4neg6XG\n\t\t\t\t\t\tMfac7z4zH4mgPgRDdM9yZU21CjuCGmHqVKYQhz27rUhkxn/LTEYANpKYlULAKk/N\n\t\t\t\t\t\tzc920LYEc7WudUXMp8/0+q0f20iPBWRETgybUmCEQE6yabF3wuQ0QMpBW2f71dzP\n\t\t\t\t\t\tqUpkwubpN3QS7q9U8Emmulh/zSie3zkeBQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.sae.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp.sae.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.sae.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp.sae.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://student.mit-ik.ladok.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://student.mit-ik.ladok.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.mit-ik.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.mit-ik.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.mit-ik.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.mit-ik.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.mit-ik.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://student.mit-ik.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://student.mit-ik.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3-projektets Migrations-, Integrations- och Testmilj\u00f6 (MIT-milj\u00f6n)"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 MIT IK Studentgr\u00e4nsnitt"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://student.mit-ik.ladok.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "student.mit-ik.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQTCCAimgAwIBAgIJAKoOk/IYnkUHMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF3N0dWRlbnQubWl0LWlrLmxhZG9rLnNlMB4XDTE1MDIxMTE1MDUzNFoXDTI1\nMDIwODE1MDUzNFowIjEgMB4GA1UEAxMXc3R1ZGVudC5taXQtaWsubGFkb2suc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDFjdHFypvK6B6Rir74wGCP\nIhe6Q2cPg4LFX6MllAToyZ8hTCWjgkWfuIQb0Y19feu0+OtVkX1PNGHI++xZ2jRe\nWXjtbVVvYLZJXZ0pHc5BWKTVBO/ceUHaPpxqHvBG5H/45hD+nBlgNugOEYHuONt3\nkk44ykHEmkOFfXFK2evKDvU0hQQoIvcJLqCnF4YoY+uoW6B0kR85V9S26dI/OYf4\npQ97FBLjTpdp1mrxl3FzvhreYdp87pMX/Mt8glnlPcC75QISofzhdbCwKt4/K6kp\nQsh3SogfG0utTmTrMRrX70A4FUT8tINWMW7lYzv3EmQG4NzYqblzEFGW081NNc+d\nAgMBAAGjejB4MFcGA1UdEQRQME6CF3N0dWRlbnQubWl0LWlrLmxhZG9rLnNlhjNo\ndHRwczovL3N0dWRlbnQubWl0LWlrLmxhZG9rLnNlL3N0dWRlbnQtZnJvbnRlbmQt\nc3AwHQYDVR0OBBYEFAIPsERizWQ0mxP5l/tZoFmLFdJaMA0GCSqGSIb3DQEBBQUA\nA4IBAQCtIQI5dumWKvG+8JMOl7FHUShqrqLUNZQrOIOaR3vUUpt+e83aHZvxHVjW\nHdk2KxQXPqzhLZSn6HdPwCvVKjAtEOVnQyDIi46XAgcd5jPxphqO596DQuNvTpOw\nt0HqFe6ZMyNyx/sXNoUioUfDOuNJpOeBq8qcYzE8TILDyXzkdcmnQxzJla9jcCn1\nBTZkB4p0AKYSK6Bj/8Ei2Ts1Qsc91jKuL8IBwtCzwBX/ylIwXZ3gsEHPml4aoQ9K\nnPk29bFsyJEWcfYMu3UnTMPSxCIkr+nyaydY1WWJXWhmbBQ5Sf2AfGrHaA3Lau4W\nFC/69gmQ454invqHaiq/uMW2hYdh"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=student.mit-ik.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.mit-ik.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.mit-ik.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.mit-ik.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.mit-ik.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.mit-ik.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.mit-ik.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://student.mit-ik.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://student.mit-ik.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://student.mit-ik.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.weymouth.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Templeton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Phil_Templeton@weymouth.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Phil"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Templeton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Phil_Templeton@weymouth.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Phil"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.weymouth.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-07-09T11:53:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUZFz+kRz+YW7p9f/N9n5Of8fT2j0wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHTEbMBkGA1UEAwwSaWRwLndleW1vdXRoLmFjLnVrMB4XDTE1MDUxNDE1MDE0\n\t\t\t\t\t\tOFoXDTM1MDUxNDE1MDE0OFowHTEbMBkGA1UEAwwSaWRwLndleW1vdXRoLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkUna4sDGdpwE4oEaTO34\n\t\t\t\t\t\tu65rTxJM6IL7WQYrUVqrqxedUClwy7hLk49DQFXB1AH4xOKolxDkapobo2hMVU3d\n\t\t\t\t\t\tQ0yGD998OQf8C6xLEl4Yco9uN0fN83ZqVuEKDkQ272kuL/kdfKx0ZRUBWgRVcnKB\n\t\t\t\t\t\tyV4tRhnfhl8ajYgBsLtTSWyNIjGjtiqYGuwhuHTcGG7Oi0I9y2j/NLHx1jdB8xUY\n\t\t\t\t\t\tz7ohgAlcoDyP8BPjS1j0fEt97AxdmNIQ29xe/xsweJ/KnSIvhBm++TJ+bHSGTYyA\n\t\t\t\t\t\twN5NIlGWR/CJLuFEuOFi1z1b3KL6ThdQMnAODxXX3mX0urdQ9Pt+4EqmopjB4ouo\n\t\t\t\t\t\tHwIDAQABo2swaTAdBgNVHQ4EFgQUQyIHvBA0HQf/jmuE1vFqZ0WYal0wSAYDVR0R\n\t\t\t\t\t\tBEEwP4ISaWRwLndleW1vdXRoLmFjLnVrhilodHRwczovL2lkcC53ZXltb3V0aC5h\n\t\t\t\t\t\tYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAQh5Rj41IABCV\n\t\t\t\t\t\tOmRnYHiV9Jcoo8xm4YK964n/K9Bz3stiTFGghIIyvysliIn54jlUYifHMVbgNdMD\n\t\t\t\t\t\tOR6Pu27JF7VMhx/9j9KCTCXse2mOxxtBfFF2agH1713rGNHxnDt7pof5j3hAJPQl\n\t\t\t\t\t\tmYDZzDfuRlVRQy1LIFXykqO9qQlLz8ee8nlF4szS3DhG1s7p8UZG+tormNOG9/Iy\n\t\t\t\t\t\tmlfxKAyZAGpZSw+SG9B5J1hp7iBcull1xzHm1RkMKgO6y8ZepIcKuHqcgg8J588H\n\t\t\t\t\t\tZhW5ckHO38W5sam0GEuPfinLTDrEk7u+PvLSKtyZHaW8iNegbWtTgKL/Zspe1vBw\n\t\t\t\t\t\tijX+yImKyg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "weymouth.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.weymouth.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.weymouth.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.weymouth.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.weymouth.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.weymouth.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.weymouth.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.weymouth.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.weymouth.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "weymouth.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUZFz+kRz+YW7p9f/N9n5Of8fT2j0wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHTEbMBkGA1UEAwwSaWRwLndleW1vdXRoLmFjLnVrMB4XDTE1MDUxNDE1MDE0\n\t\t\t\t\t\tOFoXDTM1MDUxNDE1MDE0OFowHTEbMBkGA1UEAwwSaWRwLndleW1vdXRoLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkUna4sDGdpwE4oEaTO34\n\t\t\t\t\t\tu65rTxJM6IL7WQYrUVqrqxedUClwy7hLk49DQFXB1AH4xOKolxDkapobo2hMVU3d\n\t\t\t\t\t\tQ0yGD998OQf8C6xLEl4Yco9uN0fN83ZqVuEKDkQ272kuL/kdfKx0ZRUBWgRVcnKB\n\t\t\t\t\t\tyV4tRhnfhl8ajYgBsLtTSWyNIjGjtiqYGuwhuHTcGG7Oi0I9y2j/NLHx1jdB8xUY\n\t\t\t\t\t\tz7ohgAlcoDyP8BPjS1j0fEt97AxdmNIQ29xe/xsweJ/KnSIvhBm++TJ+bHSGTYyA\n\t\t\t\t\t\twN5NIlGWR/CJLuFEuOFi1z1b3KL6ThdQMnAODxXX3mX0urdQ9Pt+4EqmopjB4ouo\n\t\t\t\t\t\tHwIDAQABo2swaTAdBgNVHQ4EFgQUQyIHvBA0HQf/jmuE1vFqZ0WYal0wSAYDVR0R\n\t\t\t\t\t\tBEEwP4ISaWRwLndleW1vdXRoLmFjLnVrhilodHRwczovL2lkcC53ZXltb3V0aC5h\n\t\t\t\t\t\tYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAQh5Rj41IABCV\n\t\t\t\t\t\tOmRnYHiV9Jcoo8xm4YK964n/K9Bz3stiTFGghIIyvysliIn54jlUYifHMVbgNdMD\n\t\t\t\t\t\tOR6Pu27JF7VMhx/9j9KCTCXse2mOxxtBfFF2agH1713rGNHxnDt7pof5j3hAJPQl\n\t\t\t\t\t\tmYDZzDfuRlVRQy1LIFXykqO9qQlLz8ee8nlF4szS3DhG1s7p8UZG+tormNOG9/Iy\n\t\t\t\t\t\tmlfxKAyZAGpZSw+SG9B5J1hp7iBcull1xzHm1RkMKgO6y8ZepIcKuHqcgg8J588H\n\t\t\t\t\t\tZhW5ckHO38W5sam0GEuPfinLTDrEk7u+PvLSKtyZHaW8iNegbWtTgKL/Zspe1vBw\n\t\t\t\t\t\tijX+yImKyg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Weymouth College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.weymouth.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Weymouth College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://test.ukfederation.org.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:service@ukfederation.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UK federation helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ukfed.infrastructure@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UK federation infrastructure"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test.ukfederation.org.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-07-13T11:19:55Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UK federation SAML 1.1/2.0 Test SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://ukfederation.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.ukfederation.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This test service provider allows you to see the attributes your identity provider is releasing."
                  }
                ],
                "logo": [
                  {
                    "text": "https://test.ukfederation.org.uk/images/twigs_500x216.jpg",
                    "height": "216",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "500"
                  },
                  {
                    "text": "https://test.ukfederation.org.uk/images/twigs_240x104.jpg",
                    "height": "104",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "240"
                  },
                  {
                    "text": "https://test.ukfederation.org.uk/images/twigs_100x43.jpg",
                    "height": "43",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  },
                  {
                    "text": "https://test.ukfederation.org.uk/images/twigs_75x75.jpg",
                    "height": "75",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "75"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UK federation SAML 1.1/2.0 Test SP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/Login1",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/UKfedWAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/UKfedDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/UKfedDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/UKfedWAYFall",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/UKtestWAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/UKtestDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/UKtestDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "4"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/TESTfedWAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/TESTfedDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/TESTfedDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "5"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/TESTfedWAYFall",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/TESTtestWAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/TESTtestDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/TESTtestDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "6"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/EDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://test.ukfederation.org.uk/Shibboleth.sso/EDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "7"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJALYNI4chorkFMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\n\t\t\t\t\t\tBAMTE3VrZi1zdmMuZWRpbmEuYWMudWswHhcNMTEwMTI4MTY1MjQ2WhcNMjEwMTI1\n\t\t\t\t\t\tMTY1MjQ2WjAeMRwwGgYDVQQDExN1a2Ytc3ZjLmVkaW5hLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAv8qWcZAP79noTlNXCrHVJoUUgWlcaBQc\n\t\t\t\t\t\tV94tQnjUo313VRnbzWgaghHfv8xFEXpWRjQhTOCuAugI3wKmKVjmJQmSYhNc6pgJ\n\t\t\t\t\t\tlUSUwlefMu2kDBhU9fcY9YhqMgMcsMYNkHygU0gMIZm2HDkJGxTM/BU03VLCM/8o\n\t\t\t\t\t\toJqJBqArueI2Crt/6emG2dT9KkxBhYb+mKiI4N8vK/XS6bCQHoAZTsh2fMCcjP/z\n\t\t\t\t\t\tmI4oGoitkoEEYh4tHf489XQXmCXil7parkOfYPiSbOscpTMnKw+e1E9otaoDakH1\n\t\t\t\t\t\tSgs81mRPAWBcWttIOSmS75a6mfooDeVNAE5S4iGuakKTw424ykb96QIDAQABo0Ew\n\t\t\t\t\t\tPzAeBgNVHREEFzAVghN1a2Ytc3ZjLmVkaW5hLmFjLnVrMB0GA1UdDgQWBBT4yzTF\n\t\t\t\t\t\td+G9wC0XOImSgaDBtORrbzANBgkqhkiG9w0BAQUFAAOCAQEAFsLiJAnNO6EQiXwx\n\t\t\t\t\t\thdKhH40h4veNxKL4bq3azVkH/YP7Ej8uQ89Ta+aR6xC+TDuvt2Baj3bmN5Dxejen\n\t\t\t\t\t\tr4I2/WP0eR6nH4r2vZ0cNKNDV2LBcjmxJhvcOM5151HzRDxNdw9nNHfR5kFreU2N\n\t\t\t\t\t\tee/3SL8B+EZrQCu9mKZSL1OwuQbm9I9tp7Aqp414UDG9ivZIorrkIA5cJplfOaR9\n\t\t\t\t\t\t/gIB1Eu9tAgJgofTwi9bzNde2kjOY410MZFfya1T7juPUJYx5WEJ0oHkJLbilx/W\n\t\t\t\t\t\t2UAEC+Ir/a8rk/IjmVn+uHAyFUJCizUMUiYXlaJSiV3ltexNYOMgj/llrYMKgIjS\n\t\t\t\t\t\t0HjUig=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.ukfederation.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://test.ukfederation.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.ukfederation.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://test.ukfederation.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://test.ukfederation.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://test.ukfederation.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "UK federation SAML 1.1/2.0 Test SP"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This test service provider allows you to see the attributes\n\t\t\t\tyour identity provider is releasing."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonTargetedID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonEntitlement",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonNickname",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonNickname",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonNickname",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.2",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonOrgDN",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonOrgDN",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonOrgDN",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonOrgUnitDN",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonOrgUnitDN",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonOrgUnitDN",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrimaryAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrimaryAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrimaryAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.5",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrimaryOrgUnitDN",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrimaryOrgUnitDN",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrimaryOrgUnitDN",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.8",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAssurance",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonAssurance",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAssurance",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.11",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:cn",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "description",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:description",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "description",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.13",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:displayName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "facsimileTelephoneNumber",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:facsimileTelephoneNumber",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "facsimileTelephoneNumber",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.23",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:givenName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "initials",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:initials",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "initials",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.43",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "l",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:l",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "l",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:mail",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "manager",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:manager",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "manager",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "o",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:o",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "o",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "ou",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:ou",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "ou",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.11",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "postalCode",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:postalCode",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "postalCode",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.17",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "postofficeBox",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:postOfficeBox",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "postOfficeBox",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.18",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "preferredLanguage",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:preferredLanguage",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "preferredLanguage",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.39",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "seeAlso",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:seeAlso",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "seeAlso",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.34",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:sn",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "st",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:st",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "st",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.8",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "street",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:street",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "street",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "telephoneNumber",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:telephoneNumber",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "telephoneNumber",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.20",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "title",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:title",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "title",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.12",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "carLicense",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:carLicense",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "carLicense",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "departmentNumber",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:departmentNumber",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "departmentNumber",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.2",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "employeeNumber",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:employeeNumber",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "employeeNumber",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.2.840.113556.1.2.610",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "employeeType",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:employeeType",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "employeeType",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.2.840.113556.1.2.613",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "businessCategory",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:businessCategory",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "businessCategory",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.15",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "physicalDeliveryOfficeName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:physicalDeliveryOfficeName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "physicalDeliveryOfficeName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.19",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cafe.uesb.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Leonardo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "leonardo@uesb.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.uesb.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDoDCCAogCAQAwDQYJKoZIhvcNAQEFBQAwgZUxDTALBgNVBAoTBFVFU0IxDzAN\nBgNVBAsTBlVJTkZPUjEjMCEGCSqGSIb3DQEJARYUbGVvbmFyZG9AdWVzYi5lZHUu\nYnIxHTAbBgNVBAcTFFZpdG9yaWEgZGEgQ29ucXVpc3RhMQswCQYDVQQIEwJCQTEL\nMAkGA1UEBhMCQlIxFTATBgNVBAMTDGNhZmUudWVzYi5icjAeFw0xMzA5MjAxODIz\nMjFaFw0xNjA5MTkxODIzMjFaMIGVMQ0wCwYDVQQKEwRVRVNCMQ8wDQYDVQQLEwZV\nSU5GT1IxIzAhBgkqhkiG9w0BCQEWFGxlb25hcmRvQHVlc2IuZWR1LmJyMR0wGwYD\nVQQHExRWaXRvcmlhIGRhIENvbnF1aXN0YTELMAkGA1UECBMCQkExCzAJBgNVBAYT\nAkJSMRUwEwYDVQQDEwxjYWZlLnVlc2IuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQDX5Qd680PTIaF0ZaDfpTfPIdAIp+ydojMhCd34S3idsFGwSKiJ\nNnfOn65iPMJFynxfQuqoo9wWnPAcS22fudOTuqdwf6NFl3sUM6fXh1UmQn2pyHxe\nUrJCwViQDV6ZplF0Uw3ABnYew3gZfUk/34NR8kkB2NdBs6jp7PD+nWn9fPLNd23p\nthdpumkzbkkzRM9SweDmFbbCwJcrn0JR2H1xtUlqT/Aq9Vb8BT3JD44mZypxKU4d\njI2/Kr9ZqaidQTcOqloiBoT1Az/fKmd1xXDDH8VFJvCGOSaXyWdEPR5kazOTLYyL\nQAq5KdWcpqU23keAklg0tw41kt1Wl1E+rb9fAgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBAE0BAVExopeUKLY/yXZhQ+rw6uYi+JY64Y3w2qp3o4TKqgN9j5ziZge76fWL\n4zMh7PO1TsZLnlWPcP4oP1OQNc4EiiiNGgLT4DfNU3NtpFFhVCKU5v3JUcw/ZHGj\nJ4diZ6Rb6Q2TCcBJV02Gz7p6U6nhXE0blVlyqWuZ4GZWg2PSTHgaG2JzHUHC+wzf\n7OaEuX3loT+wlm2Jq2ebDBlm+Yoth1pwE+puOluSk23P6aa71SkQjxb4pEv9sx8A\nW8Xj75F/MRL9CKazIOsUVwMSJnhDgZCDc/XxD29lBYLycFS5AJiCngmO+nYI61bv\nf+RldW1MxS+H81kufj7Rum74V4I="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.uesb.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.uesb.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.uesb.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.uesb.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.uesb.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.uesb.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.uesb.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.uesb.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uesb.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uesb.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UESB - Universidade Estadual do Sudoeste da Bahia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UESB - Universidade Estadual do Sudoeste da Bahia"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UESB - Universidade Estadual do Sudoeste da Bahia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UESB - Universidade Estadual do Sudoeste da Bahia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDoDCCAogCAQAwDQYJKoZIhvcNAQEFBQAwgZUxDTALBgNVBAoTBFVFU0IxDzAN\nBgNVBAsTBlVJTkZPUjEjMCEGCSqGSIb3DQEJARYUbGVvbmFyZG9AdWVzYi5lZHUu\nYnIxHTAbBgNVBAcTFFZpdG9yaWEgZGEgQ29ucXVpc3RhMQswCQYDVQQIEwJCQTEL\nMAkGA1UEBhMCQlIxFTATBgNVBAMTDGNhZmUudWVzYi5icjAeFw0xMzA5MjAxODIz\nMjFaFw0xNjA5MTkxODIzMjFaMIGVMQ0wCwYDVQQKEwRVRVNCMQ8wDQYDVQQLEwZV\nSU5GT1IxIzAhBgkqhkiG9w0BCQEWFGxlb25hcmRvQHVlc2IuZWR1LmJyMR0wGwYD\nVQQHExRWaXRvcmlhIGRhIENvbnF1aXN0YTELMAkGA1UECBMCQkExCzAJBgNVBAYT\nAkJSMRUwEwYDVQQDEwxjYWZlLnVlc2IuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQDX5Qd680PTIaF0ZaDfpTfPIdAIp+ydojMhCd34S3idsFGwSKiJ\nNnfOn65iPMJFynxfQuqoo9wWnPAcS22fudOTuqdwf6NFl3sUM6fXh1UmQn2pyHxe\nUrJCwViQDV6ZplF0Uw3ABnYew3gZfUk/34NR8kkB2NdBs6jp7PD+nWn9fPLNd23p\nthdpumkzbkkzRM9SweDmFbbCwJcrn0JR2H1xtUlqT/Aq9Vb8BT3JD44mZypxKU4d\njI2/Kr9ZqaidQTcOqloiBoT1Az/fKmd1xXDDH8VFJvCGOSaXyWdEPR5kazOTLYyL\nQAq5KdWcpqU23keAklg0tw41kt1Wl1E+rb9fAgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBAE0BAVExopeUKLY/yXZhQ+rw6uYi+JY64Y3w2qp3o4TKqgN9j5ziZge76fWL\n4zMh7PO1TsZLnlWPcP4oP1OQNc4EiiiNGgLT4DfNU3NtpFFhVCKU5v3JUcw/ZHGj\nJ4diZ6Rb6Q2TCcBJV02Gz7p6U6nhXE0blVlyqWuZ4GZWg2PSTHgaG2JzHUHC+wzf\n7OaEuX3loT+wlm2Jq2ebDBlm+Yoth1pwE+puOluSk23P6aa71SkQjxb4pEv9sx8A\nW8Xj75F/MRL9CKazIOsUVwMSJnhDgZCDc/XxD29lBYLycFS5AJiCngmO+nYI61bv\nf+RldW1MxS+H81kufj7Rum74V4I="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UESB - Universidade Estadual do Sudoeste da Bahia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UESB - Universidade Estadual do Sudoeste da Bahia"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uesb.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uesb.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UESB - Universidade Estadual do Sudoeste da Bahia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UESB - Universidade Estadual do Sudoeste da Bahia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://nyu.reclaimhosting.com",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tim@reclaimhosting.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim Owens"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jim@reclaimhosting.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jim Groom"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://nyu.reclaimhosting.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Reclaim Hosting, LLC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://reclaimhosting.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Reclaim Hosting, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hosting.nyu.edu/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://hosting.nyu.edu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hosting.nyu.edu/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://hosting.nyu.edu"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NYU Domains"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJAJPEuYz0OXIoMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFm55dS5yZWNsYWltaG9zdGluZy5jb20wHhcNMTYwMTA0MTMyNDIyWhcNMjYw\nMTAxMTMyNDIyWjAhMR8wHQYDVQQDExZueXUucmVjbGFpbWhvc3RpbmcuY29tMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvtLGxzYHTwRPHUIsQgwPa1n0\n1dAzDytRw1a4Bk3a8Gz7p82Jxr/2Sux1+ZPLD1ziAKbwDFdcb4RENMZWXmMPp5Xp\nDsSzMtWdrE1ZolwtEynzJ7uiAc3Vl0ztVVZVAUySIfsjNNdpXM94xja+XrNYiEEF\nL0NftuIQuI3uc1NOl1YIwsem+JZeoZbEYdf0farUqeHtDaVM3wk1NDfLPb2iOVaG\nsuAo334IZbPjp9GIy5dsmzNfSjXyesUvSHVGzI3gZzYJdde+V0LhXLjrRE8OWIjo\nGEDbLbaRllCTQBAc5zF2fRojNp43Yw5UJUNEgRXGwW95TV7MeSxt901L1d5kFQID\nAQABo0QwQjAhBgNVHREEGjAYghZueXUucmVjbGFpbWhvc3RpbmcuY29tMB0GA1Ud\nDgQWBBSRoHyH/9kV7fuCYCn2kHjXyW9lxjANBgkqhkiG9w0BAQUFAAOCAQEAd5Ge\nvHVXb8NCt4dp2m4Rny5PO3HCjWwS53b4/SC5Xp3D7Sxi35NKgJSVPasvrHfxiQjZ\n75NKFk97TyMrq4WzJfGKP6k316KZM5fxAUSV8Fyc5kRHCKjwJac6pf1LyX/SUu+n\n1AZeeKe/iM2dIZUMm+JeDsHq9QzER2fEiJILAaPYv0zfwMsybjpRSRNbAPjKDaHz\nTFZtretB5/VzPuQVXtW+vJFruW0d9E118qiALqOOzza6wSnRQaM0N3S2QJ0alEYC\naZk9fzZpu0dOU8vlpWhAra6IebMahNUamuaNfjAVcTQ8OdaEmhQyeZrrjIyu3mzx\n22R32vEVA6N+Z5b/8g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hosting.nyu.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://hosting.nyu.edu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hosting.nyu.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://hosting.nyu.edu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://hosting.nyu.edu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://hosting.nyu.edu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "NYU Domains"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-p12.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-p12.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;p12"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;p12"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-p12.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-p12.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQTCCAimgAwIBAgIJAJwfFHHm4QTAMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2xhZG9rMy1wMTIubGFkb2sudW11LnNlMB4XDTE1MDIwOTEwNDE0NloXDTI1\nMDIwNjEwNDE0NlowIjEgMB4GA1UEAxMXbGFkb2szLXAxMi5sYWRvay51bXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC1hH5bfM0hd5d2hD4Na6LP\nGBeBX337nRyUU0tJaLVQj2fZMygo2zV6fE9ht4dIEzUaS0u8C8HhY2ASHMVYYsb4\nE5L1Jx9fosv8L6tqoX+hL8QZQ2w2SCYGHjRaAEkmhdjMSTp9O3n3q5lFG8jA+unf\nSA9CDvL/R//Imq2oqNrf3cgbfifhD5XnOZRc0gj2THlq0E/fpqXK6XYOIc1ZO9dx\nr2tNw1Zu3zY+c1BbQ42gMa43O1L9S9szfQfJZC6cMa3C5DXHCidJ/sFJ5ITLmxur\nR6pteZI9vyHaIPC+zX4Ta5kn50rhqeITajNExyWo1fA5ebVlRlQ5Jl9L5l6scnMR\nAgMBAAGjejB4MFcGA1UdEQRQME6CF2xhZG9rMy1wMTIubGFkb2sudW11LnNlhjNo\ndHRwczovL2xhZG9rMy1wMTIubGFkb2sudW11LnNlL3N0dWRlbnQtZnJvbnRlbmQt\nc3AwHQYDVR0OBBYEFIl6Hqs8E9quQ9zh8x5nn5SzlqF8MA0GCSqGSIb3DQEBBQUA\nA4IBAQCFZ9SxV0u3FYj8PTzaDa6unPRH/0qzZ4LuD87Hmx87n4NL3XFu2e5ocgvf\nlHY3XEr23zWm0u7vZu2M9lD3No/y4wmFPxpv4uSt27EcLPbD8u1LA0q+xzO6/T5j\nNKnxy7NcK+a17PXnsp/XXzOfRtFqkPByitZIbD9KWkuDg6ri2gws1BPc/fHV9V1i\nDWuaLVpBYp5vMqIr5esITLLVNIwk0A68PZy05J87SEr7Gepyg1zyX4AYa52rqkY0\nXQHW0Eym6LKaJ2wLzF/Il9WlgBNOFr7nN2344wyG3cq8Qd1d/zWyms+sauuZxZz7\nuqxBQkCvnX33vrqLW5c3nz5GznAD"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-p12.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-p12.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://dirg.org.umu.se/sp.xml",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "H\u00f6rberg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dirg@umu.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hans"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dirg.org.umu.se/sp.xml",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ume\u00e5 univeristet, ITS - DIRG"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ume\u00e5 University, ITS - DIRG"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://dirg.org.umu.se/page/home"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ume\u00e5 University, ITS - DIRG"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ITS - DIRG unit external webpage."
                  }
                ],
                "logo": [
                  {
                    "text": "https://dirg.org.umu.se/static/dirg_green_fp.png",
                    "lang": "en",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DIRG web"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dirg.org.umu.se/disco",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICVzCCAcACCQCD0IEgR/GBozANBgkqhkiG9w0BAQUFADBwMQswCQYDVQQGEwJz\nZTELMAkGA1UECAwCQUMxDTALBgNVBAcMBFVtZWExDDAKBgNVBAoMA0lUUzEMMAoG\nA1UECwwDSVRTMQ0wCwYDVQQDDARESVJHMRowGAYJKoZIhvcNAQkBFgtkaXJnQHVt\ndS5zZTAeFw0xNDAyMDcxNDI3MDBaFw0xNTAyMDcxNDI3MDBaMHAxCzAJBgNVBAYT\nAnNlMQswCQYDVQQIDAJBQzENMAsGA1UEBwwEVW1lYTEMMAoGA1UECgwDSVRTMQww\nCgYDVQQLDANJVFMxDTALBgNVBAMMBERJUkcxGjAYBgkqhkiG9w0BCQEWC2RpcmdA\ndW11LnNlMIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQCbpaYV1RzKKYbWAJGQ\nszgiUgrP16ODFpNJloj1Tm5FIYUbcetCbwbPp3417mHObQS7rBvTm/ZJe2bbnenN\nl4qRZWZSwmXDvDeIinAxwkr4C/rK392TKfHMfej1hDL2IeCn5oY7Fl2DTjDTAjKd\n5KBaTqwIh0J3sJxUICQFpQ0rFwIDAQABMA0GCSqGSIb3DQEBBQUAA4GBAFhpGdSZ\nA6gAcjDA5Wqd0HTtpqkWqEbVKPtxI0pBnFy4J5CARk43R2yn1sHH/HRNTuTcZEmB\nxz6UWuCYykD4kDTwppQdXn4l3/RkA1NOLvSse3P3Db7JbK5EkjHRyWCRnhREloh9\n606LRX1Kc0uWKNEBRs6uN9VA9aiIHVHpRboU"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICVzCCAcACCQCD0IEgR/GBozANBgkqhkiG9w0BAQUFADBwMQswCQYDVQQGEwJz\nZTELMAkGA1UECAwCQUMxDTALBgNVBAcMBFVtZWExDDAKBgNVBAoMA0lUUzEMMAoG\nA1UECwwDSVRTMQ0wCwYDVQQDDARESVJHMRowGAYJKoZIhvcNAQkBFgtkaXJnQHVt\ndS5zZTAeFw0xNDAyMDcxNDI3MDBaFw0xNTAyMDcxNDI3MDBaMHAxCzAJBgNVBAYT\nAnNlMQswCQYDVQQIDAJBQzENMAsGA1UEBwwEVW1lYTEMMAoGA1UECgwDSVRTMQww\nCgYDVQQLDANJVFMxDTALBgNVBAMMBERJUkcxGjAYBgkqhkiG9w0BCQEWC2RpcmdA\ndW11LnNlMIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQCbpaYV1RzKKYbWAJGQ\nszgiUgrP16ODFpNJloj1Tm5FIYUbcetCbwbPp3417mHObQS7rBvTm/ZJe2bbnenN\nl4qRZWZSwmXDvDeIinAxwkr4C/rK392TKfHMfej1hDL2IeCn5oY7Fl2DTjDTAjKd\n5KBaTqwIh0J3sJxUICQFpQ0rFwIDAQABMA0GCSqGSIb3DQEBBQUAA4GBAFhpGdSZ\nA6gAcjDA5Wqd0HTtpqkWqEbVKPtxI0pBnFy4J5CARk43R2yn1sHH/HRNTuTcZEmB\nxz6UWuCYykD4kDTwppQdXn4l3/RkA1NOLvSse3P3Db7JbK5EkjHRyWCRnhREloh9\n606LRX1Kc0uWKNEBRs6uN9VA9aiIHVHpRboU"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dirg.org.umu.se/acsredirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dirg.org.umu.se/acspost",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idptest.brunel.ac.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sysweb@brunel.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Systems Web"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sysweb@brunel.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Systems Web"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idptest.brunel.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_instant": "2013-08-02T13:14:14Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVANgJSDgjyA0miJmS6WdosLWR8bo3MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB8xHTAbBgNVBAMTFGlkcHRlc3QuYnJ1bmVsLmFjLnVrMB4XDTEzMDUxMzA4\n\t\t\t\t\t\tNDEyM1oXDTMzMDUxMzA4NDEyM1owHzEdMBsGA1UEAxMUaWRwdGVzdC5icnVuZWwu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC9CGamVclmceIU\n\t\t\t\t\t\tIoWVlbz5FN6NBXoVLscwFQBBKH4E3vm6RLOtD7YP6yteWiPM0N7olXtHNg9OdpS5\n\t\t\t\t\t\twiRbDIH7W+sbQ4hw7uvwOZooL0XGyOhMtbUKwtJ/N2ziXDgRAW+r08o5fiiMzcxO\n\t\t\t\t\t\tYOvSggeea3relXuwRLMPhccKiUAcYX7fx7wdlFG2py5XJc4sQqnGgv6/7TsUhL1I\n\t\t\t\t\t\tWwqE/WX+gjF6Jj5Biwft2NAIdQXaC67NkhOO8tL2WtAfCWe6qYRQXSTPExj6QffB\n\t\t\t\t\t\tE57VQbcWcTPtTdI+eSAj5Ow1OO6HwRsTOR5Ur/zdxheMxe4FWlkX/TxawU95t+rC\n\t\t\t\t\t\t7My4IferAgMBAAGjZzBlMEQGA1UdEQQ9MDuCFGlkcHRlc3QuYnJ1bmVsLmFjLnVr\n\t\t\t\t\t\thiNodHRwczovL2lkcHRlc3QuYnJ1bmVsLmFjLnVrL2VudGl0eTAdBgNVHQ4EFgQU\n\t\t\t\t\t\tiLv8778GItQ8Ac1IH0WDtGQk3VswDQYJKoZIhvcNAQEFBQADggEBAE6S3UPN9N+e\n\t\t\t\t\t\tsp3BUOsJZ0wGXJak9UTAStjeVOOSPYjPGGrwHxhOWFXNtQfTWrNaPXtTnxxSl2QZ\n\t\t\t\t\t\t1LfgeGVhsEDKvL4x4cSqi+PkyLTiDf+BoTxThoFhA0FSdL4R06/L8qBdZGjUQyQy\n\t\t\t\t\t\tMkv6tJmG+JKLnS92lsz85icowAjvZYj3auwqTWlVIy+4GnNG83eaC64GZoR5ivj2\n\t\t\t\t\t\th+VvNQOmjY+C94nTzu1K+rlVIWPphqWSA93s3a10ryKWUngnIPDuxv1i/CHyerbu\n\t\t\t\t\t\tbmvYeuDZtLYLGxK6LdrBY2JUf4diIibARVq+AbGCakqOmEB6A00OU1kNWnHZ1s2F\n\t\t\t\t\t\tZxYoLjTTweY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brunel.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idptest.brunel.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idptest.brunel.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idptest.brunel.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idptest.brunel.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idptest.brunel.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idptest.brunel.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idptest.brunel.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idptest.brunel.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idptest.brunel.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idptest.brunel.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idptest.brunel.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brunel.ac.uk"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Brunel University test identity provider"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idptest.brunel.ac.uk/logo/80x60.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idptest.brunel.ac.uk/logo/16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Brunel University (Test)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVANgJSDgjyA0miJmS6WdosLWR8bo3MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB8xHTAbBgNVBAMTFGlkcHRlc3QuYnJ1bmVsLmFjLnVrMB4XDTEzMDUxMzA4\n\t\t\t\t\t\tNDEyM1oXDTMzMDUxMzA4NDEyM1owHzEdMBsGA1UEAxMUaWRwdGVzdC5icnVuZWwu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC9CGamVclmceIU\n\t\t\t\t\t\tIoWVlbz5FN6NBXoVLscwFQBBKH4E3vm6RLOtD7YP6yteWiPM0N7olXtHNg9OdpS5\n\t\t\t\t\t\twiRbDIH7W+sbQ4hw7uvwOZooL0XGyOhMtbUKwtJ/N2ziXDgRAW+r08o5fiiMzcxO\n\t\t\t\t\t\tYOvSggeea3relXuwRLMPhccKiUAcYX7fx7wdlFG2py5XJc4sQqnGgv6/7TsUhL1I\n\t\t\t\t\t\tWwqE/WX+gjF6Jj5Biwft2NAIdQXaC67NkhOO8tL2WtAfCWe6qYRQXSTPExj6QffB\n\t\t\t\t\t\tE57VQbcWcTPtTdI+eSAj5Ow1OO6HwRsTOR5Ur/zdxheMxe4FWlkX/TxawU95t+rC\n\t\t\t\t\t\t7My4IferAgMBAAGjZzBlMEQGA1UdEQQ9MDuCFGlkcHRlc3QuYnJ1bmVsLmFjLnVr\n\t\t\t\t\t\thiNodHRwczovL2lkcHRlc3QuYnJ1bmVsLmFjLnVrL2VudGl0eTAdBgNVHQ4EFgQU\n\t\t\t\t\t\tiLv8778GItQ8Ac1IH0WDtGQk3VswDQYJKoZIhvcNAQEFBQADggEBAE6S3UPN9N+e\n\t\t\t\t\t\tsp3BUOsJZ0wGXJak9UTAStjeVOOSPYjPGGrwHxhOWFXNtQfTWrNaPXtTnxxSl2QZ\n\t\t\t\t\t\t1LfgeGVhsEDKvL4x4cSqi+PkyLTiDf+BoTxThoFhA0FSdL4R06/L8qBdZGjUQyQy\n\t\t\t\t\t\tMkv6tJmG+JKLnS92lsz85icowAjvZYj3auwqTWlVIy+4GnNG83eaC64GZoR5ivj2\n\t\t\t\t\t\th+VvNQOmjY+C94nTzu1K+rlVIWPphqWSA93s3a10ryKWUngnIPDuxv1i/CHyerbu\n\t\t\t\t\t\tbmvYeuDZtLYLGxK6LdrBY2JUf4diIibARVq+AbGCakqOmEB6A00OU1kNWnHZ1s2F\n\t\t\t\t\t\tZxYoLjTTweY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Brunel University (Test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.brunel.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Brunel University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.lrb.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Larkin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:clarkin@lrb.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sowden"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:csowden@lrb.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.lrb.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-04-30T13:36:59Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "London Review of Books"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lrb.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LRB Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.lrb.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.lrb.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.lrb.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.lrb.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.lrb.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.lrb.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.lrb.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Online access to the London Review of Books archive"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.lrb.co.uk/shibboleth-sp/logo.png",
                    "height": "71",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "London Review of Books"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJANyqIs0OWWWhMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXd3dy5scmIuY28udWswHhcNMTMwNDEwMTUwODQ5WhcNMjMwNDA4MTUwODQ5\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw13d3cubHJiLmNvLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAu8m19a1SY54Kh43Uwe0g/Q2nJInoV7MhgrZ3afYRXzSnulOd\n\t\t\t\t\t\tXSv9AxWl0WqlzxVlAC9ak1AKJEFMkhyg0z7DPQHDmboixrQBP1jxvPxvq1EQ2B2G\n\t\t\t\t\t\tRwlQTNwxyOs4Ud10y/X5uZKBYKfwb7Xr6wJVug2Jk3g0m9Q/xOB5vFdytmVo0Htd\n\t\t\t\t\t\tX8JzDYiovHh8/01nw1zqRL9XYYfDqTzlIzkVzMpaXUtlEUySY+Pk/KP9LW612NLj\n\t\t\t\t\t\t0leIa6umDD3o1ZfhlTBcsMrzrVmGq8MZE4JAXM05DZ3hEZpXmr9xQ6vAx0U8kigg\n\t\t\t\t\t\tXWfw31ME2r/mfdySgRdPDEinr3OEe6oJsS8gDwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg13d3cubHJiLmNvLnVrMB0GA1UdDgQWBBQqFtNRW4fjzMcAqBf0Uofy4ZeW+TAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAW1hamIuAkBxhF/uQ4cpKvKy75st3aI/rmiFZcCFh\n\t\t\t\t\t\tYHK5SZUj5DIfreGZG02onq3/dA7Kj9rjiEIFXnBULpcNulp3DcpVKkoxkfnV180A\n\t\t\t\t\t\tZltn8jPSbrzNGpb536PMYa21yycxBxh0uR+IbznLqlVhQCmQI5/7HOAPihUvV/w5\n\t\t\t\t\t\tulQI3JKrLeE42xPVToBYWCk4SrfciKq06ZZG1s1WbYkf1uracUDpZZ8g2YkvQrdK\n\t\t\t\t\t\teGkLyLvQrBJ3Rfmx2ukVAk5y/ajluFz9DQrG/jc5H9J6/ql4BXhfXsAH+PiIxbzI\n\t\t\t\t\t\tKsYWHAVwkTwGO4W2Vf2JeTWKbVpWYsr7Ct32TqFFMS09FA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.lrb.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.lrb.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.lrb.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.lrb.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.lrb.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.lrb.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://nyainloggning.slu.se/shibboleth-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://nyainloggning.slu.se/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nyainloggning.slu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nyainloggning.slu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nyainloggning.slu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nyainloggning.slu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nyainloggning.slu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://nyainloggning.slu.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "nyainloggning.ad.slu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAPNvtwQGu5raMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF255YWlubG9nZ25pbmcuYWQuc2x1LnNlMB4XDTEwMDYwNzEzMDY0MFoXDTIw\nMDYwNDEzMDY0MFowIjEgMB4GA1UEAxMXbnlhaW5sb2dnbmluZy5hZC5zbHUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCrvkY2EP9gO6kh+rPYDHnO\nTOVOJfAF8EQpC963TUWQAY/EYwQ+5Boz9fgahLt2xcd8TUFxDefFTh1PPxLCQxqB\nVNBp27KlZujuESk2JOkvotU6sSJaGJKun2P5SeH+LbO3/hifJ9KkO2hBv1uhz1cV\n/64Hza2+EqjJmQ7vY5MmUH6NTydVUdM63DewsQokyBJSXwLFzCPoZQr+G3Gwd8GM\nDc4YbZUnwRv1wFSUP+0KF2UaYANTuDddj8T83FWSPmAL1qExZLGaULTNnjIrBA2c\nN2P0j8iAUpvWAQovdkIjzo+O2L0fhO85DCk2zVvOev4R00+ut6gL1WYjBEAc3gy1\nAgMBAAGjRTBDMCIGA1UdEQQbMBmCF255YWlubG9nZ25pbmcuYWQuc2x1LnNlMB0G\nA1UdDgQWBBSeAB6mREIQclJ7ntJqvwXYhc6BYzANBgkqhkiG9w0BAQUFAAOCAQEA\nXR17owAC8V1WxsMbjxmNrjXlcQxoQM8sSiCGkI6gM0yZRW4NEiiifC9LA2Ncj0p6\nlM3gS1rZw7Op/MjdgpIgguH6odezNCJNErzxy9+akiloUVrcbgXSgQ6YoPreZ5Ru\nXZzLGkuwQIl6iTcV4DsqdRR/Onnd5AIPS+kK7L7DaT32w1uMTa1Az4ZhpskGcAlw\noedluZRMipYG3KN1dTvzTZZ9adC7tzaURUQdyBivNg0XsENhOw8EQZirOssqDdgM\n1ojDx5WxuWm2qh9fdLSXiYDSn1nvy2LEyx8AJKz7WfJNcpCMQ8c0YuYN3Pz5Tqiy\nz20UtLAP2AqEvO2tJbiVIw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=nyainloggning.ad.slu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "nyainloggning.ad.slu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAPNvtwQGu5raMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF255YWlubG9nZ25pbmcuYWQuc2x1LnNlMB4XDTEwMDYwNzEzMDY0MFoXDTIw\nMDYwNDEzMDY0MFowIjEgMB4GA1UEAxMXbnlhaW5sb2dnbmluZy5hZC5zbHUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCrvkY2EP9gO6kh+rPYDHnO\nTOVOJfAF8EQpC963TUWQAY/EYwQ+5Boz9fgahLt2xcd8TUFxDefFTh1PPxLCQxqB\nVNBp27KlZujuESk2JOkvotU6sSJaGJKun2P5SeH+LbO3/hifJ9KkO2hBv1uhz1cV\n/64Hza2+EqjJmQ7vY5MmUH6NTydVUdM63DewsQokyBJSXwLFzCPoZQr+G3Gwd8GM\nDc4YbZUnwRv1wFSUP+0KF2UaYANTuDddj8T83FWSPmAL1qExZLGaULTNnjIrBA2c\nN2P0j8iAUpvWAQovdkIjzo+O2L0fhO85DCk2zVvOev4R00+ut6gL1WYjBEAc3gy1\nAgMBAAGjRTBDMCIGA1UdEQQbMBmCF255YWlubG9nZ25pbmcuYWQuc2x1LnNlMB0G\nA1UdDgQWBBSeAB6mREIQclJ7ntJqvwXYhc6BYzANBgkqhkiG9w0BAQUFAAOCAQEA\nXR17owAC8V1WxsMbjxmNrjXlcQxoQM8sSiCGkI6gM0yZRW4NEiiifC9LA2Ncj0p6\nlM3gS1rZw7Op/MjdgpIgguH6odezNCJNErzxy9+akiloUVrcbgXSgQ6YoPreZ5Ru\nXZzLGkuwQIl6iTcV4DsqdRR/Onnd5AIPS+kK7L7DaT32w1uMTa1Az4ZhpskGcAlw\noedluZRMipYG3KN1dTvzTZZ9adC7tzaURUQdyBivNg0XsENhOw8EQZirOssqDdgM\n1ojDx5WxuWm2qh9fdLSXiYDSn1nvy2LEyx8AJKz7WfJNcpCMQ8c0YuYN3Pz5Tqiy\nz20UtLAP2AqEvO2tJbiVIw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=nyainloggning.ad.slu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nyainloggning.slu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nyainloggning.slu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nyainloggning.slu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nyainloggning.slu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nyainloggning.slu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://nyainloggning.slu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nyainloggning.slu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://nyainloggning.slu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://nyainloggning.slu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://nyainloggning.slu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.bilborough.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.bilborough.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/bilborough.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/bilborough.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bilborough.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bilborough College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bilborough.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://gatekeeper2.tudelft.nl/openaselect/profiles/saml2/",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://gatekeeper2.tudelft.nl/openaselect/profiles/saml2/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-03-31T12:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/86d78b7ddf7216410b6724876ce1f75f",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Technische Universiteit Delft"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Technische Universiteit Delft"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/tudelft.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "120"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Technische Universiteit Delft (OpenASelect)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Delft University of Technology (OpenASelect)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Technische Universiteit Delft"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://tudelft.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Technische Universiteit Delft"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://scccd.instructure.com/saml2",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "http://scccd.instructure.com/saml2",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Instructure, Inc"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.instructure.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Instructure, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://scccd.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://scccd.test.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://scccd.beta.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.canvaslms.com/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://canvas.instructure.com/images/canvas/header_canvas_logo@2x.png",
                    "lang": "en",
                    "height": "220",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "220"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.canvaslms.com/policies/privacy-policy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "OEI - State Center Community College District- Canvas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE8TCCA9mgAwIBAgIJAOBms/PYWcPLMA0GCSqGSIb3DQEBCwUAMIGrMQswCQYD\nVQQGEwJVUzENMAsGA1UECBMEVXRhaDEXMBUGA1UEBxMOU2FsdCBMYWtlIENpdHkx\nGTAXBgNVBAoTEEluc3RydWN0dXJlLCBJbmMxEzARBgNVBAsTCk9wZXJhdGlvbnMx\nIDAeBgNVBAMTF0NhbnZhcyBTQU1MIENlcnRpZmljYXRlMSIwIAYJKoZIhvcNAQkB\nFhNvcHNAaW5zdHJ1Y3R1cmUuY29tMB4XDTE1MDQxNTAxMDAwMFoXDTE3MDQyMjAx\nMDAwMFowgasxCzAJBgNVBAYTAlVTMQ0wCwYDVQQIEwRVdGFoMRcwFQYDVQQHEw5T\nYWx0IExha2UgQ2l0eTEZMBcGA1UEChMQSW5zdHJ1Y3R1cmUsIEluYzETMBEGA1UE\nCxMKT3BlcmF0aW9uczEgMB4GA1UEAxMXQ2FudmFzIFNBTUwgQ2VydGlmaWNhdGUx\nIjAgBgkqhkiG9w0BCQEWE29wc0BpbnN0cnVjdHVyZS5jb20wggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDckDPQGWedlVGC2Z9fn1wNFmN+0IPNi6OSE1nM\nvoTWx2oZlQepaAu4zI5QqOfnV0rW2V1volpoJbu0WelH0DkGzdOEQdWJjAs3nRBf\ny0evxtpg0tK5kIvGsnN6YcD41YmkfWzvwbMf0cEq1Y0wCmymF6XzOUUE4zsi0nhP\nm2Z7WiuongDQdR01UsDN13YcpD/i1JXr3YtkNnJ/a1Kc9OXNycI8M5NVo5QQgdx/\nQ7zAmTk8p9E0ZRthdOQ/PBicWx39mNmBij5KpqCWlHu3NWdgcG8KXSv5atXU8Crd\nTRJ3aGIEN9vBYIHe8MHGCzs1QlRfJmXFMkeUSOTnJJx78rMDAgMBAAGjggEUMIIB\nEDAdBgNVHQ4EFgQUo0WWVlJ1SxZOs11L85ZAuZGyuzEwgeAGA1UdIwSB2DCB1YAU\no0WWVlJ1SxZOs11L85ZAuZGyuzGhgbGkga4wgasxCzAJBgNVBAYTAlVTMQ0wCwYD\nVQQIEwRVdGFoMRcwFQYDVQQHEw5TYWx0IExha2UgQ2l0eTEZMBcGA1UEChMQSW5z\ndHJ1Y3R1cmUsIEluYzETMBEGA1UECxMKT3BlcmF0aW9uczEgMB4GA1UEAxMXQ2Fu\ndmFzIFNBTUwgQ2VydGlmaWNhdGUxIjAgBgkqhkiG9w0BCQEWE29wc0BpbnN0cnVj\ndHVyZS5jb22CCQDgZrPz2FnDyzAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUA\nA4IBAQBV3EmmnzYqYQ5fXNZymG2WaspEW0NeFMhDXa3p3AMIQJbnnU14lR7bqIvf\n/bLW1YE0fw1kSzsw8VrkQp7k1U+kaYA3i5/FQBy2WtqUCVq2GXZA2gs5YD4nvJB/\nF57E//0kEhbATZH9+wJqDkqyIgsrSIlJjiXDth1BppGK8weboPtr9sWV24Ui0+ls\nw16XTsGlnRRO19g+gXKOZp5ApXkDrB+HwZQvZxiCuSgvJlcBzMdxVvWSL+vPtg8Y\nshIKzobIhaQ2MzXHLcxrDhW10YFPwDXh8Tfn5iU9ONsaJivuvVhtDYZD1ZzSoPpm\nq4vYqxxY/6rFJhrCtnlLepSaxlXM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://scccd.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://scccd.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://scccd.beta.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://scccd.beta.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://scccd.test.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://scccd.test.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "OEI - State Center Community College District- Canvas"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.stephensoncoll.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@stephensoncoll.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Spencer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jspencer@stephensoncoll.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jason"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Calcutt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:scalcutt@stephensoncoll.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.stephensoncoll.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-07-02T14:19:16Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.stephensoncoll.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.stephensoncoll.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stephensoncoll.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUjCCAjqgAwIBAgIIfT3WdIwbJEkwDQYJKoZIhvcNAQEFBQAwQDEbMBkGA1UE\n\t\t\t\t\t\tCgwSU3RlcGhlbnNvbiBDb2xsZWdlMSEwHwYDVQQDDBhpZHAuc3RlcGhlbnNvbmNv\n\t\t\t\t\t\tbGwuYWMudWswHhcNMTMxMTA1MTcyMzMyWhcNMjMxMTA1MTcyMzMyWjBAMRswGQYD\n\t\t\t\t\t\tVQQKDBJTdGVwaGVuc29uIENvbGxlZ2UxITAfBgNVBAMMGGlkcC5zdGVwaGVuc29u\n\t\t\t\t\t\tY29sbC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIO4Ktpx\n\t\t\t\t\t\tXh8JZ+nQ7NjRa9l1aJgmixDwwEeQXfYU8TGDFIy6L96RmVSzyZ8OHYooPknpwFYU\n\t\t\t\t\t\tOEgMBEy9NE4y5zhwmpEKIQpaRMMUw82nkv4jwzcyoCk0wbfuyv7UliX0+42xxsYm\n\t\t\t\t\t\tSTxBS5Td24F6piq4Sk7kD4uj2h/5GS8uskJ3tC7D67dNQrn0+xGtYZbT7h6bwqwO\n\t\t\t\t\t\t6dKaYUzsvxJpzqrHD+eI3xQOrD+QvFOGidUFhFLfoboyAtt5JEmAeMqgXeIYcfgg\n\t\t\t\t\t\tZnpoT/kh0erowh9DEJyNYmHtiTaJGLRqnEzIAV6bkfIF9k9xe6CjlCKG3qWSkZ3n\n\t\t\t\t\t\txhtd3Y6wME1NcJUCAwEAAaNQME4wHQYDVR0OBBYEFObgAHIlxiAG3In5EQoUwdKV\n\t\t\t\t\t\ttxojMB8GA1UdIwQYMBaAFObgAHIlxiAG3In5EQoUwdKVtxojMAwGA1UdEwQFMAMB\n\t\t\t\t\t\tAf8wDQYJKoZIhvcNAQEFBQADggEBADuhtxyErNqg72q0VFUOjLuzTQB9uvIR3KSJ\n\t\t\t\t\t\ts3C53FojjVc09TT4uWwZb2fr8IZ/1WmgynPcR2rivRuVpOTs6uRkwDScLR8I7Rdd\n\t\t\t\t\t\t7lrbO1jvQHAU0s9kTy0AP434DOv3jTiLe8doYnX+pKZgqVoQJ+Ey58Ew+DRdVY90\n\t\t\t\t\t\tQNu1y4EsCQWEUFETwdAideLi1B6xq3xVbyX+UVe23Y2r4tdKnzeZpEgrrldHTy24\n\t\t\t\t\t\tf0ULIm3qzXRm+c5J53XwQunZ8M8bdXu0kWoObJX95hqxbT5yRe8v3JQz7pogI6cj\n\t\t\t\t\t\tPBmeqvbMw2skz8O3eiRr/9AI2YZBzaRMpZ4QwgfHF/Owg5NONWo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Stephenson College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.stephensoncoll.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Stephenson College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://vho.aaf.edu.au/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "(07) 3138 2424"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smith"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:t.smith@aaf.edu.au"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Australian Access Federation"
          },
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Terry"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@aaf.edu.au"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Australian Access Federation"
          },
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAF"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Beddoes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:b.beddoes@aaf.edu.au"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Australian Access Federation"
          },
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bradley"
          }
        }
      ],
      "entity_id": "https://vho.aaf.edu.au/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aaf.edu.au"
              }
            ],
            "registration_instant": "2010-12-06T12:35:21Z",
            "registration_authority": "https://aaf.edu.au",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute": [
            {
              "friendly_name": "homeOrganizationType",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "homeOrganization",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "auEduPersonLegalName",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.27856.1.2.2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "auEduPersonSharedToken",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.27856.1.2.5",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "eduPersonPrimaryAffiliation",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.5",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "telephoneNumber",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:2.5.4.20",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "auEduPersonAffiliation",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.27856.1.2.1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "organizationalUnit",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:2.5.4.11",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "commonName",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:2.5.4.3",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "eduPersonAssurance",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.11",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "eduPersonTargetedID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "givenName",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:2.5.4.42",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "email",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:0.9.2342.19200300.100.1.3",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "eduPersonScopedAffiliation",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "displayName",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:2.16.840.1.113730.3.1.241",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "organizationName",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:2.5.4.10",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "eduPersonEntitlement",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "postalAddress",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:2.5.4.16",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "mobileNumber",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:0.9.2342.19200300.100.1.41",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "eduPersonAffiliation",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "eduPersonPrincipalName",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "surname",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:2.5.4.4",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJANmymmwJai/+MA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDnZoby5hYWYuZWR1LmF1MB4XDTE0MDgxNDA1MDI1OFoXDTM0MDgwOTA1MDI1\nOFowGTEXMBUGA1UEAxMOdmhvLmFhZi5lZHUuYXUwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQC+rU6AApNBp4f2e0oRp5D1xgRw/DbY/6bc1juqR3IQ3Exn\nmY1HCsJwjMSaoopLKn58LAxw23uvDg457wYlSXj8GStIeCOvRXjbLMLsrJiIDrHZ\nyCzgUet7seMibzIt89XVvcrck14QcAr+AshYZhzzcjxZNz9b5krrQJ4/wwAsDqAu\n73o7UnoUPiHyrGYF/kn/prIYJ852MZWndBompMbiT5F5762UfXp1TxsIAfJsPb1H\n+orkniPGP4bgfhBl9+DPoVH8yZXwVi8uXTwmfwiDduKqAVa+nmjsRfSGz4CP5dXq\ng6dPsV3wHe/G9eT56QjEgY0DXHmBAccDPp26/71NAgMBAAGjYzBhMEAGA1UdEQQ5\nMDeCDnZoby5hYWYuZWR1LmF1hiVodHRwczovL3Zoby5hYWYuZWR1LmF1L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBTXcHppI+pY/xeHFf+u3bwo9Z+3VzANBgkqhkiG\n9w0BAQUFAAOCAQEAGV7J5771fkI1LlTcvQmmgliEaWZaxVMWIx9ZjaXZQF4DuhD5\nyFq+L7b/2XJqtweclm8eLqWPZ8Fgjt/euwpssiBspE8YTqU1KK9QmGmNKBrV5jrR\nVqjFhrIoKIUYnm273r00sMkQ1RlsuWQOpeOIxdtVF03ePutS2nFMFYS5LSWATm4S\ndya+JvRuLxrfFiBKrO5Rjs4sv9buELCZ+rVVHXn6cXfmSviGuedRTIXNqOp81qNq\nQ7xGcAxovDCv5oRVo3yliESIPPT/41JjPymodvFNDP4SNJFhfGIWW9SVDXkq1fFH\nLlmjJm9hYPxJyxlhjchh/4tGprdMSlHa+v8xlw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=vho.aaf.edu.au"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "true",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "^([a-zA-Z0-9-]{1,63}\\.){0,2}vho\\.aaf\\.edu\\.au$"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vho.aaf.edu.au:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://vho.aaf.edu.au:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "attribute": [
            {
              "friendly_name": "homeOrganizationType",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "homeOrganization",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "auEduPersonLegalName",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.27856.1.2.2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "auEduPersonSharedToken",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.27856.1.2.5",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "eduPersonPrimaryAffiliation",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.5",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "telephoneNumber",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:2.5.4.20",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "auEduPersonAffiliation",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.27856.1.2.1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "organizationalUnit",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:2.5.4.11",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "commonName",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:2.5.4.3",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "eduPersonAssurance",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.11",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "eduPersonTargetedID",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "givenName",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:2.5.4.42",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "email",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:0.9.2342.19200300.100.1.3",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "eduPersonScopedAffiliation",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "displayName",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:2.16.840.1.113730.3.1.241",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "organizationName",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:2.5.4.10",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "eduPersonEntitlement",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "postalAddress",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:2.5.4.16",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "mobileNumber",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:0.9.2342.19200300.100.1.41",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "eduPersonAffiliation",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "eduPersonPrincipalName",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            },
            {
              "friendly_name": "surname",
              "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
              "name": "urn:oid:2.5.4.4",
              "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
            }
          ],
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vho.aaf.edu.au/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vho.aaf.edu.au/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vho.aaf.edu.au/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://vho.aaf.edu.au/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vho.aaf.edu.au/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "index": "2",
              "location": "https://vho.aaf.edu.au:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "is_default": "false"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "index": "1",
              "location": "https://vho.aaf.edu.au:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "is_default": "false"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Australian Access Federation Virtual Home Organization"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "AAF Virtual Home"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "true",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "^([a-zA-Z0-9-]{1,63}\\.){0,2}vho\\.aaf\\.edu\\.au$"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJANmymmwJai/+MA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDnZoby5hYWYuZWR1LmF1MB4XDTE0MDgxNDA1MDI1OFoXDTM0MDgwOTA1MDI1\nOFowGTEXMBUGA1UEAxMOdmhvLmFhZi5lZHUuYXUwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQC+rU6AApNBp4f2e0oRp5D1xgRw/DbY/6bc1juqR3IQ3Exn\nmY1HCsJwjMSaoopLKn58LAxw23uvDg457wYlSXj8GStIeCOvRXjbLMLsrJiIDrHZ\nyCzgUet7seMibzIt89XVvcrck14QcAr+AshYZhzzcjxZNz9b5krrQJ4/wwAsDqAu\n73o7UnoUPiHyrGYF/kn/prIYJ852MZWndBompMbiT5F5762UfXp1TxsIAfJsPb1H\n+orkniPGP4bgfhBl9+DPoVH8yZXwVi8uXTwmfwiDduKqAVa+nmjsRfSGz4CP5dXq\ng6dPsV3wHe/G9eT56QjEgY0DXHmBAccDPp26/71NAgMBAAGjYzBhMEAGA1UdEQQ5\nMDeCDnZoby5hYWYuZWR1LmF1hiVodHRwczovL3Zoby5hYWYuZWR1LmF1L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBTXcHppI+pY/xeHFf+u3bwo9Z+3VzANBgkqhkiG\n9w0BAQUFAAOCAQEAGV7J5771fkI1LlTcvQmmgliEaWZaxVMWIx9ZjaXZQF4DuhD5\nyFq+L7b/2XJqtweclm8eLqWPZ8Fgjt/euwpssiBspE8YTqU1KK9QmGmNKBrV5jrR\nVqjFhrIoKIUYnm273r00sMkQ1RlsuWQOpeOIxdtVF03ePutS2nFMFYS5LSWATm4S\ndya+JvRuLxrfFiBKrO5Rjs4sv9buELCZ+rVVHXn6cXfmSviGuedRTIXNqOp81qNq\nQ7xGcAxovDCv5oRVo3yliESIPPT/41JjPymodvFNDP4SNJFhfGIWW9SVDXkq1fFH\nLlmjJm9hYPxJyxlhjchh/4tGprdMSlHa+v8xlw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=vho.aaf.edu.au"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "AAF Virtual Home"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aaf.edu.au"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "vho.aaf.edu.au"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://liverpool.idm.oclc.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Support Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Support Desk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://liverpool.idm.oclc.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-11-10T09:48:41Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Liverpool Hosted EZProxy"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oclc.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "OCLC (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://login.liverpool.idm.oclc.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.liverpool.idm.oclc.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.liverpool.idm.oclc.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.liverpool.idm.oclc.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIECzCCAvOgAwIBAgIBAjANBgkqhkiG9w0BAQUFADBmMSEwHwYDVQQDFBgqLmxp\n\t\t\t\t\t\tdmVycG9vbC5pZG0ub2NsYy5vcmcxCzAJBgNVBAYTAlVLMQ0wCwYDVQQKEwRPQ0xD\n\t\t\t\t\t\tMSUwIwYJKoZIhvcNAQkBFhZjYXJsLnByZW50aWNlQG9jbGMub3JnMB4XDTE0MTEw\n\t\t\t\t\t\tNzE1NDczOFoXDTI0MTEwNjE1NDczOFowZjEhMB8GA1UEAxQYKi5saXZlcnBvb2wu\n\t\t\t\t\t\taWRtLm9jbGMub3JnMQswCQYDVQQGEwJVSzENMAsGA1UEChMET0NMQzElMCMGCSqG\n\t\t\t\t\t\tSIb3DQEJARYWY2FybC5wcmVudGljZUBvY2xjLm9yZzCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBAMR8ySKDcf3OT9U/DzD5phNed/00olgxko57IMTRvhek\n\t\t\t\t\t\tew/PJCROOTOWkgHi3jn5gdCJUmY52LA+R/1DS85h6jBvIHCfM9hPRzzJ+UhxaYx9\n\t\t\t\t\t\tV3UFpPXdwQRCkPT7IJ4t5PUH4Ejoxk/7kNfXIMvtZKbP/2RBK37BNF+jtRCuCo75\n\t\t\t\t\t\tOTlAuuiAmuuu87S11EBpGc2FAVg4dgFkP0kXkwB94+TH5xMhbaTAcj2EFvn0UYBX\n\t\t\t\t\t\tFHyTBMkrPhjKzQBIwvKsxLVZpshshn5By4ehV4i/aNxn+vtN2i2wI8WUaNGsfx6R\n\t\t\t\t\t\tlpA5mhFtgUzKoZdaP26TRcFNxMLwRcsz5H/Mn+UbNJkCAwEAAaOBwzCBwDAdBgNV\n\t\t\t\t\t\tHQ4EFgQUFjxA60obD8QtsXc1NHdND3Ye//gwgZAGA1UdIwSBiDCBhYAUFjxA60ob\n\t\t\t\t\t\tD8QtsXc1NHdND3Ye//ihaqRoMGYxITAfBgNVBAMUGCoubGl2ZXJwb29sLmlkbS5v\n\t\t\t\t\t\tY2xjLm9yZzELMAkGA1UEBhMCVUsxDTALBgNVBAoTBE9DTEMxJTAjBgkqhkiG9w0B\n\t\t\t\t\t\tCQEWFmNhcmwucHJlbnRpY2VAb2NsYy5vcmeCAQIwDAYDVR0TBAUwAwEB/zANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAC9bn5EoAcvFfD21a5RT/k9u4QS6FpLZGZiLiPx5w44eF\n\t\t\t\t\t\tfZPIr8WpKD/MuSnW4zaXLQUsQGxNbPvnh5gIqSMtqFErnD0HAggq+4ameyhrmL9U\n\t\t\t\t\t\tCKv4M31+DlYdYuryrrrVmKIEI3G/sNTsuChxYG3qh+frm8nI2tKqXYcoWyQAOO/e\n\t\t\t\t\t\tXx7jgG7X3RADR3aW9mxhwCslNWmlcXCg08Cb4xkpo1CnWp+gNSm1u3G0rIgqsqXR\n\t\t\t\t\t\tKvELFtpZjI6wYAmWgr2ERYbKlOGXCLNOTTD3u+t2WvIQsk9iWrDUGJuXP6rjadr2\n\t\t\t\t\t\tuGQq30Q0dqFgd1jyc5ZHakixPZMu9DniEhOkcW5oHA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://login.liverpool.idm.oclc.org/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://rastreador.ifba.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Reinaldo Fonseca"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "reinaldocosta@ifba.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://rastreador.ifba.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID4jCCAsoCAQAwDQYJKoZIhvcNAQEFBQAwgbYxKjAoBgNVBAoTIUlGQkEgLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkYSBCYWhpYTENMAsGA1UECxMEREdUSTEoMCYGCSqG\nSIb3DQEJARYZcmVpbmFsZG9jb3N0YUBpZmJhLmVkdS5icjERMA8GA1UEBxMIU2Fs\ndmFkb3IxDjAMBgNVBAgTBUJhaGlhMQswCQYDVQQGEwJCUjEfMB0GA1UEAxMWcmFz\ndHJlYWRvci5pZmJhLmVkdS5icjAeFw0xNDA1MjgxNDExMDVaFw0xNzA1MjcxNDEx\nMDVaMIG2MSowKAYDVQQKEyFJRkJBIC0gSW5zdGl0dXRvIEZlZGVyYWwgZGEgQmFo\naWExDTALBgNVBAsTBERHVEkxKDAmBgkqhkiG9w0BCQEWGXJlaW5hbGRvY29zdGFA\naWZiYS5lZHUuYnIxETAPBgNVBAcTCFNhbHZhZG9yMQ4wDAYDVQQIEwVCYWhpYTEL\nMAkGA1UEBhMCQlIxHzAdBgNVBAMTFnJhc3RyZWFkb3IuaWZiYS5lZHUuYnIwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC76YPzCeUvBq3XTaaWh0zo1nn6\n1lSxQFz/f0d9NOSjMe4aIxyMfCQHhWvoCldVgPzeVBHM8pioQsSyP8KZve1N0H5d\n6KWPZzk99oCPPkuGWVocYfEOHgodYqKD5aEU4gu8x+sggzZO0sCFlrqCbI26dhEx\nWmBLPy7bu0iownsyQE4UKeYWMBDI9Zmpq8LAIkzlLcs6RPkCqeC5Fl0JY1rmOYqd\n1/dr2oZapOQApH9En6lxfCBm4lo/BWKYJXnJ48GgpxsmaiUZ5A/2ORM7Ts0cJ8Fa\nFOi3KP1izvNxheJRS5i/H9dzPtrpbAz5cvpj36eLPNvLf038tNgRSTpKBCe5AgMB\nAAEwDQYJKoZIhvcNAQEFBQADggEBALAgWE0GCvUpvnMtQD1Jht1dNdGX+1MlVt2k\n9Vq2Z6qlQbidL2aP2nsg8wvGCnoJbH3ChV8URBf0nSxjo070sjoPd24++a8+FZ66\nfxopAvdKKImq6VnSQIXL2fUFtIld/vGGnbPj/IKdlKCvhNNziDBkhnc+N5bM9qnS\nhjssLnLT/qVvMxplYjAB4fCD+h83bAPR2b9oFjduMP9LQ4c0/EMD/2HNmvomB4mM\nFtuj6MoBNtSICbkYC4Kq9a/J4z4huIrz69ZxKnayVTztrnRJCUPaoOecIpXL/r/g\nNN2zz1zPr1Dc/+gDsijnBBws0KDp9946d4alZG05drL11LjY9bk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://rastreador.ifba.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://rastreador.ifba.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://rastreador.ifba.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://rastreador.ifba.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://rastreador.ifba.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://rastreador.ifba.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://rastreador.ifba.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://rastreador.ifba.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifba.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifba.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFBA - Instituto Federal da Bahia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFBA - Instituto Federal da Bahia"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFBA - Instituto Federal da Bahia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFBA - Instituto Federal da Bahia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID4jCCAsoCAQAwDQYJKoZIhvcNAQEFBQAwgbYxKjAoBgNVBAoTIUlGQkEgLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkYSBCYWhpYTENMAsGA1UECxMEREdUSTEoMCYGCSqG\nSIb3DQEJARYZcmVpbmFsZG9jb3N0YUBpZmJhLmVkdS5icjERMA8GA1UEBxMIU2Fs\ndmFkb3IxDjAMBgNVBAgTBUJhaGlhMQswCQYDVQQGEwJCUjEfMB0GA1UEAxMWcmFz\ndHJlYWRvci5pZmJhLmVkdS5icjAeFw0xNDA1MjgxNDExMDVaFw0xNzA1MjcxNDEx\nMDVaMIG2MSowKAYDVQQKEyFJRkJBIC0gSW5zdGl0dXRvIEZlZGVyYWwgZGEgQmFo\naWExDTALBgNVBAsTBERHVEkxKDAmBgkqhkiG9w0BCQEWGXJlaW5hbGRvY29zdGFA\naWZiYS5lZHUuYnIxETAPBgNVBAcTCFNhbHZhZG9yMQ4wDAYDVQQIEwVCYWhpYTEL\nMAkGA1UEBhMCQlIxHzAdBgNVBAMTFnJhc3RyZWFkb3IuaWZiYS5lZHUuYnIwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC76YPzCeUvBq3XTaaWh0zo1nn6\n1lSxQFz/f0d9NOSjMe4aIxyMfCQHhWvoCldVgPzeVBHM8pioQsSyP8KZve1N0H5d\n6KWPZzk99oCPPkuGWVocYfEOHgodYqKD5aEU4gu8x+sggzZO0sCFlrqCbI26dhEx\nWmBLPy7bu0iownsyQE4UKeYWMBDI9Zmpq8LAIkzlLcs6RPkCqeC5Fl0JY1rmOYqd\n1/dr2oZapOQApH9En6lxfCBm4lo/BWKYJXnJ48GgpxsmaiUZ5A/2ORM7Ts0cJ8Fa\nFOi3KP1izvNxheJRS5i/H9dzPtrpbAz5cvpj36eLPNvLf038tNgRSTpKBCe5AgMB\nAAEwDQYJKoZIhvcNAQEFBQADggEBALAgWE0GCvUpvnMtQD1Jht1dNdGX+1MlVt2k\n9Vq2Z6qlQbidL2aP2nsg8wvGCnoJbH3ChV8URBf0nSxjo070sjoPd24++a8+FZ66\nfxopAvdKKImq6VnSQIXL2fUFtIld/vGGnbPj/IKdlKCvhNNziDBkhnc+N5bM9qnS\nhjssLnLT/qVvMxplYjAB4fCD+h83bAPR2b9oFjduMP9LQ4c0/EMD/2HNmvomB4mM\nFtuj6MoBNtSICbkYC4Kq9a/J4z4huIrz69ZxKnayVTztrnRJCUPaoOecIpXL/r/g\nNN2zz1zPr1Dc/+gDsijnBBws0KDp9946d4alZG05drL11LjY9bk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFBA - Instituto Federal da Bahia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFBA - Instituto Federal da Bahia"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifba.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifba.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFBA - Instituto Federal da Bahia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFBA - Instituto Federal da Bahia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.aai.um.si/idp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Golob"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:izidor.golob@uni-mb.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Izidor"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:skrbnik@um.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ropo\u0161a"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:gorazd.roposa@um.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gorazd"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rebolj"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:danijel.rebolj@um.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Danijel"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Brezovnik"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:janez.brezovnik@um.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Janez"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bregant"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:albin.bregant@um.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Albin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ropo\u0161a"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:gorazd.roposa@um.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gorazd"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Golob"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:izidor.golob@um.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Izidor"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Anorga Irigoyen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:eneko.anorga@um.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Eneko"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.aai.um.si/idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_general.pdf"
              },
              {
                "lang": "sl",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_splosni_pogoji.pdf"
              }
            ],
            "registration_instant": "2015-10-29T16:10:11Z",
            "registration_authority": "http://aai.arnes.si",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.aai.um.si/idp/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.aai.um.si/idp/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "um.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "guest.um.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "student.um.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "u-m.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "guest.u-m.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "student.u-m.si"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.um.si"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.um.si"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for organization University of Maribor"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ponudnik identitet organizacije Univerza v Mariboru"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "300",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "300"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Maribor"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Univerza v Mariboru"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Univerza v Mariboru"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Univerza v Mariboru"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.um.si"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.um.si"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Univerza v Mariboru"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Univerza v Mariboru"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://gateway.capella.edu/FIM/sps/capella_saml2_idp/saml20",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Angie.Shand@capella.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Angie Shand"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://gateway.capella.edu/FIM/sps/capella_saml2_idp/saml20",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gateway.capella.edu/FIM/sps/capella_saml2_idp/saml20/login",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://gateway.capella.edu/FIM/sps/capella_saml2_idp/saml20/login",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDajCCAlKgAwIBAgIET7QbxjANBgkqhkiG9w0BAQQFADB3MQswCQYDVQQGEwJVUzESMBAGA1UE\nCBMJTWlubmVzb3RhMRQwEgYDVQQHEwtNaW5uZWFwb2xpczEbMBkGA1UEChMSQ2FwZWxsYSBVbml2\nZXJzaXR5MQswCQYDVQQLEwJJVDEUMBIGA1UEAxMLY2FwZWxsYS1pZHAwHhcNMTIwNTE2MjEyNzM0\nWhcNMjIwNTE0MjEyNzM0WjB3MQswCQYDVQQGEwJVUzESMBAGA1UECBMJTWlubmVzb3RhMRQwEgYD\nVQQHEwtNaW5uZWFwb2xpczEbMBkGA1UEChMSQ2FwZWxsYSBVbml2ZXJzaXR5MQswCQYDVQQLEwJJ\nVDEUMBIGA1UEAxMLY2FwZWxsYS1pZHAwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDh\nHG8seF+2p1nfpLIl25JwFu9/l4Qkkodvn6dR9FKdqrbG4YzRrFL0eZX3GjiXxdO4EvP9tyZcnWo7\ntcQETdBBG+WdKhF8/ufDjlh8xVUnhTywdEBM3TwpUMQrl3kpA0XDV2PL+pMY4wUK9ZWOHXugfITa\nuYZWgF+oXKnlr4FRx198YV2mpFIx6Cp6eD6F3IdDWpd/hk87NSPspilsmwk/8QdniGyCYC0HwWeq\nw6Frddt85g483icKe/uYS0Br13mC3idsjih87SGKTnsLZomdCAhvkGvqzHsqhDyZG0UkcL4CrTGK\nyxk/K1TAP6bHpoDnHQqf72PIBC+GjeXfrMNDAgMBAAEwDQYJKoZIhvcNAQEEBQADggEBAGuTQIli\nPaReWGl8X37s2eF14tiChzoQ4VvWKGUCMi9sFmnXbVev0tbwgfINiTyLV1yBm6ksDn7zGR/knBYn\nC5gPAQfaQ9KxZ0vGkO/cd0r5XRF82GFcyFbU9e7B+IMTnplFjMBecy9O/L1GuptEkqbLlSy6I1iM\n1G2kOdU+BPDc8BAS2DThMhUd4hGh1XJo8eGrHjUxdvuA9xGbYLKWEaREJw2gXKBBmhs0RVx0oKR+\n8KhkknImHBoobn9fC6X2NbCbq2fFl7ToETDtOHyOfea/GjhqBLjIGdML/yslGrwX4AmSrwyclk4e\nHh6Nd35KRm7+gqZhZXpHBm3kbX+mqUs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "capella.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Capella University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Capella University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.capella.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Capella University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.upay.co.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cachia"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dean.cachia@uniware.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dean"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Moore"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Craig.Moore@uniware.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Craig"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.upay.co.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-05-29T15:41:57Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Uniware Systems Limited: Upay Cashless Payments"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uniware.co.uk/cashless-payments"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Uniware Systems Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.upay.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.upay.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.upay.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.upay.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.upay.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.upay.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.upay.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Upay online payment processing and cashless account management."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.upay.co.uk/images/upay.jpg",
                    "height": "55",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "218"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Upay"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJAPuCQS/zC4R2MA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\n\t\t\t\t\tBAMTFnUwMTU4MjQuY2FzaGxlc3MubG9jYWwwHhcNMTIwNTI4MTQwMDI3WhcNMjIw\n\t\t\t\t\tNTI2MTQwMDI3WjAhMR8wHQYDVQQDExZ1MDE1ODI0LmNhc2hsZXNzLmxvY2FsMIIB\n\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAylulP1Jro85baAfyhsYZlfMP\n\t\t\t\t\tPZWBKbntkMX59cZHY9GdQxJvxOWaew7PP5vMPbXlntPoLRo07E086jOmYZwsR/YF\n\t\t\t\t\tHnXX/JDnGoUaNPxEjllzsIaSkrC3NTN1yYhUuRWDZ4iXHfK9MXjfsZPi07dLY84E\n\t\t\t\t\tBLTOS7Y/AWs0gDM428GbWAPVZUitiNxeYVM4/AoflNAwdCYbzFtObgiayUNJ5Lny\n\t\t\t\t\tacR3i4yGTrfQnlvk8CwUtYSHFMv3mwoff3Mwqi4s+6gl0KExm/HdokJQQ2JrZsdC\n\t\t\t\t\tCxr74jbQ63dTY0fa2LT/Iu1Il70zDtEKfjs8p9RCWF0jGHiYXTalW1MXqjltbQID\n\t\t\t\t\tAQABo0QwQjAhBgNVHREEGjAYghZ1MDE1ODI0LmNhc2hsZXNzLmxvY2FsMB0GA1Ud\n\t\t\t\t\tDgQWBBTfgLOw2BB/94hVVe6sGztOy8FtZzANBgkqhkiG9w0BAQUFAAOCAQEAWxDq\n\t\t\t\t\tU9phfn4hdENxWAPa+WkEtl9K5R/fabWcKYseolrkgLimEBHwrlsnvwG1+N3KUvxm\n\t\t\t\t\tOAQ4mwzAMdzR5BT3T2nECeSPuIjYHhYDMHT3NQo0EPugBKRiHHCbGtbq1koVhker\n\t\t\t\t\tu1D7q7vdwrpuafZOaBKxN6J33hOVDdkiCDwMvkgyiBDpe5L8KleiCMpnF2mMobxF\n\t\t\t\t\tR1+JIciWhw8MKc2WfekC/yXPzAHvJen7/xbCk6mn03m65aUhQ/mS5swiULmmnkpk\n\t\t\t\t\t0eEFK2StndDnHHteY0pFIbFv0wX7/PzIN9HHmLMd2vMhX9LOpMX5j8J14VB9HVm+\n\t\t\t\t\tXXxEezyYkBQIe2xJxg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.upay.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.upay.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.upay.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.upay.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.upay.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.upay.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-15.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-15.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-15.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-15.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-15.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-15.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-15.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-15.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-15.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;15"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;15"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-15.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-15.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJAKy7rna6TjX/MA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0xNS5sYWRvay51bXUuc2UwHhcNMTQwOTAxMTQ0NTIyWhcNMjQw\nODI5MTQ0NTIyWjAhMR8wHQYDVQQDExZsYWRvazMtMTUubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqW+HsYtZNGevLrOmDq/z0UZW\nb4BPmQAWTffcTyv3yNLan3D4kCajY3jwi7Sufj+E3TPbKFd0d8sItPpGed6Kz3aq\n031Af6HJJdQrzkHF58q0xgbuXI+iv9fWH9+GHsEXR8+18wK5tZZD50nVeq+hWgNB\nK8w7OyfBgRFv3M+uIjs8N2rpI7cYuK3cfQyKJ5euLGG7FiOKL+tjyivkau19boCT\nbS/8UzFzkGIFPlmR1qHASnY29kPh0zfgHi8p/xzk0Dajavzelx5m9CTUTh9PRbMs\njMFu9K+uQC56DbyvIx5EmijreaFjGFkCqdsdxScvphtVXhtQBkt1PDF7V3dq7QID\nAQABo2swaTBIBgNVHREEQTA/ghZsYWRvazMtMTUubGFkb2sudW11LnNlhiVodHRw\nczovL2xhZG9rMy0xNS5sYWRvay51bXUuc2UvZ3VpLXNwMB0GA1UdDgQWBBRMJNLN\n4Uhk/3++FnALBdpyKlYBIjANBgkqhkiG9w0BAQUFAAOCAQEAl5Hl6PM7y4i4WbQx\niqEPYWqbJNCphWcgmb1cWtfCzTVeZK+drUbAj90oVrvlJJ/Az/WkcmXx965t7u/7\nL3CLNdPpyjh76QeQeh8Mwj4Lrw4n5OUnjgBj5yzDGCJtjIM6bqxKeOtQi2TAlMX9\n8bLSRozoOFEDiDQO4FM5bqDjUZIV7G1NXDif9Anv67zNlOs1N3T8DAqUdo5zLlL/\niSw/m9WxAcAVbw/VC7p0eR6Cbf8xlIbznCGwXzCDQGSAJiuDkvJ8Vv0f0sOEpP7R\nJvDZsW/4WG/6yjj9c/zSH/9Bs/6tQ5cIARH9IU+mQkB3UDdZ9NLqGRU77aHeBsDx\n7TQbWQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-15.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-15.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-15.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-15.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-15.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-15.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-15.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-15.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-15.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-15.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://incommon.slb.com/simplesaml/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "hnguyen39@slb.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Huy Nguyen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "schmid1@slb.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brad Schmid"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "chinwala@slb.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ali Chinwala"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://incommon.slb.com/simplesaml/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Schlumberger"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.slb.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Schlumberger"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://incommon.slb.com/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Schlumberger will leverage Simplesamlphp on Incommon.slb.com to provide service to trusted Identity providers"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Schlumberger Federated Resources"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIElTCCA32gAwIBAgIJAJcc5Hf2fo6oMA0GCSqGSIb3DQEBCwUAMIGNMQswCQYD\nVQQGEwJVUzELMAkGA1UECBMCVFgxEDAOBgNVBAcTB0hvdXN0b24xFTATBgNVBAoT\nDFNjaGx1bWJlcmdlcjELMAkGA1UECxMCSVQxGTAXBgNVBAMTEFRva2VuIEVuY3J5\ncHRpb24xIDAeBgkqhkiG9w0BCQEWEWhuZ3V5ZW4zOUBzbGIuY29tMB4XDTE2MDIx\nNzE5MzA1N1oXDTI2MDIxNDE5MzA1N1owgY0xCzAJBgNVBAYTAlVTMQswCQYDVQQI\nEwJUWDEQMA4GA1UEBxMHSG91c3RvbjEVMBMGA1UEChMMU2NobHVtYmVyZ2VyMQsw\nCQYDVQQLEwJJVDEZMBcGA1UEAxMQVG9rZW4gRW5jcnlwdGlvbjEgMB4GCSqGSIb3\nDQEJARYRaG5ndXllbjM5QHNsYi5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQDtzGOnikF9uLTQxoeVWVhPcpZ9egESh+GAdz492CzZiEzmNhEHeni/\nHHOpu6RjAZwzF3PBpPgyiuiLps6ajqq4vpZGVjSS+7uJecQHoNN5lG3T4oTZeBY4\nU3gfdyal6XDG0RBUU97QNs4ANNc1r5Td2HW2X4aj2p3gtVEFfN/oljF8DFbP1xAk\n+vdpqEAEn9GmdA8R40ytN2aeKsXE3aroX4WY4gU1PBwpKeJDsHZKzgmeXZ3gcAZ+\nOa0QNB9YPoUUEL3BS6vGcdNQ+jBCSTptJZDMhbGXK5A7d6imiEs9FiK+5Wyilf8e\nNUK/D2d7jm1qmOUqmHxLW1cFhdgmXCpNAgMBAAGjgfUwgfIwHQYDVR0OBBYEFItx\nke5IH0z3PmdDyCRTOCfUEj2PMIHCBgNVHSMEgbowgbeAFItxke5IH0z3PmdDyCRT\nOCfUEj2PoYGTpIGQMIGNMQswCQYDVQQGEwJVUzELMAkGA1UECBMCVFgxEDAOBgNV\nBAcTB0hvdXN0b24xFTATBgNVBAoTDFNjaGx1bWJlcmdlcjELMAkGA1UECxMCSVQx\nGTAXBgNVBAMTEFRva2VuIEVuY3J5cHRpb24xIDAeBgkqhkiG9w0BCQEWEWhuZ3V5\nZW4zOUBzbGIuY29tggkAlxzkd/Z+jqgwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0B\nAQsFAAOCAQEAMrXRxwRJeQVbGYzrEHO6MFzsFMOoAetjljrSBf2kq2sT09TgnXnD\nut03rfgnpcu3A1oEaC+ULyN5PsY7rloocdKeYQVpG3ej7Ri6LLByEgyImAuC9Ti+\n6PlKonoGPzFtVfWtFBvYcPuzn0xOei5BNo5xplmDCOdiUr7iQ5dONFbuauCBJOg5\nMLHo+cYNfyUHKRh9N2hJ3u5vRfYSMWZwjPGpFPTUipK4DrCk8daUfN1wN4xpCFv0\nWT4vmL/TsVbWVVJPkvUyqhYEMO7REsp4W7nz1P2UEjVHQOZwyTJvy5Kdudlspxch\naD3z+32MqMLcKRqOhSCStLCAyZIqdMJEfA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://incommon.slb.com/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://incommon.slb.com/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://incommon.slb.com/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Schlumberger Federated Resources"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Schlumberger will leverage Simplesamlphp on Incommon.slb.com to provide service to trusted Identity providers"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "o",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.rediris.es/sir/upvidp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sir@rediris.es"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SIR helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.rediris.es/sir/upvidp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.rediris.es/sir/edugain/SIR_MRPS.pdf"
              }
            ],
            "registration_instant": "2012-10-09T13:08:24Z",
            "registration_authority": "http://www.rediris.es/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "response_location": "http://sir.rediris.es/upv/saml2/idp/SingleLogoutService.php",
              "location": "http://sir.rediris.es/upv/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "http://sir.rediris.es/upv/shib13/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "http://sir.rediris.es/upv/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Identity Provider of Universitat Polit\u00e8cnica de Val\u00e8ncia"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "El proveedor de identidad de la Universitat Polit\u00e8cnica de Val\u00e8ncia"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UPV - Universitat Polit\u00e8cnica de Val\u00e8ncia"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UPV - Universitat Polit\u00e8cnica de Val\u00e8ncia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "upv.es"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEeTCCA2GgAwIBAgIQCP9faAGj247/+QVzgpX08zANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDcwMTAwMDAwMFoXDTE2MDYzMDIzNTk1OVowRDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMR8wHQYDVQQDExZzYW1saWRwLnNp\nci5yZWRpcmlzLmVzMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA5tO6\ntYAdozpFMDwS7QH1qm7eECkY05lG1sp14vcVOdyN0mAf8oai+M8dCQ5iyMxD/RaG\noSmhXfHUvJ+0x8Cp/NHYbKr0cXskANcYTI0JFMFypn9Uac62CGxUYZRhHQ/2LxiE\nvzNgKrm2JiXCvOQbWrbg0sZDEsONv2G1Ln3fvOLiSiO1AjWLvOeYFPNgkNy5dxxt\n7ms7mZ0bFth6Cj38BBL0I1RebVnMgAKZWSgICUXDx35nkB+iLtidIykBgz92ZQ5h\nUrVNndP5+lraoMRuIewESSFt+LBYVeUZFTBGlupiUZ/bi7rhtIuhMM8ahaKIstbu\nIgfQBHPqRkkiiKOJawIDAQABo4IBczCCAW8wHwYDVR0jBBgwFoAUDL2TaAzz3quj\nSWsrN1dH6pDjue0wHQYDVR0OBBYEFARoBLDWcsveEZQhaMVIR9mmJkUkMA4GA1Ud\nDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggr\nBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNV\nHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNT\nTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQu\ndGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRw\nOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAhBgNVHREEGjAYghZzYW1saWRwLnNpci5y\nZWRpcmlzLmVzMA0GCSqGSIb3DQEBBQUAA4IBAQB0gmr232YgpUC4HkwAHXaH91Zx\n8ZrwiEc8c4jGLh5VsaO0OqMfUEIXMuqZ+P9JNWVwlc6VLtmsypqTuqb9a06DS88q\n2o5sAUpbXZwhArhQs1bQnu5HJ6S84Ajn+NfMOyaO7NF8Colq/9lf3DihkT0jlD7i\nPHPMw2zauvtR/WPwdPszgfIOV/vkJ0rq9AjOXxSX7V2jpkxISGW/m93iahwXEoVF\nc8VXQhNjEfcm6uawmISjsyp6ta/U3e/8GJka2csDrF/bfipMBDSdWcLMscpYO8cb\nDC0L6vehZJ+lPz3wPH6YJmlstICZUdJIgDV3TUhmji6NNKa4p6by34QdYcDH"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UPV - Universitat Polit\u00e8cnica de Val\u00e8ncia"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UPV - Universitat Polit\u00e8cnica de Val\u00e8ncia"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rediris.es/index.php.en"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rediris.es/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UPV"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UPV"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-p02.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-p02.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p02.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p02.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p02.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p02.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p02.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-p02.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-p02.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;p02"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;p02"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-p02.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-p02.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIJAKRkiwQKZbYOMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2xhZG9rMy1wMDIubGFkb2sudW11LnNlMB4XDTE0MDEyNDEzNTMwMFoXDTI0\nMDEyMjEzNTMwMFowIjEgMB4GA1UEAxMXbGFkb2szLXAwMi5sYWRvay51bXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDmyoAgpEldOYRq+j0YapBf\nSjUqgG1ZntCmd9uxH3dkluGCU4S43LfcH+jXnmNZJXB+i5J9zvY//RV0L+WFgMBJ\ns6OtIbUMsZK8aHwYZkRUf6PAld55u8KRCFIZ6TohSWDvY973xOai7FVMUUgYlrW4\nMLNjFcVmyxD4PBLVrrcEvpeCeTdjdhgrx8ZeeNcx7Oqm1NFriK09IHtflLGH2uXU\nFECOw2O3pwIdYPjFsfDE1AkdVTIw2inWz2v9pvkoUZ5mTZ0FQknMSOWsF1kdS+GJ\nIdUclOqIZNBTxIKt32IF/RuG+NYvC+b/XByrxqfwqAVpAE8HKGBPaUh8VwSw+4IP\nAgMBAAGjbTBrMEoGA1UdEQRDMEGCF2xhZG9rMy1wMDIubGFkb2sudW11LnNlhiZo\ndHRwczovL2xhZG9rMy1wMDIubGFkb2sudW11LnNlL2d1aS1zcDAdBgNVHQ4EFgQU\nGEUPdpozdCaj4J8yThk1tsKaFDkwDQYJKoZIhvcNAQEFBQADggEBAFoOR0o5rHGf\neR5X2KVVm37DCQ7nBkVJBsOCf38WMWF2neCvuZYr4yuKroE0jH584pDmqtcvgAPg\n+e1KDi3oD0/q+P9T9riyrBnIlYhGXsK5DEEyCisxL4rZWu9MnFtSVKrXWvRGvtQ/\nSSobMBbwCNycPpksjdpspFBaEZ8s+uen/mniWdSUo/aqmYMC+kbiNNneywxz3Jhn\nr7D2z+aDZQYktAAo5fSdst683jHq1b2OW3gZFlO07nXslNS0eGQNyBYLfxlhtlV8\nAl5BqP8qWS5p/VYAytgFhDBZuYxOviJGP5bLFh1unkvw2AK6nO+rLrdURyYtZ8Zm\n10F05Rsroms="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-p02.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p02.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p02.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p02.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p02.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p02.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p02.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-p02.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-p02.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-p02.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-p07.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-p07.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p07.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p07.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p07.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p07.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p07.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-p07.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-p07.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;p07"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;p07"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-p07.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-p07.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIJAPuSuMx8rNv8MA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2xhZG9rMy1wMDcubGFkb2sudW11LnNlMB4XDTE0MTAyNzEyMjYzMVoXDTI0\nMTAyNDEyMjYzMVowIjEgMB4GA1UEAxMXbGFkb2szLXAwNy5sYWRvay51bXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDew0DXPVY89n/fw3HkRC+/\n01TBXuX5pM6oLYVINLP12XtS/WHTQYUXDTpil6Hsc39p+8T6bsh2sqEQ9v/J0iSk\n/EBCU5JBl5fo2YI7X59UynmfUy8jQeJWjFqt+VVck0fG5XNuW8I5MX+eP5uNd2h2\nhNcOPXejYn5BXFrO04jqWZATpUcPA1vEwua3GcLOtuFBx4BrBZTFmo0EEoU2Kecd\n4+oXjNwXzwAeZFtEzgfr9Ge35qUF9FtBxfrkR8pR6alVqNsJbMWPNbGqLOdeY74s\nMtOVeGmKZxtheVDY07lJOC1Uk4JSbJl6RSEOv3QMn5SUhFHX43jS+jEf87tGLIzd\nAgMBAAGjbTBrMEoGA1UdEQRDMEGCF2xhZG9rMy1wMDcubGFkb2sudW11LnNlhiZo\ndHRwczovL2xhZG9rMy1wMDcubGFkb2sudW11LnNlL2d1aS1zcDAdBgNVHQ4EFgQU\nYKkebBi9Q5NFhgW9QbqZ2zlWt0owDQYJKoZIhvcNAQEFBQADggEBACsjRf6d8l5L\njjQnxKoVcj7IF5fTWwqahBWs3mumUr10j5ank9lTlKnX2kbnXOy8ubGE+6ECbFHn\nDuVYzvhfQn5hXKfXef7a5LeHl2MvmyfELr+TRl+CBATS3YQrnk7OtI95YhbY0Gjw\n6OTTd4RGDRhw9FsRr+Vo3ejF3pmmltO4czKFELBTxY+ErHnlne6KVqa7Vo98V72b\ndFYR4LA/NJrG00mHvw4vvqx4Zo5byKhzc35hky03VA6XcBDjfViXQE7ycKzqYJuC\nRTluWVSsQj+BYQ3yEKlXqYkzX+hnX3QUWjw40D4Eapo4h4ukwQu+z/rGvdxV3uE8\n5KUQzHgMLs0="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-p07.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p07.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p07.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p07.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p07.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p07.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p07.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-p07.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-p07.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-p07.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.unimedizin-mainz.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Khoddam-Zadeh"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ataollah.khoddam-zadeh@unimedizin-mainz.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ataollah"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Khoddam-Zadeh"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ataollah.khoddam-zadeh@unimedizin-mainz.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ataollah"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Khoddam-Zadeh"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ataollah.khoddam-zadeh@unimedizin-mainz.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ataollah"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.unimedizin-mainz.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2014-10-09T21:46:04Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.unimedizin-mainz.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGnTCCBYWgAwIBAgIHGFIEk0Z6CDANBgkqhkiG9w0BAQsFADCB2DELMAkGA1UE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\nAO8Ifi/pFzKtodcKmmfls3M="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.unimedizin-mainz.de,O=Universitaetsmedizin der Johannes Gutenberg-Universitaet Mainz,L=Mainz,ST=Rheinland-Pfalz,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.unimedizin-mainz.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGnTCCBYWgAwIBAgIHGFIEk0Z6CDANBgkqhkiG9w0BAQsFADCB2DELMAkGA1UE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\nAO8Ifi/pFzKtodcKmmfls3M="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.unimedizin-mainz.de,O=Universitaetsmedizin der Johannes Gutenberg-Universitaet Mainz,L=Mainz,ST=Rheinland-Pfalz,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unimedizin-mainz.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unimedizin-mainz.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unimedizin-mainz.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unimedizin-mainz.de/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unimedizin-mainz.de/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unimedizin-mainz.de:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.unimedizin-mainz.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unimedizin-mainz.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.unimedizin-mainz.de/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unimedizin-mainz.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unimedizin-mainz.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unimedizin-mainz.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unimedizin-mainz.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unimedizin-mainz.de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unimedizin-mainz.de"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Universit\u00e4tsmedizin der Johannes Gutenberg-Universit\u00e4t Mainz"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University Medical Center of the Johannes Gutenberg University Mainz"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e4tsmedizin der JoGu Mainz"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University Medical Center of the JoGu Mainz"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.unimedizin-mainz.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGnTCCBYWgAwIBAgIHGFIEk0Z6CDANBgkqhkiG9w0BAQsFADCB2DELMAkGA1UE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\nAO8Ifi/pFzKtodcKmmfls3M="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.unimedizin-mainz.de,O=Universitaetsmedizin der Johannes Gutenberg-Universitaet Mainz,L=Mainz,ST=Rheinland-Pfalz,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.unimedizin-mainz.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGnTCCBYWgAwIBAgIHGFIEk0Z6CDANBgkqhkiG9w0BAQsFADCB2DELMAkGA1UE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\nAO8Ifi/pFzKtodcKmmfls3M="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.unimedizin-mainz.de,O=Universitaetsmedizin der Johannes Gutenberg-Universitaet Mainz,L=Mainz,ST=Rheinland-Pfalz,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e4tsmedizin der Johannes Gutenberg-Universit\u00e4t Mainz"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University Medical Center of the Johannes Gutenberg University Mainz Germany"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unimedizin-mainz.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unimedizin-mainz.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e417"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e417"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.itsligo.ie/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kennedy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kennedy.kieran@itsligo.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kieran"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.itsligo.ie/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2011-07-07T00:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.itsligo.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.itsligo.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.itsligo.ie/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "itsligo.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.itsligo.ie"
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/its.png",
                    "height": "68",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "224"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Technology Sligo"
                  },
                  {
                    "lang": "ga",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "An Institi\u00faid Teicneola\u00edochta, Sligeach"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:54.2769291,-8.4651857"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAM0cwxuTuo+doAYLQTZ+F9Kh2xiQMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC5pdHNsaWdvLmllMB4XDTExMDcyNjA3NTc0NVoX\nDTMxMDcyNjA3NTc0NVowGTEXMBUGA1UEAxMOaWRwLml0c2xpZ28uaWUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDQz7PoJrvZxLSnvg6ZaRmqMStCmR5w\n6i3JklsDuILt/HaYtlKpbZtjb5j86rgDcyp2CK6YNm3k7xn/9nfScn/LnGKSW87r\nlwiSXePGAJ2OgCbVks+bQQIO4ALm3EKNao07x5EsyFrlbSzyw6/l0d3Vmd6HtRRQ\nF9+nA9uqvOSofbhYexl7KB2Ahebmp+d6SxuEU7gUkZScJ7Re9jd1z2cWBuSwRvkT\nWUcCa8i7YfiDvTq7BvVE+rHSkQAC2tUpH5kGHFr25P8J6f6Mr+flO44eNgo+pbJ8\n3KGETRjM/Fug7wAkDWu5JP+pJk7LOHVuuxg0NW/7jny6H6Bzkmc2ypMlAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC5pdHNsaWdvLmllhiVodHRwczovL2lkcC5pdHNs\naWdvLmllL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSqqAIq1XMY1iF8IG8Nrqws\nBTWwrDANBgkqhkiG9w0BAQUFAAOCAQEAgu0p4z0DPoFXijkpdX0OqB7CVQMqjIqY\nCTlQqZ56bKGKdQP7NpUHD5tiRHh4pB1LNLSh2xqKOgudqFo2lAHGQKf8nMtCi++K\njy7Q+vVmTnTXvQrYm32l9Rz94LI87vJTUATa8/4sCpUCw2xxT3EfhQpdssprrygj\nQIetzxpSXXz3n8tdU8r0wql2IbivjLdPKS0QOD+RAnTzVVBbKR0lXGBsVfR5oI2Z\nk3pnLaUJBrOCfFJMyrbTiKAOM4VDp8biKKxnYH0hs+hnDDOmKhRH1aqC9JuQ96xk\nAzsGEoivSwmcdqqwrTDW9ILcLk9Z7EsHRPKz1erD1ItJqsdN5EHsFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Technology Sligo"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.itsligo.ie"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Technology Sligo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.pathcal.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pathcal@lists.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "PathCAL"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Juszczyk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:arek.juszczyk@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Arek"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.pathcal.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-03-22T11:39:16Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Edinburgh: PathCAL"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lts.mvm.ed.ac.uk/index.asp"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.pathcal.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.pathcal.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.pathcal.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.pathcal.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.pathcal.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.pathcal.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.pathcal.ac.uk/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.pathcal.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.pathcal.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Series of online tutorials covering a wide range of pathology and pathophysiology subjects."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.pathcal.ac.uk/pathcal_wayf.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "300"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PathCAL"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIJAP0iPdXcGeGuMA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\n\t\t\t\t\t\tBAMTEXd3dy5wYXRoY2FsLmFjLnVrMB4XDTExMDMzMDE1MTIzNVoXDTIxMDMyNzE1\n\t\t\t\t\t\tMTIzNVowHDEaMBgGA1UEAxMRd3d3LnBhdGhjYWwuYWMudWswggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQCl7DYwQXP82QOrgN1cMH+8KqLz2e9wgOM66+0X\n\t\t\t\t\t\tNds/VycQAEP29h1DiYQbl/154Vqvf2E9PSlCz1gNLJjdEvnCrbTyECPNt9BG2H8n\n\t\t\t\t\t\tsDnGSzYpmAGiq42QiuPxa2LGdS9HpPDipxJCEs35HmeOeqFOIQtoUpmtAA9XRnth\n\t\t\t\t\t\tWG4C1JF8dZNAWpjpFzNCvLZHDUiZzJPgQjdQZ76UBEMoXYX7jDM4cAXHqNuRvFo6\n\t\t\t\t\t\ticFowW5TAtcx1WXL0HwRHxHRCRfWKDANn7HeN8H9Jk5M1lkRhN0DOu1RJN+8RBaI\n\t\t\t\t\t\tNJ5WnM3lY1oNZos2ui78+mXX5kdHStG9E+vfwUxBh23tmOfJAgMBAAGjZTBjMEIG\n\t\t\t\t\t\tA1UdEQQ7MDmCEXd3dy5wYXRoY2FsLmFjLnVrhiRodHRwczovL3d3dy5wYXRoY2Fs\n\t\t\t\t\t\tLmFjLnVrL3NoaWJib2xldGgwHQYDVR0OBBYEFBQnhIEnumryfjPopVA9OUDmxyks\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQAj+C0DVNjbwW7LxXwNAAXbYLDNQDm+wNwLvOV2\n\t\t\t\t\t\tk01FyU3k0M8F4F86i8Zh/fj1xZ3pZfV6uZcvB9CtIMqLG5aDKRBWqRqWGG8OvhAn\n\t\t\t\t\t\tJ0JBLmbhcz40RbfmeZUoq0+Zy8gGxARR/kjaZ16U4t5rgG7fSJlBiSsdu4FPjGNx\n\t\t\t\t\t\t3GzdsKqAZRjDhs7Ar7OltkqGz/ko4V/ok+WP7aTdzXWMe++ZSyyNxTNVVdSO+L3j\n\t\t\t\t\t\tZy9ytOPZlc12HwkN83CgQD6dPOEr4zmypBtg7RR6Bf0lhD7ldrSlA1LvrTQX6/vz\n\t\t\t\t\t\tGxJxVd0AU9FzIdALwx59lXkBvyhje3QI6dYfxwDZPyKxo4PA"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.pathcal.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.pathcal.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.pathcal.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.pathcal.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.pathcal.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.pathcal.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.pathcal.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.pathcal.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.pathcal.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.pathcal.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://eresources.city.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:e-access@city.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "E-Resources Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Zakrocki"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Robert.zakrocki.1@city.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://eresources.city.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://eresources.city.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://eresources.city.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "city.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDqTCCApGgAwIBAgIJANEnL7ss8XzBMA0GCSqGSIb3DQEBBQUAMEExHzAdBgNV\n\t\t\t\t\t\tBAoTFkNpdHkgVW5pdmVyc2l0eSBMb25kb24xHjAcBgNVBAMTFWVyZXNvdXJjZXMu\n\t\t\t\t\t\tY2l0eS5hYy51azAeFw0xMTA1MTgxMzA0MDhaFw0yMTA1MTUxMzA0MDhaMEExHzAd\n\t\t\t\t\t\tBgNVBAoTFkNpdHkgVW5pdmVyc2l0eSBMb25kb24xHjAcBgNVBAMTFWVyZXNvdXJj\n\t\t\t\t\t\tZXMuY2l0eS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK4B\n\t\t\t\t\t\t2cssI9cYHB6pShfCTfHPbLxpvtS6UDCSiyk59QjBkEe+xNOooWADPm/hOpJ8YSaJ\n\t\t\t\t\t\t+P0YtBcGASJH7TZDoRDrQv4ilKnf4q3j634N3W7M/a/9QYhFb5+hoLCCFKW8k/Ci\n\t\t\t\t\t\t2HGccZoXf71l1fm8WbaARlxr+jbfXm27xNTRYI0DQuLljCYEX4CbVULdJwJEDbly\n\t\t\t\t\t\tzjE/m35pFfBSGkIfLW2Pb1kfqhQibPK9OFgaIS+CqnLjeeSu+vKCLZTReLO066k+\n\t\t\t\t\t\tkD7w4sA5iQO8wgI/tplI3Qfk5nVYZ+U/lvwTErkUv8SHMRrSM5IpLCZJlt5c/kSs\n\t\t\t\t\t\tdO3LGvR9DRDu5ZKeiKMCAwEAAaOBozCBoDAdBgNVHQ4EFgQU+ZtIxxwofqtAgktA\n\t\t\t\t\t\t4ikJYEOr5Y8wcQYDVR0jBGowaIAU+ZtIxxwofqtAgktA4ikJYEOr5Y+hRaRDMEEx\n\t\t\t\t\t\tHzAdBgNVBAoTFkNpdHkgVW5pdmVyc2l0eSBMb25kb24xHjAcBgNVBAMTFWVyZXNv\n\t\t\t\t\t\tdXJjZXMuY2l0eS5hYy51a4IJANEnL7ss8XzBMAwGA1UdEwQFMAMBAf8wDQYJKoZI\n\t\t\t\t\t\thvcNAQEFBQADggEBAAc1kylLE8KGgvXnA/WBu/ZQ/A/oHL0upJqpWr3cJeP3PMCG\n\t\t\t\t\t\tT7XSvNK9gmFPakF0A5w14wtn+Q3cQTkPlfcEVbyUSOENFazXGRUxCzAZsVH7gnL+\n\t\t\t\t\t\tFyZK+NT73wdvqR2OiwAMUWITHISyem029BRpbe59MR2V1uYk2l4xEHrqTt520XCQ\n\t\t\t\t\t\tfRIGR+/ORhOm5ANGNp+uIL3YRPth2g0z+j3EB130sVfEt1LQdC6nsf6Nn1v7JXuV\n\t\t\t\t\t\tHIkvnhXmEYmfriKBwfQlQmXn8e/r6MalkbDoyAwpj89nad1Qnt64y7Xlwuhv73Yh\n\t\t\t\t\t\tIzI6BtUZKeH0qlf6/tMjgAJWUSgRl/w2i1F6Kf0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDqTCCApGgAwIBAgIJANEnL7ss8XzBMA0GCSqGSIb3DQEBBQUAMEExHzAdBgNV\n\t\t\t\t\t\tBAoTFkNpdHkgVW5pdmVyc2l0eSBMb25kb24xHjAcBgNVBAMTFWVyZXNvdXJjZXMu\n\t\t\t\t\t\tY2l0eS5hYy51azAeFw0xMTA1MTgxMzA0MDhaFw0yMTA1MTUxMzA0MDhaMEExHzAd\n\t\t\t\t\t\tBgNVBAoTFkNpdHkgVW5pdmVyc2l0eSBMb25kb24xHjAcBgNVBAMTFWVyZXNvdXJj\n\t\t\t\t\t\tZXMuY2l0eS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK4B\n\t\t\t\t\t\t2cssI9cYHB6pShfCTfHPbLxpvtS6UDCSiyk59QjBkEe+xNOooWADPm/hOpJ8YSaJ\n\t\t\t\t\t\t+P0YtBcGASJH7TZDoRDrQv4ilKnf4q3j634N3W7M/a/9QYhFb5+hoLCCFKW8k/Ci\n\t\t\t\t\t\t2HGccZoXf71l1fm8WbaARlxr+jbfXm27xNTRYI0DQuLljCYEX4CbVULdJwJEDbly\n\t\t\t\t\t\tzjE/m35pFfBSGkIfLW2Pb1kfqhQibPK9OFgaIS+CqnLjeeSu+vKCLZTReLO066k+\n\t\t\t\t\t\tkD7w4sA5iQO8wgI/tplI3Qfk5nVYZ+U/lvwTErkUv8SHMRrSM5IpLCZJlt5c/kSs\n\t\t\t\t\t\tdO3LGvR9DRDu5ZKeiKMCAwEAAaOBozCBoDAdBgNVHQ4EFgQU+ZtIxxwofqtAgktA\n\t\t\t\t\t\t4ikJYEOr5Y8wcQYDVR0jBGowaIAU+ZtIxxwofqtAgktA4ikJYEOr5Y+hRaRDMEEx\n\t\t\t\t\t\tHzAdBgNVBAoTFkNpdHkgVW5pdmVyc2l0eSBMb25kb24xHjAcBgNVBAMTFWVyZXNv\n\t\t\t\t\t\tdXJjZXMuY2l0eS5hYy51a4IJANEnL7ss8XzBMAwGA1UdEwQFMAMBAf8wDQYJKoZI\n\t\t\t\t\t\thvcNAQEFBQADggEBAAc1kylLE8KGgvXnA/WBu/ZQ/A/oHL0upJqpWr3cJeP3PMCG\n\t\t\t\t\t\tT7XSvNK9gmFPakF0A5w14wtn+Q3cQTkPlfcEVbyUSOENFazXGRUxCzAZsVH7gnL+\n\t\t\t\t\t\tFyZK+NT73wdvqR2OiwAMUWITHISyem029BRpbe59MR2V1uYk2l4xEHrqTt520XCQ\n\t\t\t\t\t\tfRIGR+/ORhOm5ANGNp+uIL3YRPth2g0z+j3EB130sVfEt1LQdC6nsf6Nn1v7JXuV\n\t\t\t\t\t\tHIkvnhXmEYmfriKBwfQlQmXn8e/r6MalkbDoyAwpj89nad1Qnt64y7Xlwuhv73Yh\n\t\t\t\t\t\tIzI6BtUZKeH0qlf6/tMjgAJWUSgRl/w2i1F6Kf0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "City University London (IT log-in)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.city.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "City University London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://indicate-gw.consorzio-cometa.it/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fargetta"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:marco.fargetta@ct.infn.it"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:credentials-admin@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marco"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rotondo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:riccardo.rotondo@ct.infn.it"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:credentials-admin@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Riccardo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Platania"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:giuseppe.platania@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Giuseppe"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rocca"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:carlo.rocca@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Carlo"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barbera"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:roberto.barbera@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roberto"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://indicate-gw.consorzio-cometa.it/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2011-09-05T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "COMETA"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "COMETA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.consorzio-cometa.it/"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.consorzio-cometa.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "COMETA Consortium"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consorzio COMETA (COnsorzio Multi Ente per la promozione e l'adozione di Tecnologie di calcolo Avanzato)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://indicate-gw.consorzio-cometa.it/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://indicate-gw.consorzio-cometa.it/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://indicate-gw.consorzio-cometa.it/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://indicate-gw.consorzio-cometa.it/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://indicate-gw.consorzio-cometa.it/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service allows users to access the digital repositories created for the INDICATE\n                        project to demonstrate the usefulness of the adoption of e-Infrastructures for Digital\n                        Cultural Heritage. It is devoted to the INDICATE partners as well as to cultural institutions,\n                        e-Infrastructure providers and the general public."
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Questo servizio permette agli utenti di accedere gli archivi digitali creati per il progetto\n                        europeo INDICATE con l'obiettivo di dimostrare l'opportunit\u00e0 di adottare e-Infrastrutture per\n                        i patrimoni culturali digitali. Esso \u00e8 indirizzato ai partner di INDICATE ed altre istituzioni\n                        culturali, i fornitori di e-Infrastrutture ed al pubblico."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INDICATE e-Culture Science Gateway"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INDICATE e-Culture Science Gateway"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://indicate-gw.consorzio-cometa.it/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://indicate-gw.consorzio-cometa.it/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFhDCCBGygAwIBAgIRAOyXU1f6GS689kEaSDAhQPYwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDA1MTkwMDAwMDBaFw0xNzA1MTgyMzU5NTlaMEAxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEbMBkGA1UEAxMSbGlmZXJheS5j\ndC5pbmZuLml0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApizyvtMI\nuoSnnz/fvk7lcXwoDUk11NVAlg5w4zh01YKNvy5SzBu0eRIzRos/ALs4CwmxrmCv\n3JQPA4xxItxVd8x9Q+YElQteEcX+mWXXW5LI5XE3xhPzkdFeQrhkinAK2JreSn6E\nTQk8YO1rOxW3qCpKeYZ2VQF3grAU/JRWbvLF+r2j4zE27n+RzBxnYeZ9rtJ/67gU\n7t1S39DRDTyKit7dJIYl50n9g3atWGALb56QoVnlR+RPRxVI9EFd2hEXfrxWXGdt\nF2v6YIMSAAM5l2/SlEmhQSSkmQ4zXcmPrzC6pte9NWoPOTsQnCnocwMJ16aXsnQy\nBxaoywMtq8NsdwIDAQABo4ICgTCCAn0wHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsr\nN1dH6pDjue0wHQYDVR0OBBYEFCy5dq76F94vaAuznAys6UmGxySTMA4GA1UdDwEB\n/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEF\nBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8E\nMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENB\nLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNz\nLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8v\nb2NzcC50Y3MudGVyZW5hLm9yZzCCAS0GA1UdEQSCASQwggEgghJsaWZlcmF5LmN0\nLmluZm4uaXSCGWFwcGxpY2F0aW9ucy5ldS1kZWNpZGUuZXWCGWFwcGxpY2F0aW9u\ncy5ldW1lZGdyaWQuZXWCEGdpbGRhLmN0LmluZm4uaXSCFGdpc2VsYS1ndy5jdC5p\nbmZuLml0gg1ndy5jdC5pbmZuLml0ghNnd2VhdGhlci5jdC5pbmZuLml0ghBnd2xp\nYi5jdC5pbmZuLml0gh9pbmRpY2F0ZS1ndy5jb25zb3J6aW8tY29tZXRhLml0ghFy\naWNldmkuY3QuaW5mbi5pdIIUdmlyYWxncmlkLmN0LmluZm4uaXSCFHd3dy5jaGFp\nbi1wcm9qZWN0LmV1ghZ3d3cuc3BlY2lhbC1wcm9qZWN0Lml0MA0GCSqGSIb3DQEB\nBQUAA4IBAQCEZIHNNQPD5WkGSlUhCN/BRSharmQ6dT0NiwjQNmRODCpVqBgwVZY0\nVUlAobHaF186QXeiNYge8ZYSpYY2VhBa4znL7IjFODE3FsaJNseKgsyNFqKR8xNO\nnsOCM//SN9N79hwH8yAxLhGyxbnInpOhE6rEkbhtowTjqhDq26cGGlH8JTTPuYvY\nJhgPGGkxo1286x1nuN4ELKvwZ7RF+YTH/WPOIBMNi+ee+vxrIhWbU6iy97f7k4PA\n2e35ZQ6gutnmX2v/ybFWh0ruO4zszYKiMo+zGyLvYmIpV/+Mjs26KbqqrBOS1jjN\nW3MiH8HMxzzYHExNCvzrAgN1TfB+SCiB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://indicate-gw.consorzio-cometa.it/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://indicate-gw.consorzio-cometa.it/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://indicate-gw.consorzio-cometa.it/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://indicate-gw.consorzio-cometa.it/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://indicate-gw.consorzio-cometa.it/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://indicate-gw.consorzio-cometa.it/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "INDICATE e-Culture Science Gateway"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This service allows users to access the digital repositories created for the INDICATE\n                    project to demonstrate the usefulness of the adoption of e-Infrastructures for Digital\n                    Cultural Heritage. It is devoted to the INDICATE partners as well as to cultural institutions,\n                    e-Infrastructure providers and the general public."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "http://adfs.hsmarnix.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs.hsmarnix.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-04-15T16:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/96cbfec0d8a42ee032111ece52d3185a",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Marnix Academie"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Marnix Academie"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/marnix.png",
                    "height": "18",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Marnix Academie"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Marnix Academie"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Marnix Academie"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.marnixacademie.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Marnix Academie"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://youidlite.youid.net/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Payne"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mpayne@imperosoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Payne"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mpayne@imperosoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://youidlite.youid.net/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-07-01T14:56:47Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUa8xPw+mOVIxAKWoeoNJ1T1hc6p4wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHjEcMBoGA1UEAxMTeW91aWRsaXRlLnlvdWlkLm5ldDAeFw0xNDA2MTExMjQ4\n\t\t\t\t\t\tMDhaFw0zNDA2MTExMjQ4MDhaMB4xHDAaBgNVBAMTE3lvdWlkbGl0ZS55b3VpZC5u\n\t\t\t\t\t\tZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCBYPbq7OB/Qqs8F6U5\n\t\t\t\t\t\tvJ9e1oAwLlW17j2DMTV3vGqBk+F3Er1Zu97STKlhRQNHdBrH5S176Re2xbYyHQyc\n\t\t\t\t\t\terLd5rc8Gd0gCMr2TtvmXoCLOT1ToObM6pZy014yCrGUjtaI0z6HxZKsGi+QtDPi\n\t\t\t\t\t\ts9AYYhINTv4MJyuZWH0a5w2YgoU0gQAvubCGeHmtbT/fEC0kcXCOXcljXJONyZVl\n\t\t\t\t\t\tdH6PTlSxzuU44lLDssvrnPnb07pQLbV9oXtZBN5Tp/7UA8JM5d+VMC1vqcM2Mjm2\n\t\t\t\t\t\tcm7pQz9hLAQschFh2jv/uHqyrH+0BibfVssQj2H+KjPk6qHmpkwt92rW+Jn7Bh3N\n\t\t\t\t\t\tNcbTAgMBAAGjbTBrMEoGA1UdEQRDMEGCE3lvdWlkbGl0ZS55b3VpZC5uZXSGKmh0\n\t\t\t\t\t\tdHBzOi8veW91aWRsaXRlLnlvdWlkLm5ldC9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4E\n\t\t\t\t\t\tFgQUAteTwYYaGMljF20EP0WeZ76psFIwDQYJKoZIhvcNAQEFBQADggEBAA1uyLQR\n\t\t\t\t\t\tRAGMPHDD+fis2bqS7Fz2GyXx/EsjW6GccOVGMShLcuDitzeI8YqNwvPK3AJY9pyW\n\t\t\t\t\t\tFjsLULR++K2RTNhXAAsG+kL7aHT8GtP8u8T304stuPgLG87BrIatXiizUPUnUaMv\n\t\t\t\t\t\tsz3EKWbnTP4qt1U4EkcuMQs9XBcNlvF9DTe4FdSA477b7Rr0slBDXEtysxAlZr70\n\t\t\t\t\t\tQqCLOxffcf6mmPf44qfkgnYOroEeF2zDHUiwUFFdGNnJ0TxpddCLwAzdZ7nZl9ah\n\t\t\t\t\t\tX2IqdL5C4SpWjnrD6/Y3VQAZl+FkssUHp4N/ebLeWRg2/ZsqhikESOcAOMnYnN2P\n\t\t\t\t\t\tASTdIdKTeaOQfXw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "youid.net"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://youidlite.youid.net:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://youidlite.youid.net:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://youidlite.youid.net:446/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://youidlite.youid.net:446/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://youidlite.youid.net:446/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://youidlite.youid.net:446/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://youidlite.youid.net:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://youidlite.youid.net:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "youid.net"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUa8xPw+mOVIxAKWoeoNJ1T1hc6p4wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHjEcMBoGA1UEAxMTeW91aWRsaXRlLnlvdWlkLm5ldDAeFw0xNDA2MTExMjQ4\n\t\t\t\t\t\tMDhaFw0zNDA2MTExMjQ4MDhaMB4xHDAaBgNVBAMTE3lvdWlkbGl0ZS55b3VpZC5u\n\t\t\t\t\t\tZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCBYPbq7OB/Qqs8F6U5\n\t\t\t\t\t\tvJ9e1oAwLlW17j2DMTV3vGqBk+F3Er1Zu97STKlhRQNHdBrH5S176Re2xbYyHQyc\n\t\t\t\t\t\terLd5rc8Gd0gCMr2TtvmXoCLOT1ToObM6pZy014yCrGUjtaI0z6HxZKsGi+QtDPi\n\t\t\t\t\t\ts9AYYhINTv4MJyuZWH0a5w2YgoU0gQAvubCGeHmtbT/fEC0kcXCOXcljXJONyZVl\n\t\t\t\t\t\tdH6PTlSxzuU44lLDssvrnPnb07pQLbV9oXtZBN5Tp/7UA8JM5d+VMC1vqcM2Mjm2\n\t\t\t\t\t\tcm7pQz9hLAQschFh2jv/uHqyrH+0BibfVssQj2H+KjPk6qHmpkwt92rW+Jn7Bh3N\n\t\t\t\t\t\tNcbTAgMBAAGjbTBrMEoGA1UdEQRDMEGCE3lvdWlkbGl0ZS55b3VpZC5uZXSGKmh0\n\t\t\t\t\t\tdHBzOi8veW91aWRsaXRlLnlvdWlkLm5ldC9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4E\n\t\t\t\t\t\tFgQUAteTwYYaGMljF20EP0WeZ76psFIwDQYJKoZIhvcNAQEFBQADggEBAA1uyLQR\n\t\t\t\t\t\tRAGMPHDD+fis2bqS7Fz2GyXx/EsjW6GccOVGMShLcuDitzeI8YqNwvPK3AJY9pyW\n\t\t\t\t\t\tFjsLULR++K2RTNhXAAsG+kL7aHT8GtP8u8T304stuPgLG87BrIatXiizUPUnUaMv\n\t\t\t\t\t\tsz3EKWbnTP4qt1U4EkcuMQs9XBcNlvF9DTe4FdSA477b7Rr0slBDXEtysxAlZr70\n\t\t\t\t\t\tQqCLOxffcf6mmPf44qfkgnYOroEeF2zDHUiwUFFdGNnJ0TxpddCLwAzdZ7nZl9ah\n\t\t\t\t\t\tX2IqdL5C4SpWjnrD6/Y3VQAZl+FkssUHp4N/ebLeWRg2/ZsqhikESOcAOMnYnN2P\n\t\t\t\t\t\tASTdIdKTeaOQfXw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "YouID-E2BN Integration"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.imperosoftware.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Impero Solutions Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.cue-lillenorddefrance.fr/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "info-infra.dir@espe-lnf.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cue-lillenorddefrance.fr/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-06-16T16:33:41Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cue-lillenorddefrance.fr/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cue-lillenorddefrance.fr/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.cue-lillenorddefrance.fr/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cue-lillenorddefrance.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.espe-lnf.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnels, Formateurs et \u00e9tudiants"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnels, Formateurs et \u00e9tudiants"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Communaut\u00e9 d'Universit\u00e9s et d'Etablissements - Lille Nord de France"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Communaut\u00e9 d'Universit\u00e9s et d'Etablissements - Lille Nord de France"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEhjCCA26gAwIBAgIRANSLXSw4ru5ryYhm5hf/p58wDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDA2MTYwMDAwMDBaFw0xNzA2MTUyMzU5NTlaMEoxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDElMCMGA1UEAxMcaWRwLmN1ZS1s\naWxsZW5vcmRkZWZyYW5jZS5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\nggEBAPFaRQj5mYaG4U4ROsOmg7AtHftdd/UNBNDz36zXv99uRcrbhSi+rVrgfsnC\nelpbxwACvNNRYvxov5oxBFR9UeFT9sSzrM+PacXR1Qa435AP8hao5TmGR4O8i4JW\nahGqQHjwooVCoZt1i0ri2aE5tI4HVp8GBl1lNGRlTPYDWjh4a/irL0JeqMs8DAnN\nswJBuiJ4I1exC3/KIy37cqMleGnpwbx1E1RKPitFtbpHKENiYIgAPmhnNDk1FQOj\nF6O2eIGwKguruSAMJe/ObpYCObIdYXhxBMiSAUX8KQpx5ASBxzE4BgT+rdrOv82q\n9z1Z71Tb2bPSXZ24PzLyTwIMX4sCAwEAAaOCAXkwggF1MB8GA1UdIwQYMBaAFAy9\nk2gM896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBQyUKxCROm0WgHBk0YYobumdPLD\nejAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEF\nBQcDAQYIKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwB\nAgEwOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9U\nRVJFTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRw\nOi8vY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcw\nAYYaaHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwJwYDVR0RBCAwHoIcaWRwLmN1\nZS1saWxsZW5vcmRkZWZyYW5jZS5mcjANBgkqhkiG9w0BAQUFAAOCAQEAM5EI+tv8\nA6F8sdy0LjO+LcVeIO7i7QMaaN6CQyn1wh/P+rEBk0mk6kiCqDbjksjAsGTPYYZ7\nFdq4bS6Bmqd9BQyZMbq4Sm3eFiMqa87oDZHjsuiWWIccmrCKAIWKr447PpDBBs95\nGOL5hwuqjHIPvb1qKFUBvriW0B8ujEdcJl3ja/oy0oBz8xlSmpvCZPS6vNc0cCn+\nYm0QTm2dtTLNmPUW4DcV32K0eJCsrrT/nNy18Vw5aatD6U3TuggE7Ocgcb+QUsH+\nk3M5769UhOUotF3wRjXyBQsbW81d7LsdsxPvhAF9GQiX3uGrBDEYWK4Uq3KQE0/L\npjRCf2fUkk8Bag=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Communaut\u00e9 d'Universit\u00e9s et d'Etablissements - Lille Nord de France"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.espe-lnf.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Communaut\u00e9 d'Universit\u00e9s et d'Etablissements - Lille Nord de France"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.cant-col.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Friend"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:n.friend@canterburycollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nathan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Friend"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:n.friend@canterburycollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nathan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.cant-col.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-04T14:23:04Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID3jCCAsYCCQD4z6zira6C7TANBgkqhkiG9w0BAQUFADCBsDELMAkGA1UEBhMC\n\t\t\t\t\t\tVUsxDTALBgNVBAgMBEtlbnQxEzARBgNVBAcMCkNhbnRlcmJ1cnkxGzAZBgNVBAoM\n\t\t\t\t\t\tEkNhbnRlcmJ1cnkgQ29sbGVnZTEaMBgGA1UECwwRQ29tcHV0aW5nIFN1cHBvcnQx\n\t\t\t\t\t\tIjAgBgNVBAMMGXNoaWJib2xldGguY2FudC1jb2wuYWMudWsxIDAeBgkqhkiG9w0B\n\t\t\t\t\t\tCQEWEW5zQGNhbnQtY29sLmFjLnVrMB4XDTE2MDMyNDEwMDc0MloXDTIxMDMyMzEw\n\t\t\t\t\t\tMDc0MlowgbAxCzAJBgNVBAYTAlVLMQ0wCwYDVQQIDARLZW50MRMwEQYDVQQHDApD\n\t\t\t\t\t\tYW50ZXJidXJ5MRswGQYDVQQKDBJDYW50ZXJidXJ5IENvbGxlZ2UxGjAYBgNVBAsM\n\t\t\t\t\t\tEUNvbXB1dGluZyBTdXBwb3J0MSIwIAYDVQQDDBlzaGliYm9sZXRoLmNhbnQtY29s\n\t\t\t\t\t\tLmFjLnVrMSAwHgYJKoZIhvcNAQkBFhFuc0BjYW50LWNvbC5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBANL1WfdbMgBzfEOxwHeSK+MDNURlQWyV\n\t\t\t\t\t\taNSsn1KqEd13v+Ja/YwUyM0htgC95qFrRD2X2J6Vx1I8qTHJgyTr8nCz9iImV1uG\n\t\t\t\t\t\temG/skA2IKmkMVyfCX5DxQcmmiShm1b+cNW1fuJSxexUpUlHysJDMUeZnKIHUpug\n\t\t\t\t\t\tqCabMwY7KmSMmcvT4+tn86Hh2xi2fDK/9stbiNo+5CAC8LA7FDQeQDiQaQyBmF6o\n\t\t\t\t\t\tA5cSOq7/WA2lb+r/7LTznxWf3E4wCEQW3oaShETf9wJjC/wd0gFoyWKRz101xqW5\n\t\t\t\t\t\tMqC8PgS4zcOkQuEIFTGPyAwnNYxKr67pqxsJIo+Ynq5TOUm4JHQJ6LcCAwEAATAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEALKs+qNF+Z35LBada4feOxHMLiGq3qBLh4ULKzPrt\n\t\t\t\t\t\tD5u4Xp1+4PGHWGkq5umdasnHcDH77T0jzFRCg3dGp6ZLF67SJjtPBC2Fg6n3QtGM\n\t\t\t\t\t\tAvKTJHXQ4YOljSjVyXFtJjCJ4BLLBvld1WPWnJcI6d+hOM2AoWTGGIcZULxZjkk3\n\t\t\t\t\t\tVnfieg8hEskAqp9Ausr7zqgibczT83qM/JPTJmE4HygbhlE7AC8G3plV1Xx4Zdmq\n\t\t\t\t\t\tU2lDsbpM9CoKDz+VeQbwhx4sIgu04JezZDJrtLEVWaf8Yx/CS7HoMNHrpH3bh+/O\n\t\t\t\t\t\teOGSNd/fcIupfbOlmBneWAsTPWNhQqts16hoEnHbf5t+3A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cant-col.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.cant-col.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.cant-col.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.cant-col.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.cant-col.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.cant-col.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.cant-col.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.cant-col.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.cant-col.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "logo": [
                  {
                    "text": "https://shibboleth.cant-col.ac.uk/canterbury-college-logo.png",
                    "height": "274",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "88"
                  },
                  {
                    "text": "https://shibboleth.cant-col.ac.uk/canterbury-college-logo-icon.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://shibboleth.cant-col.ac.uk/canterbury-college-logo-cds.png",
                    "height": "80",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Canterbury College (test)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cant-col.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID3jCCAsYCCQD4z6zira6C7TANBgkqhkiG9w0BAQUFADCBsDELMAkGA1UEBhMC\n\t\t\t\t\t\tVUsxDTALBgNVBAgMBEtlbnQxEzARBgNVBAcMCkNhbnRlcmJ1cnkxGzAZBgNVBAoM\n\t\t\t\t\t\tEkNhbnRlcmJ1cnkgQ29sbGVnZTEaMBgGA1UECwwRQ29tcHV0aW5nIFN1cHBvcnQx\n\t\t\t\t\t\tIjAgBgNVBAMMGXNoaWJib2xldGguY2FudC1jb2wuYWMudWsxIDAeBgkqhkiG9w0B\n\t\t\t\t\t\tCQEWEW5zQGNhbnQtY29sLmFjLnVrMB4XDTE2MDMyNDEwMDc0MloXDTIxMDMyMzEw\n\t\t\t\t\t\tMDc0MlowgbAxCzAJBgNVBAYTAlVLMQ0wCwYDVQQIDARLZW50MRMwEQYDVQQHDApD\n\t\t\t\t\t\tYW50ZXJidXJ5MRswGQYDVQQKDBJDYW50ZXJidXJ5IENvbGxlZ2UxGjAYBgNVBAsM\n\t\t\t\t\t\tEUNvbXB1dGluZyBTdXBwb3J0MSIwIAYDVQQDDBlzaGliYm9sZXRoLmNhbnQtY29s\n\t\t\t\t\t\tLmFjLnVrMSAwHgYJKoZIhvcNAQkBFhFuc0BjYW50LWNvbC5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBANL1WfdbMgBzfEOxwHeSK+MDNURlQWyV\n\t\t\t\t\t\taNSsn1KqEd13v+Ja/YwUyM0htgC95qFrRD2X2J6Vx1I8qTHJgyTr8nCz9iImV1uG\n\t\t\t\t\t\temG/skA2IKmkMVyfCX5DxQcmmiShm1b+cNW1fuJSxexUpUlHysJDMUeZnKIHUpug\n\t\t\t\t\t\tqCabMwY7KmSMmcvT4+tn86Hh2xi2fDK/9stbiNo+5CAC8LA7FDQeQDiQaQyBmF6o\n\t\t\t\t\t\tA5cSOq7/WA2lb+r/7LTznxWf3E4wCEQW3oaShETf9wJjC/wd0gFoyWKRz101xqW5\n\t\t\t\t\t\tMqC8PgS4zcOkQuEIFTGPyAwnNYxKr67pqxsJIo+Ynq5TOUm4JHQJ6LcCAwEAATAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEALKs+qNF+Z35LBada4feOxHMLiGq3qBLh4ULKzPrt\n\t\t\t\t\t\tD5u4Xp1+4PGHWGkq5umdasnHcDH77T0jzFRCg3dGp6ZLF67SJjtPBC2Fg6n3QtGM\n\t\t\t\t\t\tAvKTJHXQ4YOljSjVyXFtJjCJ4BLLBvld1WPWnJcI6d+hOM2AoWTGGIcZULxZjkk3\n\t\t\t\t\t\tVnfieg8hEskAqp9Ausr7zqgibczT83qM/JPTJmE4HygbhlE7AC8G3plV1Xx4Zdmq\n\t\t\t\t\t\tU2lDsbpM9CoKDz+VeQbwhx4sIgu04JezZDJrtLEVWaf8Yx/CS7HoMNHrpH3bh+/O\n\t\t\t\t\t\teOGSNd/fcIupfbOlmBneWAsTPWNhQqts16hoEnHbf5t+3A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Canterbury College (test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cant-col.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Canterbury College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.crous-reims.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "informatique@crous-reims.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.crous-reims.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-01-08T17:28:08Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.crous-reims.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.crous-reims.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.crous-reims.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "crous-reims.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.crous-reims.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Server Shibboleth"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Serveur  Shibboleth fournisseur d'identit\u00e9e"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/vnd.microsoft.icon;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Reims"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Reims"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIJAOjHz8Rlt5DLMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEmlkcC5jcm91cy1yZWltcy5mcjAeFw0xNTEyMjIwNTIwMjRaFw0xODEyMjEw\nNTIwMjRaMB0xGzAZBgNVBAMTEmlkcC5jcm91cy1yZWltcy5mcjCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAM3dwzfpnyEAOsmLeJZ8yxlrOAZv/1V6w4yR\nabxkwBF8o0++QUB1uyduzHrBQWcgDtMfhuY6/gIAeCXl6sX681l/9aqhvY3q7fe0\nzkx2NbpNHYGH95kN1oSg0mhCjoR2QA/jnuA+epuw0mgMiJXB22bvogqr6xtPORa8\nObuvxbr9T5HhykgQCKBhl1qJ0Urehobfe7Py0ksJg/XpW57KQjv0QFhLEmhVRLle\nHda54Yyrl/vMGVlpqkrFKuEw9hzk9OfVVMbGlamVkay35e8U0h2A0yQY5RxeC6S9\noGiBICOgBQD4Ofxn3avCokUCsXiMPEG5u37tV0+6bWdvOITlWmECAwEAAaNrMGkw\nSAYDVR0RBEEwP4ISaWRwLmNyb3VzLXJlaW1zLmZyhilodHRwczovL2lkcC5jcm91\ncy1yZWltcy5mci9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU9QiwBg78Xxdav9h+\nhy5om5GJbPkwDQYJKoZIhvcNAQEFBQADggEBALAmbzYRQmKJMDVcqnrA8EUA7VpC\ng+MQ9Zv43NN24J2mfxZ+dp9P1a2YdsN//Ruukrf9+G/04BlQD8nnX5abCjnCxUKN\nTHSRSEyhzGO+958eYuBCweB0h9hGzPATks0NsOxDIH6WMymVhE0HfkTmXN7Db8vU\nyme8Rjea2onN07ookIVgM+MbGVEL+eA+y0TGRk+/WR1wtN2cj/e+g9/GXvHcqQlP\ngXKNVq8c9yhEuK0mhtZ7n3AlCLrDQUKWetzGbaSvHFTNd/XYwYKc9lfVEu71II6a\nJRfS8xrL01pysyULxIGNBTU1zdajH4UHS3EqRRLKCm4gF5CU40pxLSEqm/E="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEajCCA1KgAwIBAgIQa6ko9Kashh39Z5Tcht03DzANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDEwODAwMDAwMFoXDTE2MDEwODIzNTk1OVowQzELMAkGA1UE\nBhMCRlIxFzAVBgNVBAoTDkNST1VTIGRlIFJFSU1TMRswGQYDVQQDExJpZHAuY3Jv\ndXMtcmVpbXMuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC555WB\n8B1fRb8vSWEVIm0fFonTJazsqrpwELDuWp9zUHdP0bgjSW1AmzSrSyNUWcflmqw2\nyQD7ouaCQ2g8JWNaMo73Z4E9t8ttNVYzpnP4MaMkWATQtsi4eP/EVCRX3v0yaQcR\nyQ8T2YjpJOHviOcI7lfyHG6Nxks3kW7SjzfweWLt9jEW8pH9UE7jYDsLnHwLml0q\nZp+MglspxeqgziNhk91qS3W/ZtvbnDVLXXLetYjXrlLZGHw08Qo0hq9OYrio3OOZ\ndshYmQL0bD5egtq61kbU3ayzIc1IbrD1mtI3EP2CtZEdVr9JgCRCNrlrcAOEqnfT\nrCfA75FdYGYZROQnAgMBAAGjggFlMIIBYTAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJ\nays3V0fqkOO57TAdBgNVHQ4EFgQUjAtStb1iJUaE03HYtDq+0Udv1hwwDgYDVR0P\nAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsG\nAQUFBwMCMBgGA1UdIAQRMA8wDQYLKwYBBAGyMQECAh0wOgYDVR0fBDMwMTAvoC2g\nK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcmwwbQYI\nKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50ZXJlbmEu\nb3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29jc3AudGNz\nLnRlcmVuYS5vcmcwHQYDVR0RBBYwFIISaWRwLmNyb3VzLXJlaW1zLmZyMA0GCSqG\nSIb3DQEBBQUAA4IBAQBP0ba+bGMAePVNe5hvffTp4SW2wRDL6y9gNabJnQrGIln+\ntiitKXKTHYT+uxa3DqTpxYCHr5FtKPPhPKPIS7dyIVIxvkRAWOee+/spfUPC7Y8J\n/Mx3kyMlSZQGXzhDJkRDJqYKkoNVp0F/hEtJMAJKlWq2ERKrVzdF+x2ipvCMkRUQ\n+Ta0RqsMn+JrYiptiNpafPwigC7kYJ4YB1UnrfI94RkWADh3qjyRbj1UZfY5jTjv\nquzYxmp0LyZyMdkQcCQ3FVJ+AxPgSJaRjjDOc8yEDIG2kkxnZf2qoctXs077A4XH\nLgLBAZ0NCQeidPwxsKvCoYW5xQKIBaqW2ZTmqAbG"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS Reims"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.crous-reims.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS Reims"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ticket.iop.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hayes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Chris.Hayes@iop.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Garcia"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:estela.garcia@iop.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Estela"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ticket.iop.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-04-02T16:45:39Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IOP online services"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iop.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IOP Publishing Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF/jCCBOagAwIBAgIQM+YpmcylIPDSTgnHfWNmNTANBgkqhkiG9w0BAQUFADCB\n\t\t\t\t\t\ttTELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMR8wHQYDVQQL\n\t\t\t\t\t\tExZWZXJpU2lnbiBUcnVzdCBOZXR3b3JrMTswOQYDVQQLEzJUZXJtcyBvZiB1c2Ug\n\t\t\t\t\t\tYXQgaHR0cHM6Ly93d3cudmVyaXNpZ24uY29tL3JwYSAoYykxMDEvMC0GA1UEAxMm\n\t\t\t\t\t\tVmVyaVNpZ24gQ2xhc3MgMyBTZWN1cmUgU2VydmVyIENBIC0gRzMwHhcNMTIwMzE5\n\t\t\t\t\t\tMDAwMDAwWhcNMTgwMzE2MjM1OTU5WjCB6DELMAkGA1UEBhMCR0IxDTALBgNVBAgT\n\t\t\t\t\t\tBEF2b24xEDAOBgNVBAcUB0JyaXN0b2wxGzAZBgNVBAoUEklPUCBQdWJsaXNoaW5n\n\t\t\t\t\t\tIEx0ZDE1MDMGA1UECxQsVGVybXMgb2YgdXNlIGF0IHd3dy52ZXJpc2lnbi5jby51\n\t\t\t\t\t\tay9ycGEgKGMpMDUxIjAgBgNVBAsTGUF1dGhlbnRpY2F0ZWQgYnkgVmVyaVNpZ24x\n\t\t\t\t\t\tJzAlBgNVBAsTHk1lbWJlciwgVmVyaVNpZ24gVHJ1c3QgTmV0d29yazEXMBUGA1UE\n\t\t\t\t\t\tAxQOdGlja2V0LmlvcC5vcmcwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQC5WcglO3vKPNW09UA2GygrxCcozj67wA8Qd6d7Mu17EPrFzxRUP3h2jqk9wAPn\n\t\t\t\t\t\tvaIMcNooYHK/CzUawroiINRtdArpRT0lW1aNeXuiZ+9H6SU2KQKfMSI5WoXvIdW9\n\t\t\t\t\t\txUUnQyyptaXNVyXINAlkm5y+HTsrbRATRkjJN94Qw4ssRaYfWhOP66rpviu1DfLA\n\t\t\t\t\t\tVhhhc/uSme+la90C+bVQ9EHnfF5adHAMsGIiJbqdQCK4Hq5nFlzpW535GRqleHcE\n\t\t\t\t\t\t9x3HUppIJ32Q1ehYEvzwSIMBp8ACO7hgnSiYPbegpYPdeH+eV1vBmPuSLo/DxaON\n\t\t\t\t\t\tKCvHtgDOt1QzxMuqiCBfp5QFAgMBAAGjggHTMIIBzzAJBgNVHRMEAjAAMAsGA1Ud\n\t\t\t\t\t\tDwQEAwIFoDBFBgNVHR8EPjA8MDqgOKA2hjRodHRwOi8vU1ZSU2VjdXJlLUczLWNy\n\t\t\t\t\t\tbC52ZXJpc2lnbi5jb20vU1ZSU2VjdXJlRzMuY3JsMEYGA1UdIAQ/MD0wOwYLYIZI\n\t\t\t\t\t\tAYb4RQEHFwMwLDAqBggrBgEFBQcCARYeaHR0cHM6Ly93d3cudmVyaXNpZ24uY28u\n\t\t\t\t\t\tdWsvcnBhMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAfBgNVHSMEGDAW\n\t\t\t\t\t\tgBQNRFwWU0TBgn4dIKsl9AFj2L55pTB2BggrBgEFBQcBAQRqMGgwJAYIKwYBBQUH\n\t\t\t\t\t\tMAGGGGh0dHA6Ly9vY3NwLnZlcmlzaWduLmNvbTBABggrBgEFBQcwAoY0aHR0cDov\n\t\t\t\t\t\tL1NWUlNlY3VyZS1HMy1haWEudmVyaXNpZ24uY29tL1NWUlNlY3VyZUczLmNlcjBu\n\t\t\t\t\t\tBggrBgEFBQcBDARiMGChXqBcMFowWDBWFglpbWFnZS9naWYwITAfMAcGBSsOAwIa\n\t\t\t\t\t\tBBRLa7kolgYMu9BSOJsprEsHiyEFGDAmFiRodHRwOi8vbG9nby52ZXJpc2lnbi5j\n\t\t\t\t\t\tb20vdnNsb2dvMS5naWYwDQYJKoZIhvcNAQEFBQADggEBAJo/xmh2qJqsFbNlxD2V\n\t\t\t\t\t\twhco2sZBjNrNBk12LFGtcFJmeUXPPIcAFeKGlWx/37mKirZ1ryxRbgdEi6ShZo8n\n\t\t\t\t\t\tHGtdJlw9Wj0otC4Idr7PGPH/BEThfx27NYz2OzKiMvfm5vFfvHUPiSKdFlxleIBr\n\t\t\t\t\t\tbeDsBgKfA6YbhWElH6QIqmL9T6Qg2iMvAHdrgN6afMvuJ4h9iT5ad0LfuRxE3Gvq\n\t\t\t\t\t\tY7B/QdOZHDQVZ0KquFe/qnRDrWFhlvdPXRxwgByi9XOmbNVuRnlxfnbUOw8Jgks1\n\t\t\t\t\t\tH39D5zTQOKl+AEOTomKwTr53TFgDjSw8j9R/8Hi0f++axKR29JCknxBnJltVE+iU\n\t\t\t\t\t\tm7g="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF/jCCBOagAwIBAgIQM+YpmcylIPDSTgnHfWNmNTANBgkqhkiG9w0BAQUFADCB\n\t\t\t\t\t\ttTELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMR8wHQYDVQQL\n\t\t\t\t\t\tExZWZXJpU2lnbiBUcnVzdCBOZXR3b3JrMTswOQYDVQQLEzJUZXJtcyBvZiB1c2Ug\n\t\t\t\t\t\tYXQgaHR0cHM6Ly93d3cudmVyaXNpZ24uY29tL3JwYSAoYykxMDEvMC0GA1UEAxMm\n\t\t\t\t\t\tVmVyaVNpZ24gQ2xhc3MgMyBTZWN1cmUgU2VydmVyIENBIC0gRzMwHhcNMTIwMzE5\n\t\t\t\t\t\tMDAwMDAwWhcNMTgwMzE2MjM1OTU5WjCB6DELMAkGA1UEBhMCR0IxDTALBgNVBAgT\n\t\t\t\t\t\tBEF2b24xEDAOBgNVBAcUB0JyaXN0b2wxGzAZBgNVBAoUEklPUCBQdWJsaXNoaW5n\n\t\t\t\t\t\tIEx0ZDE1MDMGA1UECxQsVGVybXMgb2YgdXNlIGF0IHd3dy52ZXJpc2lnbi5jby51\n\t\t\t\t\t\tay9ycGEgKGMpMDUxIjAgBgNVBAsTGUF1dGhlbnRpY2F0ZWQgYnkgVmVyaVNpZ24x\n\t\t\t\t\t\tJzAlBgNVBAsTHk1lbWJlciwgVmVyaVNpZ24gVHJ1c3QgTmV0d29yazEXMBUGA1UE\n\t\t\t\t\t\tAxQOdGlja2V0LmlvcC5vcmcwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQC5WcglO3vKPNW09UA2GygrxCcozj67wA8Qd6d7Mu17EPrFzxRUP3h2jqk9wAPn\n\t\t\t\t\t\tvaIMcNooYHK/CzUawroiINRtdArpRT0lW1aNeXuiZ+9H6SU2KQKfMSI5WoXvIdW9\n\t\t\t\t\t\txUUnQyyptaXNVyXINAlkm5y+HTsrbRATRkjJN94Qw4ssRaYfWhOP66rpviu1DfLA\n\t\t\t\t\t\tVhhhc/uSme+la90C+bVQ9EHnfF5adHAMsGIiJbqdQCK4Hq5nFlzpW535GRqleHcE\n\t\t\t\t\t\t9x3HUppIJ32Q1ehYEvzwSIMBp8ACO7hgnSiYPbegpYPdeH+eV1vBmPuSLo/DxaON\n\t\t\t\t\t\tKCvHtgDOt1QzxMuqiCBfp5QFAgMBAAGjggHTMIIBzzAJBgNVHRMEAjAAMAsGA1Ud\n\t\t\t\t\t\tDwQEAwIFoDBFBgNVHR8EPjA8MDqgOKA2hjRodHRwOi8vU1ZSU2VjdXJlLUczLWNy\n\t\t\t\t\t\tbC52ZXJpc2lnbi5jb20vU1ZSU2VjdXJlRzMuY3JsMEYGA1UdIAQ/MD0wOwYLYIZI\n\t\t\t\t\t\tAYb4RQEHFwMwLDAqBggrBgEFBQcCARYeaHR0cHM6Ly93d3cudmVyaXNpZ24uY28u\n\t\t\t\t\t\tdWsvcnBhMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAfBgNVHSMEGDAW\n\t\t\t\t\t\tgBQNRFwWU0TBgn4dIKsl9AFj2L55pTB2BggrBgEFBQcBAQRqMGgwJAYIKwYBBQUH\n\t\t\t\t\t\tMAGGGGh0dHA6Ly9vY3NwLnZlcmlzaWduLmNvbTBABggrBgEFBQcwAoY0aHR0cDov\n\t\t\t\t\t\tL1NWUlNlY3VyZS1HMy1haWEudmVyaXNpZ24uY29tL1NWUlNlY3VyZUczLmNlcjBu\n\t\t\t\t\t\tBggrBgEFBQcBDARiMGChXqBcMFowWDBWFglpbWFnZS9naWYwITAfMAcGBSsOAwIa\n\t\t\t\t\t\tBBRLa7kolgYMu9BSOJsprEsHiyEFGDAmFiRodHRwOi8vbG9nby52ZXJpc2lnbi5j\n\t\t\t\t\t\tb20vdnNsb2dvMS5naWYwDQYJKoZIhvcNAQEFBQADggEBAJo/xmh2qJqsFbNlxD2V\n\t\t\t\t\t\twhco2sZBjNrNBk12LFGtcFJmeUXPPIcAFeKGlWx/37mKirZ1ryxRbgdEi6ShZo8n\n\t\t\t\t\t\tHGtdJlw9Wj0otC4Idr7PGPH/BEThfx27NYz2OzKiMvfm5vFfvHUPiSKdFlxleIBr\n\t\t\t\t\t\tbeDsBgKfA6YbhWElH6QIqmL9T6Qg2iMvAHdrgN6afMvuJ4h9iT5ad0LfuRxE3Gvq\n\t\t\t\t\t\tY7B/QdOZHDQVZ0KquFe/qnRDrWFhlvdPXRxwgByi9XOmbNVuRnlxfnbUOw8Jgks1\n\t\t\t\t\t\tH39D5zTQOKl+AEOTomKwTr53TFgDjSw8j9R/8Hi0f++axKR29JCknxBnJltVE+iU\n\t\t\t\t\t\tm7g="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ticket.iop.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ticket.iop.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ticket.iop.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ticket.iop.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ticket.iop.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ticket.iop.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dev.ticket.iop.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dev.ticket.iop.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dev.ticket.iop.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.ticket.iop.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.ticket.iop.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dev.ticket.iop.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://pmh.ticket.iop.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://pmh.ticket.iop.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://pmh.ticket.iop.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pmh.ticket.iop.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://pmh.ticket.iop.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://pmh.ticket.iop.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "18"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dev2.ticket.iop.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "19"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dev2.ticket.iop.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "20"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dev2.ticket.iop.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "21"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev2.ticket.iop.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "22"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev2.ticket.iop.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "23"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dev2.ticket.iop.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "24"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://test.ticket.iop.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "25"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://test.ticket.iop.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "26"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://test.ticket.iop.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "27"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.ticket.iop.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "28"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.ticket.iop.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "29"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://test.ticket.iop.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "30"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://test2.ticket.iop.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "31"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://test2.ticket.iop.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "32"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://test2.ticket.iop.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "33"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test2.ticket.iop.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "34"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test2.ticket.iop.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "35"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://test2.ticket.iop.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "36"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://hstalks.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@hstalks.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "HST - Support Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Shohat"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:barak@bazzisoft.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Barak"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://hstalks.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-08-26T08:48:02Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Henry Stewart Talks"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://hstalks.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Henry Stewart Talks Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hstalks.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://hstalks.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hstalks.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hstalks.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hstalks.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Online presentations by leading world experts in biomedicine, life sciences, management & marketing."
                  }
                ],
                "logo": [
                  {
                    "text": "https://hstalks.com/shibboleth/img/logo.gif",
                    "height": "78",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "96"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Henry Stewart Talks"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://hstalks.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://hstalks.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAPOoQOYTDcolMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\n\t\t\t\t\t\tBAMTFzIxMTA0Ni13d3cxLmhzdGFsa3MuY29tMB4XDTEzMDgxOTA4NDIzNVoXDTIz\n\t\t\t\t\t\tMDgxNzA4NDIzNVowIjEgMB4GA1UEAxMXMjExMDQ2LXd3dzEuaHN0YWxrcy5jb20w\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDDwUS4Z4M6ixecb4Vbc0df\n\t\t\t\t\t\tSM0rK7UoFyUZL/uSvhDcDQ1mVIaZW2/JVrNwvyoypQfezCAYrHhynA/JajADjftM\n\t\t\t\t\t\trh/TEUSh/BcL/xyohZ6WsyWn22vvQRRSWTNOvY0P+c2VnW59o6yS3Xlw7HVIBS3E\n\t\t\t\t\t\tjUBu2NDbU/UmxAAAgtv2ItIq3vY0zAj11ZsXypvGY9UiB2sWVdaz/DhffJlMUfKw\n\t\t\t\t\t\t6seKYXY24FoRLO1NsxPl5K3sA6h9kpvh/ptuoaqUiWurVW5b09Cag/C3qTWGZ3f4\n\t\t\t\t\t\tbSTAlNfBzESKAKQ6p7i7ykSGBxFOzyuSgOrdzBmiHHTSADN2s8kOqmMq8SdFRJ09\n\t\t\t\t\t\tAgMBAAGjRTBDMCIGA1UdEQQbMBmCFzIxMTA0Ni13d3cxLmhzdGFsa3MuY29tMB0G\n\t\t\t\t\t\tA1UdDgQWBBRcbPDBD7FUM6VckPyUUf1FJaoOljANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tQf4hezdmCmhSfbg3ocxbWrROdwYUAW8JaBxerYTKdVOVIVgsNHZh8e1joDYBcmjK\n\t\t\t\t\t\tTYGmC4C0mXhzdIwqnPdBpY7S8RXcl71FRbn4CdqOzIgn4O8Y4bgwMwSNs7JH+qFy\n\t\t\t\t\t\tOpekXMCX0409+PmdbNvQBFk3uznEiCdkW+P2RnlNF3HaAfd8U9YBVGZvlHE/i1Qt\n\t\t\t\t\t\tevKdTg8DniD9m/fmUJySob5xsbCyNb0DW+52VzVBlOWDteMdD5snEKi49Lod1RIN\n\t\t\t\t\t\t/SLLOwRq3tC3sJSqLJKeYl1AJrhenhReOXXMuk+CNGpag/HRtsObyEpV8upRF3wy\n\t\t\t\t\t\t5KwSB/UVbWmCLme4qlhnRQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hstalks.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://hstalks.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hstalks.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://hstalks.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://hstalks.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://hstalks.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.fareham.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.fareham.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/fareham.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/fareham.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fareham.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Fareham College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fareham.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://connect.sunet.se/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:noc@nordu.net"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "NORDUnet NOC"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://connect.sunet.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://connect.sunet.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://connect.sunet.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect.sunet.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect.sunet.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SUNET E-Meeting Service"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "SUNET E-Meeting Service (Adobe Connect Pro)"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://connect.sunet.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://connect.sunet.se/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://connect.sunet.se/Shibboleth.sso/DS/nordu.net",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://connect.sunet.se/Shibboleth.sso/DS/kalmar2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "4"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "connect01.acp.sunet.se"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://connect.sunet.se/shibboleth"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLjCCAhagAwIBAgIJALJTE8wpfDmAMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmNvbm5lY3QwMS5hY3Auc3VuZXQuc2UwHhcNMDkwOTAyMTIwNTIwWhcNMTkw\nODMxMTIwNTIwWjAhMR8wHQYDVQQDExZjb25uZWN0MDEuYWNwLnN1bmV0LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzaNMBLHGgzRrAHLQDUiM+xu6\nghKwdRqBcg171qVDeA4wSoVJLVeAY2xWKjudYzXtcwqL7qkDcHD3wOd0FLQSFfxE\no67z4chBMNrkK9b9NgdHWp/Nb8gsdYNZt2ZjJVOD/oWTFXRHZDJhqkXFvVjL1gKu\nE3a2vDK6LRqYCLx5cyFleuRoqBvMrDxKLHvmqxo+Qt2e+ntL1sDVyKeMxgZc2s0/\nxGYFFzSVDT08XrWlgpN0AmxhfC0ULDb8YzQiJxsdeZ3C57RnC0InabCCvzPQsy9t\nc1VU/TNXkkXQn3H5aC+LUu8olnYndtFac56k/OaAUPe15/1MQVXvL8vbGG6JkQID\nAQABo2kwZzBGBgNVHREEPzA9ghZjb25uZWN0MDEuYWNwLnN1bmV0LnNlhiNodHRw\nczovL2Nvbm5lY3Quc3VuZXQuc2Uvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUxPAGA++l\ntPOMkUezKJJrwSNAz/0wDQYJKoZIhvcNAQEFBQADggEBADJJgcI6VADyB8749iGB\nUbK97Zav6/YoX3jMH21tpO0+iZyPlfCxlDmNIBSSrHmNIs7g8sBSi+z8ko2IaSKS\nYa0fI0N+cvBoi+3Wfszq0LpUSu/5pMWiw3DacOCNesR76h+FKD/UPgUL+LDw7ebz\nK3aeVvtsIjPijrcCaUKrZg5dv/5CRx/oQLbV20L3xk5UTTO/RNrR1gef37yEowDd\nd8hQaQgw5uujjjdkr/6u03kjO6rEZAySsiBPGcpBDXAbk4lnJVQltP0MBE4pu+es\n0oZu+lC7LltiBjJxdh/7SaqdLbn7G7cApwQKqXHVFITX9ncVMM04FtM9MzMc9d4y\nbUs="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=connect01.acp.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "connect01.acp.sunet.se"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://connect.sunet.se/shibboleth"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLjCCAhagAwIBAgIJALJTE8wpfDmAMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmNvbm5lY3QwMS5hY3Auc3VuZXQuc2UwHhcNMDkwOTAyMTIwNTIwWhcNMTkw\nODMxMTIwNTIwWjAhMR8wHQYDVQQDExZjb25uZWN0MDEuYWNwLnN1bmV0LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzaNMBLHGgzRrAHLQDUiM+xu6\nghKwdRqBcg171qVDeA4wSoVJLVeAY2xWKjudYzXtcwqL7qkDcHD3wOd0FLQSFfxE\no67z4chBMNrkK9b9NgdHWp/Nb8gsdYNZt2ZjJVOD/oWTFXRHZDJhqkXFvVjL1gKu\nE3a2vDK6LRqYCLx5cyFleuRoqBvMrDxKLHvmqxo+Qt2e+ntL1sDVyKeMxgZc2s0/\nxGYFFzSVDT08XrWlgpN0AmxhfC0ULDb8YzQiJxsdeZ3C57RnC0InabCCvzPQsy9t\nc1VU/TNXkkXQn3H5aC+LUu8olnYndtFac56k/OaAUPe15/1MQVXvL8vbGG6JkQID\nAQABo2kwZzBGBgNVHREEPzA9ghZjb25uZWN0MDEuYWNwLnN1bmV0LnNlhiNodHRw\nczovL2Nvbm5lY3Quc3VuZXQuc2Uvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUxPAGA++l\ntPOMkUezKJJrwSNAz/0wDQYJKoZIhvcNAQEFBQADggEBADJJgcI6VADyB8749iGB\nUbK97Zav6/YoX3jMH21tpO0+iZyPlfCxlDmNIBSSrHmNIs7g8sBSi+z8ko2IaSKS\nYa0fI0N+cvBoi+3Wfszq0LpUSu/5pMWiw3DacOCNesR76h+FKD/UPgUL+LDw7ebz\nK3aeVvtsIjPijrcCaUKrZg5dv/5CRx/oQLbV20L3xk5UTTO/RNrR1gef37yEowDd\nd8hQaQgw5uujjjdkr/6u03kjO6rEZAySsiBPGcpBDXAbk4lnJVQltP0MBE4pu+es\n0oZu+lC7LltiBjJxdh/7SaqdLbn7G7cApwQKqXHVFITX9ncVMM04FtM9MzMc9d4y\nbUs="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=connect01.acp.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://connect.sunet.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://connect.sunet.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect.sunet.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect.sunet.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect.sunet.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://connect.sunet.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect.sunet.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://connect.sunet.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://connect.sunet.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://connect.sunet.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://converis.info/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://converis.info/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://converis.info/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://converis.info/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://converis.info/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://converis.info/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "converis.info"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICaTCCAdICCQCLAbSDwUzlcTANBgkqhkiG9w0BAQUFADB5MQswCQYDVQQGEwJE\nRTEMMAoGA1UECBMDQmFkMQwwCgYDVQQHEwNLYXIxEjAQBgNVBAoTCUF2ZWRhcyBB\nRzEWMBQGA1UEAxMNY29udmVyaXMuaW5mbzEiMCAGCSqGSIb3DQEJARYTY29udmVy\naXNAYXZlZGFzLmNvbTAeFw0wOTA2MzAxMzI3MzlaFw0xMDA2MzAxMzI3MzlaMHkx\nCzAJBgNVBAYTAkRFMQwwCgYDVQQIEwNCYWQxDDAKBgNVBAcTA0thcjESMBAGA1UE\nChMJQXZlZGFzIEFHMRYwFAYDVQQDEw1jb252ZXJpcy5pbmZvMSIwIAYJKoZIhvcN\nAQkBFhNjb252ZXJpc0BhdmVkYXMuY29tMIGfMA0GCSqGSIb3DQEBAQUAA4GNADCB\niQKBgQC0AXsGnmd4Ue0YGctAeKBjrRxENIszZj2NjzEZ5hjGXwsvgHExBYejynR4\nx0YRlF7kVg+hkZ5jIK+t3iIDLmUkRBlMZSbkQ0EYUBHvLXECtxggRZFoFEMssB20\nDm4F2I0bK51/ip6KZpltX81Zo44RpRjconBMc0FUZwjNYM2JUwIDAQABMA0GCSqG\nSIb3DQEBBQUAA4GBAIs+aQEHMnmVo8jm8NpzVYpPCN3/27F5IGtS0xgduAttJnYX\nlXi4upRjGaljdEqtTicQzpuZVZTnyik5KscVuSU4rtI5u1b7ybf6oL1xKiqkN7m1\nu7Xr9dYOqLXYBTCx/0NY5C+RF+dq2CYmY8fL/TILzmVGaZhXKzEYKIAPiKv3"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=converis@avedas.com,CN=converis.info,O=Avedas AG,L=Kar,ST=Bad,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "converis.info"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICaTCCAdICCQCLAbSDwUzlcTANBgkqhkiG9w0BAQUFADB5MQswCQYDVQQGEwJE\nRTEMMAoGA1UECBMDQmFkMQwwCgYDVQQHEwNLYXIxEjAQBgNVBAoTCUF2ZWRhcyBB\nRzEWMBQGA1UEAxMNY29udmVyaXMuaW5mbzEiMCAGCSqGSIb3DQEJARYTY29udmVy\naXNAYXZlZGFzLmNvbTAeFw0wOTA2MzAxMzI3MzlaFw0xMDA2MzAxMzI3MzlaMHkx\nCzAJBgNVBAYTAkRFMQwwCgYDVQQIEwNCYWQxDDAKBgNVBAcTA0thcjESMBAGA1UE\nChMJQXZlZGFzIEFHMRYwFAYDVQQDEw1jb252ZXJpcy5pbmZvMSIwIAYJKoZIhvcN\nAQkBFhNjb252ZXJpc0BhdmVkYXMuY29tMIGfMA0GCSqGSIb3DQEBAQUAA4GNADCB\niQKBgQC0AXsGnmd4Ue0YGctAeKBjrRxENIszZj2NjzEZ5hjGXwsvgHExBYejynR4\nx0YRlF7kVg+hkZ5jIK+t3iIDLmUkRBlMZSbkQ0EYUBHvLXECtxggRZFoFEMssB20\nDm4F2I0bK51/ip6KZpltX81Zo44RpRjconBMc0FUZwjNYM2JUwIDAQABMA0GCSqG\nSIb3DQEBBQUAA4GBAIs+aQEHMnmVo8jm8NpzVYpPCN3/27F5IGtS0xgduAttJnYX\nlXi4upRjGaljdEqtTicQzpuZVZTnyik5KscVuSU4rtI5u1b7ybf6oL1xKiqkN7m1\nu7Xr9dYOqLXYBTCx/0NY5C+RF+dq2CYmY8fL/TILzmVGaZhXKzEYKIAPiKv3"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=converis@avedas.com,CN=converis.info,O=Avedas AG,L=Kar,ST=Bad,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://converis.info/Shibboleth.sso/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://converis.info/Shibboleth.sso/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://converis.info/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://converis.info/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://converis.info/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://converis.info/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://converis.info/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://converis.info/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://converis.info/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://converis.info/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://press.endocrine.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso-support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "sso-support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso-tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "sso-tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://press.endocrine.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-02-11T17:17:12Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Endocrine Press"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://press.endocrine.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIJAIDfY9h2oTCVMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\n\t\t\t\t\t\tBAMTE3ByZXNzLmVuZG9jcmluZS5vcmcwHhcNMTMxMjExMDUzOTQ2WhcNMjMxMjA5\n\t\t\t\t\t\tMDUzOTQ2WjAeMRwwGgYDVQQDExNwcmVzcy5lbmRvY3JpbmUub3JnMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAw2Hn+r9tAA0W/oAXm9ShLD2wvy+YKkeV\n\t\t\t\t\t\tyrmUJbzdU8DeJ0mQ0SS6/Y3yKZEAT6vsh4j4xso51qtly0HHh459F8y8n3vd829B\n\t\t\t\t\t\tvhxRwdE5PMZixPbWyltRPbx3XogpswBust9PXIWW4Unmo37NZhxrZQrt7GHvVvIX\n\t\t\t\t\t\tkuUAEoTkLkSurvgkLuUrPs/wm179D50kbx4E50Uz7nvJYVyEWqHdf3TGaD8gMM1E\n\t\t\t\t\t\t6DR2w0j4pKHBAjkLDy9mHGV6c91qFVNnWrhACmX35JjBiCvc1+JTVRpapM1/JgzP\n\t\t\t\t\t\tHNTCJogvQNn5SDU3cZsZV0T1Bu23Pb8MlXoZPmWJy2djNPzw1JtO6QIDAQABo2kw\n\t\t\t\t\t\tZzBGBgNVHREEPzA9ghNwcmVzcy5lbmRvY3JpbmUub3JnhiZodHRwczovL3ByZXNz\n\t\t\t\t\t\tLmVuZG9jcmluZS5vcmcvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUG3/mbZR4LTuD9+bU\n\t\t\t\t\t\tdU0k7Li0WNkwDQYJKoZIhvcNAQEFBQADggEBAC4Sz/Os31gGbtIPklQ8SJHBs0ji\n\t\t\t\t\t\tMgbcKx15S3OkM06S75oDVI2qIrWXnAuWidexconSD35izsAscXlGI4EJgOflRJIB\n\t\t\t\t\t\t1kD9LOsHiz9kqUS2q7MNxWVloiQzxYCX14HGwPMtmKVTeTg5Vjo2BAuCRAhdxdFH\n\t\t\t\t\t\tseE5nYMbC4i31u1taTsM1Ydifr3UzmWTI5AZ884SYR9TfPh07rcW5m26Pmr3LLOa\n\t\t\t\t\t\twDROxGmfeBQHWTnOJkbhLdE2Rv1MqCWP4XzA1a8PsuBxyboLCQUYxsn4J8hOP3ZN\n\t\t\t\t\t\tb3NsdouxzxBdj+PJxciM9yTP1Ju8l1QfVXC68KZ2WeEowX3e84BW8jaZ0OM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://press.endocrine.org/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://press.endocrine.org/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://press.endocrine.org/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://adfs.driestar-educatief.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs.driestar-educatief.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-04-24T12:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/c228c1e233ead8d6893a3f502e2cb773",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Driestar Educatief"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Driestar Educatief"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/driestar.png",
                    "height": "30",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Driestar Educatief"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Driestar Educatief"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Driestar Educatief"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.driestar-educatief.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Driestar Educatief"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso.kenyon.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "hoffmanj@kenyon.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jared Hoffman"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "burgettw@kenyon.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Weylin Burgett"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "davrayn@kenyon.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Niranjan Davray"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.kenyon.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.kenyon.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.kenyon.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.kenyon.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kenyon.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kenyon College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAK2tE/i3d4cbJjnF+rIPl/2yeGs7MA0GCSqGSIb3DQEB\nCwUAMBkxFzAVBgNVBAMMDnNzby5rZW55b24uZWR1MB4XDTE1MTAyMjIwMzk1MVoX\nDTM1MTAyMjIwMzk1MVowGTEXMBUGA1UEAwwOc3NvLmtlbnlvbi5lZHUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCJ3dWrRgSuFJweEWO/wpNKdLkxRVRm\nmoK1qxla4aks7/msfulsAVm8qIG8gDlMKGQKlIKkimam8vKGXLwHEUizLkUb2p+o\nmoYQXW3DCykRrInwlfREagnWbIKE8Z+O8TskqJCzLpCluHLLkrohrkovTgrSGC4q\nYe6EqPLQ62cSP6n5IBlQ+8fg02ghszAp+qar4/pm/V+6GmITsFC6TCM9Co2TKovu\nBCTI1IIb0siKkuUYI8BsExpRIU+WOuCvYwc/J0/IYt+4LmgTiHDGOmqnJZbLu75c\nDWBYWIHARJuMVEHNqBy62rNamE3X0NLG5C3O3TIqd/qvovu/H/Y+1oqLAgMBAAGj\nYzBhMB0GA1UdDgQWBBQIboRDapuoD4QZqK2AXEjGhOV26DBABgNVHREEOTA3gg5z\nc28ua2VueW9uLmVkdYYlaHR0cHM6Ly9zc28ua2VueW9uLmVkdS9pZHAvc2hpYmJv\nbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAGUv/Y4q/H7JQTlYw78ZFcJm95vmDMzUu\nP8QEz14ohtWrCuXmy55RMzVNI4f0huJWvrhHzCf0soJrbJcxImbRDjqL2CPhhERh\n6KHG6XPzkgNd4toi1X4txTH4uckfY3fe4VVwtag8g2w0q2C74D4MQKwXWMq3oVJo\nJ0HQGT3NstNQjx/goFWRZMrI0mBm33FX1bmMNaSaUzJQ1yK3KjCOxYySbGDV87QE\nLkWOh5+fHd7q2DPFtok5j37RUr3hmISN7RGNQqDn7WExZxL+rw8twptbjLuRzuaf\nq+cjT7zoWgOltRQimTXSpr3o4+dhKHnttZ/r6k+m0jjfKeJzueOnwQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAKh5Jzh1FnqrN8RCEbmOwhRu1fwZMA0GCSqGSIb3DQEB\nCwUAMBkxFzAVBgNVBAMMDnNzby5rZW55b24uZWR1MB4XDTE1MTAyMjIwMzk0OVoX\nDTM1MTAyMjIwMzk0OVowGTEXMBUGA1UEAwwOc3NvLmtlbnlvbi5lZHUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDCnDS4gR4UUICN60zJEpzRB5PPM7ro\nnahB+w0JygC6TczMhGUYISuPCFzI6RmM1gCNxcK84EBysKt9CpRE9yUmCJLo/cmf\nbVyOWpP3KFJyZscS6wr9kv2ZbbSZuka0E9bjS15h0duWQ644kx8ujfhnr8smwEQr\nJcc/7v/gCstdbr994p1/94rmO0HRdez1RgFhlBA2Vodz0Jhj6YKqttYEP19WX8C8\nvwfGenjtny2DeXCzbNgJA79kdLMG4NH/BqF/IgEyh8r6cugJ0eV/YLK3RDKDa1xm\nGIMjOLZQFPZ4S7lqNFUV87gK4o+yVDiMiWIQaDMOXLn00FY+9Kkysw2XAgMBAAGj\nYzBhMB0GA1UdDgQWBBRgAnH54F6pj/xxhxn/s4Jz0L9D+zBABgNVHREEOTA3gg5z\nc28ua2VueW9uLmVkdYYlaHR0cHM6Ly9zc28ua2VueW9uLmVkdS9pZHAvc2hpYmJv\nbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAe3zZXvo/Pql6kmOORt1fWJwxXrchUfCe\nEuPl8JI75kBX2OrB0pBkSG9oXEwAjNIHs4lLpIRMtti531czVWeZ6vuek2dddv4w\nefnPBJ6bU12geroCPRri6dtE57PxfaR6PLxUZQzkR4z2Nkj1injgyl/+pAQrbbre\n79MHLnG2jy5eVUl7FmYQClrzQgKApRaN3sdAlO1/S3mAAWGU0pElbj6jYwjYnQU6\ntAyR/K8zodgqRQTLQ8SNVIFBGGwfxfknwsQAfnPGV5f53HQGfTxtoJnn/xzkZsI+\nKIV7jeKH4X9c2EWe5OCrzq1lK8pTN5rdICjsVTE1ULAWyQsBKmjlzA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://lbis.kenyon.edu/facilities-technology/help"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Kenyon College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kenyon.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Kenyon College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://student.utb.grayzone.ladok.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://student.utb.grayzone.ladok.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.utb.grayzone.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.utb.grayzone.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.utb.grayzone.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.utb.grayzone.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.utb.grayzone.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://student.utb.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://student.utb.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://student.utb.grayzone.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok student.utb.grayzone.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok student.utb.grayzone.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://student.utb.grayzone.ladok.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "student.utb.grayzone.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIJAL6+vvBLbienMA0GCSqGSIb3DQEBCwUAMCgxJjAkBgNV\nBAMTHXN0dWRlbnQudXRiLmdyYXl6b25lLmxhZG9rLnNlMB4XDTE2MDMxNDExMzU1\nMVoXDTI2MDMxMjExMzU1MVowKDEmMCQGA1UEAxMdc3R1ZGVudC51dGIuZ3JheXpv\nbmUubGFkb2suc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCrwO5t\n+t/WjW2ub3ds5fX0J1LKHHxX23zdhtgvZSvwhlJeJPzDaHVvDFs8A/hgCBcem+bJ\nXxtLsMG/uA2VMgDpG8dd1x/CtOBiLhehLLK44RwLG1A3Wf4BQgC9A9Yy+101ySDg\nQmTdPxPUoV/QdE2RNqIt7xtDU5xJsRR/TCcdPesYVNnvwJ/cTGpjJv4TwjFyds8C\nyt9tklRFO0QpcTTctN5jwHWOcS5F5XUz/yxymf0nIeVjcC+hBwYlRLSEVndTXH94\nY3uEfD3Nr9Wh3fvVz3yFKvMvJ3+7rdAmazp8kr5ZFOz+mRp78WNWMEneeQ3E657w\nzeqNnnUn4WjDg1LbAgMBAAGjeTB3MFYGA1UdEQRPME2CHXN0dWRlbnQudXRiLmdy\nYXl6b25lLmxhZG9rLnNlhixodHRwczovL3N0dWRlbnQudXRiLmdyYXl6b25lLmxh\nZG9rLnNlL2d1aS1zcDAdBgNVHQ4EFgQUAoLT9XTxfcWhOBxQGxepp8ZhQR0wDQYJ\nKoZIhvcNAQELBQADggEBAFaVox+9QFZO6kud6xiIzTtdZA6UhfB7k7UdnpoTB5kp\nWgLtoBl10sEs4J4fdfNRqFmM0y6M6Ui2KMQ8CwVL3wPUiA4k6WmvX2wL7iNaULuh\n5NW6E6E1VV4AkF3aGXv+wP86oCR+7xUxGabJIP4A5wkE4EFnb5o8YfHHFlZ2kENF\nyZNMRxHA6hxBu4AUwVHn9w3NeLFvdz+VIoRdTCwJiKQIdOiIwh4uqdz+Nb27JawK\nFcB1uUnfHOFrWxR3hRPy/mxOtvCbBn1Ze80nVHwGUXnZU03EQD79EsrojE7X6Dy9\nAPPgdPDSoTzmfWG0jod4DFTR1ldSdgpydyNVnmBMHaM="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=student.utb.grayzone.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.utb.grayzone.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.utb.grayzone.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.utb.grayzone.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.utb.grayzone.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.utb.grayzone.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.utb.grayzone.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://student.utb.grayzone.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://student.utb.grayzone.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://student.utb.grayzone.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://royalsocietypublishing.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://royalsocietypublishing.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-01-16T18:24:44Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Royal Society Publishing Organization"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://royalsocietypublishing.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HighWire Press, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.highwire.org/applications/roysocjnls/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.highwire.org/applications/roysocjnls/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIJAMTRVlqTJ11lMA0GCSqGSIb3DQEBBQUAMIG+MQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBD\n\t\t\t\t\t\taXR5MRcwFQYDVQQKEw5IaWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUx\n\t\t\t\t\t\tIDAeBgNVBAMTF3NoaWJib2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkB\n\t\t\t\t\t\tFiZzaGliYm9sZXRoLWFkbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTAeFw0xNDA0\n\t\t\t\t\t\tMTUxOTQzMDNaFw0yNDA0MTIxOTQzMDNaMIG+MQswCQYDVQQGEwJVUzETMBEGA1UE\n\t\t\t\t\t\tCBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBDaXR5MRcwFQYDVQQKEw5I\n\t\t\t\t\t\taWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUxIDAeBgNVBAMTF3NoaWJi\n\t\t\t\t\t\tb2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkBFiZzaGliYm9sZXRoLWFk\n\t\t\t\t\t\tbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALPB99M9iWjentrddY/rLgzKn1X0j4Ao191iyiowBBt/r/pmn2oz\n\t\t\t\t\t\tfrbONkkTVBB++mNtiufK6jyKnBM5mffPOkXHRo+K1DQec7TvpQ1PmLv/BpBgPrr9\n\t\t\t\t\t\tldViOSUnYJuB0IgJVV8oylgeH2Ay0XRkNPlBUjBA2fUPWVpXcvFe+aD2tLdVR9uO\n\t\t\t\t\t\tXvfTMxAEGqzxTU+OxO6pW2sBXNBmGvZQ0TRyovQh5+pTURY/lm0V/iWvRmRe51WE\n\t\t\t\t\t\tO/nhYyvRuMmNj8EL38o10S9TXuCkVzY00hK5cclaFge7gz/tfjmadVVcbe8xCVxc\n\t\t\t\t\t\tnb1lhmt1kH2XtKvU5hyZMTO+VUfXQvqcQyECAwEAAaN7MHkwCQYDVR0TBAIwADAs\n\t\t\t\t\t\tBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYD\n\t\t\t\t\t\tVR0OBBYEFJpUZq/XaW9/bPvjffkxX0IDvuPiMB8GA1UdIwQYMBaAFJpUZq/XaW9/\n\t\t\t\t\t\tbPvjffkxX0IDvuPiMA0GCSqGSIb3DQEBBQUAA4IBAQCq/FF56ZB1cL3KbniEJP99\n\t\t\t\t\t\tU9wTD6KpOrWxvqNbUSV1cefLf5cYHonOjy6oAJSSBSNuP7U5Q//0tXtkvlJoqGUY\n\t\t\t\t\t\tvqngmeg9wLZ/Fla3tXcDdTj0n1F+NZOx9vBDacIk0Ua4aHXDA4bdytzkV1QyZDRq\n\t\t\t\t\t\tQ8vq7RoQ8E5IF7Cll+kt2dZXQk8o6Qp3w2ppoMRtYdKOQassqn+V1MYcMPgdxZkS\n\t\t\t\t\t\tDrcgzktR/JMb5OmPrp4mSy1OWDGrFvUIigsLBPZV9tw1f7y42lnbmQas3RCS30yr\n\t\t\t\t\t\tCtUPT/PQDkCdBRViGmmMkYwjdaOTiHOJveWtrVXu8vLvO36pqFF4Kft0pgqlfvAE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.highwire.org/applications/roysocjnls/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.highwire.org/applications/roysocjnls/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.highwire.org/applications/roysocjnls/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.highwire.org/applications/roysocjnls/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.csudh.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "elazarian@csudh.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Edgar Lazarian"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.csudh.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.csudh.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.csudh.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFizCCBHOgAwIBAgICAm0wDQYJKoZIhvcNAQEFBQAwVjELMAkGA1UEBhMCVVMx\nHDAaBgNVBAoTE0luQ29tbW9uIEZlZGVyYXRpb24xKTAnBgNVBAMTIEluQ29tbW9u\nIENlcnRpZmljYXRpb24gQXV0aG9yaXR5MB4XDTA5MDgxMDE3NTMxNFoXDTExMDgx\nMTE3NTMxNFowGDEWMBQGA1UEAxMNaWRwLmNzdWRoLmVkdTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAKfAyfjcPsk/7da74lfelxUZZ8sHUsakoVd+94TL\nT53OzSsZrCz0GgH1ECzYbYrojfv6L3dZmBCwJzssmK0sziUTyoxPT1/IwpG1Nfmn\nV7UKCZcDVB3FCUkjdjhp9gnmfRHHF3GOp2PbLM23gAqKJasKyAPBrvIE0YEr1vnN\n8KPI36lPmDkZ+poY70RGLt4oT72Ezzt7muvUQrTc/KEG4BbhUCzcJegVIQvMLMu8\nPgHwB2Qc2riUSDUkL3ZXzGunHEsdvGGLmBF1DyVa2T8lDAfW6rhFqewSo7IzWQtN\nQbqsJ4jX8f7DSYGHbphcVLgd/5NrDr7KeMgBIUMwnrgROBsCAwEAAaOCAp8wggKb\nMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUF\nBwMBBggrBgEFBQcDAjAdBgNVHQ4EFgQUwqZaeiLSv2CSUIBYNHS6xPRSkIUwfgYD\nVR0jBHcwdYAUky3IYRitY+ObZbOd3Y2TuufKY0WhWqRYMFYxCzAJBgNVBAYTAlVT\nMRwwGgYDVQQKExNJbkNvbW1vbiBGZWRlcmF0aW9uMSkwJwYDVQQDEyBJbkNvbW1v\nbiBDZXJ0aWZpY2F0aW9uIEF1dGhvcml0eYIBADCBsgYIKwYBBQUHAQEEgaUwgaIw\nTwYIKwYBBQUHMAKGQ2h0dHA6Ly9pbmNvbW1vbmNhMS5pbmNvbW1vbmZlZGVyYXRp\nb24ub3JnL2JyaWRnZS9jZXJ0cy9jYS1jZXJ0cy5wN2IwTwYIKwYBBQUHMAKGQ2h0\ndHA6Ly9pbmNvbW1vbmNhMi5pbmNvbW1vbmZlZGVyYXRpb24ub3JnL2JyaWRnZS9j\nZXJ0cy9jYS1jZXJ0cy5wN2IwgY0GA1UdHwSBhTCBgjA/oD2gO4Y5aHR0cDovL2lu\nY29tbW9uY3JsMS5pbmNvbW1vbmZlZGVyYXRpb24ub3JnL2NybC9lZWNybHMuY3Js\nMD+gPaA7hjlodHRwOi8vaW5jb21tb25jcmwyLmluY29tbW9uZmVkZXJhdGlvbi5v\ncmcvY3JsL2VlY3Jscy5jcmwwXgYDVR0gBFcwVTBTBgsrBgEEAa4jAQQBATBEMEIG\nCCsGAQUFBwIBFjZodHRwOi8vaW5jb21tb25jYS5pbmNvbW1vbmZlZGVyYXRpb24u\nb3JnL3ByYWN0aWNlcy5wZGYwGAYDVR0RBBEwD4INaWRwLmNzdWRoLmVkdTANBgkq\nhkiG9w0BAQUFAAOCAQEAIJVMQA/nHK/g2Cl2Q18Es9TZYwOX9uT7IvoTwIFl/Yq0\nuntwsTmtPA2R6nEm5vl57Un0Fx3ngOg5UcKeMc9mV/uRrm2E9ODRZzynYEn4H54p\n2O3C2zN0oVniMjcvVh390EykGYIFNazPvKpl2SYSFALALW5meas8K3vFus71oqu+\nr3cf52wnQAsbE5cXL4Mf9wDvAFOlK+pgkstgJvpibk/JfUesgSCvmZwGyrQGK1lR\n0wPmWZthqEjNQhZ6UVb1sSFijfYNnsrPZS+xujaKqzJrSXLR09VtAUYPuP20PY/N\nYzlLClhgY9axf7qCtv/2rUKxME2tnK8GLNnGXGkvTg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csudh.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.csudh.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.csudh.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.csudh.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.csudh.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.csudh.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csudh.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "California State University, Dominguez Hills"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFizCCBHOgAwIBAgICAm0wDQYJKoZIhvcNAQEFBQAwVjELMAkGA1UEBhMCVVMx\nHDAaBgNVBAoTE0luQ29tbW9uIEZlZGVyYXRpb24xKTAnBgNVBAMTIEluQ29tbW9u\nIENlcnRpZmljYXRpb24gQXV0aG9yaXR5MB4XDTA5MDgxMDE3NTMxNFoXDTExMDgx\nMTE3NTMxNFowGDEWMBQGA1UEAxMNaWRwLmNzdWRoLmVkdTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAKfAyfjcPsk/7da74lfelxUZZ8sHUsakoVd+94TL\nT53OzSsZrCz0GgH1ECzYbYrojfv6L3dZmBCwJzssmK0sziUTyoxPT1/IwpG1Nfmn\nV7UKCZcDVB3FCUkjdjhp9gnmfRHHF3GOp2PbLM23gAqKJasKyAPBrvIE0YEr1vnN\n8KPI36lPmDkZ+poY70RGLt4oT72Ezzt7muvUQrTc/KEG4BbhUCzcJegVIQvMLMu8\nPgHwB2Qc2riUSDUkL3ZXzGunHEsdvGGLmBF1DyVa2T8lDAfW6rhFqewSo7IzWQtN\nQbqsJ4jX8f7DSYGHbphcVLgd/5NrDr7KeMgBIUMwnrgROBsCAwEAAaOCAp8wggKb\nMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUF\nBwMBBggrBgEFBQcDAjAdBgNVHQ4EFgQUwqZaeiLSv2CSUIBYNHS6xPRSkIUwfgYD\nVR0jBHcwdYAUky3IYRitY+ObZbOd3Y2TuufKY0WhWqRYMFYxCzAJBgNVBAYTAlVT\nMRwwGgYDVQQKExNJbkNvbW1vbiBGZWRlcmF0aW9uMSkwJwYDVQQDEyBJbkNvbW1v\nbiBDZXJ0aWZpY2F0aW9uIEF1dGhvcml0eYIBADCBsgYIKwYBBQUHAQEEgaUwgaIw\nTwYIKwYBBQUHMAKGQ2h0dHA6Ly9pbmNvbW1vbmNhMS5pbmNvbW1vbmZlZGVyYXRp\nb24ub3JnL2JyaWRnZS9jZXJ0cy9jYS1jZXJ0cy5wN2IwTwYIKwYBBQUHMAKGQ2h0\ndHA6Ly9pbmNvbW1vbmNhMi5pbmNvbW1vbmZlZGVyYXRpb24ub3JnL2JyaWRnZS9j\nZXJ0cy9jYS1jZXJ0cy5wN2IwgY0GA1UdHwSBhTCBgjA/oD2gO4Y5aHR0cDovL2lu\nY29tbW9uY3JsMS5pbmNvbW1vbmZlZGVyYXRpb24ub3JnL2NybC9lZWNybHMuY3Js\nMD+gPaA7hjlodHRwOi8vaW5jb21tb25jcmwyLmluY29tbW9uZmVkZXJhdGlvbi5v\ncmcvY3JsL2VlY3Jscy5jcmwwXgYDVR0gBFcwVTBTBgsrBgEEAa4jAQQBATBEMEIG\nCCsGAQUFBwIBFjZodHRwOi8vaW5jb21tb25jYS5pbmNvbW1vbmZlZGVyYXRpb24u\nb3JnL3ByYWN0aWNlcy5wZGYwGAYDVR0RBBEwD4INaWRwLmNzdWRoLmVkdTANBgkq\nhkiG9w0BAQUFAAOCAQEAIJVMQA/nHK/g2Cl2Q18Es9TZYwOX9uT7IvoTwIFl/Yq0\nuntwsTmtPA2R6nEm5vl57Un0Fx3ngOg5UcKeMc9mV/uRrm2E9ODRZzynYEn4H54p\n2O3C2zN0oVniMjcvVh390EykGYIFNazPvKpl2SYSFALALW5meas8K3vFus71oqu+\nr3cf52wnQAsbE5cXL4Mf9wDvAFOlK+pgkstgJvpibk/JfUesgSCvmZwGyrQGK1lR\n0wPmWZthqEjNQhZ6UVb1sSFijfYNnsrPZS+xujaKqzJrSXLR09VtAUYPuP20PY/N\nYzlLClhgY9axf7qCtv/2rUKxME2tnK8GLNnGXGkvTg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California State University, Dominguez Hills"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csudh.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California State University, Dominguez Hills"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://identity.unamur.be/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Technical Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "siu-serveurs@unamur.be"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://identity.unamur.be/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://federation.belnet.be/files/Belnet-metadata-registration-practice-statement.txt"
              }
            ],
            "registration_instant": "2012-03-27T12:00:00Z",
            "registration_authority": "http://federation.belnet.be/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUOFEO17meQZ7yZbR00GFaaEZCBIUwDQYJKoZIhvcNAQEF\nBQAwHTEbMBkGA1UEAwwSaWRlbnRpdHkudW5hbXVyLmJlMB4XDTE0MTAwMTExMzAz\nMloXDTM0MTAwMTExMzAzMlowHTEbMBkGA1UEAwwSaWRlbnRpdHkudW5hbXVyLmJl\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoBOrnhzyOHqWdf3eka1y\n4cQ9PU9DgvGVBKPkBVy8N3vNXrFQIgMbObDS1l9eYYuvyY+hHAPucMS0i1OdP2Aj\nEv/UE4gx4z2hiXwQb/ne1cdwJ0hocacKwoj8U7VjOcVmb6jkj8iQ+cf4xVm8g4tH\nrdYJ44FWWzyTbhJqdsh7LlxLBl7OiXNib9Mdmgc0/yR21q4z6Gfzq9lAL8n0Qol2\noa32RWvsOdbvUsfHGH+MzcmI7KENiz/ppbrgmKDqpfWX9RNNDzE4RIDqt4Vh40Is\nEjAuizxuaWGGuGE/aPxdUji6xUB18USEE7/yMm6PGfgsibwxBmFGBiUq8qrS7sH0\nCwIDAQABo2swaTAdBgNVHQ4EFgQUY7BxMDAhCKPAsUtkHiqjikltMpAwSAYDVR0R\nBEEwP4ISaWRlbnRpdHkudW5hbXVyLmJlhilodHRwczovL2lkZW50aXR5LnVuYW11\nci5iZS9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAjoKO8E/Geoa1\n6W+nbLFir4Fm6k9SW4cJW3Wabnf5yC7M5Qf7CDPQOmt/dC/IwKHLfkMu/AfmbOEe\n8GmK3mrqWZEAU/R7vg/AbiX9ci0PGOeSg1Zg4TE1Gl+vDCx47gBsqNJk/j09EJ0E\nQQrqWCW9oHfWcjENvvErtwTKuYhGV/8BdQNDd9D+ji40xn2JVLhnTyeyCpVYAGFh\nPiz6aamOjjjdutjif20mGC2CWwQOF754FFmYl9Zy11PlcKtxmU8h3rMUO+L6u6jp\nbvVxLwAnn3hdXccfJDUwVmmmeK4ePR3brG0NPafaCdQdFYvSci45kcjQ2bnT13CG\nsAFHfgCexQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unamur.be"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://identity.unamur.be:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://identity.unamur.be:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://identity.unamur.be/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://identity.unamur.be/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://identity.unamur.be:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://identity.unamur.be/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://identity.unamur.be/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://identity.unamur.be/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://identity.unamur.be/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://identity.unamur.be:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://identity.unamur.be:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unamur.be"
              },
              {
                "description": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Le personnel et les etudiants de l'Universite de Namur - Belgique"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Staff and students from the University of Namur - Belgium"
                  }
                ],
                "display_name": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universite de Namur"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Namur"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "unamur.be"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "50.466101,4.860253"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "138.48.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:6a8:3900::/64"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUOFEO17meQZ7yZbR00GFaaEZCBIUwDQYJKoZIhvcNAQEF\nBQAwHTEbMBkGA1UEAwwSaWRlbnRpdHkudW5hbXVyLmJlMB4XDTE0MTAwMTExMzAz\nMloXDTM0MTAwMTExMzAzMlowHTEbMBkGA1UEAwwSaWRlbnRpdHkudW5hbXVyLmJl\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoBOrnhzyOHqWdf3eka1y\n4cQ9PU9DgvGVBKPkBVy8N3vNXrFQIgMbObDS1l9eYYuvyY+hHAPucMS0i1OdP2Aj\nEv/UE4gx4z2hiXwQb/ne1cdwJ0hocacKwoj8U7VjOcVmb6jkj8iQ+cf4xVm8g4tH\nrdYJ44FWWzyTbhJqdsh7LlxLBl7OiXNib9Mdmgc0/yR21q4z6Gfzq9lAL8n0Qol2\noa32RWvsOdbvUsfHGH+MzcmI7KENiz/ppbrgmKDqpfWX9RNNDzE4RIDqt4Vh40Is\nEjAuizxuaWGGuGE/aPxdUji6xUB18USEE7/yMm6PGfgsibwxBmFGBiUq8qrS7sH0\nCwIDAQABo2swaTAdBgNVHQ4EFgQUY7BxMDAhCKPAsUtkHiqjikltMpAwSAYDVR0R\nBEEwP4ISaWRlbnRpdHkudW5hbXVyLmJlhilodHRwczovL2lkZW50aXR5LnVuYW11\nci5iZS9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAjoKO8E/Geoa1\n6W+nbLFir4Fm6k9SW4cJW3Wabnf5yC7M5Qf7CDPQOmt/dC/IwKHLfkMu/AfmbOEe\n8GmK3mrqWZEAU/R7vg/AbiX9ci0PGOeSg1Zg4TE1Gl+vDCx47gBsqNJk/j09EJ0E\nQQrqWCW9oHfWcjENvvErtwTKuYhGV/8BdQNDd9D+ji40xn2JVLhnTyeyCpVYAGFh\nPiz6aamOjjjdutjif20mGC2CWwQOF754FFmYl9Zy11PlcKtxmU8h3rMUO+L6u6jp\nbvVxLwAnn3hdXccfJDUwVmmmeK4ePR3brG0NPafaCdQdFYvSci45kcjQ2bnT13CG\nsAFHfgCexQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universite de Namur"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unamur.be"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNamur"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://1010SE17FAM-V03.famerp.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Joao Marcelo Rondina"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "joaomarcelo@famerp.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://1010SE17FAM-V03.famerp.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3jCCAcYCAQAwDQYJKoZIhvcNAQEFBQAwNTEMMAoGA1UECxMDQ1BEMQswCQYD\nVQQGEwJCUjEYMBYGA1UEAxMPMTAxMFNFMTdGQU0tVjAzMB4XDTE1MTExMTE4MTEx\nOFoXDTE4MTExMDE4MTExOFowNTEMMAoGA1UECxMDQ1BEMQswCQYDVQQGEwJCUjEY\nMBYGA1UEAxMPMTAxMFNFMTdGQU0tVjAzMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEAs35C96cae6HotPptuHb31jj78SqAX2VAW+ghyUZvG8BS3zTBnc0o\npqB5xkKiSnHUTTBIShlpRRgLnwv/5K99Yqkw0gL4je6c5t+l+nU0NNAlkCp6Sdac\nmI/JdXm72rED2VX2OuTLuZZt4ezoblhaJl4rfxVU0N7gto4vcLsUsHrTp9BskSk4\n0QbCfGhMuDNm7i8d2z0y6L/fy++bjKkzzsBTu71ZDTIy3hmrrZDuPSdPKFoCQz/R\nQHMBq2n4BJFYuDGoadeNHFiPJfpdqOOOF00FQCJtrFaJeRM5+CEeKh5qoFSt6Krd\nJ+Ysn+isP3tu2HaPKzcpi83uAXt+EdHkDwIDAQABMA0GCSqGSIb3DQEBBQUAA4IB\nAQCUvPYzLFvAoSdLliRuUKcNNiGFOwUr0DBUELsN+tpKn5sKAJhfONkwihG3Ym40\n6LUtxKuOK1gIDEPINhcv91d81dQowUfjEwd1ovaoSngK5D82zGx98cYHff0S6ahH\nwOJxhkLH4dzLOO+TlRBK0XJHcgDadgkIgPbEOVUy5A3YvFm0Sz2FGu55oQItilK1\nbvlYxi/3H8gw7Q5gl0kpFqzajcsNPmLJHqjYHkCeKG3d9Cn1aQNozqJToXTz9D6c\n18BMRBxE6HjineIuaNcVPROkHt42bS3I4+InmCQCzaH8L4dPBTTxcFnSQIMa+Ko0\nOIFoXRLcQ4+oGzgukcHZg8eG"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "famerp.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://1010SE17FAM-V03.famerp.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://1010SE17FAM-V03.famerp.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://1010SE17FAM-V03.famerp.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://1010SE17FAM-V03.famerp.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://1010SE17FAM-V03.famerp.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://1010SE17FAM-V03.famerp.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://1010SE17FAM-V03.famerp.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://1010SE17FAM-V03.famerp.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "famerp.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.famerp.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.famerp.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "FAMERP - Faculdade de Medicina de Rio Preto"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "FAMERP - Faculdade de Medicina de Rio Preto"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FAMERP - Faculdade de Medicina de Rio Preto"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FAMERP - Faculdade de Medicina de Rio Preto"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3jCCAcYCAQAwDQYJKoZIhvcNAQEFBQAwNTEMMAoGA1UECxMDQ1BEMQswCQYD\nVQQGEwJCUjEYMBYGA1UEAxMPMTAxMFNFMTdGQU0tVjAzMB4XDTE1MTExMTE4MTEx\nOFoXDTE4MTExMDE4MTExOFowNTEMMAoGA1UECxMDQ1BEMQswCQYDVQQGEwJCUjEY\nMBYGA1UEAxMPMTAxMFNFMTdGQU0tVjAzMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEAs35C96cae6HotPptuHb31jj78SqAX2VAW+ghyUZvG8BS3zTBnc0o\npqB5xkKiSnHUTTBIShlpRRgLnwv/5K99Yqkw0gL4je6c5t+l+nU0NNAlkCp6Sdac\nmI/JdXm72rED2VX2OuTLuZZt4ezoblhaJl4rfxVU0N7gto4vcLsUsHrTp9BskSk4\n0QbCfGhMuDNm7i8d2z0y6L/fy++bjKkzzsBTu71ZDTIy3hmrrZDuPSdPKFoCQz/R\nQHMBq2n4BJFYuDGoadeNHFiPJfpdqOOOF00FQCJtrFaJeRM5+CEeKh5qoFSt6Krd\nJ+Ysn+isP3tu2HaPKzcpi83uAXt+EdHkDwIDAQABMA0GCSqGSIb3DQEBBQUAA4IB\nAQCUvPYzLFvAoSdLliRuUKcNNiGFOwUr0DBUELsN+tpKn5sKAJhfONkwihG3Ym40\n6LUtxKuOK1gIDEPINhcv91d81dQowUfjEwd1ovaoSngK5D82zGx98cYHff0S6ahH\nwOJxhkLH4dzLOO+TlRBK0XJHcgDadgkIgPbEOVUy5A3YvFm0Sz2FGu55oQItilK1\nbvlYxi/3H8gw7Q5gl0kpFqzajcsNPmLJHqjYHkCeKG3d9Cn1aQNozqJToXTz9D6c\n18BMRBxE6HjineIuaNcVPROkHt42bS3I4+InmCQCzaH8L4dPBTTxcFnSQIMa+Ko0\nOIFoXRLcQ4+oGzgukcHZg8eG"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "FAMERP - Faculdade de Medicina de Rio Preto"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "FAMERP - Faculdade de Medicina de Rio Preto"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.famerp.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.famerp.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "FAMERP - Faculdade de Medicina de Rio Preto"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "FAMERP - Faculdade de Medicina de Rio Preto"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ku-primo.hosted.exlibrisgroup.com/shib",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ku-primo.hosted.exlibrisgroup.com/shib",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-03-28T14:43:10Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Primo Resource Discovery at Kingston University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://exlibrisgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ex Libris (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ku-primo.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ku-primo.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ku-primo.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ku-primo.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ku-primo.hosted.exlibrisgroup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ku-primo.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ku-primo.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is an Ex Libris Primo Hosted SP on behalf of the Kingston University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kingston University - Primo Production"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNjCCAh6gAwIBAgIJAOj3Zz/p9Vx7MA0GCSqGSIb3DQEBBQUAMDAxLjAsBgNV\n\t\t\t\t\t\tBAMTJWRjMDNrZzAzNTFldS5ob3N0ZWQuZXhsaWJyaXNncm91cC5jb20wHhcNMTQw\n\t\t\t\t\t\tMjI2MDYwNDE0WhcNMjQwMjI0MDYwNDE0WjAwMS4wLAYDVQQDEyVkYzAza2cwMzUx\n\t\t\t\t\t\tZXUuaG9zdGVkLmV4bGlicmlzZ3JvdXAuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAs22oyR6YHnUVlPNR5rrT+7OGLDqXqRlEiY421vfiWrK45xJU\n\t\t\t\t\t\t9421fSc08tvnqwK+Wb3lrpreJKWVD45K+Z3+UNjdHph8NYPLhbJIbj7zSr+omGbG\n\t\t\t\t\t\tiFeNesU2DhrQyT5LLMPl+qUQINUt4v7W1xyAVO0RF2PxAAvcyVS6vcDtIVUmLZNP\n\t\t\t\t\t\tuN581JOJaccTqiU/iAByjPzTHJlL0OfKeGJb0BYYdOCqTyGZZxShWk/RoFyA4Sbt\n\t\t\t\t\t\tkG7U/BD0rkeJ4ELkq2vLefxGDK23/AT5C3N4lhDvX1KFGZOzlYguLyNAIToxfjh4\n\t\t\t\t\t\tkXcrGtVE/kUvGih0i+J7nBYI9ZzbnMqmSJ7XhQIDAQABo1MwUTAwBgNVHREEKTAn\n\t\t\t\t\t\tgiVkYzAza2cwMzUxZXUuaG9zdGVkLmV4bGlicmlzZ3JvdXAuY29tMB0GA1UdDgQW\n\t\t\t\t\t\tBBSTwa3ljw9niFjJ56VIlGAjNu3LYTANBgkqhkiG9w0BAQUFAAOCAQEAldmrNdUD\n\t\t\t\t\t\t5+i8MC5tiz066ckM4SZQEY5H0nGHdZQQJ5Q4y3umW9574rssXH3hYURDl+694FXM\n\t\t\t\t\t\tj69h6iPUdihT1zKvFB24hz23XDMRiEF5sorDXDJ/xzzxOqntc7XSuGPUTDjcdGS2\n\t\t\t\t\t\trDCC/Pu2G5iD9xJIE5OX95DV8fNx1MRYmDtrShM2Szi1i/IgwaAYPDpw5ueH5JGd\n\t\t\t\t\t\twvc45uy/tbhY1br1RKM0v9UTqSkpfOnkZ1fpgkLs28mopwsbTWZbVATkhnNcIZVd\n\t\t\t\t\t\tAPMzE/0MXO3jaiZ2cfUUB12yOjNZj8owMUBTx+2lv35IC/QuEZ3KLf7qyY2fDD5i\n\t\t\t\t\t\t3SdruRngVtkFYA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ku-primo.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ku-primo.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ku-primo.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ku-primo.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ku-primo.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ku-primo.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://member.goodpractice.net/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ferguson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:oferguson@goodpractice.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Owen"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Anderson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:janderson@goodpractice.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jonny"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://member.goodpractice.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Good Practice"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.goodpractice.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Good Practice Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://member.goodpractice.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://member.goodpractice.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://member.goodpractice.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://member.goodpractice.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://member.goodpractice.net/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC2TCCAcGgAwIBAgIJANAQiZL85UcxMA0GCSqGSIb3DQEBBQUAMBExDzANBgNV\n\t\t\t\t\t\tBAMTBmdwd2ViMTAeFw0wOTEwMjkwOTQyMDhaFw0xOTEwMjcwOTQyMDhaMBExDzAN\n\t\t\t\t\t\tBgNVBAMTBmdwd2ViMTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJo3\n\t\t\t\t\t\tK9NuAfabszZBVr7jycgfy5gF5CuTKcE7E3NKECb80e5tBzNZMtVP9bysddyd6m51\n\t\t\t\t\t\tBcUb6B/f/iE6Qjve9+RyIsGtXshJTfPKfNyt0m+hp5PS9JNxhwW1GQRYgAXMRAXI\n\t\t\t\t\t\t1c4U1TT/ZVyriupfhjjmm4gNH7MFWlC73jPEImN3Azykz/9/SKAYSH5DQVcE30wC\n\t\t\t\t\t\tI0q6Nl99CBcgBxPU4KT1eBxlWtXwCA/2brBBUnBkcB8MiHljAbHI3qDi3pAvPfNd\n\t\t\t\t\t\t/88T0Gh76moQIzjYc34FInQ9bdbsnebyFvtFuXT819lo6dL+1i688wxUMJlklKWq\n\t\t\t\t\t\tm+juOoKmeL6XoXRGZN8CAwEAAaM0MDIwEQYDVR0RBAowCIIGZ3B3ZWIxMB0GA1Ud\n\t\t\t\t\t\tDgQWBBS+l+ek7zsiE7FuieyU4W19XwhfNzANBgkqhkiG9w0BAQUFAAOCAQEALofg\n\t\t\t\t\t\tbvE4ztxhrWJMt5IDwYrc/c31N3+xSMsyLZjKSRY5jKN1sd5s7xDi3aXduMua1MKV\n\t\t\t\t\t\tBFOuiXQqWS8wv/5GOrI1/K0yFxasQEOzPGhrj3ceMfut8iP7peeBWQrNOQyi+SkV\n\t\t\t\t\t\taxuK3oO/KhVtGaPWpv+c/RzLMP7UXF7Zw4O/OsdYHPppr7UF0BgibN2jCiIPUBOd\n\t\t\t\t\t\t4fobI74SpX1VIQa8pyC6NOR6lPU7Ozex4xzKCq6nnS4OxObTjylU/2d8YdGB/Zda\n\t\t\t\t\t\thgAqoNDf0vZ9o4I+/6GGvgcEbYv7mKbt3TUuccRc5lIFVpggzB037hyw4n055xO+\n\t\t\t\t\t\t1GNLhUn46SUcF9uHqw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC2TCCAcGgAwIBAgIJANAQiZL85UcxMA0GCSqGSIb3DQEBBQUAMBExDzANBgNV\n\t\t\t\t\t\tBAMTBmdwd2ViMTAeFw0wOTEwMjkwOTQyMDhaFw0xOTEwMjcwOTQyMDhaMBExDzAN\n\t\t\t\t\t\tBgNVBAMTBmdwd2ViMTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJo3\n\t\t\t\t\t\tK9NuAfabszZBVr7jycgfy5gF5CuTKcE7E3NKECb80e5tBzNZMtVP9bysddyd6m51\n\t\t\t\t\t\tBcUb6B/f/iE6Qjve9+RyIsGtXshJTfPKfNyt0m+hp5PS9JNxhwW1GQRYgAXMRAXI\n\t\t\t\t\t\t1c4U1TT/ZVyriupfhjjmm4gNH7MFWlC73jPEImN3Azykz/9/SKAYSH5DQVcE30wC\n\t\t\t\t\t\tI0q6Nl99CBcgBxPU4KT1eBxlWtXwCA/2brBBUnBkcB8MiHljAbHI3qDi3pAvPfNd\n\t\t\t\t\t\t/88T0Gh76moQIzjYc34FInQ9bdbsnebyFvtFuXT819lo6dL+1i688wxUMJlklKWq\n\t\t\t\t\t\tm+juOoKmeL6XoXRGZN8CAwEAAaM0MDIwEQYDVR0RBAowCIIGZ3B3ZWIxMB0GA1Ud\n\t\t\t\t\t\tDgQWBBS+l+ek7zsiE7FuieyU4W19XwhfNzANBgkqhkiG9w0BAQUFAAOCAQEALofg\n\t\t\t\t\t\tbvE4ztxhrWJMt5IDwYrc/c31N3+xSMsyLZjKSRY5jKN1sd5s7xDi3aXduMua1MKV\n\t\t\t\t\t\tBFOuiXQqWS8wv/5GOrI1/K0yFxasQEOzPGhrj3ceMfut8iP7peeBWQrNOQyi+SkV\n\t\t\t\t\t\taxuK3oO/KhVtGaPWpv+c/RzLMP7UXF7Zw4O/OsdYHPppr7UF0BgibN2jCiIPUBOd\n\t\t\t\t\t\t4fobI74SpX1VIQa8pyC6NOR6lPU7Ozex4xzKCq6nnS4OxObTjylU/2d8YdGB/Zda\n\t\t\t\t\t\thgAqoNDf0vZ9o4I+/6GGvgcEbYv7mKbt3TUuccRc5lIFVpggzB037hyw4n055xO+\n\t\t\t\t\t\t1GNLhUn46SUcF9uHqw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://member.goodpractice.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://member.goodpractice.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://member.goodpractice.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://member.goodpractice.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://member.goodpractice.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://member.goodpractice.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://member.goodpractice.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://member.goodpractice.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://member.goodpractice.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://member.goodpractice.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://umentor.goodpractice.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://umentor.goodpractice.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://umentor.goodpractice.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://umentor.goodpractice.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://umentor.goodpractice.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://umentor.goodpractice.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://rushib.rockefeller.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "chrisv@rockefeller.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris Vancil"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "anne@rockefeller.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Anne Duffy"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "svetlan@rockefeller.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Svetlana Zarubina"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "marty@rockefeller.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marty Leidner"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://rushib.rockefeller.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://rushib.rockefeller.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://rushib.rockefeller.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rockefeller.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rockefeller University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVAPI9h0Gu4CtEoQlfycXU2mmLEEeJMA0GCSqGSIb3DQEB\nBQUAMCExHzAdBgNVBAMTFnJ1c2hpYi5yb2NrZWZlbGxlci5lZHUwHhcNMTQwNTAx\nMTczOTI2WhcNMzQwNTAxMTczOTI2WjAhMR8wHQYDVQQDExZydXNoaWIucm9ja2Vm\nZWxsZXIuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAgqOnUz5i\n9tVVs7wd0ZKlToCMv7hWhgFgbZXJ84oRTvegpVAFmWMmZIh1GCcmMLl02fYcewBW\nyplRm+hD41T+07oLxX1pbIv+dQTUNKFaBj05xxk/OazrtgQ1642JfT6mOop6Jq/U\n1BjPBRMCcVevvA9qwav1rihjv854vhR9sTRIPJvfcupkcUDme0HZPF9uDy6XhEJz\nMhHOMpD/txYHA00mW33m2bemAgSOTwn2yz0HIs6395o3M1g7tBfuuHUN5S2luuZQ\no8EOpuV0qPjD2q2RBetKKBop4Ku6duEyOri5bwuQXk3l8xAPKBFnkhUXS6PAMLah\nYN5MPHnUKpRAHwIDAQABo3MwcTBQBgNVHREESTBHghZydXNoaWIucm9ja2VmZWxs\nZXIuZWR1hi1odHRwczovL3J1c2hpYi5yb2NrZWZlbGxlci5lZHUvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFNwc7cnXlFheGGYaSNOv6FcWQyRqMA0GCSqGSIb3DQEB\nBQUAA4IBAQAnPKCvFwkpw5p4tbSJS3XvReVUjnJPdzGiaznu6j11k6CoQoUqFuOd\nXqin8UHInoS7XYXxWdY51DAB5ONkOwjkfhixpzmXBNuhs0vOh9mCMGiGW7CHbDu+\nGg4gEzh7+ZEuj+aLTfa3Y4rmoaV8BJPBX7+ZZKHEmBTOyHZHmCbZfyQOrCXKAN/2\n5n3rFSaPyjc54O5nXSGbhTyEEWlA9zlx5FWheKLz5dHf+i17qLIbkQGww0saMXNz\nBptks6bmLj9P1PAtmV842uqh05xFIHHG4WAqp7tqnglkDDw6Lze4NuxnxU9/xQFU\nXKx9JBd0Ah6DZb6aHj5cXlPl2utzn7Qd"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "error_url": "https://rushib.rockefeller.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Rockefeller University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rockefeller.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Rockefeller University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.londonmet.ac.uk/entity",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Zong"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:r.zong@londonmet.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rui"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Zong"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:r.zong@londonmet.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rui"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.londonmet.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUDHdfCxkdKbK8wHhVtq9PRTUWSm0wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHjEcMBoGA1UEAxMTaWRwLmxvbmRvbm1ldC5hYy51azAeFw0xMDA4MjYxNTA3\n\t\t\t\t\t\tNDZaFw0zMDA4MjYxNTA3NDZaMB4xHDAaBgNVBAMTE2lkcC5sb25kb25tZXQuYWMu\n\t\t\t\t\t\tdWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCR+B1vhlwrPAclk8E8\n\t\t\t\t\t\tcaI6LAji53lGsQxavp7cQoBl7zmZq8V7vH+MkgT+uapudGHd18RBAeUETvsYnD7V\n\t\t\t\t\t\t+hzefC6B77OfzFuO1WRWsKrUQg+V21Q1kgxPZZTFoJEEjogCOhkmGFy+hpyTljmD\n\t\t\t\t\t\tykP9wxq8nT6Oow0aQy987spH1+E1dd4F6GCLphhs0UrwGzAAkC/k5rX9dfMQ8TS0\n\t\t\t\t\t\tuyj7bxG8cT3wvjbDtpQ1sjd70wm3qNSgF/Hsj+GpXP8L7J/mBdOUsqIFW8TSfFxT\n\t\t\t\t\t\t4zIBkDyAp1k2zDu/iIN5K+luD5KKB7ReYuEDLYxBbjgaMqqb2G3J1A3Bfhx140O7\n\t\t\t\t\t\tq59hAgMBAAGjbTBrMEoGA1UdEQRDMEGCE2lkcC5sb25kb25tZXQuYWMudWuGKmh0\n\t\t\t\t\t\tdHBzOi8vaWRwLmxvbmRvbm1ldC5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4E\n\t\t\t\t\t\tFgQUVZtYAu6CRSMuMvOOlHw1d6h0MrAwDQYJKoZIhvcNAQEFBQADggEBAGc6MFMQ\n\t\t\t\t\t\tQ2A8YhaN13qv5pb3BP580s3mmw0kLgbwM9/tirmmIIjazYjHVUcz7IJugVy13siE\n\t\t\t\t\t\tMFDc0dxKK/9ExXHYS1qvGJPEoMsmzliUBOV6yIesRHw39hK9vUbKV5sb8ahok9Qc\n\t\t\t\t\t\tDMo2Oi6eF88nwgd3Gee6F973E5g2UEcJGDfN/KTK/b5kmxXtaR/+QGjz1Vzmtm+t\n\t\t\t\t\t\tnTG9ggzmeCJvWcmldZSYOKchXZPTvYi6n0coTblLIYzo30miElRLEajmiMLxR9xg\n\t\t\t\t\t\tdl+2HVg3VDLg4o4BRGZnC5Ip8nX8UyDgdiyzeBtFk5pXSXmyDl4ck421skd7CKOW\n\t\t\t\t\t\tO+pzHAT8SmUOATI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "londonmet.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.londonmet.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.londonmet.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.londonmet.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.londonmet.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.londonmet.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.londonmet.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.londonmet.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.londonmet.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "londonmet.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUDHdfCxkdKbK8wHhVtq9PRTUWSm0wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHjEcMBoGA1UEAxMTaWRwLmxvbmRvbm1ldC5hYy51azAeFw0xMDA4MjYxNTA3\n\t\t\t\t\t\tNDZaFw0zMDA4MjYxNTA3NDZaMB4xHDAaBgNVBAMTE2lkcC5sb25kb25tZXQuYWMu\n\t\t\t\t\t\tdWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCR+B1vhlwrPAclk8E8\n\t\t\t\t\t\tcaI6LAji53lGsQxavp7cQoBl7zmZq8V7vH+MkgT+uapudGHd18RBAeUETvsYnD7V\n\t\t\t\t\t\t+hzefC6B77OfzFuO1WRWsKrUQg+V21Q1kgxPZZTFoJEEjogCOhkmGFy+hpyTljmD\n\t\t\t\t\t\tykP9wxq8nT6Oow0aQy987spH1+E1dd4F6GCLphhs0UrwGzAAkC/k5rX9dfMQ8TS0\n\t\t\t\t\t\tuyj7bxG8cT3wvjbDtpQ1sjd70wm3qNSgF/Hsj+GpXP8L7J/mBdOUsqIFW8TSfFxT\n\t\t\t\t\t\t4zIBkDyAp1k2zDu/iIN5K+luD5KKB7ReYuEDLYxBbjgaMqqb2G3J1A3Bfhx140O7\n\t\t\t\t\t\tq59hAgMBAAGjbTBrMEoGA1UdEQRDMEGCE2lkcC5sb25kb25tZXQuYWMudWuGKmh0\n\t\t\t\t\t\tdHBzOi8vaWRwLmxvbmRvbm1ldC5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4E\n\t\t\t\t\t\tFgQUVZtYAu6CRSMuMvOOlHw1d6h0MrAwDQYJKoZIhvcNAQEFBQADggEBAGc6MFMQ\n\t\t\t\t\t\tQ2A8YhaN13qv5pb3BP580s3mmw0kLgbwM9/tirmmIIjazYjHVUcz7IJugVy13siE\n\t\t\t\t\t\tMFDc0dxKK/9ExXHYS1qvGJPEoMsmzliUBOV6yIesRHw39hK9vUbKV5sb8ahok9Qc\n\t\t\t\t\t\tDMo2Oi6eF88nwgd3Gee6F973E5g2UEcJGDfN/KTK/b5kmxXtaR/+QGjz1Vzmtm+t\n\t\t\t\t\t\tnTG9ggzmeCJvWcmldZSYOKchXZPTvYi6n0coTblLIYzo30miElRLEajmiMLxR9xg\n\t\t\t\t\t\tdl+2HVg3VDLg4o4BRGZnC5Ip8nX8UyDgdiyzeBtFk5pXSXmyDl4ck421skd7CKOW\n\t\t\t\t\t\tO+pzHAT8SmUOATI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "London Metropolitan University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.londonmet.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "London Metropolitan University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.dkit.ie/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Deenihan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:michael.denihan@dkit.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Brady"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:frank.brady@dkit.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Frank"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.dkit.ie/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2010-11-09T00:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.dkit.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.dkit.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.dkit.ie/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dkit.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.dkit.ie"
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/dkit.png",
                    "height": "98",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "155"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "lang": "en",
                    "height": "98",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "155"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Dundalk Institute of Technology"
                  },
                  {
                    "lang": "ga",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institi\u00faid Teicneola\u00edochta Dh\u00fan Dealgan"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "dkit.ie"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.984667,-6.394150"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.1.40.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:0770:0028::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUXWnVlumk2ydwS9DRW7Xoxc2vfvcwDQYJKoZIhvcNAQEF\nBQAwFjEUMBIGA1UEAxMLaWRwLmRraXQuaWUwHhcNMDkwODExMTAyNTQ3WhcNMjkw\nODExMTAyNTQ3WjAWMRQwEgYDVQQDEwtpZHAuZGtpdC5pZTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBANkYoFuj1yxD2P68jA2zsEtokAAUExRcur1pdVIF\n3iTS3l/vifRLxstc0IVniaOcWvBxWcLKLueZeBMTuWsyePGz5BhecXzs2u6alYZW\nITUxJTE0jxZ+WfpPQqnWsysa4rIzksw9l7sbccSz7qvZPLFlwdprrU1rMAMqAcXv\nhYg5iJLRPfRHMN9piFrlibi0RM+u9QPj8/KqJnYVjDZ1+oMeVArEdLk787YlMp79\nGaiKbP6u1cJ3FIgtnWmtph4XWhdMNoh3VBVIo30LnxANGSotMEo+pz/UphUarBjF\nwUzy8vyJdF5+L/Lh/3q6JKVIViC064jQe+PsSJYG0R3ynVcCAwEAAaNdMFswOgYD\nVR0RBDMwMYILaWRwLmRraXQuaWWGImh0dHBzOi8vaWRwLmRraXQuaWUvaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFHrvvvBubZqHTcyxZa3VdPhPDWX3MA0GCSqGSIb3\nDQEBBQUAA4IBAQAPn2bTK88XJI8cyWVVRvKXQuNTwIY3KLE+dRs+6EGeF46Ipzfn\nfGIF1je7IrsIUAIKs+8KBWoCwoOp0Nasilib/F90OK6NwEXNKqGdwZXQxJLdvOK7\nyHOXKS+J27t05krcLbutSwcNdnOVEdWbtOz7+/qbx2CSxbrOIDSgTcVDwn/wqm7G\nQW48Aoz0QReQV0oYglj3D9zNUfpnshQqcv45i9+toGTLTdkQfFm/4DUMEWQXM/IE\n+hxh2RRIl0wE/qVYfd5hahptuNWfhjSbTtUB4iPaY18z1TMG3JfgQvtKszQeHRa9\nLKIUf4wMQHssUFNv5TXV1zu1W4f9ctYYLexH"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Dundalk Institute of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dkit.ie"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Dundalk Institute of Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.insa-rouen.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "LE GUILLOUS Franck"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "franck.le-guillous@insa-rouen.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kesraoui Nadir"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "nadir.kesraoui@insa-rouen.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.insa-rouen.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2010-03-02T14:41:38Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.insa-rouen.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.insa-rouen.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.insa-rouen.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "insa-rouen.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.insa-rouen.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INSA de Rouen"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INSA de Rouen"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIVAMjnzzUZMi+gw/G65zb8aEmhPMcsMA0GCSqGSIb3DQEB\nBQUAMCMxITAfBgNVBAMTGHNoaWJib2xldGguaW5zYS1yb3Vlbi5mcjAeFw0xMDAy\nMTIxNDE0MTNaFw0zMDAyMTIxNDE0MTNaMCMxITAfBgNVBAMTGHNoaWJib2xldGgu\naW5zYS1yb3Vlbi5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIrS\n+3iUIFUKCA9bdG5CkzYxYKWg6huMkcRrqruetEbUobvCf/B5Q4R2SuEHa+VG2SMd\nbgjcHSjPIqwtzcaFq9cEK+I24UPSpBUYei/m9//CWMUNR0YGJWgQdtMi9v4N60qP\nFiep4U5vj/whakGeMY5J3E8mKrzITemh0yLFThQh+edav5QaPOuOuWW1kx8e3Y2P\nuCEdDDvxXS6vtUJ0Y9OOmq824e9Olo2DIHsbicraB3hnHVDwljw4gwKGDqlkr7kJ\nP/5ORgPyRa51RcD21XHaMcNbiZ9BWuyZkgIX7MwY5Pucn9xZBLOCF1XVPrIz5Thw\n3JBDfons1+l52SpmlW0CAwEAAaN3MHUwVAYDVR0RBE0wS4IYc2hpYmJvbGV0aC5p\nbnNhLXJvdWVuLmZyhi9odHRwczovL3NoaWJib2xldGguaW5zYS1yb3Vlbi5mci9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUVroJwDQMTj+P/Qy2rF0hgSrMGd0wDQYJ\nKoZIhvcNAQEFBQADggEBABzLkZCSjBO68HuRhDjlVblgc9up8dN5pZZMxxWyQfQM\nGZgv3sYwktpBL/I7jUuEhiMbr5n8I/hq0HrxiBAFulVvuLhahzfY4GxMwEBHTYm/\ngOoNn2cJD+ZKFF1PPZ3TYnlbM1nJ17AbSCjS2QxzNygTzi2tDulpOJgUmacLr81Q\nVZrWGgkPWyDKh3foQ7Olh9eiySh1jSl55uJE4ze1yopOiFyLfe4PHYnsfanu9F0k\n2VITeNSh7Epbl3wutJnfXFpa4XpmWMIzeQD7Eowrs5Oewk1peM6kl2fzn4gKcFXo\nu1n3Fa3LxTYXo8TB+XbBKdEFD+MdaGILc/H8Gb5EEak="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "INSA de Rouen"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.insa-rouen.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "INSA de Rouen"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.qmu.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Haining"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ghaining@qmu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Garry"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Haining"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ghaining@qmu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Garry"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.qmu.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-02-02T13:55:52Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.qmu.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.qmu.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.qmu.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.qmu.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.qmu.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.qmu.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "qmu.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUeld6GBPF1gEMJF1Cbn4IarRMleUwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwGDEWMBQGA1UEAwwNaWRwLnFtdS5hYy51azAeFw0xNTA4MjUxMzI1NTRaFw0z\n\t\t\t\t\t\tNTA4MjUxMzI1NTRaMBgxFjAUBgNVBAMMDWlkcC5xbXUuYWMudWswggEiMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDkJvSQX9O231NMC1VYk5fVWeGmId4ndlmi\n\t\t\t\t\t\tWljnN9C9LYcaVypSvgxmcDvUzn5FugBCVZYM5NsI2HTwHq35TCMBBzpKlaWtg3Ee\n\t\t\t\t\t\t/2Sv77vCORa1pRyPNUdO86zDh603CLo0k6o7JNO2MSPfLprObYX2+NNuOhHc1CwV\n\t\t\t\t\t\tHFB2UxYQzni8xZJG1hRm4vrv3Po/Y2DibKsQNRUW5QQXhzDzfJUn2IQEMrbKr8bb\n\t\t\t\t\t\tHcjMue5d8/UILt0PNruvyYhFAQFLjnXhhJd6L0ax4LeMpeI7PDj6QtVyQNr5bsrS\n\t\t\t\t\t\tNH/utrzNpeopKYnBQgdPgJFM3HiHOGUMfbSIRrh2CESMZtdQonH3AgMBAAGjYTBf\n\t\t\t\t\t\tMB0GA1UdDgQWBBTjtAI0dD9q/Hob5nJHSwwABUuVuTA+BgNVHREENzA1gg1pZHAu\n\t\t\t\t\t\tcW11LmFjLnVrhiRodHRwczovL2lkcC5xbXUuYWMudWsvaWRwL3NoaWJib2xldGgw\n\t\t\t\t\t\tDQYJKoZIhvcNAQELBQADggEBAFAnnZiyhEhPxT1iNCFV5lHMDI+fVCJgl2O7Sfx6\n\t\t\t\t\t\t2utnqoV1oIWjqXKyaNvsEKPoN+8IpBnITNoknudRLY/qLFzualTRSflQonZBCMHJ\n\t\t\t\t\t\tSCliHcZOVzriCUTWTOh+5Pw0bQ7aJd1DMg8kAnLXhdG+wIRhBSNuqvYgiNmIQZoN\n\t\t\t\t\t\tEAncOU5+HylasbLL6ZZVIsXDT5lstVMsxZ8QQWVscHK1Ib4jTOvPY+1j9o0oabcz\n\t\t\t\t\t\tV+EK/7pRHMo+7Lzphh4M+JsfJ2UNGp/mkLeTD6focMqJyQen/YpL/1QR8nu3o5Wb\n\t\t\t\t\t\txQfQRA9vi20FOGF8jZCNLk3ywdmThRrTB+tdowQmVlTGmEw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAJHckdGW1E6nDrwPcGkVRFgwIkLVMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMBgxFjAUBgNVBAMMDWlkcC5xbXUuYWMudWswHhcNMTUwODI1MTMyNTUyWhcN\n\t\t\t\t\t\tMzUwODI1MTMyNTUyWjAYMRYwFAYDVQQDDA1pZHAucW11LmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAhJKUCoRpDd0DgKIvr1QyYsOCN6nxa60f\n\t\t\t\t\t\tjNX+VVuYHdyZjQCf3sBa3C/NPOifPl8/nORvcQcW4LlUc9t21d7EgNcYYL9+nZ6B\n\t\t\t\t\t\tkAlVHTmD0ssH4axtHbPwXnMgs60KnZ5TMPQkgERnTIehjPngxzy89sOGESZDcsQz\n\t\t\t\t\t\t7c9thvLDLvOQwtb168FClmnMonZc2Ey1h5BfS5ZyxAfuckhoDL98iJFdPOW3yp8D\n\t\t\t\t\t\tbDPKuPpuMcPl+M3pWHvCLkrkScgqRHypmxYwhMId2kDroJQiT3NXmQGvYzHBn3eo\n\t\t\t\t\t\tOd9PlcJ+2YNyUXnfvgI/0Pv6m8KCRj107HsgVaYi8w1FtoK3Im7/cwIDAQABo2Ew\n\t\t\t\t\t\tXzAdBgNVHQ4EFgQUdl+HXullkjaAS02+Es07DHWO230wPgYDVR0RBDcwNYINaWRw\n\t\t\t\t\t\tLnFtdS5hYy51a4YkaHR0cHM6Ly9pZHAucW11LmFjLnVrL2lkcC9zaGliYm9sZXRo\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBCwUAA4IBAQBi0qp6mORG4KC3dI2HjH35OuHs1NjO44y0Lo76\n\t\t\t\t\t\tBBDlDfrDxxMm0LniYXmmNVHIjhshDcnpMUPsyoDEE3wieLxwEp0QLmg44LYmB6YD\n\t\t\t\t\t\tRF3hb3c3EtOs294StyzX3HBzmDbb0YfN6nhLMd2euOB3EYZpLoJzYoy1luIs/KQm\n\t\t\t\t\t\tpX+c3pqWsgkqGHBd4s6G5DGb8krulZrK9VKXb1HGqqqY17lKwavAzqE06MzhFRRo\n\t\t\t\t\t\tGgN5wDmdOa/5B1kzbZ9W6/3JbMd+sKVMS93O1zI8fG8DfLq+4g5f6RY23JbD76ss\n\t\t\t\t\t\tgYK+Lt/CJr+Opa1+bBQrBwkJGoWP8EfuKDyVYj44Wvutm45J"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAKQI4LOpTw+gfDcBaUDIhqnlSKnDMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMBgxFjAUBgNVBAMMDWlkcC5xbXUuYWMudWswHhcNMTUwODI1MTMyNTUzWhcN\n\t\t\t\t\t\tMzUwODI1MTMyNTUzWjAYMRYwFAYDVQQDDA1pZHAucW11LmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2BfAJesvYBMEHgDojaV+sTJ1HbsCXYYy\n\t\t\t\t\t\tHQeuctNHxMHROrO4dh9fPrILsNyX3u94ub+OZiV/GE5Tlb1rni09BCOWG4Svq1vR\n\t\t\t\t\t\tYUaZC9FvQo+vMNPR86m6eJbnMDCvi2IOFKcGcdjQIGS2VfA6H0WwRPR3IRYqygOF\n\t\t\t\t\t\t+KC/lKLcIyjlKCJB21k12GITnn1tsy6y0Ylg2Ets031eUhK5cpEMR70IVtnJSYyn\n\t\t\t\t\t\t3yYtk8FA517oY/dUaWxCst45ZvU10e5/lue9DO+JVXLXYnr8c0t6bTebpaBXVCKF\n\t\t\t\t\t\tmq2sGnoE2nSxMhF9vDx5Tw5QE3R7hwoW0z2s6lIiiD58JAjikkoR3wIDAQABo2Ew\n\t\t\t\t\t\tXzAdBgNVHQ4EFgQUzWcVUZGHqt8uFsmoKsB0xxhz2cgwPgYDVR0RBDcwNYINaWRw\n\t\t\t\t\t\tLnFtdS5hYy51a4YkaHR0cHM6Ly9pZHAucW11LmFjLnVrL2lkcC9zaGliYm9sZXRo\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBCwUAA4IBAQAPjIxhzi2FrZtkC734nd0tBZ0e8Alub1o7XMAK\n\t\t\t\t\t\tNZbBZVAz4pfEIA55PhIS/a43SD6N46DPX/Ufx3AKZZEc7y16xnJTpIZczot9sAzw\n\t\t\t\t\t\tHNQpneDehvS13eE7LPJ/XBND5Gwelz6rvX0dgsmA7SvNnHgp2yjVWyoswC99zf4U\n\t\t\t\t\t\tUONrG0m1HRS8bILFSFYwAEsQbQxlZvRwApWKvUDIFmeBke5wuxCzb4dd/zK7H1X9\n\t\t\t\t\t\tcjRpce3uDuOhKGQtmMHmig3dd72nJeHUoDY1QzQc4nw1IciJyJ6r3LzScy+GpSje\n\t\t\t\t\t\tk4A44yA3kIp6HlqiHqF23koUpogpejP3TauQB3gGJQaVeLti"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Queen Margaret University, Edinburgh TEST (Do not use)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qmu.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Queen Margaret University, Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.vcu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tsmiddleware@vcu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "L T Harris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.vcu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.vcu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.vcu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.vcu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIJAMyTsDp4A5caMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEnNoaWJib2xldGgudmN1LmVkdTAeFw0xMjEwMDIxNTI2MzhaFw0yMjA5MzAx\nNTI2MzhaMB0xGzAZBgNVBAMTEnNoaWJib2xldGgudmN1LmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALFTvPHWzUL5EaaR1MVTG9wQ1Kn93kblwNRY\nOa2vdsN25zod0NQCsp+XvqN1pn2w7zOvcY/ed3lYS9LqUZtiOTi6UCstT9w/4ci3\n9hJ9A4mRwk2+AUI7bQREhSF9z3Qk6FGjQfJXPFFyE3mnVIfavR9p/czIJIXlOIcX\ni6FCX3JQlMjdJue2xra0B6VkIavzFVkFNGlBkH/Mydxzt3HqgjI1k/57DnS0yCyy\n/pvfGmqtO11BxuZOHRfwIdxNIr3P5Mlc8kazUaPU+C3/fn0rfmvbdpAiCsSBSiAF\nuGapr9NfPRzVDnvwFNxz0PkLoHVm3yAaa7D7FeiFDUoo2ejrUR8CAwEAAaN+MHww\nHQYDVR0OBBYEFHp4Wom01tr/3XpayMXmUS5fLLCXME0GA1UdIwRGMESAFHp4Wom0\n1tr/3XpayMXmUS5fLLCXoSGkHzAdMRswGQYDVQQDExJzaGliYm9sZXRoLnZjdS5l\nZHWCCQDMk7A6eAOXGjAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAH\niM8gjbZBldvhW1qopkF1KFqRh0HKOjSVTgQBNj5vU/AlL5PS7Cz9Ja/2X4+V24K+\nbyitlj98kZF0OKDvWRb74w8cNDEE9us8Tl1txZVhTXfN7b5uzWb6g8CEcqxbLbHv\nRD3SSuWFEPpQlMAKDkGtSAS3ho3miQSIR1d236DA69ot8BTe8YM6P3AocDO7jPAn\ntlcoYKNW6ADof1DI8Q1z6ZgtYEnc/zVfA7dtudPYeYQZ6TL/R00gSdfN9GM+j7PA\nPBMWlPnwimjDzbm/2/sjWQ4+XXo1LpySq58tAyeqlmwQchr7rWzfQdJw8h5pBTLI\ntBa/rT5xLEJ4lKciSEO4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIJAMkP0cy6Mj6OMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEnNoaWJib2xldGgudmN1LmVkdTAeFw0wOTEwMzAxMzM0MjFaFw0xMjEwMjkx\nMzM0MjFaMB0xGzAZBgNVBAMTEnNoaWJib2xldGgudmN1LmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAL4gIuA1ljlDh/jlffYhbTRMsfGFErcWrejd\n5UA2FvUEL14+PPzpHq6+8HHZL1TYW5WnRq4dpuvHUxOfSxt5gom9bl3SUa3pAFsk\nhKcXqOwZzvPPVo0Rp7iZguVjkiZBlSYXo3cP4bfMuNrfvDTCAFvxa8fZN8yxclVL\nBg7yXKh6gPbVN9VST3KG/mExI7yghNFnxJgh1xsfl4idJCvKb+V3IuD8hdWiS7hp\nQ+mcn+1rA+TQarXODC5rf/JilvWaRvh6cwMHw35sBownzI44h/L1vfHimiPGXvo7\noroZ7NGUK1j0G6GolK7ixBHjQZZGUv7O2X/4Rj+NaIFkf+KnNIECAwEAAaN+MHww\nHQYDVR0OBBYEFFb2M0GvEkqM6CsDMAgoGdxe/022ME0GA1UdIwRGMESAFFb2M0Gv\nEkqM6CsDMAgoGdxe/022oSGkHzAdMRswGQYDVQQDExJzaGliYm9sZXRoLnZjdS5l\nZHWCCQDJD9HMujI+jjAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBl\nRNsX0fk9l9EeZa8AHpPcxk3eQaW8r4MT+o57LXtBDZEvKFc8fRws09Ptkyg9CETv\n5uT7GQZ0HEFZyONJHsQy8Q1Etr4Q7I5J9EAxokBG4kFAn7Jcp1LHf5zHlWVhDsR+\nLMhDmHPuyDGqN8pVU/47MA0hFGILpckRY6q4j7L3aXyet0ImyPVlgJUoMXRso7vN\nUw8mKyvL8HT3iZ42D8wENFNhA3nck2RDX3K1nv0qCbNF+FlnUDTy7i6EnH4U2aoe\nmYJ3G1FBVt0b8LdS0XisQ9pY3kpuQqspN4SFrJUDi6luNLdH8/YguSB0uf2Pdyyj\nKUd8anrB7gIglUS1bz6F"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vcu.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Virginia Commonwealth University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Virginia Commonwealth University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vcu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Virginia Commonwealth University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.enorf.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.enorf.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-09-18T13:51:33Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/enorf.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/enorf.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "enorf.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "East Norfolk Sixth Form College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.enorf.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth2sp.bw.semcs.net/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Williamson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mawilliams@wiley.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:wiley-support@semantico.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Wiley Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth2sp.bw.semcs.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-07-06T13:59:27Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Semantico Limited: Wiley Shibboleth 2 SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://eu.wiley.com/WileyCDA/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Semantico Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.bw.semcs.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.bw.semcs.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.bw.semcs.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.bw.semcs.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.bw.semcs.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth2sp.bw.semcs.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth2sp.bw.semcs.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDzjCCAragAwIBAgIJAOrzhMg7IMvZMA0GCSqGSIb3DQEBBQUAMGoxCzAJBgNV\n\t\t\t\t\t\tBAYTAlVLMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIwEAYD\n\t\t\t\t\t\tVQQKEwlzZW1hbnRpY28xIzAhBgNVBAMTGnNoaWJib2xldGgyc3AuYncuc2VtY3Mu\n\t\t\t\t\t\tbmV0MB4XDTE0MTIwMjE0NTgyMloXDTM0MTEyNzE0NTgyMlowajELMAkGA1UEBhMC\n\t\t\t\t\t\tVUsxDzANBgNVBAgTBlN1c3NleDERMA8GA1UEBxMIQnJpZ2h0b24xEjAQBgNVBAoT\n\t\t\t\t\t\tCXNlbWFudGljbzEjMCEGA1UEAxMac2hpYmJvbGV0aDJzcC5idy5zZW1jcy5uZXQw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDFi/wIgmSuv3qLeh0z3FfF\n\t\t\t\t\t\tTwkaZ13XUKHPsI7r7vFySiGIlV141jGkE+ilWb8BZwjV75nC10l+4bGHueGzxpwg\n\t\t\t\t\t\tKk0EWzZlUDFHW6xyjEn4uAocTyZw3LI4yn2DjdhTm07QA2f3ckS3FAg9NcA0Uj22\n\t\t\t\t\t\tWQD8TcGgr3IpRm2b2PwFY7a2WW+KK0nAkbJl8XeD+ZmofIgBodzj2HvAsabCyCSg\n\t\t\t\t\t\tzDm07iEIYj2QPTFwi7ZlNHK5p1QPtyBhv4Uh3STvSnWEjwT74TplvYXv6BBwwbVA\n\t\t\t\t\t\tMc3O+uq9F/nkHcxR8MWGXbWpPVIs4JkxO9et0yKjw7nTCugEYGlRjfNMGv86FzKd\n\t\t\t\t\t\tAgMBAAGjdzB1MFQGA1UdEQRNMEuCGnNoaWJib2xldGgyc3AuYncuc2VtY3MubmV0\n\t\t\t\t\t\thi1odHRwczovL3NoaWJib2xldGgyc3AuYncuc2VtY3MubmV0L3NoaWJib2xldGgw\n\t\t\t\t\t\tHQYDVR0OBBYEFG5qIQhlR9RI7eUVWXgkBhe+LcnIMA0GCSqGSIb3DQEBBQUAA4IB\n\t\t\t\t\t\tAQCaWKa/mQaXL1VF57LYXA3HyAhgzWNzDbZfXAgaloose/a/db23f482HU4Ibx/G\n\t\t\t\t\t\tY9oksWNs43Ltp7lFdSXSfgAwqQ/ca1aZvnFuqyawQ9kNgUQkbIh86GHovYAi9Ame\n\t\t\t\t\t\th6J01wD3LwNGW9/x/nNA6QqgtUgPSWk0YxD6vczPWDJzRD0kAtnmxGPf08elXArq\n\t\t\t\t\t\tTPMxoFxhzliDDW4k/Nwydfiw7fSkPbmZAPCS7ykyzeGF7yMAZSz+7yc/uKY5ixAL\n\t\t\t\t\t\t4voeK7R1wmoYtSVdDb506kbMzSM+jsSaX8tjlI5AULxOFcarmZnJQzSV6RkSUSqP\n\t\t\t\t\t\tdZIy/reh17W2tzo/KX0nvOa+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.bw.semcs.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.bw.semcs.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.bw.semcs.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.bw.semcs.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.bw.semcs.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth2sp.bw.semcs.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.bw.semcs.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth2sp.bw.semcs.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth2sp.bw.semcs.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth2sp.bw.semcs.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://accountcheckout.lnu.se",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://accountcheckout.lnu.se",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://accountcheckout.lnu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://accountcheckout.lnu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://accountcheckout.lnu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://accountcheckout.lnu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "accountcheckout.lnu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEQjCCA6ugAwIBAgIEBAAD+zANBgkqhkiG9w0BAQUFADB1MQswCQYDVQQGEwJV\nUzEYMBYGA1UEChMPR1RFIENvcnBvcmF0aW9uMScwJQYDVQQLEx5HVEUgQ3liZXJU\ncnVzdCBTb2x1dGlvbnMsIEluYy4xIzAhBgNVBAMTGkdURSBDeWJlclRydXN0IEds\nb2JhbCBSb290MB4XDTA2MDMxNDIwMzAwMFoXDTEzMDMxNDIzNTkwMFowXzELMAkG\nA1UEBhMCQkUxEzARBgNVBAoTCkN5YmVydHJ1c3QxFzAVBgNVBAsTDkVkdWNhdGlv\nbmFsIENBMSIwIAYDVQQDExlDeWJlcnRydXN0IEVkdWNhdGlvbmFsIENBMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAlSKhEB1KRmBuBZGb34PC7RKyWnz4\nq+H4UFwoLH5+ADiTsItK8cJMPBAsPO+w7KFpL7n8zAgUa41PGPOD0vqpNwggqlyq\ngGCi1aUiAM9a5bSX37oevlyOFxlm/a+ffHuJsg4k2MerY8SVMo1I5mNZfQS4M6i9\n111kvGO1900o/fkGcjFcukWUZaPStFjsO2FYRKMvYrObgLSC/dXHzFEl5ZU/Ry8w\ne6zIeG7i4W0n6z3MAYLoNXeNq1i7VdHVpIFWjRzQFLGwBt6gkSLz8Kg0F0fG4D72\nDFqsflBLzeFpbgb8Bn5qTbSVmaBZXDVm7NlJ1BfgYLBdpdca4ipuZvKvHQIDAQAB\no4IBbzCCAWswRQYDVR0fBD4wPDA6oDigNoY0aHR0cDovL3d3dy5wdWJsaWMtdHJ1\nc3QuY29tL2NnaS1iaW4vQ1JMLzIwMTgvY2RwLmNybDAdBgNVHQ4EFgQUZWWjPdc7\nEaMKByU3yUJKW3Z3UOEwUwYDVR0gBEwwSjBIBgkrBgEEAbE+AQAwOzA5BggrBgEF\nBQcCARYtaHR0cDovL3d3dy5wdWJsaWMtdHJ1c3QuY29tL0NQUy9PbW5pUm9vdC5o\ndG1sMIGJBgNVHSMEgYEwf6F5pHcwdTELMAkGA1UEBhMCVVMxGDAWBgNVBAoTD0dU\nRSBDb3Jwb3JhdGlvbjEnMCUGA1UECxMeR1RFIEN5YmVyVHJ1c3QgU29sdXRpb25z\nLCBJbmMuMSMwIQYDVQQDExpHVEUgQ3liZXJUcnVzdCBHbG9iYWwgUm9vdIICAaUw\nDgYDVR0PAQH/BAQDAgEGMBIGA1UdEwEB/wQIMAYBAf8CAQAwDQYJKoZIhvcNAQEF\nBQADgYEAQ7NFg1RxxB/csjxrTr8m8k7yrZpb+oY3iOgUbEEYQl/vZT7rA3egt551\nelF8uxVbuK+RoDSSU+1/KkmErLmAS7XHsiMi++vY+27JPPPS0bu+yRz/bQHbaYAO\nmaXqnnuXmI+3zyKcs7hd5akzF3TGlzcPtOkmgl9hCz8ePWTpK5s="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=accountcheckout.lnu.se,OU=IT,O=Hogskolan i Kalmar,L=Kalmar,ST=Smaland,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "accountcheckout.lnu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEQjCCA6ugAwIBAgIEBAAD+zANBgkqhkiG9w0BAQUFADB1MQswCQYDVQQGEwJV\nUzEYMBYGA1UEChMPR1RFIENvcnBvcmF0aW9uMScwJQYDVQQLEx5HVEUgQ3liZXJU\ncnVzdCBTb2x1dGlvbnMsIEluYy4xIzAhBgNVBAMTGkdURSBDeWJlclRydXN0IEds\nb2JhbCBSb290MB4XDTA2MDMxNDIwMzAwMFoXDTEzMDMxNDIzNTkwMFowXzELMAkG\nA1UEBhMCQkUxEzARBgNVBAoTCkN5YmVydHJ1c3QxFzAVBgNVBAsTDkVkdWNhdGlv\nbmFsIENBMSIwIAYDVQQDExlDeWJlcnRydXN0IEVkdWNhdGlvbmFsIENBMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAlSKhEB1KRmBuBZGb34PC7RKyWnz4\nq+H4UFwoLH5+ADiTsItK8cJMPBAsPO+w7KFpL7n8zAgUa41PGPOD0vqpNwggqlyq\ngGCi1aUiAM9a5bSX37oevlyOFxlm/a+ffHuJsg4k2MerY8SVMo1I5mNZfQS4M6i9\n111kvGO1900o/fkGcjFcukWUZaPStFjsO2FYRKMvYrObgLSC/dXHzFEl5ZU/Ry8w\ne6zIeG7i4W0n6z3MAYLoNXeNq1i7VdHVpIFWjRzQFLGwBt6gkSLz8Kg0F0fG4D72\nDFqsflBLzeFpbgb8Bn5qTbSVmaBZXDVm7NlJ1BfgYLBdpdca4ipuZvKvHQIDAQAB\no4IBbzCCAWswRQYDVR0fBD4wPDA6oDigNoY0aHR0cDovL3d3dy5wdWJsaWMtdHJ1\nc3QuY29tL2NnaS1iaW4vQ1JMLzIwMTgvY2RwLmNybDAdBgNVHQ4EFgQUZWWjPdc7\nEaMKByU3yUJKW3Z3UOEwUwYDVR0gBEwwSjBIBgkrBgEEAbE+AQAwOzA5BggrBgEF\nBQcCARYtaHR0cDovL3d3dy5wdWJsaWMtdHJ1c3QuY29tL0NQUy9PbW5pUm9vdC5o\ndG1sMIGJBgNVHSMEgYEwf6F5pHcwdTELMAkGA1UEBhMCVVMxGDAWBgNVBAoTD0dU\nRSBDb3Jwb3JhdGlvbjEnMCUGA1UECxMeR1RFIEN5YmVyVHJ1c3QgU29sdXRpb25z\nLCBJbmMuMSMwIQYDVQQDExpHVEUgQ3liZXJUcnVzdCBHbG9iYWwgUm9vdIICAaUw\nDgYDVR0PAQH/BAQDAgEGMBIGA1UdEwEB/wQIMAYBAf8CAQAwDQYJKoZIhvcNAQEF\nBQADgYEAQ7NFg1RxxB/csjxrTr8m8k7yrZpb+oY3iOgUbEEYQl/vZT7rA3egt551\nelF8uxVbuK+RoDSSU+1/KkmErLmAS7XHsiMi++vY+27JPPPS0bu+yRz/bQHbaYAO\nmaXqnnuXmI+3zyKcs7hd5akzF3TGlzcPtOkmgl9hCz8ePWTpK5s="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=accountcheckout.lnu.se,OU=IT,O=Hogskolan i Kalmar,L=Kalmar,ST=Smaland,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://accountcheckout.lnu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://accountcheckout.lnu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://accountcheckout.lnu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://accountcheckout.lnu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://accountcheckout.lnu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://accountcheckout.lnu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://accountcheckout.lnu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://accountcheckout.lnu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://accountcheckout.lnu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://accountcheckout.lnu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sts.learnium.net/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@learnium.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Learnium Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hughes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:thughes@alacrityfoundation.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Toby"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sts.learnium.net/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-08-28T12:34:24Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Learnium"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.alacrityfoundation.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Alacrity Foundation"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sts.learnium.net/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE+jCCA+KgAwIBAgIJAO4YoaUX4maKMA0GCSqGSIb3DQEBBQUAMIGuMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEOMAwGA1UECBMFR3dlbnQxEDAOBgNVBAcTB05ld3BvcnQxIDAeBgNV\n\t\t\t\t\t\tBAoTF1RoZSBBbGFjcml0eSBGb3VuZGF0aW9uMREwDwYDVQQLEwhMZWFybml1bTEZ\n\t\t\t\t\t\tMBcGA1UEAxMQc3RzLmxlYXJuaXVtLm5ldDEtMCsGCSqGSIb3DQEJARYedGh1Z2hl\n\t\t\t\t\t\tc0BhbGFjcml0eWZvdW5kYXRpb24uY29tMB4XDTEzMDgyODExNTQyOFoXDTIzMDgy\n\t\t\t\t\t\tODExNTQyOFowga4xCzAJBgNVBAYTAkdCMQ4wDAYDVQQIEwVHd2VudDEQMA4GA1UE\n\t\t\t\t\t\tBxMHTmV3cG9ydDEgMB4GA1UEChMXVGhlIEFsYWNyaXR5IEZvdW5kYXRpb24xETAP\n\t\t\t\t\t\tBgNVBAsTCExlYXJuaXVtMRkwFwYDVQQDExBzdHMubGVhcm5pdW0ubmV0MS0wKwYJ\n\t\t\t\t\t\tKoZIhvcNAQkBFh50aHVnaGVzQGFsYWNyaXR5Zm91bmRhdGlvbi5jb20wggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCmsrdUSgNYSnRE0ddtJg2bdkb+bFVy\n\t\t\t\t\t\tswu2z7H91PCUpp3eSQ87eVRKhjMnWnsDwhjWptrAd5k7FiOJXhYjkAVtEYgzUAF8\n\t\t\t\t\t\twiNNR2JKTP89x0JjwY3i9wBh3UqymZs23eqC5PSotG9hwXZLob6juabI07F0cIH+\n\t\t\t\t\t\tF1RA8pZ5fcp02mdKogWlMFOKbIWXR1whOgYtAh4S8TnvNNPBg0Iqe8JO9wOHnnL/\n\t\t\t\t\t\tSOPjSeJaaEnEt2yv4CVu3Zi1ve1gyZ2ZAKdLb4wZA2ujtxr2EGuvi+S2zIQNx491\n\t\t\t\t\t\tBevoFakzEmrpaCb5i68k25Uw7aQywrgxq+EqGbCrbgxXvQKQKfu0EushAgMBAAGj\n\t\t\t\t\t\tggEXMIIBEzAdBgNVHQ4EFgQUSy9nXlJjwq8KvJJ0yRPJL+zaPfkwgeMGA1UdIwSB\n\t\t\t\t\t\t2zCB2IAUSy9nXlJjwq8KvJJ0yRPJL+zaPfmhgbSkgbEwga4xCzAJBgNVBAYTAkdC\n\t\t\t\t\t\tMQ4wDAYDVQQIEwVHd2VudDEQMA4GA1UEBxMHTmV3cG9ydDEgMB4GA1UEChMXVGhl\n\t\t\t\t\t\tIEFsYWNyaXR5IEZvdW5kYXRpb24xETAPBgNVBAsTCExlYXJuaXVtMRkwFwYDVQQD\n\t\t\t\t\t\tExBzdHMubGVhcm5pdW0ubmV0MS0wKwYJKoZIhvcNAQkBFh50aHVnaGVzQGFsYWNy\n\t\t\t\t\t\taXR5Zm91bmRhdGlvbi5jb22CCQDuGKGlF+JmijAMBgNVHRMEBTADAQH/MA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQCN+mOdxNb0Old9C8EXDZl47iMT/eLVGHRwTD1lKEOG7RxZ\n\t\t\t\t\t\tC9/M2IWlWfAaczahV6o5J+AgkHMcRpr7Ba3AtKQGAa1CAjci6cUVqWDJuLVZoJwa\n\t\t\t\t\t\tZQK8Hio+p0uCqmWaxnfyJDCCPiSweI3JfFf16zKE7JpdwMN3FCwL3C9jZ9ox5AUB\n\t\t\t\t\t\tys8Sl9SIeCu/0BWv9719L8rOvWLf7A4A14xyqLJnN/DQ7HAGjZmy/mdT0BJsy3IH\n\t\t\t\t\t\txMwg3id/eGcieKkMTZ6UmrKAPvN+9pr1fUedp8kFlnTNJJ9manlE9KIjNWuhX8l3\n\t\t\t\t\t\tzblMCr3htJ+JowBQNDrmfFz0yCR8VZlzh5JsEs+W"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE+jCCA+KgAwIBAgIJAO4YoaUX4maKMA0GCSqGSIb3DQEBBQUAMIGuMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEOMAwGA1UECBMFR3dlbnQxEDAOBgNVBAcTB05ld3BvcnQxIDAeBgNV\n\t\t\t\t\t\tBAoTF1RoZSBBbGFjcml0eSBGb3VuZGF0aW9uMREwDwYDVQQLEwhMZWFybml1bTEZ\n\t\t\t\t\t\tMBcGA1UEAxMQc3RzLmxlYXJuaXVtLm5ldDEtMCsGCSqGSIb3DQEJARYedGh1Z2hl\n\t\t\t\t\t\tc0BhbGFjcml0eWZvdW5kYXRpb24uY29tMB4XDTEzMDgyODExNTQyOFoXDTIzMDgy\n\t\t\t\t\t\tODExNTQyOFowga4xCzAJBgNVBAYTAkdCMQ4wDAYDVQQIEwVHd2VudDEQMA4GA1UE\n\t\t\t\t\t\tBxMHTmV3cG9ydDEgMB4GA1UEChMXVGhlIEFsYWNyaXR5IEZvdW5kYXRpb24xETAP\n\t\t\t\t\t\tBgNVBAsTCExlYXJuaXVtMRkwFwYDVQQDExBzdHMubGVhcm5pdW0ubmV0MS0wKwYJ\n\t\t\t\t\t\tKoZIhvcNAQkBFh50aHVnaGVzQGFsYWNyaXR5Zm91bmRhdGlvbi5jb20wggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCmsrdUSgNYSnRE0ddtJg2bdkb+bFVy\n\t\t\t\t\t\tswu2z7H91PCUpp3eSQ87eVRKhjMnWnsDwhjWptrAd5k7FiOJXhYjkAVtEYgzUAF8\n\t\t\t\t\t\twiNNR2JKTP89x0JjwY3i9wBh3UqymZs23eqC5PSotG9hwXZLob6juabI07F0cIH+\n\t\t\t\t\t\tF1RA8pZ5fcp02mdKogWlMFOKbIWXR1whOgYtAh4S8TnvNNPBg0Iqe8JO9wOHnnL/\n\t\t\t\t\t\tSOPjSeJaaEnEt2yv4CVu3Zi1ve1gyZ2ZAKdLb4wZA2ujtxr2EGuvi+S2zIQNx491\n\t\t\t\t\t\tBevoFakzEmrpaCb5i68k25Uw7aQywrgxq+EqGbCrbgxXvQKQKfu0EushAgMBAAGj\n\t\t\t\t\t\tggEXMIIBEzAdBgNVHQ4EFgQUSy9nXlJjwq8KvJJ0yRPJL+zaPfkwgeMGA1UdIwSB\n\t\t\t\t\t\t2zCB2IAUSy9nXlJjwq8KvJJ0yRPJL+zaPfmhgbSkgbEwga4xCzAJBgNVBAYTAkdC\n\t\t\t\t\t\tMQ4wDAYDVQQIEwVHd2VudDEQMA4GA1UEBxMHTmV3cG9ydDEgMB4GA1UEChMXVGhl\n\t\t\t\t\t\tIEFsYWNyaXR5IEZvdW5kYXRpb24xETAPBgNVBAsTCExlYXJuaXVtMRkwFwYDVQQD\n\t\t\t\t\t\tExBzdHMubGVhcm5pdW0ubmV0MS0wKwYJKoZIhvcNAQkBFh50aHVnaGVzQGFsYWNy\n\t\t\t\t\t\taXR5Zm91bmRhdGlvbi5jb22CCQDuGKGlF+JmijAMBgNVHRMEBTADAQH/MA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQCN+mOdxNb0Old9C8EXDZl47iMT/eLVGHRwTD1lKEOG7RxZ\n\t\t\t\t\t\tC9/M2IWlWfAaczahV6o5J+AgkHMcRpr7Ba3AtKQGAa1CAjci6cUVqWDJuLVZoJwa\n\t\t\t\t\t\tZQK8Hio+p0uCqmWaxnfyJDCCPiSweI3JfFf16zKE7JpdwMN3FCwL3C9jZ9ox5AUB\n\t\t\t\t\t\tys8Sl9SIeCu/0BWv9719L8rOvWLf7A4A14xyqLJnN/DQ7HAGjZmy/mdT0BJsy3IH\n\t\t\t\t\t\txMwg3id/eGcieKkMTZ6UmrKAPvN+9pr1fUedp8kFlnTNJJ9manlE9KIjNWuhX8l3\n\t\t\t\t\t\tzblMCr3htJ+JowBQNDrmfFz0yCR8VZlzh5JsEs+W"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sts.learnium.net/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sts.learnium.net/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sts.learnium.net/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sts.learnium.net/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.tcd.ie/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McCall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:katrina.mccall@tcd.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Katrina"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mills"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:millslh@tcd.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lee"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Brookes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:brooken@tcd.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Neil"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Brookes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:brooken@tcd.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Neil"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.tcd.ie/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2011-03-02T00:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.tcd.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.tcd.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.tcd.ie/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tcd.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://isservices.tcd.ie"
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/tcd.png",
                    "height": "92",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "165"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Trinity College Dublin"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.345294,-6.257722"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAPRPufbduHXCtO3D7xf4VyBenGK1MA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC50Y2QuaWUwHhcNMTEwMjExMTIyMDI3WhcNMzEw\nMjExMTIyMDI3WjAVMRMwEQYDVQQDEwppZHAudGNkLmllMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAgxPT7BB9FbyCsi+tS0c7qNCpW5iVWFG0Bb8EFWwP\ncJZjwC3UFm2CSUwc6iYBwXJ6hduAiKlzcms4d68aBBZLC9NNOFu24SjazMfCitD7\ncb+zOwZVsegEF/E+ZDReGJQ2fhxty5IhPBwZs5A3SUQ0kXESG2p4iDVS0ugLPuSH\nolZWNdhhCxjjlZL4GQsJ9vsX5VvkEuEygS/D6wOqzTzmM/YspJqsvI8XEhl8GftV\nzo1TGQzcncBLKSUKjElRH6D4fRzxd8iDwBxupDOoH+A90lClUuFjKwlDXiZdWJZ+\nwdVi6e1sjXzoU/CEXYGpEZ43Z+Gv9CUbW7uANh+1+A0I+wIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAudGNkLmllhiFodHRwczovL2lkcC50Y2QuaWUvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFF7+WlJ+91zFVE0TxAf1INwckKy/MA0GCSqGSIb3DQEB\nBQUAA4IBAQBe2KlhwI2a5teCe/g+mGtpgqbFr0ZVK5Q46843EyBPVI1SiT4M0zue\noyYcllaTffyDHewnLmbLDPSCX4EFUCwtESto79BnP88Oh55MLq+nAGrJ3S2sCIWw\nzGKT6XuF3HohylbpC9c+3QaA+nsnkqgE3zwJC3130YCwxQGddnTx0PR8dhwKZqi6\nfwSAxBZ6Sa3Tu8mUpjpbrpMzMOVzm+eVq2svOziznMC0OH5gBe0m9JA5KOnKLNjV\nTKbh+Z5mRJsjPLO7Nw37TfB4qV4jqG1zsnToPK4g5bVWtDie9VREe7rVdik4ojQC\nQ3LYLrBZf+t0v+PaZ+yBfJCbEk4iRX/l"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Trinity College Dublin"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://isservices.tcd.ie"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Trinity College Dublin"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://pleiades.lesoco.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Humphries"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dan.humphries@lesoco.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "West"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:John.West@lesoco.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://pleiades.lesoco.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-09-27T15:24:20Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVAKbHiecwCXwEW8jzRANDUcHw0nS3MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCAxHjAcBgNVBAMTFXBsZWlhZGVzLmxlc29jby5hYy51azAeFw0xMzA5MDQx\n\t\t\t\t\t\tNDQ5MjBaFw0zMzA5MDQxNDQ5MjBaMCAxHjAcBgNVBAMTFXBsZWlhZGVzLmxlc29j\n\t\t\t\t\t\tby5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAPujg+dd0hL+\n\t\t\t\t\t\tZJb26+crh6T4fcFpxBBdaKNGTF1LNu5esjitzTXrAnijQVB4y1P5lR/fmqO+ajmA\n\t\t\t\t\t\tx3hoPL7UNgH7ID5fgyMLNzzox82qoByHejpswLKp+4Snvt7bhxo/6w97iKV1Sjh3\n\t\t\t\t\t\tpRRtxoeRBq7uxnL8e5WFbr7Ew9MFGDlD07ytU1gLVXZCg8+zxUU+BJ6PwLKnvujE\n\t\t\t\t\t\thYdC+A+DDAcHWGF6BlQaDjH1CXmh66E9zCRJ6YSLvazKqcJiaGbOP9skQ0Rgo4Lu\n\t\t\t\t\t\tXq1qXbfHxKbBhTcQbqvjSnzuMLLKrX0mGWugn+sfk7cwIXNNgBs+JbI8AfNF7dTs\n\t\t\t\t\t\tJ6e9Qasq25UCAwEAAaNxMG8wTgYDVR0RBEcwRYIVcGxlaWFkZXMubGVzb2NvLmFj\n\t\t\t\t\t\tLnVrhixodHRwczovL3BsZWlhZGVzLmxlc29jby5hYy51ay9pZHAvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQUA1OBiJSoiADL+KSZEPRvSD86g0YwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAISZ2JQYw5QMKpAL5VZh0/noDgzh+zYZWjDwj8w4PmvFqi7ZXyu+jLUcwU8C\n\t\t\t\t\t\tHCSmMn/ehuxZ2zR8I1qqFSbASBPTmAcYvoK4gEVyXHVEQVkwJNj0gG39UzYcymO6\n\t\t\t\t\t\tif1dnoQNOpU/a0wIxjtN4XqBamWuDybeb5vzGtWUDFlHn8kBMeNQjK8OjdPwF91X\n\t\t\t\t\t\tdHvlCj9Ab4Uvebf2faiFpEykRznumWXGzFmfqHyXlwXbomP/wBN56GbiWQUEc2+1\n\t\t\t\t\t\tMlS0EzvvZ6OgubfsZWeevOMHj5lPtwQGVrxtssl9uWEeA7ca7ZJq8J57Bk6IJIwc\n\t\t\t\t\t\tTtsUWjpvdWLpLWoB34gTflTw080="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lesoco.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://pleiades.lesoco.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://pleiades.lesoco.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://pleiades.lesoco.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pleiades.lesoco.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://pleiades.lesoco.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://pleiades.lesoco.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://pleiades.lesoco.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://pleiades.lesoco.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lesoco.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVAKbHiecwCXwEW8jzRANDUcHw0nS3MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCAxHjAcBgNVBAMTFXBsZWlhZGVzLmxlc29jby5hYy51azAeFw0xMzA5MDQx\n\t\t\t\t\t\tNDQ5MjBaFw0zMzA5MDQxNDQ5MjBaMCAxHjAcBgNVBAMTFXBsZWlhZGVzLmxlc29j\n\t\t\t\t\t\tby5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAPujg+dd0hL+\n\t\t\t\t\t\tZJb26+crh6T4fcFpxBBdaKNGTF1LNu5esjitzTXrAnijQVB4y1P5lR/fmqO+ajmA\n\t\t\t\t\t\tx3hoPL7UNgH7ID5fgyMLNzzox82qoByHejpswLKp+4Snvt7bhxo/6w97iKV1Sjh3\n\t\t\t\t\t\tpRRtxoeRBq7uxnL8e5WFbr7Ew9MFGDlD07ytU1gLVXZCg8+zxUU+BJ6PwLKnvujE\n\t\t\t\t\t\thYdC+A+DDAcHWGF6BlQaDjH1CXmh66E9zCRJ6YSLvazKqcJiaGbOP9skQ0Rgo4Lu\n\t\t\t\t\t\tXq1qXbfHxKbBhTcQbqvjSnzuMLLKrX0mGWugn+sfk7cwIXNNgBs+JbI8AfNF7dTs\n\t\t\t\t\t\tJ6e9Qasq25UCAwEAAaNxMG8wTgYDVR0RBEcwRYIVcGxlaWFkZXMubGVzb2NvLmFj\n\t\t\t\t\t\tLnVrhixodHRwczovL3BsZWlhZGVzLmxlc29jby5hYy51ay9pZHAvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQUA1OBiJSoiADL+KSZEPRvSD86g0YwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAISZ2JQYw5QMKpAL5VZh0/noDgzh+zYZWjDwj8w4PmvFqi7ZXyu+jLUcwU8C\n\t\t\t\t\t\tHCSmMn/ehuxZ2zR8I1qqFSbASBPTmAcYvoK4gEVyXHVEQVkwJNj0gG39UzYcymO6\n\t\t\t\t\t\tif1dnoQNOpU/a0wIxjtN4XqBamWuDybeb5vzGtWUDFlHn8kBMeNQjK8OjdPwF91X\n\t\t\t\t\t\tdHvlCj9Ab4Uvebf2faiFpEykRznumWXGzFmfqHyXlwXbomP/wBN56GbiWQUEc2+1\n\t\t\t\t\t\tMlS0EzvvZ6OgubfsZWeevOMHj5lPtwQGVrxtssl9uWEeA7ca7ZJq8J57Bk6IJIwc\n\t\t\t\t\t\tTtsUWjpvdWLpLWoB34gTflTw080="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "LeSoCo"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lesoco.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LeSoCo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.univ-lyon3.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "contact-shibboleth@univ-lyon3.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.univ-lyon3.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2011-01-28T10:43:17Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univ-lyon3.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univ-lyon3.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.univ-lyon3.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-lyon3.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-lyon3.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Lyon 3 - Jean Moulin"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Lyon 3 - Jean Moulin"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAJNAAx/pIfn3JBeuoLwC9QIBjkqyMA0GCSqGSIb3DQEB\nCwUAMBwxGjAYBgNVBAMMEWlkcC51bml2LWx5b24zLmZyMB4XDTE2MDMyMjEzMzYz\nM1oXDTM2MDMyMjEzMzYzM1owHDEaMBgGA1UEAwwRaWRwLnVuaXYtbHlvbjMuZnIw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCfbijCgX3LY/XFe5ubx774\nYWFm1IGTkY2MJJkfZi9BlHbXgeZcT0YHPpcLxrgkPcBLbO/DmFtlEHMvTe+vgEax\nwrQVkUP953VFPs0LZocTgNZsug49pvPPtzTUIDpLBg0K57ltJaG3lP8V+MYmp2ic\nzF+TG/hf8taR/fXpho9nzfjUmXNohTPJtJm8MacvzJgSdBhgnpIx7cJR9I14Bh10\nWTqFB23b1USDhbocuvZZkBJUukuaKECUV8cBLHDQqPcqxg2ssJonqBHGkhi6hsfv\n5+d2LOR22FcRwZW7bckY8Avv7FFf/S6Azku8C7KpGU0uhLqf+Wt1QaIjcoqNaWM1\nAgMBAAGjaTBnMB0GA1UdDgQWBBT8htL957q/I0ShSPdLgET2y/RhfjBGBgNVHREE\nPzA9ghFpZHAudW5pdi1seW9uMy5mcoYoaHR0cHM6Ly9pZHAudW5pdi1seW9uMy5m\nci9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAG8OJHNxf7TivPOMu\nCMngN0NrBnCv52OnNwBT9zCIwgomdmoBpObihfCVZi+99nr2ts7qNK+0RtUnSkZa\nWoMft02Hm8vIjPgANCb+VEzdHhz5NiOG67PITHQbv1y3wy3SdUOyyS43E5HE7kfl\nbR/ALgPVgZdVeHUD/+1wke0AaCwhdCkbD/IUoI11z8NvAIi4cHYNFu6EHcwebCWf\nbeVYAgW2oOn1NDiGKBarnIA9/Eil38PyILcfbRZ9TSJs+nReh5YpTLe9AsDRF8Pm\nN7wNdIRYdDxrWcRJorbhwW9cZBgLUpUBbDc9ZL1iafHOYbyh7C0kqqHBmXxbgZoQ\nt0Ge9Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVALk8mZ+AAF53uwidDGYBnH0PYWxbMA0GCSqGSIb3DQEB\nBQUAMBwxGjAYBgNVBAMTEWlkcC51bml2LWx5b24zLmZyMB4XDTEwMTAxMjEzMzk1\nNVoXDTMwMTAxMjEzMzk1NVowHDEaMBgGA1UEAxMRaWRwLnVuaXYtbHlvbjMuZnIw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCnHRL8McVU1CwfcgOZzodc\nG9yjFNUlE5+tKEwGlkDNpOW+dIK3nZ4o3LxeOZVCA6sBJ6zGvPKLrbwaQ1ec7wUw\nZd2/VGlpT6puPc6hPuqa8ghTKgAsYAaLgnnXMTsXgOi2ieu+KpOhBWUChZU8UgjT\nPFa7KjRzQ7xLoHd4+ZdkXIcb4VUMR8nEBNVQ2C18c4CNgGN6aYPpP++kFHJJi85F\n2jmD07ccl0DES2sPfDLpniZDin+eD8ij8UXviy9e8v4ssrXi/qNvP8eHSsDTUkT8\nzkMEs6ovVCGMZf/aie0RVaZ0h8G4n9UF2xk/+ASAxVcAl5Kwfy6g4/sno0BDWul7\nAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEWlkcC51bml2LWx5b24zLmZyhihodHRwczov\nL2lkcC51bml2LWx5b24zLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQRoWeg\nQi5urVmZRbLmZzQW2w0DkjANBgkqhkiG9w0BAQUFAAOCAQEAYA43hVTg4DIEtI5l\n1I2MMrZhXAkpihNEC8G2HTtpUAq2GeAKTzUzUyQ133V3JgY8XDkpCM8XhPqI6wAH\n5k9pOwKeePRjDWkycJYsBeCl5x1wspNqNGfbWEMfCALXeP8YI5annKFUBnit2VrX\neXB9i4dKcDeYCVzKW1hd7meBbw6Iijwnxt7ZESzVzibWVYi/gB3zT2OLHjFhONj4\nTWXosGddVcZLkq+eFRjPBFUZmin0Y1i6IPWtHveMnegwrIimwh4hc3Hq9x9frai9\nvU4n/dUR4kWq12hY6VObixqfgw9dHPnALDINjOdTHmmXaSJAyv5tQkmIRGZyMOmc\nn4c/iw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Lyon 3 - Jean Moulin"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-lyon3.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Lyon 3 - Jean Moulin"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib2.qmu.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Haining"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ghaining@qmu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Garry"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Haining"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ghaining@qmu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Garry"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib2.qmu.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-05-04T12:46:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEHDCCAwSgAwIBAgIJALXqP3+WEFbxMA0GCSqGSIb3DQEBBQUAMIGOMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEVMBMGA1UECBMMRWFzdCBMb3RoaWFuMRQwEgYDVQQHEwtNdXNzZWxi\n\t\t\t\t\t\tdXJnaDEiMCAGA1UEChMZUXVlZW4gTWFyZ2FyZXQgVW5pdmVyc2l0eTEUMBIGA1UE\n\t\t\t\t\t\tCxMLSVQgU2VydmljZXMxGDAWBgNVBAMTD3NoaWIyLnFtdS5hYy51azAeFw0xNTAy\n\t\t\t\t\t\tMDYxMzQ5MzlaFw0yNTAyMDMxMzQ5MzlaMIGOMQswCQYDVQQGEwJHQjEVMBMGA1UE\n\t\t\t\t\t\tCBMMRWFzdCBMb3RoaWFuMRQwEgYDVQQHEwtNdXNzZWxidXJnaDEiMCAGA1UEChMZ\n\t\t\t\t\t\tUXVlZW4gTWFyZ2FyZXQgVW5pdmVyc2l0eTEUMBIGA1UECxMLSVQgU2VydmljZXMx\n\t\t\t\t\t\tGDAWBgNVBAMTD3NoaWIyLnFtdS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALZ45sT4BFzeyQq+7s+fB3MXY5DEJ7M5LqLwOuLQu9qQy8QXkfjl\n\t\t\t\t\t\tIF/njXWdTISjaQduqpfxQ2s2math1WjYqw+ahbBo7pLMtJjUZaFuBu8SfWOvlAcj\n\t\t\t\t\t\tnBmZGuo38oaKVi7F+cPEltwEyA4soxdjy+VnwIHlcmgapQf6/qu/zUwDzQpr+DjO\n\t\t\t\t\t\tVXLc2E/F4ac6DdWaymQgCyuukR6nz8y690XurJmd9neaZGMjYRcM9MStHM6rNuRh\n\t\t\t\t\t\tsnpjcTgJ1LVtMeLHzp6F3AyEy10oRGmuehLNsG53jD8qyjVQgiN1BICaUBEwuz49\n\t\t\t\t\t\tlB5IsP1LbP5ZaGx23w/gm/TndqTo3toThX8CAwEAAaN7MHkwCQYDVR0TBAIwADAs\n\t\t\t\t\t\tBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYD\n\t\t\t\t\t\tVR0OBBYEFG+x6Z1HFy1EVNofQT5Pz5MbLFglMB8GA1UdIwQYMBaAFG+x6Z1HFy1E\n\t\t\t\t\t\tVNofQT5Pz5MbLFglMA0GCSqGSIb3DQEBBQUAA4IBAQBu+SRFvMc99/KKW615vkO0\n\t\t\t\t\t\tIZYqXVKtt13FjHOzNIm9Pb51dzOqEBVqSn4Hc0lhaL5Bat8t8JgDbKFd85H8v/oB\n\t\t\t\t\t\ttM7XBK4bgQhyG4jd144SSwN1HLqWKdQE54w3MyWvFHrGrPAqjgqZMqGSCFpORlJG\n\t\t\t\t\t\trd2EC/yHEkOrY0X74q0uaU6D7Kp96Ayv5NtZWvCcj1hNdQF/CoX0vA+uFdYWWUEd\n\t\t\t\t\t\toiaa7CX11axaCto39+d4wwqSeX3j0YUkvkU+0spZeYstSA5PNX4G8drgxRGK3+uV\n\t\t\t\t\t\tblLOGW/k9vBqR2M4FEIMjli/7ytkIVG6q0g1ENv3x89Q6y7pqzP/G1L4q0d0lkKq"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "qmu.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib2.qmu.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib2.qmu.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib2.qmu.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib2.qmu.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib2.qmu.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib2.qmu.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib2.qmu.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib2.qmu.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "logo": [
                  {
                    "text": "https://shib2.qmu.ac.uk/qmu_logo.gif",
                    "height": "47",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "https://shib2.qmu.ac.uk/qmu_icon.gif",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Queen Margaret University, Edinburgh"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "qmu.ac.uk"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:55.931696,-3.073457"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "194.83.92.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.62.47.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "194.83.30.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "212.219.89.0/25"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "qmu.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEHDCCAwSgAwIBAgIJALXqP3+WEFbxMA0GCSqGSIb3DQEBBQUAMIGOMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEVMBMGA1UECBMMRWFzdCBMb3RoaWFuMRQwEgYDVQQHEwtNdXNzZWxi\n\t\t\t\t\t\tdXJnaDEiMCAGA1UEChMZUXVlZW4gTWFyZ2FyZXQgVW5pdmVyc2l0eTEUMBIGA1UE\n\t\t\t\t\t\tCxMLSVQgU2VydmljZXMxGDAWBgNVBAMTD3NoaWIyLnFtdS5hYy51azAeFw0xNTAy\n\t\t\t\t\t\tMDYxMzQ5MzlaFw0yNTAyMDMxMzQ5MzlaMIGOMQswCQYDVQQGEwJHQjEVMBMGA1UE\n\t\t\t\t\t\tCBMMRWFzdCBMb3RoaWFuMRQwEgYDVQQHEwtNdXNzZWxidXJnaDEiMCAGA1UEChMZ\n\t\t\t\t\t\tUXVlZW4gTWFyZ2FyZXQgVW5pdmVyc2l0eTEUMBIGA1UECxMLSVQgU2VydmljZXMx\n\t\t\t\t\t\tGDAWBgNVBAMTD3NoaWIyLnFtdS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALZ45sT4BFzeyQq+7s+fB3MXY5DEJ7M5LqLwOuLQu9qQy8QXkfjl\n\t\t\t\t\t\tIF/njXWdTISjaQduqpfxQ2s2math1WjYqw+ahbBo7pLMtJjUZaFuBu8SfWOvlAcj\n\t\t\t\t\t\tnBmZGuo38oaKVi7F+cPEltwEyA4soxdjy+VnwIHlcmgapQf6/qu/zUwDzQpr+DjO\n\t\t\t\t\t\tVXLc2E/F4ac6DdWaymQgCyuukR6nz8y690XurJmd9neaZGMjYRcM9MStHM6rNuRh\n\t\t\t\t\t\tsnpjcTgJ1LVtMeLHzp6F3AyEy10oRGmuehLNsG53jD8qyjVQgiN1BICaUBEwuz49\n\t\t\t\t\t\tlB5IsP1LbP5ZaGx23w/gm/TndqTo3toThX8CAwEAAaN7MHkwCQYDVR0TBAIwADAs\n\t\t\t\t\t\tBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYD\n\t\t\t\t\t\tVR0OBBYEFG+x6Z1HFy1EVNofQT5Pz5MbLFglMB8GA1UdIwQYMBaAFG+x6Z1HFy1E\n\t\t\t\t\t\tVNofQT5Pz5MbLFglMA0GCSqGSIb3DQEBBQUAA4IBAQBu+SRFvMc99/KKW615vkO0\n\t\t\t\t\t\tIZYqXVKtt13FjHOzNIm9Pb51dzOqEBVqSn4Hc0lhaL5Bat8t8JgDbKFd85H8v/oB\n\t\t\t\t\t\ttM7XBK4bgQhyG4jd144SSwN1HLqWKdQE54w3MyWvFHrGrPAqjgqZMqGSCFpORlJG\n\t\t\t\t\t\trd2EC/yHEkOrY0X74q0uaU6D7Kp96Ayv5NtZWvCcj1hNdQF/CoX0vA+uFdYWWUEd\n\t\t\t\t\t\toiaa7CX11axaCto39+d4wwqSeX3j0YUkvkU+0spZeYstSA5PNX4G8drgxRGK3+uV\n\t\t\t\t\t\tblLOGW/k9vBqR2M4FEIMjli/7ytkIVG6q0g1ENv3x89Q6y7pqzP/G1L4q0d0lkKq"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Queen Margaret University, Edinburgh"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qmu.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Queen Margaret University, Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.iit.cnr.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:iit-idem@iit.cnr.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.iit.cnr.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2010-07-06T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVANNctxDOg6xktyigLZGJNgH/9KDGMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC5paXQuY25yLml0MB4XDTA5MDMwMjEwMDQ1OFoX\nDTI5MDMwMjEwMDQ1OFowGTEXMBUGA1UEAxMOaWRwLmlpdC5jbnIuaXQwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDUU9hTCDxUfrFa+IsB4gTIYZCyDRau\ntXeow0NhSDYZrDBwYrc2CiuM26zz9N1TKx6Ap+8CXwQA0PXou+WdFCz1RTMJX+Uq\nkOCjAKN2HmoiDIrI5P2MsHKl+DPLd9Lvnob1dTCDYrWMnPNYBm0iuRDvU59RZWPE\nV9hiqKcKAmT3KB4Gt2SqbFoD3ML/VpZOzolak4/7qvV3/YmuBl82ekz1+w3Adbwy\ngNQsyILyw020F1lL2FDWji5LaUuMPqYzPKykZDWT6wnDw2fZ9j0XxmUCWHDKsUqR\nrbPei38Gy+jtToJ2kNQp7qwFW1C9pvP4PBqhq3gGu6QF1qOT8qTEYs8nAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC5paXQuY25yLml0hiVodHRwczovL2lkcC5paXQu\nY25yLml0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSkgwUVx8ERu+P2jzA6x8r6\ne9wUzTANBgkqhkiG9w0BAQUFAAOCAQEAVoMKYN2nyFAF9dsAV21/r9Gse2s4d/zJ\n4lVNUCJGrKvWkiUD9GKInX8TdqrQOW5bjjTB4ldkzrHKqVfi2sPDTfvscQ/4OM7w\nE6dsFiiTz71NrDQ2bYIplDqrpWNzRTs5hxXCKkXmGwCtWd9MWlb181qCFuKq+3u0\nOygjy0U5YBCULsebWcg1GT5swQiRYtRuJkFDEnwQ79j91ceADPiQ+DeIdeBeK+Xz\n8eGhNrtn3uOLW2SCx5QBkfE5cBFYMPMSQLM5FaCetuZl6mePHuaj0IkpVQDJpYI6\nRS0HkZxnqxq0gCbYR4dSCVUR/8NFcO/jsQCEZIauvzx9bXt7vpBKSg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iit.cnr.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.iit.cnr.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.iit.cnr.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.iit.cnr.it/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.iit.cnr.it/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.iit.cnr.it:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.iit.cnr.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.iit.cnr.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.iit.cnr.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.iit.cnr.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.iit.cnr.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.iit.cnr.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iit.cnr.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://idp.iit.cnr.it/idpservice.php"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.iit.cnr.it/en"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for CNR Institute of Informatics and Telematics users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti di CNR Istituto di Informatica e Telematica"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CNR Institute of Informatics and Telematics"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CNR Istituto di Informatica e Telematica"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVANNctxDOg6xktyigLZGJNgH/9KDGMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC5paXQuY25yLml0MB4XDTA5MDMwMjEwMDQ1OFoX\nDTI5MDMwMjEwMDQ1OFowGTEXMBUGA1UEAxMOaWRwLmlpdC5jbnIuaXQwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDUU9hTCDxUfrFa+IsB4gTIYZCyDRau\ntXeow0NhSDYZrDBwYrc2CiuM26zz9N1TKx6Ap+8CXwQA0PXou+WdFCz1RTMJX+Uq\nkOCjAKN2HmoiDIrI5P2MsHKl+DPLd9Lvnob1dTCDYrWMnPNYBm0iuRDvU59RZWPE\nV9hiqKcKAmT3KB4Gt2SqbFoD3ML/VpZOzolak4/7qvV3/YmuBl82ekz1+w3Adbwy\ngNQsyILyw020F1lL2FDWji5LaUuMPqYzPKykZDWT6wnDw2fZ9j0XxmUCWHDKsUqR\nrbPei38Gy+jtToJ2kNQp7qwFW1C9pvP4PBqhq3gGu6QF1qOT8qTEYs8nAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC5paXQuY25yLml0hiVodHRwczovL2lkcC5paXQu\nY25yLml0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSkgwUVx8ERu+P2jzA6x8r6\ne9wUzTANBgkqhkiG9w0BAQUFAAOCAQEAVoMKYN2nyFAF9dsAV21/r9Gse2s4d/zJ\n4lVNUCJGrKvWkiUD9GKInX8TdqrQOW5bjjTB4ldkzrHKqVfi2sPDTfvscQ/4OM7w\nE6dsFiiTz71NrDQ2bYIplDqrpWNzRTs5hxXCKkXmGwCtWd9MWlb181qCFuKq+3u0\nOygjy0U5YBCULsebWcg1GT5swQiRYtRuJkFDEnwQ79j91ceADPiQ+DeIdeBeK+Xz\n8eGhNrtn3uOLW2SCx5QBkfE5cBFYMPMSQLM5FaCetuZl6mePHuaj0IkpVQDJpYI6\nRS0HkZxnqxq0gCbYR4dSCVUR/8NFcO/jsQCEZIauvzx9bXt7vpBKSg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CNR Institute of Informatics and Telematics"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CNR Istituto di Informatica e Telematica"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iit.cnr.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iit.cnr.it/en"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consiglio Nazionale delle Ricerche (CNR)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National Research Council (CNR)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.sci-ware-customer.com/prod/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:customersupport@sci-ware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Customer Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Scecina"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ondrej.scecina@sci-ware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ondrej"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.sci-ware-customer.com/prod/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-10-03T15:51:20Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Science Warehouse Prod"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sci-ware.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Science Warehouse Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.sci-ware-customer.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.sci-ware-customer.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.sci-ware-customer.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.sci-ware-customer.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.sci-ware-customer.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.sci-ware-customer.com/Shibboleth.sso/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.sci-ware-customer.com/Shibboleth.sso/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.sci-ware-customer.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.sci-ware-customer.com/Shibboleth.sso/LoginYSJ",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEjCCAfqgAwIBAgIJAKlKWUryntpMMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\n\t\t\t\t\t\tBAMTGXByaW1lcHJkd2ViMS5zY2ktd2FyZS5jb20wHhcNMTMwOTAzMTExMjEwWhcN\n\t\t\t\t\t\tMjMwOTAxMTExMjEwWjAkMSIwIAYDVQQDExlwcmltZXByZHdlYjEuc2NpLXdhcmUu\n\t\t\t\t\t\tY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsbBRJSDJTCy3wMgv\n\t\t\t\t\t\t6ZrBBI0uezsJcx29t6kW+Qk+5bwEhB8jcYf/LNSpnVs8GKpuxScPxXLOp8PSn0g5\n\t\t\t\t\t\tsmhtTdCc5Ejsluu7SM6vd70o0YkufgCih3qtIKnFVgR++G5s5//uaY/3z6eO47YT\n\t\t\t\t\t\tav+X9gagf8GlJCums10JcVTNqwmZlsoa9WSaprXOlcBij6zqqWvsv1en37KkE699\n\t\t\t\t\t\tFEK779lvNleZWW8gK+QpsNSOMcIH2qTDNRHxpWRw61iMay33ec7M3wMivX13VKLV\n\t\t\t\t\t\tfEbWi7OxG0tRSYQDZtrqDHSTzyJ4h6MexQj9sVrJYftCb7w51tf8l0X6zmMsdFLs\n\t\t\t\t\t\touB8gQIDAQABo0cwRTAkBgNVHREEHTAbghlwcmltZXByZHdlYjEuc2NpLXdhcmUu\n\t\t\t\t\t\tY29tMB0GA1UdDgQWBBTCBrpWzU/p3zVsmMp+CJkBA4cuHDANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAT02NyaYkpI8qwUt1BLp4Papn82/4dQwxz9E9zYTpqBwAUaDrXpC+T62Q\n\t\t\t\t\t\t8KIq9rAGrefopyxJ8nMFJi+zUlaKKnkE6vCGtHC2isaH5MYa+h6fiLzhEsa3mB9B\n\t\t\t\t\t\t+K+lrr3EjXiAxcb2/pRVdO85XGSD8mbXyxaB0ZcD4scC32mrccBdLL+jda5KAw7Z\n\t\t\t\t\t\tIS7teotcfyoewPeFFVjZ98U6FFLguL25Sp5SsJerWsHVv9uDw+4gCoEk0jfOjMQU\n\t\t\t\t\t\tf92do3qVdA2tG+NS4/sKj5ge1TOC1SRIclDy286Fp+9De5zRAsGT7hTyNjR2IQxN\n\t\t\t\t\t\tQ/xODP8/OH7oPsl9aC8UfiSUxgwqsw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.sci-ware-customer.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.sci-ware-customer.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.sci-ware-customer.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.sci-ware-customer.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.sci-ware-customer.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.sci-ware-customer.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.sci-ware-customer.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.sci-ware-customer.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.sci-ware-customer.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.sci-ware-customer.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayfa.efif.dk/fg/module.php/saml/sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayfa.efif.dk/fg/module.php/saml/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2011-02-02T13:02:24Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayfa.efif.dk/fg/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "frsgym.dk"
              },
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Frederikssund Gymnasium"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Frederikssund Gymnasium"
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Frederikssund Gymnasium"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Frederikssund Gymnasium"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "frsgym.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4DCCAcgCAQcwDQYJKoZIhvcNAQELBQAwNjE0MDIGA1UEAwwraHR0cHM6Ly93\nYXlmYS5lZmlmLmRrL2ZnL21vZHVsZS5waHAvc2FtbC9zcDAeFw0xNTAxMDEwMDAw\nMDBaFw0yNTEyMzEyMzU5NTlaMDYxNDAyBgNVBAMMK2h0dHBzOi8vd2F5ZmEuZWZp\nZi5kay9mZy9tb2R1bGUucGhwL3NhbWwvc3AwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQDHiAwKahBTuI4Z+IJ1rgOeEiCCy3bR9QIe3BpCsejFCU5rSzkW\nANqVuc1PDfp0JdIZhrPXsmDJQMmidPCGPIDQKo+bk+af3+EUFS/I/+35sSBX2vf+\nh1DHvZV9jsznmpSVjp7HZ/WoPWBykWBJO0AOVmzB5zlaqkS36J76+wxerwdpuExV\nnYSNd73S+AyT/EZ+tXAO+6lQ8FL/YMlJnUkSaSqLSHFy01D2qBNmYRwBpCS6/dUZ\nyxi0t5j8ghKUD4BHOZVavn65J62cJdXiOcMRyUAIp57GXQrL63KtrjIcXddq+CZy\nZ5t37EdUOIz42joFcy73MFOntynlKEvOw1BJAgMBAAEwDQYJKoZIhvcNAQELBQAD\nggEBAHAHUMAarPKICDUsUip01HiutylcGhvPKlOtBXJKeksrZ5iAJp9W9i2ITSJP\n6CfI8XYTNAc+kGVLyFPujVscCA4QUwlkVlg0bxNbr3tMKJqQCmuzZZak1aIjgvdd\n+l3W5qRCWaQkU8dJ4S//ctURTHyYY8K6jVgTkLadbdi4YN+RkqFSIN9e6D+q9NWO\nk+79zUEOfp+n+tLG7SjVo+i+4WbIjxVHjXGgIwOUUJ97CmfQO6DV7yIuptVdeQMU\nTfZ2fqqqJuGx1GBc5SXHKFypaavBGP+UfY/xo/Z4VIoSS48u3cCdGAdToeKpUKYZ\nWl7WIRfFhXMrMTMiDDMGbZpFe+s="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Frederikssund Gymnasium"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Frederikssund Gymnasium"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.frsgym.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.frsgym.dk"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Frederikssund Gymnasium"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Frederikssund Gymnasium"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:muohio.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tepeds@muohio.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dirk Tepe"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kidddw@muohio.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Don Kidd"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "beckmd@muohio.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael Beck"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:muohio.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://muidp.miamioh.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://muidp.miamioh.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAKw5joclkRM7v8BoI/l7FWUAWuZmMA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEG11aWRwLm11b2hpby5lZHUwHhcNMTEwOTA2MTgxNzM3\nWhcNMzEwOTA2MTgxNzM3WjAbMRkwFwYDVQQDExBtdWlkcC5tdW9oaW8uZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqb1TAe1bFQ71cuQZz4gP91bT\nRr8OIr9VA6lAB9L3kO5KQYx5NUBkCbKsWky7M/dbW/+Pt9tj6pkwIEr4GDO0un36\nEZPi3+1Gv0Wmc2WTGA8xQVCPoUP/bd7e5H+gRF7gla5Aj7zvejARFVnw5ajgVvTT\nz5YZAp7Nmw+uJLHMb6IQf+m3xpKGM/tHqZDyhmKIFD18TopyiBLnRGHwKFwxx1Sq\nqfAzkq2OOr5LWb6M6D4FSF0jR0OGKzl6GNi05zvRm40P+nwydCIaC/XduoWodKuU\nl7UkX7JaltsaEVLbpXJBato9Uwyif1vqXMG4oKv0JqMv0I6uzA2J9wbLhQNgjQID\nAQABo2cwZTBEBgNVHREEPTA7ghBtdWlkcC5tdW9oaW8uZWR1hidodHRwczovL211\naWRwLm11b2hpby5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFHletfQytS1u\nCV3Q3wC3ObBMfcpPMA0GCSqGSIb3DQEBBQUAA4IBAQAZUdcZLnMUQpH01ZtHKveu\nPhbjFymh5NThn5Djx83uHXJV8duDEn9+DlEBmIkJefT5IIoRtHQZDeJVk5i5DDm6\nMJpaN48/EVYIlsAnJqO1d6u+ccAIRSlWyqeQPTCJ59mEsv6Va9EEO106EPvcAmzk\nPjkOhl1Xv1kTYkhNlUe+lD76xgvaizZqxQNOZSohGB6JKWVgpVmNKXrG70bPFoVD\nW9zHQ1QMn4zgrcdIXAh35hfJ3V11hYNAxbEJR+a6JcLx6w8sYF4hKcNMez89uunC\nYYDYqK0Q9zukmasDWzcclzuqiJdWWMieNGYFgQOru5/17okAMls3dl2RmjoQgEsN"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "muohio.edu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "miamioh.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://muidp.miamioh.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://muidp.miamioh.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://muidp.miamioh.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://muidp.miamioh.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://muidp.miamioh.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://muidp.miamioh.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "muohio.edu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "miamioh.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Miami University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAKw5joclkRM7v8BoI/l7FWUAWuZmMA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEG11aWRwLm11b2hpby5lZHUwHhcNMTEwOTA2MTgxNzM3\nWhcNMzEwOTA2MTgxNzM3WjAbMRkwFwYDVQQDExBtdWlkcC5tdW9oaW8uZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqb1TAe1bFQ71cuQZz4gP91bT\nRr8OIr9VA6lAB9L3kO5KQYx5NUBkCbKsWky7M/dbW/+Pt9tj6pkwIEr4GDO0un36\nEZPi3+1Gv0Wmc2WTGA8xQVCPoUP/bd7e5H+gRF7gla5Aj7zvejARFVnw5ajgVvTT\nz5YZAp7Nmw+uJLHMb6IQf+m3xpKGM/tHqZDyhmKIFD18TopyiBLnRGHwKFwxx1Sq\nqfAzkq2OOr5LWb6M6D4FSF0jR0OGKzl6GNi05zvRm40P+nwydCIaC/XduoWodKuU\nl7UkX7JaltsaEVLbpXJBato9Uwyif1vqXMG4oKv0JqMv0I6uzA2J9wbLhQNgjQID\nAQABo2cwZTBEBgNVHREEPTA7ghBtdWlkcC5tdW9oaW8uZWR1hidodHRwczovL211\naWRwLm11b2hpby5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFHletfQytS1u\nCV3Q3wC3ObBMfcpPMA0GCSqGSIb3DQEBBQUAA4IBAQAZUdcZLnMUQpH01ZtHKveu\nPhbjFymh5NThn5Djx83uHXJV8duDEn9+DlEBmIkJefT5IIoRtHQZDeJVk5i5DDm6\nMJpaN48/EVYIlsAnJqO1d6u+ccAIRSlWyqeQPTCJ59mEsv6Va9EEO106EPvcAmzk\nPjkOhl1Xv1kTYkhNlUe+lD76xgvaizZqxQNOZSohGB6JKWVgpVmNKXrG70bPFoVD\nW9zHQ1QMn4zgrcdIXAh35hfJ3V11hYNAxbEJR+a6JcLx6w8sYF4hKcNMez89uunC\nYYDYqK0Q9zukmasDWzcclzuqiJdWWMieNGYFgQOru5/17okAMls3dl2RmjoQgEsN"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://shib-idp.muohio.edu/shibboleth/error.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Miami University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.muohio.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Miami University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://hexaa.eduid.hu/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "aai@niif.hu"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@niif.hu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "aai@niif.hu"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@niif.hu"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "aai@niif.hu"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@niif.hu"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://hexaa.eduid.hu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-edugain"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "hexaa"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:geant:niif.hu:eduid.hu:entity-attributes:processing-info",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "hu",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://metadata.eduid.hu/registration_policy_1_0.txt"
              }
            ],
            "registration_instant": "2013-08-01T07:17:19.807Z",
            "registration_authority": "http://eduid.hu",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NIIF - Nemzeti Inform\u00e1ci\u00f3s Infrastrukt\u00fara Fejleszt\u00e9si Int\u00e9zet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NIIF Institute - National Information Infrastructure Development"
          }
        ],
        "organization_url": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.niif.hu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.niif.hu/en"
          }
        ],
        "organization_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NIIF - Nemzeti Inform\u00e1ci\u00f3s Infrastrukt\u00fara Fejleszt\u00e9si Int\u00e9zet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NIIF Institute - National Information Infrastructure Development"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://hexaa.eduid.hu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://hexaa.eduid.hu/"
                  }
                ],
                "description": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "A HEXAA egy k\u00fcls\u0151 attrib\u00fatum szolg\u00e1ltat\u00e1s. A szolg\u00e1ltat\u00e1s c\u00e9lja az, hogy felhaszn\u00e1l\u00f3i adatokat r\u00f6gz\u00edthessenek bele, amelyet megoszthatnak tartalomszolg\u00e1ltat\u00f3kkal. A HEXAA-ban nyilv\u00e1ntarthat\u00f3ak csoportok, virtu\u00e1lis szervezetek, jogosults\u00e1gi inform\u00e1ci\u00f3k, valamint a felhaszn\u00e1l\u00f3ra jellemz\u0151 egy\u00e9b inform\u00e1ci\u00f3k is."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "HEXAA is an External Attribute Authority.  It can store user attributes that can be shared with Service Providers. Virtual organizations and groups can also be managed with HEXAA as well as access control infromation and profile information."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.eduid.hu/hu/hexaa-adatkezelesi-szabalyzat/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "HEXAA"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "HEXAA"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "hexaa.eduid.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hexaa.eduid.hu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://hexaa.eduid.hu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "hu",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "HEXAA"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "HEXAA"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://student.ate.ladok.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://student.ate.ladok.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.ate.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.ate.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.ate.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.ate.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.ate.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://student.ate.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://student.ate.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://student.ate.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok student.ate.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok student.ate.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://student.ate.ladok.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "student.ate.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIJAPGA6tzcgNkTMA0GCSqGSIb3DQEBCwUAMB8xHTAbBgNV\nBAMTFHN0dWRlbnQuYXRlLmxhZG9rLnNlMB4XDTE2MDMxNDEzMDMyN1oXDTI2MDMx\nMjEzMDMyN1owHzEdMBsGA1UEAxMUc3R1ZGVudC5hdGUubGFkb2suc2UwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDKyIfQtdq2FrR8qsthGDMXmaFHZ/Ge\nbpjOO6YMeNpIP3U8QceGuMWWLkgweeci78hkFZ/zni1WNF5V0zhMTLGrRs+ASHpM\n+BqYM5Xf6OIyKTuUOMhaJnQY55HPNy5SWB3pZLi/8WP7QWL6wkZSOJTtwvjHz8vu\nWy+0qVx//LSul6BFIEOMMfc6NJGg3KT91n8Fs3kxZcawiyuJiO7O9pCdbOG0RXW3\nipIOZzv/YjC7Cb0e3kea1ED37TO4I8AxwVKpkhqNlZoRONY439NGqG21e+Oqrogs\nhFy7g35Irf4c/EizrTah+bZtlPzxi11GN7AeBzDucj4IfnPg4WEfqOydAgMBAAGj\nZzBlMEQGA1UdEQQ9MDuCFHN0dWRlbnQuYXRlLmxhZG9rLnNlhiNodHRwczovL3N0\ndWRlbnQuYXRlLmxhZG9rLnNlL2d1aS1zcDAdBgNVHQ4EFgQUCS6vUkUfFHEL0Vjp\n2qWovVeYakwwDQYJKoZIhvcNAQELBQADggEBAFeXHEuJgAFOa9Iq1WhDXzmcv6BG\npQYZLrHS9LCXL1fhVK/9yr3T0/vB3yyovt+poihL+LOTauVvpR64GQOYbwoQmoMr\n8XySdGBhTol5B/jnBRiRuWMOMtJ5P+Bs/BqGb2tpyFjgujIJoH67k2C7mIbqef+4\n1livYsr6oZqYqCM7p7I1e7ZrD23Izt9t/xfRB1rWwqrhyDSJIOSdkJihcv9tty71\nkGZl4+dk2BsiU3oulvfww5KhVbMYttnmm+4N4Gh4Sc8/xNM2TEuLZY+1AsZGh5RW\nKrMJx6CX82Vpnibn2PQZsp52iXVQN/95m3Cx3Oq2Cj+cYpfNQHPcSdSET5s="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=student.ate.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.ate.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.ate.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.ate.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.ate.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.ate.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.ate.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://student.ate.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://student.ate.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://student.ate.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://sts.roc-nijmegen.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://sts.roc-nijmegen.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-07-30T10:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/d8ea069ad0633af0a11fe741f3ceb585",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ROC Nijmegen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ROC Nijmegen"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/roc-nijmegen.png",
                    "height": "15",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ROC Nijmegen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ROC Nijmegen"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ROC Nijmegen"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.roc-nijmegen.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ROC Nijmegen"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://play.hb.se/shibboleth",
    {
      "entity_id": "https://play.hb.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://play.hb.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://play.hb.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.hb.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://play.hb.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://play.hb.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://play.hb.se/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://play.hb.se/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "play.hb.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJAOvLiNnV6cTzMA0GCSqGSIb3DQEBBQUAMBUxEzARBgNV\nBAMTCnBsYXkuaGIuc2UwHhcNMTIwNzA0MTM0NDIyWhcNMjIwNzAyMTM0NDIyWjAV\nMRMwEQYDVQQDEwpwbGF5LmhiLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\nCgKCAQEAsC+n2G+sTBN1LFD3ouhmVNujuIZlzpgP22MWLZ4REIG4HOH2jOJRFbAS\nZ3hIBe35cMYT1099TJhGK/TpurA2zCiXrwu4FzVH8oAFK7Ko/EruEUZoqxwKO3fS\nbVRZhEW0YFPj2R5ENOoiccD55mp3RE5+wJ+GKgEWlYIJF/APZ8kFrXkTAv9Af6LH\nWZL1f5SEgqXCD7y7pr/Y97QbHz1ruAYsq7UFnOjtVMHhFNY2G9IrpzcqMQ7L18TE\noBTQ0udKMOgMhcFwQh5lSDazrvCjMddUj8rQDymsl3pHZbPAOrWd15ojuwpO0dql\nLvvAwBMYWeozikSZk2/BtS2J+QRIhwIDAQABo0QwQjAhBgNVHREEGjAYggpwbGF5\nLmhiLnNlhgpwbGF5LmhiLnNlMB0GA1UdDgQWBBSVesO6y/DVoLHWvQjeutwfnSHQ\nkTANBgkqhkiG9w0BAQUFAAOCAQEAXS12bCxjIYpnC5oGD0UCOZmlgzBJtqTY/o76\nE7GuwCSO9i/SIEL06fzgzkJGjaUbLlAHws0Qo6QkS8PGlM0/Judv1qFrzG1Two0t\nTjwLfVTfl0MNCvx3BUnk/quKsj2s6o12EH279gND5Wuh4kAqSFIlO05mYxt+3eM6\nanE0HCN44TbeEOgfcWeXR8bYwjEIPQZM8FUfzK8z0R3FL0hMRPItgfEMnRiOqX05\nhQgJy7Uk7DD3Lcy9yZoMmihj9baBhImCe3aKc/2UTNKPYHiB9DGqY5Ab6iZeA5bg\nX6RkltZT6yho98P4hxRs87RcrU+ScrgsjYZq9RoLHDPid7sDIA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=play.hb.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://play.hb.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://play.hb.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.hb.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://play.hb.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.hb.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://play.hb.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://play.hb.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://play.hb.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://play.hb.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://play.hb.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://app.staging.goodpractice.net",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ferguson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:oferguson@goodpractice.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Owen"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Anderson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:janderson@goodpractice.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jonny"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://app.staging.goodpractice.net",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-11-13T11:18:16Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GoodPractice (Staging)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.goodpractice.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Good Practice Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIJAPkZY/RifCMCMA0GCSqGSIb3DQEBCwUAMA8xDTALBgNV\n\t\t\t\t\t\tBAMTBHRlc3QwHhcNMTQxMTEyMTEwMTM1WhcNMjQxMTA5MTEwMTM1WjAPMQ0wCwYD\n\t\t\t\t\t\tVQQDEwR0ZXN0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAwbnYcv3B\n\t\t\t\t\t\tIHH5O1Nu9aOw7IgjsYrzTFGmx/R/Lgbyh03t34FkAQ9SZ4ToKHRI7wJuHN2SveV2\n\t\t\t\t\t\tLBjZ8PgoM7Nzkryl2fpF6sytuqMhKFzdSEbHEXMn1GqKCQoQGno5jzZAtcyqxXrF\n\t\t\t\t\t\tiK5WrwSuPbopgGzu9UyPfaxaqmYVN0BW50z3NlKEZoQsc8w5WR9r1GDLNTSG0Jqx\n\t\t\t\t\t\tsCpzRktkdKAsjskRiqp0X/gFquBEwajyWqF08PGsfwW0iqISc+bCmD1IWGZCQLcy\n\t\t\t\t\t\t7eanVD3w13oFNPmqmxZSIiNNSXP5Gb7jcBZ+xWORwnIGOTBeThIPEWOlO4Kr7dDC\n\t\t\t\t\t\t2fm1YW1OiJwRPQIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1P\n\t\t\t\t\t\tcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUwN4Ob3oWtiCr\n\t\t\t\t\t\tFwqrickuFNGD/e8wHwYDVR0jBBgwFoAUwN4Ob3oWtiCrFwqrickuFNGD/e8wDQYJ\n\t\t\t\t\t\tKoZIhvcNAQELBQADggEBAEOVm9crJjxi8CPsqJZEfV4ZnO4IlDyEFt3zNpKyamsC\n\t\t\t\t\t\t01KFXkldoUhg1YNjLkpueysSyCpYrVe3BgkWdEccPO1GrGWYCYOgT3lf9LQ9hH5z\n\t\t\t\t\t\tKTrkC+vftsNFv8YwWQgrncNscMPldbC6ig0khE2IC3mGJMKR8MgHLJWlNV3txgR5\n\t\t\t\t\t\tRi4pgGB+Ax6on6oQHks4I4EvDti7vtarY62Vuu8K6lJHltPkM6BjmQo2n0qJE9Hd\n\t\t\t\t\t\t4Cp1NN51cLFIhjRA/gurU7ZUJMg84oaEpG+CVQn0ckKLb9JiKajXSh8HvjX5+COk\n\t\t\t\t\t\tGvUxcf3q5ZXwJL6K+o0lrNadM/TN+8gZW441MEjl8Fc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://app.staging.goodpractice.net/security/saml2/response",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "GoodPractice provides relevant leadership and management programmes that improve performance and deliver measurable business change."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "GoodPractice Ltd"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "Email",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "DisplayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "FirstName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "LastName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://aai-logon.fhsg.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support Contact"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:switchaai@fhsg.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hotline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Informatik"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@switch.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SWITCHaai Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://aai-logon.fhsg.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2015-10-13T07:59:38Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIJAJPilzxxDSFSMA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\nBAMTEWFhaS1sb2dvbi5maHNnLmNoMB4XDTE0MDkwNDA3NDc1NFoXDTE3MDkwMzA3\nNDc1NFowHDEaMBgGA1UEAxMRYWFpLWxvZ29uLmZoc2cuY2gwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDDu7JMJ94andqk76Bv1KS2ZWWeDgrV+M1XkTK3\nZUHWgJtzXIg9+9uQnOZel/TkDp6L+by+AGwcXod61E0uw1RbA+E1NNjYAZhr4JS/\nosFjJkz606hKYOAiv/68xQvmhi/P34U36qsKjX0Zhz2KX84j9lnEdhqQpre4nnsb\n41ykQWuQAJ5QOP0rW/BjjX+GXI+gLiORkHMtb3G34RG6NpzqSDy28wQFDDqFHSrA\nGJyGgNpg0t/gqO8zhI0nATXivoqlRoAd+U6OmUvpQEMQbC0UViv+/Iu2NWif0i2b\nNE36VFxhZSFg28pW9/Axqos+oDEA+zUlZkKz8QE5TGwtlzurAgMBAAGjaTBnMEYG\nA1UdEQQ/MD2CEWFhaS1sb2dvbi5maHNnLmNohihodHRwczovL2FhaS1sb2dvbi5m\naHNnLmNoL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBR2uqcGmoc4uzwkZ0o2rmgb\nRlsGXTANBgkqhkiG9w0BAQUFAAOCAQEAT9ApCu7pG2zaOzhiDM5LzcQnJcDMckV5\n6q0cpTnjYB90Ff0KIVTsUUDAQ7yixqY9PchIvdzOnMsti9Yc2RyOWj9xkQPS/wR2\nZyWmBoXBl363F4kijL6zH4BD/e28hQx5FtFj1xTASJUhZuV47VlZglsM1rWeGyxf\ncr+IxYfp7Y4/zFsPuTlCDJrCdMan00AmEEyNDD0hCjuhOCNZVolP4BRJSLusiyRp\naKbKSwtCxelgvX/DrTHG/CPz5LGC4mO8ZdagGbPscpwxQ97gzYfNoQG0BWoKX9BM\n8EEBPaXFRM+soV0oreSVta3bE4+da2JcQYWXypXGXA2vfp1ZqqBnbA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fhsg.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-logon.fhsg.ch:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-logon.fhsg.ch:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aai-logon.fhsg.ch/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai-logon.fhsg.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai-logon.fhsg.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-logon.fhsg.ch:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-logon.fhsg.ch:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fhsg.ch"
              },
              {
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "FHS St. Gallen - Hochschule f\u00fcr Angewandte Wissenschaften"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "FHS St. Gallen - University of Applied Sciences St. Gallen"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FHS St. Gallen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FHS St.Gallen"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "fhsg.ch"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.425413,9.371350"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.16.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.16.0/25"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.17.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.18.200/30"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.18.204/31"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.19.0/25"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.19.128/27"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.19.160/28"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.19.0/25"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.19.128/27"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.19.160/28"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.19.0/28"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "error_url": "http://portal.fhsg.ch/it",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIJAJPilzxxDSFSMA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\nBAMTEWFhaS1sb2dvbi5maHNnLmNoMB4XDTE0MDkwNDA3NDc1NFoXDTE3MDkwMzA3\nNDc1NFowHDEaMBgGA1UEAxMRYWFpLWxvZ29uLmZoc2cuY2gwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDDu7JMJ94andqk76Bv1KS2ZWWeDgrV+M1XkTK3\nZUHWgJtzXIg9+9uQnOZel/TkDp6L+by+AGwcXod61E0uw1RbA+E1NNjYAZhr4JS/\nosFjJkz606hKYOAiv/68xQvmhi/P34U36qsKjX0Zhz2KX84j9lnEdhqQpre4nnsb\n41ykQWuQAJ5QOP0rW/BjjX+GXI+gLiORkHMtb3G34RG6NpzqSDy28wQFDDqFHSrA\nGJyGgNpg0t/gqO8zhI0nATXivoqlRoAd+U6OmUvpQEMQbC0UViv+/Iu2NWif0i2b\nNE36VFxhZSFg28pW9/Axqos+oDEA+zUlZkKz8QE5TGwtlzurAgMBAAGjaTBnMEYG\nA1UdEQQ/MD2CEWFhaS1sb2dvbi5maHNnLmNohihodHRwczovL2FhaS1sb2dvbi5m\naHNnLmNoL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBR2uqcGmoc4uzwkZ0o2rmgb\nRlsGXTANBgkqhkiG9w0BAQUFAAOCAQEAT9ApCu7pG2zaOzhiDM5LzcQnJcDMckV5\n6q0cpTnjYB90Ff0KIVTsUUDAQ7yixqY9PchIvdzOnMsti9Yc2RyOWj9xkQPS/wR2\nZyWmBoXBl363F4kijL6zH4BD/e28hQx5FtFj1xTASJUhZuV47VlZglsM1rWeGyxf\ncr+IxYfp7Y4/zFsPuTlCDJrCdMan00AmEEyNDD0hCjuhOCNZVolP4BRJSLusiyRp\naKbKSwtCxelgvX/DrTHG/CPz5LGC4mO8ZdagGbPscpwxQ97gzYfNoQG0BWoKX9BM\n8EEBPaXFRM+soV0oreSVta3bE4+da2JcQYWXypXGXA2vfp1ZqqBnbA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "FHS St. Gallen"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "FHS St.Gallen"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fhsg.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fhsg.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "fhsg.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib-idp.tufts.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "george.turner@tufts.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "George Turner"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ESS@tufts.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ESS"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "george.turner@tufts.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "George Turner"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "PeiQuan.Ho@tufts.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "PeiQuan Ho"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib-idp.tufts.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-idp.tufts.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.tufts.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDujCCAqICCQDcDfgQ9DFFeTANBgkqhkiG9w0BAQUFADCBnjELMAkGA1UEBhMC\nVVMxFjAUBgNVBAgTDU1hc3NhY2h1c2V0dHMxEzARBgNVBAcTClNvbWVydmlsbGUx\nGTAXBgNVBAoTEFR1ZnRzIFVuaXZlcnNpdHkxDDAKBgNVBAsTA1VJVDEbMBkGA1UE\nAxMSc2hpYi1pZHAudHVmdHMuZWR1MRwwGgYJKoZIhvcNAQkBFg1lc3NAdHVmdHMu\nZWR1MB4XDTEzMDEzMTE2MTEwOVoXDTIzMDEyOTE2MTEwOVowgZ4xCzAJBgNVBAYT\nAlVTMRYwFAYDVQQIEw1NYXNzYWNodXNldHRzMRMwEQYDVQQHEwpTb21lcnZpbGxl\nMRkwFwYDVQQKExBUdWZ0cyBVbml2ZXJzaXR5MQwwCgYDVQQLEwNVSVQxGzAZBgNV\nBAMTEnNoaWItaWRwLnR1ZnRzLmVkdTEcMBoGCSqGSIb3DQEJARYNZXNzQHR1ZnRz\nLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKl/x1AF4NuRjPA2\noEI/WMyzBf5XmVt9cy4T7ZH5MLdmeiRfmFIGLy9YdF4Q2KHBDGk+ZQlHVv06sHze\nUUKmYGt+QS2K14Frei3yaCV3rKb9aA/ukeiVWfnn7Wsxn5qWi+mvEZq55iq8xCnw\nkLij3Fx6nWrC8T9ACLo3mfx4s9GXFY1ZIXtXj1qxwI5r93NnXUI7gMGXdHVKX7Um\nVsxL155CCb3KQRGml+1f1jl5XEHbKVVvAKQT3KdrTaa9I2Ncsx2rqtDnztV3nOUz\nb8girjEOHXLyS8rxI/xkbFajZohpFBr2aXuXvDphUO20CG4fRotIfZlokK/LHGL6\nhL5WyMkCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAIy3sZ9gt86yIpmU71AFriz9P\n516u7R6F6jvvQiHNNcg5RB/6qA3LDZZrmxzHdgWGGnbSd5mWiyr6ebGoxRxWzYpu\nr9ZgIOxCK7D9Ec6rhlX0jxy+ouZ5YtgENiIgCsvJaKnrMLkQrePkiunedxSHsgap\n3gF4jSiY6YZ6XN0sfbxJf4jlaI4kl47XvxHkdkjf+u8WvW+sz1tfui5rj0xLtgWN\nh7eQBFk5zu2vH7IlJ+5NrUQPM5srLIyyAQPkX3TwCIu0imLAMKVb/QMpa3jfj0u4\nnx4gfZBsxdfXaIUPuLZsW1Ae7E8kqKmgkS5floclqDnC9ebJtliJqXqaGQr+/A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tufts.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib-idp.tufts.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-idp.tufts.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib-idp.tufts.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-idp.tufts.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-idp.tufts.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.tufts.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tufts.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://shib-idp.tufts.edu/tufts_logo.jpg",
                    "lang": "en",
                    "height": "67",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "154"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Tufts University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDujCCAqICCQDcDfgQ9DFFeTANBgkqhkiG9w0BAQUFADCBnjELMAkGA1UEBhMC\nVVMxFjAUBgNVBAgTDU1hc3NhY2h1c2V0dHMxEzARBgNVBAcTClNvbWVydmlsbGUx\nGTAXBgNVBAoTEFR1ZnRzIFVuaXZlcnNpdHkxDDAKBgNVBAsTA1VJVDEbMBkGA1UE\nAxMSc2hpYi1pZHAudHVmdHMuZWR1MRwwGgYJKoZIhvcNAQkBFg1lc3NAdHVmdHMu\nZWR1MB4XDTEzMDEzMTE2MTEwOVoXDTIzMDEyOTE2MTEwOVowgZ4xCzAJBgNVBAYT\nAlVTMRYwFAYDVQQIEw1NYXNzYWNodXNldHRzMRMwEQYDVQQHEwpTb21lcnZpbGxl\nMRkwFwYDVQQKExBUdWZ0cyBVbml2ZXJzaXR5MQwwCgYDVQQLEwNVSVQxGzAZBgNV\nBAMTEnNoaWItaWRwLnR1ZnRzLmVkdTEcMBoGCSqGSIb3DQEJARYNZXNzQHR1ZnRz\nLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKl/x1AF4NuRjPA2\noEI/WMyzBf5XmVt9cy4T7ZH5MLdmeiRfmFIGLy9YdF4Q2KHBDGk+ZQlHVv06sHze\nUUKmYGt+QS2K14Frei3yaCV3rKb9aA/ukeiVWfnn7Wsxn5qWi+mvEZq55iq8xCnw\nkLij3Fx6nWrC8T9ACLo3mfx4s9GXFY1ZIXtXj1qxwI5r93NnXUI7gMGXdHVKX7Um\nVsxL155CCb3KQRGml+1f1jl5XEHbKVVvAKQT3KdrTaa9I2Ncsx2rqtDnztV3nOUz\nb8girjEOHXLyS8rxI/xkbFajZohpFBr2aXuXvDphUO20CG4fRotIfZlokK/LHGL6\nhL5WyMkCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAIy3sZ9gt86yIpmU71AFriz9P\n516u7R6F6jvvQiHNNcg5RB/6qA3LDZZrmxzHdgWGGnbSd5mWiyr6ebGoxRxWzYpu\nr9ZgIOxCK7D9Ec6rhlX0jxy+ouZ5YtgENiIgCsvJaKnrMLkQrePkiunedxSHsgap\n3gF4jSiY6YZ6XN0sfbxJf4jlaI4kl47XvxHkdkjf+u8WvW+sz1tfui5rj0xLtgWN\nh7eQBFk5zu2vH7IlJ+5NrUQPM5srLIyyAQPkX3TwCIu0imLAMKVb/QMpa3jfj0u4\nnx4gfZBsxdfXaIUPuLZsW1Ae7E8kqKmgkS5floclqDnC9ebJtliJqXqaGQr+/A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Tufts University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tufts.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Tufts University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://iam.cf.ac.uk/sp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:insrvConnect@cardiff.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "INSRV Connect"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smart"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:smartp@cardiff.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Philip"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://iam.cf.ac.uk/sp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-02-22T13:42:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cardiff University: IAM@Cardiff's Site"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://iam.cf.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cardiff University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://iam.cf.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://iam.cf.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://iam.cf.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://iam.cf.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Cardiff University IAM Team's Site"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This is the website of the Identity and Access Management team at Cardiff University, including the trac for RAPTOR and WUGEN."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonTargetedID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonEntitlement",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:mail",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://iam.cf.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://iam.cf.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAMuQ3vgWPWjiMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\n\t\t\t\t\t\tBAMTDGlhbS5jZi5hYy51azAeFw0xMzAyMTUxMDM1MjBaFw0zMzAyMTAxMDM1MjBa\n\t\t\t\t\t\tMBcxFTATBgNVBAMTDGlhbS5jZi5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBAL6J4304XtLySk3GhICIZf9SWzmwHwtlUDhA+pH+03WiCv6ZWOJl\n\t\t\t\t\t\tpiGglBiTyYB6aOPRSsz89pzGBUoUgApTH4zGvD6tkFrzQsX7QCWmi48UnkrsgSw7\n\t\t\t\t\t\tbTvwMP6EQOgR/cJH3lftaQGlspt2+CxGj8+inSKdzA5/v24GLWUKrLSI7+vk9z3P\n\t\t\t\t\t\tHIEVY0mxRWZIomtb9Z3vCaSdESR0fR6egsT6pbRl9X7EdQJVwQmKC0PzL260cBmk\n\t\t\t\t\t\tJmckbSpY1POebUgOXF2CzJup6tTSiIJrN9ppKY4aLKSNIoQPxEF2Zzl7Lsx5HffV\n\t\t\t\t\t\tDe6GIYKjgp9y0CTsIn4xYdHhlAmUUbV4y/ECAwEAAaNeMFwwOwYDVR0RBDQwMoIM\n\t\t\t\t\t\taWFtLmNmLmFjLnVrhiJodHRwczovL2lhbS5jZi5hYy51ay9zcC9zaGliYm9sZXRo\n\t\t\t\t\t\tMB0GA1UdDgQWBBRpauq5kzBefcX+Qm3CixEbP3/3RDANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAkrz51AVE6XZK3fq+CX/g+xC58we4jFRkGVA9dmcIpKJsSJMsEaeo78GPFKLq\n\t\t\t\t\t\tgYiy7pHHqSGFXc+8ySrN5kex7bGqERg1qldhQ2CkVEEV6sVd5X1LOnc9D9uJrl9n\n\t\t\t\t\t\tjDOiI//2rGM+hR5xCFQ04hVlpgxN+yHwvK/idqxiV2HpoynB2MadfarxAPGEOe+i\n\t\t\t\t\t\twmv/9U74Jjd93zhGfQNEfTOXTP/h/dt6v86cJ9Z4DkAtOUnVA6bLi08ANaJDBBgp\n\t\t\t\t\t\tCOS3qN36Vz4ifhyel26f9yBxKvPZaJtwoSBEJHntaS5nbC301TYIRohm2hsmFMnE\n\t\t\t\t\t\tVwKYG1nWV+7ql4LLn3dcdr+5sw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://iam.cf.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://iam.cf.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://iam.cf.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://iam.cf.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://iam.cf.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://iam.cf.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://iam.cf.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://iam.cf.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://iam.cf.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://iam.cf.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.yeovil.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cullen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Craig.Cullen@yeovil.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Craig"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cullen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Craig.Cullen@yeovil.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Craig"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.yeovil.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-10-05T11:25:44Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUc+MFJHCvsiXTJD9AbAGFOho/nyQwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHDEaMBgGA1UEAxMRaWRwMi55ZW92aWwuYWMudWswHhcNMTIxMDA0MTYxNTQy\n\t\t\t\t\t\tWhcNMzIxMDA0MTYxNTQyWjAcMRowGAYDVQQDExFpZHAyLnllb3ZpbC5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANxEEpNwNxfUmo9qh7EXLPAw\n\t\t\t\t\t\tRgYA86Ml4ZxwB2l2NnDL0VE/dts87f3wKPuECWDH1cZz/z8CSKZTktU0ANDGrNnC\n\t\t\t\t\t\tyZz15BN51mSFiwKR0xOrpRe5EJrEGrzUyjxmMwEhEup0eiRH1c8VAbjyB3/2BPrI\n\t\t\t\t\t\ts/eq9/bCa9K3WRPK+DihZqPEaH7DbWUDGCmyMNLY3hR7lXuhnWgQYUS42YYuPZsb\n\t\t\t\t\t\tuKf1fzMdC2zRA3Z00fHfUBxPqCcWMdLsCGoJUh8zc+IYSEax8hdu1zf85LZqhXi4\n\t\t\t\t\t\t/gsTGcWeAT3cq42Zb6hzIDgLHEanG/MWLxgDB0JBf2GZMPy13WrXQT0/Vc1iHqEC\n\t\t\t\t\t\tAwEAAaNpMGcwRgYDVR0RBD8wPYIRaWRwMi55ZW92aWwuYWMudWuGKGh0dHBzOi8v\n\t\t\t\t\t\taWRwMi55ZW92aWwuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFJ2w10W1\n\t\t\t\t\t\tabGXJEftfLDwfLzYWieSMA0GCSqGSIb3DQEBBQUAA4IBAQCq8ksSrdQPwyg9QfzK\n\t\t\t\t\t\tpUdTOoRRaGlY4zDVD1LBKWntpL+O1KGCn61ePiyoMQeONgtFBJDOP2rAiZXWZ6qN\n\t\t\t\t\t\tseHfry/67Ssd2C4DbiG5QunQ19EzoZAGBUZD7yK7wcaJpBM7AWnwDnovEElNklyV\n\t\t\t\t\t\tEkO9UVdYiFrq2gSN/p0K2OjW1FyNkvScbSoesI0AgUk0Wc7oaqWuz8IYmoFMQbkN\n\t\t\t\t\t\tmDkeTy+Rlhf60bYRaLyxcHryq47BInhFWsuQ5S1MaxmS9m4bnYpUeo+ejqOkvIIX\n\t\t\t\t\t\tSctLza4RkP6ubwWg7hVn8Qy7IEaDcvgpq1vVeRcOdo/TxQeWnASMZGbpVa9ik5Nn\n\t\t\t\t\t\tKFgn"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "yeovil.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.yeovil.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.yeovil.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp2.yeovil.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.yeovil.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp2.yeovil.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2.yeovil.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.yeovil.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.yeovil.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "yeovil.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUc+MFJHCvsiXTJD9AbAGFOho/nyQwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHDEaMBgGA1UEAxMRaWRwMi55ZW92aWwuYWMudWswHhcNMTIxMDA0MTYxNTQy\n\t\t\t\t\t\tWhcNMzIxMDA0MTYxNTQyWjAcMRowGAYDVQQDExFpZHAyLnllb3ZpbC5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANxEEpNwNxfUmo9qh7EXLPAw\n\t\t\t\t\t\tRgYA86Ml4ZxwB2l2NnDL0VE/dts87f3wKPuECWDH1cZz/z8CSKZTktU0ANDGrNnC\n\t\t\t\t\t\tyZz15BN51mSFiwKR0xOrpRe5EJrEGrzUyjxmMwEhEup0eiRH1c8VAbjyB3/2BPrI\n\t\t\t\t\t\ts/eq9/bCa9K3WRPK+DihZqPEaH7DbWUDGCmyMNLY3hR7lXuhnWgQYUS42YYuPZsb\n\t\t\t\t\t\tuKf1fzMdC2zRA3Z00fHfUBxPqCcWMdLsCGoJUh8zc+IYSEax8hdu1zf85LZqhXi4\n\t\t\t\t\t\t/gsTGcWeAT3cq42Zb6hzIDgLHEanG/MWLxgDB0JBf2GZMPy13WrXQT0/Vc1iHqEC\n\t\t\t\t\t\tAwEAAaNpMGcwRgYDVR0RBD8wPYIRaWRwMi55ZW92aWwuYWMudWuGKGh0dHBzOi8v\n\t\t\t\t\t\taWRwMi55ZW92aWwuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFJ2w10W1\n\t\t\t\t\t\tabGXJEftfLDwfLzYWieSMA0GCSqGSIb3DQEBBQUAA4IBAQCq8ksSrdQPwyg9QfzK\n\t\t\t\t\t\tpUdTOoRRaGlY4zDVD1LBKWntpL+O1KGCn61ePiyoMQeONgtFBJDOP2rAiZXWZ6qN\n\t\t\t\t\t\tseHfry/67Ssd2C4DbiG5QunQ19EzoZAGBUZD7yK7wcaJpBM7AWnwDnovEElNklyV\n\t\t\t\t\t\tEkO9UVdYiFrq2gSN/p0K2OjW1FyNkvScbSoesI0AgUk0Wc7oaqWuz8IYmoFMQbkN\n\t\t\t\t\t\tmDkeTy+Rlhf60bYRaLyxcHryq47BInhFWsuQ5S1MaxmS9m4bnYpUeo+ejqOkvIIX\n\t\t\t\t\t\tSctLza4RkP6ubwWg7hVn8Qy7IEaDcvgpq1vVeRcOdo/TxQeWnASMZGbpVa9ik5Nn\n\t\t\t\t\t\tKFgn"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Yeovil College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.yeovil.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Yeovil College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.twu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kwilliams1@twu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kerry Williams"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sgaluzinschii@twu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Svetlana Galuzinschii"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jmuller@twu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Julie Muller"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sgaluzinschii@twu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Svetlana Galuzinschii"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.twu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.twu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.twu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.twu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.twu.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.twu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.twu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "twu.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.twu.edu"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Texas Woman's University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Texas Woman's University"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.twu.edu/webguide/images/twu-logo-screen.jpg",
                    "lang": "en",
                    "height": "536",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "1001"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.twu.edu/privacy.asp"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAI0T7xzZIygfVuYxMru5q5nZHShqMA0GCSqGSIb3DQEB\nBQUAMB0xGzAZBgNVBAMTEnNoaWJib2xldGgudHd1LmVkdTAeFw0xNDA0MDcyMjEw\nMDZaFw0zNDA0MDcyMjEwMDZaMB0xGzAZBgNVBAMTEnNoaWJib2xldGgudHd1LmVk\ndTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIx+VXaomj3kZQ4iHNng\nslXgUKdvvrMK95fSEIQaAFLGT7FRqE5x9XT8A/6MD7IGK8ju1oTRSNQCB2Y4SuvL\nfipAKnPVdOkbLIWHnCqOz/k/FK5cawLUE5oHcO/Z8G3yuS8e/5JTd/0uvjg3UaeH\nwx0NjTqQ3nsgU0PGXYjb7mecQoRscb7sbuNs1hfc+HVP3XCpg4UtH3d8blHojFQF\nwmpn9JhFBz8nLUpVzciQR0MVdIGfHKorBiAchpIPuiUMsQyH3bhstf6UfovHjJDP\n+D+QQEK9xltDiAsg7n0r2X+Qmcbn9UaVkBe19n+CMbUWI8Xyu8WJwtonkmqgu5Et\n+ecCAwEAAaNrMGkwSAYDVR0RBEEwP4ISc2hpYmJvbGV0aC50d3UuZWR1hilodHRw\nczovL3NoaWJib2xldGgudHd1LmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\nihWr1R5mHoynw9MVCPrH0FNDuWkwDQYJKoZIhvcNAQEFBQADggEBAAntMjyeQnD7\ncV4V3xEHC+PZIURMgMlf533Zuq1I55mwpt71Vpyw5aCMGgnL+ijvLUVwBRowdUtn\nwjLhcOB6gF7jUBs70tcY2JCCxXqIJOpLrOkKuMpcbQbuyQ/INy6pVYXJuiBdwBUW\n/3Ys+ape2tq11LtVh9p7U2GqiFvYhD1Gi2axD8Dw6hZuFWxSPZxPfRqjB+LG6QuU\nBTKp7zGJR7u+0fClzPPD0eNrB+Xm/EVxKiy974O3LxRtdM7f1Y+PajUVqEmCrfA8\nliI+dPkY6jYTEUJ5o8LqDH2gOs/p5xDeNllYxA2hcA4ap4RI3SVsKyyJHGLaLyjJ\nepclpLX4uwE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "http://www.twu.edu/tis/InCommon_help.asp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Texas Woman's University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.twu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Texas Woman's University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://lpw.ki.se/shibboleth",
    {
      "entity_id": "https://lpw.ki.se/shibboleth",
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Karolinska Institutet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ki.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "KI"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lpw.ki.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lpw.ki.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lpw.ki.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lpw.ki.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lpw.ki.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://lpw.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://lpw.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok p\u00e5 webb f\u00f6r studenter p\u00e5 Karolinska Institutet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok on the web for students at Karolinska Institutet"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "LPW - Karolinska Institutet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "LPW - Karolinska Institutet"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "kiladok01.ki.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJALIjJ4W5G5NlMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2tpbGFkb2swMS5raS5zZTAeFw0xMTA2MDkwOTE3MzJaFw0yMTA2MDYwOTE3\nMzJaMBoxGDAWBgNVBAMTD2tpbGFkb2swMS5raS5zZTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAKaPBu20JzB9Ko3IQNSei/zbfY2N75RUATikwdmju6Uy\nlIFdSbQCsEl6o1mktZysNrUL2tj6l45kDZmaCxvKakuC5bIHQY9E8kWHdrXHTxEx\nQCDw6+NSHcRzJwKpUQZKVz7YdTNl+7qnoqpQpVYTB7aPMXn71xDHIspRg6RtJvly\nFH1ADlRyVuiUd/CKvp4b6UBOMmnHgbdKSaY0N362Ks0wmw13ZMc4O9QChgx4R33R\n4ooNV79byMtJ8RPomTNMTlVAnsSMFjXh3yNzxra7zGQnUAlzXyY5+rH1kaRqstfr\nXyxVg9nlvv82gsczPxXl0kexWh+DW3wB9LtflKkCyA0CAwEAAaM9MDswGgYDVR0R\nBBMwEYIPa2lsYWRvazAxLmtpLnNlMB0GA1UdDgQWBBRzCPPEABQ2vMTzaw86FhJS\n/qGq9DANBgkqhkiG9w0BAQUFAAOCAQEAgcz87bN6b0aAbEceZR+bmbAHDrcU5bA2\nZ7LQt+PWQDeXS3WCf7xwGxHSUEer9gP078Zo1Z72UMnowQW4Fuwrp/lAOVhsAGPZ\ng10njIwKk9oi69hIgjoU+YD03Zt2zglrkOFoSH4Gy2QbmIiF3ihSjiY/eYtrDQhr\nyPAkIV8gl8A16so6D364fbNuF9ay5ONY3J+P20Scmuhuel55KdEnR1SIxdQ0Fml0\nXBbBB8yIgXxH5y12cJA0350DeuLjV2lI+Vwo+cHc4l4Iy60nCmU/AhOPsrn/KSol\nD1QNfeY/pFOqpfSxgp64TIVe9v9UJ7QJRm7zh51LDEjqyJwd/xxNyA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=kiladok01.ki.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lpw.ki.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://lpw.ki.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lpw.ki.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://lpw.ki.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://lpw.ki.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://lpw.ki.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib.exprodo.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Robinson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul@exprodo.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Robinson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul@exprodo.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.exprodo.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-06-23T14:30:24Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Exprodo Software"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.exprodo.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Exprodo Software Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.exprodo.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.exprodo.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.exprodo.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.exprodo.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.exprodo.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Web-based database and research/clinical bookings and facility management software"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.exprodo.com/wp-content/uploads/2014/10/exprodo-software_271x100.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "271"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Exprodo Software"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib.exprodo.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shib.exprodo.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIJALCR79ZDW2xvMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHNoaWIuZXhwcm9kby5jb20wHhcNMTUwNjIyMTUyMTAxWhcNMjUwNjE5MTUy\n\t\t\t\t\t\tMTAxWjAbMRkwFwYDVQQDExBzaGliLmV4cHJvZG8uY29tMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAlihJNaZPZ3oGM5NQlpgwJUJxlWZ8rbWrx9Kk5rPB\n\t\t\t\t\t\t4Fb0C6CH+YIOKHb9sxVXPL5Vi9JypYE0Y7JRFEKf7qzbFNTEDAKhq0hjJ+XMWiVq\n\t\t\t\t\t\tPJjbKYW4LJtM05DoPpTe/gKZJRaktGUDGu8m5ifLtd7klhFQmV0duDriDEPiW4ik\n\t\t\t\t\t\tLeYZGiReIkvWSx4kFnQbERYuyrjXPOnhKw8pnv4HuzR/Js4tmUQbMy9VPbjbWSET\n\t\t\t\t\t\to2x9TfCubitIiOguXNGU8hcOv+ys/sWKTddPQ8208qpsfQLo+YSm9NmYDn3bJ3tg\n\t\t\t\t\t\tSdA/9OTLJSjTZrz7RUZUeCYF/yv0vhRpicDDg1Ym8kdtCQIDAQABo2MwYTBABgNV\n\t\t\t\t\t\tHREEOTA3ghBzaGliLmV4cHJvZG8uY29thiNodHRwczovL3NoaWIuZXhwcm9kby5j\n\t\t\t\t\t\tb20vc2hpYmJvbGV0aDAdBgNVHQ4EFgQU7xBaV9vU2BCTDlQLhTkL5L6/1ckwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBAChUHGR1vS+giyhBJLy6gvfWFpfmo6dJlVn9zTIiztus\n\t\t\t\t\t\tSNX3AR7Xe3KLO+YV/8r1vUz5WO+xnUwFQd7Et20M5oeeZqbDqyPJqynepUZ3NeE5\n\t\t\t\t\t\tGfzERa8Rdvr6t6HoY0H19u0IMiMemtxQpFDt2uLtkawJLw7L3A2hUdbVta8MyUAQ\n\t\t\t\t\t\t7WV7raxbNae56DlNuivOY2kkEl9T39xiLNpQ4cHtB2Z1uGLxPcE49j1AzfAM5ugk\n\t\t\t\t\t\t29ai5m2neGiTzsvlEvw88pW7CMGcfZEPNsDA4zbQNTAu0FYIhrP60+OifLLZoMen\n\t\t\t\t\t\tlT/unHR4GJe4dtKbypAo6cvgW2Uu7aCV0wO0ni7MiCE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.exprodo.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.exprodo.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.exprodo.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shib.exprodo.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shib.exprodo.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shib.exprodo.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://pubs.rsna.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://pubs.rsna.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-08-21T09:50:58Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Radiological Society of North America"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://pubs.rsna.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://pubs.rsna.org/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pubs.rsna.org/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://pubs.rsna.org/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEDCCAfigAwIBAgIJAJzgAWzkM8T0MA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXB1YnMucnNuYS5vcmcwHhcNMTMxMDA3MjA0NzI1WhcNMjMxMDA1MjA0NzI1\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1wdWJzLnJzbmEub3JnMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAqRPhvibBGQpooUm65mN4690Qia2tM6BbQnYd/7y9HRKQe1Kk\n\t\t\t\t\t\thmUlNF4+ZjeEmxFvmawnGLTA/eN2oYdQXANiSjrGgmQRIUr1fcPK5xoeyyNULdic\n\t\t\t\t\t\tiLZejtSlvXzY4dgz/DX2hMlH4Q+w6A4c1UBD8qKHDgE4ss+bN+noT4ObEua8n/Tb\n\t\t\t\t\t\tJ290MYG3/kwRyfx6Wnsm8J3kKnRwyiTMxMchimxpd1IXDE/Dt8M45TKzEQwzqlux\n\t\t\t\t\t\tl1qz9v71h9zk5nkBKmhJ4b1BTIdECQ2Ah56jOQ/9Cuxbv0AKltJM7bLEB8qTsV/Q\n\t\t\t\t\t\t29xm/rVVt5rQbWk1Imam0403xgmMyvGEyR/7UQIDAQABo10wWzA6BgNVHREEMzAx\n\t\t\t\t\t\tgg1wdWJzLnJzbmEub3JnhiBodHRwczovL3B1YnMucnNuYS5vcmcvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQU0JkMEFSeGhSejeQCBo6K11ftUFEwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBADP2WaN5mVSM3Zv9UqUPG2bO7XTXPnhtvHIgAa4hSobLixQP98Ml7sXVlqnL\n\t\t\t\t\t\tP31IWgToTjtXTjpTNYE7vsCsKRVP9uvVOziS2A5EBtoKWrQLbOCrwTBl0IzFLn8s\n\t\t\t\t\t\tiJfNHHNUdwDxOhJYCC0cwS22b3t0Rfv9LjQ82TRO0FvIc82gJMzlnPogQyrWOTjR\n\t\t\t\t\t\tIhAm74GLoDngxl3tXhPN8jSSx82EAYJJpITK4Fffule8pHHZFSwOXTB73RfDBu2L\n\t\t\t\t\t\tXZ4ZcLi1+DpZ+s8Cz8C3mKyEo1f6CRUaqaypMRhLDwi9VHOqZtE2nUqEafnyZVd6\n\t\t\t\t\t\tWKS8JkDbp5nnxgaI0eM2fo7rUFg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://pubs.rsna.org/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "RSNA publishes two top peer-reviewed journals: Radiology, the highest-impact scientific journal in the field, and RadioGraphics, the only journal dedicated to continuing education in radiology."
                  }
                ],
                "logo": [
                  {
                    "text": "https://pubs.rsna.org/pb/assets/raw/Publications%20%2FJournals_logo.png",
                    "height": "76",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "354"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Radiological Society of North America"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://idp.wmin.ac.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cav-its@westminster.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Cavendish IT Service"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Marriott"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:d.marriott@westminster.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.wmin.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2007-03-09T15:50:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDxTCCAq2gAwIBAgIJAKJTZR5Gg4aEMA0GCSqGSIb3DQEBCwUAMHkxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMQ8wDQYDVQQIDAZMb25kb24xDzANBgNVBAcMBkxvbmRvbjEiMCAGA1UE\n\t\t\t\t\t\tCgwZVW5pdmVyc2l0eSBvZiBXZXN0bWluc3RlcjELMAkGA1UECwwCSVMxFzAVBgNV\n\t\t\t\t\t\tBAMMDmlkcC53bWluLmFjLnVrMB4XDTE1MDEwODE2MDUwOVoXDTI1MDEwNTE2MDUw\n\t\t\t\t\t\tOVoweTELMAkGA1UEBhMCR0IxDzANBgNVBAgMBkxvbmRvbjEPMA0GA1UEBwwGTG9u\n\t\t\t\t\t\tZG9uMSIwIAYDVQQKDBlVbml2ZXJzaXR5IG9mIFdlc3RtaW5zdGVyMQswCQYDVQQL\n\t\t\t\t\t\tDAJJUzEXMBUGA1UEAwwOaWRwLndtaW4uYWMudWswggEiMA0GCSqGSIb3DQEBAQUA\n\t\t\t\t\t\tA4IBDwAwggEKAoIBAQCYvgnD7J51erwpxIAgeDt1L0WAQ3V9Mft1HCB8ebimah+M\n\t\t\t\t\t\tET2RsgJtMWLvUCs+TOnl9ESgyR/jgh4Nui1mCUloooNnTKmiVagj+o+xHObPmA3j\n\t\t\t\t\t\t6Dk1Zhun/kcCgXPZq0gxdr+PtA0zfh0NeU7hiUWIFu/XXRrdCTlOrOXYmGTHx+bv\n\t\t\t\t\t\taJllG5632hhJAMVB6saH2OQp70AapusaXsYnY+eYInmIlEs9VKcdLlYVXdS9iMmQ\n\t\t\t\t\t\tQgxgMTzKsb5uaZxTpzR6ZhGCIpE9gkfqD0TT1juH6adT5JFQ8K/xqjT4TonA6sXs\n\t\t\t\t\t\tWoeWSjLLg/J/81B2fyrtz4M5bVmtCKH9pdXywKNpAgMBAAGjUDBOMB0GA1UdDgQW\n\t\t\t\t\t\tBBSpJvZ2yI13jz9K7Bje0+nKQFinvTAfBgNVHSMEGDAWgBSpJvZ2yI13jz9K7Bje\n\t\t\t\t\t\t0+nKQFinvTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQB807x92SUY\n\t\t\t\t\t\tE+BToJCZrf3rvKFvczshq+sVXurkPA/pIo9p0MQVEmHnnRugW5ybhkmdb38PP7xH\n\t\t\t\t\t\tw9FbjppTttAwJVKszX/0ZHyFLZmlE/6Zp90BuK7ikvJFpWrLXQv4tvcEjKzpqUjA\n\t\t\t\t\t\tAIsT3BGhF33rMGp8cA915264YwmjkHMhUo/+hCPRaQ8PfHVDvLHC8FXQB9+kt2bI\n\t\t\t\t\t\tbF++uJUXXusfXJ6WSDLE8bTPftQpgTu/lSDnQi3tV4xmdI0Wgvr4nl4SaVHat8wY\n\t\t\t\t\t\tplQT+YQoWyrQDZMfk+B9dJHcBAr7Sb57l799Hilx3PqrmUkb0JI4K+TxLLlwoGh0\n\t\t\t\t\t\tf1W0FLEz3Y37"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wmin.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.wmin.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.wmin.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib-login.wmin.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-login.wmin.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib-login.wmin.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-login.wmin.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.wmin.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.wmin.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wmin.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDxTCCAq2gAwIBAgIJAKJTZR5Gg4aEMA0GCSqGSIb3DQEBCwUAMHkxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMQ8wDQYDVQQIDAZMb25kb24xDzANBgNVBAcMBkxvbmRvbjEiMCAGA1UE\n\t\t\t\t\t\tCgwZVW5pdmVyc2l0eSBvZiBXZXN0bWluc3RlcjELMAkGA1UECwwCSVMxFzAVBgNV\n\t\t\t\t\t\tBAMMDmlkcC53bWluLmFjLnVrMB4XDTE1MDEwODE2MDUwOVoXDTI1MDEwNTE2MDUw\n\t\t\t\t\t\tOVoweTELMAkGA1UEBhMCR0IxDzANBgNVBAgMBkxvbmRvbjEPMA0GA1UEBwwGTG9u\n\t\t\t\t\t\tZG9uMSIwIAYDVQQKDBlVbml2ZXJzaXR5IG9mIFdlc3RtaW5zdGVyMQswCQYDVQQL\n\t\t\t\t\t\tDAJJUzEXMBUGA1UEAwwOaWRwLndtaW4uYWMudWswggEiMA0GCSqGSIb3DQEBAQUA\n\t\t\t\t\t\tA4IBDwAwggEKAoIBAQCYvgnD7J51erwpxIAgeDt1L0WAQ3V9Mft1HCB8ebimah+M\n\t\t\t\t\t\tET2RsgJtMWLvUCs+TOnl9ESgyR/jgh4Nui1mCUloooNnTKmiVagj+o+xHObPmA3j\n\t\t\t\t\t\t6Dk1Zhun/kcCgXPZq0gxdr+PtA0zfh0NeU7hiUWIFu/XXRrdCTlOrOXYmGTHx+bv\n\t\t\t\t\t\taJllG5632hhJAMVB6saH2OQp70AapusaXsYnY+eYInmIlEs9VKcdLlYVXdS9iMmQ\n\t\t\t\t\t\tQgxgMTzKsb5uaZxTpzR6ZhGCIpE9gkfqD0TT1juH6adT5JFQ8K/xqjT4TonA6sXs\n\t\t\t\t\t\tWoeWSjLLg/J/81B2fyrtz4M5bVmtCKH9pdXywKNpAgMBAAGjUDBOMB0GA1UdDgQW\n\t\t\t\t\t\tBBSpJvZ2yI13jz9K7Bje0+nKQFinvTAfBgNVHSMEGDAWgBSpJvZ2yI13jz9K7Bje\n\t\t\t\t\t\t0+nKQFinvTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQB807x92SUY\n\t\t\t\t\t\tE+BToJCZrf3rvKFvczshq+sVXurkPA/pIo9p0MQVEmHnnRugW5ybhkmdb38PP7xH\n\t\t\t\t\t\tw9FbjppTttAwJVKszX/0ZHyFLZmlE/6Zp90BuK7ikvJFpWrLXQv4tvcEjKzpqUjA\n\t\t\t\t\t\tAIsT3BGhF33rMGp8cA915264YwmjkHMhUo/+hCPRaQ8PfHVDvLHC8FXQB9+kt2bI\n\t\t\t\t\t\tbF++uJUXXusfXJ6WSDLE8bTPftQpgTu/lSDnQi3tV4xmdI0Wgvr4nl4SaVHat8wY\n\t\t\t\t\t\tplQT+YQoWyrQDZMfk+B9dJHcBAr7Sb57l799Hilx3PqrmUkb0JI4K+TxLLlwoGh0\n\t\t\t\t\t\tf1W0FLEz3Y37"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Westminster"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wmin.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Westminster"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://test.mp.uu.se/Shibboleth.sso",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://test.mp.uu.se/Shibboleth.sso",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.mp.uu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://test.mp.uu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.mp.uu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.mp.uu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.mp.uu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.mp.uu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.mp.uu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "test.mp.uu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJAIl80G+yw8TEMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDXRlc3QubXAudXUuc2UwHhcNMTIxMDExMTQzMjU5WhcNMjIxMDA5MTQzMjU5\nWjAYMRYwFAYDVQQDEw10ZXN0Lm1wLnV1LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAwqaqXqq9CgNf5q0dxBc26da3IDJgGqkDDLfguvwBEGzNl+GZ\nRFqt0zYvgm2xESBbUHYtghGhfei7o75e73wax8gNVl92BZ8pwWuzNDobGgeh4Au/\nCBm0WuZS4C9c+H7tEnaY+gajQIrIsMnVmNUg6SYw8WRVaMJ1DFJXVdVPv84hFGQl\nhhJ3JhMVSTr5XonzlEfOERC50MmJpdFWsw18ZZYguYxAO3sr8/bNWCil/UoyGlqd\nsuBvl/0TBy999sppMJi9Ruf1EYZJEMp+cwktiJ0amHNM/p9Bh3UiHTmy4ezy7iOZ\nnbsZPE0kDZBy73tImrQo+gV8MXEtZMB7oLbE4QIDAQABozswOTAYBgNVHREEETAP\ngg10ZXN0Lm1wLnV1LnNlMB0GA1UdDgQWBBQ7Ui+hkYbochetApl5wxE3yuiYvjAN\nBgkqhkiG9w0BAQUFAAOCAQEAwkO8JPsnUzHZdMYJ8hARdTtucqNs7KAxHVKzrff/\nsV6M4aaXx2ZKQJnN2OKrH/VEeuia4znvgHavnLdTPt7rXiyOpBR3eLwrc8rBNEyt\nO1jddcOwjv+rihqX5h8ab1OZ2QE7ZIZO0fi2maJjOsdzJvr9CwkTpKJjHT7WCTQV\nzfAidxqveMFn/7UsoXIsiVTgQ7eEVJPl3njBDDi/E0PDmQCNMG6Trzpof9iKHAuJ\nf91arR1JmuNzmHFNaLikuWCqw/8qr938FM2uP4W2OTcMm998DSp5z+SDOHphuhZF\n6OzPcq8bOQu+OlGG4/PkOBSezPss+Vn4cuY0pAQ8VTeGSA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=test.mp.uu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.mp.uu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://test.mp.uu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.mp.uu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.mp.uu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.mp.uu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://test.mp.uu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.mp.uu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://test.mp.uu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.mp.uu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://test.mp.uu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.mp.uu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://test.mp.uu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://test.mp.uu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://test.mp.uu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://birk.wayf.dk/birk.php/fs.edu.simac.dk/adfs/services/trust",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://birk.wayf.dk/birk.php/fs.edu.simac.dk/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2015-08-05T14:39:40Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/fs.edu.simac.dk/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "simac.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SIMAC"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SIMAC"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "simac.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3jCCAcYCAQcwDQYJKoZIhvcNAQELBQAwNTEzMDEGA1UEAwwqaHR0cDovL2Zz\nLmVkdS5zaW1hYy5kay9hZGZzL3NlcnZpY2VzL3RydXN0MB4XDTE1MDEwMTAwMDAw\nMFoXDTI1MTIzMTIzNTk1OVowNTEzMDEGA1UEAwwqaHR0cDovL2ZzLmVkdS5zaW1h\nYy5kay9hZGZzL3NlcnZpY2VzL3RydXN0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEAx4gMCmoQU7iOGfiCda4DnhIggst20fUCHtwaQrHoxQlOa0s5FgDa\nlbnNTw36dCXSGYaz17JgyUDJonTwhjyA0CqPm5Pmn9/hFBUvyP/t+bEgV9r3/odQ\nx72VfY7M55qUlY6ex2f1qD1gcpFgSTtADlZswec5WqpEt+ie+vsMXq8HabhMVZ2E\njXe90vgMk/xGfrVwDvupUPBS/2DJSZ1JEmkqi0hxctNQ9qgTZmEcAaQkuv3VGcsY\ntLeY/IISlA+ARzmVWr5+uSetnCXV4jnDEclACKeexl0Ky+tyra4yHF3Xavgmcmeb\nd+xHVDiM+No6BXMu9zBTp7cp5ShLzsNQSQIDAQABMA0GCSqGSIb3DQEBCwUAA4IB\nAQCMnEPPjnsBWSGeheSYbDsSi0Xu7lRxxqEKZYwRCoTMmYIJRCXnJbPxA/BiP2nK\nK/ZnqJB9yHrNaLzE5rQw8QOkgCw1hGH3KspHtW29g9LkUpUnlPrmcqHYJFFuAIhF\ngsqSQ6jdv9q0q4vOSnhyKNVOA613djnxmNfbpPhwTMS6Udv/1euPi9xo6x/+ExL7\nbeahYAykMS99l1bn1/tAhD+HoHbF1E5bKhsAQ5VqhEm+c1zY3sZNDrSi8ca7wv/x\n3vZ3PhzIxt23JHiArE7JPSQ7/8sbDf5qKUPRltdh8NxLRwVFzeyTrBwEwMF/mpRg\nfwnoK0wK5Qy+Hac98sg1DygI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SIMAC"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SIMAC"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.simac.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.simac.dk"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SIMAC"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SIMAC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://buttecollege.instructure.com/saml2",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@instructure.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Canvas Support"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "http://buttecollege.instructure.com/saml2",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Instructure, Inc"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.instructure.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Instructure, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://butte.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://butte.test.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://butte.beta.instructure.com/login/saml/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.canvaslms.com/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "OEI - Butte College - Canvas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "`"
                  }
                ],
                "logo": [
                  {
                    "text": "https://canvas.instructure.com/images/canvas/header_canvas_logo@2x.png",
                    "lang": "en",
                    "height": "220",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "220"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.canvaslms.com/policies/privacy-policy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE8TCCA9mgAwIBAgIJAOBms/PYWcPLMA0GCSqGSIb3DQEBCwUAMIGrMQswCQYD\nVQQGEwJVUzENMAsGA1UECBMEVXRhaDEXMBUGA1UEBxMOU2FsdCBMYWtlIENpdHkx\nGTAXBgNVBAoTEEluc3RydWN0dXJlLCBJbmMxEzARBgNVBAsTCk9wZXJhdGlvbnMx\nIDAeBgNVBAMTF0NhbnZhcyBTQU1MIENlcnRpZmljYXRlMSIwIAYJKoZIhvcNAQkB\nFhNvcHNAaW5zdHJ1Y3R1cmUuY29tMB4XDTE1MDQxNTAxMDAwMFoXDTE3MDQyMjAx\nMDAwMFowgasxCzAJBgNVBAYTAlVTMQ0wCwYDVQQIEwRVdGFoMRcwFQYDVQQHEw5T\nYWx0IExha2UgQ2l0eTEZMBcGA1UEChMQSW5zdHJ1Y3R1cmUsIEluYzETMBEGA1UE\nCxMKT3BlcmF0aW9uczEgMB4GA1UEAxMXQ2FudmFzIFNBTUwgQ2VydGlmaWNhdGUx\nIjAgBgkqhkiG9w0BCQEWE29wc0BpbnN0cnVjdHVyZS5jb20wggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDckDPQGWedlVGC2Z9fn1wNFmN+0IPNi6OSE1nM\nvoTWx2oZlQepaAu4zI5QqOfnV0rW2V1volpoJbu0WelH0DkGzdOEQdWJjAs3nRBf\ny0evxtpg0tK5kIvGsnN6YcD41YmkfWzvwbMf0cEq1Y0wCmymF6XzOUUE4zsi0nhP\nm2Z7WiuongDQdR01UsDN13YcpD/i1JXr3YtkNnJ/a1Kc9OXNycI8M5NVo5QQgdx/\nQ7zAmTk8p9E0ZRthdOQ/PBicWx39mNmBij5KpqCWlHu3NWdgcG8KXSv5atXU8Crd\nTRJ3aGIEN9vBYIHe8MHGCzs1QlRfJmXFMkeUSOTnJJx78rMDAgMBAAGjggEUMIIB\nEDAdBgNVHQ4EFgQUo0WWVlJ1SxZOs11L85ZAuZGyuzEwgeAGA1UdIwSB2DCB1YAU\no0WWVlJ1SxZOs11L85ZAuZGyuzGhgbGkga4wgasxCzAJBgNVBAYTAlVTMQ0wCwYD\nVQQIEwRVdGFoMRcwFQYDVQQHEw5TYWx0IExha2UgQ2l0eTEZMBcGA1UEChMQSW5z\ndHJ1Y3R1cmUsIEluYzETMBEGA1UECxMKT3BlcmF0aW9uczEgMB4GA1UEAxMXQ2Fu\ndmFzIFNBTUwgQ2VydGlmaWNhdGUxIjAgBgkqhkiG9w0BCQEWE29wc0BpbnN0cnVj\ndHVyZS5jb22CCQDgZrPz2FnDyzAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUA\nA4IBAQBV3EmmnzYqYQ5fXNZymG2WaspEW0NeFMhDXa3p3AMIQJbnnU14lR7bqIvf\n/bLW1YE0fw1kSzsw8VrkQp7k1U+kaYA3i5/FQBy2WtqUCVq2GXZA2gs5YD4nvJB/\nF57E//0kEhbATZH9+wJqDkqyIgsrSIlJjiXDth1BppGK8weboPtr9sWV24Ui0+ls\nw16XTsGlnRRO19g+gXKOZp5ApXkDrB+HwZQvZxiCuSgvJlcBzMdxVvWSL+vPtg8Y\nshIKzobIhaQ2MzXHLcxrDhW10YFPwDXh8Tfn5iU9ONsaJivuvVhtDYZD1ZzSoPpm\nq4vYqxxY/6rFJhrCtnlLepSaxlXM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://butte.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://butte.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://buttecollege.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://buttecollege.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://buttecollege.beta.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://buttecollege.beta.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://buttecollege.test.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://buttecollege.test.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://butte.beta.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://butte.beta.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://butte.test.instructure.com/saml_consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://butte.test.instructure.com/login/saml",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "OEI - Butte College - Canvas"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "`"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://dev.k-int.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Woodfield"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chas.woodfield@k-int.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chas"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Woodfield"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chas.woodfield@k-int.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chas"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dev.k-int.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-09-09T14:33:59Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Development Server for Knowledge Integration"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.k-int.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Knowledge Integration Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.k-int.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev.k-int.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.k-int.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.k-int.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.k-int.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dev.k-int.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dev.k-int.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEDCCAfigAwIBAgIJANET7G0zB2ebMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDWRldi5rLWludC5jb20wHhcNMTQwOTA4MTUxNTQxWhcNMjQwOTA1MTUxNTQx\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1kZXYuay1pbnQuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEA4FRK1M3lvxHPR22JlwT04/9qBnHfwh/Qb3HdfCxslyPnMZ0B\n\t\t\t\t\t\tEK67BoSmJTwaOxgFc05qiPiFvtC5TAA7J2T9OEKXswsu45VWcDQ6ol/slKsUg8pC\n\t\t\t\t\t\t1YzR/o935v7tlgLv/2q2MnQq+Be+aRfPDj3x/EEBbtyLl3SGECiz/RZvE0b5fmm6\n\t\t\t\t\t\tb1vRlIkhaJcedMk0hKeI0HB0S/sVEYqFJ8UGyBA5R6x1Ix3uWqH29yB2nmPAXuTP\n\t\t\t\t\t\tWEo4ErvyUmkOnzqm6Id4QNyN3ngaLojKRfOOQVbjZ5WSPz8krDydSe2T4VzAjozX\n\t\t\t\t\t\tf+fizC/O3Vp7SQhoR5qmmE+lO4Crk2+4ZnIIPQIDAQABo10wWzA6BgNVHREEMzAx\n\t\t\t\t\t\tgg1kZXYuay1pbnQuY29thiBodHRwczovL2Rldi5rLWludC5jb20vc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQUYelLBe5LEJDiZ43Ly+/dldqjfOswDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAGYaZug6eU/zrg+hL8qDgdrRqQMQuDF40s/aUyy5UU3p0Re+Z7KB7bf9tCle\n\t\t\t\t\t\tTf+f8zu9ZxxIkQQQuiAwE+x+DNLzldvf4fzYTtdE2VOw9SBV4uSI8fYxspPTnsZT\n\t\t\t\t\t\tzhAG1Ftcp8OexmaBAK+N05f8Jh069tLoLlDLv4kigccyMWdGTOeHgBhXekm2W5w6\n\t\t\t\t\t\tCmGRDp+nhCqLP48loKcq8oYJCP/DDpbfvkF8RQnV+x58NaXYZeg+fGRuz5YzDAMK\n\t\t\t\t\t\tJmuy/Q2tX05sTkOwM+nMe1p8LGRyZRuOYnEAarUWU/wJhTzVfP3FTonNwdGkCHVJ\n\t\t\t\t\t\tNZQGTuoZ4yj8q5imTpVcX0ApBkk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.k-int.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dev.k-int.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.k-int.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dev.k-int.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dev.k-int.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dev.k-int.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://vwww.itslearning.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Akhtar"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Waseem.Akhtar@itslearning.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Waseemr"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Akhtar"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Waseem.Akhtar@itslearning.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Waseemr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://vwww.itslearning.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "it's learning UK Limited: verification"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.itslearning.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "it's learning UK Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vwww.itslearning.com/elogin/logout.aspx",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSjCCAjKgAwIBAgIJAMta8TnXJcroMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\n\t\t\t\t\t\tBAMTG3Z3d3cuZWxvZ2luLml0c2xlYXJuaW5nLmNvbTAeFw0xMTAyMTgxMzA3NDZa\n\t\t\t\t\t\tFw0yMTAyMTUxMzA3NDZaMCYxJDAiBgNVBAMTG3Z3d3cuZWxvZ2luLml0c2xlYXJu\n\t\t\t\t\t\taW5nLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMi6jtOqE9dQ\n\t\t\t\t\t\t0/ZrFLEue3bh9wHSsjzdCvM2YoTGhFuiNsdpaeeGb5A61xJFxBXEzM6CeWoQqCVq\n\t\t\t\t\t\tV2yhfgUfvi0oerkhXrScWxTC+Na3YLL1wmfBRD8apCqB21B18GR2LMmaExKmnM0g\n\t\t\t\t\t\tHRV4TL7Xf5tQwxRuvMOZVMFC0KOzSf7II70rj2pzdWV9nLZmOGreF7KSQd89v3F0\n\t\t\t\t\t\tqBccgJzS81TG4n0HxUWWCdD3fdlP45RNX5uOwjU5F+tUPbfcbjyl8odL6YPicgCG\n\t\t\t\t\t\tFMs2Z8jMtEPZ8lZpqBnb8dEsPW44CBYa4veEbUAlcVbjXMWrZCCJF4kFICYBLgnP\n\t\t\t\t\t\tI1ckqaNBIAkCAwEAAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3Bl\n\t\t\t\t\t\tblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFEtsr6/AQyDcs5vC\n\t\t\t\t\t\tdNu9H/ZlmO80MB8GA1UdIwQYMBaAFEtsr6/AQyDcs5vCdNu9H/ZlmO80MA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQA+hJuHf93yK2ZfQT1U14Ojy9nkC25PlQU8N9fYCRBksGOV\n\t\t\t\t\t\tDOGxeJL+o8EI2X86hPq3n2KdTlZsyZQwC0ilaOsWqogHh0VFMWN8Yr6aQuhTrNUS\n\t\t\t\t\t\t0v2kDYbeBw3Ze867Skj8Yd7rbeEZ7qFReiXCjqs71vCRwuUnafqM5xK7NlgMZybl\n\t\t\t\t\t\tYmKgFj2vl9a8kOCfSeYy32Nv6o5whRGYBPsfGb2SqacHqjiUA8oUpWgAdwSaw/+L\n\t\t\t\t\t\tzqyv/l+j9cjqywds1og9dhnz/QwuWxYkaFatUN4XUMiUYE7Y8Vq11D6c2i1XSOYF\n\t\t\t\t\t\tK+kRpFiXVF8cgB84mxDx+1zN/jVusGRfE4yyWzkL"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://vwww.itslearning.com/elogin/default.aspx",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.fgu.cas.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Van\u00ed\u010dek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vanicekp@utia.cas.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.fgu.cas.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2014-05-29T13:36:13Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/avcr"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUW8Fvk+9NuCdYJn9rrxSID4QcQWUwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOaWRwLmZndS5jYXMuY3owHhcNMTQwNTE2MDcwMjEzWhcN\nMzQwNTE2MDcwMjEzWjAZMRcwFQYDVQQDEw5pZHAuZmd1LmNhcy5jejCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBALqySf+1bTV+w3dZgWBv7N697eGABM+v\nktmLnnyfLT9jlyGPH/kK/cGHdjVvAObBTP+igmarMWKuZM2TF9E0Onlgv9lwLOrF\nN5mltg3+PH/C1pawJWY80yx2OWB4F9a/6X69TUPPV+ZmYX8O6ivEsvlN6dTCnRma\nOu4U1lUpVlLGvYMuyDlt6ES+GGW73D+v7TW+oz5FHdidCWIJ8L2hYyjkn21O+IEI\nmFMi9gMYh09tWcPzn6t3H8JBUDY6iovnNAfUtdTY/rcH86YCQ42Hv2snpsjUiDTl\nn2G1TgRMq09iX8OGQSxcY4YDUHx5DzzrYSZcIlERS6MXyFnE+knavisCAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOaWRwLmZndS5jYXMuY3qGJWh0dHBzOi8vaWRwLmZndS5j\nYXMuY3ovaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFCRKRKtvKnxOQZHYF1aSsGu9\nGe2oMA0GCSqGSIb3DQEBBQUAA4IBAQCJ8ZeUl6jKt3ecQjX0gUsBEePJOREHlTtG\nAAb67oxhH9Mm/Z/5Qu5tvBoI7U+lncj/1gAf8FObQlUu4CSc02f5DeS0F80MAg3h\n/OAvZq85zFMJfhlbBQHdOtNqNROLwIu34JvIz+ukc2DG25weY/lgvU6ulUICkgd9\n9U1V77HhjdIIm5JYfTzKC3Iwss2/OT1WaY5esO+stlchg3D8kyKRlm2bG+WlWqAp\ngiXM0j45ZDJZNxmZ/U9kvaKVpmXE5DEYEvyMFGRZqyeo1DaHwiYAWPBbRO+tJp3A\n4O2O0wmUOZ0O6IPd8iDs0Q0eWV11U7mb3fGgeWKOIBS4zmQD2By5"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fgu.cas.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.fgu.cas.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.fgu.cas.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.fgu.cas.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.fgu.cas.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.fgu.cas.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.fgu.cas.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.fgu.cas.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.fgu.cas.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.fgu.cas.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.fgu.cas.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.fgu.cas.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fgu.cas.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.fgu.cas.cz/en"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.fgu.cas.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider  IOP AV CR employees."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance FG\u00da AV \u010cR"
                  }
                ],
                "logo": [
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-fgu-44.png",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "282"
                  },
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-fgu-153.png",
                    "height": "153",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "980"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Physiology AS CR"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Fyziologick\u00fd \u00fastav AV \u010cR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUW8Fvk+9NuCdYJn9rrxSID4QcQWUwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOaWRwLmZndS5jYXMuY3owHhcNMTQwNTE2MDcwMjEzWhcN\nMzQwNTE2MDcwMjEzWjAZMRcwFQYDVQQDEw5pZHAuZmd1LmNhcy5jejCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBALqySf+1bTV+w3dZgWBv7N697eGABM+v\nktmLnnyfLT9jlyGPH/kK/cGHdjVvAObBTP+igmarMWKuZM2TF9E0Onlgv9lwLOrF\nN5mltg3+PH/C1pawJWY80yx2OWB4F9a/6X69TUPPV+ZmYX8O6ivEsvlN6dTCnRma\nOu4U1lUpVlLGvYMuyDlt6ES+GGW73D+v7TW+oz5FHdidCWIJ8L2hYyjkn21O+IEI\nmFMi9gMYh09tWcPzn6t3H8JBUDY6iovnNAfUtdTY/rcH86YCQ42Hv2snpsjUiDTl\nn2G1TgRMq09iX8OGQSxcY4YDUHx5DzzrYSZcIlERS6MXyFnE+knavisCAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOaWRwLmZndS5jYXMuY3qGJWh0dHBzOi8vaWRwLmZndS5j\nYXMuY3ovaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFCRKRKtvKnxOQZHYF1aSsGu9\nGe2oMA0GCSqGSIb3DQEBBQUAA4IBAQCJ8ZeUl6jKt3ecQjX0gUsBEePJOREHlTtG\nAAb67oxhH9Mm/Z/5Qu5tvBoI7U+lncj/1gAf8FObQlUu4CSc02f5DeS0F80MAg3h\n/OAvZq85zFMJfhlbBQHdOtNqNROLwIu34JvIz+ukc2DG25weY/lgvU6ulUICkgd9\n9U1V77HhjdIIm5JYfTzKC3Iwss2/OT1WaY5esO+stlchg3D8kyKRlm2bG+WlWqAp\ngiXM0j45ZDJZNxmZ/U9kvaKVpmXE5DEYEvyMFGRZqyeo1DaHwiYAWPBbRO+tJp3A\n4O2O0wmUOZ0O6IPd8iDs0Q0eWV11U7mb3fGgeWKOIBS4zmQD2By5"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Physiology, Public Research Institution"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Fyziologick\u00fd \u00fastav AV \u010cR, v.v.i."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fgu.cas.cz/en"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fgu.cas.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Physiology"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Fyziologick\u00fd \u00fastav AV \u010cR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://neuresmail.sclintra.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jsullivan@sclogic.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Josh Sullivan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "wevans@sclogic.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Warren Evans"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://neuresmail.sclintra.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SCLogic"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sclogic.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SCLogic"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://neuresmail.sclintra.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Northeastern Resident Mail Services Student Portal"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Northeastern ResMail Student Portal"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC5TCCAc2gAwIBAgIJAIR74j0ayvKFMA0GCSqGSIb3DQEBBQUAMBUxEzARBgNV\nBAMTClNoaWJib2xldGgwHhcNMTUwOTEwMTQzOTIwWhcNMjUwOTA3MTQzOTIwWjAV\nMRMwEQYDVQQDEwpTaGliYm9sZXRoMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\nCgKCAQEAtS4wsy53ARWdIt1zGL9FL+65xOPWlA23J6U2lwoWPqSCg6l1v6po8y21\nkxsMEkHb52Xa1i3ik69i9X/IRpp43dYvfJLGJjRqxjVl6JE0703diTlaxCEN0O5M\ne2sHHqSYjMLRNOsQcgWVIIbmuN3ddxjHlm7qPYGzMIeqqNPSFLIzmjoOtJqjQNrZ\nUX6bTeFslnWed71x+f8+I4bU30F+rEZAQWS8x/rKsCtQCCU3Q3AHxRtQDQH0ZFIr\nuuSfp4FHrfhjx4WvDX80v2DhtXjZE73CfH3k6upGDaFpkjTaOG8EK3Cp1SJ26EBj\nVSO4hHKugZFaMGqIf3Zv1R6wdzYEmwIDAQABozgwNjAVBgNVHREEDjAMggpTaGli\nYm9sZXRoMB0GA1UdDgQWBBQl1wpM8ovMZB8f/SDNKbyA3k9SVTANBgkqhkiG9w0B\nAQUFAAOCAQEAXceagDJagtDgAzurO+zPaQgLn+4+B6rKwLecbE1e2YFN68iM2afd\n/jcNxxxTkVgNHr7PzBIl4ISRXMnZFwH9SMJhEAfBeryiIjVhoIMkLgTSAW+VmP8c\nAJ/rcomQRlYBxB7mLGbcyI64xU8tbV0azSg1RgKCuOVfm/lOD1NNonoA7+a+aHVN\nmDP3++DpOQcHpcGplHu75Ebr8freUMjzu2ut/fekP7sfrRe4uQhqJlC48lfm+f30\nqyCycAczHbvz3DXbqt4xsXtPAOfzdsTjDgI1uF4Vqo4Pgr0G05SnX8wg06A47A6t\n7LfGF7pjIcw52rCXI3f337AqLrkbL7Ft1Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://neuresmail.sclintra.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://neuresmail.sclintra.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://neuresmail.sclintra.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://neuresmail.sclintra.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Northeastern ResMail Student Portal"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Northeastern Resident Mail Services Student Portal"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://auth.creighton.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "bmclaughlin@creighton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bryan McLaughlin"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "security_team@creighton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bryan McLaughlin"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "security_team@creighton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bryan McLaughlin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sysadmins@creighton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rajendra Adhikari"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sysadmins@creighton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rajendra Adhikari"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sysadmins@creighton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rajendra Adhikari"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "security_team@creighton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bryan McLaughlin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://auth.creighton.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://auth.creighton.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://auth.creighton.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVALYutb/xiaSJQYhFEZztGzttPQiYMA0GCSqGSIb3DQEB\nBQUAMB0xGzAZBgNVBAMTEmF1dGguY3JlaWdodG9uLmVkdTAeFw0xMDA4MDYxNjAx\nNTBaFw0zMDA4MDYxNjAxNTBaMB0xGzAZBgNVBAMTEmF1dGguY3JlaWdodG9uLmVk\ndTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANhJqHK+SEJjfVTz2lmV\ng03xgDRh4jL0JLwACofJtdz0W9mr5fhRw8a2zXansvQoFP12E+UO2GahhPZCElcG\nL6zRZUfSlb0KcnP6JtBp45AtTeDiOZ0DJIsNwhYKL8JUsj+3UTO5Aol/CQi4CMAh\nvz5+LyurEWOQXOSRwZZ26Ou/HoLTevBS+wOdJ/ygRczZzy1GbXarHCfJRaomkqqC\nZazBGwRaJ25phGqQczdGwS7KJNSwqrPbJ9F+3hlSMvf+rVk3ebgmiFO0SqePMDJX\nFYMsHc1vXFJ02/NP0G3zErPuy560oZL3Nt0Nd98uLT3tS1tlGWTy0UXRDqmBq9TV\nGxMCAwEAAaNrMGkwSAYDVR0RBEEwP4ISYXV0aC5jcmVpZ2h0b24uZWR1hilodHRw\nczovL2F1dGguY3JlaWdodG9uLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\nW4FcvnGbLi/+v4v7EJbU6cQOhc4wDQYJKoZIhvcNAQEFBQADggEBAKu6nJ9/lEm6\n9/aGgFt4UVXLMf+ROxl5jX613BAZNDsCNdv5J7K5dtHZIifxtTuiw1cnWpPCM9ZP\nqaJmn+am9f60N6cDQOWIpWne7ItRlzcslfSG4u7vLWeIMmxasYJVSXceES8+HjXz\nzV0uTMTSncUUYeCA22RjoJarD+wMM5hkJ4pgXC85bLiDrCWNzSsWtDCmmBk+J+Zl\nYkxSHxmSoP7i5MikR+xIK5cL0GoN/5JeEvrUEpP/NPz8xWMjseoN5xqqQqyPwY0M\nB2t+c1HUlXTChLy6ntg0E/kSQxOSXpG9ymyxSfl6YDlPLY4uH1BxhvfmjIMo4VvA\n2x9R41E75LU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "creighton.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://auth.creighton.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.creighton.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.creighton.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://auth.creighton.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://auth.creighton.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://auth.creighton.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "creighton.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://auth.creighton.edu/creighton-logo.gif",
                    "lang": "en",
                    "height": "75",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "160"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Creighton University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVALYutb/xiaSJQYhFEZztGzttPQiYMA0GCSqGSIb3DQEB\nBQUAMB0xGzAZBgNVBAMTEmF1dGguY3JlaWdodG9uLmVkdTAeFw0xMDA4MDYxNjAx\nNTBaFw0zMDA4MDYxNjAxNTBaMB0xGzAZBgNVBAMTEmF1dGguY3JlaWdodG9uLmVk\ndTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANhJqHK+SEJjfVTz2lmV\ng03xgDRh4jL0JLwACofJtdz0W9mr5fhRw8a2zXansvQoFP12E+UO2GahhPZCElcG\nL6zRZUfSlb0KcnP6JtBp45AtTeDiOZ0DJIsNwhYKL8JUsj+3UTO5Aol/CQi4CMAh\nvz5+LyurEWOQXOSRwZZ26Ou/HoLTevBS+wOdJ/ygRczZzy1GbXarHCfJRaomkqqC\nZazBGwRaJ25phGqQczdGwS7KJNSwqrPbJ9F+3hlSMvf+rVk3ebgmiFO0SqePMDJX\nFYMsHc1vXFJ02/NP0G3zErPuy560oZL3Nt0Nd98uLT3tS1tlGWTy0UXRDqmBq9TV\nGxMCAwEAAaNrMGkwSAYDVR0RBEEwP4ISYXV0aC5jcmVpZ2h0b24uZWR1hilodHRw\nczovL2F1dGguY3JlaWdodG9uLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\nW4FcvnGbLi/+v4v7EJbU6cQOhc4wDQYJKoZIhvcNAQEFBQADggEBAKu6nJ9/lEm6\n9/aGgFt4UVXLMf+ROxl5jX613BAZNDsCNdv5J7K5dtHZIifxtTuiw1cnWpPCM9ZP\nqaJmn+am9f60N6cDQOWIpWne7ItRlzcslfSG4u7vLWeIMmxasYJVSXceES8+HjXz\nzV0uTMTSncUUYeCA22RjoJarD+wMM5hkJ4pgXC85bLiDrCWNzSsWtDCmmBk+J+Zl\nYkxSHxmSoP7i5MikR+xIK5cL0GoN/5JeEvrUEpP/NPz8xWMjseoN5xqqQqyPwY0M\nB2t+c1HUlXTChLy6ntg0E/kSQxOSXpG9ymyxSfl6YDlPLY4uH1BxhvfmjIMo4VvA\n2x9R41E75LU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Creighton University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.creighton.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Creighton University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://mccall.henley-cov.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McAll"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:imcall@henley-cov.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McAll"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:imcall@henley-cov.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://mccall.henley-cov.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIRAMs1hpx5cLrrnqC1wRQthWwwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzA5MTIwMDAwMDBaFw0xNjA5MTEyMzU5NTlaMEUxITAfBgNV\n\t\t\t\t\t\tBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEgMB4GA1UEAxMXbWNjYWxsLmhl\n\t\t\t\t\t\tbmxleS1jb3YuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDQ\n\t\t\t\t\t\t5xUydUjAY8iBFq35sgRsWpuqs1cKDHv5LkIL4N8qaVekHdBej6mWW6CXWc+OGXPm\n\t\t\t\t\t\te3M1JpIkEgT85GEckGTiQAEzGk6BviKhHTLbg6r1goWR891xbXkbdaPlY/MUtKpb\n\t\t\t\t\t\tNGXR1CBMgGEiW22sy9omQRGQlSAMNaM9c4zsVBbWfKHSCSyZ5mxR5Q1AjQVvM2w0\n\t\t\t\t\t\tPCxLRfWyYxp16QxXWCUYr+XB/S7BHERXETpaoH+sBcspjT70g4taoOzjRmL8IlN5\n\t\t\t\t\t\tRk9V4DZxybO+lun4IJ7hYsEm+1Hxd91pzB3MUDUuZ4W3+wiBxcTdGWWl6mbWIV+z\n\t\t\t\t\t\tnnkpse1/4oHG+yihRBKHAgMBAAGjggF0MIIBcDAfBgNVHSMEGDAWgBQMvZNoDPPe\n\t\t\t\t\t\tq6NJays3V0fqkOO57TAdBgNVHQ4EFgQUdTMEcyrs2BVOrd+a9jLSinjcU8gwDgYD\n\t\t\t\t\t\tVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEG\n\t\t\t\t\t\tCCsGAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoG\n\t\t\t\t\t\tA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5B\n\t\t\t\t\t\tU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2Ny\n\t\t\t\t\t\tdC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0\n\t\t\t\t\t\tdHA6Ly9vY3NwLnRjcy50ZXJlbmEub3JnMCIGA1UdEQQbMBmCF21jY2FsbC5oZW5s\n\t\t\t\t\t\tZXktY292LmFjLnVrMA0GCSqGSIb3DQEBBQUAA4IBAQB4+WToqhio4ygMFQRaR7jx\n\t\t\t\t\t\tGnN7OvUWOSdUUfzmwE54tXHoKqshC3xp1rqhZjdK77Vaoe5VdzuQv8lO0YyBdEfY\n\t\t\t\t\t\t6DKG7nqsZdomYRoogxOPL8TPrkh+AGVmfZaJhJ/GZauEvJAXHO1zjP/1IMIxia+Y\n\t\t\t\t\t\t4SkJBKVpsA4cUn7A082gFqfnGhHvl2JuDNszY/E+mDVxx3MXBT6aeq+gNF2Qx3kc\n\t\t\t\t\t\t6GAWgZoqoIrF6FQX6E032WNWyzV4thdB93S9CK2bvsq+yQwWWCZHqAT3fY7Peyrj\n\t\t\t\t\t\tfJtg6uLXHqJiAjTaAhXMEIB5Fk9lQIqXLXJg/2RCGMHw654O8j0K65JS1yQ4T4db"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "henley-cov.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://mccall.henley-cov.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mccall.henley-cov.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://mccall.henley-cov.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mccall.henley-cov.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://mccall.henley-cov.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mccall.henley-cov.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://mccall.henley-cov.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mccall.henley-cov.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "henley-cov.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIRAMs1hpx5cLrrnqC1wRQthWwwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzA5MTIwMDAwMDBaFw0xNjA5MTEyMzU5NTlaMEUxITAfBgNV\n\t\t\t\t\t\tBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEgMB4GA1UEAxMXbWNjYWxsLmhl\n\t\t\t\t\t\tbmxleS1jb3YuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDQ\n\t\t\t\t\t\t5xUydUjAY8iBFq35sgRsWpuqs1cKDHv5LkIL4N8qaVekHdBej6mWW6CXWc+OGXPm\n\t\t\t\t\t\te3M1JpIkEgT85GEckGTiQAEzGk6BviKhHTLbg6r1goWR891xbXkbdaPlY/MUtKpb\n\t\t\t\t\t\tNGXR1CBMgGEiW22sy9omQRGQlSAMNaM9c4zsVBbWfKHSCSyZ5mxR5Q1AjQVvM2w0\n\t\t\t\t\t\tPCxLRfWyYxp16QxXWCUYr+XB/S7BHERXETpaoH+sBcspjT70g4taoOzjRmL8IlN5\n\t\t\t\t\t\tRk9V4DZxybO+lun4IJ7hYsEm+1Hxd91pzB3MUDUuZ4W3+wiBxcTdGWWl6mbWIV+z\n\t\t\t\t\t\tnnkpse1/4oHG+yihRBKHAgMBAAGjggF0MIIBcDAfBgNVHSMEGDAWgBQMvZNoDPPe\n\t\t\t\t\t\tq6NJays3V0fqkOO57TAdBgNVHQ4EFgQUdTMEcyrs2BVOrd+a9jLSinjcU8gwDgYD\n\t\t\t\t\t\tVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEG\n\t\t\t\t\t\tCCsGAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoG\n\t\t\t\t\t\tA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5B\n\t\t\t\t\t\tU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2Ny\n\t\t\t\t\t\tdC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0\n\t\t\t\t\t\tdHA6Ly9vY3NwLnRjcy50ZXJlbmEub3JnMCIGA1UdEQQbMBmCF21jY2FsbC5oZW5s\n\t\t\t\t\t\tZXktY292LmFjLnVrMA0GCSqGSIb3DQEBBQUAA4IBAQB4+WToqhio4ygMFQRaR7jx\n\t\t\t\t\t\tGnN7OvUWOSdUUfzmwE54tXHoKqshC3xp1rqhZjdK77Vaoe5VdzuQv8lO0YyBdEfY\n\t\t\t\t\t\t6DKG7nqsZdomYRoogxOPL8TPrkh+AGVmfZaJhJ/GZauEvJAXHO1zjP/1IMIxia+Y\n\t\t\t\t\t\t4SkJBKVpsA4cUn7A082gFqfnGhHvl2JuDNszY/E+mDVxx3MXBT6aeq+gNF2Qx3kc\n\t\t\t\t\t\t6GAWgZoqoIrF6FQX6E032WNWyzV4thdB93S9CK2bvsq+yQwWWCZHqAT3fY7Peyrj\n\t\t\t\t\t\tfJtg6uLXHqJiAjTaAhXMEIB5Fk9lQIqXLXJg/2RCGMHw654O8j0K65JS1yQ4T4db"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Henley College Coventry"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.henley-cov.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Henley College Coventry"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.southend.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.southend.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/southend.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/southend.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "southend.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "South Essex College of Further and Higher Education"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.southessex.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.bucksstudentsunion.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.bucksstudentsunion.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-09-12T14:09:18Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Buckingham New University Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bucksstudentsunion.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.bucksstudentsunion.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.bucksstudentsunion.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.bucksstudentsunion.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.bucksstudentsunion.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.bucksstudentsunion.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.bucksstudentsunion.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.bucksstudentsunion.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.bucksstudentsunion.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.bucksstudentsunion.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.bucksstudentsunion.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.bucksstudentsunion.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.bucksstudentsunion.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.unibg.it/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:postmaster@unibg.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IDP"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.unibg.it/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2012-11-27T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unibg.it/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unibg.it/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.unibg.it/simplesaml/shib13/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unibg.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unibg.it/idem"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for University of Bergamo users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti dell'Universita' degli studi di Bergamo"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.unibg.it/logo.jpg",
                    "height": "55",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "153"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Bergamo"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 degli studi di Bergamo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "unibg.it"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:45.69548,9.66664"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZzCCAk+gAwIBAgIJAO63/giuk/ngMA0GCSqGSIb3DQEBBQUAMEoxCzAJBgNV\nBAYTAklUMRMwEQYDVQQIDApTb21lLVN0YXRlMQ8wDQYDVQQKDAZDSU5FQ0ExFTAT\nBgNVBAMMDGlkcC51bmliZy5pdDAeFw0xNDA0MTQxMzA1MTRaFw0yNDA0MTMxMzA1\nMTRaMEoxCzAJBgNVBAYTAklUMRMwEQYDVQQIDApTb21lLVN0YXRlMQ8wDQYDVQQK\nDAZDSU5FQ0ExFTATBgNVBAMMDGlkcC51bmliZy5pdDCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAKpOSuOvQeVjjWlpxbpDz+35Ag9lt4TxUk2ljeTggV2C\njSrp9HfDwdn3i5+LvFhFeXN+U/iDY9q1ljUsyuG6sPEgkTOUunJOjWXUMQPfNUZ9\nAP6Rn6/AXhpaTv5e6t3tZxac3zhRe+ptPASsabv/GtMkK+Oyfn39+1FP/mnWRM+p\nvIR4MTkOIiNoN4xT/AqshNkMN5zJMrEGiq9oQT4wObjHPjOYanihde0auFMLAXGR\nxYpiq+vsiezitnc2JXNbWVfwieK5FIFGGh94EV4mrui/YGVj+mjF25fqTU7B5YBW\nWENnNtbfiT4qfOGRX2JvV70y5zPbilypbS+nYnn8m8sCAwEAAaNQME4wHQYDVR0O\nBBYEFN2Dnm5ywy81VJkNqIDC/URi/BOkMB8GA1UdIwQYMBaAFN2Dnm5ywy81VJkN\nqIDC/URi/BOkMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBADc2os6T\nj9GRr+YXVWu4mP3sYgynhVEMq+7akx22HEmOLbQkhlJc2igNolmQiknG6Dm6KUlY\nMbHTAx1YMF5iW2GFrjXBQa+Ro5aALKf7Q7YW9qsNLlTjNj7ZB4GSPh/J+DR4vZUR\n797WlcR3uIg+696zSTaY5xJVcKdTNOCZ/BLmyo/g1OC/EwQFxU1jCqH+J3FMd0G6\ne9/ZJFUYBBD+yvrOxMnVCRSnh98phe5P3ZdJVZ/LEMVZvv/HghnVKsDUQZDQc6MQ\nwEH76GwmZQFrC65dac+I+viPLUSDmj2lnXVcCpeG85C5Utg4ulhGWISYK2RVbG/P\nMNMgaClKqsoAXo8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZzCCAk+gAwIBAgIJAO63/giuk/ngMA0GCSqGSIb3DQEBBQUAMEoxCzAJBgNV\nBAYTAklUMRMwEQYDVQQIDApTb21lLVN0YXRlMQ8wDQYDVQQKDAZDSU5FQ0ExFTAT\nBgNVBAMMDGlkcC51bmliZy5pdDAeFw0xNDA0MTQxMzA1MTRaFw0yNDA0MTMxMzA1\nMTRaMEoxCzAJBgNVBAYTAklUMRMwEQYDVQQIDApTb21lLVN0YXRlMQ8wDQYDVQQK\nDAZDSU5FQ0ExFTATBgNVBAMMDGlkcC51bmliZy5pdDCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAKpOSuOvQeVjjWlpxbpDz+35Ag9lt4TxUk2ljeTggV2C\njSrp9HfDwdn3i5+LvFhFeXN+U/iDY9q1ljUsyuG6sPEgkTOUunJOjWXUMQPfNUZ9\nAP6Rn6/AXhpaTv5e6t3tZxac3zhRe+ptPASsabv/GtMkK+Oyfn39+1FP/mnWRM+p\nvIR4MTkOIiNoN4xT/AqshNkMN5zJMrEGiq9oQT4wObjHPjOYanihde0auFMLAXGR\nxYpiq+vsiezitnc2JXNbWVfwieK5FIFGGh94EV4mrui/YGVj+mjF25fqTU7B5YBW\nWENnNtbfiT4qfOGRX2JvV70y5zPbilypbS+nYnn8m8sCAwEAAaNQME4wHQYDVR0O\nBBYEFN2Dnm5ywy81VJkNqIDC/URi/BOkMB8GA1UdIwQYMBaAFN2Dnm5ywy81VJkN\nqIDC/URi/BOkMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBADc2os6T\nj9GRr+YXVWu4mP3sYgynhVEMq+7akx22HEmOLbQkhlJc2igNolmQiknG6Dm6KUlY\nMbHTAx1YMF5iW2GFrjXBQa+Ro5aALKf7Q7YW9qsNLlTjNj7ZB4GSPh/J+DR4vZUR\n797WlcR3uIg+696zSTaY5xJVcKdTNOCZ/BLmyo/g1OC/EwQFxU1jCqH+J3FMd0G6\ne9/ZJFUYBBD+yvrOxMnVCRSnh98phe5P3ZdJVZ/LEMVZvv/HghnVKsDUQZDQc6MQ\nwEH76GwmZQFrC65dac+I+viPLUSDmj2lnXVcCpeG85C5Utg4ulhGWISYK2RVbG/P\nMNMgaClKqsoAXo8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 di Bergamo"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Bergamo"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unibg.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unibg.it/en_index.asp"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli studi di Bergamo"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Bergamo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp-dgnocchi.irccs.garr.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idpcloud-service@garr.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-dgnocchi.irccs.garr.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2014-03-12T12:15:14Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUP1k5hfSRuNvbFEuq697H3+caJKQwDQYJKoZIhvcNAQEF\nBQAwJTEjMCEGA1UEAxMaaWRwLWRnbm9jY2hpLmlyY2NzLmdhcnIuaXQwHhcNMTMx\nMTI4MTQ0NTI3WhcNMzMxMTI4MTQ0NTI3WjAlMSMwIQYDVQQDExppZHAtZGdub2Nj\naGkuaXJjY3MuZ2Fyci5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAJcayGTp5Elhk5nXeuntBEg2r0Le/6nIsQG8FgkNf+qggXSHNVWxhFvw3EblGttY\n9jISmSjGdUwNpGknPPEXdZ3w/RO+czI3zZmMNUxIvF+RBOv45FQRd6JpMojAOBjZ\nblIJ9uxIZl9CTc7AytutChk/JS0uME0bZnCdIxitsMraRITSiUqZw9FDlghcbAPU\n66+EIqmAas0pNzHIgICsTQFpVpR7aOCrGDgLH8ZhnE895Bte5hdTbDwEBVFYZ4NE\noMGUwgRhly0g9EAh04ercObE4NZLuF9XIrw6L5bUoOAn7AXCiIfGcUHukEt2NbSi\nzwOfrKyshMvwQeUu1QXdr2sCAwEAAaN7MHkwWAYDVR0RBFEwT4IaaWRwLWRnbm9j\nY2hpLmlyY2NzLmdhcnIuaXSGMWh0dHBzOi8vaWRwLWRnbm9jY2hpLmlyY2NzLmdh\ncnIuaXQvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFMfsRTXhI2SK/tSeRLeojBMD\ny034MA0GCSqGSIb3DQEBBQUAA4IBAQBZTmIO9IWCOi8wbPcBpgyZYhwn39CfeBJp\nqf4NhXa9ZO6IC+qMG3+dZGlg0FkqTkbArc7tTATUL0b7p1zWXsH8GgtyigKjzdKB\n6mKwtYErqp0gF4438G8XpXsolrjF/RyCrxj7aXDzIKktk2cXKVqF9xtMc5H1AAkq\nhnyOXvP4oteo+j+aww+rS4ITijKAXLhgFoNbGIfN3zTfTywBKU46+ZAuuzbLyNa/\nfKX+hJtcp9X9ctp8azb3HudIHe+5YSDOKWYPAgEdXDTlBXdd0/9zrEp1UIZ3jx6I\nMJX+TT5lOVFqu29vcvoiXmH3XIAZi7JIvcAt3STJGs7wZFJzrTrx"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dongnocchi.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-dgnocchi.irccs.garr.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-dgnocchi.irccs.garr.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-dgnocchi.irccs.garr.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-dgnocchi.irccs.garr.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-dgnocchi.irccs.garr.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-dgnocchi.irccs.garr.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-dgnocchi.irccs.garr.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-dgnocchi.irccs.garr.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dongnocchi.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idp-dgnocchi.irccs.garr.it/idp/info.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idp-dgnocchi.irccs.garr.it/idp/info.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IRCCS Fondazione Don Carlo Gnocchi Onlus"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IRCCS Fondazione Don Carlo Gnocchi Onlus"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for Fondazione Don Carlo Gnocchi Onlus users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider per gli utenti della Fondazione Don Carlo Gnocchi Onlus"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp-dgnocchi.irccs.garr.it/idp/images/institutionLogo-32x32_en.png",
                    "lang": "en",
                    "height": "32",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "32"
                  },
                  {
                    "text": "https://idp-dgnocchi.irccs.garr.it/idp/images/institutionLogo-160x120_en.png",
                    "lang": "en",
                    "height": "120",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "160"
                  },
                  {
                    "text": "https://idp-dgnocchi.irccs.garr.it/idp/images/institutionLogo-32x32_it.png",
                    "lang": "it",
                    "height": "32",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "32"
                  },
                  {
                    "text": "https://idp-dgnocchi.irccs.garr.it/idp/images/institutionLogo-160x120_it.png",
                    "lang": "it",
                    "height": "120",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "160"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://idp-dgnocchi.irccs.garr.it/idp/privacy.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://idp-dgnocchi.irccs.garr.it/idp/privacy.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUP1k5hfSRuNvbFEuq697H3+caJKQwDQYJKoZIhvcNAQEF\nBQAwJTEjMCEGA1UEAxMaaWRwLWRnbm9jY2hpLmlyY2NzLmdhcnIuaXQwHhcNMTMx\nMTI4MTQ0NTI3WhcNMzMxMTI4MTQ0NTI3WjAlMSMwIQYDVQQDExppZHAtZGdub2Nj\naGkuaXJjY3MuZ2Fyci5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAJcayGTp5Elhk5nXeuntBEg2r0Le/6nIsQG8FgkNf+qggXSHNVWxhFvw3EblGttY\n9jISmSjGdUwNpGknPPEXdZ3w/RO+czI3zZmMNUxIvF+RBOv45FQRd6JpMojAOBjZ\nblIJ9uxIZl9CTc7AytutChk/JS0uME0bZnCdIxitsMraRITSiUqZw9FDlghcbAPU\n66+EIqmAas0pNzHIgICsTQFpVpR7aOCrGDgLH8ZhnE895Bte5hdTbDwEBVFYZ4NE\noMGUwgRhly0g9EAh04ercObE4NZLuF9XIrw6L5bUoOAn7AXCiIfGcUHukEt2NbSi\nzwOfrKyshMvwQeUu1QXdr2sCAwEAAaN7MHkwWAYDVR0RBFEwT4IaaWRwLWRnbm9j\nY2hpLmlyY2NzLmdhcnIuaXSGMWh0dHBzOi8vaWRwLWRnbm9jY2hpLmlyY2NzLmdh\ncnIuaXQvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFMfsRTXhI2SK/tSeRLeojBMD\ny034MA0GCSqGSIb3DQEBBQUAA4IBAQBZTmIO9IWCOi8wbPcBpgyZYhwn39CfeBJp\nqf4NhXa9ZO6IC+qMG3+dZGlg0FkqTkbArc7tTATUL0b7p1zWXsH8GgtyigKjzdKB\n6mKwtYErqp0gF4438G8XpXsolrjF/RyCrxj7aXDzIKktk2cXKVqF9xtMc5H1AAkq\nhnyOXvP4oteo+j+aww+rS4ITijKAXLhgFoNbGIfN3zTfTywBKU46+ZAuuzbLyNa/\nfKX+hJtcp9X9ctp8azb3HudIHe+5YSDOKWYPAgEdXDTlBXdd0/9zrEp1UIZ3jx6I\nMJX+TT5lOVFqu29vcvoiXmH3XIAZi7JIvcAt3STJGs7wZFJzrTrx"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IRCCS Fondazione Don Carlo Gnocchi Onlus"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IRCCS Fondazione Don Carlo Gnocchi Onlus"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dongnocchi.it/documenti/eng/index_eng.htm"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dongnocchi.it"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IRCCS Fondazione Don Carlo Gnocchi Onlus"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IRCCS Fondazione Don Carlo Gnocchi Onlus"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://cas.cgcent.miami.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "akadiyala@miami.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Anil Kadiyala"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cas.cgcent.miami.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cas.cgcent.miami.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cas.cgcent.miami.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cas.cgcent.miami.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cas.cgcent.miami.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cas.cgcent.miami.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "miami.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "zTest_University of Miami"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUENN7pIAppEM5kpFqfJ0yapfX/lgwDQYJKoZIhvcNAQEF\nBQAwHzEdMBsGA1UEAxMUY2FzLmNnY2VudC5taWFtaS5lZHUwHhcNMTEwNjE1MTMy\nNjExWhcNMzEwNjE1MTMyNjExWjAfMR0wGwYDVQQDExRjYXMuY2djZW50Lm1pYW1p\nLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ+Y4nj/hU3gkyyy\nDrXqooTIuSZfnlNORDNhhiBHlDZ6hZuMfxeQ2Rlq00lkSS7bNHGZBlf9Wj2dtkDZ\n7xqyqtLFT1Pfnn+wQ3ordhAagOx1sh8Re/clsbPDfH6lhnf669uNxR3uoCM2/kLV\n9WKWXjhYgq6bP7521sGNYJrz7dDB+Kk1zRiYnT8NtbcBoWyWpHffbnPY3nqhiyvL\ncd9dyQdcfymMf6HLnQZmcOdZJSdpgQRJ7vUKTLqKn6lEVgweqTJscURo89Ef73Bs\nNOLXZ3gaKp40wxUmYv2u5EG9vazigo5A8E7L3ahmEIULkQS2wBxiYDIyGUYQXnB2\nSW45bJMCAwEAAaNvMG0wTAYDVR0RBEUwQ4IUY2FzLmNnY2VudC5taWFtaS5lZHWG\nK2h0dHBzOi8vY2FzLmNnY2VudC5taWFtaS5lZHUvaWRwL3NoaWJib2xldGgwHQYD\nVR0OBBYEFCX0KLFqcbwPHS4lBV5ynBkOjkJdMA0GCSqGSIb3DQEBBQUAA4IBAQAE\n+INXRGUhPoYzJuRcmhmAMXqpMVPcZGJm4jx/Kd4JE7bYgpWgLULLm4nVAptIOS6y\nZ6kaQpf0wQApCLb5mqofcqfzIVsqhcQ9jpzcP1cMFgRkl2D8WbgSnT4PoObCjsU/\n7vEkNaAQ5EZz1+N/5fzvUs8kLJagjyTMTNcMxvGlAVE7OY/SF8aN6InvKH8L440z\nC0CCRFh4Nv4ABEh4J9zCETIuv5x5X+73JBTm/Lqv77wlHDIo5u3gQMKRC8zHn7xv\nIsLKXZxJPuY1fEpWPmB2KT8oMw7oTbO92Jskpie62r7N3dnb2J1OMHevgm7DOP+D\nRPbHcgoMCemXOUYD6n4c"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "zTest_University of Miami"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.miami.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Miami"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://adfs.glu.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs.glu.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-04-29T12:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/24e321ebbe6056f380b73ca8d20398a9",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Grafisch Lyceum Utrecht"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Grafisch Lyceum Utrecht"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/glu.png",
                    "height": "35",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Grafisch Lyceum Utrecht"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Grafisch Lyceum Utrecht"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Grafisch Lyceum Utrecht"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.glu.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Grafisch Lyceum Utrecht"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://test.stir.unidesk.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:IS.Helpline@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-techmgt@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Application Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test.stir.unidesk.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-04T11:23:53Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Test Unidesk- University of Stirling"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.stir.unidesk.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://test.stir.unidesk.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.stir.unidesk.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.stir.unidesk.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.stir.unidesk.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.stir.unidesk.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAKOQZJ9XeRRZMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\n\t\t\t\t\t\tBAMTEnRlc3QudW5pZGVzay5hYy51azAeFw0xMjAzMjIxNjUwMTdaFw0yMjAzMjAx\n\t\t\t\t\t\tNjUwMTdaMB0xGzAZBgNVBAMTEnRlc3QudW5pZGVzay5hYy51azCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBAPweFLYNELDowDm8YWp8G8RKR0q+ufgUN7H7\n\t\t\t\t\t\th7RTesgxlO9T8wXLT1e4s1ruCVrYtkt8q3K+iXukZ+J5QD4lMtvWHfbpKJNddygG\n\t\t\t\t\t\tRkURpJQ7bY1rTdWA6jNi16TR+8M2ECIf4Q6CVukHHrX9PuZM+b7Ktg2gf3fmy7vQ\n\t\t\t\t\t\tMQ2/2Rp8/LKGKotVAoRYrNc8y3Y2PR9omsidxNGyyXxfD2OyTobuk1Ezb7Fk4Oq+\n\t\t\t\t\t\t4VmetrJ5CwFOwTBmFUgfaazuooEvGM7tA/jjRGDY5H+4oyVDK63Ktf59pwGln6Bo\n\t\t\t\t\t\tJyBfJIWYK/5w3psQJZCFyNgJ4WQSgxbAiORGQPZLfKxsvAaGD2UCAwEAAaNAMD4w\n\t\t\t\t\t\tHQYDVR0RBBYwFIISdGVzdC51bmlkZXNrLmFjLnVrMB0GA1UdDgQWBBRxsmQCxZXe\n\t\t\t\t\t\tbZvQMvehqWxt1yHYijANBgkqhkiG9w0BAQUFAAOCAQEAtOWghRw2KKVvYbX0sQEX\n\t\t\t\t\t\tVDYPpi4Q1q6b1vl/MK0WU+zWjOmuljIIw377NOuH+A8zwJF2maelKlEHFmlMg8nl\n\t\t\t\t\t\ta8MPTIQIhgJ3baXwfy5jvEIQrK++0LwaFiBdwg0dM3er6pyODVypn6oNpKY9gcFA\n\t\t\t\t\t\txCl05pTEBIWPAxFNcvYj/liPrDC8RcEBpnEiGZcJgvPGCulXV3O9FCRkoyTaVoUB\n\t\t\t\t\t\te42UmPVs7zqOGsBy6ZcHRGoD53VWtkvax8iBGBobK0fGICh6vyX7Qb6Me3r/7S1h\n\t\t\t\t\t\t6WUcF/Nm7P5V6V2an8MJPYyIVNn6QorTplFsBhK4/Wr+Xb4JIurIwCWDqbVIYo1j\n\t\t\t\t\t\tTA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.stir.unidesk.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://test.stir.unidesk.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.stir.unidesk.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://test.stir.unidesk.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://test.stir.unidesk.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://test.stir.unidesk.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.uth.gr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@uth.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University of Thessaly NOC"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@uth.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "University of Thessaly NOC"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uth.gr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCDCCAfCgAwIBAgIJAPbE4JqrFTBTMA0GCSqGSIb3DQEBBQUAMBUxEzARBgNV\n                            BAMTCmFhaS51dGguZ3IwHhcNMTUwMTIwMDkzNTQwWhcNMTgwMTE5MDkzNTQwWjAV\n                            MRMwEQYDVQQDEwphYWkudXRoLmdyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n                            CgKCAQEAuXbp6/MQmvg+nE34bdjQ1VE0Bx8bzobfj6Eh4yFBmJhfHr8fWEaAP+jx\n                            o9hodJl6FeByG8ejPkAm9m9K/SGphLEQQFlSKsg1BaRfaa6pmKWONaolqPuS35gb\n                            E/SypucbCNX8ZMapxLyZY8IzjZO5gf9WAP+XcZj3LrpXYKMBOhG6XGWvPZUaqlU8\n                            5Qt5ZoceksS8otlnaJ6OC4tiCKpCO7qcTrB7RMaQt3/tlA1eBYz9yDBaEbfpaLvs\n                            WloGeQuWy4tuDhqjB7P/iTioGCPG9RTj5jFKfkj+M6VEpHBFAZetIFqXtuMisSGo\n                            e/MYcN/xVte6Wr4ZNzfr09D+oMP2SwIDAQABo1swWTA4BgNVHREEMTAvggphYWku\n                            dXRoLmdyhiFodHRwczovL2lkcC51dGguZ3IvaWRwL3NoaWJib2xldGgwHQYDVR0O\n                            BBYEFF6MV6RBvR2vKtPxO+t6S3oWOPYwMA0GCSqGSIb3DQEBBQUAA4IBAQBMX4wH\n                            U4VnJitYpBJ/9QQakfl+t9kGdP6lxwKPU8NigHCqZ7eFf3Ab39rp1tmF7wLp5V7P\n                            mYDfeP1fY3P//p3bEh8JRGR/xVQhsjSUj3u0o8vND/95CmjH6OygHBTCWxAG4+NT\n                            mMT63CBmj000B+4M3tCSi6dw26MYkR6YzqqExK7TzZkhAcqzq+cX12UerWRU9+4N\n                            gFgnxt7wCTDgr5vLE7l2gPZsW6fARMepI1Hi1R4HtWfvsUWuqdi/+UWAOrP3GEfk\n                            0S9jSEGt7/vFOwbLNDFHydht9HP6Vvf9ELgW+wP9r0ebCWow/++ye7/QPqJ0hyel\n                            v6N4PY24wsBai7PU"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uth.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai.uth.gr:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai.uth.gr:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aai.uth.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai.uth.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aai.uth.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai.uth.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai.uth.gr:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai.uth.gr:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uth.gr"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uth.gr/en/"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uth.gr/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://aai.uth.gr/idp/images/uth_logo_87x87.png",
                    "height": "87",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "87"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Thessaly"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u03a0\u03b1\u03bd\u03b5\u03c0\u03b9\u03c3\u03c4\u03ae\u03bc\u03b9\u03bf \u0398\u03b5\u03c3\u03c3\u03b1\u03bb\u03af\u03b1\u03c2"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "www.uth.gr"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "it.uth.gr"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:39.357718,22.950722"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:39.360568,22.931205"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:39.388834,22.940703"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:39.614609,22.387859"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:39.637292,22.418366"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:39.525625,21.775881"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:39.372241,21.916267"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:38.912572,22.428045"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "194.177.200.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.251.17.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.251.18.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "83.212.32.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "83.212.201.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.251.108.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:648:2480::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCDCCAfCgAwIBAgIJAPbE4JqrFTBTMA0GCSqGSIb3DQEBBQUAMBUxEzARBgNV\n                            BAMTCmFhaS51dGguZ3IwHhcNMTUwMTIwMDkzNTQwWhcNMTgwMTE5MDkzNTQwWjAV\n                            MRMwEQYDVQQDEwphYWkudXRoLmdyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n                            CgKCAQEAuXbp6/MQmvg+nE34bdjQ1VE0Bx8bzobfj6Eh4yFBmJhfHr8fWEaAP+jx\n                            o9hodJl6FeByG8ejPkAm9m9K/SGphLEQQFlSKsg1BaRfaa6pmKWONaolqPuS35gb\n                            E/SypucbCNX8ZMapxLyZY8IzjZO5gf9WAP+XcZj3LrpXYKMBOhG6XGWvPZUaqlU8\n                            5Qt5ZoceksS8otlnaJ6OC4tiCKpCO7qcTrB7RMaQt3/tlA1eBYz9yDBaEbfpaLvs\n                            WloGeQuWy4tuDhqjB7P/iTioGCPG9RTj5jFKfkj+M6VEpHBFAZetIFqXtuMisSGo\n                            e/MYcN/xVte6Wr4ZNzfr09D+oMP2SwIDAQABo1swWTA4BgNVHREEMTAvggphYWku\n                            dXRoLmdyhiFodHRwczovL2lkcC51dGguZ3IvaWRwL3NoaWJib2xldGgwHQYDVR0O\n                            BBYEFF6MV6RBvR2vKtPxO+t6S3oWOPYwMA0GCSqGSIb3DQEBBQUAA4IBAQBMX4wH\n                            U4VnJitYpBJ/9QQakfl+t9kGdP6lxwKPU8NigHCqZ7eFf3Ab39rp1tmF7wLp5V7P\n                            mYDfeP1fY3P//p3bEh8JRGR/xVQhsjSUj3u0o8vND/95CmjH6OygHBTCWxAG4+NT\n                            mMT63CBmj000B+4M3tCSi6dw26MYkR6YzqqExK7TzZkhAcqzq+cX12UerWRU9+4N\n                            gFgnxt7wCTDgr5vLE7l2gPZsW6fARMepI1Hi1R4HtWfvsUWuqdi/+UWAOrP3GEfk\n                            0S9jSEGt7/vFOwbLNDFHydht9HP6Vvf9ELgW+wP9r0ebCWow/++ye7/QPqJ0hyel\n                            v6N4PY24wsBai7PU"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Thessaly"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u03a0\u03b1\u03bd\u03b5\u03c0\u03b9\u03c3\u03c4\u03ae\u03bc\u03b9\u03bf \u0398\u03b5\u03c3\u03c3\u03b1\u03bb\u03af\u03b1\u03c2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uth.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uth.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Thessaly"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u03a0\u03b1\u03bd\u03b5\u03c0\u03b9\u03c3\u03c4\u03ae\u03bc\u03b9\u03bf \u0398\u03b5\u03c3\u03c3\u03b1\u03bb\u03af\u03b1\u03c2"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://vfu-gemdev.it.su.se/Shibboleth.sso",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://vfu-gemdev.it.su.se/Shibboleth.sso",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vfu-gemdev.it.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vfu-gemdev.it.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vfu-gemdev.it.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vfu-gemdev.it.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vfu-gemdev.it.su.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://vfu-gemdev.it.su.se/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://vfu-gemdev.it.su.se/Shibboleth.sso/WAYF/wavelan",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://vfu-gemdev.it.su.se/Shibboleth.sso/WAYF/idp.secure.su.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://vfu-gemdev.it.su.se/Shibboleth.sso/SWAMID",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "4"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "VFU-portalen utvecklingsmiljl\u00f6, Stockholms univsersitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "VFU-portalen development environment, Stockholm University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "VFU-Portalen utvecklingsmilj\u00f6"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "VFU-Portalen development environment"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "vfu-gemdev-sp01"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAM2DRYvk1gHoMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD3ZmdS1nZW1kZXYtc3AwMTAeFw0xMjAzMjMxMTIzNTVaFw0yMjAzMjExMTIz\nNTVaMBoxGDAWBgNVBAMTD3ZmdS1nZW1kZXYtc3AwMTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAMNWXQiNwZrd5EpYMZEYbTTQAGLIHPuAgzAf5mrjnyXF\n+811k0uJova1/Jsb1TYyua5Ti5SncDIKsLZFFpxbIHF7Yq22r4bmrYdsQ9bTeifc\nNlMjY/N9we9x/07LmxMopbAZEHbwm7b/xsoSpJ6uGs6wRSxpBejGmB9t5BhQzNN2\nicp/H89hzyOqyzAMl3O6SirdVh/cNqFBAlnVS21Nryy1wWZMr3w0HhkbkEz6Zanz\n6KtWI3IFqeHOhPomiVaWquTp49pGO43cwHb6Tx1h4h+OSqCN9TazA8nOJ0PMAUMp\nNnPgWQW6SO13nVAcHihIDPfoYvD/wW2CYJjUT5OzjqECAwEAAaM9MDswGgYDVR0R\nBBMwEYIPdmZ1LWdlbWRldi1zcDAxMB0GA1UdDgQWBBSEdlf3VKcDHEXFAgPS21B9\nV+cblDANBgkqhkiG9w0BAQUFAAOCAQEAsre/1aUSAAo9bV7rYksGRiCev7VWIxQo\nedcLShMNCBNB9/ozjHtc84J70ONzGPT8oluEBIv5Pl6A0E1RdOjEcnqlvC0Xy0Ad\nu2MmVCM59MNhPMhh8IeBwLcX5jXTOWNvus/Z1rN4NNvYUoPZ9V4+ghAhE09qWSXG\n//NXO1nEPxaPOvs7mwS74gevi6bcbhDULdLWm9Sh6h8La66MHL88QlLHoY9wNCJw\nxAS3RyWn29BJ1tVJtSzAQZLzUtL1XisTFaGHGcCxEgG0+JkqxEl5zi2gGcYxkdpq\nUaFs0ulwkp2uVhPCL1SV0KFnIWeKpY9rkcacQlpaDxwK5TKUnmw3zA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=vfu-gemdev-sp01"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "vfu-gemdev-sp01"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAM2DRYvk1gHoMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD3ZmdS1nZW1kZXYtc3AwMTAeFw0xMjAzMjMxMTIzNTVaFw0yMjAzMjExMTIz\nNTVaMBoxGDAWBgNVBAMTD3ZmdS1nZW1kZXYtc3AwMTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAMNWXQiNwZrd5EpYMZEYbTTQAGLIHPuAgzAf5mrjnyXF\n+811k0uJova1/Jsb1TYyua5Ti5SncDIKsLZFFpxbIHF7Yq22r4bmrYdsQ9bTeifc\nNlMjY/N9we9x/07LmxMopbAZEHbwm7b/xsoSpJ6uGs6wRSxpBejGmB9t5BhQzNN2\nicp/H89hzyOqyzAMl3O6SirdVh/cNqFBAlnVS21Nryy1wWZMr3w0HhkbkEz6Zanz\n6KtWI3IFqeHOhPomiVaWquTp49pGO43cwHb6Tx1h4h+OSqCN9TazA8nOJ0PMAUMp\nNnPgWQW6SO13nVAcHihIDPfoYvD/wW2CYJjUT5OzjqECAwEAAaM9MDswGgYDVR0R\nBBMwEYIPdmZ1LWdlbWRldi1zcDAxMB0GA1UdDgQWBBSEdlf3VKcDHEXFAgPS21B9\nV+cblDANBgkqhkiG9w0BAQUFAAOCAQEAsre/1aUSAAo9bV7rYksGRiCev7VWIxQo\nedcLShMNCBNB9/ozjHtc84J70ONzGPT8oluEBIv5Pl6A0E1RdOjEcnqlvC0Xy0Ad\nu2MmVCM59MNhPMhh8IeBwLcX5jXTOWNvus/Z1rN4NNvYUoPZ9V4+ghAhE09qWSXG\n//NXO1nEPxaPOvs7mwS74gevi6bcbhDULdLWm9Sh6h8La66MHL88QlLHoY9wNCJw\nxAS3RyWn29BJ1tVJtSzAQZLzUtL1XisTFaGHGcCxEgG0+JkqxEl5zi2gGcYxkdpq\nUaFs0ulwkp2uVhPCL1SV0KFnIWeKpY9rkcacQlpaDxwK5TKUnmw3zA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=vfu-gemdev-sp01"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vfu-gemdev.it.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vfu-gemdev.it.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vfu-gemdev.it.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vfu-gemdev.it.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vfu-gemdev.it.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vfu-gemdev.it.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vfu-gemdev.it.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vfu-gemdev.it.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vfu-gemdev.it.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://kilw.ki.se/shibboleth",
    {
      "entity_id": "https://kilw.ki.se/shibboleth",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Karolinska Institutet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ki.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "KI"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://kilw.ki.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://kilw.ki.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://kilw.ki.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://kilw.ki.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://kilw.ki.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://kilw.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://kilw.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://kilw.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://kilw.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Proxy mot Ladoks uppf\u00f6ljningstj\u00e4nster"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Karolinska Institutet LW-proxy"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "kiladok01.ki.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJALIjJ4W5G5NlMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2tpbGFkb2swMS5raS5zZTAeFw0xMTA2MDkwOTE3MzJaFw0yMTA2MDYwOTE3\nMzJaMBoxGDAWBgNVBAMTD2tpbGFkb2swMS5raS5zZTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAKaPBu20JzB9Ko3IQNSei/zbfY2N75RUATikwdmju6Uy\nlIFdSbQCsEl6o1mktZysNrUL2tj6l45kDZmaCxvKakuC5bIHQY9E8kWHdrXHTxEx\nQCDw6+NSHcRzJwKpUQZKVz7YdTNl+7qnoqpQpVYTB7aPMXn71xDHIspRg6RtJvly\nFH1ADlRyVuiUd/CKvp4b6UBOMmnHgbdKSaY0N362Ks0wmw13ZMc4O9QChgx4R33R\n4ooNV79byMtJ8RPomTNMTlVAnsSMFjXh3yNzxra7zGQnUAlzXyY5+rH1kaRqstfr\nXyxVg9nlvv82gsczPxXl0kexWh+DW3wB9LtflKkCyA0CAwEAAaM9MDswGgYDVR0R\nBBMwEYIPa2lsYWRvazAxLmtpLnNlMB0GA1UdDgQWBBRzCPPEABQ2vMTzaw86FhJS\n/qGq9DANBgkqhkiG9w0BAQUFAAOCAQEAgcz87bN6b0aAbEceZR+bmbAHDrcU5bA2\nZ7LQt+PWQDeXS3WCf7xwGxHSUEer9gP078Zo1Z72UMnowQW4Fuwrp/lAOVhsAGPZ\ng10njIwKk9oi69hIgjoU+YD03Zt2zglrkOFoSH4Gy2QbmIiF3ihSjiY/eYtrDQhr\nyPAkIV8gl8A16so6D364fbNuF9ay5ONY3J+P20Scmuhuel55KdEnR1SIxdQ0Fml0\nXBbBB8yIgXxH5y12cJA0350DeuLjV2lI+Vwo+cHc4l4Iy60nCmU/AhOPsrn/KSol\nD1QNfeY/pFOqpfSxgp64TIVe9v9UJ7QJRm7zh51LDEjqyJwd/xxNyA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=kiladok01.ki.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://kilw.ki.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://kilw.ki.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://kilw.ki.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://kilw.ki.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://kilw.ki.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://kilw.ki.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayf.supportcenter.dk/sss/saml2/idp/metadata.php?unit=sss",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayf.supportcenter.dk/sss/saml2/idp/metadata.php?unit=sss",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2010-08-17T13:59:19Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayf.supportcenter.dk/sss/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sss.itsf.dk"
              },
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Social- og Sundhedsskolen i Silkeborg"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Basic Health Care College Silkeborg"
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Social- og Sundhedsskolen i Silkeborg"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Basic Health Care College Silkeborg"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "sss.itsf.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfQCAQcwDQYJKoZIhvcNAQELBQAwTDFKMEgGA1UEAwxBaHR0cHM6Ly93\nYXlmLnN1cHBvcnRjZW50ZXIuZGsvc3NzL3NhbWwyL2lkcC9tZXRhZGF0YS5waHA/\ndW5pdD1zc3MwHhcNMTUwMTAxMDAwMDAwWhcNMjUxMjMxMjM1OTU5WjBMMUowSAYD\nVQQDDEFodHRwczovL3dheWYuc3VwcG9ydGNlbnRlci5kay9zc3Mvc2FtbDIvaWRw\nL21ldGFkYXRhLnBocD91bml0PXNzczCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBAMeIDApqEFO4jhn4gnWuA54SIILLdtH1Ah7cGkKx6MUJTmtLORYA2pW5\nzU8N+nQl0hmGs9eyYMlAyaJ08IY8gNAqj5uT5p/f4RQVL8j/7fmxIFfa9/6HUMe9\nlX2OzOealJWOnsdn9ag9YHKRYEk7QA5WbMHnOVqqRLfonvr7DF6vB2m4TFWdhI13\nvdL4DJP8Rn61cA77qVDwUv9gyUmdSRJpKotIcXLTUPaoE2ZhHAGkJLr91RnLGLS3\nmPyCEpQPgEc5lVq+frknrZwl1eI5wxHJQAinnsZdCsvrcq2uMhxd12r4JnJnm3fs\nR1Q4jPjaOgVzLvcwU6e3KeUoS87DUEkCAwEAATANBgkqhkiG9w0BAQsFAAOCAQEA\njP2/I0Mu2SqJ93nB4rXgdV5mSzWsFB4q7bkfA1Ra7XYzfSpGOvMHcqaaKcAchA1O\nyfx9LLQMEEBwHkR7pYk7LtaMcvkNVHkIJE7dtkhA2jDXzagwBAWqu8sYTxDjNjDJ\n7aZ+zaVDTBlH0rTmv4Vv2Qtyuw1KhOdYwGIcyHj59TYIVXXsPkGdpjZ6E9A+oN+m\nyXhtHaPq2WoDER6YZ1zcW2kp0iXpVku3TQo4oQhV65uC37g0748riJRED3HuCw+R\nSASmcxjMh0wZ/egIWQ4X3KUVvSPR+A5TJ5uS4KsccZMTb1ICyaUs7skEEWHkbPxO\nZ0FIk7cDlCfAO6WS9Da4VQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Social- og Sundhedsskolen i Silkeborg"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Basic Health Care College Silkeborg"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sosusilkeborg.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sosusilkeborg.dk/?224"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Social- og Sundhedsskolen i Silkeborg"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Basic Health Care College Silkeborg"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.utb.uppfoljning.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.utb.uppfoljning.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.utb.uppfoljning.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.utb.uppfoljning.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.utb.uppfoljning.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.utb.uppfoljning.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.utb.uppfoljning.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.utb.uppfoljning.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.utb.uppfoljning.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.utb.uppfoljning.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.utb.uppfoljning.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.utb.uppfoljning.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.utb.uppfoljning.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.utb.uppfoljning.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIJAJRuttYMy/CdMA0GCSqGSIb3DQEBBQUAMCcxJTAjBgNV\nBAMTHHd3dy51dGIudXBwZm9sam5pbmcubGFkb2suc2UwHhcNMTUxMDIzMDgyNzE0\nWhcNMjUxMDIwMDgyNzE0WjAnMSUwIwYDVQQDExx3d3cudXRiLnVwcGZvbGpuaW5n\nLmxhZG9rLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAlHyyl8lw\nwkevAYlRJiSqa3yaCbU8D5cUNH9mIPojH1kfb1QXByscQPc9MwGR0tDl67o4+qr8\nf51okBl4+C/AfkGgsc2C+jvPhO/p16Uzw9AXCSN8Nzl+RHBUhONYOKgQA4OaRxOI\nAs/rvAYZQEmqVoENANdNNJRi0Tqwqo9FxlX4q9XHwx+53oOfeXVMetMAi/uU75OT\nYCPW5F0Y72XQ2QPZkRNsqYK1IVqMCsgXS1VPiuqCyWHdUhesYC+S2279QrP2sXcJ\nxiQhohE7dY2vdgHLmQq+T2YERVIoGqCNxvKQ4JPeVr9MPVAN1uiJ3wiPpLxh4VVs\nOa7beN4vr+KboQIDAQABo3cwdTBUBgNVHREETTBLghx3d3cudXRiLnVwcGZvbGpu\naW5nLmxhZG9rLnNlhitodHRwczovL3d3dy51dGIudXBwZm9sam5pbmcubGFkb2su\nc2UvZ3VpLXNwMB0GA1UdDgQWBBTUNZ+hmTCzgsSS3vs4dxj8Mm5kuzANBgkqhkiG\n9w0BAQUFAAOCAQEAkEPx2U0iQ4NfF+ixzf0LOBUT8njxb8lHfX4PjqinJS15N4si\nxGispD9fabYPNVGK500/Md/4Gl6MrPhsxbAMcRn9FL962JiuTccfsecGAv5+4BKY\nIjBj97jbFJ2fhsQBBaevgfNP2wLHsyQheQgAXY72cCG3OaZeTMMNECb1FG1MhvRt\nZvdcx+ES1HMOgLCAU2BF/oYnuuGhwOI4H6jabKK44GbWeE0Mv8L/A5knUoujfR0n\ngUbDaBy4oNdSbv4VXVLXLD6XwwzJNfn8TGE8LQh3pvSAOdiTz4ie2ybYfXI2VKVG\nIgTd2o/JWpObjIU/AurReC6h+UPQ4M3O3lBYFA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.utb.uppfoljning.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.utb.uppfoljning.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.utb.uppfoljning.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.utb.uppfoljning.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.utb.uppfoljning.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.utb.uppfoljning.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.utb.uppfoljning.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.utb.uppfoljning.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.utb.uppfoljning.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.utb.uppfoljning.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.cityofglasgowcollege.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@cityofglasgowcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Landi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:marco.landi@cityofglasgowcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marco"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cityofglasgowcollege.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-06-02T14:34:09Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZjCCAk6gAwIBAgIVAI38uSRnFA9tDvzGsjh8FcUJn5XSMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCkxJzAlBgNVBAMTHmlkcC5jaXR5b2ZnbGFzZ293Y29sbGVnZS5hYy51azAe\n\t\t\t\t\t\tFw0xNDA1MTkwOTIyMDVaFw0zNDA1MTkwOTIyMDVaMCkxJzAlBgNVBAMTHmlkcC5j\n\t\t\t\t\t\taXR5b2ZnbGFzZ293Y29sbGVnZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBAJthr2byyj0MBLQhYUMjKtn4jUJzN+1/3bzxFjCYtgPf6rQqhG2e\n\t\t\t\t\t\tgaoOkDx2r3Tqq/Rh66oQYqqR/+T02JzQKFaUrYllBNDLRmoY6ks52ayLTrhY3kZy\n\t\t\t\t\t\tVYntEzsKiRZ15lPMDxGs/LpyXoxW2DfWhUF6clXeyTUJwLBVSM1eHvtXcaMpf85F\n\t\t\t\t\t\t+F3zfdt+ReHqBM2gzy/6zN9QPi3u6UUSDkKHjkxjnn4Uf2vyo8WREjildb4Xdon2\n\t\t\t\t\t\tTf3Gmg3zfLgs0qZI2X5+Z/KbSu+Dp1MjnannE+MKoqPU6cjc13CFxXR3CDozwrAc\n\t\t\t\t\t\t8O7tJktCHDTMqkBEwFCijV70OTukkapjP8ECAwEAAaOBhDCBgTBgBgNVHREEWTBX\n\t\t\t\t\t\tgh5pZHAuY2l0eW9mZ2xhc2dvd2NvbGxlZ2UuYWMudWuGNWh0dHBzOi8vaWRwLmNp\n\t\t\t\t\t\tdHlvZmdsYXNnb3djb2xsZWdlLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQW\n\t\t\t\t\t\tBBRAcYAdOlKRaOjN2yAIoJy7Q1hAyjANBgkqhkiG9w0BAQUFAAOCAQEAQTWIeg+3\n\t\t\t\t\t\tVunEEEvdbvvhcDwMJkzK+AXoCMU9CwXn0fIpjNCV9/sGLdKLJr9RlYk3mnOWRwR6\n\t\t\t\t\t\tJNWOWRBe9OVw7t59LY0orNSLGR6hK1lv74P7sjmwy3wOuN1suPGYkgj9Z20n7Q/j\n\t\t\t\t\t\t3P5yoL9o3OR5qheUO1q/nB9BSf3PZMWtgGHuas4xd9H611JaFXn3Twol6IZfqfjP\n\t\t\t\t\t\tJTx/ZE9prDzEYog9nZyWMrazcMRg0ZKNvgd7vuk6x8VIZYTUYONQ2h0h+Crz1dz6\n\t\t\t\t\t\tIKiRu3CJ7CUBlfqfhvOAlSfA6aPZZK7UqVXaB2JNlw2gqvoms/9/WAiph1lk6kSj\n\t\t\t\t\t\tjatFpe4qgOFjPw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cityofglasgowcollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cityofglasgowcollege.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cityofglasgowcollege.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cityofglasgowcollege.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cityofglasgowcollege.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cityofglasgowcollege.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.cityofglasgowcollege.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cityofglasgowcollege.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.cityofglasgowcollege.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cityofglasgowcollege.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cityofglasgowcollege.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cityofglasgowcollege.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cityofglasgowcollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZjCCAk6gAwIBAgIVAI38uSRnFA9tDvzGsjh8FcUJn5XSMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCkxJzAlBgNVBAMTHmlkcC5jaXR5b2ZnbGFzZ293Y29sbGVnZS5hYy51azAe\n\t\t\t\t\t\tFw0xNDA1MTkwOTIyMDVaFw0zNDA1MTkwOTIyMDVaMCkxJzAlBgNVBAMTHmlkcC5j\n\t\t\t\t\t\taXR5b2ZnbGFzZ293Y29sbGVnZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBAJthr2byyj0MBLQhYUMjKtn4jUJzN+1/3bzxFjCYtgPf6rQqhG2e\n\t\t\t\t\t\tgaoOkDx2r3Tqq/Rh66oQYqqR/+T02JzQKFaUrYllBNDLRmoY6ks52ayLTrhY3kZy\n\t\t\t\t\t\tVYntEzsKiRZ15lPMDxGs/LpyXoxW2DfWhUF6clXeyTUJwLBVSM1eHvtXcaMpf85F\n\t\t\t\t\t\t+F3zfdt+ReHqBM2gzy/6zN9QPi3u6UUSDkKHjkxjnn4Uf2vyo8WREjildb4Xdon2\n\t\t\t\t\t\tTf3Gmg3zfLgs0qZI2X5+Z/KbSu+Dp1MjnannE+MKoqPU6cjc13CFxXR3CDozwrAc\n\t\t\t\t\t\t8O7tJktCHDTMqkBEwFCijV70OTukkapjP8ECAwEAAaOBhDCBgTBgBgNVHREEWTBX\n\t\t\t\t\t\tgh5pZHAuY2l0eW9mZ2xhc2dvd2NvbGxlZ2UuYWMudWuGNWh0dHBzOi8vaWRwLmNp\n\t\t\t\t\t\tdHlvZmdsYXNnb3djb2xsZWdlLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQW\n\t\t\t\t\t\tBBRAcYAdOlKRaOjN2yAIoJy7Q1hAyjANBgkqhkiG9w0BAQUFAAOCAQEAQTWIeg+3\n\t\t\t\t\t\tVunEEEvdbvvhcDwMJkzK+AXoCMU9CwXn0fIpjNCV9/sGLdKLJr9RlYk3mnOWRwR6\n\t\t\t\t\t\tJNWOWRBe9OVw7t59LY0orNSLGR6hK1lv74P7sjmwy3wOuN1suPGYkgj9Z20n7Q/j\n\t\t\t\t\t\t3P5yoL9o3OR5qheUO1q/nB9BSf3PZMWtgGHuas4xd9H611JaFXn3Twol6IZfqfjP\n\t\t\t\t\t\tJTx/ZE9prDzEYog9nZyWMrazcMRg0ZKNvgd7vuk6x8VIZYTUYONQ2h0h+Crz1dz6\n\t\t\t\t\t\tIKiRu3CJ7CUBlfqfhvOAlSfA6aPZZK7UqVXaB2JNlw2gqvoms/9/WAiph1lk6kSj\n\t\t\t\t\t\tjatFpe4qgOFjPw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "City of Glasgow College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cityofglasgowcollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "City of Glasgow College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://nhs-shib.hosted.exlibrisgroup.com/shib",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://nhs-shib.hosted.exlibrisgroup.com/shib",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-03-24T14:40:19Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cardiff - NHS - Primo"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://exlibrisgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ex Libris (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nhs-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nhs-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nhs-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nhs-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nhs-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://nhs-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Cardiff - NHS - Primo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAKcM8Bu1ZURlMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB2FpbzAwMjkwHhcNMTUwNDAyMTkyMzI3WhcNMjUwMzMwMTkyMzI3WjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdhaW8wMDI5MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tp9TB2B6ZVcE0YXR+6D+OaMqqF1NRHYWMQb+tVAf3wIz9VlTyKGuEcq3qs8kudbc8\n\t\t\t\t\t\tXfgR4C9fklmDeP356bFkPJEv2mLlNlLTwytcsjC3h+Lkg5YdQ1k7BRhZBd7AonZA\n\t\t\t\t\t\tV5wo5oqjug3MJaSKqeWW/ixf++u8OjmY4phwvcxyFTKlyMzBU/gWj392GKVJadZK\n\t\t\t\t\t\t4daAKFszh0a/M5Oxh59Npax08GLp3LDqnAYMCI8TSjY2+7qJzcMPkOyS2x1C5Wn/\n\t\t\t\t\t\tP475YDhN4/0BKcdbZVO44m6c+dsH7eNvmufWpxKzLZqBQ1oUFIIpaDb2yLXH4izt\n\t\t\t\t\t\twZslyX/4dquLe6NSK7UFPwIDAQABozUwMzASBgNVHREECzAJggdhaW8wMDI5MB0G\n\t\t\t\t\t\tA1UdDgQWBBRrShcAeaU6zh2MSQQFy6m90evNQTANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tA9yiTshpLhPQp9qICL1S6LXCtT0DR7EyvEnw7EsIrX5o4j7bpFe6ZVvp903LtXld\n\t\t\t\t\t\t2fHtqsndLHeaRyn26JWT+7uJ8oYQgREecGP+ruHRo2slTjk5Iyn2/C1d5+1egAgR\n\t\t\t\t\t\tEJ22wmfiVA6c2BIzCDYgRZ+revX9LIjaPuKXxDFVWJPGecJjOXXszHe907wd6HNp\n\t\t\t\t\t\tHWo35M04rRkchlPmc/Xzcb+oPqBNas3/5uINUWRqbWKfyvQ2NodO9Pc6aDQ07Tux\n\t\t\t\t\t\tOqPrbuYFYgPfLjGriXZYQRplICtMyCzzOMhYCdfJ1ic5/HOBikOTFjMgPHht3Mq+\n\t\t\t\t\t\tdyeKZ7Et4QKnh9FjfMCOCg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nhs-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://nhs-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nhs-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://nhs-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://nhs-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://nhs-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://test.ed.unidesk.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:IS.Helpdesk@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-certs@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Application Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test.ed.unidesk.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-04-02T15:42:38Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Edinburgh: Unidesk (Test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.ed.unidesk.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://test.ed.unidesk.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.ed.unidesk.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.ed.unidesk.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.ed.unidesk.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.ed.unidesk.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://test.ed.unidesk.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAKOQZJ9XeRRZMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\n\t\t\t\t\t\tBAMTEnRlc3QudW5pZGVzay5hYy51azAeFw0xMjAzMjIxNjUwMTdaFw0yMjAzMjAx\n\t\t\t\t\t\tNjUwMTdaMB0xGzAZBgNVBAMTEnRlc3QudW5pZGVzay5hYy51azCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBAPweFLYNELDowDm8YWp8G8RKR0q+ufgUN7H7\n\t\t\t\t\t\th7RTesgxlO9T8wXLT1e4s1ruCVrYtkt8q3K+iXukZ+J5QD4lMtvWHfbpKJNddygG\n\t\t\t\t\t\tRkURpJQ7bY1rTdWA6jNi16TR+8M2ECIf4Q6CVukHHrX9PuZM+b7Ktg2gf3fmy7vQ\n\t\t\t\t\t\tMQ2/2Rp8/LKGKotVAoRYrNc8y3Y2PR9omsidxNGyyXxfD2OyTobuk1Ezb7Fk4Oq+\n\t\t\t\t\t\t4VmetrJ5CwFOwTBmFUgfaazuooEvGM7tA/jjRGDY5H+4oyVDK63Ktf59pwGln6Bo\n\t\t\t\t\t\tJyBfJIWYK/5w3psQJZCFyNgJ4WQSgxbAiORGQPZLfKxsvAaGD2UCAwEAAaNAMD4w\n\t\t\t\t\t\tHQYDVR0RBBYwFIISdGVzdC51bmlkZXNrLmFjLnVrMB0GA1UdDgQWBBRxsmQCxZXe\n\t\t\t\t\t\tbZvQMvehqWxt1yHYijANBgkqhkiG9w0BAQUFAAOCAQEAtOWghRw2KKVvYbX0sQEX\n\t\t\t\t\t\tVDYPpi4Q1q6b1vl/MK0WU+zWjOmuljIIw377NOuH+A8zwJF2maelKlEHFmlMg8nl\n\t\t\t\t\t\ta8MPTIQIhgJ3baXwfy5jvEIQrK++0LwaFiBdwg0dM3er6pyODVypn6oNpKY9gcFA\n\t\t\t\t\t\txCl05pTEBIWPAxFNcvYj/liPrDC8RcEBpnEiGZcJgvPGCulXV3O9FCRkoyTaVoUB\n\t\t\t\t\t\te42UmPVs7zqOGsBy6ZcHRGoD53VWtkvax8iBGBobK0fGICh6vyX7Qb6Me3r/7S1h\n\t\t\t\t\t\t6WUcF/Nm7P5V6V2an8MJPYyIVNn6QorTplFsBhK4/Wr+Xb4JIurIwCWDqbVIYo1j\n\t\t\t\t\t\tTA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.ed.unidesk.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://test.ed.unidesk.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.ed.unidesk.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://test.ed.unidesk.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://test.ed.unidesk.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://test.ed.unidesk.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth3t.lsbu.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "James"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jamesbe@lsbu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bethan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Swigg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:swiggtc@lsbu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tom"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth3t.lsbu.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-02-23T11:48:22Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth3t.lsbu.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth3t.lsbu.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth3t.lsbu.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth3t.lsbu.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth3t.lsbu.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth3t.lsbu.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lsbu.ac.uk"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "shibboleth3t.lsbu.ac.uk a test server for shibboleth 3"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www1.lsbu.ac.uk/clsdresources/libimages/ShibbolethLSBULogo.png",
                    "height": "80",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "London South Bank University Shibboleth3 Test Server"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRzCCAi+gAwIBAgIUE/fT/9pMSO/v5nE3rz+9rwFT5wgwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwIjEgMB4GA1UEAwwXc2hpYmJvbGV0aDN0LmxzYnUuYWMudWswHhcNMTYwMjE3\n\t\t\t\t\t\tMTEwOTI5WhcNMzYwMjE3MTEwOTI5WjAiMSAwHgYDVQQDDBdzaGliYm9sZXRoM3Qu\n\t\t\t\t\t\tbHNidS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANYE0JxI\n\t\t\t\t\t\tH5PD5Fz76qlumRg8TBABA962mUd07WYtvYRWsbZTms5ny+85y0Na2DRaBAiyyHJp\n\t\t\t\t\t\tVzzywQffXZ3GrLGLO3EzVTjnObEB04/zhcMASdehCkOJ/BOYD/zN+82ku6gI02Je\n\t\t\t\t\t\ttvEAUhnuN66BrX3UfTlHNFqRQZapCAtcqxH/qY47R2VerpRS6lJXubODIjoxC3Td\n\t\t\t\t\t\tI0sTiTym6AuuyjCwnLrxnl3e+dSyw7MU64ef8PbepJ/44EMlfJImkZQK1KVkaKM8\n\t\t\t\t\t\tZpQ+hJC6l7B1S2mfo8kC2ahRBx+AQ7Y/H46OznRdb/3fiZQsyCCwy5mRpNEXmzKc\n\t\t\t\t\t\tMMuvofZWxtoBF9UCAwEAAaN1MHMwHQYDVR0OBBYEFKxy131G57Lv3A8LhxONlprK\n\t\t\t\t\t\tFeugMFIGA1UdEQRLMEmCF3NoaWJib2xldGgzdC5sc2J1LmFjLnVrhi5odHRwczov\n\t\t\t\t\t\tL3NoaWJib2xldGgzdC5sc2J1LmFjLnVrL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBCwUAA4IBAQCI1MBOhIjpCXeMIMFuVinhfL5vudiVu4BLoicYtyWP+ptJMzhl\n\t\t\t\t\t\t7V2aoI3c9vWzMnD85z6MFvOH2makEkJnH7UZBhBwdhPMhgg5gBUv0lgjMArhgkMM\n\t\t\t\t\t\tzoFAX7b+svs2Uo7Ubf9oY8oANzozvJJIez9MjF0xuWV52hCkGMHzIggU3BGjDh8b\n\t\t\t\t\t\tnY1W3UyHiEJ/flSPPgYZugYqk4rCPGs0RXofHFFF+YwHXhc5GOFRmnp55MKUy3cS\n\t\t\t\t\t\taYrSsA4SIpO2p2XH139JUCYRdqe1bwdkRR0vZC+Ptlamgy9+b41Khs++0leMZyCp\n\t\t\t\t\t\tsVe7a6G/u+7AFOngbpVv9w0jzNUnUFfcBHwE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRzCCAi+gAwIBAgIUS+bn4hDHkAGNq6o7sEADhOt+uiswDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwIjEgMB4GA1UEAwwXc2hpYmJvbGV0aDN0LmxzYnUuYWMudWswHhcNMTYwMjE3\n\t\t\t\t\t\tMTEwOTI4WhcNMzYwMjE3MTEwOTI4WjAiMSAwHgYDVQQDDBdzaGliYm9sZXRoM3Qu\n\t\t\t\t\t\tbHNidS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIzm6jEM\n\t\t\t\t\t\t6C3QeBwI5L30N0ZA6cA88/GIyyeoEWSMeiuKzV5LNMAMnycHTxiftkq8pYc+Hafr\n\t\t\t\t\t\tOv171xzh68x74Bnsz4kVSUmzFdN1qJDesJn9VIHEBRecxlgzq8u4W9nKTeuhHqAv\n\t\t\t\t\t\tpYO3Zn+0TbhRMdTYEExXE7DmeEbvuG1cIs/WVV0XGGGlMKRfp/iHWdf6FqsTC3Y6\n\t\t\t\t\t\tBAf9trJzqcbjbqjyZw+FGtxeaBe1IRUXu5wTtEAitXgec6L1wO0OZchAlUn7dOPC\n\t\t\t\t\t\tBgpGXS3BTwjIZKi5ta7WRUY61Jl7FWEOTvQ8KecaLIxHBReUOKP5IecMZ9CTG75c\n\t\t\t\t\t\tEhfMGF+kxi8scqECAwEAAaN1MHMwHQYDVR0OBBYEFEw72+rdRAtd18zDFMbeSk3E\n\t\t\t\t\t\tWrpcMFIGA1UdEQRLMEmCF3NoaWJib2xldGgzdC5sc2J1LmFjLnVrhi5odHRwczov\n\t\t\t\t\t\tL3NoaWJib2xldGgzdC5sc2J1LmFjLnVrL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBCwUAA4IBAQAw+dwocFHw82gDHR+utBMUMRdorJ/R8HgSEMkQhTFvPLKCiZAg\n\t\t\t\t\t\thcjhDjgsWojPpWDxncJUdVp5cATL/jvLK8slAQi0QDQKybJvvdC1IdS/hh++ZnEg\n\t\t\t\t\t\tG+MZgaWZFT5ZUph90aHXMCq+ApCmz9zmHfUI23c0NrCYUUBkqjE7LvZDrWdwjs3z\n\t\t\t\t\t\ts0vldCW71QyFN10OeGz1yHAwIoge72BdMO0qg8T2VDGYm+xpF9jd2osnsu2mPyGi\n\t\t\t\t\t\tBbf3A4EFzN/y5UzHcSYtDcK8cYDj3Uysx0Kggc9RLkWKh+OyEssxCNlgb+bE3coW\n\t\t\t\t\t\ttGrLYFmeRvM/llGe2Z+2PTPmBu7g8e0bsJOn"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRzCCAi+gAwIBAgIUBKlrJrjzS1nUF+AXlA8lmcYlmG4wDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwIjEgMB4GA1UEAwwXc2hpYmJvbGV0aDN0LmxzYnUuYWMudWswHhcNMTYwMjE3\n\t\t\t\t\t\tMTEwOTI5WhcNMzYwMjE3MTEwOTI5WjAiMSAwHgYDVQQDDBdzaGliYm9sZXRoM3Qu\n\t\t\t\t\t\tbHNidS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALnSoR13\n\t\t\t\t\t\tit8YwBxHcVrEs2tP4x45Hg0i0xL6ilSLs7X2mvEpZ5W7X1aB9EKfAHqO4OzQ0L9e\n\t\t\t\t\t\t/dWRISvqC918mhOaxbWYbZvSApljdxZFVgqxGJifj31KuBpbFyS2LGFTMbS5MHmn\n\t\t\t\t\t\tZWO8WfcvWv8+hXDw5epLJQ5bEb2hRx54FqPnAg+yTEGeekHR2KDTg03dx55yX73J\n\t\t\t\t\t\twMqDehSr4VGC93VIHbMcgaJpHiW/YOB6oCwiaF/s2iDb65xk54zzK3Sxc0Mzfz6n\n\t\t\t\t\t\t6oKjPY9VSARj+cecwvH+s3o/Sq2Rrpk6aQw6VZjvNeFMLCStlXGJ7zrSq4C9+KW1\n\t\t\t\t\t\tXYbeL5cWYNRl91ECAwEAAaN1MHMwHQYDVR0OBBYEFOh/DY8N02hFIqriX3sa2TPb\n\t\t\t\t\t\t8Zb/MFIGA1UdEQRLMEmCF3NoaWJib2xldGgzdC5sc2J1LmFjLnVrhi5odHRwczov\n\t\t\t\t\t\tL3NoaWJib2xldGgzdC5sc2J1LmFjLnVrL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBCwUAA4IBAQCKVSrLJFUvi45vEH/3kuI+VbR09u7lsWuxJl//1d1nTbmth2DG\n\t\t\t\t\t\tU8t4egS3PauglK1fcnA/dVr4cc+s2qv+dHL+WTLbmyG9/YZHb4VEKyZGTyHEABCR\n\t\t\t\t\t\tsgn6uGVhlEx7y68ub3r06qnXLCzURihljCS7T/klT/obE9YikK7xYsLS5nMHbfr0\n\t\t\t\t\t\t9avBIjzA912sKqr8NN7lHY2V16/ObacWAKMXtvAzpnmUoYxNFvQC//q23o9+P7t/\n\t\t\t\t\t\tFvDijCjqTEo3JeTvKJxdiF7wGCiuIWw0iOscp1vSmBgJnpr9jECB3v24PflxzpzJ\n\t\t\t\t\t\tZrKdJ6BC/BQX0WPYD5TrOObIbg3wh61P7mSA"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "London South Bank University Shibboleth3 Test Server"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lsbu.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "London South Bank University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ec-lille.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jonathan Chatriot"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jonathan.chatriot@ec-lille.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ec-lille.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-04-02T09:29:58Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ec-lille.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ec-lille.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ec-lille.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ec-lille.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ig2i.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ec-lille.fr"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Centrale de LILLE"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Centrale de LILLE"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEmDCCA4CgAwIBAgIQcy0ZZwSdmc+3hWilVNQxZzANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMjAeFw0xNTAzMjMwMDAwMDBaFw0xODAzMjIyMzU5NTlaMD0xITAfBgNVBAsT\nGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEYMBYGA1UEAxMPaWRwLmVjLWxpbGxl\nLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvIvmvu5jWlZn0Eva\nR1CvZIIeGgeXJviar84SKY7g5zXrKtKw2036rCkEw+cTCum8DIVhd79V4fo7SO7X\nwIqPc+fGO+hI3vxQGCcPSwCQOXEK+1/+4mWhFqhaMlLvZdXb80gKTJWPCV6TumcU\nDdEFT01R/+HUvPvD+LZocS0zsdKRLxKoeiiLWiN9reHMh4J4awZTTBzqLVCMfnV0\nhnlH028J8iN+/eMSTz9BycRnJ2exLtGdBL5ovRS8djKHYfCv+AXlHAR6Abyb4Uwv\nMiLUDk7HTqFQ0pf+Eh/y5NTHZSmgCj8UluRWE8OiBKBcxx7S/kz4+gULJoYu9WTi\nnRvN3wIDAQABo4IBazCCAWcwHwYDVR0jBBgwFoAUW9CKHJoyW+C13ZZUG+GGKLD9\ntr0wHQYDVR0OBBYEFFFdGtRc1Qnq/4/65VH9LwZZHNjRMA4GA1UdDwEB/wQEAwIF\noDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAi\nBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAxMC+g\nLaArhilodHRwOi8vY3JsLnVzZXJ0cnVzdC5jb20vVEVSRU5BU1NMQ0EyLmNybDBs\nBggrBgEFBQcBAQRgMF4wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudXNlcnRydXN0\nLmNvbS9URVJFTkFTU0xDQTIuY3J0MCUGCCsGAQUFBzABhhlodHRwOi8vb2NzcC51\nc2VydHJ1c3QuY29tMBoGA1UdEQQTMBGCD2lkcC5lYy1saWxsZS5mcjANBgkqhkiG\n9w0BAQsFAAOCAQEAjfGK/BTPOw5NI4lI8ui8Zn3W4k4gOg/LrfU9w4NS/ZLovbMH\nm+K8DLDLr1Z13vI39AxclUo6SkTJlXDkCUIMgkjSbEmXh7hUs5aHqw69dSCMeL9c\nD6bY0VzxOu6mwuzmqXWEZbGNrCIgzaCkgfVeza8Pic1qyZxVOfhhiOIdoKl4OZn5\nlOmT/ktPTXy+RT89JlL+Qx/89eRXDQuyZFBsSh3XMULUaR3KIR6mamS/O4rxOvGa\nCdxKtn2kD2HvpO5vJdrfiXRa9unqJZaT9Dx9huACKUTnXFPx5sOq659EvjN23Htt\nmSbHEPZCcinNQ9WAP2AgelqpJ6dm3OxPuWFe+w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ecole Centrale de LILLE"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ec-lille.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ecole Centrale de LILLE"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://rcm.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Knapp"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mknapp@rcm.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Knapp"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mknapp@rcm.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://rcm.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://openathensla.rcm.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://openathensla.rcm.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rcm.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDXjCCAkagAwIBAgIIPDy/aki2TD8wDQYJKoZIhvcNAQEFBQAwRjEjMCEGA1UE\n\t\t\t\t\t\tCgwaVGhlIFJveWFsIENvbGxlZ2UgT2YgTXVzaWMxHzAdBgNVBAMMFm9wZW5hdGhl\n\t\t\t\t\t\tbnNsYS5yY20uYWMudWswHhcNMTMxMDE1MTMzNDAwWhcNMjMxMDE1MTMzNDAwWjBG\n\t\t\t\t\t\tMSMwIQYDVQQKDBpUaGUgUm95YWwgQ29sbGVnZSBPZiBNdXNpYzEfMB0GA1UEAwwW\n\t\t\t\t\t\tb3BlbmF0aGVuc2xhLnJjbS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\n\t\t\t\t\t\tAQoCggEBANtJudIyT/BQLf6P2zHPfjH4YZIqzeMjC9WgCSjtRx/asbh+78VXuUwy\n\t\t\t\t\t\tpii28+E34wn1N0QtNx/03Bp3ngCAdm5l4WG0oB8l/prCKS3Y+Y/otrlBq9nF2NmX\n\t\t\t\t\t\taVh0f3PEGCFs5mCIoCMQlwZZrXBoRB+aqaCDo3jRwxoUDqWI76KMsXdPepMWwGD2\n\t\t\t\t\t\tqnXP22WWpvrvAJBBrlxJDa9RH48vYh6hiydfjx43wRbz6zlCCsRphZpZ6UQneUw+\n\t\t\t\t\t\ttKYrSMmKnaFFLEOzWov4slEqxwcGkq+KbF7pNRv+GHAZFmuoOR5y3+9OB1mpyU70\n\t\t\t\t\t\tjdVwT8X4fKAycVV1m0HwGrXniqL7RfkCAwEAAaNQME4wHQYDVR0OBBYEFB6LU7jQ\n\t\t\t\t\t\t5XlDoou/R5C0Amhjp0rXMB8GA1UdIwQYMBaAFB6LU7jQ5XlDoou/R5C0Amhjp0rX\n\t\t\t\t\t\tMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAGiCXJS6KYYdPOa16ONp\n\t\t\t\t\t\tYO9RxyV1UAJ4SWolE2othZv8HQHhH6lxlI9rOISOoBo8XkeSscrVAYMLA6fPM1aR\n\t\t\t\t\t\t8+X/Et65VWSZN52sI2oEFlXub3DmwFI77vd67QYt13jdrJQW9rLG4Jqf7XKjvtLf\n\t\t\t\t\t\tSwPhDfohab9O3yTxGcfxRLwgU1ZyNHOQMIz72ti085RavSLCsFOqy7hGE2DvZFrD\n\t\t\t\t\t\t01UxhUq4UgJxcsbvAMRjOJVsxJ1TowhnDxLNv67GSMTj83+5zZaCU0ZWvU9nTggB\n\t\t\t\t\t\tUztrSjOIxJq/HOK/cJv4DONOpL6wbJHZdA2trTfmm+YBc3cuBtPmhPcHEMfqSGS0\n\t\t\t\t\t\tUtc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Royal College of Music"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rcm.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Royal College of Music"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.wisc.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cholsman@doit.wisc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris Holsman"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "hazelton@wisc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Keith Hazelton"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@login.wisc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NetID Login Service"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tech@login.wisc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NetID Login Service"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "admin@login.wisc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NetID Login Service"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "security@login.wisc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NetID Login Service"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://login.wisc.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.wisc.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.wisc.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUEaB9lRXzHbDuhaiZVdnMYbZJAPwwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMObG9naW4ud2lzYy5lZHUwHhcNMTAwMTE4MDIwNzQxWhcN\nMzAwMTE4MDIwNzQxWjAZMRcwFQYDVQQDEw5sb2dpbi53aXNjLmVkdTCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBANS6cCAMOW+9Zo0FWAbmYH0OXIEIh9OD\ndABBZNCMD90g5/Xtls/oE3/jJxpVdyXMogKg6KcM90t5w9sP2svSqOQ3FAXWlnEK\ndsINxvnIb0hf7Jt+KKNdsq4gxySy6c3xdGeWwiRQunsd3xB6B9Ulg2+n6dJ5VfC5\nNlv3WERC+AcqvZ0/I0/FyWSJtRoNbIlrSP2avecaUYeyhKBHVD84h3H1afqF1b+E\niyzS29PFnI2PRoWYXZ1PGRZhM5fjU51KF43KmgXsMzjWo3l2T/jLpZqb6BcBI1kh\ndqubb4pzfmolbyptIAUNWDlNNVfSwzIxEk5RAkD2MIZxj+G8/gvjAf8CAwEAAaNj\nMGEwQAYDVR0RBDkwN4IObG9naW4ud2lzYy5lZHWGJWh0dHBzOi8vbG9naW4ud2lz\nYy5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFNKxQa0sDqRml8gWCQ7wdTTC\nwj8+MA0GCSqGSIb3DQEBBQUAA4IBAQB5mYeX11Pwrv+wDmBdcb22umAO3YJw4PtF\nZpjYiFxaANu5ldpxRj3NZ3kI4sYEDPhD533hGQ6u/uuiTCf0uHqPWzsXoITZeb7W\nUWvIucWwbEOq3m5KAaYUr6DcC3g5T+q3BFlJyY6HjEdZVv/kh/G888Nio7e/KUSM\nNa165r+kVLYSZDAQYPkB0/e6STvqf7L+NBewj4X+vsQy7ABpZAZI0cdJV0xmHzru\nU3y0KYm2vqpBEqkASp0sQSsFxpw9ogQPY/EFAMN+Nui5kzvCWNRkuF6KEJm32iP9\ni5LcnTHCgUUFH7J7EyAEl002xfE9jD8pK/2vObhH81f39z6ANpYw"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wisc.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.wisc.edu/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.wisc.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.wisc.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.wisc.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.wisc.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.wisc.edu/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.wisc.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.wisc.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wisc.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://login.wisc.edu/docs"
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.wisc.edu/images/logo.png",
                    "lang": "en",
                    "height": "150",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "224"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.cio.wisc.edu/policies.aspx"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Wisconsin-Madison"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUEaB9lRXzHbDuhaiZVdnMYbZJAPwwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMObG9naW4ud2lzYy5lZHUwHhcNMTAwMTE4MDIwNzQxWhcN\nMzAwMTE4MDIwNzQxWjAZMRcwFQYDVQQDEw5sb2dpbi53aXNjLmVkdTCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBANS6cCAMOW+9Zo0FWAbmYH0OXIEIh9OD\ndABBZNCMD90g5/Xtls/oE3/jJxpVdyXMogKg6KcM90t5w9sP2svSqOQ3FAXWlnEK\ndsINxvnIb0hf7Jt+KKNdsq4gxySy6c3xdGeWwiRQunsd3xB6B9Ulg2+n6dJ5VfC5\nNlv3WERC+AcqvZ0/I0/FyWSJtRoNbIlrSP2avecaUYeyhKBHVD84h3H1afqF1b+E\niyzS29PFnI2PRoWYXZ1PGRZhM5fjU51KF43KmgXsMzjWo3l2T/jLpZqb6BcBI1kh\ndqubb4pzfmolbyptIAUNWDlNNVfSwzIxEk5RAkD2MIZxj+G8/gvjAf8CAwEAAaNj\nMGEwQAYDVR0RBDkwN4IObG9naW4ud2lzYy5lZHWGJWh0dHBzOi8vbG9naW4ud2lz\nYy5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFNKxQa0sDqRml8gWCQ7wdTTC\nwj8+MA0GCSqGSIb3DQEBBQUAA4IBAQB5mYeX11Pwrv+wDmBdcb22umAO3YJw4PtF\nZpjYiFxaANu5ldpxRj3NZ3kI4sYEDPhD533hGQ6u/uuiTCf0uHqPWzsXoITZeb7W\nUWvIucWwbEOq3m5KAaYUr6DcC3g5T+q3BFlJyY6HjEdZVv/kh/G888Nio7e/KUSM\nNa165r+kVLYSZDAQYPkB0/e6STvqf7L+NBewj4X+vsQy7ABpZAZI0cdJV0xmHzru\nU3y0KYm2vqpBEqkASp0sQSsFxpw9ogQPY/EFAMN+Nui5kzvCWNRkuF6KEJm32iP9\ni5LcnTHCgUUFH7J7EyAEl002xfE9jD8pK/2vObhH81f39z6ANpYw"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://login.wisc.edu/redirect/support"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Wisconsin-Madison"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wisc.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Wisconsin-Madison"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://federatie.lumc.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://federatie.lumc.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-05-06T13:42:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/65b0296020f1f17d969eb6dbe232c4b1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Leids Universitair Medisch Centrum"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Leids Universitair Medisch Centrum"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/lumc-logo.png",
                    "height": "70",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "280"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Leids Universitair Medisch Centrum"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Leids Universitair Medisch Centrum"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Leids Universitair Medisch Centrum"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lumc.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Leids Universitair Medisch Centrum"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://aai-logon.bfh.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41 31 848 48 48"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it-support@bfh.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "BFH-ITS"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41 31 848 48 19"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Admins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai-admins@bfh.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAI"
          }
        }
      ],
      "entity_id": "https://aai-logon.bfh.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2015-05-13T09:43:11Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIJAPneN1luv6WBMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGFhaS1sb2dvbi5iZmguY2gwHhcNMTUwNTA3MTQwNTAwWhcNMTgwNTA2MTQw\nNTAwWjAbMRkwFwYDVQQDExBhYWktbG9nb24uYmZoLmNoMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA7GW/n7pU61p+pjImwqFMpIudeZxliexRwmcN8w6A\nMUpIAVoj0Csr9zhZfQMHVV4JGuDo2AVAwX1vvcFNR2qCoCmbQ8GgxX/B3MSc42dy\nbCHMhtxCNcvigqermkUG4mcFtEA4zbpJ+ILqPZ4rGiZfy/DaWYGEH2f8rFrXjC+H\nS0/oxnS9D7o/V/mCrAYEIErX8aAMQJJcw94YBIVGVs/Bv0AXJOgoL2YjDI8xINyd\npbED93BdwHb1ksfrNJH/t9/dc2GiRPx2Gv7E4zY30Zkm8KRjSAmkybQeyhfeoetw\nJUDA2cqWB39JCVg1VeSeJ2Voi48WrQqA54uRgUvbya+v8QIDAQABo2cwZTBEBgNV\nHREEPTA7ghBhYWktbG9nb24uYmZoLmNohidodHRwczovL2FhaS1sb2dvbi5iZmgu\nY2gvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFCF9TJLxvi9kSOejHvssZ6v1pMW8\nMA0GCSqGSIb3DQEBBQUAA4IBAQB/A5JSvw+YiWYL2qn9piA5kbNaX9q/uHyukcGa\nf2cWyCD8U1H3YYuDpGQevmNOaSHUzMGpGn9FKXOvjxBLotY7jH50ReFifcNalFs2\nDv1JnyrrHc3BsqHexZKoOupT2L3hadEhJdfTmZX3hQY4yqi/RNKlYbIC1t1SjEUN\nnnt3eVesg87paE+VMTFIBB6OO8iKD9hSLbFwOvsuasUURF8X1239cT6Kg0qFYXit\nOa8ckwETZviCoz1wPxbbdE+tYkZFObQkgkoeDvJ/zLLenx0Vrw7EE/cFcZuriBTI\nFHdGUwjqh5AdbYDl7t25yKp91OODdNaifm8UyA/veqsHrygR"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bfh.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-logon.bfh.ch:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-logon.bfh.ch:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aai-logon.bfh.ch/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai-logon.bfh.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai-logon.bfh.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aai-logon.bfh.ch/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-logon.bfh.ch:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-logon.bfh.ch:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bfh.ch"
              },
              {
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Berner Fachhochschule BFH"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "BFH - Bern University of Applied Sciences"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Haute \u00e9cole sp\u00e9cialis\u00e9e bernoise BFH"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABmJLR0QA/wD/AP+gvaeTAAAACXBIWXMAAAsTAAALEwEAmpwYAAAAB3RJTUUH3gQEDgYKIhOF+gAAANRJREFUOMtj/P//PwMDAwNDVt0kCAMLUFWQPhDiaVcoKyl6AV2OiYEIcPvBU4cJ89fue/z8tQFRBkx0y4djGPj+45fgtv0n69DVsuCyNX/XRAyxizfuBRLtBXQX4AIkuUBGQoS8QIQBL0fzRqIMwGa7haHmAgNN5Q1ku+DE+esJx89dSyA6GpFpGFi8Yc/8t+8/yZMdBgwMDAzHz19LIjoaiQFMpEQjSQbgAvqayuuR+YzE5EYYcLI06A/xtCvCmhI5Odjef//xSxBXdna0NJiILR0AAN4ETpBaPLgrAAAAAElFTkSuQmCC",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "58",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "BFH - Berner Fachhochschule"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "BFH - Bern University of Applied Sciences"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "BFH - Haute \u00e9cole sp\u00e9cialis\u00e9e bernoise"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "bfh.ch"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.142358,7.244692"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.057423,7.621388"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:46.947922,7.444609"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:46.946692,7.391228"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:46.991818,7.468039"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.145776,7.219669"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:620:500::/48"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.5.80.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.87.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.3.0/26"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "error_url": "https://it-support.bfh.ch",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIJAPneN1luv6WBMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGFhaS1sb2dvbi5iZmguY2gwHhcNMTUwNTA3MTQwNTAwWhcNMTgwNTA2MTQw\nNTAwWjAbMRkwFwYDVQQDExBhYWktbG9nb24uYmZoLmNoMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA7GW/n7pU61p+pjImwqFMpIudeZxliexRwmcN8w6A\nMUpIAVoj0Csr9zhZfQMHVV4JGuDo2AVAwX1vvcFNR2qCoCmbQ8GgxX/B3MSc42dy\nbCHMhtxCNcvigqermkUG4mcFtEA4zbpJ+ILqPZ4rGiZfy/DaWYGEH2f8rFrXjC+H\nS0/oxnS9D7o/V/mCrAYEIErX8aAMQJJcw94YBIVGVs/Bv0AXJOgoL2YjDI8xINyd\npbED93BdwHb1ksfrNJH/t9/dc2GiRPx2Gv7E4zY30Zkm8KRjSAmkybQeyhfeoetw\nJUDA2cqWB39JCVg1VeSeJ2Voi48WrQqA54uRgUvbya+v8QIDAQABo2cwZTBEBgNV\nHREEPTA7ghBhYWktbG9nb24uYmZoLmNohidodHRwczovL2FhaS1sb2dvbi5iZmgu\nY2gvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFCF9TJLxvi9kSOejHvssZ6v1pMW8\nMA0GCSqGSIb3DQEBBQUAA4IBAQB/A5JSvw+YiWYL2qn9piA5kbNaX9q/uHyukcGa\nf2cWyCD8U1H3YYuDpGQevmNOaSHUzMGpGn9FKXOvjxBLotY7jH50ReFifcNalFs2\nDv1JnyrrHc3BsqHexZKoOupT2L3hadEhJdfTmZX3hQY4yqi/RNKlYbIC1t1SjEUN\nnnt3eVesg87paE+VMTFIBB6OO8iKD9hSLbFwOvsuasUURF8X1239cT6Kg0qFYXit\nOa8ckwETZviCoz1wPxbbdE+tYkZFObQkgkoeDvJ/zLLenx0Vrw7EE/cFcZuriBTI\nFHdGUwjqh5AdbYDl7t25yKp91OODdNaifm8UyA/veqsHrygR"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "BFH - Berner Fachhochschule"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "BFH - Bern University of Applied Sciences"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "BFH - Haute \u00e9cole sp\u00e9cialis\u00e9e bernoise"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bfh.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bfh.ch/"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bfh.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "bfh.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://idp.ihe.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://idp.ihe.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-02-01T00:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/67c13bb00741bc9f65da46d70bbad594",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNESCO-IHE Institute for Water Education"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNESCO-IHE Institute for Water Education"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/unesco-ihe.jpg",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNESCO-IHE Institute for Water Education"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNESCO-IHE Institute for Water Education"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNESCO-IHE Institute for Water Education"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNESCO-IHE Institute for Water Education"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unesco-ihe.org/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unesco-ihe.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNESCO-IHE Institute for Water Education"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNESCO-IHE Institute for Water Education"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://man-fe.hosted.exlibrisgroup.com/shib",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fasoli"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Alessandro.Fasoli@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alessandro"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fasoli"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Alessandro.Fasoli@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alessandro"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://man-fe.hosted.exlibrisgroup.com/shib",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-01-21T13:40:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ex Libris: Primo ASP Service on behalf of The University of Manchester"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.exlibrisgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ex Libris (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://man-fe.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://man-fe.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://man-fe.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://man-fe.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://man-fe.hosted.exlibrisgroup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://man-fe.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://man-fe.hosted.exlibrisgroup.com/Shibboleth.sso/WAYF/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4jCCAcqgAwIBAgIJAIbeMpWWYVSeMA0GCSqGSIb3DQEBBQUAMBQxEjAQBgNV\n\t\t\t\t\t\tBAMTCXByaW1vMDV2MTAeFw0xMTEyMjAxMzUyMzJaFw0yMTEyMTcxMzUyMzJaMBQx\n\t\t\t\t\t\tEjAQBgNVBAMTCXByaW1vMDV2MTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAKiRUXmFIRlhuxsJeh0+w5gfpNAdGrklnQCjra/ZKnDLTPUkNRfPV4anjMpj\n\t\t\t\t\t\tPGgb74nMKHmC0w/JQnaNc1bujjkovT8kuUqtTakxiFx2YBYNt6g8Zf540iV87WwC\n\t\t\t\t\t\tf4+EqBHAc9jb/BCxD+/27ena7P0sFijzKnqXSZwVCLjYTUniRSxqRoYj9zWbVVp/\n\t\t\t\t\t\tQ/kgLM6dvx4oKkwr+LVOt8hrva24fkHcI2JkDpSuB8WQk9rqkF9pangmtwL70i47\n\t\t\t\t\t\tnUc40roGM0Xm1joVEO4vMycHevYDVDCbfsQRY9GLmSC3MFkg7K1+t1CUPBaK1N2L\n\t\t\t\t\t\tvxf/xyVEj3xzv+R35PSyVZowc+ECAwEAAaM3MDUwFAYDVR0RBA0wC4IJcHJpbW8w\n\t\t\t\t\t\tNXYxMB0GA1UdDgQWBBS5QVANx9PFctiP1JyHti3S/g/xCDANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAHiif6wam0p7c/7tdnRzgRsmJzEv57G0S4pHOA77fJvNdgGxwM3geVHAu\n\t\t\t\t\t\tRsiw17BFn4goleyfXxBFU2v9tFYxttKuAGtD0yKoi03Ow8zKkQmBmNCCxc0/1+CQ\n\t\t\t\t\t\t0pdMDkNUcxBClO7CKruncD1pHT5ma5t7/pXLgg/RDPN5Gne4hGo0ATiG0sn0Md6D\n\t\t\t\t\t\t/yqSdIsk+Q+YUG8vuYNuGMpsyZLO+oyjI6O/5TV2+hONQ4Gl4YkiNLflLOq9YArz\n\t\t\t\t\t\txu+sfXm5Vz/xJCu3Nv3uhHzNTFCBcy2GKUQtjMF0urKfflleQNKKAmD3mEi7msCS\n\t\t\t\t\t\t/gNJ6QmwQgxVykU77MUZfn6sO6YmDg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://man-fe.hosted.exlibrisgroup.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://man-fe.hosted.exlibrisgroup.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://man-fe.hosted.exlibrisgroup.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://man-fe.hosted.exlibrisgroup.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://man-fe.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://man-fe.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://man-fe.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://man-fe.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://man-fe.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://man-fe.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp-test.bsms.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@brighton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Holden"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ukfederation-tech@brighton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-test.bsms.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAMOvj1rjzW6b/X9XZ3j1EUBtCU2TMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB4xHDAaBgNVBAMTE2lkcC10ZXN0LmJzbXMuYWMudWswHhcNMTIwMTA0MTYy\n\t\t\t\t\t\tODA5WhcNMzIwMTA0MTYyODA5WjAeMRwwGgYDVQQDExNpZHAtdGVzdC5ic21zLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxzsApSD1TEB3bPOk\n\t\t\t\t\t\t+DTAPumCIRiZmHOncQ5ki6b/znHmtqsFWmfQp8lHBB7DNEUvhdLi7O/yRYKZe8Hj\n\t\t\t\t\t\tevuPCTv4bHAejyME8XYyoQmHkVGfyOeT8xPSI1AIkV3R6lGEi7Xdi8M15M4PMJ/V\n\t\t\t\t\t\tX+FoMACN/5z16y7ppoioCMnVPpmV/6QbzJSwYsVGUFPYvBxEpHVVVoShjgxVhAYL\n\t\t\t\t\t\tpdFC+C9tdtpNpxLWYhF+n9Z7t6A7T6TfogFmXH7SFruwU7vVCp1/dMehg2TOppPi\n\t\t\t\t\t\t9GouMfeFj44ijf/RViKwGZPNW6kE0/amfhslCfsv3/lq4YeI+JlNPMqmTXfoJUSu\n\t\t\t\t\t\tmxGF8wIDAQABo2kwZzBGBgNVHREEPzA9ghNpZHAtdGVzdC5ic21zLmFjLnVrhiZo\n\t\t\t\t\t\tdHRwczovL2lkcC10ZXN0LmJzbXMuYWMudWsvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n\t\t\t\t\t\thqiSOiWevN21AzwBuYHdQSX/y5EwDQYJKoZIhvcNAQEFBQADggEBAFC5TWxPIPTm\n\t\t\t\t\t\t/QVEjmIP6V0YmE7/uHDv+2xt8X6OC0uDndotIsQEmdpoK2DbdsQA+YrNDB2IrZpu\n\t\t\t\t\t\tRqB+Cdfe9s5sDkoWzk5ID7Hv6PRMQCFs+Vdl0ab46Ru2+y+CbydcyMJVt2lg2olA\n\t\t\t\t\t\tBa60gQz6HR1eSBkTuCV8CkN+8rSFv+mkWkWHfmS3GZRLH81/YjCLdoU+LJvdjPZ8\n\t\t\t\t\t\ts63TODIhTZQ5JqX4DDpP1ptSTuD2toVIgJbt5/0cixm4HDE79mgFYvq5praLbzXy\n\t\t\t\t\t\tO57WM45US3pZcz15guQB57aIg2+BtLfebM+aNxsCMYVlt31goe51bqG2Y/jT6HnQ\n\t\t\t\t\t\tYXhX6GjmeXs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brighton.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sussex.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-test.bsms.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-test.bsms.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-test.bsms.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-test.bsms.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-test.bsms.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-test.bsms.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-test.bsms.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-test.bsms.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brighton.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sussex.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://idp-test.bsms.ac.uk/idp/images/logo-bsms.ac.uk.png",
                    "height": "63",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "40"
                  },
                  {
                    "text": "https://idp-test.bsms.ac.uk/idp/images/favicon-bsms.ac.uk.ico",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Brighton and Sussex Medical School (Test)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAMOvj1rjzW6b/X9XZ3j1EUBtCU2TMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB4xHDAaBgNVBAMTE2lkcC10ZXN0LmJzbXMuYWMudWswHhcNMTIwMTA0MTYy\n\t\t\t\t\t\tODA5WhcNMzIwMTA0MTYyODA5WjAeMRwwGgYDVQQDExNpZHAtdGVzdC5ic21zLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxzsApSD1TEB3bPOk\n\t\t\t\t\t\t+DTAPumCIRiZmHOncQ5ki6b/znHmtqsFWmfQp8lHBB7DNEUvhdLi7O/yRYKZe8Hj\n\t\t\t\t\t\tevuPCTv4bHAejyME8XYyoQmHkVGfyOeT8xPSI1AIkV3R6lGEi7Xdi8M15M4PMJ/V\n\t\t\t\t\t\tX+FoMACN/5z16y7ppoioCMnVPpmV/6QbzJSwYsVGUFPYvBxEpHVVVoShjgxVhAYL\n\t\t\t\t\t\tpdFC+C9tdtpNpxLWYhF+n9Z7t6A7T6TfogFmXH7SFruwU7vVCp1/dMehg2TOppPi\n\t\t\t\t\t\t9GouMfeFj44ijf/RViKwGZPNW6kE0/amfhslCfsv3/lq4YeI+JlNPMqmTXfoJUSu\n\t\t\t\t\t\tmxGF8wIDAQABo2kwZzBGBgNVHREEPzA9ghNpZHAtdGVzdC5ic21zLmFjLnVrhiZo\n\t\t\t\t\t\tdHRwczovL2lkcC10ZXN0LmJzbXMuYWMudWsvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n\t\t\t\t\t\thqiSOiWevN21AzwBuYHdQSX/y5EwDQYJKoZIhvcNAQEFBQADggEBAFC5TWxPIPTm\n\t\t\t\t\t\t/QVEjmIP6V0YmE7/uHDv+2xt8X6OC0uDndotIsQEmdpoK2DbdsQA+YrNDB2IrZpu\n\t\t\t\t\t\tRqB+Cdfe9s5sDkoWzk5ID7Hv6PRMQCFs+Vdl0ab46Ru2+y+CbydcyMJVt2lg2olA\n\t\t\t\t\t\tBa60gQz6HR1eSBkTuCV8CkN+8rSFv+mkWkWHfmS3GZRLH81/YjCLdoU+LJvdjPZ8\n\t\t\t\t\t\ts63TODIhTZQ5JqX4DDpP1ptSTuD2toVIgJbt5/0cixm4HDE79mgFYvq5praLbzXy\n\t\t\t\t\t\tO57WM45US3pZcz15guQB57aIg2+BtLfebM+aNxsCMYVlt31goe51bqG2Y/jT6HnQ\n\t\t\t\t\t\tYXhX6GjmeXs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Brighton and Sussex Medical School (Test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bsms.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Brighton"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ed.unidesk.ac.uk/tas/public/login/verify",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:is.helpline@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-certs@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Apps Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ed.unidesk.ac.uk/tas/public/login/verify",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-05T08:56:17Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Unidesk - University of Edinburgh"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDrzCCApegAwIBAgIJAMVROTQuFXoxMA0GCSqGSIb3DQEBCwUAMEMxGTAXBgNV\n\t\t\t\t\t\tBAMTEGVkLnVuaWRlc2suYWMudWsxGTAXBgNVBAoTEGVkLnVuaWRlc2suYWMudWsx\n\t\t\t\t\t\tCzAJBgNVBAYTAlVLMB4XDTE2MDQwMTEyNTc1MFoXDTI2MDMzMDEyNTc1MFowQzEZ\n\t\t\t\t\t\tMBcGA1UEAxMQZWQudW5pZGVzay5hYy51azEZMBcGA1UEChMQZWQudW5pZGVzay5h\n\t\t\t\t\t\tYy51azELMAkGA1UEBhMCVUswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDBSIaEqZsBLHTmdv2pTau02z5iX2M+Y/I7rY3SBWy/is2bfuBuEzPS58oPMeHi\n\t\t\t\t\t\twFjfr8CAPQ2bQ32GK3lbvQzVAZqwabe+s+hcsdLFSmm26GxrmgbiL/U1Inx32gHL\n\t\t\t\t\t\t8Y494i1DNURJl7ImhY1LtSQBg81C/7uOf1P6pDoWQcUSooN+I0WLKVf4S5JGU4WW\n\t\t\t\t\t\t7uCUGFTVIEGFwveU4cpE/B1i6kuu1zq1n3X0zRyFG1Uu34fzujM8+0rlh/w9yl67\n\t\t\t\t\t\thq8qAHL/9j0909WXeaOXj/TPYSRISQCnq2biEmzOb09Jb/2/5gRFUSRVxh3fm5HT\n\t\t\t\t\t\tP1YDRav07OAGGhSmC75JTJvJAgMBAAGjgaUwgaIwHQYDVR0OBBYEFPHFACKjBapO\n\t\t\t\t\t\tRoiScm580WU4EzPbMHMGA1UdIwRsMGqAFPHFACKjBapORoiScm580WU4EzPboUek\n\t\t\t\t\t\tRTBDMRkwFwYDVQQDExBlZC51bmlkZXNrLmFjLnVrMRkwFwYDVQQKExBlZC51bmlk\n\t\t\t\t\t\tZXNrLmFjLnVrMQswCQYDVQQGEwJVS4IJAMVROTQuFXoxMAwGA1UdEwQFMAMBAf8w\n\t\t\t\t\t\tDQYJKoZIhvcNAQELBQADggEBAFOywZTwbtNhO4YAicWZ1MLcJoZnD3diuQhccHKO\n\t\t\t\t\t\tzaWZJju/OxbF4rurP3BH0rqJxruXwksD3bk45PKKTb6jLlBkRsqaTrSRL/Z/M6Hs\n\t\t\t\t\t\tNWy1pBAjP4EMEB+2Tmnikqx/e6BdfhogcPAwFAtup6u9H+kFY/tzprNH20q+07Gk\n\t\t\t\t\t\tyFKCJJwKZac1TFHLGA6PIzVFOuNqyFQGFqxVew/oL94UCJTTwtLTTuIPvpZaCTo+\n\t\t\t\t\t\tIyjlIMVigvenyr68jnkrJCgsberkaoPyxP00uK4QvdA0E9by1SvwNVy420Kvvb6+\n\t\t\t\t\t\tx/fFAXseVm8uRjmuM2HiffZhqgSKm1X1S4+nJ6HXYjGo8+g="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDrzCCApegAwIBAgIJAMVROTQuFXoxMA0GCSqGSIb3DQEBCwUAMEMxGTAXBgNV\n\t\t\t\t\t\tBAMTEGVkLnVuaWRlc2suYWMudWsxGTAXBgNVBAoTEGVkLnVuaWRlc2suYWMudWsx\n\t\t\t\t\t\tCzAJBgNVBAYTAlVLMB4XDTE2MDQwMTEyNTc1MFoXDTI2MDMzMDEyNTc1MFowQzEZ\n\t\t\t\t\t\tMBcGA1UEAxMQZWQudW5pZGVzay5hYy51azEZMBcGA1UEChMQZWQudW5pZGVzay5h\n\t\t\t\t\t\tYy51azELMAkGA1UEBhMCVUswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDBSIaEqZsBLHTmdv2pTau02z5iX2M+Y/I7rY3SBWy/is2bfuBuEzPS58oPMeHi\n\t\t\t\t\t\twFjfr8CAPQ2bQ32GK3lbvQzVAZqwabe+s+hcsdLFSmm26GxrmgbiL/U1Inx32gHL\n\t\t\t\t\t\t8Y494i1DNURJl7ImhY1LtSQBg81C/7uOf1P6pDoWQcUSooN+I0WLKVf4S5JGU4WW\n\t\t\t\t\t\t7uCUGFTVIEGFwveU4cpE/B1i6kuu1zq1n3X0zRyFG1Uu34fzujM8+0rlh/w9yl67\n\t\t\t\t\t\thq8qAHL/9j0909WXeaOXj/TPYSRISQCnq2biEmzOb09Jb/2/5gRFUSRVxh3fm5HT\n\t\t\t\t\t\tP1YDRav07OAGGhSmC75JTJvJAgMBAAGjgaUwgaIwHQYDVR0OBBYEFPHFACKjBapO\n\t\t\t\t\t\tRoiScm580WU4EzPbMHMGA1UdIwRsMGqAFPHFACKjBapORoiScm580WU4EzPboUek\n\t\t\t\t\t\tRTBDMRkwFwYDVQQDExBlZC51bmlkZXNrLmFjLnVrMRkwFwYDVQQKExBlZC51bmlk\n\t\t\t\t\t\tZXNrLmFjLnVrMQswCQYDVQQGEwJVS4IJAMVROTQuFXoxMAwGA1UdEwQFMAMBAf8w\n\t\t\t\t\t\tDQYJKoZIhvcNAQELBQADggEBAFOywZTwbtNhO4YAicWZ1MLcJoZnD3diuQhccHKO\n\t\t\t\t\t\tzaWZJju/OxbF4rurP3BH0rqJxruXwksD3bk45PKKTb6jLlBkRsqaTrSRL/Z/M6Hs\n\t\t\t\t\t\tNWy1pBAjP4EMEB+2Tmnikqx/e6BdfhogcPAwFAtup6u9H+kFY/tzprNH20q+07Gk\n\t\t\t\t\t\tyFKCJJwKZac1TFHLGA6PIzVFOuNqyFQGFqxVew/oL94UCJTTwtLTTuIPvpZaCTo+\n\t\t\t\t\t\tIyjlIMVigvenyr68jnkrJCgsberkaoPyxP00uK4QvdA0E9by1SvwNVy420Kvvb6+\n\t\t\t\t\t\tx/fFAXseVm8uRjmuM2HiffZhqgSKm1X1S4+nJ6HXYjGo8+g="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ed.unidesk.ac.uk/tas/public/login/verify",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://idp.rice.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pengle@rice.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul Engle"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dlane@rice.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dean Lane"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.rice.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.rice.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.rice.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUNB1FAd9Ux2knx5u0LT/2TS1LGcYwDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMaWRwLnJpY2UuZWR1MB4XDTA5MTAyOTE5NTYzMVoXDTI5\nMTAyOTE5NTYzMVowFzEVMBMGA1UEAxMMaWRwLnJpY2UuZWR1MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAliD8WG6wXXuqN8dnBBSKBEa0fuwutw4biOSz\nHPN5OLFDH22c9jBFTdPg4ozxGM6x6n30LXVRjAsdx5mFvqWXXrdihpSs2d/VLSSt\npDjJOOwc0mL+B7mB2zIqvHuJYyUKOaHAOxmjlQ2w74AzToragPQxgEFXkSNGi0TX\nNl9vtBkuP4XXCnVZaOyNOH5GFYLIw0UjekXCUbUWWQ7YkoZsA/rSgMctM1duiWq6\ncbI9bpl5GPd4Jc1z7c2QYOZYSvrRWnvJWtV1/3rlMfIWSra7FnMCk8OsWgqyozN5\nKGTt/F59qnkVHTp40O2NjqqRGyyZrXxy1TvXNqvglQJDeNuKxQIDAQABo18wXTA8\nBgNVHREENTAzggxpZHAucmljZS5lZHWGI2h0dHBzOi8vaWRwLnJpY2UuZWR1L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBT5ap3rsIH4qpnJk9rKCDdZCxGVdzANBgkq\nhkiG9w0BAQUFAAOCAQEAMI6twrzu3GVsqLcEXvgzomE4NqUjHqLn9LfV7Kts87gE\n7SedxD1UpGke9y/ca5AjwOaJeUdqAgbfD4jNIccpwht4kEZL8ZlBBIkx5fcPJ3uO\nAj26/fg1C2/JlOFitYP/wsHJGJhPjtK3lRxfXGa+NQzrX8f+9qyLWhwza1CV1Cus\nv+P0jZo3wAfCgA7hw84PHU/Az7nB9sawg2s082B0QKpMfeIjtrmWlRqyZiUxOpyC\nu6hryK6pnoO5TWNzyFnOZq8oNpXi+6+ulfu6Gf8ENofwnhxtj30Drh/uzGjJfwhb\nYGiGeQcYxxiDQvtt3hzYv/pHQ1/6svEiUxzRpwvC7Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rice.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.rice.edu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.rice.edu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.rice.edu:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.rice.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.rice.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.rice.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.rice.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.rice.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.rice.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rice.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Rice University Identity Provider"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.rice.edu/idp/images/RiceLogo_small.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "152"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rice University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUNB1FAd9Ux2knx5u0LT/2TS1LGcYwDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMaWRwLnJpY2UuZWR1MB4XDTA5MTAyOTE5NTYzMVoXDTI5\nMTAyOTE5NTYzMVowFzEVMBMGA1UEAxMMaWRwLnJpY2UuZWR1MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAliD8WG6wXXuqN8dnBBSKBEa0fuwutw4biOSz\nHPN5OLFDH22c9jBFTdPg4ozxGM6x6n30LXVRjAsdx5mFvqWXXrdihpSs2d/VLSSt\npDjJOOwc0mL+B7mB2zIqvHuJYyUKOaHAOxmjlQ2w74AzToragPQxgEFXkSNGi0TX\nNl9vtBkuP4XXCnVZaOyNOH5GFYLIw0UjekXCUbUWWQ7YkoZsA/rSgMctM1duiWq6\ncbI9bpl5GPd4Jc1z7c2QYOZYSvrRWnvJWtV1/3rlMfIWSra7FnMCk8OsWgqyozN5\nKGTt/F59qnkVHTp40O2NjqqRGyyZrXxy1TvXNqvglQJDeNuKxQIDAQABo18wXTA8\nBgNVHREENTAzggxpZHAucmljZS5lZHWGI2h0dHBzOi8vaWRwLnJpY2UuZWR1L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBT5ap3rsIH4qpnJk9rKCDdZCxGVdzANBgkq\nhkiG9w0BAQUFAAOCAQEAMI6twrzu3GVsqLcEXvgzomE4NqUjHqLn9LfV7Kts87gE\n7SedxD1UpGke9y/ca5AjwOaJeUdqAgbfD4jNIccpwht4kEZL8ZlBBIkx5fcPJ3uO\nAj26/fg1C2/JlOFitYP/wsHJGJhPjtK3lRxfXGa+NQzrX8f+9qyLWhwza1CV1Cus\nv+P0jZo3wAfCgA7hw84PHU/Az7nB9sawg2s082B0QKpMfeIjtrmWlRqyZiUxOpyC\nu6hryK6pnoO5TWNzyFnOZq8oNpXi+6+ulfu6Gf8ENofwnhxtj30Drh/uzGjJfwhb\nYGiGeQcYxxiDQvtt3hzYv/pHQ1/6svEiUxzRpwvC7Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Rice University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rice.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Rice University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://nagios-vm.nordu.net/shibboleth",
    {
      "entity_id": "https://nagios-vm.nordu.net/shibboleth",
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nagios-vm.nordu.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nagios-vm.nordu.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nagios-vm.nordu.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nagios-vm.nordu.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nagios-vm.nordu.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://nagios-vm.nordu.net/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "nagios-vm.nordu.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFTCCAf2gAwIBAgIJAOw/1rDNh+d1MA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE25hZ2lvcy12bS5ub3JkdS5uZXQwHhcNMTIwMTE4MTUxMTEzWhcNMjIwMTE1\nMTUxMTEzWjAeMRwwGgYDVQQDExNuYWdpb3Mtdm0ubm9yZHUubmV0MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuvq7eAvCyajQnHvaHTSH1iQrejBHrBUr\nZYkZktae1onE3oC74JwUbVQNBKu0FS0uLxdphAib923Ra3xpLmFV3cvGQrtYgxeG\n0MJOqyq8wMX5Q/2+VArKsk+BfL5XK/HdFDkZAZWSh2Se/+dgpAwo0GZuSqN64RA4\nb7uaodXO9PwLOKAVeaS522vr14mRXEG12w1D+R29+8kDW3UQHpD8/oDwXuvjS23N\nxiRxgOAI3c1khI8PuKH7mljFXG6H+KAikr9lhPo/ikFk4oh28pRtHFSzAnRem4a+\naoSVLXXLHhjWd1mJbRPXHuQQBkNHZB1atBRvxR9gibfNpHfQTGtEMQIDAQABo1Yw\nVDAzBgNVHREELDAqghNuYWdpb3Mtdm0ubm9yZHUubmV0hhNuYWdpb3Mtdm0ubm9y\nZHUubmV0MB0GA1UdDgQWBBSj4lzVVrzyTNgaGDhYFU4VG2YclDANBgkqhkiG9w0B\nAQUFAAOCAQEAZAlVWmvyps2vBdo86LsSj18c4ajuR14D2vAJmhLRSzjsvMjgg2dP\npca2fCvqh1c96TiJ47lKq13cLgOSnNkL6yaNnCjSDr/qC67X9BOoZdXBQyJziWZr\ng+eF3GQzzrnvJB2/CQeT7IoyYtHeOMUgoodhiu4ABWIlkKJ5CymHGoOqDTkoibV0\niw2iKpPj52u7wvsN0sSzQ1Gh4pf8D75dJZtAQevNRKz89wGVQUxFrgm5OEviuhIR\n5AMm/41ESEoDFvKk3RCK3JqTM6hV2s8ofGYJzGv1rK8qD78nJEsdbd0DRqgD4Iwi\niTg/j/tOBYfIuWhX2ipi+fFwWaqmIk1LxA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=nagios-vm.nordu.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "nagios-vm.nordu.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFTCCAf2gAwIBAgIJAOw/1rDNh+d1MA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE25hZ2lvcy12bS5ub3JkdS5uZXQwHhcNMTIwMTE4MTUxMTEzWhcNMjIwMTE1\nMTUxMTEzWjAeMRwwGgYDVQQDExNuYWdpb3Mtdm0ubm9yZHUubmV0MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuvq7eAvCyajQnHvaHTSH1iQrejBHrBUr\nZYkZktae1onE3oC74JwUbVQNBKu0FS0uLxdphAib923Ra3xpLmFV3cvGQrtYgxeG\n0MJOqyq8wMX5Q/2+VArKsk+BfL5XK/HdFDkZAZWSh2Se/+dgpAwo0GZuSqN64RA4\nb7uaodXO9PwLOKAVeaS522vr14mRXEG12w1D+R29+8kDW3UQHpD8/oDwXuvjS23N\nxiRxgOAI3c1khI8PuKH7mljFXG6H+KAikr9lhPo/ikFk4oh28pRtHFSzAnRem4a+\naoSVLXXLHhjWd1mJbRPXHuQQBkNHZB1atBRvxR9gibfNpHfQTGtEMQIDAQABo1Yw\nVDAzBgNVHREELDAqghNuYWdpb3Mtdm0ubm9yZHUubmV0hhNuYWdpb3Mtdm0ubm9y\nZHUubmV0MB0GA1UdDgQWBBSj4lzVVrzyTNgaGDhYFU4VG2YclDANBgkqhkiG9w0B\nAQUFAAOCAQEAZAlVWmvyps2vBdo86LsSj18c4ajuR14D2vAJmhLRSzjsvMjgg2dP\npca2fCvqh1c96TiJ47lKq13cLgOSnNkL6yaNnCjSDr/qC67X9BOoZdXBQyJziWZr\ng+eF3GQzzrnvJB2/CQeT7IoyYtHeOMUgoodhiu4ABWIlkKJ5CymHGoOqDTkoibV0\niw2iKpPj52u7wvsN0sSzQ1Gh4pf8D75dJZtAQevNRKz89wGVQUxFrgm5OEviuhIR\n5AMm/41ESEoDFvKk3RCK3JqTM6hV2s8ofGYJzGv1rK8qD78nJEsdbd0DRqgD4Iwi\niTg/j/tOBYfIuWhX2ipi+fFwWaqmIk1LxA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=nagios-vm.nordu.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nagios-vm.nordu.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nagios-vm.nordu.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nagios-vm.nordu.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nagios-vm.nordu.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nagios-vm.nordu.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://nagios-vm.nordu.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nagios-vm.nordu.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://nagios-vm.nordu.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://nagios-vm.nordu.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://nagios-vm.nordu.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://test-shh.pingpong.net/Shibboleth.sso/Metadata",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://test-shh.pingpong.net/Shibboleth.sso/Metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test-shh.pingpong.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test-shh.pingpong.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://test-shh.pingpong.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test-shh.pingpong.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test-shh.pingpong.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "L\u00e4rplattformen PING PONG vid Sophiahemmets h\u00f6gskola."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The learning platform PING PONG at Sophiahemmet University."
                  }
                ],
                "logo": [
                  {
                    "text": "https://test-shh.pingpong.net/login/pingpong-logo-168x50.png",
                    "height": "168",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "https://test-shh.pingpong.net/login/pingpong-logo-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PING PONG vid Sophiahemmets h\u00f6gskola"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PING PONG at Sophiahemmet University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test-shh.pingpong.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://test-shh.pingpong.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "test-server.pingpong.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAIreASj6FsJYMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\nBAMTGHRlc3Qtc2VydmVyLnBpbmdwb25nLm5ldDAeFw0xNDA2MjcxMjQ4MDhaFw0y\nNDA2MjQxMjQ4MDhaMCMxITAfBgNVBAMTGHRlc3Qtc2VydmVyLnBpbmdwb25nLm5l\ndDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANcJkAXw1cx7St7PPOAP\nUNqdouPe0CSVWODuSEtm8orAub2l9hDnfJiE/K62BYBZGZUaHjrtubaoaKRWts1m\nKSGUmfjwc38wjW5JBGTPAsTqWukNT89CzeKqNWEuPAk8Tcp1hrb+yCCqUtUcZSKL\nH6Zo8dHKCko+2HpYs4SKlJ6TukY9iB/D742FAn9+T7Sjd3XLJgb27LdElZ+Mt1Zl\nQyVeh+VzJHzMjLd8lVi4RwwkVA4T28p056ODUfQ3o4h8JrPSlZVGEb+Ayuq2QRED\nyll+DUGeuGqH/vVBp9n4EUSNTh/GJZ8lbJJcogsHjYIGkIDRi6bPZMnnE6nGSGhT\npAECAwEAAaNGMEQwIwYDVR0RBBwwGoIYdGVzdC1zZXJ2ZXIucGluZ3BvbmcubmV0\nMB0GA1UdDgQWBBSrXLwS1q7qwcr20Gawl48anQBGLjANBgkqhkiG9w0BAQUFAAOC\nAQEAj54wf6+eQkGfEjUY4ZZZdk5xByccWZjH6gwjYFdjDEsI83YbOVjuCAA46uDG\nTM9YWeg55J3+H/doRkhNbV8nHbNeuzHyHuuixtP7xREl4dRCSu0EQxgJ2FAyo3X+\n6S8wmTtBCXRTXEcgp9jSRLE6iE2EOY2fWa6pxWfLCfQBwSoI2pRXo69OU6vHWO/a\nfuT6EONz4D9pi7t8w6gfnBh+6boCt9KzpnIhq59YOHvcK8PHcMpXz+jSW1W2ZPnE\numEfUjub2UD/FBc9kMEDX6Qkz7Jr8HF/C414A9IcVXiUxDX8WX3AGpjmV/H4+qna\nOWWW78/lmlGJYmT4C6Fba3Ifag=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=test-server.pingpong.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test-shh.pingpong.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test-shh.pingpong.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://test-shh.pingpong.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://kclidp.kcl.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:systemsteam@kcl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ISS Servers and Data Storage Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:systemsteam@kcl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ISS Servers and Data Storage Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fitzpatrick"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Mike.Fitzpatrick@kcl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://kclidp.kcl.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEZjCCA06gAwIBAgIBADANBgkqhkiG9w0BAQUFADB2MQswCQYDVQQGEwJHQjEP\n\t\t\t\t\t\tMA0GA1UECBMGTG9uZG9uMQ8wDQYDVQQHEwZMb25kb24xHTAbBgNVBAoTFEtpbmdz\n\t\t\t\t\t\tIENvbGxlZ2UgTG9uZG9uMQswCQYDVQQLEwJJVDEZMBcGA1UEAxMQa2NsaWRwLmtj\n\t\t\t\t\t\tbC5hYy51azAeFw0xMzAxMDkxNjQyMTRaFw0yMzAxMDcxNjQyMTRaMHYxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMQ8wDQYDVQQIEwZMb25kb24xDzANBgNVBAcTBkxvbmRvbjEdMBsGA1UE\n\t\t\t\t\t\tChMUS2luZ3MgQ29sbGVnZSBMb25kb24xCzAJBgNVBAsTAklUMRkwFwYDVQQDExBr\n\t\t\t\t\t\tY2xpZHAua2NsLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tyEpyzp6Y1kvj+GsPL1pQiQvDBLnNck72Bn7SVCrEAbhoYSSymjchXt7yI3dw1pMB\n\t\t\t\t\t\tf9+0iA6s5ex0Mt7tnjggWV6wIGM3zw62X+cSINnWp4TRWHZ3LVEwcU9O2R1o0o3U\n\t\t\t\t\t\t467XviRD/SrNsaRnZp/5XmddQjTt0nLqsGw/RVqlEwGNoxr3/ufUqyC9C2mbOtb7\n\t\t\t\t\t\tDcrUqH7z4R+f6YokzqMhjuBtd7bHr4aKDeRKzmltpGlVFEz4wrVNi+79WfjLkX7l\n\t\t\t\t\t\tdcxzXU9jnHOpgzbnUcmkwbxSl9DBSC9VxJBC83ncXRuRBgyqPpXYmZ6xdnUm+7e2\n\t\t\t\t\t\teCRUuVRGB09QC4yrvCXZZwIDAQABo4H+MIH7MAkGA1UdEwQCMAAwLAYJYIZIAYb4\n\t\t\t\t\t\tQgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBSp\n\t\t\t\t\t\tTH5kAuUTBts/2kYGhN6eOKOXzDCBoAYDVR0jBIGYMIGVgBSpTH5kAuUTBts/2kYG\n\t\t\t\t\t\thN6eOKOXzKF6pHgwdjELMAkGA1UEBhMCR0IxDzANBgNVBAgTBkxvbmRvbjEPMA0G\n\t\t\t\t\t\tA1UEBxMGTG9uZG9uMR0wGwYDVQQKExRLaW5ncyBDb2xsZWdlIExvbmRvbjELMAkG\n\t\t\t\t\t\tA1UECxMCSVQxGTAXBgNVBAMTEGtjbGlkcC5rY2wuYWMudWuCAQAwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAJ0zF1N2N5bQS/ZK08jAbsd1gDuk4u4D5o8vEW5Np3aUPrHE3fK1\n\t\t\t\t\t\t59bl8mpz3q9/kDJuu2NGZRlNGpFOUSDZJBWz6g6gg6sYSgTVXSRnfsSBnQ103dzb\n\t\t\t\t\t\tv0MG4GA9B+WAD/6/henwXa0cSB708MU9ezq8dufilyHzNo033tfKXiWZbbvgO+mk\n\t\t\t\t\t\thBFPNvEdfJ98vLKS6q+wmNlvmzhFr7aoH1tYENryGrJWTJ0PEjv+SYWiHRjZdrF4\n\t\t\t\t\t\thZEob0ux+XK8uPgMAepyHgBduBcJgDhABlkLSZ5qECgDRpQXzgZglrHzU8k0Y0PA\n\t\t\t\t\t\tlTZdf+SSG52AWWaNmRD/L5fOY0EKkCphfrs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kcl.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://kclidp.kcl.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://kclidp.kcl.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://kclidp.kcl.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://kclidp.kcl.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://kclidp.kcl.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://kclidp.kcl.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://kclidp.kcl.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://kclidp.kcl.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kcl.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://kclidp.kcl.ac.uk/logo1.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://kclidp.kcl.ac.uk/logo2.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "King's College London"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEZjCCA06gAwIBAgIBADANBgkqhkiG9w0BAQUFADB2MQswCQYDVQQGEwJHQjEP\n\t\t\t\t\t\tMA0GA1UECBMGTG9uZG9uMQ8wDQYDVQQHEwZMb25kb24xHTAbBgNVBAoTFEtpbmdz\n\t\t\t\t\t\tIENvbGxlZ2UgTG9uZG9uMQswCQYDVQQLEwJJVDEZMBcGA1UEAxMQa2NsaWRwLmtj\n\t\t\t\t\t\tbC5hYy51azAeFw0xMzAxMDkxNjQyMTRaFw0yMzAxMDcxNjQyMTRaMHYxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMQ8wDQYDVQQIEwZMb25kb24xDzANBgNVBAcTBkxvbmRvbjEdMBsGA1UE\n\t\t\t\t\t\tChMUS2luZ3MgQ29sbGVnZSBMb25kb24xCzAJBgNVBAsTAklUMRkwFwYDVQQDExBr\n\t\t\t\t\t\tY2xpZHAua2NsLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tyEpyzp6Y1kvj+GsPL1pQiQvDBLnNck72Bn7SVCrEAbhoYSSymjchXt7yI3dw1pMB\n\t\t\t\t\t\tf9+0iA6s5ex0Mt7tnjggWV6wIGM3zw62X+cSINnWp4TRWHZ3LVEwcU9O2R1o0o3U\n\t\t\t\t\t\t467XviRD/SrNsaRnZp/5XmddQjTt0nLqsGw/RVqlEwGNoxr3/ufUqyC9C2mbOtb7\n\t\t\t\t\t\tDcrUqH7z4R+f6YokzqMhjuBtd7bHr4aKDeRKzmltpGlVFEz4wrVNi+79WfjLkX7l\n\t\t\t\t\t\tdcxzXU9jnHOpgzbnUcmkwbxSl9DBSC9VxJBC83ncXRuRBgyqPpXYmZ6xdnUm+7e2\n\t\t\t\t\t\teCRUuVRGB09QC4yrvCXZZwIDAQABo4H+MIH7MAkGA1UdEwQCMAAwLAYJYIZIAYb4\n\t\t\t\t\t\tQgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBSp\n\t\t\t\t\t\tTH5kAuUTBts/2kYGhN6eOKOXzDCBoAYDVR0jBIGYMIGVgBSpTH5kAuUTBts/2kYG\n\t\t\t\t\t\thN6eOKOXzKF6pHgwdjELMAkGA1UEBhMCR0IxDzANBgNVBAgTBkxvbmRvbjEPMA0G\n\t\t\t\t\t\tA1UEBxMGTG9uZG9uMR0wGwYDVQQKExRLaW5ncyBDb2xsZWdlIExvbmRvbjELMAkG\n\t\t\t\t\t\tA1UECxMCSVQxGTAXBgNVBAMTEGtjbGlkcC5rY2wuYWMudWuCAQAwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAJ0zF1N2N5bQS/ZK08jAbsd1gDuk4u4D5o8vEW5Np3aUPrHE3fK1\n\t\t\t\t\t\t59bl8mpz3q9/kDJuu2NGZRlNGpFOUSDZJBWz6g6gg6sYSgTVXSRnfsSBnQ103dzb\n\t\t\t\t\t\tv0MG4GA9B+WAD/6/henwXa0cSB708MU9ezq8dufilyHzNo033tfKXiWZbbvgO+mk\n\t\t\t\t\t\thBFPNvEdfJ98vLKS6q+wmNlvmzhFr7aoH1tYENryGrJWTJ0PEjv+SYWiHRjZdrF4\n\t\t\t\t\t\thZEob0ux+XK8uPgMAepyHgBduBcJgDhABlkLSZ5qECgDRpQXzgZglrHzU8k0Y0PA\n\t\t\t\t\t\tlTZdf+SSG52AWWaNmRD/L5fOY0EKkCphfrs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "King's College London"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kcl.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "King's College London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://www.ordbogen.com",
    {
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2011-09-02T15:52:55Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute_value": [
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "kalmar"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "denmark"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "iceland"
              }
            ],
            "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
            "name": "tags",
            "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "maw@ordbogen.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://www.ordbogen.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.ordbogen.com//singlesignon/simplesamlphp/saml2/sp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Form\u00e5let er at levere en online ordbog hvori du kan foretage et ubegr\u00e6nset antal opslag i de ordb\u00f8ger som din institution har k\u00f8bt adgang til."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The purpose is to provide an online dictionary in which you can look up an unlimited number of words in the dictionaries bought by your educational institution."
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ordbogen.com"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ordbogen.com"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ordbogen.com//singlesignon/simplesamlphp/saml2/sp/AssertionConsumerService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.lemma.com/wayf/response/login",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Form\u00e5let er at levere en online ordbog hvori du kan foretage et ubegr\u00e6nset antal opslag i de ordb\u00f8ger som din institution har k\u00f8bt adgang til."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The purpose is to provide an online dictionary in which you can look up an unlimited number of words in the dictionaries bought by your educational institution."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Ordbogen.com"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Ordbogen.com"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "organizationName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.pembrokeshire.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mekon@pembrokeshire.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Support Dept"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gardner"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:r.gardner@pembrokeshire.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.pembrokeshire.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-12-13T15:22:26Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDejCCAmICCQDRXJmAKdWRAzANBgkqhkiG9w0BAQUFADB/MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEWMBQGA1UECBMNUGVtYnJva2VzaGlyZTEWMBQGA1UEBxMNSGF2ZXJmb3Jkd2Vz\n\t\t\t\t\t\tdDEeMBwGA1UEChMVUGVtYnJva2VzaGlyZSBDb2xsZWdlMSAwHgYDVQQDExdpZHAu\n\t\t\t\t\t\tcGVtYnJva2VzaGlyZS5hYy51azAeFw0xMjEyMTMxMTEwNDhaFw0zMjEyMDgxMTEw\n\t\t\t\t\t\tNDhaMH8xCzAJBgNVBAYTAkdCMRYwFAYDVQQIEw1QZW1icm9rZXNoaXJlMRYwFAYD\n\t\t\t\t\t\tVQQHEw1IYXZlcmZvcmR3ZXN0MR4wHAYDVQQKExVQZW1icm9rZXNoaXJlIENvbGxl\n\t\t\t\t\t\tZ2UxIDAeBgNVBAMTF2lkcC5wZW1icm9rZXNoaXJlLmFjLnVrMIIBIjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQEFAAOCAQ8AMIIBCgKCAQEAo43iMdoX7wISei44zg0pzYm/oDHX3EOTqILe\n\t\t\t\t\t\tXT91H+u9UIa8mqCpQneXmiE6Oo/rvADRHm9+iRHcUf6GDGq4x16DRc+KPR6Dqy2N\n\t\t\t\t\t\tsGuL1sg3vmTc8njS2AUoVK0PSFb/4AVooN303PWvz0S8nHXGvDmkk7aYtBzpb2K3\n\t\t\t\t\t\tqKx+BvyTDuJQF/TcEZAKHme3FVGd29tJSLVNtFs86Dtnu15uj6f6EtenaZQ9aF6Z\n\t\t\t\t\t\tr9f1TH5cAN10k6epmK0PGxXHvv9ymEVhJMW1p1wiKDfakqOiytlpG1Ltjuz+nl6J\n\t\t\t\t\t\thMlWZASCK1lBSFRa78Vb+PqHARZvs0nvrjriaPGfA4JIttXTSQIDAQABMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQAgVzb1cy/TwNSZh3yLMaeBQlMlvZATKqIk3KRYmXo3qAJw\n\t\t\t\t\t\tZvK1t38aPzStE7CB8zq+xdp7oUet1/Arus9RAQb/1MUaWyvHnXzstO/aBctwu7QR\n\t\t\t\t\t\tuqfDg4n13Rhoy5Id370cjLlUKPkkYjvtz3mqaaG2D5xGM88lYznPXBAwjitRYb6F\n\t\t\t\t\t\t/llj4EdobocZoTO/p3Q1jneiw9q8Sz0Xo0YO5G/G5PqsRk6dzabdbgHhr32fL9H2\n\t\t\t\t\t\telD+LKh00BMxGfto3F4AuID2qRcaI+BHK2nK1tKYJgOJ57TarUPbevYx+MN5zUaQ\n\t\t\t\t\t\tqGIbeRaq+jbj1N5J6kc5YbZDPuvT6BjH0yqKQBCI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pembrokeshire.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.pembrokeshire.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.pembrokeshire.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.pembrokeshire.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.pembrokeshire.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.pembrokeshire.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.pembrokeshire.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.pembrokeshire.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.pembrokeshire.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pembrokeshire.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDejCCAmICCQDRXJmAKdWRAzANBgkqhkiG9w0BAQUFADB/MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEWMBQGA1UECBMNUGVtYnJva2VzaGlyZTEWMBQGA1UEBxMNSGF2ZXJmb3Jkd2Vz\n\t\t\t\t\t\tdDEeMBwGA1UEChMVUGVtYnJva2VzaGlyZSBDb2xsZWdlMSAwHgYDVQQDExdpZHAu\n\t\t\t\t\t\tcGVtYnJva2VzaGlyZS5hYy51azAeFw0xMjEyMTMxMTEwNDhaFw0zMjEyMDgxMTEw\n\t\t\t\t\t\tNDhaMH8xCzAJBgNVBAYTAkdCMRYwFAYDVQQIEw1QZW1icm9rZXNoaXJlMRYwFAYD\n\t\t\t\t\t\tVQQHEw1IYXZlcmZvcmR3ZXN0MR4wHAYDVQQKExVQZW1icm9rZXNoaXJlIENvbGxl\n\t\t\t\t\t\tZ2UxIDAeBgNVBAMTF2lkcC5wZW1icm9rZXNoaXJlLmFjLnVrMIIBIjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQEFAAOCAQ8AMIIBCgKCAQEAo43iMdoX7wISei44zg0pzYm/oDHX3EOTqILe\n\t\t\t\t\t\tXT91H+u9UIa8mqCpQneXmiE6Oo/rvADRHm9+iRHcUf6GDGq4x16DRc+KPR6Dqy2N\n\t\t\t\t\t\tsGuL1sg3vmTc8njS2AUoVK0PSFb/4AVooN303PWvz0S8nHXGvDmkk7aYtBzpb2K3\n\t\t\t\t\t\tqKx+BvyTDuJQF/TcEZAKHme3FVGd29tJSLVNtFs86Dtnu15uj6f6EtenaZQ9aF6Z\n\t\t\t\t\t\tr9f1TH5cAN10k6epmK0PGxXHvv9ymEVhJMW1p1wiKDfakqOiytlpG1Ltjuz+nl6J\n\t\t\t\t\t\thMlWZASCK1lBSFRa78Vb+PqHARZvs0nvrjriaPGfA4JIttXTSQIDAQABMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQAgVzb1cy/TwNSZh3yLMaeBQlMlvZATKqIk3KRYmXo3qAJw\n\t\t\t\t\t\tZvK1t38aPzStE7CB8zq+xdp7oUet1/Arus9RAQb/1MUaWyvHnXzstO/aBctwu7QR\n\t\t\t\t\t\tuqfDg4n13Rhoy5Id370cjLlUKPkkYjvtz3mqaaG2D5xGM88lYznPXBAwjitRYb6F\n\t\t\t\t\t\t/llj4EdobocZoTO/p3Q1jneiw9q8Sz0Xo0YO5G/G5PqsRk6dzabdbgHhr32fL9H2\n\t\t\t\t\t\telD+LKh00BMxGfto3F4AuID2qRcaI+BHK2nK1tKYJgOJ57TarUPbevYx+MN5zUaQ\n\t\t\t\t\t\tqGIbeRaq+jbj1N5J6kc5YbZDPuvT6BjH0yqKQBCI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Pembrokeshire College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.pembrokeshire.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Pembrokeshire College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ezproxy.wlv.ac.uk/sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Henderson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:d.henderson@wlv.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Henderson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:d.henderson@wlv.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ezproxy.wlv.ac.uk/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-07-16T07:56:29Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Wolverhampton EZproxy"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wlv.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Wolverhampton"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE4TCCA8mgAwIBAgIBBTANBgkqhkiG9w0BAQUFADCBqzEgMB4GA1UEAxMXbG9n\n\t\t\t\t\t\taW4uZXpwcm94eS53bHYuYWMudWsxCzAJBgNVBAYTAkdCMRYwFAYDVQQIEw1XZXN0\n\t\t\t\t\t\tIE1pZGxhbmRzMRYwFAYDVQQHEw1Xb2x2ZXJoYW1wdG9uMSQwIgYDVQQKExtVbml2\n\t\t\t\t\t\tZXJzaXR5IG9mIFdvbHZlcmhhbXB0b24xJDAiBgkqhkiG9w0BCQEWFWQuaGVuZGVy\n\t\t\t\t\t\tc29uQHdsdi5hYy51azAeFw0xMjA3MTMwODU4MTBaFw0yMjA3MTMwODU4MTBaMIGr\n\t\t\t\t\t\tMSAwHgYDVQQDExdsb2dpbi5lenByb3h5Lndsdi5hYy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tFjAUBgNVBAgTDVdlc3QgTWlkbGFuZHMxFjAUBgNVBAcTDVdvbHZlcmhhbXB0b24x\n\t\t\t\t\t\tJDAiBgNVBAoTG1VuaXZlcnNpdHkgb2YgV29sdmVyaGFtcHRvbjEkMCIGCSqGSIb3\n\t\t\t\t\t\tDQEJARYVZC5oZW5kZXJzb25Ad2x2LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAznoylhFt3MASgSBsG7czD9Wsvxz/02asNA4T5CajtAefmrsm\n\t\t\t\t\t\tZTMHSxf9pmbCziWmWqq/9zQ2iEO0hH7MJg81pP1qtPCdDCNRrKVfVgmbgsxvWd0b\n\t\t\t\t\t\toiBXYHad0wBqBbv2lz8JcJKo4hTIrDA3OL/xt5C3b0qhNdpItiyzYndt9VtIgUAj\n\t\t\t\t\t\tnGHGotc/0KgcCz3K0jLuQDH23glQyd8yveAsoZ2DKBfE2N6rTDQxWfG7qGJxNTml\n\t\t\t\t\t\tfS6leTgSAN7dl0n1jEimJXmox9uyk/IF2FzcQSVx+Mpy/horRv43NkWmt8fNVZIF\n\t\t\t\t\t\txLwznTWWSL4p5WY8oVvXqK8hQg7n/4iTqXe4PQIDAQABo4IBDDCCAQgwHQYDVR0O\n\t\t\t\t\t\tBBYEFN2wrxBJwZZbhFqvvF3UbC2NO6m1MIHYBgNVHSMEgdAwgc2AFN2wrxBJwZZb\n\t\t\t\t\t\thFqvvF3UbC2NO6m1oYGxpIGuMIGrMSAwHgYDVQQDExdsb2dpbi5lenByb3h5Lnds\n\t\t\t\t\t\tdi5hYy51azELMAkGA1UEBhMCR0IxFjAUBgNVBAgTDVdlc3QgTWlkbGFuZHMxFjAU\n\t\t\t\t\t\tBgNVBAcTDVdvbHZlcmhhbXB0b24xJDAiBgNVBAoTG1VuaXZlcnNpdHkgb2YgV29s\n\t\t\t\t\t\tdmVyaGFtcHRvbjEkMCIGCSqGSIb3DQEJARYVZC5oZW5kZXJzb25Ad2x2LmFjLnVr\n\t\t\t\t\t\tggEFMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAClhsJ2RbVyic9sQ\n\t\t\t\t\t\tCWJSLBHYvR1i37eXYUlaqT5AImq3KF3RZLHUJ+3qyN6lfkJulGQoAUBy7RJR+OD6\n\t\t\t\t\t\tMmVxXDos+kr+MqRiIjUfxopOpTtLOa8cUB8pnk4OLMO2ZixQ9nn5dj8mhMnhT6Ie\n\t\t\t\t\t\tlnxJWM/V5XtP6votpZ/wR64/evLcuyjIQx/AYegCD942K+4btlbRqmng5tr3IXKs\n\t\t\t\t\t\ts8OxJ1Gk4nTci0wXRBkFQ6PWuMUDmchlM7D68F/sPR6LEB12As9mF3w/zPhP6kfS\n\t\t\t\t\t\t3WgYxlcio+mumRLvxAYu2WW2g9FagvIgLiKT+OEw32ejFiraBUJ5ln1f8AF0x+wK\n\t\t\t\t\t\tKKbOZKk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://login.ezproxy.wlv.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.ezproxy.wlv.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.ezproxy.wlv.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.ezproxy.wlv.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.staffordcoll.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Nicholls"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:r.nicholls@staffordcoll.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dunning"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.dunning@staffordcoll.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Nicholls"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:r.nicholls@staffordcoll.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dunning"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.dunning@staffordcoll.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.staffordcoll.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-05-27T12:38:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID3jCCAsYCCQDD9aF4VF27mzANBgkqhkiG9w0BAQUFADCBsDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFjAUBgNVBAgMDVN0YWZmb3Jkc2hpcmUxETAPBgNVBAcMCFN0YWZmb3JkMRkw\n\t\t\t\t\t\tFwYDVQQKDBBTdGFmZm9yZCBDb2xsZWdlMQwwCgYDVQQLDANJVFUxHzAdBgNVBAMM\n\t\t\t\t\t\tFmlkcC5zdGFmZm9yZGNvbGwuYWMudWsxLDAqBgkqhkiG9w0BCQEWHXIubmljaG9s\n\t\t\t\t\t\tbHNAc3RhZmZvcmRjb2xsLmFjLnVrMB4XDTE0MDQxNDE2MDQzM1oXDTI0MDQxMTE2\n\t\t\t\t\t\tMDQzM1owgbAxCzAJBgNVBAYTAkdCMRYwFAYDVQQIDA1TdGFmZm9yZHNoaXJlMREw\n\t\t\t\t\t\tDwYDVQQHDAhTdGFmZm9yZDEZMBcGA1UECgwQU3RhZmZvcmQgQ29sbGVnZTEMMAoG\n\t\t\t\t\t\tA1UECwwDSVRVMR8wHQYDVQQDDBZpZHAuc3RhZmZvcmRjb2xsLmFjLnVrMSwwKgYJ\n\t\t\t\t\t\tKoZIhvcNAQkBFh1yLm5pY2hvbGxzQHN0YWZmb3JkY29sbC5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBALACtr71g3kiPdLfVC9EDCkmWrwkFgpq\n\t\t\t\t\t\tjY3tJSFR4+HFp1uSTI4selAUoa2JkDCXXV6Raqdl5rPb70NxpkpgUqnEJB2NfihV\n\t\t\t\t\t\trLaLiX03o95ZrO7KDVMbAvoa34arqipgZZPu7jxgNmlWpdM1FBmY7yRq2CvGHvRa\n\t\t\t\t\t\tVikoFqmEojYFWGmmnqArYx4QibTuNjxwmfVU0BTOVS7Nos9K5l4USKDrBxIuE9Qm\n\t\t\t\t\t\t8noW74ZtZzCCq2PSdZ/tj9K9EA6kEc+pI+UG7DcIFyEpmaDOXFDcOOKlAYT3MfL3\n\t\t\t\t\t\twSqg8/YPGPF9vkzk0lBv2M5YyLS9kZIaTzqkK6KLfMIR6QMYRCOrCIMCAwEAATAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACU0fU6QuYxlfW6hh6iekYfgMiVgS6oCORQR/L/to\n\t\t\t\t\t\tFJpQk0I7TDG6Gktlc5aEpsqMYQOwC99Lb8fGFQAt1g6wRyzZA8DIXnG6dQO5cTGW\n\t\t\t\t\t\tUJqX4GZUga3OsPIO+09Kso9SEmW4J3zRucsmUYFVZcJ34tCeeBt3bC1pIClbEtUZ\n\t\t\t\t\t\t1M4nHnsucufmaoO4P3k/M1pOadX8XRmpeXKILebjJx/TqzORkDeS6FFZhllv13Qw\n\t\t\t\t\t\tG/i+xOpFajMPA7nOiFBF5YXT2X5yAFGw6TSkNn1zP6vIXiPAj1nG5lpDzWp2yLvO\n\t\t\t\t\t\t86nKIfSGai7d0vsFvkCSlcRe8G5bO4rC4ajsJXg5kd46xA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "staffordcoll.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.staffordcoll.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.staffordcoll.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.staffordcoll.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.staffordcoll.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.staffordcoll.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.staffordcoll.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.staffordcoll.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.staffordcoll.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "staffordcoll.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID3jCCAsYCCQDD9aF4VF27mzANBgkqhkiG9w0BAQUFADCBsDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFjAUBgNVBAgMDVN0YWZmb3Jkc2hpcmUxETAPBgNVBAcMCFN0YWZmb3JkMRkw\n\t\t\t\t\t\tFwYDVQQKDBBTdGFmZm9yZCBDb2xsZWdlMQwwCgYDVQQLDANJVFUxHzAdBgNVBAMM\n\t\t\t\t\t\tFmlkcC5zdGFmZm9yZGNvbGwuYWMudWsxLDAqBgkqhkiG9w0BCQEWHXIubmljaG9s\n\t\t\t\t\t\tbHNAc3RhZmZvcmRjb2xsLmFjLnVrMB4XDTE0MDQxNDE2MDQzM1oXDTI0MDQxMTE2\n\t\t\t\t\t\tMDQzM1owgbAxCzAJBgNVBAYTAkdCMRYwFAYDVQQIDA1TdGFmZm9yZHNoaXJlMREw\n\t\t\t\t\t\tDwYDVQQHDAhTdGFmZm9yZDEZMBcGA1UECgwQU3RhZmZvcmQgQ29sbGVnZTEMMAoG\n\t\t\t\t\t\tA1UECwwDSVRVMR8wHQYDVQQDDBZpZHAuc3RhZmZvcmRjb2xsLmFjLnVrMSwwKgYJ\n\t\t\t\t\t\tKoZIhvcNAQkBFh1yLm5pY2hvbGxzQHN0YWZmb3JkY29sbC5hYy51azCCASIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEBBQADggEPADCCAQoCggEBALACtr71g3kiPdLfVC9EDCkmWrwkFgpq\n\t\t\t\t\t\tjY3tJSFR4+HFp1uSTI4selAUoa2JkDCXXV6Raqdl5rPb70NxpkpgUqnEJB2NfihV\n\t\t\t\t\t\trLaLiX03o95ZrO7KDVMbAvoa34arqipgZZPu7jxgNmlWpdM1FBmY7yRq2CvGHvRa\n\t\t\t\t\t\tVikoFqmEojYFWGmmnqArYx4QibTuNjxwmfVU0BTOVS7Nos9K5l4USKDrBxIuE9Qm\n\t\t\t\t\t\t8noW74ZtZzCCq2PSdZ/tj9K9EA6kEc+pI+UG7DcIFyEpmaDOXFDcOOKlAYT3MfL3\n\t\t\t\t\t\twSqg8/YPGPF9vkzk0lBv2M5YyLS9kZIaTzqkK6KLfMIR6QMYRCOrCIMCAwEAATAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACU0fU6QuYxlfW6hh6iekYfgMiVgS6oCORQR/L/to\n\t\t\t\t\t\tFJpQk0I7TDG6Gktlc5aEpsqMYQOwC99Lb8fGFQAt1g6wRyzZA8DIXnG6dQO5cTGW\n\t\t\t\t\t\tUJqX4GZUga3OsPIO+09Kso9SEmW4J3zRucsmUYFVZcJ34tCeeBt3bC1pIClbEtUZ\n\t\t\t\t\t\t1M4nHnsucufmaoO4P3k/M1pOadX8XRmpeXKILebjJx/TqzORkDeS6FFZhllv13Qw\n\t\t\t\t\t\tG/i+xOpFajMPA7nOiFBF5YXT2X5yAFGw6TSkNn1zP6vIXiPAj1nG5lpDzWp2yLvO\n\t\t\t\t\t\t86nKIfSGai7d0vsFvkCSlcRe8G5bO4rC4ajsJXg5kd46xA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Stafford College (Shibboleth)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.staffordcoll.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Stafford College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.pace.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lvaliente@pace.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lauren Valiente"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dscarano@pace.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Donna Scarano"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.pace.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.pace.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAIDwMFVZHLZMtA9SpNTVZQT/s2QcMA0GCSqGSIb3DQEB\nBQUAMB4xHDAaBgNVBAMTE3NoaWJib2xldGgucGFjZS5lZHUwHhcNMTIwOTIxMTkz\nNDU1WhcNMzIwOTIxMTkzNDU1WjAeMRwwGgYDVQQDExNzaGliYm9sZXRoLnBhY2Uu\nZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAyW3OgmQXsqS/wtC5\nsX/4lwNICfQGHUsk9m7t8VA9G5VmW81y3nZI0cwNeS2ZvVRfQsWo51/kopAS3MNy\ny6bv/mnQBquHr1cL/4SGGJePkL4GKW2KLL+KFR5Lf1QZ6It08/tWJBy95YBNOWpK\n+7sXi3v3hf+SF3D7JqRU8th6qwnYGxynnw2Kr0F7dR258l7sjpnu84ecEzresF+t\nuJzSgD1JhH8vFKUqyw4gBVvO700+Z63/9Q3JwtECxIuQ1/j6JlRe+3NwHOis2SkK\nlMzw2RezM8kq4QXETKOnxr0hCX6q3FU0cV571suawWYR2oOHzelNXheFebY026Wu\nDoQrZwIDAQABo20wazBKBgNVHREEQzBBghNzaGliYm9sZXRoLnBhY2UuZWR1hipo\ndHRwczovL3NoaWJib2xldGgucGFjZS5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0O\nBBYEFF7JGYo/Hb6pmWSoH2ZX6tYVvfToMA0GCSqGSIb3DQEBBQUAA4IBAQAheM9m\nPNR+R4sJ6gMkS5dbFuGu3o/5eH0guemCOMT+25Di/HZP2+BOj55+0hgVMmN0sFm7\njFVX/zd0LurqgCVNWu41XP/l3ybctM6bXg9XsZ/BWaXah/c4yglGzHEiulJcZyo2\nsk4EhmpFUZQXZGk3wU95X/xiX5Lgcuf9Id9gfjDG80nyd5X9PG/DOjWclGRP9KqN\nkM0iPsZNWC1xrNnNUUzrrsj2fXH3gvPuXFL1Qwrily6BtY3VekYsv4jqmM59kodg\nxe9+xuSYTj/nMFJWA8UN83T6id0A3tYIRr66BLWWQhfoNopfJPHmO7CaCJQz+16A\n908GmV+NLASTJTXX"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pace.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.pace.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.pace.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.pace.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.pace.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.pace.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pace.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Pace University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAIDwMFVZHLZMtA9SpNTVZQT/s2QcMA0GCSqGSIb3DQEB\nBQUAMB4xHDAaBgNVBAMTE3NoaWJib2xldGgucGFjZS5lZHUwHhcNMTIwOTIxMTkz\nNDU1WhcNMzIwOTIxMTkzNDU1WjAeMRwwGgYDVQQDExNzaGliYm9sZXRoLnBhY2Uu\nZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAyW3OgmQXsqS/wtC5\nsX/4lwNICfQGHUsk9m7t8VA9G5VmW81y3nZI0cwNeS2ZvVRfQsWo51/kopAS3MNy\ny6bv/mnQBquHr1cL/4SGGJePkL4GKW2KLL+KFR5Lf1QZ6It08/tWJBy95YBNOWpK\n+7sXi3v3hf+SF3D7JqRU8th6qwnYGxynnw2Kr0F7dR258l7sjpnu84ecEzresF+t\nuJzSgD1JhH8vFKUqyw4gBVvO700+Z63/9Q3JwtECxIuQ1/j6JlRe+3NwHOis2SkK\nlMzw2RezM8kq4QXETKOnxr0hCX6q3FU0cV571suawWYR2oOHzelNXheFebY026Wu\nDoQrZwIDAQABo20wazBKBgNVHREEQzBBghNzaGliYm9sZXRoLnBhY2UuZWR1hipo\ndHRwczovL3NoaWJib2xldGgucGFjZS5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0O\nBBYEFF7JGYo/Hb6pmWSoH2ZX6tYVvfToMA0GCSqGSIb3DQEBBQUAA4IBAQAheM9m\nPNR+R4sJ6gMkS5dbFuGu3o/5eH0guemCOMT+25Di/HZP2+BOj55+0hgVMmN0sFm7\njFVX/zd0LurqgCVNWu41XP/l3ybctM6bXg9XsZ/BWaXah/c4yglGzHEiulJcZyo2\nsk4EhmpFUZQXZGk3wU95X/xiX5Lgcuf9Id9gfjDG80nyd5X9PG/DOjWclGRP9KqN\nkM0iPsZNWC1xrNnNUUzrrsj2fXH3gvPuXFL1Qwrily6BtY3VekYsv4jqmM59kodg\nxe9+xuSYTj/nMFJWA8UN83T6id0A3tYIRr66BLWWQhfoNopfJPHmO7CaCJQz+16A\n908GmV+NLASTJTXX"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Pace University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.pace.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Pace University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.thestudentroom.com/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@thestudentroom.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:techies@thestudentroom.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Dept."
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.thestudentroom.com/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-01-21T09:35:48Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Student Room Group Ltd."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.thestudentroom.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Student Room Group Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.thestudentroom.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.thestudentroom.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.thestudentroom.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.thestudentroom.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.thestudentroom.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Student Room SP."
                  }
                ],
                "logo": [
                  {
                    "text": "https://static1.tsrfiles.co.uk/images/base/logo.png",
                    "height": "112",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "123"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The Student Room Group Ltd."
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sp.thestudentroom.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp.thestudentroom.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJAOQNyj4JRfiuMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\n\t\t\t\t\t\tBAMTFXNwLnRoZXN0dWRlbnRyb29tLmNvbTAeFw0xNTAxMjIxMTAyNTVaFw0yNTAx\n\t\t\t\t\t\tMTkxMTAyNTVaMCAxHjAcBgNVBAMTFXNwLnRoZXN0dWRlbnRyb29tLmNvbTCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMKvl0LQot8N6i1fvhRTGjv127ap\n\t\t\t\t\t\tIxWDJn+/vnCv7G/+UuSVJZWAUSrJB+ialjNWSTq8aV6cChi4ZbXrbvjALd7pxAop\n\t\t\t\t\t\tjhyZbU2QKO3IfJs19f+23TP4W3kK8jw8gH9qY9jbLUQR/nG3HoM5nlgIRUd0+fX0\n\t\t\t\t\t\tJiDxKq8Z3J62cE+f7eU9C+9RFq3BFju8sXK52aFyXAOMmzvSNQtNiERL2L8ep4jD\n\t\t\t\t\t\tf7Y18pKfo+mMk7tNMcJbIFzGIPHqiY1aXIlWYLNAYJY5ifcVlK5bO9kGoZHF8/wC\n\t\t\t\t\t\tDE3FWC3DEEI8GdGHyE/51wavQQAlQGPrJOkrHCASfuh4qrYLqVFo9SBJWj0CAwEA\n\t\t\t\t\t\tAaNDMEEwIAYDVR0RBBkwF4IVc3AudGhlc3R1ZGVudHJvb20uY29tMB0GA1UdDgQW\n\t\t\t\t\t\tBBRscE3ncwoF76gsgBUgGIIWI7qplTANBgkqhkiG9w0BAQUFAAOCAQEAqekMouVr\n\t\t\t\t\t\tqGq+W0OljWwinzdXO78phag5LIwKDbVzRJYpgzpscoJhHMm8BMrAA4Qkp5e0s3Qu\n\t\t\t\t\t\tWqXkHU/Io8rfU5Gq1cYWQMD4qY0Os6lsN0J51SgAAUhNzyYGn+4AXbZWsh2/CYYd\n\t\t\t\t\t\tScNd/jebhXMIBEcScQVGPIa8VQcdwX01SzwbgQR0tA6/Q2a+xvnsqcCnEkgSZFGk\n\t\t\t\t\t\tenIxKHgvQxOdL9lDDqJgsT5xmbqv7TLrwbpPHFnQwdRV5R7U3wUHmzzljbAEF8B5\n\t\t\t\t\t\tIAdwjUmiIgwi5TyEulA8NXC1w9DQuR3TBQP7NAMXYyu65JDIVqeD9Udk3vXkj87D\n\t\t\t\t\t\tvJgWzXpNHSoUNA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.thestudentroom.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp.thestudentroom.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.thestudentroom.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp.thestudentroom.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp.thestudentroom.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp.thestudentroom.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib.unl.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "phe@unl.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul Erickson"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mysupport@unl.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UNL Computer Help Center"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "bieber@unl.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brett Bieber"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "security@unl.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UNL Security Team"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://shib.unl.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.unl.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.unl.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.unl.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.unl.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVALR4hUzlhDFUyPrCzbCR8aB8/okIMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDHNoaWIudW5sLmVkdTAeFw0xMDA5MTAyMTA4MjZaFw0z\nMDA5MTAyMTA4MjZaMBcxFTATBgNVBAMTDHNoaWIudW5sLmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAJhLs+N32LNQicvVL26oZcWyU46MixkhDOdG\nh5XmzO8vWckrIPs+4LUG5U9ozfIksiYVVJW4mTl21RID0RJ9l3svZeKvEKBGrxUR\n6mQb1nQQcUPVVxNlMIZ5rlWfyffWcP686kGYTdWMU14KyflrVyFW7Vq70izKe9oT\nnX+bEclWv6KjzFayWJcIYCE4+jX7GvxSMyQTh3TRenUGOh9iukzIHlApI9bfzh89\nOdHsHy3WPmvoZYRTLeeTtG+qvzNvD+IMBNCUM9f8bRYc6N790/vBHn7kU5XSiMIv\n5sXFMt5nwNPDq3+37vY7xpu+r74tcT3HpXF5OeOPmG2OC8FSIvMCAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMc2hpYi51bmwuZWR1hiNodHRwczovL3NoaWIudW5sLmVkdS9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUTEOLq42EOS0daP8iT0PJ1kc4rMUwDQYJ\nKoZIhvcNAQEFBQADggEBAIAZpYEcXhU317hPR08os2NC3TM2K6BaNrRm53fu+tIT\nzsdHv7cfQ7ONLUE5vC0Wis6g468wGOKi01ueSrIU7emQUgQaxRoCbinUsSu1R6a1\nNP/c0ZhOo88hweNRac8zpZccjUi9Oc3WssQ/uHbkumN2hM7BhvC/4NRg5NRMWLNs\nko224ENGUqVqFkBiZJWH5ooxOM/8Gt4Ut1cTkNxyMSJvno7Gki95l0M45fNfSbWw\nvoZFOzm0IBZx1K786PNxotISs/WY/R7yJA91L0FCzrXFMh+jK5L1nCg5ZfEL0YEM\nD0DIYdBk2yItSdfimeC1/cwOOK1xLZfLs9q46OUL7UU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unl.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unl.edu/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Nebraska-Lincoln"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The University of Nebraska-Lincoln, chartered in 1869, is an educational institution of international stature. UNL is listed by the Carnegie Foundation within the \"Research Universities (very high research activity)\" category. UNL is a land-grant university and a member of the Association of Public and Land-grant Universities (APLU). The university is accredited by the Higher Learning Commission of the North Central Association of Colleges and Schools."
                  }
                ],
                "logo": [
                  {
                    "text": "https://idm.unl.edu/wdn/templates_3.0/images/logo.png",
                    "lang": "en",
                    "height": "67",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "66"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://its.unl.edu/unlprivacypolicy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Nebraska-Lincoln"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unl.edu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Nebraska-Lincoln"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://wiki.ligo.org/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "scott.koranda@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Scott Koranda"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "warren.anderson@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Warren Anderson"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rt-auth@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LIGO Identity Management Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lsc-seccomm@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LIGO Security Committee"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://wiki.ligo.org/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "LIGO Scientific Collaboration"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ligo.caltech.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LIGO Scientific Collaboration"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://wiki.ligo.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://wiki.ligo.org/Main/SPInformationURL"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "LIGO Wiki"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Primary LIGO Scientific Collaboration wiki"
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.ligo.org/SAML2/metadata/ui/ligologo80x60.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://dcc.ligo.org/cgi-bin/DocDB/ShowDocument?docid=89243"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEVjCCAz6gAwIBAgIBATANBgkqhkiG9w0BAQUFADCBhzETMBEGCgmSJomT8ixk\nARkWA29yZzEUMBIGCgmSJomT8ixkARkWBGxpZ28xDTALBgNVBAoTBExJR08xIDAe\nBgNVBAsTF0NlcnRpZmljYXRlIEF1dGhvcml0aWVzMRUwEwYDVQQLEwxXZWIgU2Vy\ndmljZXMxEjAQBgNVBAMTCUxJR08gQ0EgMTAeFw0xMDAyMDMyMDAyMTBaFw0yMDAy\nMDMyMDAyMTBaMGkxEzARBgoJkiaJk/IsZAEZFgNvcmcxFDASBgoJkiaJk/IsZAEZ\nFgRsaWdvMQ0wCwYDVQQKEwRMSUdPMRUwEwYDVQQLEwxXZWIgU2VydmljZXMxFjAU\nBgNVBAMTDXdpa2kubGlnby5vcmcwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQCsizfsa9/YZeLqX0vLLrPxFG0M1cRzSOGOpfxwo3iYPbsw08uFuYjufCaT\nfDQr9T+ZimAlpBP4+yETnYa9R/A65Zmv7ydyge8SfKIdMRY2U23PSBQKMRTp/EdC\n+LFAVZQWlKNmfb9ajrFo776dWU1ZU9NHFkX3dMTeH+BI+kRIMZnlPp7urSutuLMj\nDhoT41XufOUeJUwFm+7g1lf+cbCSPmgRGEa46gHBI+572mOCck7GN0+Zj0H74o5i\nesZrMDf08E6qsH6KnahuMuZH22L25KHULq4P9ByNFGDScvgj34HlLo91J4SzHTjS\nwx/JNBwg4V1bV4o9SGvCrRLBrSr/AgMBAAGjgekwgeYwDAYDVR0TAQH/BAIwADAO\nBgNVHQ8BAf8EBAMCBLAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMBkG\nA1UdIAQSMBAwDgYMKwYBBAGB+kYCAQIBMDkGA1UdHwQyMDAwLqAsoCqGKGh0dHA6\nLy9jYS5saWdvLm9yZy81NDE0MDRjMy81NDE0MDRjMy5jcmwwHwYDVR0jBBgwFoAU\nUm7de6pvhVwIItOXn61/I1YeatEwMAYDVR0RBCkwJ4INd2lraS5saWdvLm9yZ4EW\nc2NvdHQua29yYW5kYUBMSUdPLk9SRzANBgkqhkiG9w0BAQUFAAOCAQEAnrDCVAKE\nsv/StHC2c6VwYtrW14rgn/gmOYTWvfioYmteCuS5bqADuCN1qdNxi5nHsgXhX7UE\naaLeOKBqhNbqu+YiS/va0Kk3Azq7BS+KC0iBhHMM+ZZ86jl93ItV/xsuBc5v/AWx\njqqsEN8CN35bvZaNwm0mBARfhVll2b2T3r80mdmVbekcJKEry4H0ogGgYWNkcBt3\nrlVaEUap5FC3UzyTmKCkL65y0emhsR+6CEnmyTq5qOlMeyrgKlIJ8YXf/xj6oUaD\n6Zqf7DNzVW6gez9VkUlhivSgXaAfAZ9aJJn/aOsK3BUjJTmUCvps1F6THRr4tc0+\nfMO5DI9dhv07eg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wiki.ligo.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://wiki.ligo.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wiki.ligo.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://wiki.ligo.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "LIGO Wiki"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Primary LIGO Scientific Collaboration wiki"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:mail",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-22.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-22.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-22.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-22.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-22.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-22.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-22.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-22.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-22.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;22"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;22"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-22.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-22.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAM2Ie1tFNFQoMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0yMi5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTQ0NDE3WhcNMjQx\nMDA0MTQ0NDE3WjAhMR8wHQYDVQQDExZsYWRvazMtMjIubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAy2HDvozNEkHlvgZzEi5cJ7uY\nUiGAjQGE9OG9TzGkRlFbSe9i3yQ4Ql58jY8WDl8Y4IKcwcRJHeXRcBqJW0END1bC\n/2NbN5az7eiitNQOqHilvJnI44rv2+waQmCMaCQqrWjKbLHaxqZOIbrUWn6dbYs2\nR436ftnjGTVrOggaVI+WKDvC1Xb7Lg+SHWBz0JiBmJciJ/31ry+aeMpyYXmht5/9\nWA7eG0WxUrzTVBrHLqrv7ttm02QFhfqnSgTjN1q6LVU8CAdKlG5rHvwz7BjVdQgr\n4ef9NIfvY/NPXjiFeRdzUCbo4eNqhb9Owgy1JpMfVaF/8FHwp5miCF+rT1p/NQID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMjIubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0yMi5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUcQ9GZssn4OVCQkXo9VdxOrSwvr0wDQYJKoZIhvcNAQEFBQADggEB\nAG5I6vZKFSes7UuDSGl5LFmJh76MXpP85SoyXNlKvVeeA8o1mPYdliM2+Vvjeq8j\nPkkt7jA1vROZ9GSKbQuc78ee8XHWnIuYDW/c5L++SGif5QXFcsWG50GRmOv0/Y28\nevJ3RnMveMbXDcXVSyBqAtNEynOMT5rx7TNTNpZBKvjzYE7evzSnbhuLzs/wdutw\nSJbdq5BTzrdWKHvpYli5+38ZrFu+GHRdujixAZ8YJA7SuHisdKb6hdC0cfr92M5M\nfg3nmMBnJcjFAmgg+bPEIfg3Plb0JbxtUcq2CCNL74QwoyVswpv1Auw6ahb2eSJX\nudv5m2jOU/2r0ZbADQVJzjI="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-22.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-22.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-22.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-22.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-22.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-22.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-22.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-22.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-22.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-22.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibb1.hj.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 36 101116"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Joakim Danielsson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Joakim.Danielsson@hj.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "J\u00f6nk\u00f6ping University"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 36 101170"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Stefan Kindh"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Stefan.Kindh@hj.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "J\u00f6nk\u00f6ping University"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 36 101112"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT-Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@hj.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "J\u00f6nk\u00f6ping University"
          }
        }
      ],
      "entity_id": "https://shibb1.hj.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oasis:names:tc:SAML:attribute:assurance-certification",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUB7TrKFw9b8VuoROWwTsp8hJE5oowDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMc2hpYmIxLmhqLnNlMB4XDTA5MTAxMzA3MjcyNVoXDTI5\nMTAxMzA3MjcyNVowFzEVMBMGA1UEAxMMc2hpYmIxLmhqLnNlMIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAk5R5pnnBvG4o7SW4uekwfFNvAvGSAGUf9lOu\nf7ui6bIi2J0j4mIJXbeVdGsUbXCFUKwoJB9AfBfQm/9V3Szwxk5qHoTOFOH0Y0MS\nFCimnTUv4j2lIeab980784pyfDD2dBgMzsWmFra8JXg6Y66Ag3TXTYQOX1Bodr6W\nLff27tYfoEiUqfL1WRE3KeH2EzVaTf53zHrMwlbAifB+jhdA7AIJw9gGpMuUpzB4\nsPR5tD/M/SUJPIz37YyGbmpI3pqGoabpvZ8bBWut4Z1EnUFtd7fIwt5UMbFc4i5/\ngUL3jKpDHO7mKfZq8BstcWkgzZ1x0HHRWZFFzfowQytvHea3ewIDAQABo18wXTA8\nBgNVHREENTAzggxzaGliYjEuaGouc2WGI2h0dHBzOi8vc2hpYmIxLmhqLnNlL2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBS2nNJVvFq4dsSheCENArwBFmDmCzANBgkq\nhkiG9w0BAQUFAAOCAQEAEg326B4J0RirwToLWX/dAa5nTC2mkbzpbVnTTb06mFLp\nZEo7uIRiucdqAFhQKN6zo0GdxRnTq+9SClFxLhiuJlG7AhnoQEVe63cyVdNcmQNs\nfkeZrOpWJvTz8tWBmhmhwgMmvUgSsJE9VGBgthyoU0W46y6sQv8/fkGz4d6ThXL1\n6BXs5VYnwyXH0q5N98XvDTOEz4u892/jdWIXVsgxipFMcnAI+Kq81w0n1leqthoK\nFk3SN7U4Ui90TIxZGaNG/HIZTPwJWcbk/m9gLl+N8d1NYqzy4u4lnNYnZWca6WZ8\nnh4O/8qRXaXavKrASZvA1gmVGaA90C6rtK+zuVkU3g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hj.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibb1.hj.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibb1.hj.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibb1.hj.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibb1.hj.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibb1.hj.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibb1.hj.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibb1.hj.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibb1.hj.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hj.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://hj.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://hj.se/en.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "H\u00f6gskolan i J\u00f6nk\u00f6ping"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "J\u00f6nk\u00f6ping University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r anst\u00e4llda och studenter vid H\u00f6gskolan i J\u00f6nk\u00f6ping."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The J\u00f6nk\u00f6ping University Identity Provider is used by employees and students at the university."
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibb1.hj.se/idp/images/logo.png",
                    "lang": "sv",
                    "height": "84",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "749"
                  },
                  {
                    "text": "https://shibb1.hj.se/idp/images/logo.png",
                    "lang": "en",
                    "height": "84",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "749"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://hj.se/it-helpdesk/faq---manualer/mitt-anvandarkonto/ovrigt/gemensam-inloggningstjanst.html"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://hj.se/en/it-helpdesk/ju-faq---manuals/my-user-account/other/joint-web-login-service.html"
                  }
                ]
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "hj.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:57.7783,14.1633"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUB7TrKFw9b8VuoROWwTsp8hJE5oowDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMc2hpYmIxLmhqLnNlMB4XDTA5MTAxMzA3MjcyNVoXDTI5\nMTAxMzA3MjcyNVowFzEVMBMGA1UEAxMMc2hpYmIxLmhqLnNlMIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAk5R5pnnBvG4o7SW4uekwfFNvAvGSAGUf9lOu\nf7ui6bIi2J0j4mIJXbeVdGsUbXCFUKwoJB9AfBfQm/9V3Szwxk5qHoTOFOH0Y0MS\nFCimnTUv4j2lIeab980784pyfDD2dBgMzsWmFra8JXg6Y66Ag3TXTYQOX1Bodr6W\nLff27tYfoEiUqfL1WRE3KeH2EzVaTf53zHrMwlbAifB+jhdA7AIJw9gGpMuUpzB4\nsPR5tD/M/SUJPIz37YyGbmpI3pqGoabpvZ8bBWut4Z1EnUFtd7fIwt5UMbFc4i5/\ngUL3jKpDHO7mKfZq8BstcWkgzZ1x0HHRWZFFzfowQytvHea3ewIDAQABo18wXTA8\nBgNVHREENTAzggxzaGliYjEuaGouc2WGI2h0dHBzOi8vc2hpYmIxLmhqLnNlL2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBS2nNJVvFq4dsSheCENArwBFmDmCzANBgkq\nhkiG9w0BAQUFAAOCAQEAEg326B4J0RirwToLWX/dAa5nTC2mkbzpbVnTTb06mFLp\nZEo7uIRiucdqAFhQKN6zo0GdxRnTq+9SClFxLhiuJlG7AhnoQEVe63cyVdNcmQNs\nfkeZrOpWJvTz8tWBmhmhwgMmvUgSsJE9VGBgthyoU0W46y6sQv8/fkGz4d6ThXL1\n6BXs5VYnwyXH0q5N98XvDTOEz4u892/jdWIXVsgxipFMcnAI+Kq81w0n1leqthoK\nFk3SN7U4Ui90TIxZGaNG/HIZTPwJWcbk/m9gLl+N8d1NYqzy4u4lnNYnZWca6WZ8\nnh4O/8qRXaXavKrASZvA1gmVGaA90C6rtK+zuVkU3g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "H\u00f6gskolan i J\u00f6nk\u00f6ping"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "J\u00f6nk\u00f6ping University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hj.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HJ"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.umu.se/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 90 786 6300"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ITS datordrift"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:datordrift@its.umu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Ume\u00e5 University"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 90 786 6300"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ITS datordrift"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:datordrift@its.umu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Ume\u00e5 University"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 90 786 6300"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Servicedesk Ume\u00e5 universitet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@its.umu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Ume\u00e5 University"
          }
        }
      ],
      "entity_id": "https://idp.umu.se/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oasis:names:tc:SAML:attribute:assurance-certification",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.umu.se/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.umu.se/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.umu.se/saml2/idp/ArtifactResolutionService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "umu.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.umu.se/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.umu.se/english/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r Ume\u00e5 universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Ume\u00e5 University"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.umu.se/static/images/umu_logo.jpg",
                    "height": "63",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "358"
                  },
                  {
                    "text": "https://www.umu.se/static/images/umu_logo.jpg",
                    "lang": "sv",
                    "height": "63",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "358"
                  },
                  {
                    "text": "https://www.umu.se/static/images/umu_logo_eng.jpg",
                    "lang": "en",
                    "height": "63",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ume\u00e5 universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ume\u00e5 University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "umu.se"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.239.0.0/16"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ume\u00e5 universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ume\u00e5 University"
          }
        ],
        "organization_url": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.umu.se"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.umu.se/english"
          }
        ],
        "organization_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UmU"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UmU"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.highwire.org/entity/asmjournals",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.highwire.org/entity/asmjournals",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-09-26T17:52:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "American Society for Microbiology Journals"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://journals.asm.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HighWire Press, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.highwire.org/applications/asmjournals/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.highwire.org/applications/asmjournals/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIJAMTRVlqTJ11lMA0GCSqGSIb3DQEBBQUAMIG+MQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBD\n\t\t\t\t\t\taXR5MRcwFQYDVQQKEw5IaWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUx\n\t\t\t\t\t\tIDAeBgNVBAMTF3NoaWJib2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkB\n\t\t\t\t\t\tFiZzaGliYm9sZXRoLWFkbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTAeFw0xNDA0\n\t\t\t\t\t\tMTUxOTQzMDNaFw0yNDA0MTIxOTQzMDNaMIG+MQswCQYDVQQGEwJVUzETMBEGA1UE\n\t\t\t\t\t\tCBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBDaXR5MRcwFQYDVQQKEw5I\n\t\t\t\t\t\taWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUxIDAeBgNVBAMTF3NoaWJi\n\t\t\t\t\t\tb2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkBFiZzaGliYm9sZXRoLWFk\n\t\t\t\t\t\tbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALPB99M9iWjentrddY/rLgzKn1X0j4Ao191iyiowBBt/r/pmn2oz\n\t\t\t\t\t\tfrbONkkTVBB++mNtiufK6jyKnBM5mffPOkXHRo+K1DQec7TvpQ1PmLv/BpBgPrr9\n\t\t\t\t\t\tldViOSUnYJuB0IgJVV8oylgeH2Ay0XRkNPlBUjBA2fUPWVpXcvFe+aD2tLdVR9uO\n\t\t\t\t\t\tXvfTMxAEGqzxTU+OxO6pW2sBXNBmGvZQ0TRyovQh5+pTURY/lm0V/iWvRmRe51WE\n\t\t\t\t\t\tO/nhYyvRuMmNj8EL38o10S9TXuCkVzY00hK5cclaFge7gz/tfjmadVVcbe8xCVxc\n\t\t\t\t\t\tnb1lhmt1kH2XtKvU5hyZMTO+VUfXQvqcQyECAwEAAaN7MHkwCQYDVR0TBAIwADAs\n\t\t\t\t\t\tBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYD\n\t\t\t\t\t\tVR0OBBYEFJpUZq/XaW9/bPvjffkxX0IDvuPiMB8GA1UdIwQYMBaAFJpUZq/XaW9/\n\t\t\t\t\t\tbPvjffkxX0IDvuPiMA0GCSqGSIb3DQEBBQUAA4IBAQCq/FF56ZB1cL3KbniEJP99\n\t\t\t\t\t\tU9wTD6KpOrWxvqNbUSV1cefLf5cYHonOjy6oAJSSBSNuP7U5Q//0tXtkvlJoqGUY\n\t\t\t\t\t\tvqngmeg9wLZ/Fla3tXcDdTj0n1F+NZOx9vBDacIk0Ua4aHXDA4bdytzkV1QyZDRq\n\t\t\t\t\t\tQ8vq7RoQ8E5IF7Cll+kt2dZXQk8o6Qp3w2ppoMRtYdKOQassqn+V1MYcMPgdxZkS\n\t\t\t\t\t\tDrcgzktR/JMb5OmPrp4mSy1OWDGrFvUIigsLBPZV9tw1f7y42lnbmQas3RCS30yr\n\t\t\t\t\t\tCtUPT/PQDkCdBRViGmmMkYwjdaOTiHOJveWtrVXu8vLvO36pqFF4Kft0pgqlfvAE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.highwire.org/applications/asmjournals/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.highwire.org/applications/asmjournals/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.highwire.org/applications/asmjournals/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.highwire.org/applications/asmjournals/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.lsbu.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@lsbu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ICT Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Swigg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:swiggtc@lsbu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tom"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.lsbu.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-04-23T10:42:32Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUPksCn3BruNlalmPU1+Y/4zBDRkEwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwITEfMB0GA1UEAxMWc2hpYmJvbGV0aDIubHNidS5hYy51azAeFw0xMjAyMTMx\n\t\t\t\t\t\tMzI5NDJaFw0zMjAyMTMxMzI5NDJaMCExHzAdBgNVBAMTFnNoaWJib2xldGgyLmxz\n\t\t\t\t\t\tYnUuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQChnhct+F+F\n\t\t\t\t\t\t8yqhCpZrGgSzMVxqLQazMISxrLM+KX5+PIM5myd5MYoZ0O9JDeJF9Ww65dV7lbaw\n\t\t\t\t\t\tDlnSf1GRlQW1YD//GaeTQQYHtbx9orC7TKZF73L2nTH4NcfD/lm1jyPpNyeB8I20\n\t\t\t\t\t\tQxgIGDMmoZXqNgggmAcA8tibSiUPWP1NmiZP4fGmReqWbA1Rq9DfxwjBt4YjFvxe\n\t\t\t\t\t\t7tUnQVcEL2h5g4/RSFCwmC2O8Wsh9x4RGz4iVFpyOXZ0P96WiRShG/FnyfKXaMWe\n\t\t\t\t\t\te/zBAq0g51BcbPCVf2vELMAuH3oDKdIcyiDps7ixz+hIl9tW4g7fFeVr34eg0wj3\n\t\t\t\t\t\tOZZ2T+cyJr5pAgMBAAGjczBxMFAGA1UdEQRJMEeCFnNoaWJib2xldGgyLmxzYnUu\n\t\t\t\t\t\tYWMudWuGLWh0dHBzOi8vc2hpYmJvbGV0aDIubHNidS5hYy51ay9pZHAvc2hpYmJv\n\t\t\t\t\t\tbGV0aDAdBgNVHQ4EFgQU0DRW++Gu2kI3IgXnorvTnzWmXMQwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQADggEBAEFHkhujfcQMepjTo57cZzYSIxSYO5qvvOweEwWXKY226L1SqwOAFg0I\n\t\t\t\t\t\thqoVVuOPC2NupUK/JM9UwgR1L+rNc25Kosb0QgiLXt4kq5+fpFKu291BBRHdaHQj\n\t\t\t\t\t\t80KlkkS3H2AWyGMEFAPCBB9RpXFBOVG/Y4ed315j5KmB/DT3jYf9xBXr3RX5/6C+\n\t\t\t\t\t\t3a/VC9/mfyzUZA1tKSf+GAeS1aoNnnNVncVd4oVud+i6+rggnVbYLCT6JPtTNr38\n\t\t\t\t\t\tc913IcBFtazSONYlpG9+EtOOCn1vFzjZu3PelE4Z6aYu/AVWvhZlV6EzhXwdCyQt\n\t\t\t\t\t\tk9BFBpOxm483cpLiiSFTLULEw7NvYzs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lsbu.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth2.lsbu.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2.lsbu.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth2.lsbu.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2.lsbu.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth2.lsbu.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2.lsbu.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth2.lsbu.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2.lsbu.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lsbu.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://www.lsbu.ac.uk/clsdresources/libimages/ShibbolethLSBULogo16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://www.lsbu.ac.uk/clsdresources/libimages/ShibbolethLSBULogo.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "London South Bank University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUPksCn3BruNlalmPU1+Y/4zBDRkEwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwITEfMB0GA1UEAxMWc2hpYmJvbGV0aDIubHNidS5hYy51azAeFw0xMjAyMTMx\n\t\t\t\t\t\tMzI5NDJaFw0zMjAyMTMxMzI5NDJaMCExHzAdBgNVBAMTFnNoaWJib2xldGgyLmxz\n\t\t\t\t\t\tYnUuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQChnhct+F+F\n\t\t\t\t\t\t8yqhCpZrGgSzMVxqLQazMISxrLM+KX5+PIM5myd5MYoZ0O9JDeJF9Ww65dV7lbaw\n\t\t\t\t\t\tDlnSf1GRlQW1YD//GaeTQQYHtbx9orC7TKZF73L2nTH4NcfD/lm1jyPpNyeB8I20\n\t\t\t\t\t\tQxgIGDMmoZXqNgggmAcA8tibSiUPWP1NmiZP4fGmReqWbA1Rq9DfxwjBt4YjFvxe\n\t\t\t\t\t\t7tUnQVcEL2h5g4/RSFCwmC2O8Wsh9x4RGz4iVFpyOXZ0P96WiRShG/FnyfKXaMWe\n\t\t\t\t\t\te/zBAq0g51BcbPCVf2vELMAuH3oDKdIcyiDps7ixz+hIl9tW4g7fFeVr34eg0wj3\n\t\t\t\t\t\tOZZ2T+cyJr5pAgMBAAGjczBxMFAGA1UdEQRJMEeCFnNoaWJib2xldGgyLmxzYnUu\n\t\t\t\t\t\tYWMudWuGLWh0dHBzOi8vc2hpYmJvbGV0aDIubHNidS5hYy51ay9pZHAvc2hpYmJv\n\t\t\t\t\t\tbGV0aDAdBgNVHQ4EFgQU0DRW++Gu2kI3IgXnorvTnzWmXMQwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQADggEBAEFHkhujfcQMepjTo57cZzYSIxSYO5qvvOweEwWXKY226L1SqwOAFg0I\n\t\t\t\t\t\thqoVVuOPC2NupUK/JM9UwgR1L+rNc25Kosb0QgiLXt4kq5+fpFKu291BBRHdaHQj\n\t\t\t\t\t\t80KlkkS3H2AWyGMEFAPCBB9RpXFBOVG/Y4ed315j5KmB/DT3jYf9xBXr3RX5/6C+\n\t\t\t\t\t\t3a/VC9/mfyzUZA1tKSf+GAeS1aoNnnNVncVd4oVud+i6+rggnVbYLCT6JPtTNr38\n\t\t\t\t\t\tc913IcBFtazSONYlpG9+EtOOCn1vFzjZu3PelE4Z6aYu/AVWvhZlV6EzhXwdCyQt\n\t\t\t\t\t\tk9BFBpOxm483cpLiiSFTLULEw7NvYzs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "London South Bank University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lsbu.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "London South Bank University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.brunel.ac.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Computing-Support@brunel.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Computing Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sysweb@brunel.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Systems Web"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.brunel.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-12-23T11:55:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAN2ITPb7HnQnnS6Q5lFqSQWjQjlUMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBsxGTAXBgNVBAMTEGlkcC5icnVuZWwuYWMudWswHhcNMTMwODE5MTE0NzE5\n\t\t\t\t\t\tWhcNMzMwODE5MTE0NzE5WjAbMRkwFwYDVQQDExBpZHAuYnJ1bmVsLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnkfBXFS9PX/FYzw7I/LYOOn9\n\t\t\t\t\t\tgkCpLbs8qI8QuyxJ2klbG9RdImTz7R+WrBmAHHoaqkyOSOJYAtBb7Gh+IaD8VsvV\n\t\t\t\t\t\tGrmQt2eJJ5KKxJnam+GLg9bfJSQ5d+vnyWEubMyCRYUCFig8QTTplK6Izum0Er6L\n\t\t\t\t\t\tpON/bhJeGZiUp6zoXQaQ81jWS+/qS6hH960SxrTdqRl8E8ZJa9pRYCPUYLbUUoNt\n\t\t\t\t\t\tOewf5CD62CUTJIyk2wiz6oczWbNzkvk4ZVtccFEKdnH4G12edZzU9dLZAlquVFm5\n\t\t\t\t\t\tofSZecXeNdcpzGC1gqmJVHVKRq18aKi0SHnQLs9yom4XZ4smDSatESalOHvXVQID\n\t\t\t\t\t\tAQABo18wXTA8BgNVHREENTAzghBpZHAuYnJ1bmVsLmFjLnVrhh9odHRwczovL2lk\n\t\t\t\t\t\tcC5icnVuZWwuYWMudWsvZW50aXR5MB0GA1UdDgQWBBSjsC6Rm0NkXec+MLFab1O1\n\t\t\t\t\t\tBuP5IjANBgkqhkiG9w0BAQUFAAOCAQEAnX5jlFGsB2NFZO4VsQAp4IUNn46lxGfP\n\t\t\t\t\t\twNJHiDFKI8CB95C/LSPZjn0VVZxZgvNZrSmd+fWEsevpPymn2fme+sTHVog8zO+w\n\t\t\t\t\t\tPWmhIUfskbfJ02l3/AwtWkAougMAd5uf1j8cnNY9qjiyS459TYmz0/R5le53V8E7\n\t\t\t\t\t\tnAH57apwn9GHm9SQ06K/kP5ayMskIkptz/Bhi815NVoI5F3stNyu6oBVT4xKVXCN\n\t\t\t\t\t\t3UdINWCXCsiS4l3wREpoNON+ZcAxX+Y7PhvkYQD4XwKMZ3lXfWOHEDhzaeReClWi\n\t\t\t\t\t\tVSQUpuMp4dipeRerfQ1jhB9bZ0t09/Omp2wA2PqPJqtrQT48fpBTxA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brunel.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.brunel.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.brunel.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.brunel.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.brunel.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.brunel.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.brunel.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.brunel.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.brunel.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.brunel.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.brunel.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.brunel.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Brunel University identity provider"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.brunel.ac.uk/logo/80x60.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idp.brunel.ac.uk/logo/16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Brunel University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "134.83.0.0/16"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brunel.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAN2ITPb7HnQnnS6Q5lFqSQWjQjlUMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBsxGTAXBgNVBAMTEGlkcC5icnVuZWwuYWMudWswHhcNMTMwODE5MTE0NzE5\n\t\t\t\t\t\tWhcNMzMwODE5MTE0NzE5WjAbMRkwFwYDVQQDExBpZHAuYnJ1bmVsLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnkfBXFS9PX/FYzw7I/LYOOn9\n\t\t\t\t\t\tgkCpLbs8qI8QuyxJ2klbG9RdImTz7R+WrBmAHHoaqkyOSOJYAtBb7Gh+IaD8VsvV\n\t\t\t\t\t\tGrmQt2eJJ5KKxJnam+GLg9bfJSQ5d+vnyWEubMyCRYUCFig8QTTplK6Izum0Er6L\n\t\t\t\t\t\tpON/bhJeGZiUp6zoXQaQ81jWS+/qS6hH960SxrTdqRl8E8ZJa9pRYCPUYLbUUoNt\n\t\t\t\t\t\tOewf5CD62CUTJIyk2wiz6oczWbNzkvk4ZVtccFEKdnH4G12edZzU9dLZAlquVFm5\n\t\t\t\t\t\tofSZecXeNdcpzGC1gqmJVHVKRq18aKi0SHnQLs9yom4XZ4smDSatESalOHvXVQID\n\t\t\t\t\t\tAQABo18wXTA8BgNVHREENTAzghBpZHAuYnJ1bmVsLmFjLnVrhh9odHRwczovL2lk\n\t\t\t\t\t\tcC5icnVuZWwuYWMudWsvZW50aXR5MB0GA1UdDgQWBBSjsC6Rm0NkXec+MLFab1O1\n\t\t\t\t\t\tBuP5IjANBgkqhkiG9w0BAQUFAAOCAQEAnX5jlFGsB2NFZO4VsQAp4IUNn46lxGfP\n\t\t\t\t\t\twNJHiDFKI8CB95C/LSPZjn0VVZxZgvNZrSmd+fWEsevpPymn2fme+sTHVog8zO+w\n\t\t\t\t\t\tPWmhIUfskbfJ02l3/AwtWkAougMAd5uf1j8cnNY9qjiyS459TYmz0/R5le53V8E7\n\t\t\t\t\t\tnAH57apwn9GHm9SQ06K/kP5ayMskIkptz/Bhi815NVoI5F3stNyu6oBVT4xKVXCN\n\t\t\t\t\t\t3UdINWCXCsiS4l3wREpoNON+ZcAxX+Y7PhvkYQD4XwKMZ3lXfWOHEDhzaeReClWi\n\t\t\t\t\t\tVSQUpuMp4dipeRerfQ1jhB9bZ0t09/Omp2wA2PqPJqtrQT48fpBTxA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Brunel University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.brunel.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Brunel University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://auth.yale.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idm.techsupport@panlists.yale.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Identity Management Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idm.techsupport@panlists.yale.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Identity Management Team"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idm.techsupport@panlists.yale.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Identity Management Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://auth.yale.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://auth.yale.edu/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://auth.yale.edu/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVANUBkCs/+UH9FvRGL/Vp/l9kdXzEMA0GCSqGSIb3DQEB\nBQUAMBgxFjAUBgNVBAMTDWF1dGgueWFsZS5lZHUwHhcNMDkwOTEwMTc0NzEwWhcN\nMjkwOTEwMTc0NzEwWjAYMRYwFAYDVQQDEw1hdXRoLnlhbGUuZWR1MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmfbA8fNVeW6RJm2n9Jdos9o4eINYdMqj\nqLU0fWBs9+CHwIVb3WIyp7jhWyr+ILC6mMGvb/9TNm3vlqGPSwR3yKe5KBPlTW81\ndSUuqW6emxX1KIhQOy3ynGETcDiDzTosOYgBMynzoqkZSVDgvKn8GUnuj9V1sSwJ\n8tuiQLRu42Md+3pN0ED6bX/5wkpal5ZV5uZ2XUb0oS395BS39rAsNw7FyL72s1bT\nwMml1U1lrHOTVL1zEeuSjKjT8kBFp01Rkq7EdGtUIMswb6flZW4Ss5Kg3ufRxcnt\n2j7/OoGA6ZpD2w74R9Jk4phPoAM0nJ5mX/zKz8rU06FjHZAOHbLqEwIDAQABo2Ew\nXzA+BgNVHREENzA1gg1hdXRoLnlhbGUuZWR1hiRodHRwczovL2F1dGgueWFsZS5l\nZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFL/j9kq62w7o4+hY1Vnfvv2f8kL4\nMA0GCSqGSIb3DQEBBQUAA4IBAQASP6sIJlKHtn+bPJ/TaO2ch/pNNzeBr7ufcJzg\ntcF0hHbSegu5KlghOsdUVSke3pIThyp7Fs1kUTR7JwGJkQuplo5nbsYOXd6KhoDZ\n47omRMk0Ktm2UKvAVx1TEsQKRimFCoZvyM09M08rJBQfFqIXhdAmc4nTSnuuP4Bb\nsLIiw/Px7ck5SKU34P42sC84ZOHEipMaIvOius1kwNfXkT1WruObk76Cqhnb64QR\nGdIAn0a0g8Z+gKxllm7FIkCT7auN9E83TfvxjTXLfy6nxSAL/CtiPR4d29PvlDHn\nha4CMf2Z60YzbQ1cB5zpjHwlAyDURJtmQG3y2rHqF7/sm/aC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "yale.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://auth.yale.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.yale.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.yale.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://auth.yale.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://auth.yale.edu/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://auth.yale.edu/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "yale.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Yale University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVANUBkCs/+UH9FvRGL/Vp/l9kdXzEMA0GCSqGSIb3DQEB\nBQUAMBgxFjAUBgNVBAMTDWF1dGgueWFsZS5lZHUwHhcNMDkwOTEwMTc0NzEwWhcN\nMjkwOTEwMTc0NzEwWjAYMRYwFAYDVQQDEw1hdXRoLnlhbGUuZWR1MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmfbA8fNVeW6RJm2n9Jdos9o4eINYdMqj\nqLU0fWBs9+CHwIVb3WIyp7jhWyr+ILC6mMGvb/9TNm3vlqGPSwR3yKe5KBPlTW81\ndSUuqW6emxX1KIhQOy3ynGETcDiDzTosOYgBMynzoqkZSVDgvKn8GUnuj9V1sSwJ\n8tuiQLRu42Md+3pN0ED6bX/5wkpal5ZV5uZ2XUb0oS395BS39rAsNw7FyL72s1bT\nwMml1U1lrHOTVL1zEeuSjKjT8kBFp01Rkq7EdGtUIMswb6flZW4Ss5Kg3ufRxcnt\n2j7/OoGA6ZpD2w74R9Jk4phPoAM0nJ5mX/zKz8rU06FjHZAOHbLqEwIDAQABo2Ew\nXzA+BgNVHREENzA1gg1hdXRoLnlhbGUuZWR1hiRodHRwczovL2F1dGgueWFsZS5l\nZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFL/j9kq62w7o4+hY1Vnfvv2f8kL4\nMA0GCSqGSIb3DQEBBQUAA4IBAQASP6sIJlKHtn+bPJ/TaO2ch/pNNzeBr7ufcJzg\ntcF0hHbSegu5KlghOsdUVSke3pIThyp7Fs1kUTR7JwGJkQuplo5nbsYOXd6KhoDZ\n47omRMk0Ktm2UKvAVx1TEsQKRimFCoZvyM09M08rJBQfFqIXhdAmc4nTSnuuP4Bb\nsLIiw/Px7ck5SKU34P42sC84ZOHEipMaIvOius1kwNfXkT1WruObk76Cqhnb64QR\nGdIAn0a0g8Z+gKxllm7FIkCT7auN9E83TfvxjTXLfy6nxSAL/CtiPR4d29PvlDHn\nha4CMf2Z60YzbQ1cB5zpjHwlAyDURJtmQG3y2rHqF7/sm/aC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Yale University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.yale.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Yale University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.ktu.lt/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "SSO"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso@ktu.lt"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "KTU"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.ktu.lt/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://fedi.litnet.lt/en/policy"
              },
              {
                "lang": "lt",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://fedi.litnet.lt/lt/informacija/tvarka"
              }
            ],
            "registration_instant": "2010-07-13T06:33:00Z",
            "registration_authority": "https://fedi.litnet.lt",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.ktu.lt/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.ktu.lt/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ktu.lt"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://ktu.edu"
                  },
                  {
                    "lang": "lt",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://ktu.edu"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "KTU Single Sign On"
                  },
                  {
                    "lang": "lt",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "KTU vieningas prisijungimas"
                  }
                ],
                "logo": [
                  {
                    "text": "https://tinklas.ktu.lt/images/logo/ktu_80x88.png",
                    "height": "88",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://tinklas.ktu.lt/images/logo/ktu_80x88.png",
                    "height": "88",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://tinklas.ktu.lt/images/logo/ktu_16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://tinklas.ktu.lt/images/logo/ktu_16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kaunas University of Technology"
                  },
                  {
                    "lang": "lt",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kauno technologijos universitetas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "ktu.lt"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "ktu.edu"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:54.898986,23.912564"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:54.899057,23.917424"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:54.898912,23.921925"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:54.905337,23.951043"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:54.905435,23.956579"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:54.901102,23.960211"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "158.129.0.0/19"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "158.129.32.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "83.171.8.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "83.171.15.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "83.171.18.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "83.171.20.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.219.32.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.219.36.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.219.61.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.219.63.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.219.66.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.219.68.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.219.74.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.219.154.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.219.156.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.219.160.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.219.170.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.219.174.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.219.176.0/25"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.219.184.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:778:200::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIElTCCA32gAwIBAgIJALYznSATuns+MA0GCSqGSIb3DQEBBQUAMIGNMQswCQYD\nVQQGEwJMVDEPMA0GA1UECBMGS2F1bmFzMQ8wDQYDVQQHEwZLYXVuYXMxKjAoBgNV\nBAoTIUthdW5vIHRlY2hub2xvZ2lqb3MgdW5pdmVyc2l0ZXRhczEVMBMGA1UEAxMM\nbG9naW4ua3R1Lmx0MRkwFwYJKoZIhvcNAQkBFgpzc29Aa3R1Lmx0MB4XDTE0MDgw\nNDEzMDY0MFoXDTI0MDgwMzEzMDY0MFowgY0xCzAJBgNVBAYTAkxUMQ8wDQYDVQQI\nEwZLYXVuYXMxDzANBgNVBAcTBkthdW5hczEqMCgGA1UEChMhS2F1bm8gdGVjaG5v\nbG9naWpvcyB1bml2ZXJzaXRldGFzMRUwEwYDVQQDEwxsb2dpbi5rdHUubHQxGTAX\nBgkqhkiG9w0BCQEWCnNzb0BrdHUubHQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQCr3YT9UZdS87hoUW2O+nElhco6e1mSJnCVfDXliqaOAv421+khPEqJ\nuKeL1pCeDNHpSlcbVlmdNiwb3SZGUxaXoenTFxaqCZPV09Ggny5f9YBkEzaDOJpB\n3yGfvbhyrmoRM6zeziATUJiHcns395XuJwd2nwbkNGwY4u4BO7ennVZeQR2r9GOy\nL+yz3Kly+q8YhIEw0DBXYoPXKhfHBr+otszV9CRXCgnDgVQ7lqqMbxJiK/n7skd1\nWLRjxxIuTBh3UfTSKmmy3RqwA/NlUYl5Uh42GFE/D0UlKYwzNoBjsV7QXkkmMf8v\nUiy/x7Tj6PM4zsg716AOafJCPESSuKQJAgMBAAGjgfUwgfIwHQYDVR0OBBYEFMCp\n68JzkZdFKWHkjPn0XTCo98WhMIHCBgNVHSMEgbowgbeAFMCp68JzkZdFKWHkjPn0\nXTCo98WhoYGTpIGQMIGNMQswCQYDVQQGEwJMVDEPMA0GA1UECBMGS2F1bmFzMQ8w\nDQYDVQQHEwZLYXVuYXMxKjAoBgNVBAoTIUthdW5vIHRlY2hub2xvZ2lqb3MgdW5p\ndmVyc2l0ZXRhczEVMBMGA1UEAxMMbG9naW4ua3R1Lmx0MRkwFwYJKoZIhvcNAQkB\nFgpzc29Aa3R1Lmx0ggkAtjOdIBO6ez4wDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0B\nAQUFAAOCAQEAdpZ936wIu3ArrlB0/+RL5FreCZnnXhvxSOGWUZzrzq143BXnClnd\n/i9oZMMz5C4apRk6f7USWQZFeYrzSb8dpSjgJUYXPcCT5REf+u2aMOoPtmwGGg+z\nkQKY18WZYC3BW4LPwzNocH3YYBhPrxTkKX/d+xjGM9/b0yOCwdJjj0BlwXq5unq0\nLIK49aSIyuHwA23d+drva9TON936JL4SEqchA2hbnws1elOJNIiykHUJfKqYy/dY\n9rqRSx+Hf8gsa2TNLU3sl57neVdLF6p6w/3g4mjB111B4U382kXULKO7Y+J1uffk\nJ71sGBdRWsvH09i0ReJWzbWxAtF2jtzfkw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIElTCCA32gAwIBAgIJALYznSATuns+MA0GCSqGSIb3DQEBBQUAMIGNMQswCQYD\nVQQGEwJMVDEPMA0GA1UECBMGS2F1bmFzMQ8wDQYDVQQHEwZLYXVuYXMxKjAoBgNV\nBAoTIUthdW5vIHRlY2hub2xvZ2lqb3MgdW5pdmVyc2l0ZXRhczEVMBMGA1UEAxMM\nbG9naW4ua3R1Lmx0MRkwFwYJKoZIhvcNAQkBFgpzc29Aa3R1Lmx0MB4XDTE0MDgw\nNDEzMDY0MFoXDTI0MDgwMzEzMDY0MFowgY0xCzAJBgNVBAYTAkxUMQ8wDQYDVQQI\nEwZLYXVuYXMxDzANBgNVBAcTBkthdW5hczEqMCgGA1UEChMhS2F1bm8gdGVjaG5v\nbG9naWpvcyB1bml2ZXJzaXRldGFzMRUwEwYDVQQDEwxsb2dpbi5rdHUubHQxGTAX\nBgkqhkiG9w0BCQEWCnNzb0BrdHUubHQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQCr3YT9UZdS87hoUW2O+nElhco6e1mSJnCVfDXliqaOAv421+khPEqJ\nuKeL1pCeDNHpSlcbVlmdNiwb3SZGUxaXoenTFxaqCZPV09Ggny5f9YBkEzaDOJpB\n3yGfvbhyrmoRM6zeziATUJiHcns395XuJwd2nwbkNGwY4u4BO7ennVZeQR2r9GOy\nL+yz3Kly+q8YhIEw0DBXYoPXKhfHBr+otszV9CRXCgnDgVQ7lqqMbxJiK/n7skd1\nWLRjxxIuTBh3UfTSKmmy3RqwA/NlUYl5Uh42GFE/D0UlKYwzNoBjsV7QXkkmMf8v\nUiy/x7Tj6PM4zsg716AOafJCPESSuKQJAgMBAAGjgfUwgfIwHQYDVR0OBBYEFMCp\n68JzkZdFKWHkjPn0XTCo98WhMIHCBgNVHSMEgbowgbeAFMCp68JzkZdFKWHkjPn0\nXTCo98WhoYGTpIGQMIGNMQswCQYDVQQGEwJMVDEPMA0GA1UECBMGS2F1bmFzMQ8w\nDQYDVQQHEwZLYXVuYXMxKjAoBgNVBAoTIUthdW5vIHRlY2hub2xvZ2lqb3MgdW5p\ndmVyc2l0ZXRhczEVMBMGA1UEAxMMbG9naW4ua3R1Lmx0MRkwFwYJKoZIhvcNAQkB\nFgpzc29Aa3R1Lmx0ggkAtjOdIBO6ez4wDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0B\nAQUFAAOCAQEAdpZ936wIu3ArrlB0/+RL5FreCZnnXhvxSOGWUZzrzq143BXnClnd\n/i9oZMMz5C4apRk6f7USWQZFeYrzSb8dpSjgJUYXPcCT5REf+u2aMOoPtmwGGg+z\nkQKY18WZYC3BW4LPwzNocH3YYBhPrxTkKX/d+xjGM9/b0yOCwdJjj0BlwXq5unq0\nLIK49aSIyuHwA23d+drva9TON936JL4SEqchA2hbnws1elOJNIiykHUJfKqYy/dY\n9rqRSx+Hf8gsa2TNLU3sl57neVdLF6p6w/3g4mjB111B4U382kXULKO7Y+J1uffk\nJ71sGBdRWsvH09i0ReJWzbWxAtF2jtzfkw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "lt",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Kauno technologijos universitetas"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Kaunas University of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "lt",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://ktu.edu/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://ktu.edu"
          }
        ],
        "organization_name": [
          {
            "lang": "lt",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Kauno technologijos universitetas"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Kaunas University of Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://emrex-00.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://emrex-00.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://emrex-00.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://emrex-00.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://emrex-00.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://emrex-00.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://emrex-00.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://emrex-00.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://emrex-00.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "EMREX-projektet st\u00c3\u00b6djer EU:s m\u00c3\u00a5l f\u00c3\u00b6r 2020 att 20% av h\u00c3\u00b6gskolestuderande ska kunna vara mobila under studietiden."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The EMREX project addresses the EU 2020 target that 20% of higher education students should be mobile during their studies."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EMREX utvecklingsmilj\u00c3\u00b6, emrex-00"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EMREX development site, emrex-00"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "emrex-00.ladok.umu.se"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://emrex-00.ladok.umu.se/gui-sp"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAO51qT/SycRFMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\nBAMTFWVtcmV4LTAwLmxhZG9rLnVtdS5zZTAeFw0xNTA2MDQxNjAwMzJaFw0yNTA2\nMDExNjAwMzJaMCAxHjAcBgNVBAMTFWVtcmV4LTAwLmxhZG9rLnVtdS5zZTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM5bN8is/3EaYkeG3ZUdw32WNOtC\nzZwwWTe4cU3Jswz0A+GsoFwuF6/QrePdWB5PuulnunWFYgybFlcj3kWnTZVE5FiJ\n85eULp5tfwg/+qidwDoe+iE4Ya50L/yDdgMG99KzV0xySMRdb3iDcDtXnJM7uCWx\n6VQtG1KrykljRjpK+4wuBuD18n9uKjlnIE2WFfDp8vERd+57Yh+EoY7HvJg1PTwQ\nc1Bk7678bFIzjHiPQqKiSvHm6qUeE3rD6qUjob3gE/sVKtrzBQ6o+L7cLD4DKdHj\nPkSSWjQz1IuDAFlMKd611qd7QvB4rbJM0RVrZIxVTJUeANx8kI2gOZEISAcCAwEA\nAaNpMGcwRgYDVR0RBD8wPYIVZW1yZXgtMDAubGFkb2sudW11LnNlhiRodHRwczov\nL2VtcmV4LTAwLmxhZG9rLnVtdS5zZS9ndWktc3AwHQYDVR0OBBYEFP9bneOWWhRo\nBtSJigKJadlY0UPgMA0GCSqGSIb3DQEBBQUAA4IBAQAP8nDEv72+pNBMxDtGXght\nIOAsrTRLaWYeqoAjWqbW8NL9PCEXRHHqIUHyacgwbhFBM/VHe7fZk3oSjqL6KkF5\nFu9+ODX0/AZL2Kgln18qIw4yiarnOoL1co1sMhBtoO0h+gEQCOXySaErtJna00z/\nRmpQgB7uSYC6/Y3qqkvJWoBEsHHvJ+9hu35vrSjOsnI3xt2b/ZlBrLQ2ucIobcG2\nfrdB89xfIAiqXK4vq4/GaUgDgDpgzMYkJr82Yg16L+aEr6bpZJzfuYhrl18aSWZK\nl/WPpySp4NeKwiXjvFFpBhNHYBAgs2YKs+JHu2PwqTLEiYZFIp0ZYJBIsl9u4Gp0"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=emrex-00.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://emrex-00.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://emrex-00.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://emrex-00.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://emrex-00.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://emrex-00.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://emrex-00.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://emrex-00.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://emrex-00.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://emrex-00.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.mkcollege.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.mkcollege.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/mkcollege.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/mkcollege.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mkcollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Milton Keynes College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mkcollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ssotesteu.eu.qualtrics.com/WRSAML/simplesaml/www/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth@qualtrics.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Administrator"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ssotesteu.eu.qualtrics.com/WRSAML/simplesaml/www/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Qualtrics"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qualtrics.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Qualtrics LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ssotesteu.eu.qualtrics.com/WRSAML/simplesaml/www/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://ssotesteu.eu.qualtrics.com/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Qualtrics Surveys Test instance"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Qualtrics Test SP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFbDCCA1QCCQC8OqKPlGUkRDANBgkqhkiG9w0BAQUFADBoMQswCQYDVQQGEwJV\nUzENMAsGA1UECBMEVXRhaDEOMAwGA1UEBxMFUHJvdm8xGDAWBgNVBAoTD1F1YWx0\ncmljcywgSW5jLjEgMB4GCSqGSIb3DQEJARYRZGJhQHF1YWx0cmljcy5jb20wHhcN\nMTAwNDA3MTkzMzA0WhcNMjAwNDA3MTkzMzA0WjCBhzELMAkGA1UEBhMCVVMxDTAL\nBgNVBAgTBFV0YWgxDjAMBgNVBAcTBVByb3ZvMRgwFgYDVQQKEw9RdWFsdHJpY3Ms\nIEluYy4xGDAWBgNVBAMMDyoucXVhbHRyaWNzLmNvbTElMCMGCSqGSIb3DQEJARYW\nc3NvYWRtaW5AcXVhbHRyaWNzLmNvbTCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCC\nAgoCggIBAM7T6YYEDd91lehKK/51V3Li6zk/wqHZ1OZ4rHw22AtTasl0qrEwdXbL\nsCUmO4rEXhAnjgpIZPFHs+1sFpSCalerYa+ROJX5B5N9MnENYr6E8KHa8spbVBEl\n2/ZE6RlPdHBs+iCDuoTTqOa2sZ8vqTpTF3grVdgeW3KfBOO9yENa04lA6xhPAQs3\nkihDQvPoWnlXtQA3gmtb+sGZmKYXonBVwIDsrDbhpoFcHJJRrFEEawSHOI3IeHBo\nhR1jhfb95E3cQ0s7gQ+FbR+lkzwb3i3WrCkZr3w2KpudJEzy/kT7JBLvfELW8eR4\nj2XRKyRhxNHOKc/AC8fNIrGam0CAqK9elpJnB6zmALQUYXVGddv3sd9ITIfZQ9Ox\ng9ChVqsNAY6VIlg5+/Q3Ega+BR/P/OpMnG9xW+cyLslzjiUf4c0K6I2pObcJkJMw\nqGHOSbD9lGa/WxaEAFC1+6oDNRbC3S2mbo4gW6LPVbtCxC0IMxOyaOKBwe3sW9v+\nrumd02ZuJRtbTbarde7N6aUmm2hXfDQntCIXWUJ+9b+YvjcWUlUN0KvVq8jFn1Z7\nkD1po2eY+lc9VHYoh1jdP08G9H8CZdJTDwR4KDPG0U2rD+xXmxO+9CEeQev1d/Iu\nqcadQxRka7hbhIijtVJgjO3jP6AwiHXFGpBvApyIuuXJU8CyKSsXAgMBAAEwDQYJ\nKoZIhvcNAQEFBQADggIBAAcXtiFXJ5Vm0mwhiDRoTGwIGz+Ryg13X6X9w6GfVENt\nNexDExwzPgxnW1gG7u9FUx2tl2geZ8BJOqk3pGnLSZI4QF/nVnB+hTPMLOwXjtMk\nMF5FXlM7QvOKOTzzK7+2wug2ssZi5ZpQVGODhPsytu+GjMJwydLj6RRAnJV/9wmu\nivZhIbQyrOs0XBxuYO0n9OzlOa9JVFtUxnckT93UYIjcCVEu2r+m20Zm8BEofKTr\nTz3vodizFV5uHbmQ19iLxDrZsu9rbpEHojWMgnKnq1XoC7TmlxB1/OQctUnjpRPT\nWySZkTdWX4cKBjQHzCHJyl0Z4hAP4m3fWFLXVK3w8U1e+Mbfm0jUT9+amUfdzL+8\n9ZjwnFvpuFNWsS33yYWp51+rVdtU0jYII1f8XWNRn4EV54MwoOWrEXKDZ0qmbxi5\nnVR/F5QofEGv/ZYMgcFaX5OMP5lRE8IjQu9Eq26zZA6YuR5fZfiTHZppwc6Ey9Zc\nGpRsLwFSwma0/Vtlfxr/KtaKsk2zlOOJ6RF33MUyZvw8N+tybY0yHJ40aBZKFr9r\nr3j//DUU8zi4qvNP5z19kS08sZ7mtNK2sKBPWVSYB2HDtyrBSRupHBYeIxlfGKd6\nuVUusHTyyVjDKbuMHCw+DEp0VXmCIAv5Jf+SKZ7DOkw8cxcdL67gEc9NjAmsfmKy"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFbDCCA1QCCQC8OqKPlGUkRDANBgkqhkiG9w0BAQUFADBoMQswCQYDVQQGEwJV\nUzENMAsGA1UECBMEVXRhaDEOMAwGA1UEBxMFUHJvdm8xGDAWBgNVBAoTD1F1YWx0\ncmljcywgSW5jLjEgMB4GCSqGSIb3DQEJARYRZGJhQHF1YWx0cmljcy5jb20wHhcN\nMTAwNDA3MTkzMzA0WhcNMjAwNDA3MTkzMzA0WjCBhzELMAkGA1UEBhMCVVMxDTAL\nBgNVBAgTBFV0YWgxDjAMBgNVBAcTBVByb3ZvMRgwFgYDVQQKEw9RdWFsdHJpY3Ms\nIEluYy4xGDAWBgNVBAMMDyoucXVhbHRyaWNzLmNvbTElMCMGCSqGSIb3DQEJARYW\nc3NvYWRtaW5AcXVhbHRyaWNzLmNvbTCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCC\nAgoCggIBAM7T6YYEDd91lehKK/51V3Li6zk/wqHZ1OZ4rHw22AtTasl0qrEwdXbL\nsCUmO4rEXhAnjgpIZPFHs+1sFpSCalerYa+ROJX5B5N9MnENYr6E8KHa8spbVBEl\n2/ZE6RlPdHBs+iCDuoTTqOa2sZ8vqTpTF3grVdgeW3KfBOO9yENa04lA6xhPAQs3\nkihDQvPoWnlXtQA3gmtb+sGZmKYXonBVwIDsrDbhpoFcHJJRrFEEawSHOI3IeHBo\nhR1jhfb95E3cQ0s7gQ+FbR+lkzwb3i3WrCkZr3w2KpudJEzy/kT7JBLvfELW8eR4\nj2XRKyRhxNHOKc/AC8fNIrGam0CAqK9elpJnB6zmALQUYXVGddv3sd9ITIfZQ9Ox\ng9ChVqsNAY6VIlg5+/Q3Ega+BR/P/OpMnG9xW+cyLslzjiUf4c0K6I2pObcJkJMw\nqGHOSbD9lGa/WxaEAFC1+6oDNRbC3S2mbo4gW6LPVbtCxC0IMxOyaOKBwe3sW9v+\nrumd02ZuJRtbTbarde7N6aUmm2hXfDQntCIXWUJ+9b+YvjcWUlUN0KvVq8jFn1Z7\nkD1po2eY+lc9VHYoh1jdP08G9H8CZdJTDwR4KDPG0U2rD+xXmxO+9CEeQev1d/Iu\nqcadQxRka7hbhIijtVJgjO3jP6AwiHXFGpBvApyIuuXJU8CyKSsXAgMBAAEwDQYJ\nKoZIhvcNAQEFBQADggIBAAcXtiFXJ5Vm0mwhiDRoTGwIGz+Ryg13X6X9w6GfVENt\nNexDExwzPgxnW1gG7u9FUx2tl2geZ8BJOqk3pGnLSZI4QF/nVnB+hTPMLOwXjtMk\nMF5FXlM7QvOKOTzzK7+2wug2ssZi5ZpQVGODhPsytu+GjMJwydLj6RRAnJV/9wmu\nivZhIbQyrOs0XBxuYO0n9OzlOa9JVFtUxnckT93UYIjcCVEu2r+m20Zm8BEofKTr\nTz3vodizFV5uHbmQ19iLxDrZsu9rbpEHojWMgnKnq1XoC7TmlxB1/OQctUnjpRPT\nWySZkTdWX4cKBjQHzCHJyl0Z4hAP4m3fWFLXVK3w8U1e+Mbfm0jUT9+amUfdzL+8\n9ZjwnFvpuFNWsS33yYWp51+rVdtU0jYII1f8XWNRn4EV54MwoOWrEXKDZ0qmbxi5\nnVR/F5QofEGv/ZYMgcFaX5OMP5lRE8IjQu9Eq26zZA6YuR5fZfiTHZppwc6Ey9Zc\nGpRsLwFSwma0/Vtlfxr/KtaKsk2zlOOJ6RF33MUyZvw8N+tybY0yHJ40aBZKFr9r\nr3j//DUU8zi4qvNP5z19kS08sZ7mtNK2sKBPWVSYB2HDtyrBSRupHBYeIxlfGKd6\nuVUusHTyyVjDKbuMHCw+DEp0VXmCIAv5Jf+SKZ7DOkw8cxcdL67gEc9NjAmsfmKy"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ssotesteu.eu.qualtrics.com/WRSAML/simplesaml/www/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ssotesteu.eu.qualtrics.com/WRSAML/simplesaml/www/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ssotesteu.eu.qualtrics.com/WRSAML/simplesaml/www/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ssotesteu.eu.qualtrics.com/WRSAML/simplesaml/www/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Qualtrics Test SP"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Qualtrics Surveys Test instance"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "organizationName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.grimsby.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lilley"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lilleyf@grimsby.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Fiona"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Clarkson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:clarksonbc@grimsby.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Barry"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.grimsby.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-07-23T09:44:56Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.grimsby.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.grimsby.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "grimsby.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDhDCCAmygAwIBAgIIH70XfscAcqYwDQYJKoZIhvcNAQEFBQAwWTE7MDkGA1UE\n\t\t\t\t\t\t\tCgwyR3JpbXNieSBJbnN0aXR1dGUgZm9yIEZ1cnRoZXIgYW5kIEhpZ2hlciBFZHVj\n\t\t\t\t\t\t\tYXRpb24xGjAYBgNVBAMMEWlkcC5ncmltc2J5LmFjLnVrMB4XDTE0MDYwMzEzMjky\n\t\t\t\t\t\t\tOVoXDTI0MDYwMzEzMjkyOVowWTE7MDkGA1UECgwyR3JpbXNieSBJbnN0aXR1dGUg\n\t\t\t\t\t\t\tZm9yIEZ1cnRoZXIgYW5kIEhpZ2hlciBFZHVjYXRpb24xGjAYBgNVBAMMEWlkcC5n\n\t\t\t\t\t\t\tcmltc2J5LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAh+gq\n\t\t\t\t\t\t\t7zDrrAi7jZFx0cUlhbbcxUFDR1oTGlXf/jPDjKWavaIM/Gl1iQ9mrQVLmkH/W/IA\n\t\t\t\t\t\t\tVbk6sofrhnmzadRKq0OT4Vui4IjjeeYGYvTq5naNE+oh+W4au1oZOMQeglgIDhWd\n\t\t\t\t\t\t\tZGmimiq7k/t82K/84z6rD33/2Jt6wPZmynrhdNA0DWTGM6Ri0RQNT1SFbCousvhm\n\t\t\t\t\t\t\tG4eGvfK/rlRbouRQjRoBFOW8tdJk2fIwczS5xJoDCPP+1awIIVUYHBM1rhORFtTS\n\t\t\t\t\t\t\tsn/YWlvAp0ZahXuN/KUXtV6HQz70+LX7qPT1G3Pj2PJll+hMUD14OpMOVR0kB6MJ\n\t\t\t\t\t\t\tvHxF37Ux4DsMQRh27wIDAQABo1AwTjAdBgNVHQ4EFgQUaZXT/v4e36tmutKwfdoU\n\t\t\t\t\t\t\tM0KH9acwHwYDVR0jBBgwFoAUaZXT/v4e36tmutKwfdoUM0KH9acwDAYDVR0TBAUw\n\t\t\t\t\t\t\tAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEARhiT5E/0HuU6FcdPenL+PXlWODHxeISi\n\t\t\t\t\t\t\tw5idnZGVCiWCR+KNz+OEzF+aiQdIFDO3hAb/MGFJ8CPFEogdApZJouRmHxz8i3Y6\n\t\t\t\t\t\t\t0tuSDLJpI1t4hs2Be+PrXGHueK4+srZfpca2ns3s8Jp61r353iG+qLV1V8iQmxKy\n\t\t\t\t\t\t\tD4IlEvMsstT1ICScNeItMIb4O515zxNix+hf2CdEK5yknZSvdeYfk3A/Dgh8o4FZ\n\t\t\t\t\t\t\tlDzym0z/+t36nVPVTlYDzeOXN/e9B2LLzJwRmLG87VZj+pA3pjBKIu341QzZ1pz+\n\t\t\t\t\t\t\tnWsg1LPp3/B6n72ejbSVL5kmuwr5dWE4gcD9xLNAz2LrGPyA/ziZhw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDhDCCAmygAwIBAgIIH70XfscAcqYwDQYJKoZIhvcNAQEFBQAwWTE7MDkGA1UE\n\t\t\t\t\t\t\tCgwyR3JpbXNieSBJbnN0aXR1dGUgZm9yIEZ1cnRoZXIgYW5kIEhpZ2hlciBFZHVj\n\t\t\t\t\t\t\tYXRpb24xGjAYBgNVBAMMEWlkcC5ncmltc2J5LmFjLnVrMB4XDTE0MDYwMzEzMjky\n\t\t\t\t\t\t\tOVoXDTI0MDYwMzEzMjkyOVowWTE7MDkGA1UECgwyR3JpbXNieSBJbnN0aXR1dGUg\n\t\t\t\t\t\t\tZm9yIEZ1cnRoZXIgYW5kIEhpZ2hlciBFZHVjYXRpb24xGjAYBgNVBAMMEWlkcC5n\n\t\t\t\t\t\t\tcmltc2J5LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAh+gq\n\t\t\t\t\t\t\t7zDrrAi7jZFx0cUlhbbcxUFDR1oTGlXf/jPDjKWavaIM/Gl1iQ9mrQVLmkH/W/IA\n\t\t\t\t\t\t\tVbk6sofrhnmzadRKq0OT4Vui4IjjeeYGYvTq5naNE+oh+W4au1oZOMQeglgIDhWd\n\t\t\t\t\t\t\tZGmimiq7k/t82K/84z6rD33/2Jt6wPZmynrhdNA0DWTGM6Ri0RQNT1SFbCousvhm\n\t\t\t\t\t\t\tG4eGvfK/rlRbouRQjRoBFOW8tdJk2fIwczS5xJoDCPP+1awIIVUYHBM1rhORFtTS\n\t\t\t\t\t\t\tsn/YWlvAp0ZahXuN/KUXtV6HQz70+LX7qPT1G3Pj2PJll+hMUD14OpMOVR0kB6MJ\n\t\t\t\t\t\t\tvHxF37Ux4DsMQRh27wIDAQABo1AwTjAdBgNVHQ4EFgQUaZXT/v4e36tmutKwfdoU\n\t\t\t\t\t\t\tM0KH9acwHwYDVR0jBBgwFoAUaZXT/v4e36tmutKwfdoUM0KH9acwDAYDVR0TBAUw\n\t\t\t\t\t\t\tAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEARhiT5E/0HuU6FcdPenL+PXlWODHxeISi\n\t\t\t\t\t\t\tw5idnZGVCiWCR+KNz+OEzF+aiQdIFDO3hAb/MGFJ8CPFEogdApZJouRmHxz8i3Y6\n\t\t\t\t\t\t\t0tuSDLJpI1t4hs2Be+PrXGHueK4+srZfpca2ns3s8Jp61r353iG+qLV1V8iQmxKy\n\t\t\t\t\t\t\tD4IlEvMsstT1ICScNeItMIb4O515zxNix+hf2CdEK5yknZSvdeYfk3A/Dgh8o4FZ\n\t\t\t\t\t\t\tlDzym0z/+t36nVPVTlYDzeOXN/e9B2LLzJwRmLG87VZj+pA3pjBKIu341QzZ1pz+\n\t\t\t\t\t\t\tnWsg1LPp3/B6n72ejbSVL5kmuwr5dWE4gcD9xLNAz2LrGPyA/ziZhw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Grimsby Institute of Further & Higher Education (test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.grimsby.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Grimsby Institute of Further and Higher Education"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib-idp.hs-osnabrueck.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Beining"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:b.beining@hs-osnabrueck.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bernd"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "M\u00f6ller"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:s.moeller@hs-osnabrueck.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sebastian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "M\u00f6ller"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:s.moeller@hs-osnabrueck.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sebastian"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib-idp.hs-osnabrueck.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2016-01-20T09:45:41Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shib-idp.hs-osnabrueck.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIHSjCCBjKgAwIBAgIHGmQuE/sKwDANBgkqhkiG9w0BAQsFADCBkTELMAkGA1UE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"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=shib-idp.hs-osnabrueck.de,OU=Zentrale IT,O=Hochschule Osnabrueck,L=Osnabrueck,ST=Niedersachsen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hs-osnabrueck.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-idp.hs-osnabrueck.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.hs-osnabrueck.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib-idp.hs-osnabrueck.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-idp.hs-osnabrueck.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib-idp.hs-osnabrueck.de/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-idp.hs-osnabrueck.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-idp.hs-osnabrueck.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.hs-osnabrueck.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hs-osnabrueck.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.hs-osnabrueck.de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.hs-osnabrueck.de"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hochschule Osnabr\u00fcck University of Applied Sciences"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hochschule Osnabr\u00fcck University of Applied Sciences"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hochschule Osnabr\u00fcck"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hochschule Osnabr\u00fcck"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shib-idp.hs-osnabrueck.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIHSjCCBjKgAwIBAgIHGmQuE/sKwDANBgkqhkiG9w0BAQsFADCBkTELMAkGA1UE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"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=shib-idp.hs-osnabrueck.de,OU=Zentrale IT,O=Hochschule Osnabrueck,L=Osnabrueck,ST=Niedersachsen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hochschule Osnabr\u00fcck"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hochschule Osnabr\u00fcck"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hs-osnabrueck.de/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hs-osnabrueck.de/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e495"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e495"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.nrc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@nrc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Brown"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Alan.Brown@nrc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.nrc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-03-20T16:24:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDcjCCAloCCQDyu2TVCpnwTjANBgkqhkiG9w0BAQUFADB7MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEZMBcGA1UECBMQTm9ydGhlcm4gSXJlbGFuZDEVMBMGA1UEBxMMTmV3dG93bmFi\n\t\t\t\t\t\tYmV5MSIwIAYDVQQKExlOb3J0aGVybiBSZWdpb25hbCBDb2xsZWdlMRYwFAYDVQQD\n\t\t\t\t\t\tEw1pZHAubnJjLmFjLnVrMB4XDTE0MDYxODEzMjQzM1oXDTM0MDYxMzEzMjQzM1ow\n\t\t\t\t\t\tezELMAkGA1UEBhMCR0IxGTAXBgNVBAgTEE5vcnRoZXJuIElyZWxhbmQxFTATBgNV\n\t\t\t\t\t\tBAcTDE5ld3Rvd25hYmJleTEiMCAGA1UEChMZTm9ydGhlcm4gUmVnaW9uYWwgQ29s\n\t\t\t\t\t\tbGVnZTEWMBQGA1UEAxMNaWRwLm5yYy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQAD\n\t\t\t\t\t\tggEPADCCAQoCggEBAPVbAHe9mFv4n0AFnhR7uN3oetmnyGocFxSVR/3uZVNQWaqx\n\t\t\t\t\t\tKRZpNawsVdiAQqMP6x9+ymD6e0EKO2YKZSXWvbPxxwG4dwVpJcAy6jYoe71G7Qq1\n\t\t\t\t\t\tMQxohxtLPMk5hZ4DVTt1xSMc+ZRVr1cE6vlHhC9r6LBmyaoxj+wc+U4/i6dyKs+o\n\t\t\t\t\t\twQufX7iIN1G3vDXsBA9sqlxUCdlfUdhbmri/Vf4U6tzYyF3l0txyZejlsmbHDZA0\n\t\t\t\t\t\toSrc+3VxosQeJ4irf5yNePeHzCWp0v75tEfLERg/1vIxfEO8nh9Rr3r4tHEKK77G\n\t\t\t\t\t\tYl9oU0N7rgQvOGwfuQerFKzSHWv7ZOPXMT77iwkCAwEAATANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAblCurjRGhUqdFuDlW1TEYNiCLADfS3uuWV+KhUDiQ7zLBdMxD5DpN++v\n\t\t\t\t\t\tagA4nHoUz+EsYXrD4VPzD1RuPaRuEjSL9hS0UxiRrOR1hIvnAC63H9pi2waZ53hp\n\t\t\t\t\t\tuMiDVtG0WomR/pJW3puaZs5N/bFL2ZWBvqqaRU0zc9nz4S0odmN+pfSqsrr/Y+JL\n\t\t\t\t\t\t4s89ev740ocq4FAq6zMwMDjeYvXDx7OibZ0Omq8S1/zPz3yXIM9/mvCm/iOBKxrO\n\t\t\t\t\t\tfe41HZlxy6Kdw+f/F7agDCNyNUAhC2zaYCWvSgFieJ2kTW+cOyNGwu1GzrxTAj6p\n\t\t\t\t\t\tQdVc9wctrwklGCXhXqaNBz72HCM6Pg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nrc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.nrc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nrc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.nrc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.nrc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.nrc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.nrc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.nrc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nrc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nrc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDcjCCAloCCQDyu2TVCpnwTjANBgkqhkiG9w0BAQUFADB7MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEZMBcGA1UECBMQTm9ydGhlcm4gSXJlbGFuZDEVMBMGA1UEBxMMTmV3dG93bmFi\n\t\t\t\t\t\tYmV5MSIwIAYDVQQKExlOb3J0aGVybiBSZWdpb25hbCBDb2xsZWdlMRYwFAYDVQQD\n\t\t\t\t\t\tEw1pZHAubnJjLmFjLnVrMB4XDTE0MDYxODEzMjQzM1oXDTM0MDYxMzEzMjQzM1ow\n\t\t\t\t\t\tezELMAkGA1UEBhMCR0IxGTAXBgNVBAgTEE5vcnRoZXJuIElyZWxhbmQxFTATBgNV\n\t\t\t\t\t\tBAcTDE5ld3Rvd25hYmJleTEiMCAGA1UEChMZTm9ydGhlcm4gUmVnaW9uYWwgQ29s\n\t\t\t\t\t\tbGVnZTEWMBQGA1UEAxMNaWRwLm5yYy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQAD\n\t\t\t\t\t\tggEPADCCAQoCggEBAPVbAHe9mFv4n0AFnhR7uN3oetmnyGocFxSVR/3uZVNQWaqx\n\t\t\t\t\t\tKRZpNawsVdiAQqMP6x9+ymD6e0EKO2YKZSXWvbPxxwG4dwVpJcAy6jYoe71G7Qq1\n\t\t\t\t\t\tMQxohxtLPMk5hZ4DVTt1xSMc+ZRVr1cE6vlHhC9r6LBmyaoxj+wc+U4/i6dyKs+o\n\t\t\t\t\t\twQufX7iIN1G3vDXsBA9sqlxUCdlfUdhbmri/Vf4U6tzYyF3l0txyZejlsmbHDZA0\n\t\t\t\t\t\toSrc+3VxosQeJ4irf5yNePeHzCWp0v75tEfLERg/1vIxfEO8nh9Rr3r4tHEKK77G\n\t\t\t\t\t\tYl9oU0N7rgQvOGwfuQerFKzSHWv7ZOPXMT77iwkCAwEAATANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAblCurjRGhUqdFuDlW1TEYNiCLADfS3uuWV+KhUDiQ7zLBdMxD5DpN++v\n\t\t\t\t\t\tagA4nHoUz+EsYXrD4VPzD1RuPaRuEjSL9hS0UxiRrOR1hIvnAC63H9pi2waZ53hp\n\t\t\t\t\t\tuMiDVtG0WomR/pJW3puaZs5N/bFL2ZWBvqqaRU0zc9nz4S0odmN+pfSqsrr/Y+JL\n\t\t\t\t\t\t4s89ev740ocq4FAq6zMwMDjeYvXDx7OibZ0Omq8S1/zPz3yXIM9/mvCm/iOBKxrO\n\t\t\t\t\t\tfe41HZlxy6Kdw+f/F7agDCNyNUAhC2zaYCWvSgFieJ2kTW+cOyNGwu1GzrxTAj6p\n\t\t\t\t\t\tQdVc9wctrwklGCXhXqaNBz72HCM6Pg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Northern Regional College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nrc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Northern Regional College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://websso.pomona.edu/",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "abeba.lennox@pomona.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Abbie Lennox"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "abeba.lennox@pomona.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Abbie Lennox"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "abeba.lennox@pomona.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Abbie Lennox"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ServiceDesk@pomona.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pomona ITS"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://websso.pomona.edu/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cas1.campus.pomona.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cas1.campus.pomona.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cas1.campus.pomona.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cas1.campus.pomona.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cas1.campus.pomona.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pomona.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://its.pomona.edu/about/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Pomona College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Pomona College Shibboleth IdP"
                  }
                ],
                "logo": [
                  {
                    "text": "https://community.pomona.edu/image/2013-design-update/logo-new.png",
                    "lang": "en",
                    "height": "125",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "300"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.pomona.edu/administration/privacy/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVAO9nGE8c+lQhK2F0lPJxljFyJ4EzMA0GCSqGSIb3DQEB\nBQUAMCExHzAdBgNVBAMTFmNhczEuY2FtcHVzLnBvbW9uYS5lZHUwHhcNMTMxMjE3\nMjE0MTAxWhcNMzMxMjE3MjE0MTAxWjAhMR8wHQYDVQQDExZjYXMxLmNhbXB1cy5w\nb21vbmEuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAq4MQ9hIX\n5FR80OVIOVg8nDrwy8TAQiQusnKNggf7g+aH+E6LZaABVKqOisIao0bQJCSgSjVX\n3HHo7a8H6KZzs5CQNJEe6Hw4lRx4BoZJ4PneLjIZCh1lkpSL+fFTqyqGbo56Oe+X\nyP9K54GdokcCGcqefYYGpsSmOczdRz85vz7jvXjnwCfJV4+6r5U04xaXNu451aWe\nmFYuJ690BJ12A7E/VOc9vNqX3VoEIUTRYOup5tB7T7BVVyoluNwZMuvA+8He/8LZ\np5z7K8qlIRE/2uo7QgzBVBuJwnLdl0+h1srU6Hle/6SQ4GDZ4ANC40HdmUV8Bs4P\nDuYVeMVnECAwVQIDAQABo3MwcTBQBgNVHREESTBHghZjYXMxLmNhbXB1cy5wb21v\nbmEuZWR1hi1odHRwczovL2NhczEuY2FtcHVzLnBvbW9uYS5lZHUvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFKgbAPNzVng01H8rnvHcIWjiltBkMA0GCSqGSIb3DQEB\nBQUAA4IBAQAL1qw9bWxTA6YByua5jNnDrlz12fyfoOQjYenhhqVsnV8zaXLRh6g/\nanp0Rlg2VWr3r2dv+cRvTJ98cTd4aZg9k9SYvAfsH2IEcAC5ztt+ufAnHrJG9eJt\nYXiCUNJHG/tekuPsl2lcgL6oREFVsx8LCwH62qeWKBDmOxuzJG1miaDDfgWjXmuZ\njMW6DSKHP7nPB+TVqHV21WnrhlVqcWbXSpzRMemw+zcnbCemcPpLcm1gPyyTcWxY\nJAIZ5JbZfzs6DKluH3EJomGA7QTN7nwEYwEN/WUoCPfToQrmtQn9ycaSKru8cxS5\nnh1jiNEqWZbGOpO4My5jVY+FG0TRRRQE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "http://www.pomona.edu/bad_request"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Pomona College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.pomona.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Pomona College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.era.lib.ed.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:information.systems@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Information Systems"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Watt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:colin.watt@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Colin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.era.lib.ed.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-04-24T15:38:27Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Digital repository from the University of Edinburgh"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.era.lib.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.era.lib.ed.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.era.lib.ed.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.era.lib.ed.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.era.lib.ed.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.era.lib.ed.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.era.lib.ed.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFTCCAf2gAwIBAgIJAIOsYTB61XKdMA0GCSqGSIb3DQEBBQUAMCUxIzAhBgNV\n\t\t\t\t\t\tBAMTGmxhYy1yZXBvLWxpdmU3LmlzLmVkLmFjLnVrMB4XDTEzMDMyOTE0MTMxNFoX\n\t\t\t\t\t\tDTIzMDMyNzE0MTMxNFowJTEjMCEGA1UEAxMabGFjLXJlcG8tbGl2ZTcuaXMuZWQu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC+zOVnC2mBcnCT\n\t\t\t\t\t\tfr26aA/wrJLM65swDcG8Lt7gwHxntEg9tOwrU3Rl35XMPSPbXZU0TWyWdDAW3/PC\n\t\t\t\t\t\t9i0271PkaygdChqNLf+1norKfmWMzogCiabPSkXInm8qfEWV4gwIa8SFtQ/cQCLF\n\t\t\t\t\t\tF8nn5AWtXilZbvOas7LPdoQQ8w6m8GFotkEEmATaanVMFbovITbs2xqIqvwSMYwu\n\t\t\t\t\t\tJzMYzehMeSnceRxuhyuP4xLAMz+UYlzjq6bljIIke3xUcaeZCt4hihJi7JhKiFQa\n\t\t\t\t\t\tIxenT1bGglNvSQmIWCfiG5ax6zobIrMG5iH2PdtzY/C9YSJpZNrCDyRe+i5IWonM\n\t\t\t\t\t\t/Hq+4wSrAgMBAAGjSDBGMCUGA1UdEQQeMByCGmxhYy1yZXBvLWxpdmU3LmlzLmVk\n\t\t\t\t\t\tLmFjLnVrMB0GA1UdDgQWBBRwFfQJ/pyvVGsQAwTPkd3s4eVQRzANBgkqhkiG9w0B\n\t\t\t\t\t\tAQUFAAOCAQEAf3EeDDtDZSMO4cF6IZFkLRlWMZjEYbnNcBgimbAB1rqCvXQo1NqT\n\t\t\t\t\t\txDyKpZ8Lfxax1dsvdotu9ltkFkmSLTF8lAHkNDu8VB2XvOWJG5Zy57xmaRPpDj1z\n\t\t\t\t\t\tese9Mz2wHuFEngOh4CuTPTCvYv80VtSVBh4xmGSqC0HWcfrcKvxhwVz3RmyDtiaV\n\t\t\t\t\t\tgPqu9DPDi6CHtxNn9TRhfTZck2NBGn2hPW2Zzt+L9KSNi9goUsHYUC4q9v17v0v4\n\t\t\t\t\t\t4MHYYV6m3Xe5EtHSarPW+aqqKrL7IXrpuCLAg6FVb4ULBMisw2Nsp7zc03zLobTd\n\t\t\t\t\t\tDJFYFLGtGnkAW0rtldK8ic92p7u2SzXZYw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.era.lib.ed.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.era.lib.ed.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.era.lib.ed.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.era.lib.ed.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.era.lib.ed.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.era.lib.ed.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://fed.huit.harvard.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp_support@harvard.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IdP Support Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp_support@harvard.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IdP Support Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp_support@harvard.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IdP Support Team"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://fed.huit.harvard.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/assurance/bronze"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oasis:names:tc:SAML:attribute:assurance-certification",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://fed.huit.harvard.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://fed.huit.harvard.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://fed.huit.harvard.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAMHQ2+0FLgQvpn9LL0UhXMMNPuAgMA0GCSqGSIb3DQEB\nBQUAMB8xHTAbBgNVBAMTFGZlZC5odWl0LmhhcnZhcmQuZWR1MB4XDTEzMDgxNDE2\nMzcwMFoXDTE2MDgxNDE2MzcwMFowHzEdMBsGA1UEAxMUZmVkLmh1aXQuaGFydmFy\nZC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCx7RtyRasKHsaM\ny5JjRalxmd0wQ5f/2vRZ3/7mf2tsz7F/Omm7iehUvqdUQ1VHcqz0YtYI6LCpRsv0\ncAadIN+A52Z+mRxVS0ipqmo7dWEzq/l/a+FIFL/WH7GGhzT2CkS63egZqVwmjfGi\nnD48x8eb5iNJiFl+86nKnBd9OPa4Lu8SMZAIrIHmbMJiaZg5AMpTBqx7Aswvjw+K\nYdzwShYnIz9BJJyKmx2KM0hAFn3Rx344xeBKZ8x74Tfi2Nf/9mg+EXUNHokOmmOw\nqTDsISKfBb8B4Wi2HgFziiK0YsUPnPphaELyYz65jt7/myQq479PuBwkXDatZbkf\ndG49sFY3AgMBAAGjbzBtMEwGA1UdEQRFMEOCFGZlZC5odWl0LmhhcnZhcmQuZWR1\nhitodHRwczovL2ZlZC5odWl0LmhhcnZhcmQuZWR1L2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBQPaXv5xewHpvA6acA9EguQxtTnIDANBgkqhkiG9w0BAQUFAAOCAQEA\nEFbJC6L/TSNQ+2GhnbWDQkWDsR+GafRumjv5K4uSIPSJbn9LTwJKVDA8AwOGYyM3\nz1kLIOKdJU+rh+ZzFRBNHNa9Hwdn0rb6mv/4H6FzlSDHVh+5H+r0ohZW7mlKXi39\n4iJ2Vg1B/edJsF6jpgCZ/hNMqdvIWFIaUYSUkLLyf2gqod6vGRj69+KnPHDSYblY\nkhJAS6iLBV6oXpiLnFLsMOx3PPbDlcFKjI/GlNVR9zKfvtdLZw+pKKGa8q2tARdV\nfvoMZweNsx+LViC1oJSfNXRQGFcipJmzV0lotUCf2YiU3fAkkCQjv/QB/WD1cBn1\nfSvxgeeh4nx2Wy1uwFlYcA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "harvard.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Harvard University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Harvard University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.harvard.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Harvard College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.bhasvic.ac.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.bhasvic.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/bhasvic.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/bhasvic.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bhasvic.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Brighton Hove & Sussex 6th Form College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bhasvic.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.europeansources.info/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:esowebmaster@cardiff.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ESO Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smart"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:smartp@cardiff.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Philip"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.europeansources.info/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "European Sources Online"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.europeansources.info/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cardiff University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.europeansources.info/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.europeansources.info/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.europeansources.info/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.europeansources.info/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.europeansources.info/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.europeansources.info/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIJAKXvxs0f16ZOMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHd3dy5ldXJvcGVhbnNvdXJjZXMuaW5mbzAeFw0xMDExMDUwNDA1NDBaFw0z\n\t\t\t\t\t\tMDEwMzEwNDA1NDBaMCMxITAfBgNVBAMTGHd3dy5ldXJvcGVhbnNvdXJjZXMuaW5m\n\t\t\t\t\t\tbzCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALtY3r1/Ce/g21A23jIA\n\t\t\t\t\t\tA+p5vLCT5Ys1rEMQfTG2v2TSaMadE+Cv+cs6Srid0ViHzIrNnniBtccbGxjie0Jn\n\t\t\t\t\t\t/wogTebE5mot9SikTg8NBZ4DPBWZGbL7K2pDKkzCEseXgpitrKq8LNfTSpypLEKL\n\t\t\t\t\t\tMgus2F2a0MPIMqnmaNDLFbw5vP2VM5Xl9C9J6+ze0XzAQqLyfveaELgapFNXZNvH\n\t\t\t\t\t\tw4L2dsIL1bl07EaXxW71fbY5dHfO4V81bc+2Y7huDn8MaaYMFT6JhPLa7oUwtftt\n\t\t\t\t\t\tMp/LsjneIrSTW22VwGNrqE4/bvpFJPJWT3JT/t/+MQ+sP8KHCkzXNYJgpy1lIew3\n\t\t\t\t\t\tnwMCAwEAAaN2MHQwUwYDVR0RBEwwSoIYd3d3LmV1cm9wZWFuc291cmNlcy5pbmZv\n\t\t\t\t\t\thi5odHRwczovL3d3dy5ldXJvcGVhbnNvdXJjZXMuaW5mby9zaGliYm9sZXRoLXNw\n\t\t\t\t\t\tMB0GA1UdDgQWBBTuv2FY5i6UPbuqzxAnAuce+GomvzANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAKNnwdcrSsx7LQSzpxcggbMkOJdk1BBdMc1vAn4NGBoOK4qDrbj+M7a9S+tRP\n\t\t\t\t\t\t7WjCdhxl+1fjYH7FuN05EoecHLuBqp6TWW2BRRetk7K4fE3LeuowIknu9ZxS9OrY\n\t\t\t\t\t\teyZJMNlOx8Qlu8YOIMbhjgWBoMjz3tNf/AX7umjTWZYNftEnopxPY6SLLSjPvDN7\n\t\t\t\t\t\tW0aUUZxfepCHC3ChYL24fHsDzPOB75N6XfoGbiIig8QCFSXGgHNybjVMgMvsnL02\n\t\t\t\t\t\t+uDpys5EQJlQYf7uL7LVSQgkhyjMvvQYDCzNjDsLFkneyWKAIj3c9ZUa5gk8nvSI\n\t\t\t\t\t\tCxCvlN9hdNAKSPhbVe6gTSLw1Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIJAKXvxs0f16ZOMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHd3dy5ldXJvcGVhbnNvdXJjZXMuaW5mbzAeFw0xMDExMDUwNDA1NDBaFw0z\n\t\t\t\t\t\tMDEwMzEwNDA1NDBaMCMxITAfBgNVBAMTGHd3dy5ldXJvcGVhbnNvdXJjZXMuaW5m\n\t\t\t\t\t\tbzCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALtY3r1/Ce/g21A23jIA\n\t\t\t\t\t\tA+p5vLCT5Ys1rEMQfTG2v2TSaMadE+Cv+cs6Srid0ViHzIrNnniBtccbGxjie0Jn\n\t\t\t\t\t\t/wogTebE5mot9SikTg8NBZ4DPBWZGbL7K2pDKkzCEseXgpitrKq8LNfTSpypLEKL\n\t\t\t\t\t\tMgus2F2a0MPIMqnmaNDLFbw5vP2VM5Xl9C9J6+ze0XzAQqLyfveaELgapFNXZNvH\n\t\t\t\t\t\tw4L2dsIL1bl07EaXxW71fbY5dHfO4V81bc+2Y7huDn8MaaYMFT6JhPLa7oUwtftt\n\t\t\t\t\t\tMp/LsjneIrSTW22VwGNrqE4/bvpFJPJWT3JT/t/+MQ+sP8KHCkzXNYJgpy1lIew3\n\t\t\t\t\t\tnwMCAwEAAaN2MHQwUwYDVR0RBEwwSoIYd3d3LmV1cm9wZWFuc291cmNlcy5pbmZv\n\t\t\t\t\t\thi5odHRwczovL3d3dy5ldXJvcGVhbnNvdXJjZXMuaW5mby9zaGliYm9sZXRoLXNw\n\t\t\t\t\t\tMB0GA1UdDgQWBBTuv2FY5i6UPbuqzxAnAuce+GomvzANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAKNnwdcrSsx7LQSzpxcggbMkOJdk1BBdMc1vAn4NGBoOK4qDrbj+M7a9S+tRP\n\t\t\t\t\t\t7WjCdhxl+1fjYH7FuN05EoecHLuBqp6TWW2BRRetk7K4fE3LeuowIknu9ZxS9OrY\n\t\t\t\t\t\teyZJMNlOx8Qlu8YOIMbhjgWBoMjz3tNf/AX7umjTWZYNftEnopxPY6SLLSjPvDN7\n\t\t\t\t\t\tW0aUUZxfepCHC3ChYL24fHsDzPOB75N6XfoGbiIig8QCFSXGgHNybjVMgMvsnL02\n\t\t\t\t\t\t+uDpys5EQJlQYf7uL7LVSQgkhyjMvvQYDCzNjDsLFkneyWKAIj3c9ZUa5gk8nvSI\n\t\t\t\t\t\tCxCvlN9hdNAKSPhbVe6gTSLw1Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.europeansources.info/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.europeansources.info/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.europeansources.info/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.europeansources.info/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.europeansources.info/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.europeansources.info/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.europeansources.info/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.europeansources.info/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.europeansources.info/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.europeansources.info/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://samltest.swamid.se/re_eu/sp.xml",
    {
      "entity_id": "https://samltest.swamid.se/re_eu/sp.xml",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish Academic Identity Federation (SWAMID)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.swamid.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SWAMID"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://samltest.swamid.se/disco",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFcTCCBFmgAwIBAgIQIu7k1beHBKgWb27d90Ad9jANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQwODAwMDAwMFoXDTE3MDQwNzIzNTk1OVowQDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRswGQYDVQQDExJzYW1sdGVzdC5z\nd2FtaWQuc2UwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCcJfNqCJmM\nCWZ9+h9MAT9WbT/e+eRpGE9H8eucnnq4weTeFbT+2Ma15hY8hI6gP4GsDIZsaxTu\nDGgIYXctfnl9MTz+9rlANOo8Wjuz6CJ2trJ6BdhPvkoITuSqmIWkFbmP7/0NGkoG\n167CGp/Eq5yZnUOdiKXquH2S5OCw3mB4HGpjUk7T13cN0jOOPiK2cQhUTuUUMaVO\nei0QblIfK/+9fusfYOjd5uzNg1QZ9FvvbB/wTw4Z11eGcZWKpAprIrbx6iw119eL\nU7dvJhgA96VJmesDQejf96Xtpn7bCbxdyBqw2AtooamyrVjnAeQ8NDXW7td9MUuM\n4/yhN9H+fHTVJNs8dCX5FKayw5YoxF8eTMjRk0ObICMrLl8M/EiOG9Eqfc3TPGTF\ndn81sOGc3WzifRyG5fXUx/Xw9vXVkRAkVO6T4n6OUQxn2be9hwXR7yFw9tTplPIl\ndabhc7iWU7NgEBcBI3RWCcRNv0OVsXIMDeGZ64SOm4mpKbXMVebsnSLXxV69T1l4\nM8EegMpraRWHrbtF27FkKZPZgCbNaQbfW4vtJoN9rN07Flz8GLr200WXAepXT14L\ndGwXqjx6Cu2oilkl2OoNWQbRg3dvn1j6XqnRLbio4bvuiCYYEPpjuWcHOs/GwMnz\npml7EL51yz9PTwNZTQXsLH/xKlzWf1BuBQIDAQABo4IBbzCCAWswHwYDVR0jBBgw\nFoAUDL2TaAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFG40O0IHvLK2kXS6s4hN\nCq0DTtPLMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQG\nCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgG\nBmeBDAECATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEu\nb3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKG\nKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsG\nAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJz\nYW1sdGVzdC5zd2FtaWQuc2UwDQYJKoZIhvcNAQEFBQADggEBAHnWOLDwhrYWfd7q\n2fwTaiRP/x/tVPocNgi/wgwo6oZzC1Ru/HPjfUmnj11zkOOHeF8cf2BT2diRptPi\nqDc+7HN8GrM87+Deqvjj4pw7j4hwMpcfNd2AzqW4nPmw4LgiRehITtUtMxL9mkDh\neN0pgldD544xQRUdxYmD9nUWiIaTmuxNqusKkqUTD/kO41i+BxIeaWiXsw6IC7o6\nkPPUQHr1h2na805Kjoy5ML8K2EO+kcvFqfo42gtwa7mN38hKB+jbKF5VqqmoSb4m\nln/3lobOqcV8rrFKjvnjC6iNTbdpQ65o8CoOcfzhWmb/7RxkZ4a9fyzxVS8fMAi6\nu3Qzm3Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFcTCCBFmgAwIBAgIQIu7k1beHBKgWb27d90Ad9jANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQwODAwMDAwMFoXDTE3MDQwNzIzNTk1OVowQDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRswGQYDVQQDExJzYW1sdGVzdC5z\nd2FtaWQuc2UwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCcJfNqCJmM\nCWZ9+h9MAT9WbT/e+eRpGE9H8eucnnq4weTeFbT+2Ma15hY8hI6gP4GsDIZsaxTu\nDGgIYXctfnl9MTz+9rlANOo8Wjuz6CJ2trJ6BdhPvkoITuSqmIWkFbmP7/0NGkoG\n167CGp/Eq5yZnUOdiKXquH2S5OCw3mB4HGpjUk7T13cN0jOOPiK2cQhUTuUUMaVO\nei0QblIfK/+9fusfYOjd5uzNg1QZ9FvvbB/wTw4Z11eGcZWKpAprIrbx6iw119eL\nU7dvJhgA96VJmesDQejf96Xtpn7bCbxdyBqw2AtooamyrVjnAeQ8NDXW7td9MUuM\n4/yhN9H+fHTVJNs8dCX5FKayw5YoxF8eTMjRk0ObICMrLl8M/EiOG9Eqfc3TPGTF\ndn81sOGc3WzifRyG5fXUx/Xw9vXVkRAkVO6T4n6OUQxn2be9hwXR7yFw9tTplPIl\ndabhc7iWU7NgEBcBI3RWCcRNv0OVsXIMDeGZ64SOm4mpKbXMVebsnSLXxV69T1l4\nM8EegMpraRWHrbtF27FkKZPZgCbNaQbfW4vtJoN9rN07Flz8GLr200WXAepXT14L\ndGwXqjx6Cu2oilkl2OoNWQbRg3dvn1j6XqnRLbio4bvuiCYYEPpjuWcHOs/GwMnz\npml7EL51yz9PTwNZTQXsLH/xKlzWf1BuBQIDAQABo4IBbzCCAWswHwYDVR0jBBgw\nFoAUDL2TaAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFG40O0IHvLK2kXS6s4hN\nCq0DTtPLMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQG\nCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgG\nBmeBDAECATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEu\nb3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKG\nKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsG\nAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJz\nYW1sdGVzdC5zd2FtaWQuc2UwDQYJKoZIhvcNAQEFBQADggEBAHnWOLDwhrYWfd7q\n2fwTaiRP/x/tVPocNgi/wgwo6oZzC1Ru/HPjfUmnj11zkOOHeF8cf2BT2diRptPi\nqDc+7HN8GrM87+Deqvjj4pw7j4hwMpcfNd2AzqW4nPmw4LgiRehITtUtMxL9mkDh\neN0pgldD544xQRUdxYmD9nUWiIaTmuxNqusKkqUTD/kO41i+BxIeaWiXsw6IC7o6\nkPPUQHr1h2na805Kjoy5ML8K2EO+kcvFqfo42gtwa7mN38hKB+jbKF5VqqmoSb4m\nln/3lobOqcV8rrFKjvnjC6iNTbdpQ65o8CoOcfzhWmb/7RxkZ4a9fyzxVS8fMAi6\nu3Qzm3Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://samltest.swamid.se/acs/re_eu/redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://samltest.swamid.se/acs/re_eu/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://openathens.blackpoolsixth.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Miller"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alison.miller@blackpoolsixth.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alison"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hopwood"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lee.hopwood@blackpoolsixth.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lee"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://openathens.blackpoolsixth.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-09-03T09:47:16Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://openathens.blackpoolsixth.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://openathens.blackpoolsixth.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "openathens.blackpoolsixth.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://drive.google.com/file/d/0B0EYs7-1W-QLS0FHamZQOVJsNjQ/view?usp=sharing",
                    "height": "138",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "138"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Blackpool Sixth Form College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDfDCCAmSgAwIBAgIIZ5b5ek0HMy0wDQYJKoZIhvcNAQEFBQAwVTEpMCcGA1UE\n\t\t\t\t\t\tCgwgVGhlIEJsYWNrcG9vbCBTaXh0aCBGb3JtIENvbGxlZ2UxKDAmBgNVBAMMH29w\n\t\t\t\t\t\tZW5hdGhlbnMuYmxhY2twb29sc2l4dGguYWMudWswHhcNMTUwNzMwMDgwMDU3WhcN\n\t\t\t\t\t\tMjUwNzMwMDgwMDU3WjBVMSkwJwYDVQQKDCBUaGUgQmxhY2twb29sIFNpeHRoIEZv\n\t\t\t\t\t\tcm0gQ29sbGVnZTEoMCYGA1UEAwwfb3BlbmF0aGVucy5ibGFja3Bvb2xzaXh0aC5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKIHctjmU3wcl6Yh\n\t\t\t\t\t\tVe4FgURR+YHKiJguGgjMZvNd9jtVa7tuqiHg3j/qsOyyCfYKABR8QhXM/+ZV0AWl\n\t\t\t\t\t\tWpAZ22fqPjaHOa2oWAVCRLIlVG75J5t+p1g8AqlYdTUMRAGncyhzRrTEDai9cXTb\n\t\t\t\t\t\t9iElCg6gtkorpvwgk5C/7yVU+GbqohIw+447tPG4hsmZfQV23wHaYUR4yF8aq0c6\n\t\t\t\t\t\tqNI6MpE6SWbdl4+ePfohwlZPPKEHKh8NUdU7rlz2WMKoQafzc3zacTv1nziD/mdy\n\t\t\t\t\t\t0Mt4nrbGfKq0la+0o6BWB7tOUlht1Z4mv68tRtZ/LXlasPNuz5b9FX0zuOR3qqrV\n\t\t\t\t\t\t/vL6tIECAwEAAaNQME4wHQYDVR0OBBYEFANJG3eMfJFEMKu32tl77TsYvRnMMB8G\n\t\t\t\t\t\tA1UdIwQYMBaAFANJG3eMfJFEMKu32tl77TsYvRnMMAwGA1UdEwQFMAMBAf8wDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBAFd61jV1f534DyaS+2v57NSBArqSKsSDlOUIexOQbLJY\n\t\t\t\t\t\tgxfAhrhiRH7UBkJRPS21QTRg8S7XhruKRZvOW6ANU/xteAKyxfkmmFSVwNhlgHdk\n\t\t\t\t\t\tYv8GvOPDn8CwiDr61aU1rDIG8F90Rqa9A0S7lGyeXGlXFnXjvrMsIPzbrQ49f2JZ\n\t\t\t\t\t\tysUA7zI/n7reC5dT8wyKtSWsydSyWIuY4W1v17IALxz7KsfnVTEj/uMr9Oqm0QgL\n\t\t\t\t\t\tCU7f5enOAZT5n9W8CFI5xNcpbazKoUzjTt15yoEOsD7vYNhJnS1EFClDBmM/ERxP\n\t\t\t\t\t\t2l6IdVWB/SVkgM6+P3kLtIZ/j4HLSsJ6GEIbJGI00UE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDfDCCAmSgAwIBAgIIZ5b5ek0HMy0wDQYJKoZIhvcNAQEFBQAwVTEpMCcGA1UE\n\t\t\t\t\t\tCgwgVGhlIEJsYWNrcG9vbCBTaXh0aCBGb3JtIENvbGxlZ2UxKDAmBgNVBAMMH29w\n\t\t\t\t\t\tZW5hdGhlbnMuYmxhY2twb29sc2l4dGguYWMudWswHhcNMTUwNzMwMDgwMDU3WhcN\n\t\t\t\t\t\tMjUwNzMwMDgwMDU3WjBVMSkwJwYDVQQKDCBUaGUgQmxhY2twb29sIFNpeHRoIEZv\n\t\t\t\t\t\tcm0gQ29sbGVnZTEoMCYGA1UEAwwfb3BlbmF0aGVucy5ibGFja3Bvb2xzaXh0aC5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKIHctjmU3wcl6Yh\n\t\t\t\t\t\tVe4FgURR+YHKiJguGgjMZvNd9jtVa7tuqiHg3j/qsOyyCfYKABR8QhXM/+ZV0AWl\n\t\t\t\t\t\tWpAZ22fqPjaHOa2oWAVCRLIlVG75J5t+p1g8AqlYdTUMRAGncyhzRrTEDai9cXTb\n\t\t\t\t\t\t9iElCg6gtkorpvwgk5C/7yVU+GbqohIw+447tPG4hsmZfQV23wHaYUR4yF8aq0c6\n\t\t\t\t\t\tqNI6MpE6SWbdl4+ePfohwlZPPKEHKh8NUdU7rlz2WMKoQafzc3zacTv1nziD/mdy\n\t\t\t\t\t\t0Mt4nrbGfKq0la+0o6BWB7tOUlht1Z4mv68tRtZ/LXlasPNuz5b9FX0zuOR3qqrV\n\t\t\t\t\t\t/vL6tIECAwEAAaNQME4wHQYDVR0OBBYEFANJG3eMfJFEMKu32tl77TsYvRnMMB8G\n\t\t\t\t\t\tA1UdIwQYMBaAFANJG3eMfJFEMKu32tl77TsYvRnMMAwGA1UdEwQFMAMBAf8wDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBAFd61jV1f534DyaS+2v57NSBArqSKsSDlOUIexOQbLJY\n\t\t\t\t\t\tgxfAhrhiRH7UBkJRPS21QTRg8S7XhruKRZvOW6ANU/xteAKyxfkmmFSVwNhlgHdk\n\t\t\t\t\t\tYv8GvOPDn8CwiDr61aU1rDIG8F90Rqa9A0S7lGyeXGlXFnXjvrMsIPzbrQ49f2JZ\n\t\t\t\t\t\tysUA7zI/n7reC5dT8wyKtSWsydSyWIuY4W1v17IALxz7KsfnVTEj/uMr9Oqm0QgL\n\t\t\t\t\t\tCU7f5enOAZT5n9W8CFI5xNcpbazKoUzjTt15yoEOsD7vYNhJnS1EFClDBmM/ERxP\n\t\t\t\t\t\t2l6IdVWB/SVkgM6+P3kLtIZ/j4HLSsJ6GEIbJGI00UE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Blackpool Sixth Form College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.blackpoolsixth.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Blackpool Sixth Form College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibserv.abdn.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Morrow"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webmaster@abdn.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Morrow"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webmaster@abdn.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibserv.abdn.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-03-24T15:39:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEYDCCA0igAwIBAgIJAKyEfiLtLS+qMA0GCSqGSIb3DQEBBQUAMIGwMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjERMA8GA1UECBMIU2NvdGxhbmQxETAPBgNVBAcTCEFiZXJkZWVuMR8w\n\t\t\t\t\t\tHQYDVQQKExZVbml2ZXJzaXR5IG9mIEFiZXJkZWVuMRQwEgYDVQQLEwtJVCBTZXJ2\n\t\t\t\t\t\taWNlczEdMBsGA1UEAxMUc2hpYnNlcnYyLmFiZG4uYWMudWsxJTAjBgkqhkiG9w0B\n\t\t\t\t\t\tCQEWFnNlcnZpY2VkZXNrQGFiZG4uYWMudWswHhcNMTMwNTI5MTQwMDEyWhcNMjMw\n\t\t\t\t\t\tNTI3MTQwMDEyWjCBsDELMAkGA1UEBhMCR0IxETAPBgNVBAgTCFNjb3RsYW5kMREw\n\t\t\t\t\t\tDwYDVQQHEwhBYmVyZGVlbjEfMB0GA1UEChMWVW5pdmVyc2l0eSBvZiBBYmVyZGVl\n\t\t\t\t\t\tbjEUMBIGA1UECxMLSVQgU2VydmljZXMxHTAbBgNVBAMTFHNoaWJzZXJ2Mi5hYmRu\n\t\t\t\t\t\tLmFjLnVrMSUwIwYJKoZIhvcNAQkBFhZzZXJ2aWNlZGVza0BhYmRuLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxjGiuC2ICUaK41q9JytdjDtc\n\t\t\t\t\t\twh+gSpqeSVwFRdyjvLmZ8Y3r1be9yX0+7dqse0RmwPST6I1EX+K2hdwQA3BKqemm\n\t\t\t\t\t\tpuDVz0z5bra8Xo/vSxNfMpB0mEoH/52j5rGRuq7sXnrnfprbgX2iw7vAgTNDnlGE\n\t\t\t\t\t\t9RjAYXRZI4n+8baD6nGSKhnVxI3FBSnDknyAjrkPBJdScENBlu09YJWOKTN6RpWB\n\t\t\t\t\t\t5heA6wqQSJfrgzhLsyIVtz5bxO/FQa5hTgytbs+vtPutu2Q0oANo4Y1yZatt4oQE\n\t\t\t\t\t\t28eoLvJTHq2z9PO4qbs2xUkAl7XZ/moN8zjj2JuFe0GeEnf+L5qknYM+oAw0MwID\n\t\t\t\t\t\tAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVy\n\t\t\t\t\t\tYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUfGZPIqt5aq2RSJNIdImK1zb36rcw\n\t\t\t\t\t\tHwYDVR0jBBgwFoAUfGZPIqt5aq2RSJNIdImK1zb36rcwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAHK++6fKCQdVwNJW2zkiLWaHI82Ea/YE/8q9LXJjLE5iiCg+Nl8fjxW1Oad6\n\t\t\t\t\t\tBhH6a9cAsada37Ppyt8+Y8yGrc5lwJHd1d5XupaFyojs4FuJ3eOb9cOHIG7P62Q5\n\t\t\t\t\t\tNB0D7c52UvZDJkY3Z0OEmBhMWTFxK+H+B8B5QzAeQGWHGYScUAyelYg6kkQVeWyP\n\t\t\t\t\t\tc+4InQwPaNfaS0QqachIQKxq2DIrhpWIC191CemLyuPi/1cqiqQoe/BCEZ4LuGAe\n\t\t\t\t\t\tgnrpddtYjDrcly5nGW+xcCzHmxJE11pNuvBs3smlTrl2KWSo376k4hCTMXJkCSna\n\t\t\t\t\t\t/Of8WnJZ6TQKBGIFWx6paDusZPY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "abdn.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibserv2.abdn.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibserv2.abdn.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibserv2.abdn.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibserv2.abdn.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibserv2.abdn.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibserv2.abdn.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibserv2.abdn.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibserv2.abdn.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "abdn.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://www.abdn.ac.uk/local/shibboleth/universitylogo.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://www.abdn.ac.uk/local/shibboleth/favicon.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Aberdeen"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEYDCCA0igAwIBAgIJAKyEfiLtLS+qMA0GCSqGSIb3DQEBBQUAMIGwMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjERMA8GA1UECBMIU2NvdGxhbmQxETAPBgNVBAcTCEFiZXJkZWVuMR8w\n\t\t\t\t\t\tHQYDVQQKExZVbml2ZXJzaXR5IG9mIEFiZXJkZWVuMRQwEgYDVQQLEwtJVCBTZXJ2\n\t\t\t\t\t\taWNlczEdMBsGA1UEAxMUc2hpYnNlcnYyLmFiZG4uYWMudWsxJTAjBgkqhkiG9w0B\n\t\t\t\t\t\tCQEWFnNlcnZpY2VkZXNrQGFiZG4uYWMudWswHhcNMTMwNTI5MTQwMDEyWhcNMjMw\n\t\t\t\t\t\tNTI3MTQwMDEyWjCBsDELMAkGA1UEBhMCR0IxETAPBgNVBAgTCFNjb3RsYW5kMREw\n\t\t\t\t\t\tDwYDVQQHEwhBYmVyZGVlbjEfMB0GA1UEChMWVW5pdmVyc2l0eSBvZiBBYmVyZGVl\n\t\t\t\t\t\tbjEUMBIGA1UECxMLSVQgU2VydmljZXMxHTAbBgNVBAMTFHNoaWJzZXJ2Mi5hYmRu\n\t\t\t\t\t\tLmFjLnVrMSUwIwYJKoZIhvcNAQkBFhZzZXJ2aWNlZGVza0BhYmRuLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxjGiuC2ICUaK41q9JytdjDtc\n\t\t\t\t\t\twh+gSpqeSVwFRdyjvLmZ8Y3r1be9yX0+7dqse0RmwPST6I1EX+K2hdwQA3BKqemm\n\t\t\t\t\t\tpuDVz0z5bra8Xo/vSxNfMpB0mEoH/52j5rGRuq7sXnrnfprbgX2iw7vAgTNDnlGE\n\t\t\t\t\t\t9RjAYXRZI4n+8baD6nGSKhnVxI3FBSnDknyAjrkPBJdScENBlu09YJWOKTN6RpWB\n\t\t\t\t\t\t5heA6wqQSJfrgzhLsyIVtz5bxO/FQa5hTgytbs+vtPutu2Q0oANo4Y1yZatt4oQE\n\t\t\t\t\t\t28eoLvJTHq2z9PO4qbs2xUkAl7XZ/moN8zjj2JuFe0GeEnf+L5qknYM+oAw0MwID\n\t\t\t\t\t\tAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVy\n\t\t\t\t\t\tYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUfGZPIqt5aq2RSJNIdImK1zb36rcw\n\t\t\t\t\t\tHwYDVR0jBBgwFoAUfGZPIqt5aq2RSJNIdImK1zb36rcwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAHK++6fKCQdVwNJW2zkiLWaHI82Ea/YE/8q9LXJjLE5iiCg+Nl8fjxW1Oad6\n\t\t\t\t\t\tBhH6a9cAsada37Ppyt8+Y8yGrc5lwJHd1d5XupaFyojs4FuJ3eOb9cOHIG7P62Q5\n\t\t\t\t\t\tNB0D7c52UvZDJkY3Z0OEmBhMWTFxK+H+B8B5QzAeQGWHGYScUAyelYg6kkQVeWyP\n\t\t\t\t\t\tc+4InQwPaNfaS0QqachIQKxq2DIrhpWIC191CemLyuPi/1cqiqQoe/BCEZ4LuGAe\n\t\t\t\t\t\tgnrpddtYjDrcly5nGW+xcCzHmxJE11pNuvBs3smlTrl2KWSo376k4hCTMXJkCSna\n\t\t\t\t\t\t/Of8WnJZ6TQKBGIFWx6paDusZPY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Aberdeen"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.abdn.ac.uk/dit/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Aberdeen"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://test.st-andrews.unidesk.ac.uk/tas/secure/login/verify",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:is.helpline@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-certs@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Apps Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test.st-andrews.unidesk.ac.uk/tas/secure/login/verify",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-05T13:34:13Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Test Unidesk - St Andrews"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEADCCAuigAwIBAgIJAL3Y8PpzyOKTMA0GCSqGSIb3DQEBCwUAMF0xJjAkBgNV\n\t\t\t\t\t\tBAMTHXRlc3Quc3QtYW5kcmV3cy51bmlkZXNrLmFjLnVrMSYwJAYDVQQKEx10ZXN0\n\t\t\t\t\t\tLnN0LWFuZHJld3MudW5pZGVzay5hYy51azELMAkGA1UEBhMCVUswHhcNMTYwNDAx\n\t\t\t\t\t\tMTIzNjUxWhcNMjYwMzMwMTIzNjUxWjBdMSYwJAYDVQQDEx10ZXN0LnN0LWFuZHJl\n\t\t\t\t\t\td3MudW5pZGVzay5hYy51azEmMCQGA1UEChMddGVzdC5zdC1hbmRyZXdzLnVuaWRl\n\t\t\t\t\t\tc2suYWMudWsxCzAJBgNVBAYTAlVLMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAzAL+qWB1ilhsj9Up9IOTrKbobvYAAuBvy5ea9KePlZNaxZ9D2/fye1WL\n\t\t\t\t\t\tzAtzBVBUZxofWYbkmQ31Av0OT4QPXcR3Koqs6HkjBJatjRJ5jdlyG98j0EEEXfb/\n\t\t\t\t\t\tsT5MQ/U4YauOf2H7c8M/JP8+PL97r/3eAaiMnya/CRZZDkqE2Ib1mQVvGX5Jl++G\n\t\t\t\t\t\ttVumwW0v2GRLIFWgNByF62vNIPNDfM7+EPiZSE2vxIJ1uIB/Zbc4CTgU9Ah4W2cc\n\t\t\t\t\t\txAMeEm/7TL75HCs3ZfKXbjZSNB7QpdCgQCpREHjKPVg6xAazsbXXQ66byCt10fic\n\t\t\t\t\t\tX9OeztcDJdj0tIgTl7tU9oZ8BGCbBwIDAQABo4HCMIG/MB0GA1UdDgQWBBQiT0Yu\n\t\t\t\t\t\tSG+CekTXxr0u1lengc4v5TCBjwYDVR0jBIGHMIGEgBQiT0YuSG+CekTXxr0u1len\n\t\t\t\t\t\tgc4v5aFhpF8wXTEmMCQGA1UEAxMddGVzdC5zdC1hbmRyZXdzLnVuaWRlc2suYWMu\n\t\t\t\t\t\tdWsxJjAkBgNVBAoTHXRlc3Quc3QtYW5kcmV3cy51bmlkZXNrLmFjLnVrMQswCQYD\n\t\t\t\t\t\tVQQGEwJVS4IJAL3Y8PpzyOKTMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQELBQAD\n\t\t\t\t\t\tggEBAEWMQiWOK6hKtuggI21WHZ2WSXc+LqchHtjbqcipHhPsR7tH2kzIxaqawRRB\n\t\t\t\t\t\tjaiZZ22nyDurQ4um2rVG25dxFFA1EM+OjuKKEiwDmWMNkypRa19O4vq3WhdF2CKq\n\t\t\t\t\t\tDVC+wFRVRIvA+CFYnQt3v1Lj/ZFWmUgfH1DhBg9D2ff7hKsCO/6pvl1XLIkM+rvO\n\t\t\t\t\t\t6F4ojfCzs8ZE4ZEXe9Tvddmv0bsVdMk5Px81i8vPd+z4vgfHnnzYS4ZLrxifKAhW\n\t\t\t\t\t\tWufvINMxu4brjSiVcSFmZqwo2rD/tzI7d7Ax+n/ziLxULAEBTg1AT2t3aAELPj/m\n\t\t\t\t\t\tHoIyjVh4zNDQNVRgra00piqEoZU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEADCCAuigAwIBAgIJAL3Y8PpzyOKTMA0GCSqGSIb3DQEBCwUAMF0xJjAkBgNV\n\t\t\t\t\t\tBAMTHXRlc3Quc3QtYW5kcmV3cy51bmlkZXNrLmFjLnVrMSYwJAYDVQQKEx10ZXN0\n\t\t\t\t\t\tLnN0LWFuZHJld3MudW5pZGVzay5hYy51azELMAkGA1UEBhMCVUswHhcNMTYwNDAx\n\t\t\t\t\t\tMTIzNjUxWhcNMjYwMzMwMTIzNjUxWjBdMSYwJAYDVQQDEx10ZXN0LnN0LWFuZHJl\n\t\t\t\t\t\td3MudW5pZGVzay5hYy51azEmMCQGA1UEChMddGVzdC5zdC1hbmRyZXdzLnVuaWRl\n\t\t\t\t\t\tc2suYWMudWsxCzAJBgNVBAYTAlVLMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAzAL+qWB1ilhsj9Up9IOTrKbobvYAAuBvy5ea9KePlZNaxZ9D2/fye1WL\n\t\t\t\t\t\tzAtzBVBUZxofWYbkmQ31Av0OT4QPXcR3Koqs6HkjBJatjRJ5jdlyG98j0EEEXfb/\n\t\t\t\t\t\tsT5MQ/U4YauOf2H7c8M/JP8+PL97r/3eAaiMnya/CRZZDkqE2Ib1mQVvGX5Jl++G\n\t\t\t\t\t\ttVumwW0v2GRLIFWgNByF62vNIPNDfM7+EPiZSE2vxIJ1uIB/Zbc4CTgU9Ah4W2cc\n\t\t\t\t\t\txAMeEm/7TL75HCs3ZfKXbjZSNB7QpdCgQCpREHjKPVg6xAazsbXXQ66byCt10fic\n\t\t\t\t\t\tX9OeztcDJdj0tIgTl7tU9oZ8BGCbBwIDAQABo4HCMIG/MB0GA1UdDgQWBBQiT0Yu\n\t\t\t\t\t\tSG+CekTXxr0u1lengc4v5TCBjwYDVR0jBIGHMIGEgBQiT0YuSG+CekTXxr0u1len\n\t\t\t\t\t\tgc4v5aFhpF8wXTEmMCQGA1UEAxMddGVzdC5zdC1hbmRyZXdzLnVuaWRlc2suYWMu\n\t\t\t\t\t\tdWsxJjAkBgNVBAoTHXRlc3Quc3QtYW5kcmV3cy51bmlkZXNrLmFjLnVrMQswCQYD\n\t\t\t\t\t\tVQQGEwJVS4IJAL3Y8PpzyOKTMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQELBQAD\n\t\t\t\t\t\tggEBAEWMQiWOK6hKtuggI21WHZ2WSXc+LqchHtjbqcipHhPsR7tH2kzIxaqawRRB\n\t\t\t\t\t\tjaiZZ22nyDurQ4um2rVG25dxFFA1EM+OjuKKEiwDmWMNkypRa19O4vq3WhdF2CKq\n\t\t\t\t\t\tDVC+wFRVRIvA+CFYnQt3v1Lj/ZFWmUgfH1DhBg9D2ff7hKsCO/6pvl1XLIkM+rvO\n\t\t\t\t\t\t6F4ojfCzs8ZE4ZEXe9Tvddmv0bsVdMk5Px81i8vPd+z4vgfHnnzYS4ZLrxifKAhW\n\t\t\t\t\t\tWufvINMxu4brjSiVcSFmZqwo2rD/tzI7d7Ax+n/ziLxULAEBTg1AT2t3aAELPj/m\n\t\t\t\t\t\tHoIyjVh4zNDQNVRgra00piqEoZU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.st-andrews.unidesk.ac.uk/tas/secure/login/verify",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://www.egencia.com/auth/v1",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.egencia.com/auth/v1",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.egencia.com/auth/v1/saml/SingleLogout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.egencia.com/auth/v1/saml/SingleLogout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.egencia.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.egencia.se/public/se/en/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Egencia Sweden"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Egencia Sweden"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Egencia \u00e4r Nordens st\u00f6rsta aff\u00e4rsresebyr\u00e5 och erjbuder spjutspetsl\u00f6sningar inom aff\u00e4rsresor till ett brett segement f\u00f6retagskunder"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Egencia is the leading business travel management company in the Nordic countries, delivering state-of-the-art travel services to a wide variety of corporate clients"
                  }
                ],
                "logo": [
                  {
                    "text": "http://portal.viatravel.se/media/17254/viaegencia.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.egencia.se/public/se/sv/about-egencia/privacy-policy-en/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.egencia.se/public/se/sv/about-egencia/privacy-policy-en/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFLTCCBBWgAwIBAgIMDVCG8gAAAABQ1dX0MA0GCSqGSIb3DQEBCwUAMIG6MQswCQYDVQQGEwJV\nUzEWMBQGA1UEChMNRW50cnVzdCwgSW5jLjEoMCYGA1UECxMfU2VlIHd3dy5lbnRydXN0Lm5ldC9s\nZWdhbC10ZXJtczE5MDcGA1UECxMwKGMpIDIwMTIgRW50cnVzdCwgSW5jLiAtIGZvciBhdXRob3Jp\nemVkIHVzZSBvbmx5MS4wLAYDVQQDEyVFbnRydXN0IENlcnRpZmljYXRpb24gQXV0aG9yaXR5IC0g\nTDFLMB4XDTE1MTAyNjIxMDQxMFoXDTE4MTAyNTIxMzQwOFowZzELMAkGA1UEBhMCVVMxEzARBgNV\nBAgTCldhc2hpbmd0b24xETAPBgNVBAcTCEJlbGxldnVlMRYwFAYDVQQKEw1FeHBlZGlhLCBJbmMu\nMRgwFgYDVQQDEw9TU08uRUdFTkNJQS5DT00wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQDTn33bK5kWsiyxwi9F7zc1160xNJcWYykHIiX1aMLXhZln3oS1Ma3idei6PC9R0aK0h0Y7qe8y\nAb8AajfnCxB8gqKOCR064hMMYB2fon0tC//477x8wG2XrFDzTem21LNRkrI54EcBvykDWSqlC0lI\nQOBTtn5nTfsSuRBYl+CDGaMb/UUHZ5l18TqbCgVmELiEr37j9Cfqv6NO8b80k1zXP8FwFNQmSGxw\nQMBOAf/V43Yn1mdGxaUZBY2MnK1yKH6IoPBKAyafUPedXz5gy/xIQZTQprIb9kosei6IyOtuqmnV\no1VA7HKPV8w5cIyx11eZgOV0Fi0IswvwBJxPrf1pAgMBAAGjggGDMIIBfzALBgNVHQ8EBAMCBaAw\nHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMDMGA1UdHwQsMCowKKAmoCSGImh0dHA6Ly9j\ncmwuZW50cnVzdC5uZXQvbGV2ZWwxay5jcmwwSwYDVR0gBEQwQjA2BgpghkgBhvpsCgEFMCgwJgYI\nKwYBBQUHAgEWGmh0dHA6Ly93d3cuZW50cnVzdC5uZXQvcnBhMAgGBmeBDAECAjBoBggrBgEFBQcB\nAQRcMFowIwYIKwYBBQUHMAGGF2h0dHA6Ly9vY3NwLmVudHJ1c3QubmV0MDMGCCsGAQUFBzAChido\ndHRwOi8vYWlhLmVudHJ1c3QubmV0L2wxay1jaGFpbjI1Ni5jZXIwGgYDVR0RBBMwEYIPU1NPLkVH\nRU5DSUEuQ09NMB8GA1UdIwQYMBaAFIKicHTdvFM/z3vU981/p2DGCky/MB0GA1UdDgQWBBSgfwEI\n76qdV0qOuSAkkfaYK3AlrzAJBgNVHRMEAjAAMA0GCSqGSIb3DQEBCwUAA4IBAQC+3Mp8fw1ZSfEK\nob3KVMH0pW8geCRDnnyh/Cv5/AnlPwdFfWSzIKmE5ZknfVwcV/XftRQxbkuIt0RANWXZvltj9qEP\nbTwTgBrFW+jAxhSI2VeJlFtHwB3NIc/Dt5jrfkC6x1Sdee6X+Jh/Jv7jcDKvEwOuLwzEq1n6lU4e\n9MTmZmtqHJrD4V79qOn7W1aeGfZMqa72kms6InjTAVwENNqY+MbBg1axxr+uXjlBuuRQRHmd/N1D\ndCS4UR5oi0W8746+1iN6fE8qYdVN4bwwa3QtRn9xFzBtsy1V2Dm5H9SMCxZkewj2W7PXNr65gjRy\niYns87MN+qR53rv18Bbk6be4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFLTCCBBWgAwIBAgIMDVCG8gAAAABQ1dX0MA0GCSqGSIb3DQEBCwUAMIG6MQswCQYDVQQGEwJV\nUzEWMBQGA1UEChMNRW50cnVzdCwgSW5jLjEoMCYGA1UECxMfU2VlIHd3dy5lbnRydXN0Lm5ldC9s\nZWdhbC10ZXJtczE5MDcGA1UECxMwKGMpIDIwMTIgRW50cnVzdCwgSW5jLiAtIGZvciBhdXRob3Jp\nemVkIHVzZSBvbmx5MS4wLAYDVQQDEyVFbnRydXN0IENlcnRpZmljYXRpb24gQXV0aG9yaXR5IC0g\nTDFLMB4XDTE1MTAyNjIxMDQxMFoXDTE4MTAyNTIxMzQwOFowZzELMAkGA1UEBhMCVVMxEzARBgNV\nBAgTCldhc2hpbmd0b24xETAPBgNVBAcTCEJlbGxldnVlMRYwFAYDVQQKEw1FeHBlZGlhLCBJbmMu\nMRgwFgYDVQQDEw9TU08uRUdFTkNJQS5DT00wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQDTn33bK5kWsiyxwi9F7zc1160xNJcWYykHIiX1aMLXhZln3oS1Ma3idei6PC9R0aK0h0Y7qe8y\nAb8AajfnCxB8gqKOCR064hMMYB2fon0tC//477x8wG2XrFDzTem21LNRkrI54EcBvykDWSqlC0lI\nQOBTtn5nTfsSuRBYl+CDGaMb/UUHZ5l18TqbCgVmELiEr37j9Cfqv6NO8b80k1zXP8FwFNQmSGxw\nQMBOAf/V43Yn1mdGxaUZBY2MnK1yKH6IoPBKAyafUPedXz5gy/xIQZTQprIb9kosei6IyOtuqmnV\no1VA7HKPV8w5cIyx11eZgOV0Fi0IswvwBJxPrf1pAgMBAAGjggGDMIIBfzALBgNVHQ8EBAMCBaAw\nHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMDMGA1UdHwQsMCowKKAmoCSGImh0dHA6Ly9j\ncmwuZW50cnVzdC5uZXQvbGV2ZWwxay5jcmwwSwYDVR0gBEQwQjA2BgpghkgBhvpsCgEFMCgwJgYI\nKwYBBQUHAgEWGmh0dHA6Ly93d3cuZW50cnVzdC5uZXQvcnBhMAgGBmeBDAECAjBoBggrBgEFBQcB\nAQRcMFowIwYIKwYBBQUHMAGGF2h0dHA6Ly9vY3NwLmVudHJ1c3QubmV0MDMGCCsGAQUFBzAChido\ndHRwOi8vYWlhLmVudHJ1c3QubmV0L2wxay1jaGFpbjI1Ni5jZXIwGgYDVR0RBBMwEYIPU1NPLkVH\nRU5DSUEuQ09NMB8GA1UdIwQYMBaAFIKicHTdvFM/z3vU981/p2DGCky/MB0GA1UdDgQWBBSgfwEI\n76qdV0qOuSAkkfaYK3AlrzAJBgNVHRMEAjAAMA0GCSqGSIb3DQEBCwUAA4IBAQC+3Mp8fw1ZSfEK\nob3KVMH0pW8geCRDnnyh/Cv5/AnlPwdFfWSzIKmE5ZknfVwcV/XftRQxbkuIt0RANWXZvltj9qEP\nbTwTgBrFW+jAxhSI2VeJlFtHwB3NIc/Dt5jrfkC6x1Sdee6X+Jh/Jv7jcDKvEwOuLwzEq1n6lU4e\n9MTmZmtqHJrD4V79qOn7W1aeGfZMqa72kms6InjTAVwENNqY+MbBg1axxr+uXjlBuuRQRHmd/N1D\ndCS4UR5oi0W8746+1iN6fE8qYdVN4bwwa3QtRn9xFzBtsy1V2Dm5H9SMCxZkewj2W7PXNr65gjRy\niYns87MN+qR53rv18Bbk6be4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://www.egencia.com/auth/v1/artifactConsumer",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.egencia.com/auth/v1/artifactConsumer",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://login.mynetworkglobal.com/simplesaml/module.php/saml/sp/metadata.php/mynetwork-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Newberg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "webmaster@mynetwork.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Per"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.mynetworkglobal.com/simplesaml/module.php/saml/sp/metadata.php/mynetwork-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.mynetworkglobal.com/simplesaml/module.php/saml/sp/saml2-logout.php/mynetwork-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mynetworkglobal.com/se/info/customer/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mynetworkglobal.com/en/info/customer/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "MyNetwork Pro \u00e4r ett helt\u00e4ckande webbaserat rekryteringssystem."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "MyNetwork Pro is a web-based recruiting system."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.mynetworkglobal.com/Graphics/Logos/mynetwork.png",
                    "height": "221",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "51"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "MyNetwork Pro"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "MyNetwork Pro"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.mynetworkglobal.com/simplesaml/module.php/saml/sp/saml2-acs.php/mynetwork-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.mynetworkglobal.com/simplesaml/module.php/saml/sp/saml1-acs.php/mynetwork-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.mynetworkglobal.com/simplesaml/module.php/saml/sp/saml2-acs.php/mynetwork-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.mynetworkglobal.com/simplesaml/module.php/saml/sp/saml1-acs.php/mynetwork-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib4.rowan.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "grochowski@rowan.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Josh Grochowski"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib4.rowan.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib4.rowan.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib4.rowan.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib4.rowan.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rowan.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Rowan University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rowan University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBzCCAe+gAwIBAgIJAKC0AtYYd0CFMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMMD3NoaWI0LnJvd2FuLmVkdTAeFw0xNjAzMjExODA2MjVaFw0yNjAzMTkxODA2\nMjVaMBoxGDAWBgNVBAMMD3NoaWI0LnJvd2FuLmVkdTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAMyjgJ8pTvE0c9rVKjgUXWowwWub5gtlb2UEJvvxh8wv\nuuOEfdK3RFAMUb1YHflyu5MfRe6dnzBZqjn5AkQGCZDPZgX+xYCKoqLYvlLuM6my\nIMj35g2YDALAL+KZRfo3u8FhdX3aUvYMtCYq82b+NGm6Xbz9po8o1jUSthbKPKV/\nR5PKNAI5F4eZNJ+UWnjBFH/MPdszRz6Jqoae702QnC/2gmWGYPlWMtkohjDut6O9\n6Nz0IwleJaHZpg5Bb50JMkFkBlUuMj8H//WTlb7pVVWcUGfu6y0hohrrHSV7+kWe\nLhjlpLVWpPuzh1N8E2C2YAbzBrvRMv8/SCKqjlMK2i0CAwEAAaNQME4wHQYDVR0O\nBBYEFKkZ81OmWvKFEW6utEPiDDLK1+GVMB8GA1UdIwQYMBaAFKkZ81OmWvKFEW6u\ntEPiDDLK1+GVMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAImHwycf\nukOry2DaW8h3v5nEorMOOnFcM/7GHHkES7HOXA9ktebaOEQxNimc0Mi3sxP9PZOX\ntcZBwTGMUFmcAMDOQckaMsFseAk0OGVBx9oDfhjpSqEGk3DY7Vo+Y97tw7VeDz/Z\nNdBJLXZ5ANl4eeeLvWwPtmXco9C7lD6K9f4AukHZy5isb98dzy38F9zAcceaSJB8\n5gUdwoM73ogoSxlBP/5K88FOBSP58H/VNL+Dorao/UodqYTsDVRIzqoYqRo164Zu\njFOTfTqZ3gaY/iMM80r/D+BrficUUKE00N/OOU8fToIohseWg/0t8GDOtz+TwQQB\nVy/iNeK/cyCyf8I="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Rowan University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rowan.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Rowan University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.cairn.info/",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "De Vathaire Jean-Baptiste"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jb.devathaire@cairn.info"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Benjamin Hennon"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "benjamin.hennon@pythagoria.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.cairn.info/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-05-13T10:38:29Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/documentation"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/commercial"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CAIRN SA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cairn.info/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CAIRN SA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.cairn.info"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Created in September 2005 by four Belgian and French publishers, today Cairn offers the most comprehensive collection of publications in the French language in the humanities and social sciences available online. In 2015, more than 400 journals and around 5,000 eBooks from major French, Belgian and Swiss publishers are available on www.cairn.info. Students, scholars and librarians all over the world are thus able to access more than 200,000 full-text articles and book chapters online.\nTo make this content more visible and accessible to non\u2013francophone scholars, Cairn.info (with the support of the CNL, a French governmental agency dedicated to the promotion of French publications around the world) has designed a special interface, www.cairn-int.info, enabling internet users to browse and easily find content from French journals without speaking a word of French."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Cairn est n\u00e9 de la volont\u00e9 de quatre maisons d\u2019\u00e9dition (Belin, De Boeck, La D\u00e9couverte et Er\u00e8s) ayant en charge la publication et la diffusion de revues de sciences humaines et sociales, d\u2019unir leurs efforts pour am\u00e9liorer leur pr\u00e9sence sur l\u2019Internet, et de proposer \u00e0 d\u2019autres acteurs souhaitant d\u00e9velopper une version \u00e9lectronique de leurs publications, les outils techniques et commerciaux d\u00e9velopp\u00e9s \u00e0 cet effet. L\u2019ambition de Cairn est d\u2019aider les maisons d\u2019\u00e9dition, organismes ou associations en charge de la publication de revues de sciences humaines francophones \u00e0 g\u00e9rer la double publication de ces revues. Dans ce but, les services de Cairn couvrent \u00e0 la fois la fabrication papier et \u00e9lectronique, la distribution papier (gestion des abonnements, routage) et \u00e9lectronique (texte int\u00e9gral en ligne, distribution des m\u00e9tadonn\u00e9es aupr\u00e8s des sites et bases bibliographiques), ainsi que la diffusion et la promotion de ces revues aupr\u00e8s des publics auxquels elles s\u2019adressent."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.cairn.info/vie-privee.php"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CAIRN"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CAIRN"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICgzCCAeygAwIBAgIJANHZ2qyvCn4GMA0GCSqGSIb3DQEBBQUAMDYxCzAJBgNV\nBAYTAkJFMQ4wDAYDVQQKEwVDQUlSTjEXMBUGA1UEAxMOd3d3LmNhaXJuLmluZm8w\nHhcNMDgwMTMxMTAxMTUzWhcNMjgwMTI2MTAxMTUzWjA2MQswCQYDVQQGEwJCRTEO\nMAwGA1UEChMFQ0FJUk4xFzAVBgNVBAMTDnd3dy5jYWlybi5pbmZvMIGfMA0GCSqG\nSIb3DQEBAQUAA4GNADCBiQKBgQDRPuV40csQ00mQUww+eQ7sNqaJRLBqDgufitNd\ncMwIl6cgaPAkIvpYVQPwdxhDWqzQCYJagg6pd9Jw/Rcws7rGf1S7vlWQ6vlP/7y1\naA54xMcvM1Bx6FAp0h2oHGDfSf6HlxpsvwAJLi5ArU4EZw8CejYzWwE6XmYbj5ox\nU9p/gQIDAQABo4GYMIGVMB0GA1UdDgQWBBSKxxPh1wwwyfuboXg0mpgjcRvoujBm\nBgNVHSMEXzBdgBSKxxPh1wwwyfuboXg0mpgjcRvouqE6pDgwNjELMAkGA1UEBhMC\nQkUxDjAMBgNVBAoTBUNBSVJOMRcwFQYDVQQDEw53d3cuY2Fpcm4uaW5mb4IJANHZ\n2qyvCn4GMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADgYEArQe7ZnkoaPH+\nMBICLC8YFFEfEEpF1hLcMcJBqLQYaaqhFw6olWUogbU8eX9Wvz1qKEZwKryJkrAs\noDjy4c/5nHwxlFZheFLcnWiQdxmv9qjtZqV41SSn7zNVX0U9YUoY6lrtSZH/4Btk\nE25Bh11XZRlFI1reece1ILLnGQ7t3Hw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICgzCCAeygAwIBAgIJANHZ2qyvCn4GMA0GCSqGSIb3DQEBBQUAMDYxCzAJBgNV\nBAYTAkJFMQ4wDAYDVQQKEwVDQUlSTjEXMBUGA1UEAxMOd3d3LmNhaXJuLmluZm8w\nHhcNMDgwMTMxMTAxMTUzWhcNMjgwMTI2MTAxMTUzWjA2MQswCQYDVQQGEwJCRTEO\nMAwGA1UEChMFQ0FJUk4xFzAVBgNVBAMTDnd3dy5jYWlybi5pbmZvMIGfMA0GCSqG\nSIb3DQEBAQUAA4GNADCBiQKBgQDRPuV40csQ00mQUww+eQ7sNqaJRLBqDgufitNd\ncMwIl6cgaPAkIvpYVQPwdxhDWqzQCYJagg6pd9Jw/Rcws7rGf1S7vlWQ6vlP/7y1\naA54xMcvM1Bx6FAp0h2oHGDfSf6HlxpsvwAJLi5ArU4EZw8CejYzWwE6XmYbj5ox\nU9p/gQIDAQABo4GYMIGVMB0GA1UdDgQWBBSKxxPh1wwwyfuboXg0mpgjcRvoujBm\nBgNVHSMEXzBdgBSKxxPh1wwwyfuboXg0mpgjcRvouqE6pDgwNjELMAkGA1UEBhMC\nQkUxDjAMBgNVBAoTBUNBSVJOMRcwFQYDVQQDEw53d3cuY2Fpcm4uaW5mb4IJANHZ\n2qyvCn4GMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADgYEArQe7ZnkoaPH+\nMBICLC8YFFEfEEpF1hLcMcJBqLQYaaqhFw6olWUogbU8eX9Wvz1qKEZwKryJkrAs\noDjy4c/5nHwxlFZheFLcnWiQdxmv9qjtZqV41SSn7zNVX0U9YUoY6lrtSZH/4Btk\nE25Bh11XZRlFI1reece1ILLnGQ7t3Hw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cairn.info/shibboleth/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.cairn.info/shibboleth/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CAIRN"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CAIRN"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Cairn est n\u00e9 de la volont\u00e9 de quatre maisons d\u2019\u00e9dition (Belin, De Boeck, La D\u00e9couverte et Er\u00e8s) ayant en charge la publication et la diffusion de revues de sciences humaines et sociales, d\u2019unir leurs efforts pour am\u00e9liorer leur pr\u00e9sence sur l\u2019Internet, et de proposer \u00e0 d\u2019autres acteurs souhaitant d\u00e9velopper une version \u00e9lectronique de leurs publications, les outils techniques et commerciaux d\u00e9velopp\u00e9s \u00e0 cet effet. L\u2019ambition de Cairn est d\u2019aider les maisons d\u2019\u00e9dition, organismes ou associations en charge de la publication de revues de sciences humaines francophones \u00e0 g\u00e9rer la double publication de ces revues. Dans ce but, les services de Cairn couvrent \u00e0 la fois la fabrication papier et \u00e9lectronique, la distribution papier (gestion des abonnements, routage) et \u00e9lectronique (texte int\u00e9gral en ligne, distribution des m\u00e9tadonn\u00e9es aupr\u00e8s des sites et bases bibliographiques), ainsi que la diffusion et la promotion de ces revues aupr\u00e8s des publics auxquels elles s\u2019adressent."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Created in September 2005 by four Belgian and French publishers, today Cairn offers the most comprehensive collection of publications in the French language in the humanities and social sciences available online. In 2015, more than 400 journals and around 5,000 eBooks from major French, Belgian and Swiss publishers are available on www.cairn.info. Students, scholars and librarians all over the world are thus able to access more than 200,000 full-text articles and book chapters online.\nTo make this content more visible and accessible to non\u2013francophone scholars, Cairn.info (with the support of the CNL, a French governmental agency dedicated to the promotion of French publications around the world) has designed a special interface, www.cairn-int.info, enabling internet users to browse and easily find content from French journals without speaking a word of French."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.trinity-cm.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.trinity-cm.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/tsd.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/tsd.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tsd.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Wales Trinity Saint David: Carmarthen / Lampeter"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.trinitysaintdavid.ac.uk/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://groupes-aa.renater.fr",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@renater.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://groupes-aa.renater.fr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-09-25T15:11:29Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/collaboratif"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/community"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GIP RENATER"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.renater.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GIP RENATER"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://groupes-aa.renater.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Authorization service based on Sympa group manager (Universalistes) and SAML Attributes Authorities.\nIt allows virtual organizations (e.g. research communities) composed by people belonging to different institutions (i.e. managed by different referentials) to access to common resources (if authorization was granted) after having been authenticated by their respective institutions.\nThis service will be in charge of authentication and provide accurate access control on a community's web resource (group defined in Sympa). This resource can therefore be hosted anywhere."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Service d'autorisation bas\u00e9 sur le gestionnaire de groupes Sympa (Universalistes) et les Attributes Authorities SAML.\nIl permet \u00e0 des organisations virtuelles (VO, communaut\u00e9s de chercheurs) appartenant \u00e0 des \u00e9tablissements diff\u00e9rents (donc g\u00e9r\u00e9s dans des r\u00e9f\u00e9rentiels diff\u00e9rents) d'acc\u00e9der \u00e0 des ressources communes (sur autorisation) apr\u00e8s authentification aupr\u00e8s de leurs \u00e9tablissements respectifs.\nCe service se chargera de l'authentification et permettra un contr\u00f4le d'acc\u00e8s fin sur une ressource Web d'une communaut\u00e9 (groupe d\u00e9fini dans Sympa) qui peut donc \u00eatre h\u00e9berg\u00e9e n'importe o\u00f9."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RENATER - Validation of the Authorization Service"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RENATER - Validation du Service d'autorisation"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+jCCAeKgAwIBAgIJALBSjVtKCuQcMA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\nBAMTEWRhbW9uYS5yZW5hdGVyLmZyMB4XDTE0MDkyMjE0NDgxMVoXDTI0MDkxOTE0\nNDgxMVowHDEaMBgGA1UEAxMRZGFtb25hLnJlbmF0ZXIuZnIwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDm5OyzbhKkpArqcqSUY0eMh62d8p+/Y0Cssiie\nMb2tiETFm2GSssPWSKl8NdIKY31TnQT8kJesZLllfIuIHZAsw2vv3VNVQJsTbY8o\nindBepdVJWejKxgp80ylL9QDZhtz2dG6VJhtrypT45/f8rTtMfcIY1sN95FEigwZ\nGLXlEPTIH9r7U831DQDaOn5uR0jz+wO7bA+NvBGove4BkD1HJ4fkLWC9amSgQpan\nLw0YJ5xgYpCDZk4y0oDQObd4oBVXb30+jr2vnYZFTTfM0mxTj5naDia6ez7rAQwv\nqViUwQE+Z+thInH6erNHF7G5LJA4u4PX2s/u3TSitQePs3IbAgMBAAGjPzA9MBwG\nA1UdEQQVMBOCEWRhbW9uYS5yZW5hdGVyLmZyMB0GA1UdDgQWBBQXqnecrfW7ivww\n4GfxSu1We4CLOjANBgkqhkiG9w0BAQUFAAOCAQEAeD8GgYq59YNJv1u9j7M5/j3O\ngmk1jxFrcCeH82qF4/eQPkqMwtOlWRi4EW7ZIQusnchXyllBtOBasQNmPBfjq0GX\nzALi3Sd8sLDODKa+rRoJzZs0V3mlRU6UaEHyXMlnrpv3yn92buVxjMpX6PXFlQbB\n+Aqsv8O0II4O/6eU+hDXSpZEQFUc6iRZ7fT4IXD5SHrbHDbAU0w7ZTknn3YlQglh\nB2xZ41JS1unwqh1+azyjNCYMn9P8UYanAOTDdycZqCOFASXGSkd+aCHWrHz1lVGo\nbGESZR7Tv0Rg476ex/x+VHEXmJZurlD9Sf7UAMbErhorRKPsfrReAuWpaqSJyw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC+jCCAeKgAwIBAgIJALBSjVtKCuQcMA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\nBAMTEWRhbW9uYS5yZW5hdGVyLmZyMB4XDTE0MDkyMjE0NDgxMVoXDTI0MDkxOTE0\nNDgxMVowHDEaMBgGA1UEAxMRZGFtb25hLnJlbmF0ZXIuZnIwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDm5OyzbhKkpArqcqSUY0eMh62d8p+/Y0Cssiie\nMb2tiETFm2GSssPWSKl8NdIKY31TnQT8kJesZLllfIuIHZAsw2vv3VNVQJsTbY8o\nindBepdVJWejKxgp80ylL9QDZhtz2dG6VJhtrypT45/f8rTtMfcIY1sN95FEigwZ\nGLXlEPTIH9r7U831DQDaOn5uR0jz+wO7bA+NvBGove4BkD1HJ4fkLWC9amSgQpan\nLw0YJ5xgYpCDZk4y0oDQObd4oBVXb30+jr2vnYZFTTfM0mxTj5naDia6ez7rAQwv\nqViUwQE+Z+thInH6erNHF7G5LJA4u4PX2s/u3TSitQePs3IbAgMBAAGjPzA9MBwG\nA1UdEQQVMBOCEWRhbW9uYS5yZW5hdGVyLmZyMB0GA1UdDgQWBBQXqnecrfW7ivww\n4GfxSu1We4CLOjANBgkqhkiG9w0BAQUFAAOCAQEAeD8GgYq59YNJv1u9j7M5/j3O\ngmk1jxFrcCeH82qF4/eQPkqMwtOlWRi4EW7ZIQusnchXyllBtOBasQNmPBfjq0GX\nzALi3Sd8sLDODKa+rRoJzZs0V3mlRU6UaEHyXMlnrpv3yn92buVxjMpX6PXFlQbB\n+Aqsv8O0II4O/6eU+hDXSpZEQFUc6iRZ7fT4IXD5SHrbHDbAU0w7ZTknn3YlQglh\nB2xZ41JS1unwqh1+azyjNCYMn9P8UYanAOTDdycZqCOFASXGSkd+aCHWrHz1lVGo\nbGESZR7Tv0Rg476ex/x+VHEXmJZurlD9Sf7UAMbErhorRKPsfrReAuWpaqSJyw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://groupes-aa.renater.fr/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://groupes-aa.renater.fr/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "RENATER - Validation du Service d'autorisation"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "RENATER - Validation of the Authorization Service"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Service d'autorisation bas\u00e9 sur le gestionnaire de groupes Sympa (Universalistes) et les Attributes Authorities SAML.\nIl permet \u00e0 des organisations virtuelles (VO, communaut\u00e9s de chercheurs) appartenant \u00e0 des \u00e9tablissements diff\u00e9rents (donc g\u00e9r\u00e9s dans des r\u00e9f\u00e9rentiels diff\u00e9rents) d'acc\u00e9der \u00e0 des ressources communes (sur autorisation) apr\u00e8s authentification aupr\u00e8s de leurs \u00e9tablissements respectifs.\nCe service se chargera de l'authentification et permettra un contr\u00f4le d'acc\u00e8s fin sur une ressource Web d'une communaut\u00e9 (groupe d\u00e9fini dans Sympa) qui peut donc \u00eatre h\u00e9berg\u00e9e n'importe o\u00f9."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Authorization service based on Sympa group manager (Universalistes) and SAML Attributes Authorities.\nIt allows virtual organizations (e.g. research communities) composed by people belonging to different institutions (i.e. managed by different referentials) to access to common resources (if authorization was granted) after having been authenticated by their respective institutions.\nThis service will be in charge of authentication and provide accurate access control on a community's web resource (group defined in Sympa). This resource can therefore be hosted anywhere."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.sussexcoast.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Henderson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:phenderson@sussexcoast.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Falla"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:MFalla@sussexcoast.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.sussexcoast.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-10-22T13:54:19Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVAPawddu40r8UEYXiRI2PCN7NZhVUMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCAxHjAcBgNVBAMTFWlkcC5zdXNzZXhjb2FzdC5hYy51azAeFw0xMzA4MTUx\n\t\t\t\t\t\tNTM2MjRaFw0zMzA4MTUxNTM2MjRaMCAxHjAcBgNVBAMTFWlkcC5zdXNzZXhjb2Fz\n\t\t\t\t\t\tdC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJUCHJLmCjKw\n\t\t\t\t\t\t9qA1Ih2Dxlv6egks+noCR51m17eZiGvFX0yMgwAxaKtR3YifvbB+Is6OUmajhBpI\n\t\t\t\t\t\tCzLnXvl+JGLRdfUnfI6UkKJzbWqA6YHvJ+wpUNi/3zKsVtWKQJkNwfutETZ0lRac\n\t\t\t\t\t\tNqg4GV+LYZTrSMpYCeWYElRGl6FXqO/RGDTlGFsyz3zW1aQ0glcGXAXMjUEaqllx\n\t\t\t\t\t\tHJh1CTPqpvBSyjszE1cqOb1SOa5mjRNWpjvHqZG9MiFNkdK42o59DDutkKDrzy23\n\t\t\t\t\t\tW+LfLXpTf34Azg6OiBMUoiR8/L9sMJzQgBNpAqf8jmudVfI99dbRiE5IETXLic6D\n\t\t\t\t\t\twXEWpY9QHisCAwEAAaNxMG8wTgYDVR0RBEcwRYIVaWRwLnN1c3NleGNvYXN0LmFj\n\t\t\t\t\t\tLnVrhixodHRwczovL2lkcC5zdXNzZXhjb2FzdC5hYy51ay9pZHAvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQUGOChlS1FUiNl0WdWrVoquoZlZN0wDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAH/g5HazCvM36U9zfkj3FrlSRVhg3f1czmqx1qE6SfnhF3R6X68u9WRtpJ+D\n\t\t\t\t\t\tTvwv05UhhnSzAk+ijxQL2/1bwkWpS2d+a6d6+kjRABUVjx1mQOAuJLfFcGqBnXEs\n\t\t\t\t\t\ttRj+Gc4eqYQm/BxxCwakyRo4jy13a4Mn3GOArZmiObKaBbWEgqqdLUEASBJJzjiE\n\t\t\t\t\t\tVZpoq6DGegpSPiff212TQiVNZ63eITPS927MhNkZ8bCI5yK/iqbn4BKwM8Lg7rRX\n\t\t\t\t\t\t77Z19XW7izNdrg9EIjkLKsMdqukXpi/UkMc3QXOvBnppPp03GFVZERTUCB6WrCnR\n\t\t\t\t\t\tPKGUsR8JV4C/b+aw7Qy977lXij4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sussexcoast.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sussexcoast.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sussexcoast.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sussexcoast.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sussexcoast.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sussexcoast.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.sussexcoast.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sussexcoast.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.sussexcoast.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sussexcoast.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sussexcoast.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sussexcoast.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sussexcoast.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVAPawddu40r8UEYXiRI2PCN7NZhVUMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCAxHjAcBgNVBAMTFWlkcC5zdXNzZXhjb2FzdC5hYy51azAeFw0xMzA4MTUx\n\t\t\t\t\t\tNTM2MjRaFw0zMzA4MTUxNTM2MjRaMCAxHjAcBgNVBAMTFWlkcC5zdXNzZXhjb2Fz\n\t\t\t\t\t\tdC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJUCHJLmCjKw\n\t\t\t\t\t\t9qA1Ih2Dxlv6egks+noCR51m17eZiGvFX0yMgwAxaKtR3YifvbB+Is6OUmajhBpI\n\t\t\t\t\t\tCzLnXvl+JGLRdfUnfI6UkKJzbWqA6YHvJ+wpUNi/3zKsVtWKQJkNwfutETZ0lRac\n\t\t\t\t\t\tNqg4GV+LYZTrSMpYCeWYElRGl6FXqO/RGDTlGFsyz3zW1aQ0glcGXAXMjUEaqllx\n\t\t\t\t\t\tHJh1CTPqpvBSyjszE1cqOb1SOa5mjRNWpjvHqZG9MiFNkdK42o59DDutkKDrzy23\n\t\t\t\t\t\tW+LfLXpTf34Azg6OiBMUoiR8/L9sMJzQgBNpAqf8jmudVfI99dbRiE5IETXLic6D\n\t\t\t\t\t\twXEWpY9QHisCAwEAAaNxMG8wTgYDVR0RBEcwRYIVaWRwLnN1c3NleGNvYXN0LmFj\n\t\t\t\t\t\tLnVrhixodHRwczovL2lkcC5zdXNzZXhjb2FzdC5hYy51ay9pZHAvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQUGOChlS1FUiNl0WdWrVoquoZlZN0wDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAH/g5HazCvM36U9zfkj3FrlSRVhg3f1czmqx1qE6SfnhF3R6X68u9WRtpJ+D\n\t\t\t\t\t\tTvwv05UhhnSzAk+ijxQL2/1bwkWpS2d+a6d6+kjRABUVjx1mQOAuJLfFcGqBnXEs\n\t\t\t\t\t\ttRj+Gc4eqYQm/BxxCwakyRo4jy13a4Mn3GOArZmiObKaBbWEgqqdLUEASBJJzjiE\n\t\t\t\t\t\tVZpoq6DGegpSPiff212TQiVNZ63eITPS927MhNkZ8bCI5yK/iqbn4BKwM8Lg7rRX\n\t\t\t\t\t\t77Z19XW7izNdrg9EIjkLKsMdqukXpi/UkMc3QXOvBnppPp03GFVZERTUCB6WrCnR\n\t\t\t\t\t\tPKGUsR8JV4C/b+aw7Qy977lXij4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Sussex Coast College Hastings"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sussexcoast.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Sussex Coast College Hastings"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib-idp.dev.ja.net/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smith"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Rhys.Smith@jisc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rhys"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smith"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Rhys.Smith@jisc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rhys"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib-idp.dev.ja.net/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-08-26T09:17:56Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-idp.dev.ja.net:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.dev.ja.net:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUaU3qUCHZr7xxUW7Knfvc2zgBW7QwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwHjEcMBoGA1UEAwwTc2hpYi1pZHAuZGV2LmphLm5ldDAeFw0xNTA4MjQxODQ4\n\t\t\t\t\t\tNTNaFw0zNTA4MjQxODQ4NTNaMB4xHDAaBgNVBAMME3NoaWItaWRwLmRldi5qYS5u\n\t\t\t\t\t\tZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCJPcwZRlDNpM9h/SeA\n\t\t\t\t\t\t4x2q8VLHI31fc6DAhH/vSgfjBq5t5V/Qj/FQHme7lraCsgMYSklxQ2ND+80gZIpI\n\t\t\t\t\t\tYi3zIAeEoi8DtaStS0J8MxRnqHr7vrpoYNnKyQtWUASzCxUINnDLffrz7yJwBV+k\n\t\t\t\t\t\tdHVGc5AY3LTRzDQOTQc0/dO4tn9nwZX37L2yzASrHLf1xs2M8b5lmIvggewdzAgd\n\t\t\t\t\t\tLwD8aFu24/rxR4R6RgOO7HlOsOtfNrMzCYt99vevysNMHb1IQrcd3XAYuz5nD+rQ\n\t\t\t\t\t\t9EhrQLaHJv/UvahxVALhQYS752XITEaHca8y7scpJe00lo88P5Pvm8pkFITXxuuF\n\t\t\t\t\t\tjlVlAgMBAAGjbTBrMB0GA1UdDgQWBBShbbEIrp4AY9LJ7aYr6WrK2kH2aDBKBgNV\n\t\t\t\t\t\tHREEQzBBghNzaGliLWlkcC5kZXYuamEubmV0hipodHRwczovL3NoaWItaWRwLmRl\n\t\t\t\t\t\tdi5qYS5uZXQvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAFOKaj2F\n\t\t\t\t\t\tWaxl1hC0mry7E/19/ZbBcb1jGFrWeLxnZC1iYkGbaw4xjrgdnYLfMzcp8rbGORZB\n\t\t\t\t\t\tlO4e8pD9HZDINjJWP1gfejEK4eUHSD0Bfnn2oLhJkkzFwbYPi85aQTS94ploRPe/\n\t\t\t\t\t\tPoOdGL5tx3z224611QyU4MFiCUvDBtyfN+9igNCapXKAkwYGUD3N7YUpJqrcorEv\n\t\t\t\t\t\t6qXU19VVTOOCB8eBZ5SAo6g/vTB1VtA/5qKpBQ081D3E3iox8twvu+U1aaPYOzR2\n\t\t\t\t\t\tgS8kL8UfacDILGi4Vrf+pbQ4vR433boq3x+sT6hgs3whi5ZK1ltABgTbmCVtNEwn\n\t\t\t\t\t\tuoDqeFZtzSo+FJM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUQQ9WRv8vtZUnDG3HA8pY15fsjgkwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwHjEcMBoGA1UEAwwTc2hpYi1pZHAuZGV2LmphLm5ldDAeFw0xNTA4MjQxODQ4\n\t\t\t\t\t\tNTFaFw0zNTA4MjQxODQ4NTFaMB4xHDAaBgNVBAMME3NoaWItaWRwLmRldi5qYS5u\n\t\t\t\t\t\tZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDFCR//lF/Rv4f+FKaz\n\t\t\t\t\t\tRTch/m/KuNy60AaJ8HPE+Ni/LgyvVddP6T6A9mRkBJ4S44nGw3A01PaDQ2y4R4/l\n\t\t\t\t\t\tSM9CTn5d1urg8Gy8R2JtZvZMjWxGwmv59nZ+9XvyGzLH7zPJpEKXD4jVCp/O4kWC\n\t\t\t\t\t\tsrBBqUoi6hQHgHyNDe9ftFVDrGVf3cVaIksPWuP6Tw8UHiz19RQBQUed7UZAnDnl\n\t\t\t\t\t\tm/lTAH122n6uBCHtG6u2Tl91TFQ1HCoMpeypvzDcZObja3k3AlSoM9X7VXWy4YW8\n\t\t\t\t\t\tmvgPaY3luH/udR1ttqRc7scF+9Iw/1ma0dIeehBBhUJvhbJ87HXnDwjAFkR6LOtd\n\t\t\t\t\t\tTSu/AgMBAAGjbTBrMB0GA1UdDgQWBBTC+q/3WvsVf5Kfz0Zzp+S/ca10qzBKBgNV\n\t\t\t\t\t\tHREEQzBBghNzaGliLWlkcC5kZXYuamEubmV0hipodHRwczovL3NoaWItaWRwLmRl\n\t\t\t\t\t\tdi5qYS5uZXQvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBALcvI5x6\n\t\t\t\t\t\tCBfbRHAc6sM+msCpTaD7n8MT0Z9MYRG1UZClT0I9QrYBuHk4voNCeteoqjxmukWw\n\t\t\t\t\t\tN6mEbw0xSNjfQb9Z12YKxv6NfWuZp8SbWB50PKvxXSMVBi/h0OqPAQ0EaMeJvyeF\n\t\t\t\t\t\tPXnpVY4jxx0duCrL+Adt/AOYqssTXlHNi7T8swfoflfEQtd/V3ptiaKiv650jXL1\n\t\t\t\t\t\txT3mK+onpaeeBhetjvorjej9B8S+i6oFZJ5hHE/vHbKmiLVsjCAtOq/lYyIe9lx/\n\t\t\t\t\t\tII3qo5yGEItsYApBOcXMSXOrFd3OjyCUepX7P7siAMpQ538DnmuSLdURgdYUlIID\n\t\t\t\t\t\tavp66EtCEnhWtN8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUJNP74b6Wyv0z7gWAfmYFvRKaOPcwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwHjEcMBoGA1UEAwwTc2hpYi1pZHAuZGV2LmphLm5ldDAeFw0xNTA4MjQxODQ4\n\t\t\t\t\t\tNTFaFw0zNTA4MjQxODQ4NTFaMB4xHDAaBgNVBAMME3NoaWItaWRwLmRldi5qYS5u\n\t\t\t\t\t\tZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCk4+4Jki/alefE8Fu/\n\t\t\t\t\t\tEBwTfvdlP08P5D8DXJWe/nXYhKa6K7ppCdd1oySmbPRjm4X+2LZ1woEMovAz0TnY\n\t\t\t\t\t\tmaSj3E8kpt7aTLpLbaYpyQTlgH0b8uzjGIB2ldHj9Rmr4iGz6TT40/hSaWV3aozn\n\t\t\t\t\t\tAXAEVfM638iQbum+d3aTpFgI3P0pm2jXo+8VRxsx882dGkQaYcFOsDxjETMwsVet\n\t\t\t\t\t\t9h4kmhblFrikcdsLmaVgetcHAwfuIeF0Zh+s41//htNfpd9upAohhXCajOgCi5AJ\n\t\t\t\t\t\t7rfwsNGR9BDJ4UMSQ5LhKycY25AUjAOJqt6VbRZ5Z101W4fWSmquvdzNQuFCFq4U\n\t\t\t\t\t\tQSzRAgMBAAGjbTBrMB0GA1UdDgQWBBTZhrqH6bT0I+tmGdjFNAOFPrNsdzBKBgNV\n\t\t\t\t\t\tHREEQzBBghNzaGliLWlkcC5kZXYuamEubmV0hipodHRwczovL3NoaWItaWRwLmRl\n\t\t\t\t\t\tdi5qYS5uZXQvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAJB8qboq\n\t\t\t\t\t\tt9orqybKDTGUYpvf95rnogvL0wq2X8ectcKJivFtEkTBBWsbFNdeDc/sxqVLMSPW\n\t\t\t\t\t\tG1VPZ+FnvjTv8RKjlIGQCmVTPMK1B5mMH9hdw/3d+1o/w0w8GlfUf41s4MAhwJjz\n\t\t\t\t\t\t4sMQu17tkUmhWPavgVDZqeuRSr5D3GLMv/SAnXBrJgwu4SEUTNItkb4k/n50PaU8\n\t\t\t\t\t\tDtPk+jivu8m2qiwPXwb+ditBKHbcVKtUOV7s/finOgkwvgF+r1A+LP5PbXqhEysI\n\t\t\t\t\t\tvUurDG6P3/K7rNPP5pC43C0sUgf7PC9PvDdkz6RDLvr3EK9nqTLwvR6F2uX2OwCt\n\t\t\t\t\t\t9Bt3PLpZ5T1ZzOo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dev.ja.net"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-idp.dev.ja.net/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-idp.dev.ja.net/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib-idp.dev.ja.net/idp/profile/SAML2/POST-SimpleSign/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.dev.ja.net:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib-idp.dev.ja.net/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-idp.dev.ja.net/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib-idp.dev.ja.net/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-idp.dev.ja.net/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-idp.dev.ja.net:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.dev.ja.net:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dev.ja.net"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUaU3qUCHZr7xxUW7Knfvc2zgBW7QwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwHjEcMBoGA1UEAwwTc2hpYi1pZHAuZGV2LmphLm5ldDAeFw0xNTA4MjQxODQ4\n\t\t\t\t\t\tNTNaFw0zNTA4MjQxODQ4NTNaMB4xHDAaBgNVBAMME3NoaWItaWRwLmRldi5qYS5u\n\t\t\t\t\t\tZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCJPcwZRlDNpM9h/SeA\n\t\t\t\t\t\t4x2q8VLHI31fc6DAhH/vSgfjBq5t5V/Qj/FQHme7lraCsgMYSklxQ2ND+80gZIpI\n\t\t\t\t\t\tYi3zIAeEoi8DtaStS0J8MxRnqHr7vrpoYNnKyQtWUASzCxUINnDLffrz7yJwBV+k\n\t\t\t\t\t\tdHVGc5AY3LTRzDQOTQc0/dO4tn9nwZX37L2yzASrHLf1xs2M8b5lmIvggewdzAgd\n\t\t\t\t\t\tLwD8aFu24/rxR4R6RgOO7HlOsOtfNrMzCYt99vevysNMHb1IQrcd3XAYuz5nD+rQ\n\t\t\t\t\t\t9EhrQLaHJv/UvahxVALhQYS752XITEaHca8y7scpJe00lo88P5Pvm8pkFITXxuuF\n\t\t\t\t\t\tjlVlAgMBAAGjbTBrMB0GA1UdDgQWBBShbbEIrp4AY9LJ7aYr6WrK2kH2aDBKBgNV\n\t\t\t\t\t\tHREEQzBBghNzaGliLWlkcC5kZXYuamEubmV0hipodHRwczovL3NoaWItaWRwLmRl\n\t\t\t\t\t\tdi5qYS5uZXQvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAFOKaj2F\n\t\t\t\t\t\tWaxl1hC0mry7E/19/ZbBcb1jGFrWeLxnZC1iYkGbaw4xjrgdnYLfMzcp8rbGORZB\n\t\t\t\t\t\tlO4e8pD9HZDINjJWP1gfejEK4eUHSD0Bfnn2oLhJkkzFwbYPi85aQTS94ploRPe/\n\t\t\t\t\t\tPoOdGL5tx3z224611QyU4MFiCUvDBtyfN+9igNCapXKAkwYGUD3N7YUpJqrcorEv\n\t\t\t\t\t\t6qXU19VVTOOCB8eBZ5SAo6g/vTB1VtA/5qKpBQ081D3E3iox8twvu+U1aaPYOzR2\n\t\t\t\t\t\tgS8kL8UfacDILGi4Vrf+pbQ4vR433boq3x+sT6hgs3whi5ZK1ltABgTbmCVtNEwn\n\t\t\t\t\t\tuoDqeFZtzSo+FJM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUQQ9WRv8vtZUnDG3HA8pY15fsjgkwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwHjEcMBoGA1UEAwwTc2hpYi1pZHAuZGV2LmphLm5ldDAeFw0xNTA4MjQxODQ4\n\t\t\t\t\t\tNTFaFw0zNTA4MjQxODQ4NTFaMB4xHDAaBgNVBAMME3NoaWItaWRwLmRldi5qYS5u\n\t\t\t\t\t\tZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDFCR//lF/Rv4f+FKaz\n\t\t\t\t\t\tRTch/m/KuNy60AaJ8HPE+Ni/LgyvVddP6T6A9mRkBJ4S44nGw3A01PaDQ2y4R4/l\n\t\t\t\t\t\tSM9CTn5d1urg8Gy8R2JtZvZMjWxGwmv59nZ+9XvyGzLH7zPJpEKXD4jVCp/O4kWC\n\t\t\t\t\t\tsrBBqUoi6hQHgHyNDe9ftFVDrGVf3cVaIksPWuP6Tw8UHiz19RQBQUed7UZAnDnl\n\t\t\t\t\t\tm/lTAH122n6uBCHtG6u2Tl91TFQ1HCoMpeypvzDcZObja3k3AlSoM9X7VXWy4YW8\n\t\t\t\t\t\tmvgPaY3luH/udR1ttqRc7scF+9Iw/1ma0dIeehBBhUJvhbJ87HXnDwjAFkR6LOtd\n\t\t\t\t\t\tTSu/AgMBAAGjbTBrMB0GA1UdDgQWBBTC+q/3WvsVf5Kfz0Zzp+S/ca10qzBKBgNV\n\t\t\t\t\t\tHREEQzBBghNzaGliLWlkcC5kZXYuamEubmV0hipodHRwczovL3NoaWItaWRwLmRl\n\t\t\t\t\t\tdi5qYS5uZXQvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBALcvI5x6\n\t\t\t\t\t\tCBfbRHAc6sM+msCpTaD7n8MT0Z9MYRG1UZClT0I9QrYBuHk4voNCeteoqjxmukWw\n\t\t\t\t\t\tN6mEbw0xSNjfQb9Z12YKxv6NfWuZp8SbWB50PKvxXSMVBi/h0OqPAQ0EaMeJvyeF\n\t\t\t\t\t\tPXnpVY4jxx0duCrL+Adt/AOYqssTXlHNi7T8swfoflfEQtd/V3ptiaKiv650jXL1\n\t\t\t\t\t\txT3mK+onpaeeBhetjvorjej9B8S+i6oFZJ5hHE/vHbKmiLVsjCAtOq/lYyIe9lx/\n\t\t\t\t\t\tII3qo5yGEItsYApBOcXMSXOrFd3OjyCUepX7P7siAMpQ538DnmuSLdURgdYUlIID\n\t\t\t\t\t\tavp66EtCEnhWtN8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUJNP74b6Wyv0z7gWAfmYFvRKaOPcwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwHjEcMBoGA1UEAwwTc2hpYi1pZHAuZGV2LmphLm5ldDAeFw0xNTA4MjQxODQ4\n\t\t\t\t\t\tNTFaFw0zNTA4MjQxODQ4NTFaMB4xHDAaBgNVBAMME3NoaWItaWRwLmRldi5qYS5u\n\t\t\t\t\t\tZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCk4+4Jki/alefE8Fu/\n\t\t\t\t\t\tEBwTfvdlP08P5D8DXJWe/nXYhKa6K7ppCdd1oySmbPRjm4X+2LZ1woEMovAz0TnY\n\t\t\t\t\t\tmaSj3E8kpt7aTLpLbaYpyQTlgH0b8uzjGIB2ldHj9Rmr4iGz6TT40/hSaWV3aozn\n\t\t\t\t\t\tAXAEVfM638iQbum+d3aTpFgI3P0pm2jXo+8VRxsx882dGkQaYcFOsDxjETMwsVet\n\t\t\t\t\t\t9h4kmhblFrikcdsLmaVgetcHAwfuIeF0Zh+s41//htNfpd9upAohhXCajOgCi5AJ\n\t\t\t\t\t\t7rfwsNGR9BDJ4UMSQ5LhKycY25AUjAOJqt6VbRZ5Z101W4fWSmquvdzNQuFCFq4U\n\t\t\t\t\t\tQSzRAgMBAAGjbTBrMB0GA1UdDgQWBBTZhrqH6bT0I+tmGdjFNAOFPrNsdzBKBgNV\n\t\t\t\t\t\tHREEQzBBghNzaGliLWlkcC5kZXYuamEubmV0hipodHRwczovL3NoaWItaWRwLmRl\n\t\t\t\t\t\tdi5qYS5uZXQvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAJB8qboq\n\t\t\t\t\t\tt9orqybKDTGUYpvf95rnogvL0wq2X8ectcKJivFtEkTBBWsbFNdeDc/sxqVLMSPW\n\t\t\t\t\t\tG1VPZ+FnvjTv8RKjlIGQCmVTPMK1B5mMH9hdw/3d+1o/w0w8GlfUf41s4MAhwJjz\n\t\t\t\t\t\t4sMQu17tkUmhWPavgVDZqeuRSr5D3GLMv/SAnXBrJgwu4SEUTNItkb4k/n50PaU8\n\t\t\t\t\t\tDtPk+jivu8m2qiwPXwb+ditBKHbcVKtUOV7s/finOgkwvgF+r1A+LP5PbXqhEysI\n\t\t\t\t\t\tvUurDG6P3/K7rNPP5pC43C0sUgf7PC9PvDdkz6RDLvr3EK9nqTLwvR6F2uX2OwCt\n\t\t\t\t\t\t9Bt3PLpZ5T1ZzOo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Jisc Technologies (Development Shibboleth IdP)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jisc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "JISC Collections and Janet Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://quod.lib.umich.edu/shibboleth-sp/acls",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lit-cs-sysadmin@umich.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "University of Michigan Library IT"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lit-cs-sysadmin@umich.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "University of Michigan Library IT"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://quod.lib.umich.edu/shibboleth-sp/acls",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-11-18T16:12:43Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Michigan: ACLS Humanities E-Book"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://humanitiesebook.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Michigan"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ACLS Humanities E-Book is a digital collection of over 3,300 full-text, cross-searchable books in the humanities."
                  }
                ],
                "logo": [
                  {
                    "text": "https://quod.lib.umich.edu/a/acls/graphics/aclsheader_new.gif",
                    "height": "74",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "872"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ACLS Humanities E-Book"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEijCCA3KgAwIBAgIJAIT48jHMZ0+hMA0GCSqGSIb3DQEBBQUAMIHFMQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzERMA8GA1UECBMITWljaGlnYW4xEjAQBgNVBAcTCUFubiBBcmJvcjEf\n\t\t\t\t\t\tMB0GA1UEChMWVW5pdmVyc2l0eSBvZiBNaWNoaWdhbjEnMCUGA1UECxMeTGlicmFy\n\t\t\t\t\t\teSBJbmZvcm1hdGlvbiBUZWNobm9sb2d5MRswGQYDVQQDExJxdW9kLmxpYi51bWlj\n\t\t\t\t\t\taC5lZHUxKDAmBgkqhkiG9w0BCQEWGWxpdC1jcy1zeXNhZG1pbkB1bWljaC5lZHUw\n\t\t\t\t\t\tHhcNMDkwODA3MTUyODU0WhcNMTkwODA1MTUyODU0WjCBxTELMAkGA1UEBhMCVVMx\n\t\t\t\t\t\tETAPBgNVBAgTCE1pY2hpZ2FuMRIwEAYDVQQHEwlBbm4gQXJib3IxHzAdBgNVBAoT\n\t\t\t\t\t\tFlVuaXZlcnNpdHkgb2YgTWljaGlnYW4xJzAlBgNVBAsTHkxpYnJhcnkgSW5mb3Jt\n\t\t\t\t\t\tYXRpb24gVGVjaG5vbG9neTEbMBkGA1UEAxMScXVvZC5saWIudW1pY2guZWR1MSgw\n\t\t\t\t\t\tJgYJKoZIhvcNAQkBFhlsaXQtY3Mtc3lzYWRtaW5AdW1pY2guZWR1MIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtw76D6i/mIoKdM0RKwvl4j5DN7POIScx\n\t\t\t\t\t\thTDtXslnmEzd7Lzfl8q8NVgoFDJ7U6ciRA3ajKe26wlJO/E0F4iZPQiJvcl1T6lT\n\t\t\t\t\t\twKOp4lK4xGFBScYsaLJnI1WzjiTHJt8QpMqpuHpfFSzqozhS9rYADBKwVPANi9qr\n\t\t\t\t\t\tFplIQr/d/h3R48H/9fHcEDV8GFucH5kLw5EkLOmIAu++skkRAG6Wvajj498drE0e\n\t\t\t\t\t\tCHDGa7O2l3S7HYlLiQH+KnRk9Fv/kwWsqVAk7E/48oa3UuOdJM01/PNVSAEKBg2w\n\t\t\t\t\t\ti2S0YP5sZqBuCP43RzHarEFHNawmu8kcb51aXFagOq6xlbaisTMjUQIDAQABo3sw\n\t\t\t\t\t\teTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBD\n\t\t\t\t\t\tZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUjqnAa9SKCm5M1p4CTERZW+ouqEkwHwYDVR0j\n\t\t\t\t\t\tBBgwFoAUjqnAa9SKCm5M1p4CTERZW+ouqEkwDQYJKoZIhvcNAQEFBQADggEBAKjc\n\t\t\t\t\t\tMNz0L7eP9Ck1v07Q239cbH31S/KxWaiQP/gbHw7knNZhhNywCs5F/V+/zI/xaPUu\n\t\t\t\t\t\tgtWOiQborOuysBa7lGdrQkKqP5r8j5Tq8HtM5XhIf0r8BIZg1wX8k92CBI8JR7IY\n\t\t\t\t\t\tk4qcrrSDrImNB2EEnTTMAWWc8VTKW8+D5z1ygDXQsB2Gxf/ywk4xQ9r+AChBCwt9\n\t\t\t\t\t\t319gyt4k8RIkhvErotahf2MFzZrzM7GrEdNZhjfyprI8GilTC3MC7tep5wHyvRQ5\n\t\t\t\t\t\t6+M7kXd3PupQ48lKtXY2BvZqmHJ2XVAcLanoJobr4fBEGBT29i2sE/Uqs9N1DTz5\n\t\t\t\t\t\tPLcvWTRfLv+JNqoT2yM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEijCCA3KgAwIBAgIJAIT48jHMZ0+hMA0GCSqGSIb3DQEBBQUAMIHFMQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzERMA8GA1UECBMITWljaGlnYW4xEjAQBgNVBAcTCUFubiBBcmJvcjEf\n\t\t\t\t\t\tMB0GA1UEChMWVW5pdmVyc2l0eSBvZiBNaWNoaWdhbjEnMCUGA1UECxMeTGlicmFy\n\t\t\t\t\t\teSBJbmZvcm1hdGlvbiBUZWNobm9sb2d5MRswGQYDVQQDExJxdW9kLmxpYi51bWlj\n\t\t\t\t\t\taC5lZHUxKDAmBgkqhkiG9w0BCQEWGWxpdC1jcy1zeXNhZG1pbkB1bWljaC5lZHUw\n\t\t\t\t\t\tHhcNMDkwODA3MTUyODU0WhcNMTkwODA1MTUyODU0WjCBxTELMAkGA1UEBhMCVVMx\n\t\t\t\t\t\tETAPBgNVBAgTCE1pY2hpZ2FuMRIwEAYDVQQHEwlBbm4gQXJib3IxHzAdBgNVBAoT\n\t\t\t\t\t\tFlVuaXZlcnNpdHkgb2YgTWljaGlnYW4xJzAlBgNVBAsTHkxpYnJhcnkgSW5mb3Jt\n\t\t\t\t\t\tYXRpb24gVGVjaG5vbG9neTEbMBkGA1UEAxMScXVvZC5saWIudW1pY2guZWR1MSgw\n\t\t\t\t\t\tJgYJKoZIhvcNAQkBFhlsaXQtY3Mtc3lzYWRtaW5AdW1pY2guZWR1MIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtw76D6i/mIoKdM0RKwvl4j5DN7POIScx\n\t\t\t\t\t\thTDtXslnmEzd7Lzfl8q8NVgoFDJ7U6ciRA3ajKe26wlJO/E0F4iZPQiJvcl1T6lT\n\t\t\t\t\t\twKOp4lK4xGFBScYsaLJnI1WzjiTHJt8QpMqpuHpfFSzqozhS9rYADBKwVPANi9qr\n\t\t\t\t\t\tFplIQr/d/h3R48H/9fHcEDV8GFucH5kLw5EkLOmIAu++skkRAG6Wvajj498drE0e\n\t\t\t\t\t\tCHDGa7O2l3S7HYlLiQH+KnRk9Fv/kwWsqVAk7E/48oa3UuOdJM01/PNVSAEKBg2w\n\t\t\t\t\t\ti2S0YP5sZqBuCP43RzHarEFHNawmu8kcb51aXFagOq6xlbaisTMjUQIDAQABo3sw\n\t\t\t\t\t\teTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBD\n\t\t\t\t\t\tZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUjqnAa9SKCm5M1p4CTERZW+ouqEkwHwYDVR0j\n\t\t\t\t\t\tBBgwFoAUjqnAa9SKCm5M1p4CTERZW+ouqEkwDQYJKoZIhvcNAQEFBQADggEBAKjc\n\t\t\t\t\t\tMNz0L7eP9Ck1v07Q239cbH31S/KxWaiQP/gbHw7knNZhhNywCs5F/V+/zI/xaPUu\n\t\t\t\t\t\tgtWOiQborOuysBa7lGdrQkKqP5r8j5Tq8HtM5XhIf0r8BIZg1wX8k92CBI8JR7IY\n\t\t\t\t\t\tk4qcrrSDrImNB2EEnTTMAWWc8VTKW8+D5z1ygDXQsB2Gxf/ywk4xQ9r+AChBCwt9\n\t\t\t\t\t\t319gyt4k8RIkhvErotahf2MFzZrzM7GrEdNZhjfyprI8GilTC3MC7tep5wHyvRQ5\n\t\t\t\t\t\t6+M7kXd3PupQ48lKtXY2BvZqmHJ2XVAcLanoJobr4fBEGBT29i2sE/Uqs9N1DTz5\n\t\t\t\t\t\tPLcvWTRfLv+JNqoT2yM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://quod.lib.umich.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://quod.lib.umich.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://quod.lib.umich.edu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://quod.lib.umich.edu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "University of Michigan: ACLS Humanities E-Book"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.fhwn.ac.at/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Service-Desk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@fhwn.ac.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Zentraler"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Service-Desk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@fhwn.ac.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Zentraler"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.fhwn.ac.at/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://eduid.at/policy/mdrps-20140606"
              }
            ],
            "registration_instant": "2013-12-06T12:40:18Z",
            "registration_authority": "http://eduid.at",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIULHX3aIs7dO97h9UxvhHJhQksVhMwDQYJKoZIhvcNAQEF\nBQAwIDEeMBwGA1UEAxMVc2hpYmJvbGV0aC5maHduLmFjLmF0MB4XDTEzMTExMzA4\nMjkxMVoXDTMzMTExMzA4MjkxMVowIDEeMBwGA1UEAxMVc2hpYmJvbGV0aC5maHdu\nLmFjLmF0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoS8CXF8y8Lcd\nJ1bWqWqpcxqK07ajkBtZQ5E7Fo4pOaXx54R4eOQZR72VMLTf7Qg8W8UYopD1A1/h\ncd8u5Un/yFHDuy34pG/rPTc0rvmHEeZ5nEkDNzvKbebX78bizbZ7cThwFf8WADiV\nUAC9gxpxLAiVhqEPjytIJOnoC9ENNBqqKOaBme3KgifRW/18vEes1DANSNMP1LZi\nMLZCMLouKgwVzBpR7MGiDFx3+Xdn/g1210TpXyW4yr4FZyNxJOmuZPY8GGQBoI15\nNmWKp5Wgh1EcuMK/X0rOm7QZuuHMAUd6awXTE71MljXlPmlfDylcLWBx2QHG8Yrq\nWClEBAefeQIDAQABo3EwbzBOBgNVHREERzBFghVzaGliYm9sZXRoLmZod24uYWMu\nYXSGLGh0dHBzOi8vc2hpYmJvbGV0aC5maHduLmFjLmF0L2lkcC9zaGliYm9sZXRo\nMB0GA1UdDgQWBBRju/KxvciXjf6JW/P+nVPegBlUsTANBgkqhkiG9w0BAQUFAAOC\nAQEATpk3i0dOltmwiHTi2NwkXPVnQh6Wtk70ZJle/2Vwl6IJGU5AcruKL9ySROKO\nz69XGJlr/CJsuZcwee/rdeGkQEaNKLjL6PgGqmxWz85LRz5rbBFAFujLj5yBSEXA\nHSLH5mhf+hL6n8uwEYcGk/0WBkWYSjuNld+4XbbyCrr12WreHk7PnZxdmSzR2gQy\nI67i0vpE9NwTTnO7ZfRVvlAtC7jYv5aC3BdS89q7R68F24h2AHbXkvrWkg+DWnjw\nBIVIp1IblZQxAYs2OF5CCTkJyWmteql3RucKtC1zWuPY1heiT+2+ac44TwkIvInI\naTYBUwf6LPKYdpVL5MFq35/cnQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fhwn.ac.at"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.fhwn.ac.at:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.fhwn.ac.at:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.fhwn.ac.at/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.fhwn.ac.at/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.fhwn.ac.at:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.fhwn.ac.at/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.fhwn.ac.at/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.fhwn.ac.at/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.fhwn.ac.at/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.fhwn.ac.at:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.fhwn.ac.at:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fhwn.ac.at"
              },
              {
                "logo": [
                  {
                    "text": "https://moodle2.fhwn.ac.at/bilder/logo.jpg",
                    "height": "85",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "125"
                  },
                  {
                    "text": "https://moodle2.fhwn.ac.at/bilder/favicon.ico",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FH Wiener Neustadt"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Applied Sciences Wiener Neustadt"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "fhwn.ac.at"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.83902,16.24842"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:628:2270::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIULHX3aIs7dO97h9UxvhHJhQksVhMwDQYJKoZIhvcNAQEF\nBQAwIDEeMBwGA1UEAxMVc2hpYmJvbGV0aC5maHduLmFjLmF0MB4XDTEzMTExMzA4\nMjkxMVoXDTMzMTExMzA4MjkxMVowIDEeMBwGA1UEAxMVc2hpYmJvbGV0aC5maHdu\nLmFjLmF0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoS8CXF8y8Lcd\nJ1bWqWqpcxqK07ajkBtZQ5E7Fo4pOaXx54R4eOQZR72VMLTf7Qg8W8UYopD1A1/h\ncd8u5Un/yFHDuy34pG/rPTc0rvmHEeZ5nEkDNzvKbebX78bizbZ7cThwFf8WADiV\nUAC9gxpxLAiVhqEPjytIJOnoC9ENNBqqKOaBme3KgifRW/18vEes1DANSNMP1LZi\nMLZCMLouKgwVzBpR7MGiDFx3+Xdn/g1210TpXyW4yr4FZyNxJOmuZPY8GGQBoI15\nNmWKp5Wgh1EcuMK/X0rOm7QZuuHMAUd6awXTE71MljXlPmlfDylcLWBx2QHG8Yrq\nWClEBAefeQIDAQABo3EwbzBOBgNVHREERzBFghVzaGliYm9sZXRoLmZod24uYWMu\nYXSGLGh0dHBzOi8vc2hpYmJvbGV0aC5maHduLmFjLmF0L2lkcC9zaGliYm9sZXRo\nMB0GA1UdDgQWBBRju/KxvciXjf6JW/P+nVPegBlUsTANBgkqhkiG9w0BAQUFAAOC\nAQEATpk3i0dOltmwiHTi2NwkXPVnQh6Wtk70ZJle/2Vwl6IJGU5AcruKL9ySROKO\nz69XGJlr/CJsuZcwee/rdeGkQEaNKLjL6PgGqmxWz85LRz5rbBFAFujLj5yBSEXA\nHSLH5mhf+hL6n8uwEYcGk/0WBkWYSjuNld+4XbbyCrr12WreHk7PnZxdmSzR2gQy\nI67i0vpE9NwTTnO7ZfRVvlAtC7jYv5aC3BdS89q7R68F24h2AHbXkvrWkg+DWnjw\nBIVIp1IblZQxAYs2OF5CCTkJyWmteql3RucKtC1zWuPY1heiT+2+ac44TwkIvInI\naTYBUwf6LPKYdpVL5MFq35/cnQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "FH Wiener Neustadt"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Applied Sciences Wiener Neustadt"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fhwn.ac.at/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fhwn.ac.at/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "FH Wiener Neustadt f\u00fcr Wirtschaft und Technik GesmbH"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Applied Sciences Wiener Neustadt for Business and Engineering Ltd., Austria"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib1.hw.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ithelp@hw.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Livie"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:G.Livie@hw.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "George"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib1.hw.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-05-02T16:47:03Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEyjCCA7KgAwIBAgIJAIRz4nENPzTrMA0GCSqGSIb3DQEBBQUAMIGeMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEQMA4GA1UECBMHTG90aGlhbjESMBAGA1UEBxMJRWRpbmJ1cmdoMR8w\n\t\t\t\t\t\tHQYDVQQKExZIZXJpb3QtV2F0dCBVbml2ZXJzaXR5MQswCQYDVQQLEwJJUzEXMBUG\n\t\t\t\t\t\tA1UEAxMOc2hpYjEuaHcuYWMudWsxIjAgBgkqhkiG9w0BCQEWE24uYS5tb3JyaXNA\n\t\t\t\t\t\taHcuYWMudWswHhcNMTQwNDA0MTMzNzQ3WhcNMjQwNDAxMTMzNzQ3WjCBnjELMAkG\n\t\t\t\t\t\tA1UEBhMCR0IxEDAOBgNVBAgTB0xvdGhpYW4xEjAQBgNVBAcTCUVkaW5idXJnaDEf\n\t\t\t\t\t\tMB0GA1UEChMWSGVyaW90LVdhdHQgVW5pdmVyc2l0eTELMAkGA1UECxMCSVMxFzAV\n\t\t\t\t\t\tBgNVBAMTDnNoaWIxLmh3LmFjLnVrMSIwIAYJKoZIhvcNAQkBFhNuLmEubW9ycmlz\n\t\t\t\t\t\tQGh3LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAyz97yEPF\n\t\t\t\t\t\tVuXIJNgPVIbakqCkohOfu84WhDL2Ng6/IfVHAM0Ekw9wb36iaTnAY8FzwzHOoV3Z\n\t\t\t\t\t\tiyWJ9LNcR4LZ5twCgtmbXb+IhvTGY24M/kNmcIjy035m/JQTaZrUt98K4LjjW0tw\n\t\t\t\t\t\tHb8PaP/OH4KP+aD2RofacCD1LQ5uglFOMQtEAWUDgR2S0v4Mpsp9iPmJcr9Jk3Br\n\t\t\t\t\t\tPX+zjfhiwo05X8iS4XJL5wO3hrMi4/wNG+y2Ag1A4OBtojGwvUAeHCv5QzLgVY4N\n\t\t\t\t\t\t9YdC9Y+p89xHX4VtNpHY8Y1Mu4jU3iyUsoK0S+UKNSfdBnHJkgAjhD7hWb1ipqM7\n\t\t\t\t\t\tBrTpfWSizP5GgQIDAQABo4IBBzCCAQMwHQYDVR0OBBYEFOjliEHArhe9qgYgp1QL\n\t\t\t\t\t\tq/BpgJgXMIHTBgNVHSMEgcswgciAFOjliEHArhe9qgYgp1QLq/BpgJgXoYGkpIGh\n\t\t\t\t\t\tMIGeMQswCQYDVQQGEwJHQjEQMA4GA1UECBMHTG90aGlhbjESMBAGA1UEBxMJRWRp\n\t\t\t\t\t\tbmJ1cmdoMR8wHQYDVQQKExZIZXJpb3QtV2F0dCBVbml2ZXJzaXR5MQswCQYDVQQL\n\t\t\t\t\t\tEwJJUzEXMBUGA1UEAxMOc2hpYjEuaHcuYWMudWsxIjAgBgkqhkiG9w0BCQEWE24u\n\t\t\t\t\t\tYS5tb3JyaXNAaHcuYWMudWuCCQCEc+JxDT806zAMBgNVHRMEBTADAQH/MA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQCYhVo1561uH9WLY6BDdgrHOYy7mWEaFh9IN3hGiN0Xaol1\n\t\t\t\t\t\tl9cL/OQxrDiNAeYE5v2k4gmrmqQ1k+SarfyG1+y2Cz2nRCeIvFUgzP2ZxY6NihlK\n\t\t\t\t\t\trxiPaMOj8Lhpm1qnMYqfOgEmZm7DspgWTca9ee3GfMi3gNKDhNc3ClT3fmJEz3su\n\t\t\t\t\t\tm591vtWWwBK8FFjmdrfEpMscEBDIjmK3++ZSZcpi7RDgmcOkyYAU4SehufVqTiG/\n\t\t\t\t\t\tLVmqVmL3cap2AeHoYFLsZerEuI/3ZgBE/P0em2OQxFyXAlWOSiD2piEgAUUxl4Vt\n\t\t\t\t\t\tTeTRcCOx2CPOUV8iEok1S6c/YqtF3YOSmCca1Ey2"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hw.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib1.hw.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib1.hw.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib1.hw.ac.uk/shibboleth-idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib1.hw.ac.uk/shibboleth-idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib1.hw.ac.uk/shibboleth-idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib1.hw.ac.uk/shibboleth-idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib1.hw.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib1.hw.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hw.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEyjCCA7KgAwIBAgIJAIRz4nENPzTrMA0GCSqGSIb3DQEBBQUAMIGeMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEQMA4GA1UECBMHTG90aGlhbjESMBAGA1UEBxMJRWRpbmJ1cmdoMR8w\n\t\t\t\t\t\tHQYDVQQKExZIZXJpb3QtV2F0dCBVbml2ZXJzaXR5MQswCQYDVQQLEwJJUzEXMBUG\n\t\t\t\t\t\tA1UEAxMOc2hpYjEuaHcuYWMudWsxIjAgBgkqhkiG9w0BCQEWE24uYS5tb3JyaXNA\n\t\t\t\t\t\taHcuYWMudWswHhcNMTQwNDA0MTMzNzQ3WhcNMjQwNDAxMTMzNzQ3WjCBnjELMAkG\n\t\t\t\t\t\tA1UEBhMCR0IxEDAOBgNVBAgTB0xvdGhpYW4xEjAQBgNVBAcTCUVkaW5idXJnaDEf\n\t\t\t\t\t\tMB0GA1UEChMWSGVyaW90LVdhdHQgVW5pdmVyc2l0eTELMAkGA1UECxMCSVMxFzAV\n\t\t\t\t\t\tBgNVBAMTDnNoaWIxLmh3LmFjLnVrMSIwIAYJKoZIhvcNAQkBFhNuLmEubW9ycmlz\n\t\t\t\t\t\tQGh3LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAyz97yEPF\n\t\t\t\t\t\tVuXIJNgPVIbakqCkohOfu84WhDL2Ng6/IfVHAM0Ekw9wb36iaTnAY8FzwzHOoV3Z\n\t\t\t\t\t\tiyWJ9LNcR4LZ5twCgtmbXb+IhvTGY24M/kNmcIjy035m/JQTaZrUt98K4LjjW0tw\n\t\t\t\t\t\tHb8PaP/OH4KP+aD2RofacCD1LQ5uglFOMQtEAWUDgR2S0v4Mpsp9iPmJcr9Jk3Br\n\t\t\t\t\t\tPX+zjfhiwo05X8iS4XJL5wO3hrMi4/wNG+y2Ag1A4OBtojGwvUAeHCv5QzLgVY4N\n\t\t\t\t\t\t9YdC9Y+p89xHX4VtNpHY8Y1Mu4jU3iyUsoK0S+UKNSfdBnHJkgAjhD7hWb1ipqM7\n\t\t\t\t\t\tBrTpfWSizP5GgQIDAQABo4IBBzCCAQMwHQYDVR0OBBYEFOjliEHArhe9qgYgp1QL\n\t\t\t\t\t\tq/BpgJgXMIHTBgNVHSMEgcswgciAFOjliEHArhe9qgYgp1QLq/BpgJgXoYGkpIGh\n\t\t\t\t\t\tMIGeMQswCQYDVQQGEwJHQjEQMA4GA1UECBMHTG90aGlhbjESMBAGA1UEBxMJRWRp\n\t\t\t\t\t\tbmJ1cmdoMR8wHQYDVQQKExZIZXJpb3QtV2F0dCBVbml2ZXJzaXR5MQswCQYDVQQL\n\t\t\t\t\t\tEwJJUzEXMBUGA1UEAxMOc2hpYjEuaHcuYWMudWsxIjAgBgkqhkiG9w0BCQEWE24u\n\t\t\t\t\t\tYS5tb3JyaXNAaHcuYWMudWuCCQCEc+JxDT806zAMBgNVHRMEBTADAQH/MA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQCYhVo1561uH9WLY6BDdgrHOYy7mWEaFh9IN3hGiN0Xaol1\n\t\t\t\t\t\tl9cL/OQxrDiNAeYE5v2k4gmrmqQ1k+SarfyG1+y2Cz2nRCeIvFUgzP2ZxY6NihlK\n\t\t\t\t\t\trxiPaMOj8Lhpm1qnMYqfOgEmZm7DspgWTca9ee3GfMi3gNKDhNc3ClT3fmJEz3su\n\t\t\t\t\t\tm591vtWWwBK8FFjmdrfEpMscEBDIjmK3++ZSZcpi7RDgmcOkyYAU4SehufVqTiG/\n\t\t\t\t\t\tLVmqVmL3cap2AeHoYFLsZerEuI/3ZgBE/P0em2OQxFyXAlWOSiD2piEgAUUxl4Vt\n\t\t\t\t\t\tTeTRcCOx2CPOUV8iEok1S6c/YqtF3YOSmCca1Ey2"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Heriot-Watt University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hw.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Heriot-Watt University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.calpoly.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "identity-management@calpoly.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Identity Management Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dmalone@calpoly.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dan Malone"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "identity-management@calpoly.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Identity Management Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.calpoly.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.calpoly.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.calpoly.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGXzCCBUegAwIBAgIQJ+EtooE7aPQyEUAEQQAwyjANBgkqhkiG9w0BAQsFADB2\nMQswCQYDVQQGEwJVUzELMAkGA1UECBMCTUkxEjAQBgNVBAcTCUFubiBBcmJvcjES\nMBAGA1UEChMJSW50ZXJuZXQyMREwDwYDVQQLEwhJbkNvbW1vbjEfMB0GA1UEAxMW\nSW5Db21tb24gUlNBIFNlcnZlciBDQTAeFw0xNDEwMTMwMDAwMDBaFw0xNzEwMTIy\nMzU5NTlaMIH0MQswCQYDVQQGEwJVUzETMBEGA1UEERMKOTM0MDctMDE1NDELMAkG\nA1UECBMCQ0ExGDAWBgNVBAcTD1NhbiBMdWlzIE9iaXNwbzEiMCAGA1UECRMZQ2Fs\nIFBvbHkgU3RhdGUgVW5pdmVyc2l0eTFBMD8GA1UEChM4Q2FsaWZvcm5pYSBQb2x5\ndGVjaG5pYyBTdGF0ZSBVbml2ZXJzaXR5LCBTYW4gTHVpcyBPYmlzcG8xKDAmBgNV\nBAsTH0luZm9ybWF0aW9uIFRlY2hub2xvZ3kgU2VydmljZXMxGDAWBgNVBAMTD2lk\ncC5jYWxwb2x5LmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMcA\nY5VxfpqVsoDVEOM3E/m2WsLFKf+lHV/M7neRFa0Sn9j5ha0tM9+vNmhMU4RgX6gc\nIdX7XRkXw80KzqQxeiwyISbiXCDS1zvTJpjyKtgbDrcPGBWaXjl8Mjythfy0WdFN\nQCDI8PQ7XgX1qjrjGKp4IIAMfoqdedwHTingJCOs1XOd1LZm9OMaMiMVtOjSzGpN\ncalID/YLecguXlITBlRzJHgfTDTxuElyLxkCH++fQFYUUYUjJhuKOVaXvH6YUlm2\nwPlhsh/kvKtNDNzbPfiUzHafN31oswFGPR7ZHItAeqvR3n8gkp0hyKbKdupzyMop\nJIGkyE6Aq8LwWhNHnP0CAwEAAaOCAmgwggJkMB8GA1UdIwQYMBaAFB4Fo3ePbJbi\nW4dLprSGrHEADOc4MB0GA1UdDgQWBBTSJqS8qnRCnVm/WzmLgoB7oBXQBTAOBgNV\nHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYI\nKwYBBQUHAwIwZwYDVR0gBGAwXjBSBgwrBgEEAa4jAQQDAQEwQjBABggrBgEFBQcC\nARY0aHR0cHM6Ly93d3cuaW5jb21tb24ub3JnL2NlcnQvcmVwb3NpdG9yeS9jcHNf\nc3NsLnBkZjAIBgZngQwBAgIwRAYDVR0fBD0wOzA5oDegNYYzaHR0cDovL2NybC5p\nbmNvbW1vbi1yc2Eub3JnL0luQ29tbW9uUlNBU2VydmVyQ0EuY3JsMHUGCCsGAQUF\nBwEBBGkwZzA+BggrBgEFBQcwAoYyaHR0cDovL2NydC51c2VydHJ1c3QuY29tL0lu\nQ29tbW9uUlNBU2VydmVyQ0FfMi5jcnQwJQYIKwYBBQUHMAGGGWh0dHA6Ly9vY3Nw\nLnVzZXJ0cnVzdC5jb20wgb4GA1UdEQSBtjCBs4IPaWRwLmNhbHBvbHkuZWR1ghdp\nZHAtaGEtMS0wMS5jYWxwb2x5LmVkdYIbaWRwLWhhLTEtMDEuaXRzLmNhbHBvbHku\nZWR1ghdpZHAtaGEtMi0wMi5jYWxwb2x5LmVkdYIbaWRwLWhhLTItMDIuaXRzLmNh\nbHBvbHkuZWR1ghdpZHAtaGEtMy0wMy5jYWxwb2x5LmVkdYIbaWRwLWhhLTMtMDMu\naXRzLmNhbHBvbHkuZWR1MA0GCSqGSIb3DQEBCwUAA4IBAQCQQjzy+wjJCRNTiXhc\naDJXwPgvRH9QOHKE3rcpOFAoWnr6QSMnISXb/uLuqW0OPMxpsrh0d7La0YNU5v3K\nexkmFKBg2kyJsssfvD7khldgCJHEtjdBIofN+jVB3RG5H48xowujuiYhRR4uo2IB\nHDwXJ8Nu/98HyZfv4Wahw7JzKN6D4NDIdiNNcWUBLura157+3HSKp0I+nhiKKZDs\nZmYEyv4r6X6Fk0bEMhAJwM7Qjau0KACibd8lNUyfKRpKwFjlIPwM3bRoMCWptH2K\nytVSwHP8Fc4H3kO1pfS7kmpmR1eaVapLHcNo+/7GQXET7X9xo5jAP/LslBgvWoZn\n/xkI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "calpoly.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.calpoly.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.calpoly.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.calpoly.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.calpoly.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.calpoly.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.calpoly.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "calpoly.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.calpoly.edu/"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://afd.calpoly.edu/security/policies/index.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "California Polytechnic State University-San Luis Obispo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGXzCCBUegAwIBAgIQJ+EtooE7aPQyEUAEQQAwyjANBgkqhkiG9w0BAQsFADB2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\n/xkI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California Polytechnic State University-San Luis Obispo"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.calpoly.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California Polytechnic State University-San Luis Obispo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp1.themanchestercollege.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McInnes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:AMcInnes@themanchestercollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Afzal"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:WAfzal@themanchestercollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Waseem"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp1.themanchestercollege.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-01-24T14:49:32Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDajCCAlKgAwIBAgIVANqzJLQBsPCEFgsQ4b4IALk9qGiiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCoxKDAmBgNVBAMTH2lkcDEudGhlbWFuY2hlc3RlcmNvbGxlZ2UuYWMudWsw\n\t\t\t\t\t\tHhcNMTMwMTIyMTUzNjE5WhcNMzMwMTIyMTUzNjE5WjAqMSgwJgYDVQQDEx9pZHAx\n\t\t\t\t\t\tLnRoZW1hbmNoZXN0ZXJjb2xsZWdlLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAzVU6xLjziCjRY0eLzVtrjsHcpLtQdh8UJGyje3+Gm+bibxDW\n\t\t\t\t\t\tz+NZm3VDSinORPUXIpZyXqPC8r7jHl5zpXCeCCONABfT2biKYraqXe6zj9UYEOfq\n\t\t\t\t\t\tH3avpzgUvVx/+t9sUfqZq6IP2a+rPbN3ifc7zydBWkaKyymPm922EABECik1onEp\n\t\t\t\t\t\t59gcFf+PkozaAE51Jid8Lp9YXjQq+OVp9NjfqSXUGYjSRnxH23zws98180CDCBj4\n\t\t\t\t\t\tnWlLaFDlpPcs9AcVo30WDm2qIC93BOCThmSh/az2+80fpxVPGf3wpcPuZ11XflST\n\t\t\t\t\t\tFcvbRhADY05pwLXOgztbYNOhtS3qZkIFEce32QIDAQABo4GGMIGDMGIGA1UdEQRb\n\t\t\t\t\t\tMFmCH2lkcDEudGhlbWFuY2hlc3RlcmNvbGxlZ2UuYWMudWuGNmh0dHBzOi8vaWRw\n\t\t\t\t\t\tMS50aGVtYW5jaGVzdGVyY29sbGVnZS5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNV\n\t\t\t\t\t\tHQ4EFgQUWXjSvL0zVIJ4O/L6c+kNL3oyemgwDQYJKoZIhvcNAQEFBQADggEBAJGR\n\t\t\t\t\t\twXOT7JS6jYsWFDbUgEOUKu8qHBafTZMb3lHKqEF+i9VOxSSyquc5Z3pzJjBjlpaY\n\t\t\t\t\t\t514MqXswU4oZvCrKJDqfj47ApBSbLvZm4A0cjx7xQqwRSYfmszi0B/W46Xrt32Sc\n\t\t\t\t\t\twxcVAoj3upfUigH4SfeixJvOOuk0XibWWz27Gu+B1YCRRfenE/mpGwwaRn5ccOKe\n\t\t\t\t\t\tuV+M/JapELbKFiAzi/qTuUHV08+i/2Teqv9+0el+zTyT7dXPhtBRZR3iN/yiunX4\n\t\t\t\t\t\thawEgZ1qMsy+ujLpe3fDd0HSaUCLhV3df0xhPwuuzgoBLvnTEGkmtolNVokJ/UbL\n\t\t\t\t\t\tJ9Sk+YSY/yW1ywDO6pU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "themanchestercollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.themanchestercollege.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.themanchestercollege.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp1.themanchestercollege.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp1.themanchestercollege.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp1.themanchestercollege.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp1.themanchestercollege.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.themanchestercollege.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.themanchestercollege.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "themanchestercollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDajCCAlKgAwIBAgIVANqzJLQBsPCEFgsQ4b4IALk9qGiiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCoxKDAmBgNVBAMTH2lkcDEudGhlbWFuY2hlc3RlcmNvbGxlZ2UuYWMudWsw\n\t\t\t\t\t\tHhcNMTMwMTIyMTUzNjE5WhcNMzMwMTIyMTUzNjE5WjAqMSgwJgYDVQQDEx9pZHAx\n\t\t\t\t\t\tLnRoZW1hbmNoZXN0ZXJjb2xsZWdlLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAzVU6xLjziCjRY0eLzVtrjsHcpLtQdh8UJGyje3+Gm+bibxDW\n\t\t\t\t\t\tz+NZm3VDSinORPUXIpZyXqPC8r7jHl5zpXCeCCONABfT2biKYraqXe6zj9UYEOfq\n\t\t\t\t\t\tH3avpzgUvVx/+t9sUfqZq6IP2a+rPbN3ifc7zydBWkaKyymPm922EABECik1onEp\n\t\t\t\t\t\t59gcFf+PkozaAE51Jid8Lp9YXjQq+OVp9NjfqSXUGYjSRnxH23zws98180CDCBj4\n\t\t\t\t\t\tnWlLaFDlpPcs9AcVo30WDm2qIC93BOCThmSh/az2+80fpxVPGf3wpcPuZ11XflST\n\t\t\t\t\t\tFcvbRhADY05pwLXOgztbYNOhtS3qZkIFEce32QIDAQABo4GGMIGDMGIGA1UdEQRb\n\t\t\t\t\t\tMFmCH2lkcDEudGhlbWFuY2hlc3RlcmNvbGxlZ2UuYWMudWuGNmh0dHBzOi8vaWRw\n\t\t\t\t\t\tMS50aGVtYW5jaGVzdGVyY29sbGVnZS5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNV\n\t\t\t\t\t\tHQ4EFgQUWXjSvL0zVIJ4O/L6c+kNL3oyemgwDQYJKoZIhvcNAQEFBQADggEBAJGR\n\t\t\t\t\t\twXOT7JS6jYsWFDbUgEOUKu8qHBafTZMb3lHKqEF+i9VOxSSyquc5Z3pzJjBjlpaY\n\t\t\t\t\t\t514MqXswU4oZvCrKJDqfj47ApBSbLvZm4A0cjx7xQqwRSYfmszi0B/W46Xrt32Sc\n\t\t\t\t\t\twxcVAoj3upfUigH4SfeixJvOOuk0XibWWz27Gu+B1YCRRfenE/mpGwwaRn5ccOKe\n\t\t\t\t\t\tuV+M/JapELbKFiAzi/qTuUHV08+i/2Teqv9+0el+zTyT7dXPhtBRZR3iN/yiunX4\n\t\t\t\t\t\thawEgZ1qMsy+ujLpe3fDd0HSaUCLhV3df0xhPwuuzgoBLvnTEGkmtolNVokJ/UbL\n\t\t\t\t\t\tJ9Sk+YSY/yW1ywDO6pU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Manchester College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://themanchestercollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Manchester College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://devapp.shibstats.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Andre"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Andre"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://devapp.shibstats.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-04-16T14:34:23Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Shibboleth statistics web service"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.overtsoftware.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Overt Software Solutions Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://devapp.shibstats.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://devapp.shibstats.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://devapp.shibstats.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://devapp.shibstats.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://devapp.shibstats.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://devapp.shibstats.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://devapp.shibstats.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is the development server of Overt Software's Shibboleth statistics tool. This tool provides useful statistics from your IdP."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Overt Software Solutions Ltd"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAPXDaBba8NJ3MA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\n\t\t\t\t\t\tBAMTFGRldmFwcC5zaGlic3RhdHMuY29tMB4XDTE0MDMwNzE1MDAzMFoXDTI0MDMw\n\t\t\t\t\t\tNDE1MDAzMFowHzEdMBsGA1UEAxMUZGV2YXBwLnNoaWJzdGF0cy5jb20wggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDkpnNYg2/0yWRlgPMw6GNlAkvKetoS\n\t\t\t\t\t\tHagRXUgAs8h2c9FcNxwhluHpqFurMIBbXwIJahPJ+R+tqHWqm4A1L+5u90tdOIDl\n\t\t\t\t\t\tVrZa+uBBowowtTwkXb3qWwI4ova7SOi/f9nyjg2iaUJHn1Cx1n0GRN+f8mP/jfMP\n\t\t\t\t\t\tqPwJ/FHJ+POgIyxaDq9+H4CGRNLaw5jI0anxAs71voB01HzTL4Jcv/p1u0Gy4oI4\n\t\t\t\t\t\tBLIU7XwqiiwAnATWcIZNv3GZCpsLgGBayR+sDHT6c+Tec06War2RqIuAWQrNfOun\n\t\t\t\t\t\tdfonmB/ZbpeCqxwW6JsaV7XsHQjJNDYlhQHUuua577VdCgZJ37o+IbUTAgMBAAGj\n\t\t\t\t\t\tQjBAMB8GA1UdEQQYMBaCFGRldmFwcC5zaGlic3RhdHMuY29tMB0GA1UdDgQWBBRR\n\t\t\t\t\t\tk1ZGqhczGoKPo2Bx2eN9bWPnVzANBgkqhkiG9w0BAQUFAAOCAQEACmFwrgaWwsRB\n\t\t\t\t\t\tLhXw4y5NNRhMGd4pumhaMUPvV2otLwM5/BWwbROzOfg1WgtEXOn2sStbefiQMgYE\n\t\t\t\t\t\tJ3iwfj8KD5QcKOeGV8jrBrM0aep8fEjZusAfqNqLF5SgywQBX2IBmtDt+uhM1bZQ\n\t\t\t\t\t\t9D2qhsmFUHR4TLL9IOCZUTCUNMDY8fpE/DlscHI4KiXE3XRJxJs9grY32RRxkeVK\n\t\t\t\t\t\tO+NIIOekToPVC6RKgiyN3uQbgs9qyjMJaFfskMZ1Iaz2dAlUulnwXW33a21wSOVs\n\t\t\t\t\t\tluuCsEMDj0DApXM0/FkXU+FLjqyWHhC4csGN/ybD9YEv7j+J+vcK6oFo3InOc/oY\n\t\t\t\t\t\twgPKhs5/IQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://devapp.shibstats.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://devapp.shibstats.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://devapp.shibstats.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://devapp.shibstats.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://devapp.shibstats.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://devapp.shibstats.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.barkingcollege.ac.uk/shibbolethidp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Overt Software Solutions Ltd Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Overt Software Solutions Ltd Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.barkingcollege.ac.uk/shibbolethidp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-03-31T10:43:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDejCCAmICCQCUfpmzVfedFDANBgkqhkiG9w0BAQUFADB/MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEOMAwGA1UECBMFRXNzZXgxEDAOBgNVBAcTB1JvbWZvcmQxIzAhBgNVBAoUGkJh\n\t\t\t\t\t\tcmtpbmcgJiBEYWdlbmhhbSBDb2xsZWdlMSkwJwYDVQQDEyBpZHAuYmFya2luZ2Rh\n\t\t\t\t\t\tZ2VuaGFtY29sbGVnZS5hYy51azAeFw0xNDA5MTAwOTE4MTBaFw0zNDA5MDUwOTE4\n\t\t\t\t\t\tMTBaMH8xCzAJBgNVBAYTAkdCMQ4wDAYDVQQIEwVFc3NleDEQMA4GA1UEBxMHUm9t\n\t\t\t\t\t\tZm9yZDEjMCEGA1UEChQaQmFya2luZyAmIERhZ2VuaGFtIENvbGxlZ2UxKTAnBgNV\n\t\t\t\t\t\tBAMTIGlkcC5iYXJraW5nZGFnZW5oYW1jb2xsZWdlLmFjLnVrMIIBIjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxosouASSI48U5Rj7J/CAeIpA7GAK+JXFuqtN\n\t\t\t\t\t\tApG5F1+uVRqoUPBZ07ToDpqBMYlNq0FRRf5kPb/M/I60OqMcQUuKMJKj9tiYYNS1\n\t\t\t\t\t\tFvTX9nMCKCxx+HUpUenQ6BUhDElu3TqiHbh1nsIqErDLShY+/rYOeOYqmiIOJthr\n\t\t\t\t\t\tcWeXJ+x90ZjIJcJe9RdC5LXQF67e8xEyZttS1fgl2k1IN1PQrUr/rfrbE5U0sta4\n\t\t\t\t\t\t9stGa8EtjiRMk/5yPH/gLZrQs3qyh0nOaP4K4m7oOC5iubiNIm4CiCEl9vLtY4G/\n\t\t\t\t\t\tGw0eNzn89+0C6TR0Iyw7jpYg7cOXf/uXTf8n7Gtxe2pk9xznswIDAQABMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQBuvV6Pq6axEKaDG3tESzL7mmB3rZAnNx6AZKJ2KlUysBRQ\n\t\t\t\t\t\tgmRiTWpoPF7alHkLb853H7w13+uw4698rQyh+iVmWBcH4bgcLDerV40aB8AI7Ii1\n\t\t\t\t\t\tIPIw+3XVWeWmREG402NBelkfp4FKL2Bj5moWISC+Jo7za2/5lA/Jj/eEqV+xtY5C\n\t\t\t\t\t\t6U2QcOAeaJNeJgrMYWhTPEbd9cdx7/kiku89UdXzmKD29fC8C1c0/G7rXhvzcCsu\n\t\t\t\t\t\tztgXowLLdqXkiomBszPW+IERhpRPMd14IJJye7kQ/CDJLCbhb7VJfsrTxgef1LV+\n\t\t\t\t\t\tNb4mckExHiZcajH+gD63kcn29VoGBsEefG88zI9R"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "barkingcollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.barkingdagenhamcollege.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.barkingdagenhamcollege.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.barkingdagenhamcollege.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.barkingdagenhamcollege.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.barkingdagenhamcollege.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.barkingdagenhamcollege.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.barkingdagenhamcollege.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.barkingdagenhamcollege.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "barkingcollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDejCCAmICCQCUfpmzVfedFDANBgkqhkiG9w0BAQUFADB/MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEOMAwGA1UECBMFRXNzZXgxEDAOBgNVBAcTB1JvbWZvcmQxIzAhBgNVBAoUGkJh\n\t\t\t\t\t\tcmtpbmcgJiBEYWdlbmhhbSBDb2xsZWdlMSkwJwYDVQQDEyBpZHAuYmFya2luZ2Rh\n\t\t\t\t\t\tZ2VuaGFtY29sbGVnZS5hYy51azAeFw0xNDA5MTAwOTE4MTBaFw0zNDA5MDUwOTE4\n\t\t\t\t\t\tMTBaMH8xCzAJBgNVBAYTAkdCMQ4wDAYDVQQIEwVFc3NleDEQMA4GA1UEBxMHUm9t\n\t\t\t\t\t\tZm9yZDEjMCEGA1UEChQaQmFya2luZyAmIERhZ2VuaGFtIENvbGxlZ2UxKTAnBgNV\n\t\t\t\t\t\tBAMTIGlkcC5iYXJraW5nZGFnZW5oYW1jb2xsZWdlLmFjLnVrMIIBIjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxosouASSI48U5Rj7J/CAeIpA7GAK+JXFuqtN\n\t\t\t\t\t\tApG5F1+uVRqoUPBZ07ToDpqBMYlNq0FRRf5kPb/M/I60OqMcQUuKMJKj9tiYYNS1\n\t\t\t\t\t\tFvTX9nMCKCxx+HUpUenQ6BUhDElu3TqiHbh1nsIqErDLShY+/rYOeOYqmiIOJthr\n\t\t\t\t\t\tcWeXJ+x90ZjIJcJe9RdC5LXQF67e8xEyZttS1fgl2k1IN1PQrUr/rfrbE5U0sta4\n\t\t\t\t\t\t9stGa8EtjiRMk/5yPH/gLZrQs3qyh0nOaP4K4m7oOC5iubiNIm4CiCEl9vLtY4G/\n\t\t\t\t\t\tGw0eNzn89+0C6TR0Iyw7jpYg7cOXf/uXTf8n7Gtxe2pk9xznswIDAQABMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQBuvV6Pq6axEKaDG3tESzL7mmB3rZAnNx6AZKJ2KlUysBRQ\n\t\t\t\t\t\tgmRiTWpoPF7alHkLb853H7w13+uw4698rQyh+iVmWBcH4bgcLDerV40aB8AI7Ii1\n\t\t\t\t\t\tIPIw+3XVWeWmREG402NBelkfp4FKL2Bj5moWISC+Jo7za2/5lA/Jj/eEqV+xtY5C\n\t\t\t\t\t\t6U2QcOAeaJNeJgrMYWhTPEbd9cdx7/kiku89UdXzmKD29fC8C1c0/G7rXhvzcCsu\n\t\t\t\t\t\tztgXowLLdqXkiomBszPW+IERhpRPMd14IJJye7kQ/CDJLCbhb7VJfsrTxgef1LV+\n\t\t\t\t\t\tNb4mckExHiZcajH+gD63kcn29VoGBsEefG88zI9R"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Barking & Dagenham College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.barkingdagenhamcollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Barking and Dagenham College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibb.utpb.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sso_support@utpb.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibb.utpb.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibb.utpb.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibb.utpb.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibb.utpb.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibb.utpb.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibb.utpb.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utpb.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Texas of the Permian Basin"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAP5tjp4Tow6cy5oFYmuYaqJvvh6kMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDnNoaWJiLnV0cGIuZWR1MB4XDTA5MDIxNzIxMzQyOFoX\nDTI5MDIxNzIxMzQyOFowGTEXMBUGA1UEAxMOc2hpYmIudXRwYi5lZHUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDDr94zxTZvCkwbFAnBH4B4qHfwecnU\nc1jMKpceqTB2XWwfn3C2ta1by+DgZzZUu5yBi+pTk/ulGUpaCsQoWQuXxJGJjDeq\nGNPLA6sd40HG4sV2xP4ApPRyZEv1bHqungSMXiBKigbuQaPkTrUhFmXLAXXpk3NE\nrri8F5Dpe0Gnyuajx2swX8b52qik9FvFVr0GnM3/47cXCLzheg+Dyj7CbRpZ6F3Z\nxGh5XyNSat8gKTDPTzkAIwGuDTwvU5HpTRmBdIwxquccVsiJaxaOVp6sllut8cXD\n4W3XcBhqJXrqRYzp8rwBzwWFQqdEeBmHlWoRUkEEG4yoiC/LeIknVNn3AgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDnNoaWJiLnV0cGIuZWR1hiVodHRwczovL3NoaWJiLnV0\ncGIuZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBT259l63IiF+k5UaXZZbX5G\niJZEKzANBgkqhkiG9w0BAQUFAAOCAQEAZ70LIDprVaQl5rbmd31QMdRamxsCi8XR\nufcuqXlFIu/TeRWsQfUcPc9ta02jU0Ruut0IMRiQDEyNqKJXTXnl+w7BACWZxw8O\n/AZb9p1/hv/ql5C1/axK/1jCAZZMTZK4rYtjCgv30QCGUAGo2OZntXAhyrji6Ql8\nqwf6ulhp0qtGtOXqrgA9eqll/g5fliDRS5Jn0LltriwYFq4FjSYIR5rnfOwQls6Y\nJCyQO8jWSKK5bulKzsYQL60j7C3WKzUdgG929H61rjkDREFZXMiPOkqsQvH17X5J\nYMaaG/t0+kQC2uFq/Kq9ruMjzOhSVywAO9St96lTyQhVB9JEmThZlw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "http://www.utpb.edu/services/ird"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Texas of the Permian Basin"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utpb.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Texas of the Permian Basin"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth2sp.pm.semcs.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pm-shibboleth-support@semantico.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pm-shibboleth-support@semantico.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth2sp.pm.semcs.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Semantico Limited: Palgrave Macmillan Shibboleth 2 SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.semantico.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Semantico Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.pm.semcs.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.pm.semcs.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.pm.semcs.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.pm.semcs.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.pm.semcs.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDzjCCAragAwIBAgIJALftanjyX859MA0GCSqGSIb3DQEBBQUAMGoxCzAJBgNV\n\t\t\t\t\t\tBAYTAlVLMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIwEAYD\n\t\t\t\t\t\tVQQKEwlzZW1hbnRpY28xIzAhBgNVBAMTGnNoaWJib2xldGgyc3AucG0uc2VtY3Mu\n\t\t\t\t\t\tbmV0MB4XDTE1MDMxMDExNTkzN1oXDTM1MDMwNTExNTkzN1owajELMAkGA1UEBhMC\n\t\t\t\t\t\tVUsxDzANBgNVBAgTBlN1c3NleDERMA8GA1UEBxMIQnJpZ2h0b24xEjAQBgNVBAoT\n\t\t\t\t\t\tCXNlbWFudGljbzEjMCEGA1UEAxMac2hpYmJvbGV0aDJzcC5wbS5zZW1jcy5uZXQw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCk4Om/LJxKkUz/YG9c3lg2\n\t\t\t\t\t\t+jJP0JWGWcDPHdislxOBgQG5NPD/MpzUnyarTFwt7JUzNuwKCnEPaGvrm8RB3K19\n\t\t\t\t\t\ta6oJNbZr0BG/gHIzO3AyXb0UU60aBVrUz0S5LTNL8mLnZQkMNish0sn1LSX6jfvp\n\t\t\t\t\t\tT77EpYpI07GzXX6X5BfMnm3N5G3dpkgDO5RbkIiAZ90GyklxkBPTcbCmaczuGaGi\n\t\t\t\t\t\tQi5PL94EWG+pILFmEkG0qT7aX5QVVcq9ZmzN+PVeDcyIyX9i5qHyyztHhVaXnB7X\n\t\t\t\t\t\tQAdlrgQFPU0DdMTqWVJ50y1UNHAA0b+gANLa+W1jPAgjaVGmKQM29xVcVnj+LPcf\n\t\t\t\t\t\tAgMBAAGjdzB1MFQGA1UdEQRNMEuCGnNoaWJib2xldGgyc3AucG0uc2VtY3MubmV0\n\t\t\t\t\t\thi1odHRwczovL3NoaWJib2xldGgyc3AucG0uc2VtY3MubmV0L3NoaWJib2xldGgw\n\t\t\t\t\t\tHQYDVR0OBBYEFC9PeQ/B3VqMqTLhxaHLrmu0q/uPMA0GCSqGSIb3DQEBBQUAA4IB\n\t\t\t\t\t\tAQBlLbfCLpFhuhVPIMBOhJivtU6/IPFEJSsBnO+lsYSrl+8zSWzknW04GHvgVAQu\n\t\t\t\t\t\t98i9g+Ds7+NrMTGBQqAHJe9uGciHbJOSGlYwPfTUlCNdsLbfZfbE40jWm+5MfDKh\n\t\t\t\t\t\tAzPChYrEZKzGn3FH3ojPLoay8wRDFzf11ulFO426RBxlIlh2ZteuNTSQG6ChGr7k\n\t\t\t\t\t\tz0eD1NrDQRkUBxxWVmSAB9dju+R6gXzyIeVbOlUZiy3u1NwlYbX4EhMeccZfnXD2\n\t\t\t\t\t\twpqstIhDfYaH16h7HTMThBsVP6AlR+ANOzavUQsZTw73l/KeFAJtIFICkqK1jFlq\n\t\t\t\t\t\tCySVk3++EEgHcu1AN8Mb779L"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.pm.semcs.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.pm.semcs.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.pm.semcs.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.pm.semcs.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.pm.semcs.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth2sp.pm.semcs.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.pm.semcs.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth2sp.pm.semcs.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth2sp.pm.semcs.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth2sp.pm.semcs.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.farn-ct.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Knight"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:p.knight@farn-ct.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pat"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hancock"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:e.hancock@farn-ct.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ted"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.farn-ct.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-04-12T11:59:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID+DCCAuACCQDiBNfRRk2CeTANBgkqhkiG9w0BAQUFADCBvTELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEjAQBgNVBAgMCUhhbXBzaGlyZTEUMBIGA1UEBwwLRmFybmJvcm91Z2gxKjAo\n\t\t\t\t\t\tBgNVBAoMIUZhcm5ib3JvdWdoIENvbGxlZ2Ugb2YgVGVjaG5vbG9neTEUMBIGA1UE\n\t\t\t\t\t\tCwwLSVQgU2VydmljZXMxGjAYBgNVBAMMEWlkcC5mYXJuLWN0LmFjLnVrMSYwJAYJ\n\t\t\t\t\t\tKoZIhvcNAQkBFhd3LmhhbHNhbGxAZmFybi1jdC5hYy51azAeFw0xNDAzMDMxMjE4\n\t\t\t\t\t\tMzhaFw0yNDAyMjkxMjE4MzhaMIG9MQswCQYDVQQGEwJHQjESMBAGA1UECAwJSGFt\n\t\t\t\t\t\tcHNoaXJlMRQwEgYDVQQHDAtGYXJuYm9yb3VnaDEqMCgGA1UECgwhRmFybmJvcm91\n\t\t\t\t\t\tZ2ggQ29sbGVnZSBvZiBUZWNobm9sb2d5MRQwEgYDVQQLDAtJVCBTZXJ2aWNlczEa\n\t\t\t\t\t\tMBgGA1UEAwwRaWRwLmZhcm4tY3QuYWMudWsxJjAkBgkqhkiG9w0BCQEWF3cuaGFs\n\t\t\t\t\t\tc2FsbEBmYXJuLWN0LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\n\t\t\t\t\t\tAQEAw3S9I4W4QmKzx4xKCW/RRmBwyNJaUSe7idAWZvh/4g3pG4ZqfvjTiwHPH2QF\n\t\t\t\t\t\thHwl6+BH52jfpCMliKwYh+JyN0dStTdyvz96/G7fyBb4ZZouVuh1BOX0F8Uz8xKA\n\t\t\t\t\t\tFqJ4iS4ld9YgBhT9F57W0uGLmS4Jy0W6BWv2lPmv1OMZaL3c2CQizLs2wV0GcVxx\n\t\t\t\t\t\tKJgdVCoopE0nqi6PIBehlU2cSuluiclfojFmRLaEv8T/6C/b+MogfqR+s93RwMrn\n\t\t\t\t\t\t7v3+G6xURcDaT+OMXP7sIT/0St28+MPR+rEwbZPNjkhTnoUnPhAWl6ZZTHM46nbN\n\t\t\t\t\t\thNr4vlJL+ZGqocmQI3seEyXboQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCW+V0X\n\t\t\t\t\t\tiZ1t1PpdU0b7hgZAG0qh6R7UmUY5Baxtp4FIN1WebvnSr0keskwff59iIHeZ4/Km\n\t\t\t\t\t\tu4Q7fkvghlteTti7r2LTS47CASwKi1UrtvmNMerSmdYeDYeymt94LXiTzK9dlXRW\n\t\t\t\t\t\tZYM5LPHeEIoHOFeRvwnXACKvJs0y4MwshxDGn4WIfLKj+z9y/FRsohRlxQihFx5y\n\t\t\t\t\t\tqwjP8f2vXwGgZnM1WvcyH+Q/uhypmjdKmI1OkevgTclBZC8m6OJz0bwKqVnRD9AZ\n\t\t\t\t\t\tBqgu4cXU7lk5y1nreWIF8soBdlqgGwIngb+obZjG/cWsP4wGoVyFPgdHbpqTZVaf\n\t\t\t\t\t\tTgP5ojXtIFXiNKGS"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "farn-ct.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.farn-ct.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.farn-ct.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.farn-ct.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.farn-ct.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.farn-ct.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.farn-ct.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.farn-ct.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.farn-ct.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "farn-ct.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID+DCCAuACCQDiBNfRRk2CeTANBgkqhkiG9w0BAQUFADCBvTELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEjAQBgNVBAgMCUhhbXBzaGlyZTEUMBIGA1UEBwwLRmFybmJvcm91Z2gxKjAo\n\t\t\t\t\t\tBgNVBAoMIUZhcm5ib3JvdWdoIENvbGxlZ2Ugb2YgVGVjaG5vbG9neTEUMBIGA1UE\n\t\t\t\t\t\tCwwLSVQgU2VydmljZXMxGjAYBgNVBAMMEWlkcC5mYXJuLWN0LmFjLnVrMSYwJAYJ\n\t\t\t\t\t\tKoZIhvcNAQkBFhd3LmhhbHNhbGxAZmFybi1jdC5hYy51azAeFw0xNDAzMDMxMjE4\n\t\t\t\t\t\tMzhaFw0yNDAyMjkxMjE4MzhaMIG9MQswCQYDVQQGEwJHQjESMBAGA1UECAwJSGFt\n\t\t\t\t\t\tcHNoaXJlMRQwEgYDVQQHDAtGYXJuYm9yb3VnaDEqMCgGA1UECgwhRmFybmJvcm91\n\t\t\t\t\t\tZ2ggQ29sbGVnZSBvZiBUZWNobm9sb2d5MRQwEgYDVQQLDAtJVCBTZXJ2aWNlczEa\n\t\t\t\t\t\tMBgGA1UEAwwRaWRwLmZhcm4tY3QuYWMudWsxJjAkBgkqhkiG9w0BCQEWF3cuaGFs\n\t\t\t\t\t\tc2FsbEBmYXJuLWN0LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\n\t\t\t\t\t\tAQEAw3S9I4W4QmKzx4xKCW/RRmBwyNJaUSe7idAWZvh/4g3pG4ZqfvjTiwHPH2QF\n\t\t\t\t\t\thHwl6+BH52jfpCMliKwYh+JyN0dStTdyvz96/G7fyBb4ZZouVuh1BOX0F8Uz8xKA\n\t\t\t\t\t\tFqJ4iS4ld9YgBhT9F57W0uGLmS4Jy0W6BWv2lPmv1OMZaL3c2CQizLs2wV0GcVxx\n\t\t\t\t\t\tKJgdVCoopE0nqi6PIBehlU2cSuluiclfojFmRLaEv8T/6C/b+MogfqR+s93RwMrn\n\t\t\t\t\t\t7v3+G6xURcDaT+OMXP7sIT/0St28+MPR+rEwbZPNjkhTnoUnPhAWl6ZZTHM46nbN\n\t\t\t\t\t\thNr4vlJL+ZGqocmQI3seEyXboQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCW+V0X\n\t\t\t\t\t\tiZ1t1PpdU0b7hgZAG0qh6R7UmUY5Baxtp4FIN1WebvnSr0keskwff59iIHeZ4/Km\n\t\t\t\t\t\tu4Q7fkvghlteTti7r2LTS47CASwKi1UrtvmNMerSmdYeDYeymt94LXiTzK9dlXRW\n\t\t\t\t\t\tZYM5LPHeEIoHOFeRvwnXACKvJs0y4MwshxDGn4WIfLKj+z9y/FRsohRlxQihFx5y\n\t\t\t\t\t\tqwjP8f2vXwGgZnM1WvcyH+Q/uhypmjdKmI1OkevgTclBZC8m6OJz0bwKqVnRD9AZ\n\t\t\t\t\t\tBqgu4cXU7lk5y1nreWIF8soBdlqgGwIngb+obZjG/cWsP4wGoVyFPgdHbpqTZVaf\n\t\t\t\t\t\tTgP5ojXtIFXiNKGS"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Farnborough College of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.farn-ct.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Farnborough College of Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://edu.xtremeinformation.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ad.clientservice@ebiquity.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ADS Client Services"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ryan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rob.ryan@ebiquity.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rob"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://edu.xtremeinformation.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-11-19T12:34:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ebiquity plc: Portfolio ADS"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.xtremeinformation.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ebiquity plc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://edu.xtremeinformation.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://edu.xtremeinformation.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://edu.xtremeinformation.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://edu.xtremeinformation.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://edu.xtremeinformation.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAKUdMtp0wHmJMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\n\t\t\t\t\t\tBAMTFHdlYi0wMDEueHRyZW1lLmNvLnVrMB4XDTA5MTExODEyMTQxMFoXDTE5MTEx\n\t\t\t\t\t\tNjEyMTQxMFowHzEdMBsGA1UEAxMUd2ViLTAwMS54dHJlbWUuY28udWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDP2ZbA5SAqPMAhAeX994ZNooqO5VUG\n\t\t\t\t\t\tEtTHvZfmKSVpFLNI+LuT4dloL1eKLrFhMtVCRsR94oX15ZnMGJ8go3GXbGUqhT5I\n\t\t\t\t\t\tsoGDNIMHnvA0zeQr/VmHwrRImddyiiB9MR1C1dghV83zw1/04kcZMKd3fdXlsXaR\n\t\t\t\t\t\tlWCTuYDKstG4wivDN/rTJIlgFtLJnplVpAYnTIgxxY/cU+3j140OUX3yFQu04/BM\n\t\t\t\t\t\tuEtlz5ypWek2bHNZWH1aDYmWcpB32ao/oWEsyCoraZR5knluYNwt2uJgChfTh8zC\n\t\t\t\t\t\tyFo713ketgUndktx5sWhJnNjQeWYweMSuu1w0HzE2uKgDld1c8m1o0qLAgMBAAGj\n\t\t\t\t\t\tQjBAMB8GA1UdEQQYMBaCFHdlYi0wMDEueHRyZW1lLmNvLnVrMB0GA1UdDgQWBBR0\n\t\t\t\t\t\t5U9o3XTImfdd6YXxvMwlBN2vujANBgkqhkiG9w0BAQUFAAOCAQEAErdNoI5vHTQ4\n\t\t\t\t\t\tapBJD/KDf4+MeJRVFtsgkX0OgRAGApMILddenUgqj55eCKFu25BB2+JNpD72pLcD\n\t\t\t\t\t\tKvcRgJX9FeqyaHpUJ3u9Hq6FwyY2t0xFHEUk7VXaJm1Y7VhVuPEovGz97bj4ffYZ\n\t\t\t\t\t\triMV/JRg/7SDxjL4z4BjknQdLTYxr0vfAfkv7K679mdTRCIcho9x7b8n0V95UwhK\n\t\t\t\t\t\tGb8PQktjjg5GUaFHk7bZjPdBffYgABNwrdEoLrWBDRtUYVfRv52m7HEOa/wIuzdm\n\t\t\t\t\t\t/K9EI6W5q9FIrAy11+Z44GB/xe6WI/18xax/sGbafbwj+g0Aov5EwVcgbjmjCrjT\n\t\t\t\t\t\tpjmPlQZwNg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAKUdMtp0wHmJMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\n\t\t\t\t\t\tBAMTFHdlYi0wMDEueHRyZW1lLmNvLnVrMB4XDTA5MTExODEyMTQxMFoXDTE5MTEx\n\t\t\t\t\t\tNjEyMTQxMFowHzEdMBsGA1UEAxMUd2ViLTAwMS54dHJlbWUuY28udWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDP2ZbA5SAqPMAhAeX994ZNooqO5VUG\n\t\t\t\t\t\tEtTHvZfmKSVpFLNI+LuT4dloL1eKLrFhMtVCRsR94oX15ZnMGJ8go3GXbGUqhT5I\n\t\t\t\t\t\tsoGDNIMHnvA0zeQr/VmHwrRImddyiiB9MR1C1dghV83zw1/04kcZMKd3fdXlsXaR\n\t\t\t\t\t\tlWCTuYDKstG4wivDN/rTJIlgFtLJnplVpAYnTIgxxY/cU+3j140OUX3yFQu04/BM\n\t\t\t\t\t\tuEtlz5ypWek2bHNZWH1aDYmWcpB32ao/oWEsyCoraZR5knluYNwt2uJgChfTh8zC\n\t\t\t\t\t\tyFo713ketgUndktx5sWhJnNjQeWYweMSuu1w0HzE2uKgDld1c8m1o0qLAgMBAAGj\n\t\t\t\t\t\tQjBAMB8GA1UdEQQYMBaCFHdlYi0wMDEueHRyZW1lLmNvLnVrMB0GA1UdDgQWBBR0\n\t\t\t\t\t\t5U9o3XTImfdd6YXxvMwlBN2vujANBgkqhkiG9w0BAQUFAAOCAQEAErdNoI5vHTQ4\n\t\t\t\t\t\tapBJD/KDf4+MeJRVFtsgkX0OgRAGApMILddenUgqj55eCKFu25BB2+JNpD72pLcD\n\t\t\t\t\t\tKvcRgJX9FeqyaHpUJ3u9Hq6FwyY2t0xFHEUk7VXaJm1Y7VhVuPEovGz97bj4ffYZ\n\t\t\t\t\t\triMV/JRg/7SDxjL4z4BjknQdLTYxr0vfAfkv7K679mdTRCIcho9x7b8n0V95UwhK\n\t\t\t\t\t\tGb8PQktjjg5GUaFHk7bZjPdBffYgABNwrdEoLrWBDRtUYVfRv52m7HEOa/wIuzdm\n\t\t\t\t\t\t/K9EI6W5q9FIrAy11+Z44GB/xe6WI/18xax/sGbafbwj+g0Aov5EwVcgbjmjCrjT\n\t\t\t\t\t\tpjmPlQZwNg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://edu.xtremeinformation.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://edu.xtremeinformation.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://edu.xtremeinformation.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://edu.xtremeinformation.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://edu.xtremeinformation.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://edu.xtremeinformation.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://edu.xtremeinformation.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://edu.xtremeinformation.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://edu.xtremeinformation.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://edu.xtremeinformation.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.uws.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McIntosh"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sally.mcintosh@uws.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sally"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sword"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:julie.sword@uws.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Julie"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uws.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-02-28T12:55:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.uws.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uws.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uws.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://logos.uws.ac.uk/UWS-logo-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://logos.uws.ac.uk/UWS-logo-80x60.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of the West of Scotland (UWS)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDaDCCAlCgAwIBAgIIYbFoeRooWYAwDQYJKoZIhvcNAQEFBQAwSzExMC8GA1UE\n\t\t\t\t\t\tCgwoVW5pdmVyc2l0eSBvZiB0aGUgV2VzdCBvZiBTY290bGFuZCAoVVdTKTEWMBQG\n\t\t\t\t\t\tA1UEAwwNaWRwLnV3cy5hYy51azAeFw0xMzAyMTUxNDEyNTlaFw0yMzAyMTUxNDEy\n\t\t\t\t\t\tNTlaMEsxMTAvBgNVBAoMKFVuaXZlcnNpdHkgb2YgdGhlIFdlc3Qgb2YgU2NvdGxh\n\t\t\t\t\t\tbmQgKFVXUykxFjAUBgNVBAMMDWlkcC51d3MuYWMudWswggEiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tAQUAA4IBDwAwggEKAoIBAQCwkKLmB8Bmhsi8GGv6r72hYbHGkMbgQ/J3AwxM7B6B\n\t\t\t\t\t\tlc4QcGTRY8ziyZ1zcP9tmcSnVb5yWrYdPt49TEaH0qWJ7Uw6UDy5xSMVIAmSowYK\n\t\t\t\t\t\tuXkuIJVX+zIOAeQ6VfTF/jAfU7W3fTHGL8fyeFXScQXnDWltAmBDO59cnFwb6eur\n\t\t\t\t\t\tGRPeoixry+rtPyJTSXPEespZr/DTA35a3ydb0FNOR6aAgIQsYxiLLRGDFhy8lF+Y\n\t\t\t\t\t\t7PwC4y9uVf8gA2f3CTAFpxr78M68WDQNkN2XOgZyrdVf1/3iWhCtsfg2W16nyfAy\n\t\t\t\t\t\t1RWCPsgb9IOgsazZMK4SctNZFcBg0kgnj79cvQuKMRXdAgMBAAGjUDBOMB0GA1Ud\n\t\t\t\t\t\tDgQWBBTxj3GMfJYQ+SHcCJ/NPmkVh7WNvzAfBgNVHSMEGDAWgBTxj3GMfJYQ+SHc\n\t\t\t\t\t\tCJ/NPmkVh7WNvzAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBB1boI\n\t\t\t\t\t\tlcTo5EIRUKvFbYlmiXSEGJmh26lsUT3kUzJZm3EKH9kr4+jUciG2SJGnF2Z278f+\n\t\t\t\t\t\tCfl495RuGRxuBZcnMOsF7DxiPUPexD5tgUc1R/mY0qIADopPt5xHAro8DtLsk0Ha\n\t\t\t\t\t\tThBZmY5mpajnMiP8uPhjMLImy4nmq9PizV6YRo6z989ZrimkXWcTaMlM0zws0Qvm\n\t\t\t\t\t\taiDs9JdN9vWNYv0E003ekVuKYCuyItCQgNbxY6kY5H6gDybnUUY8lhS4tFwnYRph\n\t\t\t\t\t\tNeRvuatSXDhWfBk/lBSAF4VNSL4LfKsFPQP34DxZdtLT7EI95sGSzKno/2S18uXS\n\t\t\t\t\t\t6swfWRDPUe/Evz3k"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDaDCCAlCgAwIBAgIIYbFoeRooWYAwDQYJKoZIhvcNAQEFBQAwSzExMC8GA1UE\n\t\t\t\t\t\tCgwoVW5pdmVyc2l0eSBvZiB0aGUgV2VzdCBvZiBTY290bGFuZCAoVVdTKTEWMBQG\n\t\t\t\t\t\tA1UEAwwNaWRwLnV3cy5hYy51azAeFw0xMzAyMTUxNDEyNTlaFw0yMzAyMTUxNDEy\n\t\t\t\t\t\tNTlaMEsxMTAvBgNVBAoMKFVuaXZlcnNpdHkgb2YgdGhlIFdlc3Qgb2YgU2NvdGxh\n\t\t\t\t\t\tbmQgKFVXUykxFjAUBgNVBAMMDWlkcC51d3MuYWMudWswggEiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tAQUAA4IBDwAwggEKAoIBAQCwkKLmB8Bmhsi8GGv6r72hYbHGkMbgQ/J3AwxM7B6B\n\t\t\t\t\t\tlc4QcGTRY8ziyZ1zcP9tmcSnVb5yWrYdPt49TEaH0qWJ7Uw6UDy5xSMVIAmSowYK\n\t\t\t\t\t\tuXkuIJVX+zIOAeQ6VfTF/jAfU7W3fTHGL8fyeFXScQXnDWltAmBDO59cnFwb6eur\n\t\t\t\t\t\tGRPeoixry+rtPyJTSXPEespZr/DTA35a3ydb0FNOR6aAgIQsYxiLLRGDFhy8lF+Y\n\t\t\t\t\t\t7PwC4y9uVf8gA2f3CTAFpxr78M68WDQNkN2XOgZyrdVf1/3iWhCtsfg2W16nyfAy\n\t\t\t\t\t\t1RWCPsgb9IOgsazZMK4SctNZFcBg0kgnj79cvQuKMRXdAgMBAAGjUDBOMB0GA1Ud\n\t\t\t\t\t\tDgQWBBTxj3GMfJYQ+SHcCJ/NPmkVh7WNvzAfBgNVHSMEGDAWgBTxj3GMfJYQ+SHc\n\t\t\t\t\t\tCJ/NPmkVh7WNvzAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBB1boI\n\t\t\t\t\t\tlcTo5EIRUKvFbYlmiXSEGJmh26lsUT3kUzJZm3EKH9kr4+jUciG2SJGnF2Z278f+\n\t\t\t\t\t\tCfl495RuGRxuBZcnMOsF7DxiPUPexD5tgUc1R/mY0qIADopPt5xHAro8DtLsk0Ha\n\t\t\t\t\t\tThBZmY5mpajnMiP8uPhjMLImy4nmq9PizV6YRo6z989ZrimkXWcTaMlM0zws0Qvm\n\t\t\t\t\t\taiDs9JdN9vWNYv0E003ekVuKYCuyItCQgNbxY6kY5H6gDybnUUY8lhS4tFwnYRph\n\t\t\t\t\t\tNeRvuatSXDhWfBk/lBSAF4VNSL4LfKsFPQP34DxZdtLT7EI95sGSzKno/2S18uXS\n\t\t\t\t\t\t6swfWRDPUe/Evz3k"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of the West of Scotland (UWS)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uws.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of the West of Scotland"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.mijnhelicon.nl/nidp/saml2/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.mijnhelicon.nl/nidp/saml2/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-06-05T17:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/c02b64fa6474d47f5e17609eefe9792d",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Helicon Opleidingen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Helicon Opleidingen"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/helicon.png",
                    "height": "41",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Helicon"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.helicon.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Helicon Opleidingen"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://identites.enim.fr/idp/",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "admininfo@enim.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://identites.enim.fr/idp/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-12-10T10:41:49Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://authshib.enim.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://authshib.enim.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://authshib.enim.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "enim.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.enim.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENIM"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENIM"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUXFUXeBlCuUekINLHfPFZiIPUrsAwDQYJKoZIhvcNAQEF\nBQAwFjEUMBIGA1UEAxMLaWRwLmVuaW0uZnIwHhcNMTIxMTE0MTMzODMyWhcNMzIx\nMTE0MTMzODMyWjAWMRQwEgYDVQQDEwtpZHAuZW5pbS5mcjCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAPzw0RQQQxTO08j91FfloACjUJPfi7MnbcVZ5wpX\nv7DSZ1FOxQ+4qK6lBnNjqj2d6Y7q/6hfpU/jywg0WMzzUq+mJ+cLBKwBECJcYHt3\nV+EKb5+iLQ7jFIKn2IKOla/xTnNdhAcPhNfYRZ0b9MW5ZvSqB+Ype9cOiAgaE13i\nQszdnZQCt7iZPaWuRILIqOL9r+bzIjBT3ueQK6Pdofe4+D9bCD+Rw7K9ucj//Xwm\noJtfFUM79Lwtd4mVs+qleXUEwYSCttBnNWh4mIj9+s46JlN9XE2OLdtLE8E4wRla\nwF6s0mbvZIWJ0UMFdlOSANu6qCEusFa+N+a3k1aLbjD3y60CAwEAAaNdMFswOgYD\nVR0RBDMwMYILaWRwLmVuaW0uZnKGImh0dHBzOi8vaWRwLmVuaW0uZnIvaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFOexEULHTKANUZhFIldEyXBwm7EiMA0GCSqGSIb3\nDQEBBQUAA4IBAQCx5cOFFV30wtnqGHbRTkwDqRTkNV5DJlYaFIW9YAVuzokQuAym\nlUUBC1QjNusjF2+iI+iKwp8D18sW9ZONF+Kw4D+uPtIfT4SDms1NQWrw4+Huvy30\nlCGjPWut+kDsKco2xhQdG2DoU9NrnoAFrs5uC3SjWYIhWAKAp57VuXt8RhN4BeBt\nIJgOBe5S+60ftF+69kjdQquJLlbpk9nhZTrhJnjcxppDJhXskc2pE1zplKAl98q6\n1yBtIBFoXawK3loQMMGbW+qWhm4+WWATRl3a25GnYmq4+EgUMocSshp/dwVFB6hl\nP69qvJb0PazcY4DgIwXlIliGgHdjRIiFAYNA"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ENIM"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.enim.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ENIM"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.lhup.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp@lhup.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lock Haven University IT Department"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp@lhup.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lock Haven University IT Department"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp@lhup.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lock Haven University IT Department"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.lhup.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.lhup.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.lhup.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.lhup.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.lhup.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.lhup.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lhup.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.lhup.edu/computing_and_tech"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.lhup.edu/images/web-logo-head-11.jpg",
                    "lang": "en",
                    "height": "42",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "447"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.lhup.edu/computing_and_tech/aup.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lock Haven University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEuTCCA6GgAwIBAgIQZcvMkgZaqKLekHBsU354XjANBgkqhkiG9w0BAQUFADA8\nMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMVGhhd3RlLCBJbmMuMRYwFAYDVQQDEw1U\naGF3dGUgU1NMIENBMB4XDTEyMDcyNDAwMDAwMFoXDTE1MDcyNDIzNTk1OVowgY0x\nCzAJBgNVBAYTAlVTMRUwEwYDVQQIEwxQZW5uc3lsdmFuaWExEzARBgNVBAcUCkxv\nY2sgSGF2ZW4xLjAsBgNVBAoUJUxvY2sgSGF2ZW4gVW5pdmVyc2l0eSBPZiBQZW5u\nc3lsdmFuaWExCzAJBgNVBAsUAklUMRUwEwYDVQQDFAxpZHAubGh1cC5lZHUwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDdFclUfLWsojRGkQA9JO6S8QOl\nFAYb3FaZ9Sn4d5uM7qgSC7EHcZ4UCTPZ3d/ni2Sp5HkFHzAO2Il3lRQN5rgtepk3\nOWW2KcfipbXczbwzBO2U/fz4EQfu+1fz9nhMD3j85nDDhbhEWynYcrfmS2xnRb3p\nllgI5MH0FLSN+5umufSf7yF2lwgl4Lr7vMoKn5hEP+imHDlh9Nq+SHATDIJO6f7x\nJuJL+hAj84xWRJqGfs28TiJMM5R18rsHoE9bjqOwHjeR7SFsZaS77mn+JX5DESzU\nAE+XkGxQq+LQ4dMFXpA3sVotytUxgKUNrp2VFVOTzSixo3JpDk+Jai5W32CvAgMB\nAAGjggFjMIIBXzAXBgNVHREEEDAOggxpZHAubGh1cC5lZHUwCQYDVR0TBAIwADBC\nBgNVHSAEOzA5MDcGCmCGSAGG+EUBBzYwKTAnBggrBgEFBQcCARYbaHR0cHM6Ly93\nd3cudGhhd3RlLmNvbS9jcHMvMA4GA1UdDwEB/wQEAwIFoDAfBgNVHSMEGDAWgBSn\nooO7NEVAPfzVME8SuT6hAZ/22zA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vc3Zy\nLW92LWNybC50aGF3dGUuY29tL1RoYXd0ZU9WLmNybDAdBgNVHSUEFjAUBggrBgEF\nBQcDAQYIKwYBBQUHAwIwaQYIKwYBBQUHAQEEXTBbMCIGCCsGAQUFBzABhhZodHRw\nOi8vb2NzcC50aGF3dGUuY29tMDUGCCsGAQUFBzAChilodHRwOi8vc3ZyLW92LWFp\nYS50aGF3dGUuY29tL1RoYXd0ZU9WLmNlcjANBgkqhkiG9w0BAQUFAAOCAQEAdy3s\nU5fAwa249ELF6aywqLvnk0GXaAaikI00D0Hos6tmMuUxTj40eQwICApm5Y6fBQFC\nmBQjFYpHWxvmxTnnED0/GKgfXNA2eUyY0RVHxtydFFJB0tmbMS0w0dhPaSjMjUVE\nkSBlxl5DMgM8CIEohWoZiMahTKVhRsTbpQgOsJCGEHv3qtrvbSfuJwYBP5F4DPPY\nblFlMDAkDVVUynA6Lp+wyrf/C2+2N0jg8EVGl8PuOnBeL860Lg9j+zEwJZiQrllW\nTKvZOVB6ym5AhHfgCOR4ZcQYIh+TVAYjxgtVqTADfuOZ6WiO5D2Hilad+xW3UQyx\nL6VIWeNvK0QGSePPsg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idp.lhup.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lock Haven University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lhup.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Lock Haven University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://box-idp.nordu.net/simplesaml/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NOC"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:noc@nordu.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NORDUNet"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://box-idp.nordu.net/simplesaml/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://box-idp.nordu.net/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://box-idp.nordu.net/simplesaml/module.php/saml/sp/discoresp.php",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "NORDUnet Box Service Access"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "NORDUnet Box Service Access"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NORDUnet Box Service Access"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NORDUnet Box Service Access"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://box-idp.nordu.net/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://box-idp.nordu.net/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://box-idp.nordu.net/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://box-idp.nordu.net/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "NORDUnet Box Service Access"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "NORDUnet Box Service Access (box.com)"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrimaryAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.5",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.harrow.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biggs"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dbiggs@harrow.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biggs"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dbiggs@harrow.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.harrow.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAIAV6r9T9UOFBwHmuFZHQ/Zrx7aPMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBsxGTAXBgNVBAMTEGlkcC5oYXJyb3cuYWMudWswHhcNMTIwMjA4MDk0MjIw\n\t\t\t\t\t\tWhcNMzIwMjA4MDk0MjIwWjAbMRkwFwYDVQQDExBpZHAuaGFycm93LmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAlmctLybnvCCmJ/okx0YFhn03\n\t\t\t\t\t\tb/2PuyksfVZ0LI986BrnNSvYYlm69Z0Y+wO8FLzN7fW2ztz5Xyag3eakCiyKAfP0\n\t\t\t\t\t\t23OLkdjG42bVlpjhYzW9OyamNtd9MbvkF5vNU8QA5eyRm+jhuqgmRiwhdfbwDvdw\n\t\t\t\t\t\teW6SmDHChmGr6YGfHMfvBjQNAO/x+VPdqcz7TREb4AtGLch8+pRMSslTaMZibdYe\n\t\t\t\t\t\tzKmOMKqywQBRYiUxP6Msys1kTkEAUQbN/ZQ5Eny1ys/cXiqCwraOfqrLeaCM3qaX\n\t\t\t\t\t\tD84w1/2OQCWlpzsmG5kBOg8EpuVLfUTMSRdYwPfV67J9r90r+8XNkyKAGzYb4wID\n\t\t\t\t\t\tAQABo2cwZTBEBgNVHREEPTA7ghBpZHAuaGFycm93LmFjLnVrhidodHRwczovL2lk\n\t\t\t\t\t\tcC5oYXJyb3cuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFEE/B4YVPRZs\n\t\t\t\t\t\thx5Gp1R7uhe+AMnTMA0GCSqGSIb3DQEBBQUAA4IBAQAep4beNMViVZQ7+v1Qu9WA\n\t\t\t\t\t\tLAzsaiBDj/jkcj+iQaCzxrfzi9tkA/eP87iuMVc9y8MXbmclSZoDl91x2EZ7ohmd\n\t\t\t\t\t\tlmuA6fTdWuZ3gTFVoVD1fssqnQ5yZusGlLRtoZDqIowhiy04IVwvCopNHwu111M4\n\t\t\t\t\t\tm74wYHqOLXRK/3w/0WA/KVItqlhUBpv3ClOZWnG//zTRkmyienu7sksiRZy79H40\n\t\t\t\t\t\tnzqETopxqXGh+VtCAGvaHN2sO9Td+s03xE8YO3DSIdt8ykhOQh/yYRhRrREHAqTg\n\t\t\t\t\t\tD6jRZoljE6KqZDICisJHSEinDErpP8g07mv2HH62e25QQikqxYKRNGb/7SpAIR9o"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "harrow.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.harrow.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.harrow.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.harrow.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.harrow.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.harrow.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.harrow.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.harrow.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.harrow.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "harrow.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAIAV6r9T9UOFBwHmuFZHQ/Zrx7aPMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBsxGTAXBgNVBAMTEGlkcC5oYXJyb3cuYWMudWswHhcNMTIwMjA4MDk0MjIw\n\t\t\t\t\t\tWhcNMzIwMjA4MDk0MjIwWjAbMRkwFwYDVQQDExBpZHAuaGFycm93LmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAlmctLybnvCCmJ/okx0YFhn03\n\t\t\t\t\t\tb/2PuyksfVZ0LI986BrnNSvYYlm69Z0Y+wO8FLzN7fW2ztz5Xyag3eakCiyKAfP0\n\t\t\t\t\t\t23OLkdjG42bVlpjhYzW9OyamNtd9MbvkF5vNU8QA5eyRm+jhuqgmRiwhdfbwDvdw\n\t\t\t\t\t\teW6SmDHChmGr6YGfHMfvBjQNAO/x+VPdqcz7TREb4AtGLch8+pRMSslTaMZibdYe\n\t\t\t\t\t\tzKmOMKqywQBRYiUxP6Msys1kTkEAUQbN/ZQ5Eny1ys/cXiqCwraOfqrLeaCM3qaX\n\t\t\t\t\t\tD84w1/2OQCWlpzsmG5kBOg8EpuVLfUTMSRdYwPfV67J9r90r+8XNkyKAGzYb4wID\n\t\t\t\t\t\tAQABo2cwZTBEBgNVHREEPTA7ghBpZHAuaGFycm93LmFjLnVrhidodHRwczovL2lk\n\t\t\t\t\t\tcC5oYXJyb3cuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFEE/B4YVPRZs\n\t\t\t\t\t\thx5Gp1R7uhe+AMnTMA0GCSqGSIb3DQEBBQUAA4IBAQAep4beNMViVZQ7+v1Qu9WA\n\t\t\t\t\t\tLAzsaiBDj/jkcj+iQaCzxrfzi9tkA/eP87iuMVc9y8MXbmclSZoDl91x2EZ7ohmd\n\t\t\t\t\t\tlmuA6fTdWuZ3gTFVoVD1fssqnQ5yZusGlLRtoZDqIowhiy04IVwvCopNHwu111M4\n\t\t\t\t\t\tm74wYHqOLXRK/3w/0WA/KVItqlhUBpv3ClOZWnG//zTRkmyienu7sksiRZy79H40\n\t\t\t\t\t\tnzqETopxqXGh+VtCAGvaHN2sO9Td+s03xE8YO3DSIdt8ykhOQh/yYRhRrREHAqTg\n\t\t\t\t\t\tD6jRZoljE6KqZDICisJHSEinDErpP8g07mv2HH62e25QQikqxYKRNGb/7SpAIR9o"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Harrow College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.harrow.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Harrow College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://beta.sketchengine.co.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@sketchengine.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@sketchengine.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://beta.sketchengine.co.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-12-04T10:50:48Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Sketch Engine Beta"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.sketchengine.co.uk/documentation/wiki/Website/LexicalComputing/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Lexical Computing Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://beta.sketchengine.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://beta.sketchengine.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://beta.sketchengine.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://beta.sketchengine.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://beta.sketchengine.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://beta.sketchengine.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://beta.sketchengine.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Sketch Engine is a Corpus Query System allowing you to research how words behave."
                  }
                ],
                "logo": [
                  {
                    "text": "https://beta.sketchengine.co.uk/media/img/sketch_engine_beta_logo.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "180"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sketch Engine Beta"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJALdQBYI2gURnMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHRvYWQxLnNrZXRjaGVuZ2luZS5jby51azAeFw0xMjAyMTYxMDA2NTRaFw0y\n\t\t\t\t\t\tMjAyMTMxMDA2NTRaMCMxITAfBgNVBAMTGHRvYWQxLnNrZXRjaGVuZ2luZS5jby51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJj9g9mNJt+syu5Hypi1\n\t\t\t\t\t\tO7ozROE636f82MkvcGq3O49jW+lXaXa0TrdI6ZyWQWQQffObnp+UTI8Dy8dJPeJK\n\t\t\t\t\t\tq0yolm/V4RGnVz9sOYOT89vk1dYNmYTCkCEPvr28O9tnNrGVm+Y1GbMN/Ng1Hy1z\n\t\t\t\t\t\t0+Jw83Igqu9kZAxBxT9buBJL+1yag+f8fqL0Xh4siHHRIS20jnNWzI0sZoH4JLXA\n\t\t\t\t\t\tL/t9xQazOawCXDqgMwaybWCp2pi/GLkgktcXJFSOjivMnivwM6XUOr1RJ/7v5NXZ\n\t\t\t\t\t\tTbQiIDxOw+ur3lJaPi/04eWBTzrmLZLB/CZ+8xgG+umkMZhTF/jQTFqA3i64IDBq\n\t\t\t\t\t\tczsCAwEAAaNGMEQwIwYDVR0RBBwwGoIYdG9hZDEuc2tldGNoZW5naW5lLmNvLnVr\n\t\t\t\t\t\tMB0GA1UdDgQWBBTNszRhd97yo6rn4dsxJ4CO8ooO3zANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAZJVCs/BF3pLJxr/EgySFE0T8n2yjWRvgsrxms8dovhm7IClLWjVubK87iOao\n\t\t\t\t\t\tEyrLhKF8nlh8xX9SJQ7UVCkeK7m1X3mjx5lByKtbr/3mG+SJqCkBrG2neolJ0GRi\n\t\t\t\t\t\tcGEDCLN9HPVhKPPwlKh2TJ/jx/orZsBw2H6rZnwh9t5kspTzzvoQ4dfjg/B1EL6B\n\t\t\t\t\t\tPPwBUVBmaVzBxX1ZWIS78lHNNgynmPpcGpuhoxUzFYnc/hLuN14QALUbuad+iXWN\n\t\t\t\t\t\tR5xEvTb1qWIm+zCyONzG6xmjd18ox6m/YD6wTh2+7u0AhB+XA15AmvkfPdJyjdmg\n\t\t\t\t\t\tbpeg/CjdpV3/Q6Imu6H2cEHjkw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://beta.sketchengine.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://beta.sketchengine.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://beta.sketchengine.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://beta.sketchengine.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://beta.sketchengine.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://beta.sketchengine.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://alumniconnector.london.edu/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Woodhead"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:robbie.woodhead@freestyleinteractive.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Woodhead"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:robbie.woodhead@freestyleinteractive.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://alumniconnector.london.edu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-06-03T15:15:54Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "London Business School Alumni Connector"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.london.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "London Business School"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://alumniconnector.london.edu/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://alumniconnector.london.edu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://alumniconnector.london.edu/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://alumniconnector.london.edu/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://alumniconnector.london.edu/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://alumniconnector.london.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://alumniconnector.london.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEgTCCA2mgAwIBAgIQb1k6svpWuK5jsDHuxauJGDANBgkqhkiG9w0BAQUFADA2\n\t\t\t\t\t\tMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n\t\t\t\t\t\tU1NMIENBMB4XDTE0MDUxMzAwMDAwMFoXDTE3MDUxMjIzNTk1OVowSDEhMB8GA1UE\n\t\t\t\t\t\tCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMSMwIQYDVQQDExphbHVtbmljb25u\n\t\t\t\t\t\tZWN0b3IubG9uZG9uLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAMVhwovtjykmWCVhdA/VqLWs4ralOO8jE7qyjMxoUEeasNcxE+7IopDI2HuV8joL\n\t\t\t\t\t\tjPUNnqjA24fieLUwkd+/asyTQ0GTFbmGKAfE11mqPiOjUpw1sFcZyOAYFSSH2iBO\n\t\t\t\t\t\t9JPRVr59UFKH7nwtrPfztFvuMzJ5wLL0/zUrDQzxVEMXsRtnRgM2pFjHf2XnimHu\n\t\t\t\t\t\tjsxNNQT7KnEubHj3IeS6FVGLBKphup2L7Fr5Lz2G6+5epTuHaqMolEfhTPGowudB\n\t\t\t\t\t\tQbTHCcqXIg+GW6QDe893Q+Pi0lLjvRcuSkKHqrTrohEW0MECBtic50jm5NMdm/CT\n\t\t\t\t\t\tNF/hDNvQW7Ls9/akIwZ2yMUCAwEAAaOCAXcwggFzMB8GA1UdIwQYMBaAFAy9k2gM\n\t\t\t\t\t\t896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBR5VXq22fX+3Cl+t0YGGKsSB2SZQTAO\n\t\t\t\t\t\tBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcD\n\t\t\t\t\t\tAQYIKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEw\n\t\t\t\t\t\tOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJF\n\t\t\t\t\t\tTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8v\n\t\t\t\t\t\tY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYa\n\t\t\t\t\t\taHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwJQYDVR0RBB4wHIIaYWx1bW5pY29u\n\t\t\t\t\t\tbmVjdG9yLmxvbmRvbi5lZHUwDQYJKoZIhvcNAQEFBQADggEBAFi0t2vhnavwuw3T\n\t\t\t\t\t\tUXRWyt2QxdLIKJpzJX+DOnkB8EXaU7VrwtUhy4idA5L4e2QDIZEEGELZDLC6LaI4\n\t\t\t\t\t\tNZb7z2j2h5O1G70NhpyO6MvIlyMH/ZJ6g6YVoLiWgax4PnEPhLqq9R95rrZa5I5a\n\t\t\t\t\t\tUO3yTnzIbaw6XAaP1Rk7i2qFCL9MIn8/BMUNoHbeU1JU9EJCL2npM0o0Uk7GCiZb\n\t\t\t\t\t\tO0X28INlrfNnlOem0P6GjK7rqKerNY36IeL5hRicJuSMSEW8JPp5Ql0DRRkqPL9v\n\t\t\t\t\t\tlQzS4P/mYJscNI0c5W4QvWnQ2AZI79uKl4jHKh4K1BFLEkoZpmwz8BrhvnWiB4gw\n\t\t\t\t\t\tW7dyKKk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://alumniconnector.london.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://alumniconnector.london.edu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://alumniconnector.london.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://alumniconnector.london.edu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://alumniconnector.london.edu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://alumniconnector.london.edu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://decbmth.sisoshibboleth.co.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Info"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Oates"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://decbmth.sisoshibboleth.co.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-06-06T10:58:10Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SiSo Bournemouth University ~ DECBmth, Online Resource Booking"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.siso.uk.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "TechEthika Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://decbmth.siso.co/sso/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://decbmth.siso.co/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://decbmth.siso.co/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SiSo Bournemouth University ~ DECBmth, Online Resource Booking"
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth.siso.co/siso-logo60x60.jpg",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SiSo Bournemouth University ~ DECBmth, Online Resource Booking"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAOSUhyDXVj7AMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB3Npc28uY28wHhcNMTMwMTA3MTYzMTIxWhcNMjMwMTA1MTYzMTIxWjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdzaXNvLmNvMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\txDnj9YFJVXclawo/8rs1aWYAgk6rKi8A/Cyycq0mW5yOKLLh8MUIgDeOGL7bLl7p\n\t\t\t\t\t\tMBeZM4ILlNaeJhICWm1tuLB6SYzREnXwpO7+lvx13xsRHW2TjCPGV3yUgz55vRYj\n\t\t\t\t\t\tbseFrwFHJ8IrL24UTLcpX/R//9cMkZpSqM+77Hn22dxbYvGUOQCHOQzL78AO91qz\n\t\t\t\t\t\tdUaxKzYWyWM7w2U4APP41Zvd0flyUtRZXp8W+WwlUDffFoNndsjR4L/9wuXvOcrH\n\t\t\t\t\t\t+VZtMLy60+cB9bpvVlaQVlt+1stEABdMVvuGNkJ9wIjRjP2b9OLUI76QmgwIDtdE\n\t\t\t\t\t\t5BS0Bv0Puz66L96r2MunRQIDAQABozUwMzASBgNVHREECzAJggdzaXNvLmNvMB0G\n\t\t\t\t\t\tA1UdDgQWBBRRosxNbUQXXwtWDl/kYMScRImh5TANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tgrfjza9Btcz+9WvzcjDTZ+KSrWWvrthA3zc6Q+C/MIBG8CCuxMO+uwFBnXIopGlX\n\t\t\t\t\t\tbLa/QtVLjOugsnizFxjaEFTG4jGndtPJ8+9V8Eja5RlOazuM2LT738+Um8/1Frhr\n\t\t\t\t\t\tGXa0Hdv9ZWEbIhil65fFqZNOmOteja6xxAQ9NgGG/XUnTVTbr7msihEAYTTcS40/\n\t\t\t\t\t\tGSYpT9nQwiryfSWDNJ17Zyl44389kSw+FCUsu8Ns9VSDEDWr/R+97ZMcjN6hAfJL\n\t\t\t\t\t\tdji3X1aaAC/JbnJl/v+yR1TH/sdHyObVaM7FToUGKiyjX9VpfOe64d0hjogzEr0x\n\t\t\t\t\t\tfirJubLNu96jbGctasqcpQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://decbmth.siso.co/sso/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://decbmth.siso.co/sso/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://decbmth.siso.co/sso/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://decbmth.siso.co/sso/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://decbmth.siso.co/sso/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://decbmth.siso.co/sso/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://auth.buckingham.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@buckingham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@buckingham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://auth.buckingham.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-10-25T08:59:24Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://auth.buckingham.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.buckingham.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "buckingham.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIITuplxzadgNMwDQYJKoZIhvcNAQEFBQAwPzEdMBsGA1UE\n\t\t\t\t\t\tCgwURWR1c2VydiBUZXN0IFNlcnZpY2UxHjAcBgNVBAMMFWF1dGguYnVja2luZ2hh\n\t\t\t\t\t\tbS5hYy51azAeFw0xMjA4MjQxMDI1MzdaFw0yMjA4MjQxMDI1MzdaMD8xHTAbBgNV\n\t\t\t\t\t\tBAoMFEVkdXNlcnYgVGVzdCBTZXJ2aWNlMR4wHAYDVQQDDBVhdXRoLmJ1Y2tpbmdo\n\t\t\t\t\t\tYW0uYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCJnxt6TX6A\n\t\t\t\t\t\tPmuM/I+rOnZ+Cx0P1DO1h+rlFmdtx9Sng8dd7OhmpYSlnk30NrZzKtWPXAVMYPHf\n\t\t\t\t\t\tdgx70/z25svlFO/B02/eP+W3bJvxmLnDXTJ6vyam0I/6/vuXg8gcFyB8JlwjmQ/e\n\t\t\t\t\t\tDQPRaEK/MXivjsmo+9Y0VL5dntmKUYgq1zzm/dfdGnJ+khczg2xeI+SUZGgRAwcy\n\t\t\t\t\t\tT9KZfXmbF45RTCNDWIGQER7F8HzixesDHPemCavA6bbL/z9hpZqcoWeuXZi88Q3C\n\t\t\t\t\t\tJoH66HvJnGJyYayl3eMdATWhbnUsYlcZTFQPYliy6hwhT+qfkxA+GLBkvpMVDqrG\n\t\t\t\t\t\tnrirwFQjctWzAgMBAAGjUDBOMB0GA1UdDgQWBBSYtaC4R49myVJwK8kzCZGHAB74\n\t\t\t\t\t\tDTAfBgNVHSMEGDAWgBSYtaC4R49myVJwK8kzCZGHAB74DTAMBgNVHRMEBTADAQH/\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQB6N8ifKsxb1zLu2QuOdIJwwuw2ycjvGUerLUqy\n\t\t\t\t\t\t5LtnC4eCB302S9YUgprHSG7nlPuDYPv2dF45dudZahI7yo3/GyqeNgg12e0qpH/M\n\t\t\t\t\t\t7S4aCOYfPEhU2MNjzfcRZBaBQaKhmPT66gCEZcDLFYUL9zB3EdlvhcLSJNvGG9ys\n\t\t\t\t\t\t8WyvXEgs2IEnLh/SlEgXm2NRMSq1uONiUPRTE01r0n2wW4FHOnJTGtaWvfqCuNA5\n\t\t\t\t\t\t0PAvY7F+1+HTZgtNnq5w1ms74QgsSj7Z7vgFohyDN4YjefZs/Zi+s22bmzN6yikc\n\t\t\t\t\t\tdQIRgLcLkbamsq2LWs0Li52jrDapAHtHTxn2PsHVhIA+yIUG"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIITuplxzadgNMwDQYJKoZIhvcNAQEFBQAwPzEdMBsGA1UE\n\t\t\t\t\t\tCgwURWR1c2VydiBUZXN0IFNlcnZpY2UxHjAcBgNVBAMMFWF1dGguYnVja2luZ2hh\n\t\t\t\t\t\tbS5hYy51azAeFw0xMjA4MjQxMDI1MzdaFw0yMjA4MjQxMDI1MzdaMD8xHTAbBgNV\n\t\t\t\t\t\tBAoMFEVkdXNlcnYgVGVzdCBTZXJ2aWNlMR4wHAYDVQQDDBVhdXRoLmJ1Y2tpbmdo\n\t\t\t\t\t\tYW0uYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCJnxt6TX6A\n\t\t\t\t\t\tPmuM/I+rOnZ+Cx0P1DO1h+rlFmdtx9Sng8dd7OhmpYSlnk30NrZzKtWPXAVMYPHf\n\t\t\t\t\t\tdgx70/z25svlFO/B02/eP+W3bJvxmLnDXTJ6vyam0I/6/vuXg8gcFyB8JlwjmQ/e\n\t\t\t\t\t\tDQPRaEK/MXivjsmo+9Y0VL5dntmKUYgq1zzm/dfdGnJ+khczg2xeI+SUZGgRAwcy\n\t\t\t\t\t\tT9KZfXmbF45RTCNDWIGQER7F8HzixesDHPemCavA6bbL/z9hpZqcoWeuXZi88Q3C\n\t\t\t\t\t\tJoH66HvJnGJyYayl3eMdATWhbnUsYlcZTFQPYliy6hwhT+qfkxA+GLBkvpMVDqrG\n\t\t\t\t\t\tnrirwFQjctWzAgMBAAGjUDBOMB0GA1UdDgQWBBSYtaC4R49myVJwK8kzCZGHAB74\n\t\t\t\t\t\tDTAfBgNVHSMEGDAWgBSYtaC4R49myVJwK8kzCZGHAB74DTAMBgNVHRMEBTADAQH/\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQB6N8ifKsxb1zLu2QuOdIJwwuw2ycjvGUerLUqy\n\t\t\t\t\t\t5LtnC4eCB302S9YUgprHSG7nlPuDYPv2dF45dudZahI7yo3/GyqeNgg12e0qpH/M\n\t\t\t\t\t\t7S4aCOYfPEhU2MNjzfcRZBaBQaKhmPT66gCEZcDLFYUL9zB3EdlvhcLSJNvGG9ys\n\t\t\t\t\t\t8WyvXEgs2IEnLh/SlEgXm2NRMSq1uONiUPRTE01r0n2wW4FHOnJTGtaWvfqCuNA5\n\t\t\t\t\t\t0PAvY7F+1+HTZgtNnq5w1ms74QgsSj7Z7vgFohyDN4YjefZs/Zi+s22bmzN6yikc\n\t\t\t\t\t\tdQIRgLcLkbamsq2LWs0Li52jrDapAHtHTxn2PsHVhIA+yIUG"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Buckingham"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.buckingham.ac.uk/about/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Buckingham"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayf.supportcenter.dk/gg/saml2/idp/metadata.php?unit=gg",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayf.supportcenter.dk/gg/saml2/idp/metadata.php?unit=gg",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2010-08-17T13:55:36Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayf.supportcenter.dk/gg/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gg.itsf.dk"
              },
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Grenaa Gymnasium"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Grenaa Gymnasium"
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Grenaa Gymnasium"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Grenaa Gymnasium"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "gg.itsf.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCDCCAfACAQcwDQYJKoZIhvcNAQELBQAwSjFIMEYGA1UEAww/aHR0cHM6Ly93\nYXlmLnN1cHBvcnRjZW50ZXIuZGsvZ2cvc2FtbDIvaWRwL21ldGFkYXRhLnBocD91\nbml0PWdnMB4XDTE1MDEwMTAwMDAwMFoXDTI1MTIzMTIzNTk1OVowSjFIMEYGA1UE\nAww/aHR0cHM6Ly93YXlmLnN1cHBvcnRjZW50ZXIuZGsvZ2cvc2FtbDIvaWRwL21l\ndGFkYXRhLnBocD91bml0PWdnMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAx4gMCmoQU7iOGfiCda4DnhIggst20fUCHtwaQrHoxQlOa0s5FgDalbnNTw36\ndCXSGYaz17JgyUDJonTwhjyA0CqPm5Pmn9/hFBUvyP/t+bEgV9r3/odQx72VfY7M\n55qUlY6ex2f1qD1gcpFgSTtADlZswec5WqpEt+ie+vsMXq8HabhMVZ2EjXe90vgM\nk/xGfrVwDvupUPBS/2DJSZ1JEmkqi0hxctNQ9qgTZmEcAaQkuv3VGcsYtLeY/IIS\nlA+ARzmVWr5+uSetnCXV4jnDEclACKeexl0Ky+tyra4yHF3Xavgmcmebd+xHVDiM\n+No6BXMu9zBTp7cp5ShLzsNQSQIDAQABMA0GCSqGSIb3DQEBCwUAA4IBAQBMXkp3\nc1jLj0QNJYll4rzdfhyge7aut2vSTofZKZmd42aykUfPhQeJFyHGSkCNXE965QWw\nSJTvUUNaM3FZjae3TFY+o4lgF3KBkXGDV0nwH+IjzfJ89Cw7iCZ9NUYBsRuCRUIq\nzkJZODS1hgC75W28KoCKOiWmKN7v4+zyDk52aNm1jELnvHgmXfT6Ga7/GI+uusk3\nsxC5f4fnXJXaGsh7mXnW4r3JZkDFmHbaiqim80NgEDzlMgI9kb64p1mhM/vAMPu/\n1xqhR3VmCahpI8n6vII6+g07qhfc8GLzJ0jUaMyQoucpN4LwfIshLtBdOn9MCFVe\nZ8bY2QouT70h3w+L"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Grenaa Gymnasium"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Grenaa Gymnasium"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.grenaa-gym.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.grenaa-gym.dk/home.aspx"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Grenaa Gymnasium"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Grenaa Gymnasium"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://play.liu.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://play.liu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://play.liu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://play.liu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.liu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://play.liu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://play.liu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://play.liu.se/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "play.liu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9TCCAd2gAwIBAgIJAKe3B+KUVP3+MA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC3BsYXkubGl1LnNlMB4XDTExMTIwNjEyMTk1OVoXDTIxMTIwMzEyMTk1OVow\nFjEUMBIGA1UEAxMLcGxheS5saXUuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQC+vp3loPQsTZ0uL5qOMD6OiqrZvbtwc1yggSBWE7aZ+JCYrM9VcJQs\n3vPC9i4hf/mZDNFmvBWz8aDCXG5PpLtoVsrhYuNhetNbHyvagnl51MwK0KY5JDOk\nf5pAii8WD+88EPqdFGbLCDKQ6UpSR1hsUMudpJlmu0hdPvhVuXexRmaYPEk3vN3P\nFnmBqD4YNPTVkLrfC6OXm5EL7Q7J1DWDyowr1xAJfMlfyhSMay6DKvuE/zA8vWpp\n28kMjcoQWDFNROp6+RHlPmYBhzEmhzoxULKl3QCv/3hwvw3C70vOABBBq+xj1iRJ\nGnO5IO9HWBlUG8O1O7Ohrk+3F6tt6pY1AgMBAAGjRjBEMCMGA1UdEQQcMBqCC3Bs\nYXkubGl1LnNlhgtwbGF5LmxpdS5zZTAdBgNVHQ4EFgQUo7pfHcTYa3XfSHE+g3l0\np6ergSkwDQYJKoZIhvcNAQEFBQADggEBAJOjVfPaleYl/RdJDGtjdOredI0MoiJR\nXWkC5Zm0Qp28KRJoV7kGgzPCiF0M7CH6w1ZF0t1qMU+kSsIRsxLhwG+7bT8ECONx\n0c7DnZY/qZcZb3USf7h9DwaO/RMxGa+Fm76eUNQ9HurprEmaXfEQsYFYWsGj56Q8\n0fquuSogz4O1dEGjG85IV8ehGKS5JlLJsLnC0eggjYZFK954g3bRkEcLwcBDEbaa\n6QQZ52emPo6rYMFX90CxvkJwxt7GA2BHDziqi/51SUPpfWYhXtNiHioUt1D1dbNd\nHk7Vkl5qHXdOgulvHmmaLJXl7ABXJmddzV49NpKlhS5V79JGu6bbkeA="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=play.liu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "play.liu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9TCCAd2gAwIBAgIJAKe3B+KUVP3+MA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC3BsYXkubGl1LnNlMB4XDTExMTIwNjEyMTk1OVoXDTIxMTIwMzEyMTk1OVow\nFjEUMBIGA1UEAxMLcGxheS5saXUuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQC+vp3loPQsTZ0uL5qOMD6OiqrZvbtwc1yggSBWE7aZ+JCYrM9VcJQs\n3vPC9i4hf/mZDNFmvBWz8aDCXG5PpLtoVsrhYuNhetNbHyvagnl51MwK0KY5JDOk\nf5pAii8WD+88EPqdFGbLCDKQ6UpSR1hsUMudpJlmu0hdPvhVuXexRmaYPEk3vN3P\nFnmBqD4YNPTVkLrfC6OXm5EL7Q7J1DWDyowr1xAJfMlfyhSMay6DKvuE/zA8vWpp\n28kMjcoQWDFNROp6+RHlPmYBhzEmhzoxULKl3QCv/3hwvw3C70vOABBBq+xj1iRJ\nGnO5IO9HWBlUG8O1O7Ohrk+3F6tt6pY1AgMBAAGjRjBEMCMGA1UdEQQcMBqCC3Bs\nYXkubGl1LnNlhgtwbGF5LmxpdS5zZTAdBgNVHQ4EFgQUo7pfHcTYa3XfSHE+g3l0\np6ergSkwDQYJKoZIhvcNAQEFBQADggEBAJOjVfPaleYl/RdJDGtjdOredI0MoiJR\nXWkC5Zm0Qp28KRJoV7kGgzPCiF0M7CH6w1ZF0t1qMU+kSsIRsxLhwG+7bT8ECONx\n0c7DnZY/qZcZb3USf7h9DwaO/RMxGa+Fm76eUNQ9HurprEmaXfEQsYFYWsGj56Q8\n0fquuSogz4O1dEGjG85IV8ehGKS5JlLJsLnC0eggjYZFK954g3bRkEcLwcBDEbaa\n6QQZ52emPo6rYMFX90CxvkJwxt7GA2BHDziqi/51SUPpfWYhXtNiHioUt1D1dbNd\nHk7Vkl5qHXdOgulvHmmaLJXl7ABXJmddzV49NpKlhS5V79JGu6bbkeA="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=play.liu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://play.liu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://play.liu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.liu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://play.liu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.liu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://play.liu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://play.liu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://play.liu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://play.liu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://play.liu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://atlas.slu.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://atlas.slu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://atlas.slu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://atlas.slu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://atlas.slu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://atlas.slu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://atlas.slu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://atlas.slu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://atlas.slu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SLU:s tj\u00e4nst f\u00f6r distribution av geografiska data"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SLU service for distribution of geographical data"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "GET download service"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "GET download service"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "atlas.slu.se"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://atlas.slu.se/shibboleth"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAM4yh57daZITMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDGF0bGFzLnNsdS5zZTAeFw0xNTA2MTgxMTQxNTBaFw0yNTA2MTUxMTQxNTBa\nMBcxFTATBgNVBAMTDGF0bGFzLnNsdS5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAL67FSkIyqmdkoEAz9gxPXKf6eli4gBvwmLuh1C/lrc8s1Jzno81\nz36wrUbX5rBzMteupRLQLwfRwx2nIwhPSfQCvtEfyFNLf2D/Pm7Y6SouqyQxyatG\nsn4do9plqfEpGWU0ZK2nH8pf6NkITzDjqykplT7nfAEe5Wsp/VTl5ExXs80JwK3c\nG9xDMneo1NJoytRtjXQI+OsbhR56ZJKkxkv5P5AE523HSg5SuOOgDAFsRHKJsgeK\nZiUQam0DfzHG5Zceq8TKOmUMcNub1mg+fdgiqu21I+cNGpVgFTms9pa3OxZG6DAw\n55PDJ4e/Ika7O7KMLsfVTHILo4XHLmvVM+kCAwEAAaNbMFkwOAYDVR0RBDEwL4IM\nYXRsYXMuc2x1LnNlhh9odHRwczovL2F0bGFzLnNsdS5zZS9zaGliYm9sZXRoMB0G\nA1UdDgQWBBR06HlBgkISecFyWLaVPfCjzYwN2DANBgkqhkiG9w0BAQUFAAOCAQEA\npTMhg1KaJfRt4PkSKvjRaPzDQvLWJxE9hgDb9iGNAXvGvnmKPs7YoziMz7ICbkce\nSKTLWchBHAiAD6N/uJCDmdwDY+VmH48F4vRok/vt2FDCgtogrHXfM4K5PlhGHCl1\ngdccPmA/IMkQpSr76I6cVWjk3FTX4nahR1cq6597+iWjaN2AHwsr3vC4kvjdC8QC\nOFfBlIVvEMXWzo+JRCyZbm+BXa5wVx8qkP2HkhYAm0sI2yw0ZjpzaPi1K+3oK9gU\ntFXrBRl9ylwunnWQP2FsI/pceyGv99G2VmWvtx7wVbg4fM3FwlQswj1rM+EkHVl7\nfERSmom3Oe5HW6bTLnbS6w=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=atlas.slu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://atlas.slu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://atlas.slu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://atlas.slu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://atlas.slu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://atlas.slu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www2.foodle.cz/sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Oppolzer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jan.oppolzer@cesnet.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www2.foodle.cz/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2013-10-07T10:58:21Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CESNET"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CESNET"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cesnet.cz/?lang=en"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cesnet.cz/?lang=cs"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CESNET, a. l. e."
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CESNET, z. s. p. o"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.foodle.cz/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.foodle.cz/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.foodle.cz/?language=en"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.foodle.cz/?language=cs"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "An easy survey tool suitable for questionnaire and meetings organization"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "N\u00e1stroj pro jednoduch\u00e9 pr\u016fzkumy, dotazn\u00edky a organizov\u00e1n\u00ed sch\u016fzek"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Foodle.CZ"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Foodle.CZ"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.foodle.cz/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.foodle.cz/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.foodle.cz/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.foodle.cz/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp1.solent.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:federation.support@solent.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:federation.tech@solent.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp1.solent.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-05-22T14:40:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAMEcRei0mVIxnctKElMp/O387gtBMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBwxGjAYBgNVBAMTEWlkcDEuc29sZW50LmFjLnVrMB4XDTE1MDIxNzEwMzQx\n\t\t\t\t\t\tNFoXDTI1MDIxNzEwMzQxNFowHDEaMBgGA1UEAxMRaWRwMS5zb2xlbnQuYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCF1dDGPEUijwsKsLzmVVbu\n\t\t\t\t\t\tW4amy2HYiaCRRM9HOs1NIn4sYjG0aj5tnH1HUvbF8x2MfEGvsGidm1NLZoxIEjv8\n\t\t\t\t\t\t/gxR5aswHfQjZp8ju1bffeCNzEftrFRMCvUiWxf7ThxQDsrDY9WcocOlr7BHEtVn\n\t\t\t\t\t\t4NDqlaxjBKhRxgqZUrE+S2dvZfFYsR23AzwohJ2HLR+/3bxBhCBs+A/kQrgLMNvw\n\t\t\t\t\t\t7Z7fPiu7OiUuS2Qjqz+4HHPm6k6RtqOtayKWfToHXS/b+Yxv8DEF3xQW+if6zZA0\n\t\t\t\t\t\tzdjYIZ0hVa2ew2882rqRIlBKZpUcl6kdIWH7XjXvbzu8xkXG0ZRdXyVaRIPaY7fb\n\t\t\t\t\t\tAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEWlkcDEuc29sZW50LmFjLnVrhihodHRwczov\n\t\t\t\t\t\tL2lkcDEuc29sZW50LmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSPY2tD\n\t\t\t\t\t\t4c7/NhioEVdldj0S9Y2EADANBgkqhkiG9w0BAQUFAAOCAQEABI2dIOAflt1WkYEJ\n\t\t\t\t\t\tYUo+pk9+3xYoh6EPU8HF0a4aruul5jBLWpyZfrXWffjZtbGj1dYb5UNj/x7zzWOm\n\t\t\t\t\t\tfIn7Tig2UjjkWL/81TSPLIPHG5QpR+UxRB8eUpsr8NslOwqP0brIRqgIyzNNQz82\n\t\t\t\t\t\tIRtFzpE5SdI5Ds1lhhV5gQqSBSfuDimqrrmMMD2BQ/aAZgtnt6HfzCzDTv9o9K1a\n\t\t\t\t\t\truMAOxdwGzOWgas6VmibPb/m2j/tibs37OMzpBtwUldqDjB2/WYmIhu4zXHrMj+6\n\t\t\t\t\t\t/RF0wtwrM2dWdDlIQtm+f7yQfxrP74fx4fDWA2uetDa1RkQX7U54/Sfxx9d4UpIU\n\t\t\t\t\t\tdBTl/A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "solent.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.solent.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.solent.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp1.solent.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp1.solent.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp1.solent.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp1.solent.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.solent.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.solent.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "solent.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAMEcRei0mVIxnctKElMp/O387gtBMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBwxGjAYBgNVBAMTEWlkcDEuc29sZW50LmFjLnVrMB4XDTE1MDIxNzEwMzQx\n\t\t\t\t\t\tNFoXDTI1MDIxNzEwMzQxNFowHDEaMBgGA1UEAxMRaWRwMS5zb2xlbnQuYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCF1dDGPEUijwsKsLzmVVbu\n\t\t\t\t\t\tW4amy2HYiaCRRM9HOs1NIn4sYjG0aj5tnH1HUvbF8x2MfEGvsGidm1NLZoxIEjv8\n\t\t\t\t\t\t/gxR5aswHfQjZp8ju1bffeCNzEftrFRMCvUiWxf7ThxQDsrDY9WcocOlr7BHEtVn\n\t\t\t\t\t\t4NDqlaxjBKhRxgqZUrE+S2dvZfFYsR23AzwohJ2HLR+/3bxBhCBs+A/kQrgLMNvw\n\t\t\t\t\t\t7Z7fPiu7OiUuS2Qjqz+4HHPm6k6RtqOtayKWfToHXS/b+Yxv8DEF3xQW+if6zZA0\n\t\t\t\t\t\tzdjYIZ0hVa2ew2882rqRIlBKZpUcl6kdIWH7XjXvbzu8xkXG0ZRdXyVaRIPaY7fb\n\t\t\t\t\t\tAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEWlkcDEuc29sZW50LmFjLnVrhihodHRwczov\n\t\t\t\t\t\tL2lkcDEuc29sZW50LmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSPY2tD\n\t\t\t\t\t\t4c7/NhioEVdldj0S9Y2EADANBgkqhkiG9w0BAQUFAAOCAQEABI2dIOAflt1WkYEJ\n\t\t\t\t\t\tYUo+pk9+3xYoh6EPU8HF0a4aruul5jBLWpyZfrXWffjZtbGj1dYb5UNj/x7zzWOm\n\t\t\t\t\t\tfIn7Tig2UjjkWL/81TSPLIPHG5QpR+UxRB8eUpsr8NslOwqP0brIRqgIyzNNQz82\n\t\t\t\t\t\tIRtFzpE5SdI5Ds1lhhV5gQqSBSfuDimqrrmMMD2BQ/aAZgtnt6HfzCzDTv9o9K1a\n\t\t\t\t\t\truMAOxdwGzOWgas6VmibPb/m2j/tibs37OMzpBtwUldqDjB2/WYmIhu4zXHrMj+6\n\t\t\t\t\t\t/RF0wtwrM2dWdDlIQtm+f7yQfxrP74fx4fDWA2uetDa1RkQX7U54/Sfxx9d4UpIU\n\t\t\t\t\t\tdBTl/A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Southampton Solent University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.solent.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Southampton Solent University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso.pdx.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cis-unix@pdx.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "PSU Unix Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cis-iam@pdx.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "PSU IAM Team"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@pdx.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "PSU Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sec-requests@pdx.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "PSU Security Team"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://sso.pdx.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.pdx.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.pdx.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUdzBvspR9IxIcNVecJ9uYqw2FxOkwDQYJKoZIhvcNAQEL\nBQAwFjEUMBIGA1UEAwwLc3NvLnBkeC5lZHUwHhcNMTUwODE5MTc1NzUyWhcNMzUw\nODE5MTc1NzUyWjAWMRQwEgYDVQQDDAtzc28ucGR4LmVkdTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBALS4zeE+sjNpCyWno01ra/hBUx5dFCv0u+1maVOt\nezztTl5TgJXqIhfraP06ZzFZyYb1Zkbtler9/hcpBDHpI48dyb5QChw6UkMie1oW\n1CnXqN39DwPqSnmiX5oxaVAcSh5YnvzOeNGIumtu+MTXnwdh5HH827CiZXTzPavJ\n7NMMZ36xoNb6137Ny5N6VGJ2zJCj95Tg5KzaMWZiQa/CYaRJDdT8DD2YFb7+KKYn\nli3CDWLfVN1lhyXA0Ue/gHNChEjbfo92o1kqPYLLQQHZjH/n16tpr+L6NJ7K+7Fj\ni/T3h5l3NdPh0SD4nIyQDIkXQD80zSkzncc8Lc4+Ynr5RRsCAwEAAaNdMFswHQYD\nVR0OBBYEFK1fG4otT6OMzHQwV1tVgokTL9G3MDoGA1UdEQQzMDGCC3Nzby5wZHgu\nZWR1hiJodHRwczovL3Nzby5wZHguZWR1L2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3\nDQEBCwUAA4IBAQCM7yIzrZhbbFXv6Z6HWEig18jPbOEOjLjSti0qN3+jvvuuJKVl\ngN/1qBYQljh5fSnWIGDppn8ozRnVXHzxtgOdqFqJ6Ww88I+3dBfaPMdr/FmFo/J5\nmeMw9ypaPJRtd9TRPF7hOnjSyihAqQlJuEdEK2bonoyic/hpHFjZpxX4ProsAcUr\nEA/tefxebhlDaSIgbJxVU2dReIbV8rjFNWfjp6wksbSvj/isU7KuzPODe2Kxt8S8\n4Rn1ZTKf1dn6ThoNInVnrIGNHt0hC1S6ijthjE5dB4hos6ndOVUHrjtWSxA0Nd5o\nXIfa61/C4DF+ni+CfZSdcGSigYeyYVIroMpB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pdx.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.pdx.edu"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Portland State Identity Provider"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Portland State University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Portland State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.pdx.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Portland State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.southdevon.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cassidy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@southdevon.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kelly"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Turner"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dturner@southdevon.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.southdevon.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEXDCCA0SgAwIBAgIJAKyPn9Ts3+81MA0GCSqGSIb3DQEBCwUAMIGzMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEOMAwGA1UECAwFRGV2b24xETAPBgNVBAcMCFBhaWdudG9uMRwwGgYD\n\t\t\t\t\t\tVQQKDBNTb3V0aCBEZXZvbiBDb2xsZWdlMRowGAYDVQQLDBFDb21wdXRlciBTZXJ2\n\t\t\t\t\t\taWNlczEdMBsGA1UEAwwUaWRwLnNvdXRoZGV2b24uYWMudWsxKDAmBgkqhkiG9w0B\n\t\t\t\t\t\tCQEWGWhlbHBkZXNrQHNvdXRoZGV2b24uYWMudWswHhcNMTYwNDEyMTI1MjExWhcN\n\t\t\t\t\t\tMjYwNDEwMTI1MjExWjCBszELMAkGA1UEBhMCR0IxDjAMBgNVBAgMBURldm9uMREw\n\t\t\t\t\t\tDwYDVQQHDAhQYWlnbnRvbjEcMBoGA1UECgwTU291dGggRGV2b24gQ29sbGVnZTEa\n\t\t\t\t\t\tMBgGA1UECwwRQ29tcHV0ZXIgU2VydmljZXMxHTAbBgNVBAMMFGlkcC5zb3V0aGRl\n\t\t\t\t\t\tdm9uLmFjLnVrMSgwJgYJKoZIhvcNAQkBFhloZWxwZGVza0Bzb3V0aGRldm9uLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAw780rAsk+mJLxAxM\n\t\t\t\t\t\t4AJfvZBzfb4l9Vpu/6BO8Or54rmp/uThhC0mgdoJqQlmaEb4ZIK4/CbfstV8Qo3s\n\t\t\t\t\t\tINiy6Z1+xMVcrBalH9gG6cXB7i1E1vDuUE5gg/qd1KGCwXrVBDKGKF1enpMlOBgQ\n\t\t\t\t\t\tcTHZ2dpTf9Hgjmxcixa030ETpvmDyja86dYnQnkxGpXbIyxJR9h7XlkGXzd/fdP0\n\t\t\t\t\t\tdk45mXkzna05QThcg6SqMlZasi4iyd8UGulWAg7sYBIfxI3Xm88PaTm+KscBCVPu\n\t\t\t\t\t\tMa1WatglA9JIBlQwWantChP7AI9v4YZGG+af6uhp1l8UzXA8EdQL6lCwqvmgGD0F\n\t\t\t\t\t\t1RFX0wIDAQABo3EwbzAfBgNVHREEGDAWghRpZHAuc291dGhkZXZvbi5hYy51azAd\n\t\t\t\t\t\tBgNVHQ4EFgQUivSrY0v+NvStP9sX9z4xYKNpba0wHwYDVR0jBBgwFoAUivSrY0v+\n\t\t\t\t\t\tNvStP9sX9z4xYKNpba0wDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAQEA\n\t\t\t\t\t\tRO80zk8JjZ7UpVODbHxiyAzs1WX4wIoUc8VR6Cpf55/tTUEBhfU1sHggV5J285Xk\n\t\t\t\t\t\tngRf3d+5xcnqO+RjMPn7AXU35ycRofFWsDNtabcWoXK4X6pYrYUAQEsZu/4Q05qJ\n\t\t\t\t\t\tjzxP0lDW16HRN+JJs97Lel95y8tvhyGhc6VTLzwvOMBCTHeWhuPmlzAZmh3w3hLz\n\t\t\t\t\t\tf5rIu2knlPysAdyln9PGl1tRSchcjJhN2K/Bq2xVSCFWmGjZiENHc2yfpwc+z7Xq\n\t\t\t\t\t\tAs5id/Pz62Gwe5qtzQSiWo9G1zkAw2PODKY0rA4JNAvwT9whv2A/Ef8ggRmiJGu6\n\t\t\t\t\t\t9Ia6HkphVIymnefQl1ZO/Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE5DCCA8ygAwIBAgIRANGrqwrzcv/wwtm5h/u2MFkwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzA1MTYwMDAwMDBaFw0xNjA1MTUyMzU5NTlaMIGvMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEQMA4GA1UEERMHVFE0IDdFSjEOMAwGA1UECBMFRGV2b24xETAPBgNV\n\t\t\t\t\t\tBAcTCFBBSUdOVE9OMRIwEAYDVQQJEwlMb25nIFJvYWQxHDAaBgNVBAoTE1NvdXRo\n\t\t\t\t\t\tIERldm9uIENvbGxlZ2UxGjAYBgNVBAsTEUNvbXB1dGVyIFNlcnZpY2VzMR0wGwYD\n\t\t\t\t\t\tVQQDExRpZHAuc291dGhkZXZvbi5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBAM7bII/xHAr1oS3qU/Y+fjfA5zzvRSgLS1pEveCyck9Z1w30Tt8v\n\t\t\t\t\t\tC0NTuLUw6KnjrytWVjWdQJJoRCMI3sjpwFqDC+6js4azlee2AABynMdGzOuJ6GqA\n\t\t\t\t\t\tA8pzDxes/BSio8CxHG/Sp2rglvpDphQLKgzTACTUeooWQ2qhEm9liS5HercXHZnx\n\t\t\t\t\t\tAIZCGpw9ChqhiXAofAENjdBl3kuqHl1gn80j4uN7jtTXKb7Rz6DwsXlc3tl/rT7c\n\t\t\t\t\t\tAr8z0mTllMy09m21rLXae4CaQB/3x7j6HFWeSEcHh6o5iBjWnlmQmQnsXsybIeuz\n\t\t\t\t\t\txqdLKwDhOIqz2hW3MiQX8wCqE5YwGaZtEaMCAwEAAaOCAXEwggFtMB8GA1UdIwQY\n\t\t\t\t\t\tMBaAFAy9k2gM896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBRxOiCSLnFHA2VGV1OX\n\t\t\t\t\t\thbf81QvVgTAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAU\n\t\t\t\t\t\tBggrBgEFBQcDAQYIKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAI\n\t\t\t\t\t\tBgZngQwBAgIwOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5h\n\t\t\t\t\t\tLm9yZy9URVJFTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAC\n\t\t\t\t\t\thilodHRwOi8vY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggr\n\t\t\t\t\t\tBgEFBQcwAYYaaHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwHwYDVR0RBBgwFoIU\n\t\t\t\t\t\taWRwLnNvdXRoZGV2b24uYWMudWswDQYJKoZIhvcNAQEFBQADggEBAKjRYUyCVxuA\n\t\t\t\t\t\tVlPnjOLvXIby4ohy2rqZKc7Co2U6TNDkPMlC+7j48hBsDjGQzpW7l3B6Qktq9Iox\n\t\t\t\t\t\t0i3cS5NQVXL0aeL+4ixSnlX62EeqdAElo7mvUP/VdALPI7FUi0fKXW6JmK+5FH2b\n\t\t\t\t\t\t+5o3pw18AjHX+TylwE0rIwofwNb+TwAPXyv/Iu4fqYL4ZEfwAfIHh9sqmmZdTQfL\n\t\t\t\t\t\tAfbAiyFUkePPuF5fo05C70iZR6GIkmt09g2V8MmQZPwWyl+ar+UK0Xg8uqB5uBC0\n\t\t\t\t\t\t/+1GTST3DkvMiNpzOdE9ryueHBpQ7W5S+JuRbQ7BZUgFxBrbSPmFsCiPCKFmJ3KA\n\t\t\t\t\t\t9a0UDu0T7vU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "southdevon.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.southdevon.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.southdevon.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.southdevon.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.southdevon.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.southdevon.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.southdevon.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.southdevon.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.southdevon.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "southdevon.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEXDCCA0SgAwIBAgIJAKyPn9Ts3+81MA0GCSqGSIb3DQEBCwUAMIGzMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEOMAwGA1UECAwFRGV2b24xETAPBgNVBAcMCFBhaWdudG9uMRwwGgYD\n\t\t\t\t\t\tVQQKDBNTb3V0aCBEZXZvbiBDb2xsZWdlMRowGAYDVQQLDBFDb21wdXRlciBTZXJ2\n\t\t\t\t\t\taWNlczEdMBsGA1UEAwwUaWRwLnNvdXRoZGV2b24uYWMudWsxKDAmBgkqhkiG9w0B\n\t\t\t\t\t\tCQEWGWhlbHBkZXNrQHNvdXRoZGV2b24uYWMudWswHhcNMTYwNDEyMTI1MjExWhcN\n\t\t\t\t\t\tMjYwNDEwMTI1MjExWjCBszELMAkGA1UEBhMCR0IxDjAMBgNVBAgMBURldm9uMREw\n\t\t\t\t\t\tDwYDVQQHDAhQYWlnbnRvbjEcMBoGA1UECgwTU291dGggRGV2b24gQ29sbGVnZTEa\n\t\t\t\t\t\tMBgGA1UECwwRQ29tcHV0ZXIgU2VydmljZXMxHTAbBgNVBAMMFGlkcC5zb3V0aGRl\n\t\t\t\t\t\tdm9uLmFjLnVrMSgwJgYJKoZIhvcNAQkBFhloZWxwZGVza0Bzb3V0aGRldm9uLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAw780rAsk+mJLxAxM\n\t\t\t\t\t\t4AJfvZBzfb4l9Vpu/6BO8Or54rmp/uThhC0mgdoJqQlmaEb4ZIK4/CbfstV8Qo3s\n\t\t\t\t\t\tINiy6Z1+xMVcrBalH9gG6cXB7i1E1vDuUE5gg/qd1KGCwXrVBDKGKF1enpMlOBgQ\n\t\t\t\t\t\tcTHZ2dpTf9Hgjmxcixa030ETpvmDyja86dYnQnkxGpXbIyxJR9h7XlkGXzd/fdP0\n\t\t\t\t\t\tdk45mXkzna05QThcg6SqMlZasi4iyd8UGulWAg7sYBIfxI3Xm88PaTm+KscBCVPu\n\t\t\t\t\t\tMa1WatglA9JIBlQwWantChP7AI9v4YZGG+af6uhp1l8UzXA8EdQL6lCwqvmgGD0F\n\t\t\t\t\t\t1RFX0wIDAQABo3EwbzAfBgNVHREEGDAWghRpZHAuc291dGhkZXZvbi5hYy51azAd\n\t\t\t\t\t\tBgNVHQ4EFgQUivSrY0v+NvStP9sX9z4xYKNpba0wHwYDVR0jBBgwFoAUivSrY0v+\n\t\t\t\t\t\tNvStP9sX9z4xYKNpba0wDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAQEA\n\t\t\t\t\t\tRO80zk8JjZ7UpVODbHxiyAzs1WX4wIoUc8VR6Cpf55/tTUEBhfU1sHggV5J285Xk\n\t\t\t\t\t\tngRf3d+5xcnqO+RjMPn7AXU35ycRofFWsDNtabcWoXK4X6pYrYUAQEsZu/4Q05qJ\n\t\t\t\t\t\tjzxP0lDW16HRN+JJs97Lel95y8tvhyGhc6VTLzwvOMBCTHeWhuPmlzAZmh3w3hLz\n\t\t\t\t\t\tf5rIu2knlPysAdyln9PGl1tRSchcjJhN2K/Bq2xVSCFWmGjZiENHc2yfpwc+z7Xq\n\t\t\t\t\t\tAs5id/Pz62Gwe5qtzQSiWo9G1zkAw2PODKY0rA4JNAvwT9whv2A/Ef8ggRmiJGu6\n\t\t\t\t\t\t9Ia6HkphVIymnefQl1ZO/Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE5DCCA8ygAwIBAgIRANGrqwrzcv/wwtm5h/u2MFkwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzA1MTYwMDAwMDBaFw0xNjA1MTUyMzU5NTlaMIGvMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEQMA4GA1UEERMHVFE0IDdFSjEOMAwGA1UECBMFRGV2b24xETAPBgNV\n\t\t\t\t\t\tBAcTCFBBSUdOVE9OMRIwEAYDVQQJEwlMb25nIFJvYWQxHDAaBgNVBAoTE1NvdXRo\n\t\t\t\t\t\tIERldm9uIENvbGxlZ2UxGjAYBgNVBAsTEUNvbXB1dGVyIFNlcnZpY2VzMR0wGwYD\n\t\t\t\t\t\tVQQDExRpZHAuc291dGhkZXZvbi5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBAM7bII/xHAr1oS3qU/Y+fjfA5zzvRSgLS1pEveCyck9Z1w30Tt8v\n\t\t\t\t\t\tC0NTuLUw6KnjrytWVjWdQJJoRCMI3sjpwFqDC+6js4azlee2AABynMdGzOuJ6GqA\n\t\t\t\t\t\tA8pzDxes/BSio8CxHG/Sp2rglvpDphQLKgzTACTUeooWQ2qhEm9liS5HercXHZnx\n\t\t\t\t\t\tAIZCGpw9ChqhiXAofAENjdBl3kuqHl1gn80j4uN7jtTXKb7Rz6DwsXlc3tl/rT7c\n\t\t\t\t\t\tAr8z0mTllMy09m21rLXae4CaQB/3x7j6HFWeSEcHh6o5iBjWnlmQmQnsXsybIeuz\n\t\t\t\t\t\txqdLKwDhOIqz2hW3MiQX8wCqE5YwGaZtEaMCAwEAAaOCAXEwggFtMB8GA1UdIwQY\n\t\t\t\t\t\tMBaAFAy9k2gM896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBRxOiCSLnFHA2VGV1OX\n\t\t\t\t\t\thbf81QvVgTAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAU\n\t\t\t\t\t\tBggrBgEFBQcDAQYIKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAI\n\t\t\t\t\t\tBgZngQwBAgIwOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5h\n\t\t\t\t\t\tLm9yZy9URVJFTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAC\n\t\t\t\t\t\thilodHRwOi8vY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggr\n\t\t\t\t\t\tBgEFBQcwAYYaaHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwHwYDVR0RBBgwFoIU\n\t\t\t\t\t\taWRwLnNvdXRoZGV2b24uYWMudWswDQYJKoZIhvcNAQEFBQADggEBAKjRYUyCVxuA\n\t\t\t\t\t\tVlPnjOLvXIby4ohy2rqZKc7Co2U6TNDkPMlC+7j48hBsDjGQzpW7l3B6Qktq9Iox\n\t\t\t\t\t\t0i3cS5NQVXL0aeL+4ixSnlX62EeqdAElo7mvUP/VdALPI7FUi0fKXW6JmK+5FH2b\n\t\t\t\t\t\t+5o3pw18AjHX+TylwE0rIwofwNb+TwAPXyv/Iu4fqYL4ZEfwAfIHh9sqmmZdTQfL\n\t\t\t\t\t\tAfbAiyFUkePPuF5fo05C70iZR6GIkmt09g2V8MmQZPwWyl+ar+UK0Xg8uqB5uBC0\n\t\t\t\t\t\t/+1GTST3DkvMiNpzOdE9ryueHBpQ7W5S+JuRbQ7BZUgFxBrbSPmFsCiPCKFmJ3KA\n\t\t\t\t\t\t9a0UDu0T7vU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "South Devon College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.southdevon.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "South Devon College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://nrc-test.literatumonline.com/action/samlACS/shibboleth/testshib/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://nrc-test.literatumonline.com/action/samlACS/shibboleth/testshib/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-11-14T10:59:33Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NRC Research Press Test SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://nrc-test.literatumonline.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://nrc-test.literatumonline.com/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nrc-test.literatumonline.com/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nrc-test.literatumonline.com/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDtTCCAp2gAwIBAgIJALKKItp/j602MA0GCSqGSIb3DQEBBQUAMIGZMQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEUMBIGA1UEBxMLU2FudGEgQ2xh\n\t\t\t\t\t\tcmExHTAbBgNVBAoTFEF0eXBvbiBTeXN0ZW1zLCBJbmMuMR0wGwYDVQQLExRBdHlw\n\t\t\t\t\t\tb24gU3lzdGVtcywgSW5jLjEhMB8GA1UEAxMYd3d3Lm5yY3Jlc2VhcmNocHJlc3Mu\n\t\t\t\t\t\tY29tMB4XDTExMDExODIyMTkyOFoXDTIxMDExNTIyMTkyOFowgZkxCzAJBgNVBAYT\n\t\t\t\t\t\tAlVTMRMwEQYDVQQIEwpDYWxpZm9ybmlhMRQwEgYDVQQHEwtTYW50YSBDbGFyYTEd\n\t\t\t\t\t\tMBsGA1UEChMUQXR5cG9uIFN5c3RlbXMsIEluYy4xHTAbBgNVBAsTFEF0eXBvbiBT\n\t\t\t\t\t\teXN0ZW1zLCBJbmMuMSEwHwYDVQQDExh3d3cubnJjcmVzZWFyY2hwcmVzcy5jb20w\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDcz5rmUAuG5ucWJq6TAKiy\n\t\t\t\t\t\tjdkO5jrOKk+rUFbtvHqCdEy0ndFUraE+sQO4zuRabXKzI6p7sF090VqDi9NZ4Zq0\n\t\t\t\t\t\tuK2m6Wuwkzr5DRstBamZXzUZdFZ/NOQxFIQbhx+ZNVx02IlK89CZmzRzaczqgwtd\n\t\t\t\t\t\tj0IPZY2SpWeZuRfFZ0H6IBI/I5rL+HaokTdZaYgRUasqu7HFdKquN369iP7Qqe7l\n\t\t\t\t\t\tYhm9XtVnEMLsHuPy1gNkyOddLdHKt9oKzKkql7IkhcGbE/f4YrKIqxC5SvdSE9cg\n\t\t\t\t\t\tih+IO/OAyHn+cS0LqNCECRbdnViUgUaSr5/s9FXTTMsEMtJtgZQyEzGW9B9omLhJ\n\t\t\t\t\t\tAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBADcSQSrkKZG/QL6LSKSG8rKB0BxWNFvO\n\t\t\t\t\t\t3mEBndEEsioTZzPGzSfuMcEDdICWyILaXN7HraUkTCvSD1N9n/AS8uu+jCoe+f8z\n\t\t\t\t\t\tcV3f15LjxYyZI9ZmO9eixGA2huK2LsRzAj93TWYK7Q0CuZrTq/3J/vJ+xvM2habG\n\t\t\t\t\t\tPToSEnpA/ALGVSXSxGpLJYn84qX9ub0yX1yYNmleylRkHqFwYHvdU5Hk7UZdrCKZ\n\t\t\t\t\t\tvMIejpaSZn0yf3ZFn8eebCpLnlVN0FLNCgel39FLMGqNbey0wpFbzocv4fvX6pmi\n\t\t\t\t\t\tBz9FTGLHvLqpoRV/zghBPM32BhT8U6PJfC56HlfNfbRtx9nHZK2GfJw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://nrc-test.literatumonline.com/page/about"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "NRC Research Press Test SP"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NRC Research Press Test SP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://idp.uni-duisburg-essen.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sch\u00fcler"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:harald.schueler@uni-duisburg-essen.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Harald"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sch\u00fcler"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:harald.schueler@uni-duisburg-essen.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Harald"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wald"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:burkhard.wald@uni-duisburg-essen.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Burkhard"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wald"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:burkhard.wald@uni-due.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Burkhard"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uni-duisburg-essen.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2009-05-26T08:35:27Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.uni-duisburg-essen.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGZDCCBUygAwIBAgIHGevldPoM5DANBgkqhkiG9w0BAQsFADCBxjELMAkGA1UE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\nBkqqyY3eD4M="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.uni-duisburg-essen.de,O=Universitaet Duisburg-Essen,L=Essen,ST=Nordrhein-Westfalen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.uni-duisburg-essen.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGZDCCBUygAwIBAgIHGevldPoM5DANBgkqhkiG9w0BAQsFADCBxjELMAkGA1UE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\nBkqqyY3eD4M="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.uni-duisburg-essen.de,O=Universitaet Duisburg-Essen,L=Essen,ST=Nordrhein-Westfalen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uni-duisburg-essen.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uni-duisburg-essen.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uni-duisburg-essen.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.uni-duisburg-essen.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uni-duisburg-essen.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uni-duisburg-essen.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uni-duisburg-essen.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uni-duisburg-essen.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uni-duisburg-essen.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uni-duisburg-essen.de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uni-duisburg-essen.de"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider fuer Studenten und Mitarbeiter der Universit\u00e4t Duisburg-Essen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider fuer Studenten und Mitarbeiter der Universit\u00e4t Duisburg-Essen"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e4t Duisburg-Essen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e4t Duisburg-Essen"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.uni-duisburg-essen.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGZDCCBUygAwIBAgIHGevldPoM5DANBgkqhkiG9w0BAQsFADCBxjELMAkGA1UE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\nBkqqyY3eD4M="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.uni-duisburg-essen.de,O=Universitaet Duisburg-Essen,L=Essen,ST=Nordrhein-Westfalen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.uni-duisburg-essen.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGZDCCBUygAwIBAgIHGevldPoM5DANBgkqhkiG9w0BAQsFADCBxjELMAkGA1UE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\nBkqqyY3eD4M="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.uni-duisburg-essen.de,O=Universitaet Duisburg-Essen,L=Essen,ST=Nordrhein-Westfalen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e4t Duisburg-Essen"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e4t Duisburg-Essen"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-duisburg-essen.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-duisburg-essen.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e105"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e105"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp2.kingston.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Grove"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.grove@kingston.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matthew"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Murray"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:k.murray@kingston.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kevin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp2.kingston.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-11-19T09:52:26Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAMevtLbVmUP/KFFW/3IcXK9nAywnMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB4xHDAaBgNVBAMTE2lkcDIua2luZ3N0b24uYWMudWswHhcNMTMxMDA0MTM0\n\t\t\t\t\t\tOTM3WhcNMzMxMDA0MTM0OTM3WjAeMRwwGgYDVQQDExNpZHAyLmtpbmdzdG9uLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAs8keaoCHkhFKCrkW\n\t\t\t\t\t\t43asq9uFNsO9WW15Q4sMFYmAcFnD0VPJbSHrLLxWndapJeGrZhAYl9902GcV0X6Z\n\t\t\t\t\t\ts8pChhLQOf+k4B9YgJHb7xDi0n8h2aXoy5L9wu/ZdRbVgSIbeHIXfxLqJWDLEZGS\n\t\t\t\t\t\t9cIlvO3DYPaTo73GuINf+QVodRSgBSQez/hHJkVyJJWPNgMwHIwKOtNQygEdI/Pu\n\t\t\t\t\t\tPIxNfVwr4HNzb6GU9VlTqGaECeThjTINj189xj/kpEU1ehAl3zYa7jkBOp6FTerP\n\t\t\t\t\t\tKxJm0DLfmLWubtxDNpmQZt0b55riH6GfLHuoXbeJ4x7CriLEZPPNgyCRoKks4pxw\n\t\t\t\t\t\tck9PTQIDAQABo20wazBKBgNVHREEQzBBghNpZHAyLmtpbmdzdG9uLmFjLnVrhipo\n\t\t\t\t\t\tdHRwczovL2lkcDIua2luZ3N0b24uYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0O\n\t\t\t\t\t\tBBYEFDV+wl3i5Jhj1v3GOPpUHyBivPkpMA0GCSqGSIb3DQEBBQUAA4IBAQB5S/6O\n\t\t\t\t\t\tfH0pqKhL80xc8eVdW2uo40WZVb8Za7tkM/DDsHsfgNGk/Xl/cGLzmo2uaURLic3T\n\t\t\t\t\t\tX7FRDCBVWMKZQTyX6VkwFcOGz/emg/xCRGF45i2fRIgRixyrVhPgjT8Ku4Qk8vrE\n\t\t\t\t\t\tvgBQCV5+6dJgZ3oEGT8QFMyEEakKdXEAfAjPrFHpkfox72nvCX4yiuZfGhYHFts1\n\t\t\t\t\t\tJ48JAKw3tFfsTlSBXKsN50tyJSSWEb2JYOKXCiVuPLHF0h5sYEO12dWQIP9dOsJn\n\t\t\t\t\t\toHzU4LOVbqHbO9nk6pB/LsLmpWrpgcx4fjUJQZbLGdEqjMk0Y+LuCoFaTBgGbd5o\n\t\t\t\t\t\ts5LbIFHuwJhAyQv5"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kingston.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.kingston.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.kingston.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2.kingston.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.kingston.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.kingston.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib2-login.kingston.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib2-login.kingston.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib2-login.kingston.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib2-login.kingston.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.kingston.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.kingston.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kingston.ac.uk"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University based in Kingston upon Thames, Greater London"
                  }
                ],
                "logo": [
                  {
                    "text": "https://staffnet.kingston.ac.uk/includes/img/static/kulogo.png",
                    "height": "140",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "140"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kingston University London (Temporary)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAMevtLbVmUP/KFFW/3IcXK9nAywnMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB4xHDAaBgNVBAMTE2lkcDIua2luZ3N0b24uYWMudWswHhcNMTMxMDA0MTM0\n\t\t\t\t\t\tOTM3WhcNMzMxMDA0MTM0OTM3WjAeMRwwGgYDVQQDExNpZHAyLmtpbmdzdG9uLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAs8keaoCHkhFKCrkW\n\t\t\t\t\t\t43asq9uFNsO9WW15Q4sMFYmAcFnD0VPJbSHrLLxWndapJeGrZhAYl9902GcV0X6Z\n\t\t\t\t\t\ts8pChhLQOf+k4B9YgJHb7xDi0n8h2aXoy5L9wu/ZdRbVgSIbeHIXfxLqJWDLEZGS\n\t\t\t\t\t\t9cIlvO3DYPaTo73GuINf+QVodRSgBSQez/hHJkVyJJWPNgMwHIwKOtNQygEdI/Pu\n\t\t\t\t\t\tPIxNfVwr4HNzb6GU9VlTqGaECeThjTINj189xj/kpEU1ehAl3zYa7jkBOp6FTerP\n\t\t\t\t\t\tKxJm0DLfmLWubtxDNpmQZt0b55riH6GfLHuoXbeJ4x7CriLEZPPNgyCRoKks4pxw\n\t\t\t\t\t\tck9PTQIDAQABo20wazBKBgNVHREEQzBBghNpZHAyLmtpbmdzdG9uLmFjLnVrhipo\n\t\t\t\t\t\tdHRwczovL2lkcDIua2luZ3N0b24uYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0O\n\t\t\t\t\t\tBBYEFDV+wl3i5Jhj1v3GOPpUHyBivPkpMA0GCSqGSIb3DQEBBQUAA4IBAQB5S/6O\n\t\t\t\t\t\tfH0pqKhL80xc8eVdW2uo40WZVb8Za7tkM/DDsHsfgNGk/Xl/cGLzmo2uaURLic3T\n\t\t\t\t\t\tX7FRDCBVWMKZQTyX6VkwFcOGz/emg/xCRGF45i2fRIgRixyrVhPgjT8Ku4Qk8vrE\n\t\t\t\t\t\tvgBQCV5+6dJgZ3oEGT8QFMyEEakKdXEAfAjPrFHpkfox72nvCX4yiuZfGhYHFts1\n\t\t\t\t\t\tJ48JAKw3tFfsTlSBXKsN50tyJSSWEb2JYOKXCiVuPLHF0h5sYEO12dWQIP9dOsJn\n\t\t\t\t\t\toHzU4LOVbqHbO9nk6pB/LsLmpWrpgcx4fjUJQZbLGdEqjMk0Y+LuCoFaTBgGbd5o\n\t\t\t\t\t\ts5LbIFHuwJhAyQv5"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Kingston University London (Temporary)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kingston.ac.uk/support/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Kingston University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://medlem.chs.chalmers.se/saml/simplesamlphp/www/module.php/saml/sp/metadata.php/AgeraMedlem",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "S\u00f6lve"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "johan@montania.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Johan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://medlem.chs.chalmers.se/saml/simplesamlphp/www/module.php/saml/sp/metadata.php/AgeraMedlem",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://medlem.chs.chalmers.se/saml/simplesamlphp/www/module.php/saml/sp/saml2-logout.php/AgeraMedlem",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://medlem.chs.chalmers.se/saml/simplesamlphp/www/module.php/saml/sp/saml2-acs.php/AgeraMedlem",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://medlem.chs.chalmers.se/saml/simplesamlphp/www/module.php/saml/sp/saml1-acs.php/AgeraMedlem",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://medlem.chs.chalmers.se/saml/simplesamlphp/www/module.php/saml/sp/saml2-acs.php/AgeraMedlem",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://medlem.chs.chalmers.se/saml/simplesamlphp/www/module.php/saml/sp/saml1-acs.php/AgeraMedlem/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:profiles:holder-of-key:SSO:browser",
              "location": "https://medlem.chs.chalmers.se/saml/simplesamlphp/www/module.php/saml/sp/saml2-acs.php/AgeraMedlem",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://monitor.eduroam.org/sp/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Voncina"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dubravko.voncina@srce.hr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dubravko"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "eduroam-ot@geant.net"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "eduroam operations team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://monitor.eduroam.org/sp/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "hr",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.aaiedu.hr/docs/AAI@EduHr-pravilnik-ver1.3.1.pdf"
              }
            ],
            "registration_instant": "2012-01-01T08:00:00Z",
            "registration_authority": "http://www.srce.hr",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "eduroam"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eduroam.org"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "eduroam"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://monitor.eduroam.org/sp/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://monitor.eduroam.org/sp/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "eduroam supporting services include: eduroam database, CAT, monitoring, F-Ticks"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://monitor.eduroam.org/sp/CoC/privacystatement_en.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "eduroam supporting services"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://monitor.eduroam.org/sp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://monitor.eduroam.org/sp/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://monitor.eduroam.org/sp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://monitor.eduroam.org/sp/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "eduroam supporting services"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "eduroam supporting services include: eduroam database, CAT, monitoring, F-Ticks"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://expert.test.antagning.se/ecs-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.or g/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://expert.test.antagning.se/ecs-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://expert.test.antagning.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://expert.test.antagning.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://expert.test.antagning.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://expert.test.antagning.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://expert.test.antagning.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://expert.test.antagning.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "expert.test.antagning.se"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://expert.test.antagning.se/ecs-sp"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIJAP/aLEQmW3ceMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\nBAMTGGV4cGVydC50ZXN0LmFudGFnbmluZy5zZTAeFw0xNTExMjcxMjU2NTdaFw0y\nNTExMjQxMjU2NTdaMCMxITAfBgNVBAMTGGV4cGVydC50ZXN0LmFudGFnbmluZy5z\nZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM9pMul9mN43TEODXZtC\nHjb6Dl/LWRiAskx7f1Iz+qeN0ZIbT3rzesVJQEiWYdt5eIKaT+bfOm4I4yWpdfSu\neArGSuqF0cQzvYZzbDPTMZn8NttIIAjOrgiHfJEtJWl89DP5yMKzl+koKxjLGDcC\ngRc3Eb7K/2qI2XANigIJbExQs+tTAGQZrwcfkEIpwZbPtsKacz7vJ+5MmsLHwDaX\nMsixCnsY0jJhE0h10VHhtnNKyHanVxGb6sp/G7GEZxV0ICeF7AXgAn2VUAxGRyi/\nNnfMtyFJBrPC1giCNoMXBcHSVtZrZh2FOK9VpkbeEMWzcXnLrBA+Vd6aOoKK+Lc9\niacCAwEAAaNvMG0wTAYDVR0RBEUwQ4IYZXhwZXJ0LnRlc3QuYW50YWduaW5nLnNl\nhidodHRwczovL2V4cGVydC50ZXN0LmFudGFnbmluZy5zZS9lY3Mtc3AwHQYDVR0O\nBBYEFA7p/YrzB+zScGquE9xQYOl+KRBmMA0GCSqGSIb3DQEBBQUAA4IBAQBqt1bE\nQ7Ykq70zh7hWUoiS3OSeEgKbmlNS8qJSwRRMvQEXh97x0v4blrbJr57KS0DfyQhW\ny4UBk0hJOi4BkESy9qoHLsD2iDLhze+T4SldcW8UjJTjCRA4nX/EMOjaZlg/UDGT\nIqI9gDcTJIuot3G8Gq/AqETNO0XKV0Q6fTheqRU/0xTcETWx/6h7La2nm5BRjZBp\niSIW+pE4vGQ4Xw8uwQE7CywtHn0RlCS7rIqiPQJGzEDWPSEvKozCsdf2Lll+Yn52\n902l1p3QqToOEyRdkhAGlvaMjdQELel0a9RhOWYOw/9zV0rC+GYx2i9JE6gLZNr9\nGTcF7jYb6VGkInV0"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=expert.test.antagning.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://expert.test.antagning.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://expert.test.antagning.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://expert.test.antagning.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://expert.test.antagning.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://expert.test.antagning.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://expert.test.antagning.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://expert.test.antagning.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://expert.test.antagning.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://expert.test.antagning.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://endo-test.literatumonline.com/action/samlACS/shibboleth/testshib/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://endo-test.literatumonline.com/action/samlACS/shibboleth/testshib/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-11-19T12:45:11Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Endocrine Society Test SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://endo-test.literatumonline.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://endo-test.literatumonline.com/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://endo-test.literatumonline.com/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://endo-test.literatumonline.com/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIJANVJSQxqshdJMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\n\t\t\t\t\t\tBAMTE3ByZXNzLmVuZG9jcmluZS5vcmcwHhcNMTQwMzE0MDUwMzM2WhcNMTcwMzEz\n\t\t\t\t\t\tMDUwMzM2WjAeMRwwGgYDVQQDExNwcmVzcy5lbmRvY3JpbmUub3JnMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA3UGyo6ttd7bwlzSgZsk1I4RA30LoNfTM\n\t\t\t\t\t\t8gZB/+K39VOI2QD8Pfhrk1WIuQF4GAmVkYE7NklLw5M++OJtX28BXZNYx5B5R4gj\n\t\t\t\t\t\t1pyuhZy5sYFQsV6G2k1juhLXJXD0+AGCuBulYYSgzAAY9Z1nwZ1XQWLscXbaH3PC\n\t\t\t\t\t\tnq8cc14V/bQp6myQPahxIjkzwwGEGvWCWCuRe/gSFFMIMYEX4tnzX1CTf5kHDA6M\n\t\t\t\t\t\tJkTYI6LlyVnT1wNgzjZRZmszyMY5CUK2585Fs5EiOuOyhjpk2yX4wpcyaSMNmg4Z\n\t\t\t\t\t\tw07YKVDZAqs3TPlevvM5v8YsTI8gtmax5xJzmcWLl4ePiWQQIFlmywIDAQABo2kw\n\t\t\t\t\t\tZzBGBgNVHREEPzA9ghNwcmVzcy5lbmRvY3JpbmUub3JnhiZodHRwczovL3ByZXNz\n\t\t\t\t\t\tLmVuZG9jcmluZS5vcmcvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUGmOP9EhvjdoesbPh\n\t\t\t\t\t\tvynbx5uw5vMwDQYJKoZIhvcNAQEFBQADggEBABmbaNUQvxhPvcdkn5bvZuAV5kSf\n\t\t\t\t\t\tFI+va5RzRQ4RJbAhoLMc5rQObPJuJ+5sxhccmihmcxRJRzyfrw+uoNClm6DL3r9F\n\t\t\t\t\t\tFQ0T0/ycfBo9mK04Th6J2UR6k6afdiaucbW4R+LCapQR98FrNGBsTh6YFhhgIRyx\n\t\t\t\t\t\t5OXJvPJAQL+uVkrqQSuxtwNSaz52WyZXjb6mOSMg2+JK4WftBrPYY1XEG0QP4nMt\n\t\t\t\t\t\tqHZa5OSpp+euqH6Gyw0LT/E1wdjIx6VeYk05G7rLd8+pxEPIojYUKfEIzggIDC8J\n\t\t\t\t\t\tPS8Hhs0OkV2+QCImniSi1ZMVhcHp6Db1t2lE9LRnJz2mSTdqqocXb1O5m/s="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIJAIDfY9h2oTCVMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\n\t\t\t\t\t\tBAMTE3ByZXNzLmVuZG9jcmluZS5vcmcwHhcNMTMxMjExMDUzOTQ2WhcNMjMxMjA5\n\t\t\t\t\t\tMDUzOTQ2WjAeMRwwGgYDVQQDExNwcmVzcy5lbmRvY3JpbmUub3JnMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAw2Hn+r9tAA0W/oAXm9ShLD2wvy+YKkeV\n\t\t\t\t\t\tyrmUJbzdU8DeJ0mQ0SS6/Y3yKZEAT6vsh4j4xso51qtly0HHh459F8y8n3vd829B\n\t\t\t\t\t\tvhxRwdE5PMZixPbWyltRPbx3XogpswBust9PXIWW4Unmo37NZhxrZQrt7GHvVvIX\n\t\t\t\t\t\tkuUAEoTkLkSurvgkLuUrPs/wm179D50kbx4E50Uz7nvJYVyEWqHdf3TGaD8gMM1E\n\t\t\t\t\t\t6DR2w0j4pKHBAjkLDy9mHGV6c91qFVNnWrhACmX35JjBiCvc1+JTVRpapM1/JgzP\n\t\t\t\t\t\tHNTCJogvQNn5SDU3cZsZV0T1Bu23Pb8MlXoZPmWJy2djNPzw1JtO6QIDAQABo2kw\n\t\t\t\t\t\tZzBGBgNVHREEPzA9ghNwcmVzcy5lbmRvY3JpbmUub3JnhiZodHRwczovL3ByZXNz\n\t\t\t\t\t\tLmVuZG9jcmluZS5vcmcvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUG3/mbZR4LTuD9+bU\n\t\t\t\t\t\tdU0k7Li0WNkwDQYJKoZIhvcNAQEFBQADggEBAC4Sz/Os31gGbtIPklQ8SJHBs0ji\n\t\t\t\t\t\tMgbcKx15S3OkM06S75oDVI2qIrWXnAuWidexconSD35izsAscXlGI4EJgOflRJIB\n\t\t\t\t\t\t1kD9LOsHiz9kqUS2q7MNxWVloiQzxYCX14HGwPMtmKVTeTg5Vjo2BAuCRAhdxdFH\n\t\t\t\t\t\tseE5nYMbC4i31u1taTsM1Ydifr3UzmWTI5AZ884SYR9TfPh07rcW5m26Pmr3LLOa\n\t\t\t\t\t\twDROxGmfeBQHWTnOJkbhLdE2Rv1MqCWP4XzA1a8PsuBxyboLCQUYxsn4J8hOP3ZN\n\t\t\t\t\t\tb3NsdouxzxBdj+PJxciM9yTP1Ju8l1QfVXC68KZ2WeEowX3e84BW8jaZ0OM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://endo-test.literatumonline.com/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Endocrine Society Test SP"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Endocrine Society Test SP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://perfsonarui.geant.org",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Garnizov"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ivan.garnizov@fau.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ivan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Garnizov"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ivan.garnizov@fau.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ivan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://perfsonarui.geant.org",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-11-24T12:03:05Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "G\u00c9ANT"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.geant.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "G\u00c9ANT Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "response_location": "https://perfsonar.geant.org/perfsonar-ui/saml/LogoutServiceHTTPRedirectResponse",
              "location": "https://perfsonar.geant.org/perfsonar-ui/saml/LogoutServiceHTTPRedirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://perfsonar.geant.org/perfsonar-ui/saml/LogoutServiceSOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "G\u00c9ANT perfSONAR UI - Operations instance"
                  }
                ],
                "logo": [
                  {
                    "text": "https://psui.geant.net/perfsonar-ui/images/PerfSONAR_logo.png",
                    "lang": "en",
                    "height": "31",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "167"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "G\u00c9ANT perfSONAR UI"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFdTCCBF2gAwIBAgIQBruZHycalTIckX3CWVlozDANBgkqhkiG9w0BAQsFADBk\n\t\t\t\t\t\tMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\n\t\t\t\t\t\tQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\n\t\t\t\t\t\tQ0EgMzAeFw0xNTEwMTMwMDAwMDBaFw0xODEwMTcxMjAwMDBaMIGDMQswCQYDVQQG\n\t\t\t\t\t\tEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJQW1zdGVyZGFt\n\t\t\t\t\t\tMRswGQYDVQQKDBJHw4lBTlQgQXNzb2NpYXRpb24xCzAJBgNVBAsTAklUMR4wHAYD\n\t\t\t\t\t\tVQQDExVwZXJmc29uYXJ1aS5nZWFudC5vcmcwggEiMA0GCSqGSIb3DQEBAQUAA4IB\n\t\t\t\t\t\tDwAwggEKAoIBAQDDyMMDtxnR01PgCmtr3WpujJjW9F1GZYOlDfqsTDuZOLuPKOHi\n\t\t\t\t\t\tlcC+9ILMCAyv87oxqxV/m3dtlYUVgzRNqE47sE1JDHCAtitDKwR4wlIKJrTSfU6o\n\t\t\t\t\t\tdY3qnW8Pe6UO3rxPkqMwuMs9/FP3VVbcIeeAyuFfCnwgqljKSp2mgaS3qAc2Raox\n\t\t\t\t\t\tJOKVEAQTO5f4BHI0DdkDct/7Azq+vDpr/nZGmcoG9FLSNHWoAfeP7IQdxpgUeHB/\n\t\t\t\t\t\tJUh12S7lEtDSlMcK1yd/xLrw3Bdyai1FotqpNpoEHV6/AjOy7Hxpf8TYRRc0OYst\n\t\t\t\t\t\t3POtpZBBSKkcH0L07le9gpHYUMYUD94qai/5AgMBAAGjggIBMIIB/TAfBgNVHSME\n\t\t\t\t\t\tGDAWgBRn/YggFCeYxwnSJRm76VERY3VQYjAdBgNVHQ4EFgQUYyZTMUgTRszC2INE\n\t\t\t\t\t\tgJ9GdhuKuqYwUwYDVR0RBEwwSoIVcGVyZnNvbmFydWkuZ2VhbnQub3Jnghh0ZXN0\n\t\t\t\t\t\tLXBlcmZzb25hci5nZWFudC5vcmeCF3VhdC1wZXJmc29uYXIuZ2VhbnQub3JnMA4G\n\t\t\t\t\t\tA1UdDwEB/wQEAwIFoDAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwawYD\n\t\t\t\t\t\tVR0fBGQwYjAvoC2gK4YpaHR0cDovL2NybDMuZGlnaWNlcnQuY29tL1RFUkVOQVNT\n\t\t\t\t\t\tTENBMy5jcmwwL6AtoCuGKWh0dHA6Ly9jcmw0LmRpZ2ljZXJ0LmNvbS9URVJFTkFT\n\t\t\t\t\t\tU0xDQTMuY3JsMEwGA1UdIARFMEMwNwYJYIZIAYb9bAEBMCowKAYIKwYBBQUHAgEW\n\t\t\t\t\t\tHGh0dHBzOi8vd3d3LmRpZ2ljZXJ0LmNvbS9DUFMwCAYGZ4EMAQICMG4GCCsGAQUF\n\t\t\t\t\t\tBwEBBGIwYDAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AuZGlnaWNlcnQuY29tMDgG\n\t\t\t\t\t\tCCsGAQUFBzAChixodHRwOi8vY2FjZXJ0cy5kaWdpY2VydC5jb20vVEVSRU5BU1NM\n\t\t\t\t\t\tQ0EzLmNydDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3DQEBCwUAA4IBAQCNKlpHE86m\n\t\t\t\t\t\tc8nQ+WLe4jfoX+cm0j+Fyff7q/qEIl2g7i23FsYzgEwqziX8+a/u6KU7BJ+k0eMq\n\t\t\t\t\t\tdfenP2+86zrRXjd2clSUmkzowGRs3a5Xrl357+904BgXvxLwV7aJU8rk4Oqm3C4j\n\t\t\t\t\t\tK6m3yuZqjshzRmWkJefVq31C8luP4YN9DNM6WLAXSL3adxxsDUZvs/lvPr9DZ0eX\n\t\t\t\t\t\tktYLRFuIll3n55K0KcGvnPxl/u/pjcYovDvKdbmpoZjumDBBx6DK1xa1bojrVQOu\n\t\t\t\t\t\tESh9mXQAx0OxLyzZVgxntpNQ2qVirQ0TJhTPBY4RDC5xw56vwB18W79l1Ic13noD\n\t\t\t\t\t\tYn/y2E+4DRWc"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFdTCCBF2gAwIBAgIQBruZHycalTIckX3CWVlozDANBgkqhkiG9w0BAQsFADBk\n\t\t\t\t\t\tMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\n\t\t\t\t\t\tQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\n\t\t\t\t\t\tQ0EgMzAeFw0xNTEwMTMwMDAwMDBaFw0xODEwMTcxMjAwMDBaMIGDMQswCQYDVQQG\n\t\t\t\t\t\tEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJQW1zdGVyZGFt\n\t\t\t\t\t\tMRswGQYDVQQKDBJHw4lBTlQgQXNzb2NpYXRpb24xCzAJBgNVBAsTAklUMR4wHAYD\n\t\t\t\t\t\tVQQDExVwZXJmc29uYXJ1aS5nZWFudC5vcmcwggEiMA0GCSqGSIb3DQEBAQUAA4IB\n\t\t\t\t\t\tDwAwggEKAoIBAQDDyMMDtxnR01PgCmtr3WpujJjW9F1GZYOlDfqsTDuZOLuPKOHi\n\t\t\t\t\t\tlcC+9ILMCAyv87oxqxV/m3dtlYUVgzRNqE47sE1JDHCAtitDKwR4wlIKJrTSfU6o\n\t\t\t\t\t\tdY3qnW8Pe6UO3rxPkqMwuMs9/FP3VVbcIeeAyuFfCnwgqljKSp2mgaS3qAc2Raox\n\t\t\t\t\t\tJOKVEAQTO5f4BHI0DdkDct/7Azq+vDpr/nZGmcoG9FLSNHWoAfeP7IQdxpgUeHB/\n\t\t\t\t\t\tJUh12S7lEtDSlMcK1yd/xLrw3Bdyai1FotqpNpoEHV6/AjOy7Hxpf8TYRRc0OYst\n\t\t\t\t\t\t3POtpZBBSKkcH0L07le9gpHYUMYUD94qai/5AgMBAAGjggIBMIIB/TAfBgNVHSME\n\t\t\t\t\t\tGDAWgBRn/YggFCeYxwnSJRm76VERY3VQYjAdBgNVHQ4EFgQUYyZTMUgTRszC2INE\n\t\t\t\t\t\tgJ9GdhuKuqYwUwYDVR0RBEwwSoIVcGVyZnNvbmFydWkuZ2VhbnQub3Jnghh0ZXN0\n\t\t\t\t\t\tLXBlcmZzb25hci5nZWFudC5vcmeCF3VhdC1wZXJmc29uYXIuZ2VhbnQub3JnMA4G\n\t\t\t\t\t\tA1UdDwEB/wQEAwIFoDAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwawYD\n\t\t\t\t\t\tVR0fBGQwYjAvoC2gK4YpaHR0cDovL2NybDMuZGlnaWNlcnQuY29tL1RFUkVOQVNT\n\t\t\t\t\t\tTENBMy5jcmwwL6AtoCuGKWh0dHA6Ly9jcmw0LmRpZ2ljZXJ0LmNvbS9URVJFTkFT\n\t\t\t\t\t\tU0xDQTMuY3JsMEwGA1UdIARFMEMwNwYJYIZIAYb9bAEBMCowKAYIKwYBBQUHAgEW\n\t\t\t\t\t\tHGh0dHBzOi8vd3d3LmRpZ2ljZXJ0LmNvbS9DUFMwCAYGZ4EMAQICMG4GCCsGAQUF\n\t\t\t\t\t\tBwEBBGIwYDAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AuZGlnaWNlcnQuY29tMDgG\n\t\t\t\t\t\tCCsGAQUFBzAChixodHRwOi8vY2FjZXJ0cy5kaWdpY2VydC5jb20vVEVSRU5BU1NM\n\t\t\t\t\t\tQ0EzLmNydDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3DQEBCwUAA4IBAQCNKlpHE86m\n\t\t\t\t\t\tc8nQ+WLe4jfoX+cm0j+Fyff7q/qEIl2g7i23FsYzgEwqziX8+a/u6KU7BJ+k0eMq\n\t\t\t\t\t\tdfenP2+86zrRXjd2clSUmkzowGRs3a5Xrl357+904BgXvxLwV7aJU8rk4Oqm3C4j\n\t\t\t\t\t\tK6m3yuZqjshzRmWkJefVq31C8luP4YN9DNM6WLAXSL3adxxsDUZvs/lvPr9DZ0eX\n\t\t\t\t\t\tktYLRFuIll3n55K0KcGvnPxl/u/pjcYovDvKdbmpoZjumDBBx6DK1xa1bojrVQOu\n\t\t\t\t\t\tESh9mXQAx0OxLyzZVgxntpNQ2qVirQ0TJhTPBY4RDC5xw56vwB18W79l1Ic13noD\n\t\t\t\t\t\tYn/y2E+4DRWc"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://perfsonar.geant.org/perfsonar-ui/saml/SAMLAssertionConsumer",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "index": "1",
              "location": "https://perfsonar.geant.org/perfsonar-ui/saml/SAMLAssertionConsumer",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "false"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "G\u00c9ANT perfSONAR UI - Operations instance"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "G\u00c9ANT perfSONAR UI"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://soasunion.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://soasunion.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-04-09T15:21:15Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SOAS Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://soasunion.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://soasunion.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://soasunion.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://soasunion.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://soasunion.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://soasunion.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://soasunion.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://soasunion.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://soasunion.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://soasunion.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://soasunion.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://soasunion.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://soasunion.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://soasunion.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://test.abertay.unidesk.ac.uk/tas/secure/login/verify",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:is.helpline@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-certs@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Apps Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test.abertay.unidesk.ac.uk/tas/secure/login/verify",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-05T13:27:30Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Test Unidesk - Abertay"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID7TCCAtWgAwIBAgIJAKb90q3jCoX6MA0GCSqGSIb3DQEBCwUAMFcxIzAhBgNV\n\t\t\t\t\t\tBAMTGnRlc3QuYWJlcnRheS51bmlkZXNrLmFjLnVrMSMwIQYDVQQKExp0ZXN0LmFi\n\t\t\t\t\t\tZXJ0YXkudW5pZGVzay5hYy51azELMAkGA1UEBhMCVUswHhcNMTYwNDAxMTIzNTI2\n\t\t\t\t\t\tWhcNMjYwMzMwMTIzNTI2WjBXMSMwIQYDVQQDExp0ZXN0LmFiZXJ0YXkudW5pZGVz\n\t\t\t\t\t\tay5hYy51azEjMCEGA1UEChMadGVzdC5hYmVydGF5LnVuaWRlc2suYWMudWsxCzAJ\n\t\t\t\t\t\tBgNVBAYTAlVLMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAx/g97614\n\t\t\t\t\t\t+AFKYGTwsyWijqMFEU0kqLrP/UsTpCDeJh8quiaBTr38UrLBrovxlItPpkqbIaxP\n\t\t\t\t\t\tlhTxwZHDg13MPqiRNdIKT9woaegI7fwjgKkd497b7nlqvYPkSaVqguz6f5SCBMUn\n\t\t\t\t\t\tYKgyFmCpBq9NEO8vCPOM4rpcYRIkvUeR5MT3pTe3GJvbwiomIlkK/E+ad8h153UD\n\t\t\t\t\t\tqnF+bmmtriP4s5mxDF/2uVP+Rvf43NU7XnNUyWXHusyAH9ENHp6j42kkqGN3uRdE\n\t\t\t\t\t\t6R0Sc0vVvlMT1OIfaJBDa1aoFo/oDyX0nh+346GoShCg01iygTz5C1GC8TPzK7Oo\n\t\t\t\t\t\tFAS3BIQWTLWyqQIDAQABo4G7MIG4MB0GA1UdDgQWBBRXr6CxoOyUDhr0A2Zc91Ee\n\t\t\t\t\t\tHLXkvjCBiAYDVR0jBIGAMH6AFFevoLGg7JQOGvQDZlz3UR4cteS+oVukWTBXMSMw\n\t\t\t\t\t\tIQYDVQQDExp0ZXN0LmFiZXJ0YXkudW5pZGVzay5hYy51azEjMCEGA1UEChMadGVz\n\t\t\t\t\t\tdC5hYmVydGF5LnVuaWRlc2suYWMudWsxCzAJBgNVBAYTAlVLggkApv3SreMKhfow\n\t\t\t\t\t\tDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAQEAlHFolMwX31uyP+qbQFoC\n\t\t\t\t\t\t55phkzHYo5JF6Zamk+v7sqi4mP9JkkbJGhKGz6rNxf2/COFgryc0V+iV0vfggrzO\n\t\t\t\t\t\trOqWOg/hXGVwqF2kLHs520Uk0ZH3U0K1+NvJZHsyqslkgjIQkpzLn7kfVGYp1i6I\n\t\t\t\t\t\tw7Nr6ST2g6ilGlB2D8Jk4JCIxIwuU6cV5XV3Fy4OuWck0oPfOK3zDCCcxSW8wOmw\n\t\t\t\t\t\t/rBBSrt3FfAHM+4WO/YZVIpnKMQikmHRc4wxW8obHYu+Ut4DXWoPoqNBumdBVv/g\n\t\t\t\t\t\tsSw+9Fu2Zto/cMH17ZPL6F/LSnVBWRhfNuGP9+JhGbRqFUtn5AedGAdzwyc9ngfn\n\t\t\t\t\t\tdQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID7TCCAtWgAwIBAgIJAKb90q3jCoX6MA0GCSqGSIb3DQEBCwUAMFcxIzAhBgNV\n\t\t\t\t\t\tBAMTGnRlc3QuYWJlcnRheS51bmlkZXNrLmFjLnVrMSMwIQYDVQQKExp0ZXN0LmFi\n\t\t\t\t\t\tZXJ0YXkudW5pZGVzay5hYy51azELMAkGA1UEBhMCVUswHhcNMTYwNDAxMTIzNTI2\n\t\t\t\t\t\tWhcNMjYwMzMwMTIzNTI2WjBXMSMwIQYDVQQDExp0ZXN0LmFiZXJ0YXkudW5pZGVz\n\t\t\t\t\t\tay5hYy51azEjMCEGA1UEChMadGVzdC5hYmVydGF5LnVuaWRlc2suYWMudWsxCzAJ\n\t\t\t\t\t\tBgNVBAYTAlVLMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAx/g97614\n\t\t\t\t\t\t+AFKYGTwsyWijqMFEU0kqLrP/UsTpCDeJh8quiaBTr38UrLBrovxlItPpkqbIaxP\n\t\t\t\t\t\tlhTxwZHDg13MPqiRNdIKT9woaegI7fwjgKkd497b7nlqvYPkSaVqguz6f5SCBMUn\n\t\t\t\t\t\tYKgyFmCpBq9NEO8vCPOM4rpcYRIkvUeR5MT3pTe3GJvbwiomIlkK/E+ad8h153UD\n\t\t\t\t\t\tqnF+bmmtriP4s5mxDF/2uVP+Rvf43NU7XnNUyWXHusyAH9ENHp6j42kkqGN3uRdE\n\t\t\t\t\t\t6R0Sc0vVvlMT1OIfaJBDa1aoFo/oDyX0nh+346GoShCg01iygTz5C1GC8TPzK7Oo\n\t\t\t\t\t\tFAS3BIQWTLWyqQIDAQABo4G7MIG4MB0GA1UdDgQWBBRXr6CxoOyUDhr0A2Zc91Ee\n\t\t\t\t\t\tHLXkvjCBiAYDVR0jBIGAMH6AFFevoLGg7JQOGvQDZlz3UR4cteS+oVukWTBXMSMw\n\t\t\t\t\t\tIQYDVQQDExp0ZXN0LmFiZXJ0YXkudW5pZGVzay5hYy51azEjMCEGA1UEChMadGVz\n\t\t\t\t\t\tdC5hYmVydGF5LnVuaWRlc2suYWMudWsxCzAJBgNVBAYTAlVLggkApv3SreMKhfow\n\t\t\t\t\t\tDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAQEAlHFolMwX31uyP+qbQFoC\n\t\t\t\t\t\t55phkzHYo5JF6Zamk+v7sqi4mP9JkkbJGhKGz6rNxf2/COFgryc0V+iV0vfggrzO\n\t\t\t\t\t\trOqWOg/hXGVwqF2kLHs520Uk0ZH3U0K1+NvJZHsyqslkgjIQkpzLn7kfVGYp1i6I\n\t\t\t\t\t\tw7Nr6ST2g6ilGlB2D8Jk4JCIxIwuU6cV5XV3Fy4OuWck0oPfOK3zDCCcxSW8wOmw\n\t\t\t\t\t\t/rBBSrt3FfAHM+4WO/YZVIpnKMQikmHRc4wxW8obHYu+Ut4DXWoPoqNBumdBVv/g\n\t\t\t\t\t\tsSw+9Fu2Zto/cMH17ZPL6F/LSnVBWRhfNuGP9+JhGbRqFUtn5AedGAdzwyc9ngfn\n\t\t\t\t\t\tdQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.abertay.unidesk.ac.uk/tas/secure/login/verify",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://idp-dev.bangor.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Williams"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:matthew.williams@bangor.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matthew"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Williams"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:matthew.williams@bangor.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matthew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-dev.bangor.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_instant": "2013-01-10T13:00:11Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAKmysGQnotgkz47fU4wbfPvxaTf1MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB8xHTAbBgNVBAMTFGlkcC1kZXYuYmFuZ29yLmFjLnVrMB4XDTEzMDEwOTE2\n\t\t\t\t\t\tMzY0NVoXDTMzMDEwOTE2MzY0NVowHzEdMBsGA1UEAxMUaWRwLWRldi5iYW5nb3Iu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCA3wF9jL1ckLqJ\n\t\t\t\t\t\t8vWJ9FnW3DT/jytDdHTPcquK/N05Et3RQGxaP5ZQ4ToDej1q9x2cmyhdwnsMVSDJ\n\t\t\t\t\t\tg7kuhbEyrLagh570FxBVPkEcDfho63As2C2a0WUH7d3aNOSMFGRsM+x+5+R1oItl\n\t\t\t\t\t\twcGWGjO40SN+n0POE0lB6CZvWwJXd1rG6xBAXUUMzdkfHrc7lAr4SuC30GXyk+3G\n\t\t\t\t\t\tneGeDNcmOMbsjKhegJV3IC+BbisiZ2el7SM9pLsoRgIcmQN/Wn4mMsZGmXwhl2Da\n\t\t\t\t\t\tlYrulj8U5+L33nzOnSvPZsj4GgtmzEYUzZmswYHgQJcpCQ2zigfwICQx5NHBwi2Q\n\t\t\t\t\t\tnf7TcDjNAgMBAAGjbzBtMEwGA1UdEQRFMEOCFGlkcC1kZXYuYmFuZ29yLmFjLnVr\n\t\t\t\t\t\thitodHRwczovL2lkcC1kZXYuYmFuZ29yLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0G\n\t\t\t\t\t\tA1UdDgQWBBRpMzDTSqUcqggU6NNbFaGjxVxKQzANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tdKnHPvi+VdsbWai4TPQbjRGAoRtgrpSqH+nE0N1mqUGVTC/L8mBeHJEXPJgA7etu\n\t\t\t\t\t\tl7USXan5zL3ZXG/+3fQ+QBU07l3oeatYoit1P1R1c5tJTxR+N5fIpQ12xy1amEWx\n\t\t\t\t\t\tX5EPAaS/y+BXJhAtZnqJi7FqtkfcfHWIsju8GBekUSaeDWSmhO6Jd/9ehr7H6k5r\n\t\t\t\t\t\t0msFJOQWAsi3+KyEtbmjuI8UadcqwBY/9+1Y4exr7G0bZRFJDqO7Yy6d53MhAjVA\n\t\t\t\t\t\t3eN5JibS7UcufNOYFglCndMKbf1xVAJzk8+HIy6qmiRkRuyQu4sbkW5UKUVhZt/N\n\t\t\t\t\t\t8GDE235W9a6OGG3Ho/qA3g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bangor.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-dev.bangor.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-dev.bangor.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-dev.bangor.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-dev.bangor.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-dev.bangor.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-dev.bangor.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-dev.bangor.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-dev.bangor.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-dev.bangor.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-dev.bangor.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-dev.bangor.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bangor.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://www.bangor.ac.uk/shibboleth-logos/bangor-73x59.png",
                    "height": "73",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "59"
                  },
                  {
                    "text": "https://www.bangor.ac.uk/shibboleth-logos/bangor-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Bangor University: Development"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAKmysGQnotgkz47fU4wbfPvxaTf1MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB8xHTAbBgNVBAMTFGlkcC1kZXYuYmFuZ29yLmFjLnVrMB4XDTEzMDEwOTE2\n\t\t\t\t\t\tMzY0NVoXDTMzMDEwOTE2MzY0NVowHzEdMBsGA1UEAxMUaWRwLWRldi5iYW5nb3Iu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCA3wF9jL1ckLqJ\n\t\t\t\t\t\t8vWJ9FnW3DT/jytDdHTPcquK/N05Et3RQGxaP5ZQ4ToDej1q9x2cmyhdwnsMVSDJ\n\t\t\t\t\t\tg7kuhbEyrLagh570FxBVPkEcDfho63As2C2a0WUH7d3aNOSMFGRsM+x+5+R1oItl\n\t\t\t\t\t\twcGWGjO40SN+n0POE0lB6CZvWwJXd1rG6xBAXUUMzdkfHrc7lAr4SuC30GXyk+3G\n\t\t\t\t\t\tneGeDNcmOMbsjKhegJV3IC+BbisiZ2el7SM9pLsoRgIcmQN/Wn4mMsZGmXwhl2Da\n\t\t\t\t\t\tlYrulj8U5+L33nzOnSvPZsj4GgtmzEYUzZmswYHgQJcpCQ2zigfwICQx5NHBwi2Q\n\t\t\t\t\t\tnf7TcDjNAgMBAAGjbzBtMEwGA1UdEQRFMEOCFGlkcC1kZXYuYmFuZ29yLmFjLnVr\n\t\t\t\t\t\thitodHRwczovL2lkcC1kZXYuYmFuZ29yLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0G\n\t\t\t\t\t\tA1UdDgQWBBRpMzDTSqUcqggU6NNbFaGjxVxKQzANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tdKnHPvi+VdsbWai4TPQbjRGAoRtgrpSqH+nE0N1mqUGVTC/L8mBeHJEXPJgA7etu\n\t\t\t\t\t\tl7USXan5zL3ZXG/+3fQ+QBU07l3oeatYoit1P1R1c5tJTxR+N5fIpQ12xy1amEWx\n\t\t\t\t\t\tX5EPAaS/y+BXJhAtZnqJi7FqtkfcfHWIsju8GBekUSaeDWSmhO6Jd/9ehr7H6k5r\n\t\t\t\t\t\t0msFJOQWAsi3+KyEtbmjuI8UadcqwBY/9+1Y4exr7G0bZRFJDqO7Yy6d53MhAjVA\n\t\t\t\t\t\t3eN5JibS7UcufNOYFglCndMKbf1xVAJzk8+HIy6qmiRkRuyQu4sbkW5UKUVhZt/N\n\t\t\t\t\t\t8GDE235W9a6OGG3Ho/qA3g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bangor University: Development"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bangor.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Bangor University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp1.crous-aix-marseille.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dsi.applis@crous-aix-marseille.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp1.crous-aix-marseille.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-02-07T13:50:54Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp1.crous-aix-marseille.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp1.crous-aix-marseille.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp1.crous-aix-marseille.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "crous-aix-marseille.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "crous-aix.net"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.crous-aix-marseille.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Aix Marseille"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Aix Marseille"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkCgAwIBAgIVANHV3Yljs9HRX1MPesiB1HSIAd3wMA0GCSqGSIb3DQEB\nBQUAMCYxJDAiBgNVBAMMG2lkcDEuY3JvdXMtYWl4LW1hcnNlaWxsZS5mcjAeFw0x\nNjAxMTUxMDI3MDlaFw0zNjAxMTUxMDI3MDlaMCYxJDAiBgNVBAMMG2lkcDEuY3Jv\ndXMtYWl4LW1hcnNlaWxsZS5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\nggEBAKT/jV+9II85CSgoeyzsVKFYRy2+Z8FbLpCPTqwoTUYL+Nb2g03GSlEQdWTf\n/zA7rKNhejehIRw2XoMwCz9ZCgCvq8KEg3y9tggjDWDbOsUj41bh+KS3FJyXXRK6\nIenGlZBOYGMV7L/WzJFAdw06PIZy7LB5zlhDXnhiUbUuCyp4zAN0bzulx50DVWew\n1l/tdq65sgBDU2PN574fN2eBIj7oMoEInRl29o8EvFVhUjZFzZ8yPge3LGTtFPzj\niljx5uEpZovjNge/uz1RVJIw9pA6kwUjo0RHbnn/tHo2I4ejkZL2O7AduUmyHG1A\ne+bZFVq0PkMeMIToV8OZOQfFZgECAwEAAaN9MHswHQYDVR0OBBYEFBHxGorsBnH7\nno0HgruWpaHa1jBSMFoGA1UdEQRTMFGCG2lkcDEuY3JvdXMtYWl4LW1hcnNlaWxs\nZS5mcoYyaHR0cHM6Ly9pZHAxLmNyb3VzLWFpeC1tYXJzZWlsbGUuZnIvaWRwL3No\naWJib2xldGgwDQYJKoZIhvcNAQEFBQADggEBADnQeEw81CWJhXDTz0n+OYBxLmPy\nICbCv8gvOCQdSKz5wEFqxevgYCa0JrOvxUZoiOPEf7va3V03bIHUQnSDeXZmwGGl\nOo8JmEtmsFYz+iuHb1+24/YetxiqUt5vueo+rs6FOoHkbhuh2xxvqapB8wemEZVw\ng8WYulOyRJOhgs9LoMHQUiW1yn4yrOzu6ZDkjQbkUPvT/wkpyp/AOSdt5ROL3rNm\niwzInVxg/z31WUgChDtRdAbqK/1eslt/HIgzAt2Bxw8wt8pOAD3nzBLtukAHAzGz\n81f3T9u6PZoh7qU++8NWgS7BuwSgpuCh3zAO9dEW011SnMeGu5RS9/OmP2I="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEgTCCA2mgAwIBAgIQMbkj1D0MR48qNrGSMyNhRzANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDEyNTAwMDAwMFoXDTE2MDEyNTIzNTk1OVowUTELMAkGA1UE\nBhMCRlIxHDAaBgNVBAoTE0NST1VTIEFJWC1NQVJTRUlMTEUxJDAiBgNVBAMTG2lk\ncDEuY3JvdXMtYWl4LW1hcnNlaWxsZS5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBALxxt1r6j1fniB75UijZellhzzPfNZ7WDuHyaSDavJ7cWieuntpN\nLKGdo5Xp+0z89AcOZUSOvuIOZTL11NCE/Dl1Vd2teUL13MFdrOPsrcpaipE6cS2R\nCY+XU4hNSqiBG800YLtyexZ/a3s6qjBOA7pEt9Tu3+xza6i5SGVgiZOrI2Z48JgU\n3N3igIkDGhqsy36McnS5Qf9tpvcBIbacRH/DAw+JroswJwiy4AuSsXQuOdtSPA/d\nG40Jp1pjPb6EZ/u1Wjngc2C7Q9AqM0FirTudcOAhjFfvVKNcOobFsBsw02I2B1CS\nsgtAbC6wn47yKhsjtpCr6sdC4qXoXZ/1HucCAwEAAaOCAW4wggFqMB8GA1UdIwQY\nMBaAFAy9k2gM896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBSvDV2R28Nsq8xjoG+t\nDfdIlnmd8zAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAU\nBggrBgEFBQcDAQYIKwYBBQUHAwIwGAYDVR0gBBEwDzANBgsrBgEEAbIxAQICHTA6\nBgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVO\nQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9j\ncnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpo\ndHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAmBgNVHREEHzAdghtpZHAxLmNyb3Vz\nLWFpeC1tYXJzZWlsbGUuZnIwDQYJKoZIhvcNAQEFBQADggEBAIbtiLL2mvNNc4E8\n8eCNtgwC7uK9WZMS6qm4e2VqUnqoZn/8zxElo8vzbFQ+iIrYN50jO4Wn4HcbLF+B\n9TzWpEjmp7gxYcOG5D/GsugiN8Ha2sC4YfBqRQVFGP6TwSZPQPpI54JtlNvq3Mia\ni0XGkCE5e2h2PunU+SPlgEMhMV+o5mIiobxziZOjaW8avAlu377DXn/HpLysGSjZ\ngU+UAhYM4fdvRn/vr7ri2Fj0HCjUxN+YUWEW3IBLsU5r8OWZpa1o6N+0yFhU5yXm\nHR1USJF9XaGkC+U/bCUzTt/htxLw7uH7D0p69tkpR22dp64YLM0zAYXZem3+zdbb\ny3EJNDw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS Aix Marseille"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.crous-aix-marseille.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS Aix Marseille"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://mds.lan.kth.se/shibboleth",
    {
      "entity_id": "https://mds.lan.kth.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mds.lan.kth.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mds.lan.kth.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mds.lan.kth.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mds.lan.kth.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mds.lan.kth.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://mds.lan.kth.se/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "mds.lan.kth.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDATCCAemgAwIBAgIJAKuJLl2VWSDhMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDm1kcy5sYW4ua3RoLnNlMB4XDTExMTAyNTE0MDMzN1oXDTIxMTAyMjE0MDMz\nN1owGTEXMBUGA1UEAxMObWRzLmxhbi5rdGguc2UwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQD1ZMkEwaMPbixuO7VOmHpZ86vfKMIw5P6AzprpKXLV7m5q\nPFyb3OcK5B8R6iN+uNAE9T4G57G1N0VEQqAdZzOodZRaIypXd8Y6f0PmWPjaptC7\nRCjfyXOEdTeHPBFmJrdkdykF6/jv0zn+BE3wuVCqbULDaHd1l4eBi2Lz7elxVsVX\nrxNDJHG+qRrohbka4tSSCi6yUcSo3Go0Nv7fd5gjidMuqoTK5B0fSfEW5qg8x/Kn\nIrvIFCTlMl81PybL9D/H2uopC8jqWvMkMK8db4P4Ckq96J3KvaIbZyWPmbN0nEgR\n5gwpc7alwRrAOaxit/fB54ps6sR3s7NUwuQcx77zAgMBAAGjTDBKMCkGA1UdEQQi\nMCCCDm1kcy5sYW4ua3RoLnNlhg5tZHMubGFuLmt0aC5zZTAdBgNVHQ4EFgQU0UDQ\niSy3a0gXV/eYtxzIfft90kAwDQYJKoZIhvcNAQEFBQADggEBAHE3lggheqGWhWcS\nO2MECNb8+wKFMS+06ht2j+WJYrqtE73dGdVIwCwkSfT0C0P85NShGCdexaUfzZD6\n4vLqHHfx+zSvJomqkOV0khSte59BsajGET0aa3obgJJaWCjfsgFu840qqKX1sDcD\nmFV1KDcpYhC52EveHBchKQ45ZH/KqKJ4laQy6OkCMQPQolX+KxY8nyJ4J6qACCdY\nA/uj+L0Hs/4CBKkM9kbs0P6oszY0dbWwXLY8+bjZpD0XqZULIkjJixlJ0nQk12uE\nWq6nlMKr18cS90g2FgxclTGMrHuSxPvAdDKGAfO29lzRLGWoCSDLKqIAeajHnRNc\nK4y2OQU="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=mds.lan.kth.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "mds.lan.kth.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDATCCAemgAwIBAgIJAKuJLl2VWSDhMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDm1kcy5sYW4ua3RoLnNlMB4XDTExMTAyNTE0MDMzN1oXDTIxMTAyMjE0MDMz\nN1owGTEXMBUGA1UEAxMObWRzLmxhbi5rdGguc2UwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQD1ZMkEwaMPbixuO7VOmHpZ86vfKMIw5P6AzprpKXLV7m5q\nPFyb3OcK5B8R6iN+uNAE9T4G57G1N0VEQqAdZzOodZRaIypXd8Y6f0PmWPjaptC7\nRCjfyXOEdTeHPBFmJrdkdykF6/jv0zn+BE3wuVCqbULDaHd1l4eBi2Lz7elxVsVX\nrxNDJHG+qRrohbka4tSSCi6yUcSo3Go0Nv7fd5gjidMuqoTK5B0fSfEW5qg8x/Kn\nIrvIFCTlMl81PybL9D/H2uopC8jqWvMkMK8db4P4Ckq96J3KvaIbZyWPmbN0nEgR\n5gwpc7alwRrAOaxit/fB54ps6sR3s7NUwuQcx77zAgMBAAGjTDBKMCkGA1UdEQQi\nMCCCDm1kcy5sYW4ua3RoLnNlhg5tZHMubGFuLmt0aC5zZTAdBgNVHQ4EFgQU0UDQ\niSy3a0gXV/eYtxzIfft90kAwDQYJKoZIhvcNAQEFBQADggEBAHE3lggheqGWhWcS\nO2MECNb8+wKFMS+06ht2j+WJYrqtE73dGdVIwCwkSfT0C0P85NShGCdexaUfzZD6\n4vLqHHfx+zSvJomqkOV0khSte59BsajGET0aa3obgJJaWCjfsgFu840qqKX1sDcD\nmFV1KDcpYhC52EveHBchKQ45ZH/KqKJ4laQy6OkCMQPQolX+KxY8nyJ4J6qACCdY\nA/uj+L0Hs/4CBKkM9kbs0P6oszY0dbWwXLY8+bjZpD0XqZULIkjJixlJ0nQk12uE\nWq6nlMKr18cS90g2FgxclTGMrHuSxPvAdDKGAfO29lzRLGWoCSDLKqIAeajHnRNc\nK4y2OQU="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=mds.lan.kth.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mds.lan.kth.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mds.lan.kth.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mds.lan.kth.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mds.lan.kth.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mds.lan.kth.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://mds.lan.kth.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mds.lan.kth.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://mds.lan.kth.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://mds.lan.kth.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://mds.lan.kth.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-p07.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-p07.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p07.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p07.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p07.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p07.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p07.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-p07.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-p07.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;p07"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;p07"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-p07.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-p07.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQTCCAimgAwIBAgIJALOB0lJK9CHGMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2xhZG9rMy1wMDcubGFkb2sudW11LnNlMB4XDTE1MDIxNjExNDk1NFoXDTI1\nMDIxMzExNDk1NFowIjEgMB4GA1UEAxMXbGFkb2szLXAwNy5sYWRvay51bXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDskb5249mTkvd4IggRNYUZ\nCwmrQlwaa7Q5G80s0sgq+S2i0Sl8Z8k5RHlpKZ5WfpDbOgz1QbT/Oni7qsOYNFXR\nnNJVK1uOYtzcBM0/dRBfwZcONAizRRJxmGMqHRImIlBfJgjx2pRMNKMBb0rAWD27\nojhgkqnhs4L3/oihHJP+AsSOclFljam1fAkFL7ghC0yn/09r+U3rM2SSmyjTthoz\n5xDsRW0PwkzEvP5vzq1g9lVQ+r10P6D0oR/ZM6VTxsN6AMnAD7Sbkbe8/8hBs5Bc\nSg7Md1E4aLFdCkX4e6Y2mWDaxfNLQ4HNmHDLnsNS4BD9tZ2Z7v0wbngtu4sovjmd\nAgMBAAGjejB4MFcGA1UdEQRQME6CF2xhZG9rMy1wMDcubGFkb2sudW11LnNlhjNo\ndHRwczovL2xhZG9rMy1wMDcubGFkb2sudW11LnNlL3N0dWRlbnQtZnJvbnRlbmQt\nc3AwHQYDVR0OBBYEFOAKT12EOY5FFsGrQjyMI911PhIlMA0GCSqGSIb3DQEBBQUA\nA4IBAQC73yldc8ZmgVe0sQxrv81+rWwow4NysfqBWeTp1MeSFPrU3H5STAClLIGY\nDsTHV4uqGYrtAx3JbLPbDBiiqFWfPQXGB9108LjQwHQ6uqfDIw2Suxyk0NBfq/0R\nHnAhS6IdfecrN9VnH2jbhesBOGmp+oXaT5ZkpI7HDWH1J40fFMJumd3z3ESbK8jb\n4l6aGUwn6VH9HPas677+8eH7dDUix8WyG7W8/z7sU0o4eIWF7eNllhyazLJlUMwe\nA8HZgJOutfQBQY9/e2CfVMbEZEu1iVX0n+LnbmxPI2CRfX07E2b85fGYK2EmuNOM\nsjb5y7JZIIlUvTDHyVuJ8+91ZMNg"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-p07.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p07.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p07.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p07.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p07.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p07.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p07.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-p07.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-p07.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-p07.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayf.supportcenter.dk/its/saml2/idp/metadata.php?unit=its",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayf.supportcenter.dk/its/saml2/idp/metadata.php?unit=its",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2010-08-17T14:02:17Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayf.supportcenter.dk/its/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "its.itsf.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ITS (IT-Supportcentret)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ITS (IT Support Centre)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "its.itsf.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfQCAQcwDQYJKoZIhvcNAQELBQAwTDFKMEgGA1UEAwxBaHR0cHM6Ly93\nYXlmLnN1cHBvcnRjZW50ZXIuZGsvaXRzL3NhbWwyL2lkcC9tZXRhZGF0YS5waHA/\ndW5pdD1pdHMwHhcNMTUwMTAxMDAwMDAwWhcNMjUxMjMxMjM1OTU5WjBMMUowSAYD\nVQQDDEFodHRwczovL3dheWYuc3VwcG9ydGNlbnRlci5kay9pdHMvc2FtbDIvaWRw\nL21ldGFkYXRhLnBocD91bml0PWl0czCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBAMeIDApqEFO4jhn4gnWuA54SIILLdtH1Ah7cGkKx6MUJTmtLORYA2pW5\nzU8N+nQl0hmGs9eyYMlAyaJ08IY8gNAqj5uT5p/f4RQVL8j/7fmxIFfa9/6HUMe9\nlX2OzOealJWOnsdn9ag9YHKRYEk7QA5WbMHnOVqqRLfonvr7DF6vB2m4TFWdhI13\nvdL4DJP8Rn61cA77qVDwUv9gyUmdSRJpKotIcXLTUPaoE2ZhHAGkJLr91RnLGLS3\nmPyCEpQPgEc5lVq+frknrZwl1eI5wxHJQAinnsZdCsvrcq2uMhxd12r4JnJnm3fs\nR1Q4jPjaOgVzLvcwU6e3KeUoS87DUEkCAwEAATANBgkqhkiG9w0BAQsFAAOCAQEA\nheUfrZESXEiz40IWaeF5vnTzvrFcd6zSOsiaRWdN6qMa+0JDI4xp76P3YQ5g0XVO\nL61m7aUWclZ8ILo0QtvR9euykgrFZ4H1wkgUhs6JRP8rNWPVP3imrHmU+xaSiZcs\nqR6wNw5pQX8rykuptisWFQVopq3Du9HCbb3ClLmN2dU3IUQPZfwC0r5/BadYfXOb\nMKVUZ2RE+jkQ8jtb6iOdmhrhnDA0b169kCEfiZ5fw8iQ+dKin3YR0AH8f1IYZFsp\nae3/3F5L11KytokdEk+bBLWN3GkRKr0QAvu3V3YImPSI30fNBWLNp0PwDX+q77cy\nYWDGqSgnwi1H313Tol8U/A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ITS (IT-Supportcentret)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ITS (IT Support Centre)"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.it-supportcentret.dk/Sider/ITS.aspx"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.it-supportcentret.dk/Sider/ITS.aspx"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ITS (IT-Supportcentret)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ITS (IT Support Centre)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://cafe.on.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "luisriera"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "luisriera@on.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.on.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDwDCCAqgCAQAwDQYJKoZIhvcNAQEFBQAwgaUxIzAhBgNVBAoTGk9OIC0gT2Jz\nZXJ2YXRvcmlvIE5hY2lvbmFsMQ0wCwYDVQQLEwREVElOMRswGQYJKoZIhvcNAQkB\nFgxrYW50ZXJAb24uYnIxFzAVBgNVBAcTDlJpbyBkZSBKYW5laXJvMRcwFQYDVQQI\nEw5SaW8gZGUgSmFuZWlybzELMAkGA1UEBhMCQlIxEzARBgNVBAMTCmNhZmUub24u\nYnIwHhcNMTQwMzEwMTgxMDEwWhcNMTcwMzA5MTgxMDEwWjCBpTEjMCEGA1UEChMa\nT04gLSBPYnNlcnZhdG9yaW8gTmFjaW9uYWwxDTALBgNVBAsTBERUSU4xGzAZBgkq\nhkiG9w0BCQEWDGthbnRlckBvbi5icjEXMBUGA1UEBxMOUmlvIGRlIEphbmVpcm8x\nFzAVBgNVBAgTDlJpbyBkZSBKYW5laXJvMQswCQYDVQQGEwJCUjETMBEGA1UEAxMK\nY2FmZS5vbi5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMROHVXk\nEXBIpMbnBW0YSLczCP9rKrGpzhXvP/TmLy+cB/XPdsqEewNT+jCXrqDANL4qR2KL\nyPC2XS/ce+heyQG8aFgFuoyWSkupef9HR5LLq7NX5kvFG/iiYcJa0RGBn23rUudR\nMLP1HFn50htCjDbPV6zSyxt29J+8otWdoc7KeHOd50hq1Wcr+OdxyTQV4nXCxWsq\n6yy9mGg4SFo3csLepNs2IRI75uW+Wwq/zYRvvYJ2iBXC1Pcqw/xpAEepzquMJQQr\nhycQHBeSlmeNig7KRmX/gzTokaifcyXzz8inwvMSrSskkZEvuXO8j9H5QwAknfi2\nH8++d0LMUYaz5isCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAcY1w75rvSUZcTZq0\nMZvWHdSUhkE0RTbJgVVEiMOZMe/IViFNzh4RVFH3KWd/dOI9TL+hQLQ9MqdRCsvO\n+9cj0vzf+0w8ZDbNB9EnSSRYFGSiYUilmZkPsK3FbuzsHgPFQRz4BJTvcu5WeJFH\nTFVaH7ESNc1aH+i7L8sApWBcJgpULtmdaIzK9Ipqva+5MLaCVKqU4vyhXfLg9LUa\nEdrSKYPZgsPA2cXQrKTg2BGpAE0cjEzQGh5L29JEpEixQjVLIaM2cLzEVpafZFc/\nmZGQjPivv0WXt2G/6594Gt3zwARJoqiPVGV7ppz8jQX5oQCVfSGXh4ztJsJYZLzM\nmncIMA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "on.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.on.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.on.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.on.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.on.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.on.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.on.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.on.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.on.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "on.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.on.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.on.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ON - Observatorio Nacional"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ON - Observatorio Nacional"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ON - Observatorio Nacional"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ON - Observatorio Nacional"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDwDCCAqgCAQAwDQYJKoZIhvcNAQEFBQAwgaUxIzAhBgNVBAoTGk9OIC0gT2Jz\nZXJ2YXRvcmlvIE5hY2lvbmFsMQ0wCwYDVQQLEwREVElOMRswGQYJKoZIhvcNAQkB\nFgxrYW50ZXJAb24uYnIxFzAVBgNVBAcTDlJpbyBkZSBKYW5laXJvMRcwFQYDVQQI\nEw5SaW8gZGUgSmFuZWlybzELMAkGA1UEBhMCQlIxEzARBgNVBAMTCmNhZmUub24u\nYnIwHhcNMTQwMzEwMTgxMDEwWhcNMTcwMzA5MTgxMDEwWjCBpTEjMCEGA1UEChMa\nT04gLSBPYnNlcnZhdG9yaW8gTmFjaW9uYWwxDTALBgNVBAsTBERUSU4xGzAZBgkq\nhkiG9w0BCQEWDGthbnRlckBvbi5icjEXMBUGA1UEBxMOUmlvIGRlIEphbmVpcm8x\nFzAVBgNVBAgTDlJpbyBkZSBKYW5laXJvMQswCQYDVQQGEwJCUjETMBEGA1UEAxMK\nY2FmZS5vbi5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMROHVXk\nEXBIpMbnBW0YSLczCP9rKrGpzhXvP/TmLy+cB/XPdsqEewNT+jCXrqDANL4qR2KL\nyPC2XS/ce+heyQG8aFgFuoyWSkupef9HR5LLq7NX5kvFG/iiYcJa0RGBn23rUudR\nMLP1HFn50htCjDbPV6zSyxt29J+8otWdoc7KeHOd50hq1Wcr+OdxyTQV4nXCxWsq\n6yy9mGg4SFo3csLepNs2IRI75uW+Wwq/zYRvvYJ2iBXC1Pcqw/xpAEepzquMJQQr\nhycQHBeSlmeNig7KRmX/gzTokaifcyXzz8inwvMSrSskkZEvuXO8j9H5QwAknfi2\nH8++d0LMUYaz5isCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAcY1w75rvSUZcTZq0\nMZvWHdSUhkE0RTbJgVVEiMOZMe/IViFNzh4RVFH3KWd/dOI9TL+hQLQ9MqdRCsvO\n+9cj0vzf+0w8ZDbNB9EnSSRYFGSiYUilmZkPsK3FbuzsHgPFQRz4BJTvcu5WeJFH\nTFVaH7ESNc1aH+i7L8sApWBcJgpULtmdaIzK9Ipqva+5MLaCVKqU4vyhXfLg9LUa\nEdrSKYPZgsPA2cXQrKTg2BGpAE0cjEzQGh5L29JEpEixQjVLIaM2cLzEVpafZFc/\nmZGQjPivv0WXt2G/6594Gt3zwARJoqiPVGV7ppz8jQX5oQCVfSGXh4ztJsJYZLzM\nmncIMA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ON - Observatorio Nacional"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ON - Observatorio Nacional"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.on.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.on.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ON - Observatorio Nacional"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ON - Observatorio Nacional"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.irstea.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "federation.contact@lists.irstea.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.irstea.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-09-17T15:52:14Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.irstea.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.irstea.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.irstea.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "irstea.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.irstea.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IRSTEA - Institut national de recherche en sciences et technologies pour l'environnement et l'agriculture"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IRSTEA - Institut national de recherche en sciences et technologies pour l'environnement et l'agriculture"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAINKG8UKonnXc9QRha4KV5urgO0WMA0GCSqGSIb3DQEB\nBQUAMBgxFjAUBgNVBAMTDWlkcC5pcnN0ZWEuZnIwHhcNMTMwNDExMDkxMDE3WhcN\nMzMwNDExMDkxMDE3WjAYMRYwFAYDVQQDEw1pZHAuaXJzdGVhLmZyMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAjoVm6ET1G+LU/Bs+d24QZXmBDqxgmcmb\nj4TtylC1j9nsS6eo3hiiMewADQqRCeilde/NB2lO4WNtEwSopYDVN+qQBJXLeyIH\nnxMSDhjofcuYOLrvKEC68r5wksj4ASgdNZH26w682vmyCQK1BXM+BnDgK+8JVQYM\nfxaEhUZVqK+mKeFlKuIloGX8vqMYSR+9933ZaBgg6tRy7x1f8HXGKlJOHqfyonni\nNFLrODFiQ7iYzCO3Re+tMW7fGYT0vWBvI3ONlPWZOCcLD1T1+uVk6s4gyAm1loPS\nkUCQ4U8AyR7ai3BiQ2FJo9nL0M1dk4wa3ww/mq7M9z5A9YD32dS18QIDAQABo2Ew\nXzA+BgNVHREENzA1gg1pZHAuaXJzdGVhLmZyhiRodHRwczovL2lkcC5pcnN0ZWEu\nZnIvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFMZx2MPfMr2fV2uFJRTLZdgetgkN\nMA0GCSqGSIb3DQEBBQUAA4IBAQAmUhJ+9NVBiJS/bTle1Kbq3FU2JgpaCiTMu/Hi\nM1tKHcXGleAryzUX/yHazsFYGtGQ0XyWWdbbkc0J194/6tDxHqm6nEblm2kdGEoc\n5owRFCbVwCaTMt7NflbYQJC1EPdsMycyEw39WMx/Pk9bEAxItQaogAA9y+V0n/Mp\nzs1YMK99JgGR3A7GKIoZGi5pOgWL10ugmSPEYG7wQZwcX+S9px4BGzxJ1sgMqxyU\nekqCqNunsUWxdTSksZHzVPhHOoRpnOvy2B8CI6XDJo7D7iHhGki66kUsGuHMd/1I\n7CnuMGR/VZ7zf1lkTbIVv4J+xugV9IYQOb/hnoai7lHX658a"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IRSTEA - Institut national de recherche en sciences et technologies pour l'environnement et l'agriculture"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.irstea.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IRSTEA - Institut national de recherche en sciences et technologies pour l'environnement et l'agriculture"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://school.c2kni.net/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Boyle"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:joe.boyle@capita.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Joe"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Boyle"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:joe.boyle@capita.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Joe"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://school.c2kni.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-10-21T11:52:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVALsvx6NLIdhUhxT9mKREB6ksXTLJMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB8xHTAbBgNVBAMTFHNoaWJib2xldGguYzJrbmkubmV0MB4XDTEwMDgxMjEw\n\t\t\t\t\t\tMzcxN1oXDTMwMDgxMjEwMzcxN1owHzEdMBsGA1UEAxMUc2hpYmJvbGV0aC5jMmtu\n\t\t\t\t\t\taS5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCkD+gWZlQqFrJB\n\t\t\t\t\t\tyQRfAA7lP5L4bJeiiOEsvjG7LaA3/ZqcA+g8q+FScODRcyX/5OEU/Q1x82xrNAQw\n\t\t\t\t\t\tcCW0t5m/VaA2aRmxn0eVt9hZop9BtBhhMMALLmh8eYKz8udoO0QNpaYmFVSFoPiL\n\t\t\t\t\t\tUSj+wSmPPkFQZefSDtog6FD0SrAHQw91okx8ng4Zg3MoJtFQ0/V/F/wFMK7YjGYj\n\t\t\t\t\t\theTrgBsMYiJf3Oc0YQclckjhdp5j/t553IttizOY1tXEmapAfpiosxVDPClbfBBK\n\t\t\t\t\t\tAu/qIEF2Gq2yPRIIm+vlujmmW9eaeo1bEqk6J2z8/umD7gkzDBErFve/537oX8di\n\t\t\t\t\t\tcusmQfeFAgMBAAGjbzBtMEwGA1UdEQRFMEOCFHNoaWJib2xldGguYzJrbmkubmV0\n\t\t\t\t\t\thitodHRwczovL3NoaWJib2xldGguYzJrbmkubmV0L2lkcC9zaGliYm9sZXRoMB0G\n\t\t\t\t\t\tA1UdDgQWBBRfggaNcJ76bEhFucG0h3JafiQA5DANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tHaRM+/rYecDWHpBrYykfl91MAJFE2T4OTCW719CpNh8zG51/AFavDS6Nopm8qibi\n\t\t\t\t\t\tQjOehBpYlFdtyON8kkcMEKdikR9BW8mnpE8rP581hkfQl47IxX1ckbS5wD9EScWf\n\t\t\t\t\t\tuKCraaUUkwQ4eSGQwrpkMyKMGaW7irCowInKdiOwvb3AwRQQnpHmrTR7NeoYlWEh\n\t\t\t\t\t\teuSkfjxXVLnVBwu/4sXAV5NiZCkjNnvTE+jfqI+bYtH/7EI9Q2rn5vdwfTstN7Px\n\t\t\t\t\t\troZivJRxgHW76yyE9ASsrzLz3eL4rlbGNK4LCSyWO7I7wsKT0a4XHK3GW/mI5VAS\n\t\t\t\t\t\tSnrH9o8dANbP72exZm5mEg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "c2kni.net"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.c2kni.net:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.c2kni.net:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.c2kni.net/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.c2kni.net/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.c2kni.net/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.c2kni.net/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.c2kni.net:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.c2kni.net:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "c2kni.net"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVALsvx6NLIdhUhxT9mKREB6ksXTLJMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB8xHTAbBgNVBAMTFHNoaWJib2xldGguYzJrbmkubmV0MB4XDTEwMDgxMjEw\n\t\t\t\t\t\tMzcxN1oXDTMwMDgxMjEwMzcxN1owHzEdMBsGA1UEAxMUc2hpYmJvbGV0aC5jMmtu\n\t\t\t\t\t\taS5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCkD+gWZlQqFrJB\n\t\t\t\t\t\tyQRfAA7lP5L4bJeiiOEsvjG7LaA3/ZqcA+g8q+FScODRcyX/5OEU/Q1x82xrNAQw\n\t\t\t\t\t\tcCW0t5m/VaA2aRmxn0eVt9hZop9BtBhhMMALLmh8eYKz8udoO0QNpaYmFVSFoPiL\n\t\t\t\t\t\tUSj+wSmPPkFQZefSDtog6FD0SrAHQw91okx8ng4Zg3MoJtFQ0/V/F/wFMK7YjGYj\n\t\t\t\t\t\theTrgBsMYiJf3Oc0YQclckjhdp5j/t553IttizOY1tXEmapAfpiosxVDPClbfBBK\n\t\t\t\t\t\tAu/qIEF2Gq2yPRIIm+vlujmmW9eaeo1bEqk6J2z8/umD7gkzDBErFve/537oX8di\n\t\t\t\t\t\tcusmQfeFAgMBAAGjbzBtMEwGA1UdEQRFMEOCFHNoaWJib2xldGguYzJrbmkubmV0\n\t\t\t\t\t\thitodHRwczovL3NoaWJib2xldGguYzJrbmkubmV0L2lkcC9zaGliYm9sZXRoMB0G\n\t\t\t\t\t\tA1UdDgQWBBRfggaNcJ76bEhFucG0h3JafiQA5DANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tHaRM+/rYecDWHpBrYykfl91MAJFE2T4OTCW719CpNh8zG51/AFavDS6Nopm8qibi\n\t\t\t\t\t\tQjOehBpYlFdtyON8kkcMEKdikR9BW8mnpE8rP581hkfQl47IxX1ckbS5wD9EScWf\n\t\t\t\t\t\tuKCraaUUkwQ4eSGQwrpkMyKMGaW7irCowInKdiOwvb3AwRQQnpHmrTR7NeoYlWEh\n\t\t\t\t\t\teuSkfjxXVLnVBwu/4sXAV5NiZCkjNnvTE+jfqI+bYtH/7EI9Q2rn5vdwfTstN7Px\n\t\t\t\t\t\troZivJRxgHW76yyE9ASsrzLz3eL4rlbGNK4LCSyWO7I7wsKT0a4XHK3GW/mI5VAS\n\t\t\t\t\t\tSnrH9o8dANbP72exZm5mEg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "C2k (Western Education Library Board)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.c2kni.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Western Education and Library Board"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://inacademia.org/metadata/t01-p-test.xml",
    {
      "entity_id": "https://inacademia.org/metadata/t01-p-test.xml",
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Enduser Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@inacademia.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "InAcademia"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrative Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "admin@inacademia.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "InAcademia"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Technical Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tech@inacademia.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "InAcademia"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "InAcademia"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://inacademia.org/about"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "InAcademia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://op.srv.inacademia.org/disco",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://inacademia.org/about"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "InAcademia.org - TEST"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The InAcademia Simple validation Sevice allows for the easy validation of affiliation (Student, Faculty, Staff) of a user in Academia. This is a TEST instance"
                  }
                ],
                "logo": [
                  {
                    "text": "https://inacademia.org/static/logo.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "120"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://inacademia.org/about/privacy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "inacademia.org"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFaTCCA1GgAwIBAgIJAOVIW1ydZNQHMA0GCSqGSIb3DQEBCwUAMEsxCzAJBgNV\nBAYTAlNFMQ4wDAYDVQQKDAVTVU5FVDETMBEGA1UECwwKaW5BY2FkZW1pYTEXMBUG\nA1UEAwwOaW5BY2FkZW1pYS5vcmcwHhcNMTUwNjEyMTM0MzU5WhcNMTUwNzEyMTM0\nMzU5WjBLMQswCQYDVQQGEwJTRTEOMAwGA1UECgwFU1VORVQxEzARBgNVBAsMCmlu\nQWNhZGVtaWExFzAVBgNVBAMMDmluQWNhZGVtaWEub3JnMIICIjANBgkqhkiG9w0B\nAQEFAAOCAg8AMIICCgKCAgEAwC/WmT5QKjdIy5hKwF0XctJOQrr2OZzss/BqyOva\npWcYq4zOu4APJuVXlEpfra2n/Kkm95pv+pa2mJj5ikrVBVTU8lmd+5hIRm9qesHx\na3daG89yPteYwszePVd1Gml1FJOdlK6Vaf9YpV10AlnjYpZEAY/EFy876ZRjFT6E\nMD65UCrfxNnbxSjf42ulptymrDsn4p2ZdvUN9VZiXHqlnEmL11A1S/b5ShMCUH+2\nvMUAV3qHc0h1eD2FB+uP3ONb6dOdrs7V17Vi07aDAPq4OSk2adw1/UEIle6TOA3J\nJNEydkbJFccEmT0uLJrVuM1TEWoSQL6tHH/WOYTgBxBDL/x1e/byY/csCQKHpYF8\nJ6jnQUkLojr9IcxuGsPN0j46QGj+VlHq2joMzsdMP+qQY1DWEDP2c8dGLUfWG/wy\nzFQT8z2CcKbO7ePVoQRkEfAvekVSmX8kJxYEqlW1K4tWXdN6mfam01n2Crj0CTDr\n4BpqJEcw2SivkI0FxTi2my4BJnLl0dDQ6p4WhB2bsj5KgnOyUwq1T4BY+XSAIy6K\nFKLvjSyxqUQdNLb09pjscO28p4P2ICYl7TdKvmllFmmPxkMrYeUeL2VdrQ6A9rEg\n/hlprvwoowo6LgObCVEgxkojZ1CBnFHndnN8kkIZar/IlMTA6OrR8cjdLhC/oRRs\nmY0CAwEAAaNQME4wHQYDVR0OBBYEFK0CO9FDN5y7R7fsf+3piTjdgYQsMB8GA1Ud\nIwQYMBaAFK0CO9FDN5y7R7fsf+3piTjdgYQsMAwGA1UdEwQFMAMBAf8wDQYJKoZI\nhvcNAQELBQADggIBAFKsxMDRmpngSaQxraFbX9gnwnpoCjUazs3rRaptn3zPWERR\nNIDyO49xRxYIDPSG/FnHsvR5FJAzWR18j/e1NiZFYcLVGjXcqIJbEZh8tnqFKLDZ\nJ04r8keCSEnxHGOyMzUrvdSiY8+P6iSXdym6+v9nHisaZR8YzM1vJjiZX+aZZPeh\nSBRvpY1ag3g5yzZN9AkDtx3BckFmw+41JwiRevc7d7ePaEBZUNtgVocu38sBR+EZ\naXK1uOqUAc+9fVBHjF6TYLt3vi2qQREo/EFM2rqtsXq2THaGxXYZ6e0CoxTB44w8\nP/AGUmZ8NitlCHVXJsChzg4VvlKuZcXhcxJKrusxKR6fV/qAF5p87se3a7eRQPXi\nrnbGUa1rg/0BStM8Skt3r/72lnBnfMPyclWOgC6lGsnsE+RRAjhWveN3mMa1BP+J\n50CXKvfQ+J/Y1MycXCx/fuT1zDrMMgOAb5zZRUVfqseg9VjA5sflmSTo2TWHD4XY\ncW2UvyMopt49CyWT7TzVNACjY1H8DI22rZtBfBvMYIgCx7+ROCURerVct9qmAOZl\nr5xDQglUD/qMe+0guM4L7bSQsfirlfaySMulUL6uw16AzsVGNBayaFUxDck8S1Na\nOyAi2+3zJled9np2rxthyGEms4wOwEwziFgWzHdWhO+ySrtp9vtSFjJMpRfg"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://op.srv.inacademia.org/acs/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://op.srv.inacademia.org/acs/redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "InAcademia.org - TEST"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The InAcademia Simple validation Service allows for the easy validation of affiliation (Student, Faculty, Staff) of a user in Academia. This is a TEST instance"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "edupersonaffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schachomeorganization",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "edupersontargetedid",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "edupersonprincipalname",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "http://login.ewu.edu/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jgasper@ewu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Gasper"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jgasper@ewu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Gasper"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://login.ewu.edu/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.ewu.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.ewu.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.ewu.edu/adfs/services/trust/artifactresolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ewu.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://access.ewu.edu/OIT/Services/Accounts-Passwords.xml"
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.ewu.edu/adfs/ls/images/ewulogo.jpg",
                    "lang": "en",
                    "height": "150",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "180"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.ewu.edu/Privacy-Policy.xml"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Eastern Washington University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC1jCCAb6gAwIBAgIQd9rja1Yw76hDOrEcTgUaqjANBgkqhkiG9w0BAQsFADAn\nMSUwIwYDVQQDExxBREZTIFNpZ25pbmcgLSBsb2dpbi5ld3UuZWR1MB4XDTE1MDky\nNjA0Mjk1NFoXDTE4MDkyNTA0Mjk1NFowJzElMCMGA1UEAxMcQURGUyBTaWduaW5n\nIC0gbG9naW4uZXd1LmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAJlwoqZvoaDYYE126gexaaXDYzuCDgmEq2B7UcPkdqFj1+oyCi1cGEw0h5yGBMAH\nJrtVbEKeM0RdiqMN/AWllVv2T9BsgUpiUmtkUGmSXr2wwHHC8UgmOrImd8o9DVm8\n6dvIyHnP4o48XdrAO5BOKdJyQgImDrhoidnMUxc42M+FbqT9nE1NvkDsnU6YeikD\nf65YVGJJhNgfYFlQ4unuCVMULQZ98yULxg3oNcg4aCey7/8p2ERB2Xe3LjPY8d2F\nJN0k75y95uy8jdFKpXEQTHAoHiT9l7ehJ4KYofx+glZNAEwTSSamxJPUz0FTwbPo\nTrxiZVv2qrhJ2Cy3TdbZlokCAwEAATANBgkqhkiG9w0BAQsFAAOCAQEAeQ73+koV\naq6FAWu+khGXjPSwRz7uNrEtfpQGNOY4t6D+paPBzi+IVGEN4oFR+3Xe3C4NIvyF\nwxk8ZhmHS9fxj1zoCNwfFwOU8rMimSxXswymyL04p7pvlXBeN/YFvj1RZTf6z0dW\nhMG8no7o/nkEiE3u2FeY9naUSUGFrnPXy8aI4BlPZqwj2lt6GRK2aEQX5QXDetyr\nsD++gFMNaUppLhyZE5sFBNYW0OuQLXTRsbY7b6o+7hhlNf+fJay3rEEiWCt80xKP\nXttampjZghUiB3nh4nQRLIIL8C/zUoCRJGKZGa7Um7hRBUH+NbeNMuRur7nLHqMC\nW9q2bbNngsgQ2w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Eastern Washington University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ewu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eastern Washington University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.figsh.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gavrila"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:danielduduta@figshare.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Daniel"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gavrila"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:danielduduta@figshare.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Daniel"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.figsh.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-03-26T09:14:18Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "figshare stage SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://figshare.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Figshare LLP"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.figsh.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.figsh.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.figsh.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.figsh.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.figsh.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Cloud based repository for citable and discoverable research outputs"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "figshare - stage"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://login.figsh.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://login.figsh.com/Shibboleth.sso/DS-Tuakiri",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://login.figsh.com/Shibboleth.sso/DS-Tuakiri",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://login.figsh.com/Shibboleth.sso/DS-AAF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://login.figsh.com/Shibboleth.sso/DS-AAF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://login.figsh.com/Shibboleth.sso/DS-UKF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://login.figsh.com/Shibboleth.sso/DS-UKF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAINH4QeRdG4MMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\n\t\t\t\t\t\tBAMTD2xvZ2luLmZpZ3NoLmNvbTAeFw0xNTAyMjIxNDU2NDBaFw0yNTAyMTkxNDU2\n\t\t\t\t\t\tNDBaMBoxGDAWBgNVBAMTD2xvZ2luLmZpZ3NoLmNvbTCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBAN4JujY6Et1TBjl+Gs1z+3BxD5cgVnAO/o6DtunEQOob\n\t\t\t\t\t\tiPIjcjNPdh4zl6t1Z3J0aEFZBXGh9RJHXiGNzEFVFSldEqrczeRTKoC11yq4bFjl\n\t\t\t\t\t\tf/j+XUSafGgeQ5QslogIWzJ9saMisxdjFA/BUdQuMjleP+1sSQuVtScRU8KuIMN3\n\t\t\t\t\t\tj7RLgBLWqZjelCno33PBPeRGxShiPay7YbKrWXuYssqIvxQMlxqlFOlI/2sIdEWT\n\t\t\t\t\t\t6Y3UsPJIDDg+SrdZU1x7QMqyMrFmcJVzpu5pjvYp9zm1ywsk0A6rwWhUaqMG7Rtu\n\t\t\t\t\t\toDoKrVHiGs5QbY0bA4nduceY46GPZt5QLhKKLgPrdNkCAwEAAaM9MDswGgYDVR0R\n\t\t\t\t\t\tBBMwEYIPbG9naW4uZmlnc2guY29tMB0GA1UdDgQWBBTNUtGl6wNFgCRqbBJqQKeT\n\t\t\t\t\t\tEA79fTANBgkqhkiG9w0BAQUFAAOCAQEAYTfYrBPburtuPTubqjRRtOGkDu1cvFbs\n\t\t\t\t\t\tFtNK3COaBxomvaZOat/wpzKCvJYV1mZoANfjFsvudtrrwCRMxycO+qkB6B5iKk6i\n\t\t\t\t\t\teSuOrsAn4aOWw10NKrWn42t9sFg+MquYT0kE78U1nacmux8h+tcn+58Ng7oXZ5ZM\n\t\t\t\t\t\twkFx+mODdCJRsFtPTFcjMZsh9kKOKn39vmE+gir7H1Uq7sNKiyyOhJcseE6JmoHn\n\t\t\t\t\t\tX1Qnl4KpMY0bpGcnwMCRsptHxx/+dRKnli92HoZu814RTjBDYocFLfig8+i6tN3h\n\t\t\t\t\t\tj9He1kO/aRDrQ+eJ+ussgNgbgO1BeUoZURlifrW5ofHXTs3DIpNF9g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.figsh.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.figsh.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.figsh.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://login.figsh.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.figsh.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.figsh.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.researchprofessional.com/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Potter"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso@researchresearch.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.researchprofessional.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.researchprofessional.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.researchprofessional.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.researchprofessional.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.researchprofessional.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.researchprofessional.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.researchprofessional.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://info.researchprofessional.com/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Research Professional is an intuitive platform for online access to news and funding services."
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Research Professional \u00e4r en intuitiv plattform f\u00f6r tillg\u00e5ng online till nyheter och finansieringstj\u00e4nster."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Research Professional"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Research Professional"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.researchprofessional.com"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID6jCCAtKgAwIBAgIJALmfy/1EwX4NMA0GCSqGSIb3DQEBBQUAMHYxCzAJBgNV\nBAYTAkdCMRcwFQYDVQQIEw5HcmVhdGVyIExvbmRvbjEPMA0GA1UEBxMGTG9uZG9u\nMRYwFAYDVQQKEw1SZXNlYXJjaCBMdGQuMSUwIwYDVQQDExx3d3cucmVzZWFyY2hw\ncm9mZXNzaW9uYWwuY29tMB4XDTEzMDcyNDExMTUzNFoXDTIzMDcyMjExMTUzNFow\ndjELMAkGA1UEBhMCR0IxFzAVBgNVBAgTDkdyZWF0ZXIgTG9uZG9uMQ8wDQYDVQQH\nEwZMb25kb24xFjAUBgNVBAoTDVJlc2VhcmNoIEx0ZC4xJTAjBgNVBAMTHHd3dy5y\nZXNlYXJjaHByb2Zlc3Npb25hbC5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQDr6isqSDUBMLp8dqaP5zhEJ4IF+cOm46VCvsH7gLkSRPiU8SXuosB9\no8wcHQD4SRzdZueZ/8Pv9Dq86+d+jih2wzBzIr1ZQmwCYKdCeuVQ/NrFYOW/K/zJ\nHI2D8wWdnMRbDHQbBnpLIiI9AeNE3DlzerFfeqXc/amrlaWgCm7oKIfmn5diJmKm\n0qwlPuHyzCh4qwRPvFofSkuyOTzjdEhuYPoJ/GDuwQOWKzvRrwyr2LNywbesRG76\nErlw/jIfEld8FlJjAvAkDWpR4ZJM+K1/Gnrw/emGJbTULj5rV4tqtcRDkkzxvJlo\nP8tmBdTTFeQKa8fAN8TdqJz5nTA1noP1AgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJ\nYIZIAYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1Ud\nDgQWBBRkhl/nawpdfr1xWIgUhBkBU0z8EzAfBgNVHSMEGDAWgBRkhl/nawpdfr1x\nWIgUhBkBU0z8EzANBgkqhkiG9w0BAQUFAAOCAQEA3rqSgq+7fQHLsQSuSZ5ZAXa5\niiah5Lh0nrwNAnx4NNiRo/XreA4zS27f58BWZjETCv7X8phegFLKZawe87VrHiUT\ncktHPT1yD6LFvB/iw6KR/lmH0ssrHtXpag5V6vQVheU01kxmE1TrVqdlxR3aBX87\nAScHf43WyOPMzr798LFCOm/RFwEUYhZMtp9DMf9SOUtOA0OrZHv6AP5kclGZkq4+\nw56TWc4NlFDMfqvwFqedywQyt+FVLNJ3H3Gt3KXpootbOZBmtzd8Bsf/5/SevgkS\ntgwZBKIPISvO0cHB2chZHzDJI9PQsgD0OmVfHqQtlwuMw32qK2EcD1NC/VZZ/w=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.researchprofessional.com,O=Research Ltd.,L=London,ST=Greater London,C=GB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.researchprofessional.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.researchprofessional.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.researchprofessional.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.researchprofessional.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.researchprofessional.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.kingston-college.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@kingston-college.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@kingston-college.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.kingston-college.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIVAMdUWtt4ktwl67ApElUJmzacgr80MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCUxIzAhBgNVBAMTGmlkcC5raW5nc3Rvbi1jb2xsZWdlLmFjLnVrMB4XDTEz\n\t\t\t\t\t\tMDQxNzE1MDg0NFoXDTMzMDQxNzE1MDg0NFowJTEjMCEGA1UEAxMaaWRwLmtpbmdz\n\t\t\t\t\t\tdG9uLWNvbGxlZ2UuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCmDI0iBMmMG2bc5ALSjviEDGlHjgr3taE907rW6ArPCH5xUMBFw9Nwge0mNS3D\n\t\t\t\t\t\tnaqk9WhKANREU5kppNAoWtp65P7jqStN1dgsUpK9ruIpYp2VymgMNnXtqv+EEE12\n\t\t\t\t\t\tiZW0bZBVhmFVlJBXHIt879+jRXiR3ALSqRuE8MasJIJhwgqMU18qr9lgm3jhwDTt\n\t\t\t\t\t\tMJdc+N255WStJdWD2Q6OGJUVF2bcoFQcQ8cgxEsGjQIQ3qQ232/Cp8clHzcEBc8V\n\t\t\t\t\t\tpKtTU4jkmu+OQMsbImeY0OguIpVG1QYsgG8Vz7L9GIwx8ed52QuoJMXW4QaeNenk\n\t\t\t\t\t\toEJP2Rq3WTym/Pys1pGcXpynAgMBAAGjezB5MFgGA1UdEQRRME+CGmlkcC5raW5n\n\t\t\t\t\t\tc3Rvbi1jb2xsZWdlLmFjLnVrhjFodHRwczovL2lkcC5raW5nc3Rvbi1jb2xsZWdl\n\t\t\t\t\t\tLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRp8Hn8YhPsXqx9UpL1LtVm\n\t\t\t\t\t\t4c6hVTANBgkqhkiG9w0BAQUFAAOCAQEAHRjHFTvBHVK1NJXYoKAgunVmG4c/pqbv\n\t\t\t\t\t\t99OrLj2TNrUK/LD4395qpXoBtXAkw+76ZqbF5aBs+3IYLha5MyRZqFfa6KBXEwwj\n\t\t\t\t\t\tZej8Bdx809xIBfbkl25uUWGzg+77oaMMog1AzpCAcV0L6wHNnrLBJ6xxOzq/3wNE\n\t\t\t\t\t\tXwYLU2H+KZ6oA5nV2x7/OVH5uxkrVJpNpTpM/D2TzDvfaO3m4rotmCaKYDWqU+/v\n\t\t\t\t\t\tg22QCNGnQBNm+23uTa1K4sR+WSZ2SOwwzIdgfATd5XdnnY28BMKy4uNME+XJklhY\n\t\t\t\t\t\t4O5uQkWDV+eFTekWMLQ1esZs27Pvp0NECx1IgTb2IjoXF8X16uNqDA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kingston-college.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.kingston-college.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.kingston-college.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.kingston-college.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.kingston-college.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.kingston-college.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.kingston-college.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.kingston-college.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.kingston-college.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kingston-college.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIVAMdUWtt4ktwl67ApElUJmzacgr80MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCUxIzAhBgNVBAMTGmlkcC5raW5nc3Rvbi1jb2xsZWdlLmFjLnVrMB4XDTEz\n\t\t\t\t\t\tMDQxNzE1MDg0NFoXDTMzMDQxNzE1MDg0NFowJTEjMCEGA1UEAxMaaWRwLmtpbmdz\n\t\t\t\t\t\tdG9uLWNvbGxlZ2UuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCmDI0iBMmMG2bc5ALSjviEDGlHjgr3taE907rW6ArPCH5xUMBFw9Nwge0mNS3D\n\t\t\t\t\t\tnaqk9WhKANREU5kppNAoWtp65P7jqStN1dgsUpK9ruIpYp2VymgMNnXtqv+EEE12\n\t\t\t\t\t\tiZW0bZBVhmFVlJBXHIt879+jRXiR3ALSqRuE8MasJIJhwgqMU18qr9lgm3jhwDTt\n\t\t\t\t\t\tMJdc+N255WStJdWD2Q6OGJUVF2bcoFQcQ8cgxEsGjQIQ3qQ232/Cp8clHzcEBc8V\n\t\t\t\t\t\tpKtTU4jkmu+OQMsbImeY0OguIpVG1QYsgG8Vz7L9GIwx8ed52QuoJMXW4QaeNenk\n\t\t\t\t\t\toEJP2Rq3WTym/Pys1pGcXpynAgMBAAGjezB5MFgGA1UdEQRRME+CGmlkcC5raW5n\n\t\t\t\t\t\tc3Rvbi1jb2xsZWdlLmFjLnVrhjFodHRwczovL2lkcC5raW5nc3Rvbi1jb2xsZWdl\n\t\t\t\t\t\tLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRp8Hn8YhPsXqx9UpL1LtVm\n\t\t\t\t\t\t4c6hVTANBgkqhkiG9w0BAQUFAAOCAQEAHRjHFTvBHVK1NJXYoKAgunVmG4c/pqbv\n\t\t\t\t\t\t99OrLj2TNrUK/LD4395qpXoBtXAkw+76ZqbF5aBs+3IYLha5MyRZqFfa6KBXEwwj\n\t\t\t\t\t\tZej8Bdx809xIBfbkl25uUWGzg+77oaMMog1AzpCAcV0L6wHNnrLBJ6xxOzq/3wNE\n\t\t\t\t\t\tXwYLU2H+KZ6oA5nV2x7/OVH5uxkrVJpNpTpM/D2TzDvfaO3m4rotmCaKYDWqU+/v\n\t\t\t\t\t\tg22QCNGnQBNm+23uTa1K4sR+WSZ2SOwwzIdgfATd5XdnnY28BMKy4uNME+XJklhY\n\t\t\t\t\t\t4O5uQkWDV+eFTekWMLQ1esZs27Pvp0NECx1IgTb2IjoXF8X16uNqDA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Kingston College (Shibboleth)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kingston-college.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Kingston College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://community.staging.company.ja.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:web-submit@ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Login Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:web-submit@ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://community.staging.company.ja.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-01-25T19:22:17Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Janet Community (Staging)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ja.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "JISC Collections and Janet Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://community-stg.jisc.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://community-stg.jisc.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://community-stg.jisc.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://community-stg.jisc.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://community-stg.jisc.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://community-stg.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://community-stg.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The community driven, social business, support, and information website for Janet products and services."
                  }
                ],
                "logo": [
                  {
                    "text": "https://community.staging.company.ja.net/sites/all/themes/janetcommunity/logo.png",
                    "height": "95",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "191"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The Janet Community (Staging)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDXjCCAkagAwIBAgIJAOCcPdISR/MjMA0GCSqGSIb3DQEBBQUAMCsxKTAnBgNV\n\t\t\t\t\t\tBAMTIGNvbW11bml0eS5zdGFnaW5nLmNvbXBhbnkuamEubmV0MB4XDTEzMDEyNTEy\n\t\t\t\t\t\tNTE0NFoXDTE2MDEyNTEyNTE0NFowKzEpMCcGA1UEAxMgY29tbXVuaXR5LnN0YWdp\n\t\t\t\t\t\tbmcuY29tcGFueS5qYS5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDPWOgoD8BXAEbRvLeICCdeiSCtGd5TnC1m8hSMOa26LsKP0zjhV7HrQREdfmLD\n\t\t\t\t\t\thtdce5T+2xBjw1zXNOiD1AjkL+2cjpHdvroHjBIKd+XK8IvuXbTFwHKlD+YT7YHg\n\t\t\t\t\t\tvlUsgndFVGLTWgIWB4cqjP4nHjNSv4oICe9qD5IhfCy7P45mjHYRZLS59mvQsNNU\n\t\t\t\t\t\tfmJ5Gtxh93Ga57AWBGhj/rAWbH+lLZCUHDJw91BJf2NYtptTmiMBAmCwVFWrS5kL\n\t\t\t\t\t\t77cRQRVjxmONjSVrnoUQObyQoCcMfDFa4i1MfT3pVUeNKufvozw3Bo6l0dNL0LBO\n\t\t\t\t\t\tg/qNDWjewq5XvYPAFJN4zbt5AgMBAAGjgYQwgYEwYAYDVR0RBFkwV4IgY29tbXVu\n\t\t\t\t\t\taXR5LnN0YWdpbmcuY29tcGFueS5qYS5uZXSGM2h0dHBzOi8vY29tbXVuaXR5LnN0\n\t\t\t\t\t\tYWdpbmcuY29tcGFueS5qYS5uZXQvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUdtp8pIFT\n\t\t\t\t\t\tajJQn9wN8qKR9MRwlsIwDQYJKoZIhvcNAQEFBQADggEBAKgsVmXIr5EqZIsJTflv\n\t\t\t\t\t\t/NK04PSwJC3Y4+A4A1mgcrMQBelas1HQxfFwK/ohUb2UOv8yqF3AXspbenHJqFqc\n\t\t\t\t\t\tv1ndoEkICjewUoTpILMXz08vcwOU/qOlvIEuwBq49dnjTXYKQkb15hSSk3Q2bZ6T\n\t\t\t\t\t\tSYSe6/NIbtrfcWdmvXCd71QyhYiLaB/9woO1Yb4jDQ9Fq9PWQd5bzEI0XsBfjbYj\n\t\t\t\t\t\ta004CGcStT94SAmze/FE7w+YZtTANfHC41dhgEH/fwW0SJn/7Lb1d5uOhRiNM1p/\n\t\t\t\t\t\thrDiSI6b0gOx0wzz8NReyhFMG4Rk23HGJSUUwsZ05AFPGJbwAShqnvbVLajVIRnB\n\t\t\t\t\t\tigk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://community-stg.jisc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://community-stg.jisc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://community-stg.jisc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://community-stg.jisc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://community-stg.jisc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://community-stg.jisc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.staging.company.ja.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sso.staging.company.ja.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sso.staging.company.ja.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sso.staging.company.ja.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sso.staging.company.ja.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sso.staging.company.ja.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://jcolls.mimas.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@mimas.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mimas Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mimas-shib-tech@listserv.manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mimas Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://jcolls.mimas.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MIMAS: JISC Collections Content"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://mimas.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Manchester"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jcolls.mimas.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://jcolls.mimas.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jcolls.mimas.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://jcolls.mimas.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKzCCAxOgAwIBAgIJAP8Lcrq8+dIXMA0GCSqGSIb3DQEBBQUAMIGLMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjETMBEGA1UECBMKTWFuY2hlc3RlcjETMBEGA1UEBxMKTWFuY2hlc3Rl\n\t\t\t\t\t\tcjElMCMGA1UEChMcVGhlIFVuaXZlcnNpdHkgb2YgTWFuY2hlc3RlcjEOMAwGA1UE\n\t\t\t\t\t\tCxMFTWltYXMxGzAZBgNVBAMTEmpjb2xscy5taW1hcy5hYy51azAeFw0xMzA1MjAx\n\t\t\t\t\t\tMzM2NDFaFw0yMzA1MTgxMzM2NDFaMIGLMQswCQYDVQQGEwJHQjETMBEGA1UECBMK\n\t\t\t\t\t\tTWFuY2hlc3RlcjETMBEGA1UEBxMKTWFuY2hlc3RlcjElMCMGA1UEChMcVGhlIFVu\n\t\t\t\t\t\taXZlcnNpdHkgb2YgTWFuY2hlc3RlcjEOMAwGA1UECxMFTWltYXMxGzAZBgNVBAMT\n\t\t\t\t\t\tEmpjb2xscy5taW1hcy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAJu5gU3fnvknoUtOKZ2D014hSlAGLXQuTe9ZDgXQ+tNjrRf5arfqGIsZlHWR\n\t\t\t\t\t\t6AHBbDZaD8iljZAvsOWbAlC+gBQumWZEDAV0RJd+M8lBMnwDodXe6t0jYBTiH1Un\n\t\t\t\t\t\tvWWMm8YKMpDWJq/qPVtW+fWyKhJkA1yaDRqvNVmSL9d6sCWpzr4gvIPjg7PgdJKt\n\t\t\t\t\t\tQ3h3uJzBGJ5rXCg4zUGO6UejVKg5zy+skZQ8oEFahEH3abeWS/aQtCOesDlBh/JM\n\t\t\t\t\t\tk3OBCI+sS1g15y7bvQwcHDN+o31yDDMQ5fvdfQyUyGdCG5FIdtMOAUsYiVCDNzGd\n\t\t\t\t\t\t8h4QebK1hogewsHQYIQjTvtH7tsCAwEAAaOBjzCBjDAJBgNVHRMEAjAAMAsGA1Ud\n\t\t\t\t\t\tDwQEAwIEsDAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwHQYDVR0RBBYw\n\t\t\t\t\t\tFIISamNvbGxzLm1pbWFzLmFjLnVrMDQGA1UdEgQtMCuBKW1pbWFzLXNoaWItdGVj\n\t\t\t\t\t\taEBsaXN0c2Vydi5tYW5jaGVzdGVyLmFjLnVrMA0GCSqGSIb3DQEBBQUAA4IBAQBZ\n\t\t\t\t\t\t25RsQQiA5RuxYb+8GGPDd1N8dkLIU0nPyqlFhWQM43lSrqL54UYUlh2IBjE5KJob\n\t\t\t\t\t\tTMwRNeX3CDRHkAskF1ZIziV9RNCdd2/92WI7ieYl/Q8H14vNVEhTv496l5wBPinN\n\t\t\t\t\t\tNakZzsD1bcTod/MY/CwUeKhKDMTtRgNe+AJirONfQSY1yqjdjXG2dX2lgle7FDKX\n\t\t\t\t\t\tTQ94Ks3wbgojEoHofaKoPKkBWUnwtDL8Wc0O99jQbIVx771gJ/KbmC2Qvq7oGYBW\n\t\t\t\t\t\t3lvtbpwmo4D+SXsCeK/1HShRFHIAqLF2nSip/Usbg29FLN2tSe0E8D6zyHURdLn5\n\t\t\t\t\t\tRlTNvtB/OM17VzVTJT0i"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKzCCAxOgAwIBAgIJAP8Lcrq8+dIXMA0GCSqGSIb3DQEBBQUAMIGLMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjETMBEGA1UECBMKTWFuY2hlc3RlcjETMBEGA1UEBxMKTWFuY2hlc3Rl\n\t\t\t\t\t\tcjElMCMGA1UEChMcVGhlIFVuaXZlcnNpdHkgb2YgTWFuY2hlc3RlcjEOMAwGA1UE\n\t\t\t\t\t\tCxMFTWltYXMxGzAZBgNVBAMTEmpjb2xscy5taW1hcy5hYy51azAeFw0xMzA1MjAx\n\t\t\t\t\t\tMzM2NDFaFw0yMzA1MTgxMzM2NDFaMIGLMQswCQYDVQQGEwJHQjETMBEGA1UECBMK\n\t\t\t\t\t\tTWFuY2hlc3RlcjETMBEGA1UEBxMKTWFuY2hlc3RlcjElMCMGA1UEChMcVGhlIFVu\n\t\t\t\t\t\taXZlcnNpdHkgb2YgTWFuY2hlc3RlcjEOMAwGA1UECxMFTWltYXMxGzAZBgNVBAMT\n\t\t\t\t\t\tEmpjb2xscy5taW1hcy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAJu5gU3fnvknoUtOKZ2D014hSlAGLXQuTe9ZDgXQ+tNjrRf5arfqGIsZlHWR\n\t\t\t\t\t\t6AHBbDZaD8iljZAvsOWbAlC+gBQumWZEDAV0RJd+M8lBMnwDodXe6t0jYBTiH1Un\n\t\t\t\t\t\tvWWMm8YKMpDWJq/qPVtW+fWyKhJkA1yaDRqvNVmSL9d6sCWpzr4gvIPjg7PgdJKt\n\t\t\t\t\t\tQ3h3uJzBGJ5rXCg4zUGO6UejVKg5zy+skZQ8oEFahEH3abeWS/aQtCOesDlBh/JM\n\t\t\t\t\t\tk3OBCI+sS1g15y7bvQwcHDN+o31yDDMQ5fvdfQyUyGdCG5FIdtMOAUsYiVCDNzGd\n\t\t\t\t\t\t8h4QebK1hogewsHQYIQjTvtH7tsCAwEAAaOBjzCBjDAJBgNVHRMEAjAAMAsGA1Ud\n\t\t\t\t\t\tDwQEAwIEsDAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwHQYDVR0RBBYw\n\t\t\t\t\t\tFIISamNvbGxzLm1pbWFzLmFjLnVrMDQGA1UdEgQtMCuBKW1pbWFzLXNoaWItdGVj\n\t\t\t\t\t\taEBsaXN0c2Vydi5tYW5jaGVzdGVyLmFjLnVrMA0GCSqGSIb3DQEBBQUAA4IBAQBZ\n\t\t\t\t\t\t25RsQQiA5RuxYb+8GGPDd1N8dkLIU0nPyqlFhWQM43lSrqL54UYUlh2IBjE5KJob\n\t\t\t\t\t\tTMwRNeX3CDRHkAskF1ZIziV9RNCdd2/92WI7ieYl/Q8H14vNVEhTv496l5wBPinN\n\t\t\t\t\t\tNakZzsD1bcTod/MY/CwUeKhKDMTtRgNe+AJirONfQSY1yqjdjXG2dX2lgle7FDKX\n\t\t\t\t\t\tTQ94Ks3wbgojEoHofaKoPKkBWUnwtDL8Wc0O99jQbIVx771gJ/KbmC2Qvq7oGYBW\n\t\t\t\t\t\t3lvtbpwmo4D+SXsCeK/1HShRFHIAqLF2nSip/Usbg29FLN2tSe0E8D6zyHURdLn5\n\t\t\t\t\t\tRlTNvtB/OM17VzVTJT0i"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jcolls.mimas.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://jcolls.mimas.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jcolls.mimas.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://jcolls.mimas.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jcolls.mimas.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://jcolls.mimas.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://jcolls.mimas.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://jcolls.mimas.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://jcolls.mimas.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://jcolls.mimas.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.statista.com",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:technik@statista.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technik"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:technik@statista.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technik"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.statista.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-08-11T11:49:28Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Statista"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.statista.com/aboutus/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Statista GmbH"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.statista.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.statista.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.statista.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.statista.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.statista.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.statista.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth.statista.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Statista.com is a statistics portal integrating data on over 60,000 topics from over 18,000 sources."
                  }
                ],
                "logo": [
                  {
                    "text": "https://d28wbuch0jlv7v.cloudfront.net/static/img/Statista-Logo-Color-Primary.png",
                    "height": "36",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "169"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Statista"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE4jCCA8qgAwIBAgIHEn65XsmOBDANBgkqhkiG9w0BAQUFADBVMQswCQYDVQQG\n\t\t\t\t\t\tEwJERTETMBEGA1UEChMKREZOLVZlcmVpbjEQMA4GA1UECxMHREZOLVBLSTEfMB0G\n\t\t\t\t\t\tA1UEAxMWREZOLVZlcmVpbiBDQSBTZXJ2aWNlczAeFw0xMTA5MDEwODAxMThaFw0x\n\t\t\t\t\t\tNjA4MzAwODAxMThaME4xCzAJBgNVBAYTAkRFMRMwEQYDVQQKEwpERk4tVmVyZWlu\n\t\t\t\t\t\tMRAwDgYDVQQLEwdERk4tUEtJMRgwFgYDVQQDEw9kZS5zdGF0aXN0YS5jb20wggEi\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDIP8FskLI19g/XBvxY1ua4uEtg\n\t\t\t\t\t\tQ0vdL6f/wuKNP8wc/hCNh/HGJLYj9S0BRFmVlCxiXFhr5GRZAAZN+b6msehsgPs3\n\t\t\t\t\t\tV6yKsP0Ga4yt7ccJuAzUFVU8Qrva2TIvDLPZ7Qucj+2M4ekxpqBjp850JbTqdGO1\n\t\t\t\t\t\toDmrKAzuxWXUS/9L88tFHiHvaxLEIBK3OYf6k8lK61BZuU2DXIFkd72iCF7LS/sE\n\t\t\t\t\t\tuHh1db+185ssxNiLICu2vqJ9ZpsrYN6qOxSNvxI3jQ7jHNOlVXwFGAeDsnjg4Qxa\n\t\t\t\t\t\toqfgLekPagmmDWpAI9QHTyqUOAaN03UWigVeb01IiH8EwBKzi82mims7CHb1AgMB\n\t\t\t\t\t\tAAGjggG8MIIBuDAJBgNVHRMEAjAAMAsGA1UdDwQEAwIF4DAdBgNVHSUEFjAUBggr\n\t\t\t\t\t\tBgEFBQcDAgYIKwYBBQUHAwEwHQYDVR0OBBYEFOG/Ep6pb7z0/1gHX1D6Yx8DZsGx\n\t\t\t\t\t\tMB8GA1UdIwQYMBaAFB2p8YYmdk3PXf1Qo27r8bwidW3rMIGRBgNVHR8EgYkwgYYw\n\t\t\t\t\t\tQaA/oD2GO2h0dHA6Ly9jZHAxLnBjYS5kZm4uZGUvZ2xvYmFsLXNlcnZpY2VzLWNh\n\t\t\t\t\t\tL3B1Yi9jcmwvY2FjcmwuY3JsMEGgP6A9hjtodHRwOi8vY2RwMi5wY2EuZGZuLmRl\n\t\t\t\t\t\tL2dsb2JhbC1zZXJ2aWNlcy1jYS9wdWIvY3JsL2NhY3JsLmNybDCBqgYIKwYBBQUH\n\t\t\t\t\t\tAQEEgZ0wgZowSwYIKwYBBQUHMAKGP2h0dHA6Ly9jZHAxLnBjYS5kZm4uZGUvZ2xv\n\t\t\t\t\t\tYmFsLXNlcnZpY2VzLWNhL3B1Yi9jYWNlcnQvY2FjZXJ0LmNydDBLBggrBgEFBQcw\n\t\t\t\t\t\tAoY/aHR0cDovL2NkcDIucGNhLmRmbi5kZS9nbG9iYWwtc2VydmljZXMtY2EvcHVi\n\t\t\t\t\t\tL2NhY2VydC9jYWNlcnQuY3J0MA0GCSqGSIb3DQEBBQUAA4IBAQCJFZsyyBpVIHAp\n\t\t\t\t\t\tpreO/3S9+1Gw4OFWgS4Ajpfxz8H5pV5+6PK9bogtUWt7kSt41rbrWKWWbiZkjuTo\n\t\t\t\t\t\tTh4aHytOOeHpaUYH9qkFa7Cla5L4FEB52uarXlnXtrp3/2sTPvpZWtDk7KNZYvcN\n\t\t\t\t\t\tPsfu+IqZEGwHWuwh58Hl2v5xf137GhgcYuOm5Yabvi0+MdmtHihWuJ2sA7NEWzn8\n\t\t\t\t\t\tLW8dBcS4uGBLwmZ5Tq4zIAbppwwoqV81YwY+IaW9ObNpYJUMPhyxxW6ydTxF4yuT\n\t\t\t\t\t\tqZL8C8tvRqJtGUxFqPs4xImg3b9WLPThwMkFkuH/xzQqmN+xeoD3LvL/2DF88T3y\n\t\t\t\t\t\tl/xjGBYl"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.statista.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.statista.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.statista.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth.statista.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.statista.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.statista.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://sts.edugroepen.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "2AT"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "info@edugroepen.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EDUgroepen"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "2AT"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "info@edugroepen.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EDUgroepen"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "2AT"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "info@edugroepen.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EDUgroepen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://sts.edugroepen.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-04-07T20:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "2AT BV"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "2AT BV"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.2at.nl/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.2at.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "2AT BV"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "2AT BV"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Samenwerkingsplatform om in groepen samen te werken in de educatieve sector."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Collaboration platform for working in groups in the educational sector."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://login.edugroepen.nl/privacy"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://login.edugroepen.nl/privacy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EDUgroepen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EDUgroepen"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.edugroepen.nl/signin-edugain",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.webassign.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "djones@webassign.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dodd Jones"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "bwells@webassign.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brent Wells"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.webassign.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "WebAssign"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.webassign.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "WebAssign"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.webassign.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.webassign.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.webassign.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth.webassign.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGtDCCBZygAwIBAgIHBx3OYpjt3TANBgkqhkiG9w0BAQsFADCBjDELMAkGA1UE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\n3QhMBkpxpdG7DQxhEkDyZUArmdH011y94LJk3W5or4AQna2hVQSs8g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth.webassign.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WebAssign - PlaceU"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://idp-css.irccs.garr.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idpcloud-service@garr.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-css.irccs.garr.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2014-03-12T12:15:29Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUatdmXg8WrEt1In2rF4jLwoE2ExUwDQYJKoZIhvcNAQEF\nBQAwIDEeMBwGA1UEAxMVaWRwLWNzcy5pcmNjcy5nYXJyLml0MB4XDTEzMTIwOTEz\nNDYyMVoXDTMzMTIwOTEzNDYyMVowIDEeMBwGA1UEAxMVaWRwLWNzcy5pcmNjcy5n\nYXJyLml0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA3VFhN4BK8bGv\nOpfsmnkMKK1K64/Ref079D7hERL/AnLWBH3xTR8cXdYmm0zqUIHL224b6WQAa1kx\n1jCrBseoyK/D16PwzmuKaZBtvnXq4hdEonm8jXT4mJnRJpkJtlsBzqxi5c0KdXiC\nijcHBlgqLDR8wZOBJV1tIN8VyEPkiFtm7W1oabFSzJRBfWgQ40Ku4qvRmcSbcYke\n8DbcRQS1HULWC4Erxx6hR9I9epkWc2ubd4MiYH2HMlrV35IJR2AcoP753rJ+HpLb\n3kr3//8eOEaK0pD52RuRQbo7tYOwS0aINmnEmKrJt18udKmb45XN3Ntw0j+u0peV\nLatd8xQt6wIDAQABo3EwbzBOBgNVHREERzBFghVpZHAtY3NzLmlyY2NzLmdhcnIu\naXSGLGh0dHBzOi8vaWRwLWNzcy5pcmNjcy5nYXJyLml0L2lkcC9zaGliYm9sZXRo\nMB0GA1UdDgQWBBT/nCGumeHDpDhV5xEzXsEzK3YdFDANBgkqhkiG9w0BAQUFAAOC\nAQEAQrLhSycAVaJvvN4rIhxlZhYMi24tJIG27nMqg5aCnUbwsH97g4fyRC/PJrAU\nyLsvni9innZWp9btFrpZUXSVZTvVB2Kk+Q670m7VKEkPkOyXaWI22M3OeLNQAHs6\nwshwq6xuRHQV9Al7Ksa3VRYO6xXOGa0L7anouGijzpatNQa7FXlHvriVrWI8MJAf\nf85zy1/DrY7aUkXNokxppZUuH70Fu+znNoV9+Yhis8SAETCkWgUjBgqXJgL91/U8\nYPWByb6q+2Zn18fmie++zEPRItO9JpXGetGuOGEAHHnaQoxNn0UgXTqvwxngVDWY\nPeaxmS3Lw5E/7cnXkOo1qLnfhg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "operapadrepio.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-css.irccs.garr.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-css.irccs.garr.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-css.irccs.garr.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-css.irccs.garr.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-css.irccs.garr.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-css.irccs.garr.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-css.irccs.garr.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-css.irccs.garr.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "operapadrepio.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.operapadrepio.it/it/ricerca-scientifica/news-ricerca-scientifica/97-news-ricerca-scientifica/3719.html"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.operapadrepio.it/it/ricerca-scientifica/news-ricerca-scientifica/109-generali/3759.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IRCCS Casa Sollievo della Sofferenza Research Hospital"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider di IRCCS Casa Sollievo della Sofferenza"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider of IRCCS Casa Sollievo della Sofferenza Research Hospital"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp-css.irccs.garr.it/idp/images/institutionLogo-32x32_en.png",
                    "lang": "en",
                    "height": "32",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "32"
                  },
                  {
                    "text": "https://idp-css.irccs.garr.it/idp/images/institutionLogo-32x32_it.png",
                    "lang": "it",
                    "height": "32",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "32"
                  },
                  {
                    "text": "https://idp-css.irccs.garr.it/idp/images/institutionLogo-160x120_en.png",
                    "lang": "en",
                    "height": "120",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "160"
                  },
                  {
                    "text": "https://idp-css.irccs.garr.it/idp/images/institutionLogo-160x120_it.png",
                    "lang": "it",
                    "height": "120",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "160"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.operapadrepio.it/it/privacy-policy.html"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.operapadrepio.it/en/109-generali/3760.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUatdmXg8WrEt1In2rF4jLwoE2ExUwDQYJKoZIhvcNAQEF\nBQAwIDEeMBwGA1UEAxMVaWRwLWNzcy5pcmNjcy5nYXJyLml0MB4XDTEzMTIwOTEz\nNDYyMVoXDTMzMTIwOTEzNDYyMVowIDEeMBwGA1UEAxMVaWRwLWNzcy5pcmNjcy5n\nYXJyLml0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA3VFhN4BK8bGv\nOpfsmnkMKK1K64/Ref079D7hERL/AnLWBH3xTR8cXdYmm0zqUIHL224b6WQAa1kx\n1jCrBseoyK/D16PwzmuKaZBtvnXq4hdEonm8jXT4mJnRJpkJtlsBzqxi5c0KdXiC\nijcHBlgqLDR8wZOBJV1tIN8VyEPkiFtm7W1oabFSzJRBfWgQ40Ku4qvRmcSbcYke\n8DbcRQS1HULWC4Erxx6hR9I9epkWc2ubd4MiYH2HMlrV35IJR2AcoP753rJ+HpLb\n3kr3//8eOEaK0pD52RuRQbo7tYOwS0aINmnEmKrJt18udKmb45XN3Ntw0j+u0peV\nLatd8xQt6wIDAQABo3EwbzBOBgNVHREERzBFghVpZHAtY3NzLmlyY2NzLmdhcnIu\naXSGLGh0dHBzOi8vaWRwLWNzcy5pcmNjcy5nYXJyLml0L2lkcC9zaGliYm9sZXRo\nMB0GA1UdDgQWBBT/nCGumeHDpDhV5xEzXsEzK3YdFDANBgkqhkiG9w0BAQUFAAOC\nAQEAQrLhSycAVaJvvN4rIhxlZhYMi24tJIG27nMqg5aCnUbwsH97g4fyRC/PJrAU\nyLsvni9innZWp9btFrpZUXSVZTvVB2Kk+Q670m7VKEkPkOyXaWI22M3OeLNQAHs6\nwshwq6xuRHQV9Al7Ksa3VRYO6xXOGa0L7anouGijzpatNQa7FXlHvriVrWI8MJAf\nf85zy1/DrY7aUkXNokxppZUuH70Fu+znNoV9+Yhis8SAETCkWgUjBgqXJgL91/U8\nYPWByb6q+2Zn18fmie++zEPRItO9JpXGetGuOGEAHHnaQoxNn0UgXTqvwxngVDWY\nPeaxmS3Lw5E/7cnXkOo1qLnfhg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IRCCS Casa Sollievo della Sofferenza Research Hospital"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IRCCS Casa Sollievo della Sofferenza"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.operapadrepio.it"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.operapadrepio.it"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IRCCS Casa Sollievo della Sofferenza Research Hospital"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IRCCS Casa Sollievo della Sofferenza"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-07.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-07.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;07"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;07"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-07.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-07.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAOsgfFjj/hMdMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wNy5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTQ0MjQ5WhcNMjQx\nMDA0MTQ0MjQ5WjAhMR8wHQYDVQQDExZsYWRvazMtMDcubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA5DBg6PDwC4+C6CEkNGol26MB\neJsWIm5Ir1UnDZh23Ya3laVl6BJ7XPeqEriYDQhPEzhzVr6oI40SEzHGLxs8MoJZ\nCuMC+fLdwZePVTe3Egv03sK9fHmJ0OZT2zmr6GsfbdTT0GBKZQFVr8K0wTJp8Zb6\n9GAtlERKWb0XH9gA7xBcOAJP9SwRnbF0yPa8JLisAFAHTRnke1jfhAlbmzhdn7fe\nWWF7hwdmm6/H2fOWGRcj+D4TetrLZfe4oOgp0jqwePo40DQQl9HydvLks3wE8BoW\nIBtgueYzGAn9WQ5glfKGpOH+eIGX9f8xEWaeKymCHKLEAKC7Qgf2D9sX8U9+XwID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMDcubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0wNy5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUZwh/XMjxGo6c8it7PdID4xRpjRYwDQYJKoZIhvcNAQEFBQADggEB\nAFkbeTMkoGdJ8ORwMFJega9rncawdLSBwvOVP8oS3pCC+B1FUVgihDgBoFu/J6I+\nwndHcmlt8f2klO4J6AKIIHsC/wDRxdqez2sL6FzIPzAE/JbMAa5BCiIeJH10JNl0\n7p2ZJkS9nKYpBDbXVO5cdmaZcICPTJm28Bo2wI+krWIB1IgH1Qwi+LECBvvWpd2+\nSVM6b6Ht6z8aHkecEuUdNzpJ4yXmbC2GWsRmicYwYo5gT4olPPA6qLUq2SWxE3Va\ng4/6d9o3Ce9czm1s/j0Eeq97ZVGX6805iZmR4ne/rSkSt3w+bhhDjxo4R7lyyUau\nTf+bD9kP9t0LVFwEIee45FY="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-07.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.iamtest.ox.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sysdev@it.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Systems Development and Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sysdev@it.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Systems Development and Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.iamtest.ox.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_instant": "2013-05-03T09:53:37Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUa38GMB38Bw/fc8DRnws12ed2TT8wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAxMUaWRwLmlhbXRlc3Qub3guYWMudWswHhcNMTMwMzA3MTIx\n\t\t\t\t\t\tOTU5WhcNMzMwMzA3MTIxOTU5WjAfMR0wGwYDVQQDExRpZHAuaWFtdGVzdC5veC5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKKPxDvVvBDa7oue\n\t\t\t\t\t\tbcUFyrrd/gLxKTWVR9wObbumUQpi0T5nVa0t8KbpdKdusP1Ymj2bdMw+KPNfZrc4\n\t\t\t\t\t\tMEAMSD7BJYw9fNwvILS0hBNmn/mBW76zG+HrJjPF5UDHcy+G/PL2h0xdXLSdf/2i\n\t\t\t\t\t\tuHD5ln6jHyLqRK9K1db+yXXTv9cu5ZFWlh2DF9ByYHb8xMx4df5UWLICT09Vos3a\n\t\t\t\t\t\tMlkL3Y+MDAKznfjyGLrbac6UwxV2ZIh9F0G2wpgiAJB6zmDmNZeF7dgkvJXng1gi\n\t\t\t\t\t\tW5qb9qhP67YwlHEir9LDu+YQdEgL2o3J1bzylOX6mt3n9GU04zhkNHKWkUHtmSj2\n\t\t\t\t\t\t2LntNZMCAwEAAaNvMG0wTAYDVR0RBEUwQ4IUaWRwLmlhbXRlc3Qub3guYWMudWuG\n\t\t\t\t\t\tK2h0dHBzOi8vaWRwLmlhbXRlc3Qub3guYWMudWsvaWRwL3NoaWJib2xldGgwHQYD\n\t\t\t\t\t\tVR0OBBYEFONo0MnnlYDFHNi9JJ5MYNAFd3WxMA0GCSqGSIb3DQEBBQUAA4IBAQAZ\n\t\t\t\t\t\tCC8MLlPAXI+CAK33h7LjLYGgzT6xlPL/8qsFuP8bO/WBVg8bjuZpaC3KTi5W2HW6\n\t\t\t\t\t\tAQ7I0pXAZn7VJuH0KPyiLubgAvjLo1NM8lxkct7x4Y+jZXD2X8t3kS3Abyv69D+P\n\t\t\t\t\t\tNX3Ubvo6pYHmghQ/fcFvm0stZOo/nIMGwCZIc9wZBaOQ0mLkFQpfdLh/ncN3aaSJ\n\t\t\t\t\t\tTu79JDfGxHDvDwMMODuc7mToxakh8wH0v377RdFQ4ARrhVsLxJJhC0NgzKtw0sZd\n\t\t\t\t\t\tMDhEkM3L6GRkHkQBr16T99CJUDSbIzaYU10ERSEWb1VczZ2/ywvMLar8SszWYmrb\n\t\t\t\t\t\t+Ii81KZ2VotL9mj7v5li"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ox.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.iamtest.ox.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.iamtest.ox.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.iamtest.ox.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.iamtest.ox.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.iamtest.ox.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.iamtest.ox.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.iamtest.ox.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.iamtest.ox.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ox.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUa38GMB38Bw/fc8DRnws12ed2TT8wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAxMUaWRwLmlhbXRlc3Qub3guYWMudWswHhcNMTMwMzA3MTIx\n\t\t\t\t\t\tOTU5WhcNMzMwMzA3MTIxOTU5WjAfMR0wGwYDVQQDExRpZHAuaWFtdGVzdC5veC5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKKPxDvVvBDa7oue\n\t\t\t\t\t\tbcUFyrrd/gLxKTWVR9wObbumUQpi0T5nVa0t8KbpdKdusP1Ymj2bdMw+KPNfZrc4\n\t\t\t\t\t\tMEAMSD7BJYw9fNwvILS0hBNmn/mBW76zG+HrJjPF5UDHcy+G/PL2h0xdXLSdf/2i\n\t\t\t\t\t\tuHD5ln6jHyLqRK9K1db+yXXTv9cu5ZFWlh2DF9ByYHb8xMx4df5UWLICT09Vos3a\n\t\t\t\t\t\tMlkL3Y+MDAKznfjyGLrbac6UwxV2ZIh9F0G2wpgiAJB6zmDmNZeF7dgkvJXng1gi\n\t\t\t\t\t\tW5qb9qhP67YwlHEir9LDu+YQdEgL2o3J1bzylOX6mt3n9GU04zhkNHKWkUHtmSj2\n\t\t\t\t\t\t2LntNZMCAwEAAaNvMG0wTAYDVR0RBEUwQ4IUaWRwLmlhbXRlc3Qub3guYWMudWuG\n\t\t\t\t\t\tK2h0dHBzOi8vaWRwLmlhbXRlc3Qub3guYWMudWsvaWRwL3NoaWJib2xldGgwHQYD\n\t\t\t\t\t\tVR0OBBYEFONo0MnnlYDFHNi9JJ5MYNAFd3WxMA0GCSqGSIb3DQEBBQUAA4IBAQAZ\n\t\t\t\t\t\tCC8MLlPAXI+CAK33h7LjLYGgzT6xlPL/8qsFuP8bO/WBVg8bjuZpaC3KTi5W2HW6\n\t\t\t\t\t\tAQ7I0pXAZn7VJuH0KPyiLubgAvjLo1NM8lxkct7x4Y+jZXD2X8t3kS3Abyv69D+P\n\t\t\t\t\t\tNX3Ubvo6pYHmghQ/fcFvm0stZOo/nIMGwCZIc9wZBaOQ0mLkFQpfdLh/ncN3aaSJ\n\t\t\t\t\t\tTu79JDfGxHDvDwMMODuc7mToxakh8wH0v377RdFQ4ARrhVsLxJJhC0NgzKtw0sZd\n\t\t\t\t\t\tMDhEkM3L6GRkHkQBr16T99CJUDSbIzaYU10ERSEWb1VczZ2/ywvMLar8SszWYmrb\n\t\t\t\t\t\t+Ii81KZ2VotL9mj7v5li"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Oxford - Test IdP for IAMTEST authentication stack"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ox.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Oxford"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idea.ifc.cnr.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Raffaele Conte"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@ifc.cnr.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idea.ifc.cnr.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2009-12-31T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAPXQh7YfSjXSWrkZLXYT1bUm2Vj+MA0GCSqGSIb3DQEB\nBQUAMBoxGDAWBgNVBAMTD2lkZWEuaWZjLmNuci5pdDAeFw0wODExMjYxNjA0MTBa\nFw0yODExMjYxNjA0MTBaMBoxGDAWBgNVBAMTD2lkZWEuaWZjLmNuci5pdDCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAI6NBU4faqRoOEnab3DbjGPsno9a\n1j712yFWDpdxErwUmAAHUh83NmtwVKRSrVvZmymnGGEjBk7/2jTGfmpC/YdGm67j\nn/dbU3WCTnl+RhJh4/LrSJCsUmgw9r0JNo5BfHA781xvBIGprsHD8GOnmNIdK4nV\ndGSrslc3VpSP8Zhlaov5F5bGZuHa/dFM/GVI4YLZR0O2QNm6U3gIWM9TeaLofmA3\np1fFP/3CZlPPyNAHWUkylA4XebuLFwrA4bzpgJgkTdmc1NclfF/qPmYLsE6dxag1\n7mQNp4RPdvgf43Ivmp6Cx4UMYc1+Wu0DolG1c/vesbMnK3QdIYy3xFDjAnsCAwEA\nAaNlMGMwQgYDVR0RBDswOYIPaWRlYS5pZmMuY25yLml0hiZodHRwczovL2lkZWEu\naWZjLmNuci5pdC9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUAMIFF2Om2oTqwjUJ\nWyZb5He25R8wDQYJKoZIhvcNAQEFBQADggEBAG2loG5n8grIuX6Vr1H77E3N94O4\nQtNspFXjFOEtsFvgb+glgIRFd/4L3HCW2oWAebZ/s9JRXn+6YcrOA22SP+xg1OcQ\nJWlqTvr3XiSYQ9FjudBSt39cnOxlmwp/7SptWqLeMiZYs/muHaxcLeQMJ7W6z3wc\nSkvwMpHeTlORAfPh3RByRH9MD4rum56xY4CMP0HzcXg3iLvlBgxp63VnT216xKfR\neI8m4D0Jiu4VLtvkSAfUOcBpXPjW7KSsp6O+GMCHG+DHBcYfv8/FaP80IBenVNfd\nnvu7cp9h/xfMf1OV7tsIADMKQAeFLnIKyd74JxiM9rBSHLqWmcK2jklOHCc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ifc.cnr.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idea.ifc.cnr.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idea.ifc.cnr.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idea.ifc.cnr.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idea.ifc.cnr.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idea.ifc.cnr.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idea.ifc.cnr.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idea.ifc.cnr.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idea.ifc.cnr.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ifc.cnr.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://faq.ifc.cnr.it/index.php?sid=51484&lang=it&action=show&cat=3"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ifc.cnr.it/index.php/en"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for CNR Institute of Clinical Physiology users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti di CNR Istituto di Fisiologia Clinica"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CNR Institute of Clinical Physiology"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CNR Istituto di Fisiologia Clinica"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAPXQh7YfSjXSWrkZLXYT1bUm2Vj+MA0GCSqGSIb3DQEB\nBQUAMBoxGDAWBgNVBAMTD2lkZWEuaWZjLmNuci5pdDAeFw0wODExMjYxNjA0MTBa\nFw0yODExMjYxNjA0MTBaMBoxGDAWBgNVBAMTD2lkZWEuaWZjLmNuci5pdDCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAI6NBU4faqRoOEnab3DbjGPsno9a\n1j712yFWDpdxErwUmAAHUh83NmtwVKRSrVvZmymnGGEjBk7/2jTGfmpC/YdGm67j\nn/dbU3WCTnl+RhJh4/LrSJCsUmgw9r0JNo5BfHA781xvBIGprsHD8GOnmNIdK4nV\ndGSrslc3VpSP8Zhlaov5F5bGZuHa/dFM/GVI4YLZR0O2QNm6U3gIWM9TeaLofmA3\np1fFP/3CZlPPyNAHWUkylA4XebuLFwrA4bzpgJgkTdmc1NclfF/qPmYLsE6dxag1\n7mQNp4RPdvgf43Ivmp6Cx4UMYc1+Wu0DolG1c/vesbMnK3QdIYy3xFDjAnsCAwEA\nAaNlMGMwQgYDVR0RBDswOYIPaWRlYS5pZmMuY25yLml0hiZodHRwczovL2lkZWEu\naWZjLmNuci5pdC9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUAMIFF2Om2oTqwjUJ\nWyZb5He25R8wDQYJKoZIhvcNAQEFBQADggEBAG2loG5n8grIuX6Vr1H77E3N94O4\nQtNspFXjFOEtsFvgb+glgIRFd/4L3HCW2oWAebZ/s9JRXn+6YcrOA22SP+xg1OcQ\nJWlqTvr3XiSYQ9FjudBSt39cnOxlmwp/7SptWqLeMiZYs/muHaxcLeQMJ7W6z3wc\nSkvwMpHeTlORAfPh3RByRH9MD4rum56xY4CMP0HzcXg3iLvlBgxp63VnT216xKfR\neI8m4D0Jiu4VLtvkSAfUOcBpXPjW7KSsp6O+GMCHG+DHBcYfv8/FaP80IBenVNfd\nnvu7cp9h/xfMf1OV7tsIADMKQAeFLnIKyd74JxiM9rBSHLqWmcK2jklOHCc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CNR Istituto di Fisiologia Clinica"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CNR Institute of Clinical Physiology"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.ifc.cnr.it/index.php/it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.ifc.cnr.it/index.php/en"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consiglio Nazionale delle Ricerche (CNR)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National Research Council (CNR)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.idp.hhs.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@hhs.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Handelsh\u00f6gskolan i Stockholm"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.idp.hhs.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAPaVg+Pnce+JDTg4a490Fu28tq5UMA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEGxvZ2luLmlkcC5oaHMuc2UwHhcNMTQwMjE4MDgzNTI1\nWhcNMTcwMjE4MDgzNTI1WjAbMRkwFwYDVQQDExBsb2dpbi5pZHAuaGhzLnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApHfxE/NtoBdovpvyI+ShRpC9\nPvASzTQ7O2zsFwRsaooYlSeRxWq4jL4dyC7lm1Z5CPWgOAqcprYFkUI1wFhopOLU\nnYvqjc0jx8lSV9nqdSRC2MJrLbOS8V0CL8pAWeVbHE848nVeJS4elOr2EvYkZAij\nt78R/RvBJrVBpRKiAz1uvCGIyZ2HYt6bQBzWkG4L+pxC3z/ttjI2ql9ctWB3im00\nmzdmN7GW6bCQJlYWm8sy0iHI9Yt1aUMkXlBnrlUVNzq+cp+2hhuB7qy/XqhUVUMq\nPkBxpIkk6To2kCN+00uQP4oslomw3khz0GcrV88+nAIAAEeA3zrYbBvh05ABGQID\nAQABo2cwZTBEBgNVHREEPTA7ghBsb2dpbi5pZHAuaGhzLnNlhidodHRwczovL2xv\nZ2luLmlkcC5oaHMuc2UvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFIMbKfamMiy4\ns3T84Lli4DWzkdIbMA0GCSqGSIb3DQEBBQUAA4IBAQBZt9RVrBFSfR+F5L+zPQrl\n3rTfcJXbivC8hWORCF3mFf3Z7nlOY/c/0LvOMK5pXF+gU50kjMhQ56mQHcmph9NC\nsabeqXJNDw7XlwUTYW4JkN8UpbaPvdeWKnWIUS/3zheqKIwbngkef1VqFLLtPOOw\nIo1509ayQEdBHOVmkC6dyzfy0eLoYOhFWlsP2PGaUkwx2IPEkZIT9HYKSO29vJLh\nNpezy9C4aa5Dvq92Chi9C4SVsjbeq2LNccaYLMj9Gt9HBOoQHNn8bcgKn1I17T9S\nUXquEqvQ92VtMjTxgKgQRmQKkzigbL4FehuxJaF/BrO8KcshRQQkqdQeUvmY1/QC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hhs.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.idp.hhs.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.idp.hhs.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.idp.hhs.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.idp.hhs.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.idp.hhs.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.idp.hhs.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.idp.hhs.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.idp.hhs.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hhs.se"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r Handelsh\u00f6gskolan i Stockholm."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Stockholm School of Economics."
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.idp.hhs.se/idp/images/logo.png",
                    "height": "82",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "82"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Handelsh\u00f6gskolan i Stockholm"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Stockholm School of Economics"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "hhs.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:59.34161,18.05659"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.48.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAPaVg+Pnce+JDTg4a490Fu28tq5UMA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEGxvZ2luLmlkcC5oaHMuc2UwHhcNMTQwMjE4MDgzNTI1\nWhcNMTcwMjE4MDgzNTI1WjAbMRkwFwYDVQQDExBsb2dpbi5pZHAuaGhzLnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApHfxE/NtoBdovpvyI+ShRpC9\nPvASzTQ7O2zsFwRsaooYlSeRxWq4jL4dyC7lm1Z5CPWgOAqcprYFkUI1wFhopOLU\nnYvqjc0jx8lSV9nqdSRC2MJrLbOS8V0CL8pAWeVbHE848nVeJS4elOr2EvYkZAij\nt78R/RvBJrVBpRKiAz1uvCGIyZ2HYt6bQBzWkG4L+pxC3z/ttjI2ql9ctWB3im00\nmzdmN7GW6bCQJlYWm8sy0iHI9Yt1aUMkXlBnrlUVNzq+cp+2hhuB7qy/XqhUVUMq\nPkBxpIkk6To2kCN+00uQP4oslomw3khz0GcrV88+nAIAAEeA3zrYbBvh05ABGQID\nAQABo2cwZTBEBgNVHREEPTA7ghBsb2dpbi5pZHAuaGhzLnNlhidodHRwczovL2xv\nZ2luLmlkcC5oaHMuc2UvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFIMbKfamMiy4\ns3T84Lli4DWzkdIbMA0GCSqGSIb3DQEBBQUAA4IBAQBZt9RVrBFSfR+F5L+zPQrl\n3rTfcJXbivC8hWORCF3mFf3Z7nlOY/c/0LvOMK5pXF+gU50kjMhQ56mQHcmph9NC\nsabeqXJNDw7XlwUTYW4JkN8UpbaPvdeWKnWIUS/3zheqKIwbngkef1VqFLLtPOOw\nIo1509ayQEdBHOVmkC6dyzfy0eLoYOhFWlsP2PGaUkwx2IPEkZIT9HYKSO29vJLh\nNpezy9C4aa5Dvq92Chi9C4SVsjbeq2LNccaYLMj9Gt9HBOoQHNn8bcgKn1I17T9S\nUXquEqvQ92VtMjTxgKgQRmQKkzigbL4FehuxJaF/BrO8KcshRQQkqdQeUvmY1/QC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Handelsh\u00f6gskolan i Stockholm"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Stockholm School of Economics"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hhs.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HHS"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.eup.edinboro.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "boyles@edinboro.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ralph Boyles"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "boyles@edinboro.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ralph Boyles"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "boyles@edinboro.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ralph Boyles"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "boyles@edinboro.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ralph Boyles"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://idp.eup.edinboro.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.eup.edinboro.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.eup.edinboro.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUFianlABIFtAs3u/76iVhSuuoZOwwDQYJKoZIhvcNAQEL\nBQAwHzEdMBsGA1UEAwwUaWRwLmV1cC5lZGluYm9yby5lZHUwHhcNMTUxMTAyMTYw\nOTEzWhcNMzUxMTAyMTUwOTEzWjAfMR0wGwYDVQQDDBRpZHAuZXVwLmVkaW5ib3Jv\nLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANRhIJ6kQolqSWPU\nJ7ZgbiAf06AWsgCMBjro82YcYEMPlOuPmOc1Nu9mgd+SIVDyAWoGifohy7MAwtZK\nEBAb1N7D8mbwSGCmfULdbgQ79o0CBO/AGmXtgaLLQf2Xkk7jxCv3MKie+F+VB6V4\nBwQtxId8p4jrnAcZlRYVDD09GQD9hiWLbrnSV/mLYJgMX4RHgzPnxPWYb3r4GfvI\nxsKhL+opeVubvENsKN6CDzIE8Kp+dkH11nwDL4V3ZMEu/Ym7ngKIxFDfr7Mdc7Yf\np+/cZAY7C6u+7c+0Pncftl3AyJKehHrv2UwEwjeQhuKHkW+UxiGFHswgzPBA5SRQ\n1BWMSpUCAwEAAaNvMG0wHQYDVR0OBBYEFJUOYM/B5CgyRGRrs3wWaEo/nP5fMEwG\nA1UdEQRFMEOCFGlkcC5ldXAuZWRpbmJvcm8uZWR1hitodHRwczovL2lkcC5ldXAu\nZWRpbmJvcm8uZWR1L2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQDJ\nKmhNtUXQvB8HyONKSjJJHtQ6rLut8pn6vuRkdM7W04flENGI7Yby2JYgAm2f39Kl\noYm1LJvbsQWsXLizVIQZCtFKkdAtiH+am1qFXpYDIeWeq2Ha4rsvsu59GAjN7rah\no6RP+sRKFgt8HlMFaf74er6gtKIhZCbztDYehOiq/hkNTMbW9jbEdglrMYAlasNm\nzB/u9DYj/GrUTzuffJ4p4e4OQ+b43VUQqt/2V/jh7ZuAHFha+RaMEU0oKy+Gb3Zd\nZ1gkNL/ThIrfbDze5fC0/hfEFbUOksDJarAyckTgJ2y04gEg+rXTHou780DtxSuK\naujsroEAboRTQ/jskvQa"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edinboro.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Edinboro University of Pennsylvania"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Edinboro University of Pennsylvania"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.edinboro.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Edinboro University of Pennsylvania"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://kitstaccount01.tst.ki.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://kitstaccount01.tst.ki.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://account.tst.ki.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://account.tst.ki.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://account.tst.ki.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://account.tst.ki.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://account.tst.ki.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://account.tst.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Kontoaktiveringstj\u00c3\u00a4nst f\u00c3\u00b6r Karolinska Institutet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Account activation service for Karolinska Institutet"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kontoaktivering Karolinska Institutet (test)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Account activation Karolinska Institutet (test)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "kitstaccount01"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJAMotUlCm5wEsMA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDmtpdHN0YWNjb3VudDAxMB4XDTE1MDYxNzE0NDExM1oXDTI1MDYxNDE0NDEx\nM1owGTEXMBUGA1UEAxMOa2l0c3RhY2NvdW50MDEwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDULV+rqqGOAkO4OzuLHAie9mAXpDM3uMceCDsyJuHBBv3M\nLwN/kFR4hFOMuDl5ZlDMgKyoldfJgrzr9wNxX+yQowzG/I3sOfdKHHWuMYsDnfkQ\nw/BM7FMSPydi//iWRJp18Miv8qJGMMDyX4bBlVPvwsvA4hg9w/Lz7IztpZnF4T9l\noqEpc+9/wCOZw4YWiye078cg1jz7qgTYNiTNcYrq5IrcjXGHaqgBw1eXWeXNthFh\nHD9uTlpJ8oatCZWxo5iwgbyny0hOTTJw3qWcA6XhpDfP4aZQ9xu+AMz7hsaGxHs/\n3aJXLU2eHPzn24PYUXb+B8GUjvwBS65hsFdiylbzAgMBAAGjPDA6MBkGA1UdEQQS\nMBCCDmtpdHN0YWNjb3VudDAxMB0GA1UdDgQWBBQ5Kcc5QnyPLh/4Klhj7sXcuDvw\nOzANBgkqhkiG9w0BAQUFAAOCAQEAf3vDJ+yv6U6zRagOgoFGs0B6uuffoVbiZw0H\n+Vey5DJw6/hbVPZAKPf8FP/Ug/6V693IYCHOFGqSbJyroaggEJoih+eFdFwj1Kcg\nqv0u+jn59/5lwXMZAKEX3lVLZFpN4wqj5LoLPG9eEa+zCBZ0a6Uv32II8LaxWLim\nRPykkeSsNbO1KM0NFZc3S4PXyXAgC4peUykyHZiCekyJO1/3f82kZLUcoGQ3R6Gx\nsxAP68C4FVn1JXlyWwwF0JAhLUWkHo4bzMp8vXTI6C8Vn8TmSgcPTVZKcVUyljj7\n8yH9mWWt0u8sBHe2xo+WAhVOa9SUyyLGHeH+BNjPuT8fZO6p/w=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=kitstaccount01"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://account.tst.ki.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://account.tst.ki.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://account.tst.ki.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://account.tst.ki.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://account.tst.ki.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://login.fmach.eu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@fmach.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.fmach.eu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2013-01-03T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAL7RygPVs9a1+rjGCPpUtPOFwEDPMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmxvZ2luLmZtYWNoLmV1MB4XDTExMDYxMDA3NDEzNloX\nDTMxMDYxMDA3NDEzNlowGTEXMBUGA1UEAxMObG9naW4uZm1hY2guZXUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCgvLOdY/V7PGWb7V1/vNzCeZm+9TwO\nX1GsQmZY6D2Fga4FVcHbyhQNmZ2VrOi/JvC5SptjQZjQkKee4BUfgiieqhnwTfdI\nOV0ZMESh0YwXMkjRomZwjdnf6Z4i2LS4tbmZN1ajYkYqUprce5JwaslCw5UAIeUU\nFsimxhaLNnUdFgxbVpa1hWUEN2KHCfYZMCbXwumheaywWlSZqEWh1C5fBNgVb3Rs\ncyfaiz9t7N4GAf3EGP9MhR2pCRJXt619hUKV6mw6CDRfoTx2bYXuFPeIrLwWun/e\n9h73eWLnIAZlLkvcQ7sy6u+jYxOcNLKXSFhGyEE3zBF2/t3zuU3zA2oxAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmxvZ2luLmZtYWNoLmV1hiVodHRwczovL2xvZ2luLmZt\nYWNoLmV1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQY45TiPjkTzOErxnp12W9S\nCVH3ITANBgkqhkiG9w0BAQUFAAOCAQEAAoSAjAdcuIdCgDppnwVN9D7O12cTz8R2\ncYeudMepYKBaxKaskNMVp3FdfW/dc06JRBZm4fkf9wENsweDmhup0LoEkpbPkwsn\nRprHixFjI9xrgp4Zet8rYTv/o8/LojuPVm/fmJiw0GCJ0u0hw53ZlXXM60DvXXoQ\n2BlaYyHT1YTRi9t00RKB0s2poxPrleuS/VRSByhj9Ff2OFTkrpRhf09gy2NgjYbB\nTXqc4gocZlFG277Sgl/6aJfl0lfQPgPE/dxVNZlPDXsjIiSUcoZxxCn3OgL/BvnO\nuvwjEOFt6flbryZ1Zz0z3DZK6p8V+wwSgUEXsY09lhmVtD0h++crnQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fmach.eu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.fmach.eu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.fmach.eu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.fmach.eu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.fmach.eu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.fmach.eu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.fmach.eu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.fmach.eu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.fmach.eu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.fmach.it/idem"
                  }
                ],
                "description": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti di Fondazione Edmund Mach - Istituto Agrario di San Michele all'Adige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Fondazione Edmund Mach - Istituto Agrario di San Michele all'Adige users"
                  }
                ],
                "display_name": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Fondazione Edmund Mach - Istituto Agrario di San Michele all'Adige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Edmund Mach Foundation - Istituto Agrario di San Michele all'Adige"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fmach.eu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAL7RygPVs9a1+rjGCPpUtPOFwEDPMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmxvZ2luLmZtYWNoLmV1MB4XDTExMDYxMDA3NDEzNloX\nDTMxMDYxMDA3NDEzNlowGTEXMBUGA1UEAxMObG9naW4uZm1hY2guZXUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCgvLOdY/V7PGWb7V1/vNzCeZm+9TwO\nX1GsQmZY6D2Fga4FVcHbyhQNmZ2VrOi/JvC5SptjQZjQkKee4BUfgiieqhnwTfdI\nOV0ZMESh0YwXMkjRomZwjdnf6Z4i2LS4tbmZN1ajYkYqUprce5JwaslCw5UAIeUU\nFsimxhaLNnUdFgxbVpa1hWUEN2KHCfYZMCbXwumheaywWlSZqEWh1C5fBNgVb3Rs\ncyfaiz9t7N4GAf3EGP9MhR2pCRJXt619hUKV6mw6CDRfoTx2bYXuFPeIrLwWun/e\n9h73eWLnIAZlLkvcQ7sy6u+jYxOcNLKXSFhGyEE3zBF2/t3zuU3zA2oxAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmxvZ2luLmZtYWNoLmV1hiVodHRwczovL2xvZ2luLmZt\nYWNoLmV1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQY45TiPjkTzOErxnp12W9S\nCVH3ITANBgkqhkiG9w0BAQUFAAOCAQEAAoSAjAdcuIdCgDppnwVN9D7O12cTz8R2\ncYeudMepYKBaxKaskNMVp3FdfW/dc06JRBZm4fkf9wENsweDmhup0LoEkpbPkwsn\nRprHixFjI9xrgp4Zet8rYTv/o8/LojuPVm/fmJiw0GCJ0u0hw53ZlXXM60DvXXoQ\n2BlaYyHT1YTRi9t00RKB0s2poxPrleuS/VRSByhj9Ff2OFTkrpRhf09gy2NgjYbB\nTXqc4gocZlFG277Sgl/6aJfl0lfQPgPE/dxVNZlPDXsjIiSUcoZxxCn3OgL/BvnO\nuvwjEOFt6flbryZ1Zz0z3DZK6p8V+wwSgUEXsY09lhmVtD0h++crnQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Fondazione Edmund Mach - Istituto Agrario di San Michele all'Adige"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Edmund Mach Foundation - Istituto Agrario di San Michele all'Adige"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fmach.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fmach.it/eng"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Fondazione Edmund Mach - Istituto Agrario di San Michele all'Adige"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Edmund Mach Foundation - Istituto Agrario di San Michele all'Adige"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso.ird.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "calvayrac"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "didier.calvayrac@ird.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "rouquette"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "julien.rouquette@ird.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.ird.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-12-05T17:22:15Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.ird.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.ird.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso.ird.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ird.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ird.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IRD - Institut de Recherche pour le D\u00e9veloppement"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IRD - Institut de Recherche pour le D\u00e9veloppement"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEzCCAfugAwIBAgIUVaH89Xx207IW1cTeMZoDrJ2S8cMwDQYJKoZIhvcNAQEF\nBQAwFTETMBEGA1UEAxMKc3NvLmlyZC5mcjAeFw0xMjEyMDQwODUzMTJaFw0zMjEy\nMDQwODUzMTJaMBUxEzARBgNVBAMTCnNzby5pcmQuZnIwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQCxoxms45eFcIYxIAqWg8xwg1WpmjsGFAeOnBYoldj2\nMm2bQSxgdA5wNgdHvpsE1NfsWatZ3o+Cu+lAeL4tbzhyeLcv/5tP7xW1lCUCOsnt\nU+71/QN+hd8t0cTZnOcIVQz2933j+GSlYLb7j4mkeOmH2N1t7eZUBHDHDzhTbRbo\nowW1vMec+I7kgS5hxoOJmthyGxqKquBiFbyVR6D2afe1AoFZCTgH5o34o0LJ56JC\nJ+7L86F1PKd8M8BRD/+Bgk5z01rP6iLE4CTw0aalcVAcwUhfu+lSQaQc+UnsAkb6\nIO0r2WpflOy/h3qDYAe5ZaoadAVF7DXI3XkkM7PLvoHXAgMBAAGjWzBZMDgGA1Ud\nEQQxMC+CCnNzby5pcmQuZnKGIWh0dHBzOi8vc3NvLmlyZC5mci9pZHAvc2hpYmJv\nbGV0aDAdBgNVHQ4EFgQUxuTYXqdJEQMDfLAcMpaizQmY728wDQYJKoZIhvcNAQEF\nBQADggEBAI0GQeWZzGLSJtpy/ThyIGBsvc9I4POytPsGTAXXjl225vxBW5wREjXT\n5iZYvqDcaRX7/5Ya0LuixjZd4vw0f/GxNVA1q7UrkYD186qwxdD9ERVBK4A8TKw+\nDTqPj960n+BmHjvfbO5kUiOCxRN8aUwkroiIuokjKo/F/ee4PPhJFmjkjC5UQnAR\nXmxFE6G9gZKzMxZsGStIeip2XgtC8+XSS5mO9sXG2AciRYb9A6yAbq1H6UHgCA4+\npNLOn4jzVVeC76NhcjDI5Uqx+XbQXfZoVsft8i6RsNXGCHWst5dsepdXMoeJOfkP\nkkuzfMwgp7mBgkel9B3MiVnSCXPSNNU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IRD - Institut de Recherche pour le D\u00e9veloppement"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ird.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IRD - Institut de Recherche pour le D\u00e9veloppement"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://weblogin.albany.edu/shibboleth/idp2",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "byates@albany.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bry-Ann Yates"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://weblogin.albany.edu/shibboleth/idp2",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://weblogin.albany.edu/idp2/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://weblogin.albany.edu/idp2/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://weblogin.albany.edu/idp2/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://weblogin.albany.edu:8444/idp2/profile/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://weblogin.albany.edu:8444/idp2/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "albany.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://maenad.csc.albany.edu/incommon/logo_A1_pms269-InCommon.png",
                    "lang": "en",
                    "height": "150",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "203"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University At Albany, State University of New York"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAKWha+CKTeinjttEcaqLm7fQSZLLMA0GCSqGSIb3DQEB\nBQUAMB4xHDAaBgNVBAMTE3dlYmxvZ2luLmFsYmFueS5lZHUwHhcNMDkwMjExMTk1\nNDE0WhcNMjkwMjExMTk1NDE0WjAeMRwwGgYDVQQDExN3ZWJsb2dpbi5hbGJhbnku\nZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAjAY1R6LqpUcsbpn3\n8AcJW/KtQTyVcdcHmkEeCdW3UNzd6ibmhRFcPVhXwY9Z8jAuHQLjIkPj4QuiaGXI\nlfRJBQkTnkWeGLrHCzZA7/eZ0uJxL+SBf84OiK2jSmLqw6xGAADE8GmcyBpTQe2d\nHDFDbLvsLc3UNs0U/WzIGEE5iPBd33UntVEYezO8vszjdKZr8r4ZRVTeSUe+qkgW\n19ncHiqrbPBT+5qK2j8PaCiFrOjc0ScnsqHkgxr5krBM//SGoFPc+2bClUtbF/ci\nwuNZ3RHxhkyxlwEwkhLyuhr9gpZDYH6mi/SKUXMcXdLBKev13ddXN3Is6JZxagXn\nqZv/cwIDAQABo20wazBKBgNVHREEQzBBghN3ZWJsb2dpbi5hbGJhbnkuZWR1hipo\ndHRwczovL3dlYmxvZ2luLmFsYmFueS5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0O\nBBYEFC5IsCUVHd9dT/Q7onCX7ItOnehlMA0GCSqGSIb3DQEBBQUAA4IBAQBy+8+Q\nvnDnS010CWPNF76wHA24ka7cX4FsV/+nsUbxCtL9lundZdBfzqTquy5GuF3j96ej\nfoXg0Vz9GOn/KtRDDCFz8Gym+8hZdvPQ/XOdxHW1kjb7EbbL/K8dLilUYR9B/IOZ\nAXr4j4M4Qrh3jyxoFP+a4QTkUj/9+bcDPmqwftxaRoUIGcmyRzUvwU5pl227UkNy\nnftVP/rsZZ6nr0wJBZfPbhiBDAuzamzI05QHB+sFskVXB6Z8h2KawwNSrjgc2poj\nQWzZNOuth932vN8p2Lc6iI5v5bC/QSDDBlZ7tl+Uj/ejZC9b9WG/y83RrM333twp\nKq1D/QWBwg4oa9Zq"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://wiki.albany.edu/x/A4ZvAg"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University At Albany, State University of New York"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.albany.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University At Albany, State University of New York"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://gitlab-dev.in2p3.fr/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "webmaster@in2p3.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://gitlab-dev.in2p3.fr/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-09-08T17:43:49Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/preprod"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/community"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CNRS"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dsi.cnrs.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CNRS"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://gitlab-dev.in2p3.fr/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Git collaborative hosting intended for IN2P3 staff and their associates (test instance)."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "H\u00e9bergement git collaboratif \u00e0 l'usage des personnels IN2P3 et de leurs collaborateurs (instance de test)."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://gitlab-dev.in2p3.fr/about/privacy.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IN2P3 - Gitlab dev"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IN2P3 - Gitlab dev"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIJAMq3CLil3CmcMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE2dpdGxhYi1kZXYuaW4ycDMuZnIwHhcNMTQxMDE3MDkwMTIyWhcNMjQxMDE0\nMDkwMTIyWjAeMRwwGgYDVQQDExNnaXRsYWItZGV2LmluMnAzLmZyMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzH82rDfD9niEHMAZXa6gHOxNkW4XSKv7\n7DtPOQ2Ft0z6eYkYrgCIadDx0btS8fCiTINg90OUbjYrrHvStbdWD2hKKOM5OAeo\nxQMRec+yZ93IDt67hrsDo8dqA8eBM+MicwmQbw3pHwQ4pQ73i6/ly3jTK+Iz/UQQ\n06jjuNKmVX7IXA75OFckM7jopUvZ1TuCrA0vg2L14qqp7zkuO3MP8pkX8CwRW1iV\nP0VaFOvztkIxMWT7Amacigqk16msg4M/swnrs5el6j97CAK5VJ/RD/OSvm61GjZF\nkbMPA1W2CRBVqF4+9J7YCOAbt00maZZeoXQPiLtfO1oOYKHBPslzrwIDAQABo2Ew\nXzA+BgNVHREENzA1ghNnaXRsYWItZGV2LmluMnAzLmZyhh5odHRwczovL2dpdGxh\nYi1kZXYuaW4ycDMuZnIvc3AwHQYDVR0OBBYEFCusYwwMg6gWFnDUd31Yb+blT7lA\nMA0GCSqGSIb3DQEBBQUAA4IBAQBebrDXws3zc1y+MulOe0B17GO68qdSbAaQkNuj\nsBkhPgP+ie1gqlgTvgpT5lO115K8o7ePcqnZ1CiHg1/Q7uyyKj2XX3JaXZkUrGvH\nTHNe8fYK+oRCoPth6Zpbho7MKITdjVwIOHhNh5xSsLm5ylvy5JCFyJxcv7QxMJ9L\n0HgVAHcaKrKDVRL2RqhpurBM+IRkepzQzoQuGAadDNnhHHsXvykwztVLWbiEfPLr\nf6D2GT5SNdfCzWafeUc9DseD43+58AMau3h2sBJbmVhkc4gW+2b2r010q67f4uJE\nBoZyB+cmraisCTXvHKNw8Jc97GlS9L5soe6vlTUh50RlVt24"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIJAMq3CLil3CmcMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE2dpdGxhYi1kZXYuaW4ycDMuZnIwHhcNMTQxMDE3MDkwMTIyWhcNMjQxMDE0\nMDkwMTIyWjAeMRwwGgYDVQQDExNnaXRsYWItZGV2LmluMnAzLmZyMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzH82rDfD9niEHMAZXa6gHOxNkW4XSKv7\n7DtPOQ2Ft0z6eYkYrgCIadDx0btS8fCiTINg90OUbjYrrHvStbdWD2hKKOM5OAeo\nxQMRec+yZ93IDt67hrsDo8dqA8eBM+MicwmQbw3pHwQ4pQ73i6/ly3jTK+Iz/UQQ\n06jjuNKmVX7IXA75OFckM7jopUvZ1TuCrA0vg2L14qqp7zkuO3MP8pkX8CwRW1iV\nP0VaFOvztkIxMWT7Amacigqk16msg4M/swnrs5el6j97CAK5VJ/RD/OSvm61GjZF\nkbMPA1W2CRBVqF4+9J7YCOAbt00maZZeoXQPiLtfO1oOYKHBPslzrwIDAQABo2Ew\nXzA+BgNVHREENzA1ghNnaXRsYWItZGV2LmluMnAzLmZyhh5odHRwczovL2dpdGxh\nYi1kZXYuaW4ycDMuZnIvc3AwHQYDVR0OBBYEFCusYwwMg6gWFnDUd31Yb+blT7lA\nMA0GCSqGSIb3DQEBBQUAA4IBAQBebrDXws3zc1y+MulOe0B17GO68qdSbAaQkNuj\nsBkhPgP+ie1gqlgTvgpT5lO115K8o7ePcqnZ1CiHg1/Q7uyyKj2XX3JaXZkUrGvH\nTHNe8fYK+oRCoPth6Zpbho7MKITdjVwIOHhNh5xSsLm5ylvy5JCFyJxcv7QxMJ9L\n0HgVAHcaKrKDVRL2RqhpurBM+IRkepzQzoQuGAadDNnhHHsXvykwztVLWbiEfPLr\nf6D2GT5SNdfCzWafeUc9DseD43+58AMau3h2sBJbmVhkc4gW+2b2r010q67f4uJE\nBoZyB+cmraisCTXvHKNw8Jc97GlS9L5soe6vlTUh50RlVt24"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gitlab-dev.in2p3.fr/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://gitlab-dev.in2p3.fr/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "IN2P3 - Gitlab dev"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "IN2P3 - Gitlab dev"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "H\u00e9bergement git collaboratif \u00e0 l'usage des personnels IN2P3 et de leurs collaborateurs (instance de test)."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Git collaborative hosting intended for IN2P3 staff and their associates (test instance)."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "uid",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibprodapp.loyola.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jmccartin@loyola.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James McCartin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibprodapp.loyola.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibprodapp.loyola.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibprodapp.loyola.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUWLSGsZvWl23rl/5DUpC+PY0gdCowDQYJKoZIhvcNAQEF\nBQAwITEfMB0GA1UEAxMWc2hpYnByb2RhcHAubG95b2xhLmVkdTAeFw0xMTAyMTcx\nNjUyMDVaFw0zMTAyMTcxNjUyMDVaMCExHzAdBgNVBAMTFnNoaWJwcm9kYXBwLmxv\neW9sYS5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCQk81WTkU5\n3/Uns2puutfJt6fcr6cp8g0PLhU7TdS824eRZRquLENS9zP8Qutne8pziezilohM\nM+iDrOcqfyjXTG/NZYkzNy7pbx31YYUYMsEvP5OwIky/+GZrBUiAv15y9P5pJ+v7\nOT/BoJU97ZbRmyLgLlyXEtJQqZ4dbaSTNN9BKUUeIF34ejVY6KmUlk4MECa52MhV\nhANAQrzk154KLBPE/bM4TKZ1je7C2KTDo1dsyrN/nbRbvN3fZp5pEvsLNVgxSd85\nWwOKpSO1nxns53JrroU+1JyjcT1N3JEHokmZV94md61d82fPn8KvRI8klAQtjHmn\nlNL/cUXlcDQ/AgMBAAGjczBxMFAGA1UdEQRJMEeCFnNoaWJwcm9kYXBwLmxveW9s\nYS5lZHWGLWh0dHBzOi8vc2hpYnByb2RhcHAubG95b2xhLmVkdS9pZHAvc2hpYmJv\nbGV0aDAdBgNVHQ4EFgQU41Dh0cyz/KaBIxUJgmD2l3POdowwDQYJKoZIhvcNAQEF\nBQADggEBAGGNbwqn2yK4GO3IQAzqmc3t4g6hxVV4RiArdcl/vXka6T6/qabXADa2\n4FET0JtmQb82iwVWYB1trIFv0Vx/uNIzOW8runPeH845ue+KUJhLiOs+L5uO1qxj\nht/rW5SFnbRAX0v4KyQ3YUpnnL0335rWfuCVnyni2pzAfSzYb5/wJMvP74wI+FuJ\n/mtQFyJMOEnJVoUFX46HaugtDOQBrFR+lsjVgZxqlEFsVAkEumReRKRD7lKKFjV8\nFvQGSFkWMaNqaxat36IGB684E28xf/OPEJ+0L/x83anw+zz7oPZHhUVnK72ps3al\ntni4iLs+Rp8r9iFpwZc5M51492MyihM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "loyola.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibprodapp.loyola.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibprodapp.loyola.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibprodapp.loyola.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibprodapp.loyola.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibprodapp.loyola.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibprodapp.loyola.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "loyola.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Loyola University Maryland"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUWLSGsZvWl23rl/5DUpC+PY0gdCowDQYJKoZIhvcNAQEF\nBQAwITEfMB0GA1UEAxMWc2hpYnByb2RhcHAubG95b2xhLmVkdTAeFw0xMTAyMTcx\nNjUyMDVaFw0zMTAyMTcxNjUyMDVaMCExHzAdBgNVBAMTFnNoaWJwcm9kYXBwLmxv\neW9sYS5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCQk81WTkU5\n3/Uns2puutfJt6fcr6cp8g0PLhU7TdS824eRZRquLENS9zP8Qutne8pziezilohM\nM+iDrOcqfyjXTG/NZYkzNy7pbx31YYUYMsEvP5OwIky/+GZrBUiAv15y9P5pJ+v7\nOT/BoJU97ZbRmyLgLlyXEtJQqZ4dbaSTNN9BKUUeIF34ejVY6KmUlk4MECa52MhV\nhANAQrzk154KLBPE/bM4TKZ1je7C2KTDo1dsyrN/nbRbvN3fZp5pEvsLNVgxSd85\nWwOKpSO1nxns53JrroU+1JyjcT1N3JEHokmZV94md61d82fPn8KvRI8klAQtjHmn\nlNL/cUXlcDQ/AgMBAAGjczBxMFAGA1UdEQRJMEeCFnNoaWJwcm9kYXBwLmxveW9s\nYS5lZHWGLWh0dHBzOi8vc2hpYnByb2RhcHAubG95b2xhLmVkdS9pZHAvc2hpYmJv\nbGV0aDAdBgNVHQ4EFgQU41Dh0cyz/KaBIxUJgmD2l3POdowwDQYJKoZIhvcNAQEF\nBQADggEBAGGNbwqn2yK4GO3IQAzqmc3t4g6hxVV4RiArdcl/vXka6T6/qabXADa2\n4FET0JtmQb82iwVWYB1trIFv0Vx/uNIzOW8runPeH845ue+KUJhLiOs+L5uO1qxj\nht/rW5SFnbRAX0v4KyQ3YUpnnL0335rWfuCVnyni2pzAfSzYb5/wJMvP74wI+FuJ\n/mtQFyJMOEnJVoUFX46HaugtDOQBrFR+lsjVgZxqlEFsVAkEumReRKRD7lKKFjV8\nFvQGSFkWMaNqaxat36IGB684E28xf/OPEJ+0L/x83anw+zz7oPZHhUVnK72ps3al\ntni4iLs+Rp8r9iFpwZc5M51492MyihM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Loyola University Maryland"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.loyola.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Loyola University Maryland"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://library-test.lancs.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hartland"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:a.hartland@lancaster.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andy"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hartland"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:a.hartland@lancaster.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andy"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://library-test.lancs.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-28T09:21:19Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIVAO4MPYx98Q9Mfc6FlCYoAKZNQ3t+MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCMxITAfBgNVBAMTGGxpYnJhcnktdGVzdC5sYW5jcy5hYy51azAeFw0xNDEw\n\t\t\t\t\t\tMjcxNzEwNDhaFw0zNDEwMjcxNjEwNDhaMCMxITAfBgNVBAMTGGxpYnJhcnktdGVz\n\t\t\t\t\t\tdC5sYW5jcy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAI5A\n\t\t\t\t\t\t00q7vUBZKo8h05RQSFnBvp5pvj8p8kR+ILgATspc+KfndJk3RiDjgIliQVO+tIj4\n\t\t\t\t\t\tq0yfIvVP02t3f3oubmn91ANqysQ7hRW/JTSZKfy6RLs0Jbtno7vV5vMyOfx2PpwU\n\t\t\t\t\t\tEUT61IaM3VSHWp3/2kBaaCWN3zXeGMjYyTebuyNw9A/Zt/nxpGx6/W1byC0NkJNx\n\t\t\t\t\t\tDuX8cwfb9Rx99a78fo6fRiMrhPAyN2ugUzhbS+ern6s6bI/zesXR1X0Iq4gabSrN\n\t\t\t\t\t\tHJPv1ISAq8EFMocqTEhObRObWJO9jtQeo9YGbrU18fkw4NWrfHzuh14OOFeU4H45\n\t\t\t\t\t\tK+rSBU2BTWZx+KlDAyECAwEAAaN3MHUwVAYDVR0RBE0wS4IYbGlicmFyeS10ZXN0\n\t\t\t\t\t\tLmxhbmNzLmFjLnVrhi9odHRwczovL2xpYnJhcnktdGVzdC5sYW5jcy5hYy51ay9p\n\t\t\t\t\t\tZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU3rT0JaaohNxRSvMvk3iSq1MsjGkwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBADEdnzRF8dya8o+OZ9lEILST2bmyDcjUZyMXwnIcaLUq\n\t\t\t\t\t\tY5yxyFigIi4eK7Kzm1AvyOZEWQ9lPecR1VTyIoOAw/xYtTXUSYRDEwOc7/w/A/86\n\t\t\t\t\t\tqklOjDxnweuyswx/HpQ/rIH8TA65WYEiYgzA3o1HyJgqSdOvKdwTSHYMSs+GZpE3\n\t\t\t\t\t\trMEfC31HBuMFvn1nVJJD77CU7sP6OHLPlAjNc1vlnMHVvoGgw+4s6jCNBqtReKW7\n\t\t\t\t\t\tjs74IwmAPaxVM3IXz0laUEijn+KlMBnOn3z/G/RWrn97NBdbuNyq7zBI0DjWLQHj\n\t\t\t\t\t\tw9J0l69gw9nG5FltJm4dXurNFt58piC0BtrCKTTdvS0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lancaster.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://library-test.lancs.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://library-test.lancs.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://library-test.lancs.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://library-test.lancs.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://library-test.lancs.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://library-test.lancs.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://library-test.lancs.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://library-test.lancs.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lancaster.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://library.lancs.ac.uk/img/mdui-logo-test.png",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lancaster University Library (Test)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIVAO4MPYx98Q9Mfc6FlCYoAKZNQ3t+MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCMxITAfBgNVBAMTGGxpYnJhcnktdGVzdC5sYW5jcy5hYy51azAeFw0xNDEw\n\t\t\t\t\t\tMjcxNzEwNDhaFw0zNDEwMjcxNjEwNDhaMCMxITAfBgNVBAMTGGxpYnJhcnktdGVz\n\t\t\t\t\t\tdC5sYW5jcy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAI5A\n\t\t\t\t\t\t00q7vUBZKo8h05RQSFnBvp5pvj8p8kR+ILgATspc+KfndJk3RiDjgIliQVO+tIj4\n\t\t\t\t\t\tq0yfIvVP02t3f3oubmn91ANqysQ7hRW/JTSZKfy6RLs0Jbtno7vV5vMyOfx2PpwU\n\t\t\t\t\t\tEUT61IaM3VSHWp3/2kBaaCWN3zXeGMjYyTebuyNw9A/Zt/nxpGx6/W1byC0NkJNx\n\t\t\t\t\t\tDuX8cwfb9Rx99a78fo6fRiMrhPAyN2ugUzhbS+ern6s6bI/zesXR1X0Iq4gabSrN\n\t\t\t\t\t\tHJPv1ISAq8EFMocqTEhObRObWJO9jtQeo9YGbrU18fkw4NWrfHzuh14OOFeU4H45\n\t\t\t\t\t\tK+rSBU2BTWZx+KlDAyECAwEAAaN3MHUwVAYDVR0RBE0wS4IYbGlicmFyeS10ZXN0\n\t\t\t\t\t\tLmxhbmNzLmFjLnVrhi9odHRwczovL2xpYnJhcnktdGVzdC5sYW5jcy5hYy51ay9p\n\t\t\t\t\t\tZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU3rT0JaaohNxRSvMvk3iSq1MsjGkwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBADEdnzRF8dya8o+OZ9lEILST2bmyDcjUZyMXwnIcaLUq\n\t\t\t\t\t\tY5yxyFigIi4eK7Kzm1AvyOZEWQ9lPecR1VTyIoOAw/xYtTXUSYRDEwOc7/w/A/86\n\t\t\t\t\t\tqklOjDxnweuyswx/HpQ/rIH8TA65WYEiYgzA3o1HyJgqSdOvKdwTSHYMSs+GZpE3\n\t\t\t\t\t\trMEfC31HBuMFvn1nVJJD77CU7sP6OHLPlAjNc1vlnMHVvoGgw+4s6jCNBqtReKW7\n\t\t\t\t\t\tjs74IwmAPaxVM3IXz0laUEijn+KlMBnOn3z/G/RWrn97NBdbuNyq7zBI0DjWLQHj\n\t\t\t\t\t\tw9J0l69gw9nG5FltJm4dXurNFt58piC0BtrCKTTdvS0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lancaster University Library (Test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lancaster.ac.uk/library/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Lancaster"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.george-monoux.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.george-monoux.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/george-monoux.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/george-monoux.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "george-monoux.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Sir George Monoux College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.george-monoux.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://eduspot.crous-amiens.fr/authsaml2/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "informatique@crous-amiens.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://eduspot.crous-amiens.fr/authsaml2/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2016-01-26T13:53:04Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/wifi"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/national"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS d'Amiens"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.crous-amiens.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS d'Amiens"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://eduspot.crous-amiens.fr/authsaml2/singleSignOnPost",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIESTCCAzGgAwIBAgIJANm5Tx+6LRFxMA0GCSqGSIb3DQEBBQUAMIG6MQswCQYD\nVQQGEwJGUjERMA8GA1UECAwIUGljYXJkaWUxDzANBgNVBAcMBkFtaWVuczEmMCQG\nA1UECgwdQ0VOVFJFIE9FVVZSRVMgVU5JViBTQ09MQUlSRVMxEDAOBgNVBAsMB0Vk\ndXNwb3QxIDAeBgNVBAMMF2VkdXNwb3QuY3JvdXMtYW1pZW5zLmZyMSswKQYJKoZI\nhvcNAQkBFhxpbmZvcm1hdGlxdWVAY3JvdXMtYW1pZW5zLmZyMB4XDTE2MDEyNjEy\nNDk0N1oXDTI2MDEyMzEyNDk0N1owgboxCzAJBgNVBAYTAkZSMREwDwYDVQQIDAhQ\naWNhcmRpZTEPMA0GA1UEBwwGQW1pZW5zMSYwJAYDVQQKDB1DRU5UUkUgT0VVVlJF\nUyBVTklWIFNDT0xBSVJFUzEQMA4GA1UECwwHRWR1c3BvdDEgMB4GA1UEAwwXZWR1\nc3BvdC5jcm91cy1hbWllbnMuZnIxKzApBgkqhkiG9w0BCQEWHGluZm9ybWF0aXF1\nZUBjcm91cy1hbWllbnMuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQDAxHkkeX4b04wy0VYY46HehmnVSyqTvkAnHxgN+u8F2wqBq52aitCGB6NivmEg\na7uY4NR08tziqCqqkFhsaqqBFKBvQiyQBadr6Dm+SRHASyuLAHxnHlUQBI2qT9cp\njAiSjFseTK9shK8rymqZEeDQ6VhMC9jwfo137hTnoeO6NengaPC5/K02iXSxYqcQ\nCp73EtweLjSrkKS4Ipx167KEq+pcbigCzlUBRkBMC4U7b+SoT1U6D7ZTAMmCuhsj\njQQ3F82ke756JN8I1VCTbqp1bzZXjscpxVuKny/JzIr9rTrRiWDLSFUzIMgr+YJY\nvRaiIuAPcluGIa//GRa3v+/PAgMBAAGjUDBOMB0GA1UdDgQWBBRtMsgMn+UI6lyU\nAk2FuuM/LGrjfDAfBgNVHSMEGDAWgBRtMsgMn+UI6lyUAk2FuuM/LGrjfDAMBgNV\nHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCk6dWRJsKOkeUa3LFsSpB1Snj0\nAo9hsJj2mUU6wVD9x03gPXr3ffMSnvbRf1Xr9qvQBl8pdq5jpks9xY5k9dCOlODV\nNUiLx86HgvtX46eJJvU2tJaNUJllyoBb/0uuLq5T0BHsXBAf1ACq0rLeaogymQ3H\nxCtQ2WrBLunADcAomLScxcNu+zlHjFV6BIZp2DtdNPSaHxBU2opuegYfTG91jcn5\nkuEvQkrO4nGlv4eT2G9mfjVG7Qk9hcpAjr7jMSqcytnFWLCTr5c6Z6N/qsKpS9nw\nKBssS1tRsY8ksGJGBQ2VX/BTE9DpUMUzOcAcBZJ3c3q2s9yVcpUmNyIFrdR6"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIESTCCAzGgAwIBAgIJANm5Tx+6LRFxMA0GCSqGSIb3DQEBBQUAMIG6MQswCQYD\nVQQGEwJGUjERMA8GA1UECAwIUGljYXJkaWUxDzANBgNVBAcMBkFtaWVuczEmMCQG\nA1UECgwdQ0VOVFJFIE9FVVZSRVMgVU5JViBTQ09MQUlSRVMxEDAOBgNVBAsMB0Vk\ndXNwb3QxIDAeBgNVBAMMF2VkdXNwb3QuY3JvdXMtYW1pZW5zLmZyMSswKQYJKoZI\nhvcNAQkBFhxpbmZvcm1hdGlxdWVAY3JvdXMtYW1pZW5zLmZyMB4XDTE2MDEyNjEy\nNDk0N1oXDTI2MDEyMzEyNDk0N1owgboxCzAJBgNVBAYTAkZSMREwDwYDVQQIDAhQ\naWNhcmRpZTEPMA0GA1UEBwwGQW1pZW5zMSYwJAYDVQQKDB1DRU5UUkUgT0VVVlJF\nUyBVTklWIFNDT0xBSVJFUzEQMA4GA1UECwwHRWR1c3BvdDEgMB4GA1UEAwwXZWR1\nc3BvdC5jcm91cy1hbWllbnMuZnIxKzApBgkqhkiG9w0BCQEWHGluZm9ybWF0aXF1\nZUBjcm91cy1hbWllbnMuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQDAxHkkeX4b04wy0VYY46HehmnVSyqTvkAnHxgN+u8F2wqBq52aitCGB6NivmEg\na7uY4NR08tziqCqqkFhsaqqBFKBvQiyQBadr6Dm+SRHASyuLAHxnHlUQBI2qT9cp\njAiSjFseTK9shK8rymqZEeDQ6VhMC9jwfo137hTnoeO6NengaPC5/K02iXSxYqcQ\nCp73EtweLjSrkKS4Ipx167KEq+pcbigCzlUBRkBMC4U7b+SoT1U6D7ZTAMmCuhsj\njQQ3F82ke756JN8I1VCTbqp1bzZXjscpxVuKny/JzIr9rTrRiWDLSFUzIMgr+YJY\nvRaiIuAPcluGIa//GRa3v+/PAgMBAAGjUDBOMB0GA1UdDgQWBBRtMsgMn+UI6lyU\nAk2FuuM/LGrjfDAfBgNVHSMEGDAWgBRtMsgMn+UI6lyUAk2FuuM/LGrjfDAMBgNV\nHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCk6dWRJsKOkeUa3LFsSpB1Snj0\nAo9hsJj2mUU6wVD9x03gPXr3ffMSnvbRf1Xr9qvQBl8pdq5jpks9xY5k9dCOlODV\nNUiLx86HgvtX46eJJvU2tJaNUJllyoBb/0uuLq5T0BHsXBAf1ACq0rLeaogymQ3H\nxCtQ2WrBLunADcAomLScxcNu+zlHjFV6BIZp2DtdNPSaHxBU2opuegYfTG91jcn5\nkuEvQkrO4nGlv4eT2G9mfjVG7Qk9hcpAjr7jMSqcytnFWLCTr5c6Z6N/qsKpS9nw\nKBssS1tRsY8ksGJGBQ2VX/BTE9DpUMUzOcAcBZJ3c3q2s9yVcpUmNyIFrdR6"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://eduspot.crous-amiens.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Service to provide internet to students in universitary restaurants"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Cr\u00e9ation d'un portail pour la connexion des \u00e9tudiants au wi-fi dans les restaurants universitaires."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Crous Amiens-Picardie Eduspot"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Crous Amiens-Picardie Eduspot"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://mah.hr.evry.se/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "primulasupport@evry.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Primula"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://mah.hr.evry.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Evry HR Solutions AB"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.evry.se/it-tjanster/applikationstjanster-och-losningar/personal-och-lonesystem/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Evry HR Solutions AB"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Webgr\u00e4nssnittet till HR-systemet Primula fr\u00e5n EVRY HR Solutions AB f\u00f6r anst\u00e4llda vid Malm\u00f6 h\u00f6gskola"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The web interface to the HR software system Primula from EVRY HR Solutions AB for employees at Malm\u00f6 University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Primula"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Primula"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDuDCCAqACBQCo2ygOMA0GCSqGSIb3DQEBBAUAMIGfMQswCQYDVQQGEwJTRTEQ\nMA4GA1UECBMHVXBwc2FsYTEdMBsGA1UEChMURXZyeSBIUiBTb2x1dGlvbnMgQUIx\nEDAOBgNVBAcTB1VwcHNhbGExEzARBgNVBAMTCmhyLmV2cnkuc2UxEDAOBgNVBAsT\nB1ByaW11bGExJjAkBgkqhkiG9w0BCQEWF3ByaW11bGFzdXBwb3J0QGV2cnkuY29t\nMB4XDTE1MDEyNzEzMTQ0M1oXDTI1MDEyNDEzMTQ0M1owgZ8xCzAJBgNVBAYTAlNF\nMRAwDgYDVQQIEwdVcHBzYWxhMR0wGwYDVQQKExRFdnJ5IEhSIFNvbHV0aW9ucyBB\nQjEQMA4GA1UEBxMHVXBwc2FsYTETMBEGA1UEAxMKaHIuZXZyeS5zZTEQMA4GA1UE\nCxMHUHJpbXVsYTEmMCQGCSqGSIb3DQEJARYXcHJpbXVsYXN1cHBvcnRAZXZyeS5j\nb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCvJstEPNIMU6Q+1Fie\nekZiInII7woqYNQ9cg30gvwYluNA9aKs9Rx1OXufcvxZEhcQ1R5zCe2gWa7I9bCi\ngyluonu51qmk++c7aMLIXU1pXhM/6sIXIHy36WZbabg7HYp4Ju+diUmV+LxWAe3c\nzjvoFWC3pr4mwJBeUkQtKk+UBLd4L6rOAM2htN6lyXduMcSJMSckS4aZqYMj02Dd\nhz3lMiSVErkA351af+oVC+6HghlnfNyiJbjGh+hslPcvnrBaOCX84/QI36X0NZjo\n7/o5vfmbfEM3K4YZklqhjkXOm+0KuRWj3DLyxqDyMURu4WNpMlap+kPhm1J64agx\nuo6rAgMBAAEwDQYJKoZIhvcNAQEEBQADggEBAEl9NSzAegcuz+J2ktf63LNRge/e\nGxWW8KIM2t5HyWYudHBTsVqlSNQEe1V/vmW/lwntct7gGHXwnPp8Ulb3JrGjJq6I\nNukeIMKSMJVHsCYTwbAqeCT6POaX6C8Uzs4CFV8VUv3x61Rbr7BKrYgxf2Q+CyG7\n2fWaucSmjZ56flYFTUmJ1sFzYuFKn9Ty5xPMV/eGmlT8kJ8HBH5E3cVQ+vVSoRYf\nfP/0el9T10aI13RD/03wXWCku1Ewx8Qqw+ANcN9HhZwdH23kpP+jYiBfOmhtCDh1\nDTGN04FIC5s+8yFP1O/+RrQ8DQRmS/dfyc8iOXxm5vsWIVAnwD5nX5WrSp4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mah.hr.evry.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mah.hr.evry.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://mah.hr.evry.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:artifact-01",
              "location": "https://mah.hr.evry.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:browser-post",
              "location": "https://mah.hr.evry.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Primula Web"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eppn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "norEduPersonNIN",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.2428.90.1.5",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.silverchair.com/accp/staging/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:technicaloperations@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:technicaloperations@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Operations"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.silverchair.com/accp/staging/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-06-18T14:48:07Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Silverchair Staging: Chest Publications"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://books.publications.chestnet.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Silverchair Science + Communications, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://accprc.silverchair.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://accprc.silverchair.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://accprc.silverchair.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://accprc.silverchair.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://accprc.silverchair.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://accprc.silverchair.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJAIgwGFzp7TWjMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\n\t\t\t\t\t\tBAMTFmFjY3ByYy5zaWx2ZXJjaGFpci5jb20wHhcNMTUwNjEwMTg0NjE5WhcNMjUw\n\t\t\t\t\t\tNjA3MTg0NjE5WjAhMR8wHQYDVQQDExZhY2NwcmMuc2lsdmVyY2hhaXIuY29tMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAklyQaxRYKzdEhY1PVEjB5rc/\n\t\t\t\t\t\t6qMi56X0dJS2bTzUpcLWwGlvz1wLXRvL/zjB/jRIu9q+l+r+D3JERMIvZzkwo07T\n\t\t\t\t\t\tZro/8ztmWSYjkahT3CHgcIb3AGbHW+dmhfbYD83jxxF3m/2MWSxL2dlGudXnSafg\n\t\t\t\t\t\t7alQ6YegRMFcgZtRb2J/tdtEmpHLTDxObReg8SX5/9TBziJttdfxw50gqk5yqX5L\n\t\t\t\t\t\tZ2Of/XeVdFiJuyLdBYVvuEYKOA1kyuIYdQ0sM9p/4PyAeR+Gtalthii48AWAOM9s\n\t\t\t\t\t\tIeO3dJm9J/KYoi0xCfygdKKSK7iNefMWznmrB2Rz880Aj0BkroyIYT3KbPWC6wID\n\t\t\t\t\t\tAQABo0QwQjAhBgNVHREEGjAYghZhY2NwcmMuc2lsdmVyY2hhaXIuY29tMB0GA1Ud\n\t\t\t\t\t\tDgQWBBTESYuwQWxtO/SstsiPsctYRKn9gDANBgkqhkiG9w0BAQUFAAOCAQEACAbj\n\t\t\t\t\t\tIqXabK0hoKQlSvfS3D6uLy8aahEcfuUSd5NXcdfdzpC4bZ2TMxTl32/6D7k0VgdE\n\t\t\t\t\t\tiNNzMbFcrElUGbD172qS2758YP0CtM59bMxFFQb53Z4YmWCEhTHaSp/VB03WomrC\n\t\t\t\t\t\tQ5oxsgvrNZKxaa7tYaZp8KhmSo0FZU5tVoCyTs8dzIu88PRaMUyjS2OYZj+ScNCv\n\t\t\t\t\t\t8zsvsQ8KNuTsQbAtnVZNdrrBCFwiBMNRoh3XE6AMX659IRZfGcEZS0RcH269NPLs\n\t\t\t\t\t\tJVHIKx9avGRJlYdd81XdQ9UAaGEhx1BWYRWSDmWWNnjU6O4l78SmQLikwPsLj5dP\n\t\t\t\t\t\tKJuHiHhmS7Pxi9kfyw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://accprc.silverchair.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://accprc.silverchair.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://accprc.silverchair.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://accprc.silverchair.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://accprc.silverchair.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://accprc.silverchair.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.winchester.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.winchester.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-01T17:03:35Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/winchester.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/winchester.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "winchester.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Winchester"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.winchester.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth2sp.ios.semcs.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:customerservice@iospress.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IOS Press Customer Service"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@semantico.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Semantico Service Desk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth2sp.ios.semcs.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-01T17:31:42Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ios Shibboleth 2 SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iospress.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Semantico Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.ios.semcs.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.ios.semcs.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.ios.semcs.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.ios.semcs.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.ios.semcs.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth2sp.ios.semcs.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth2sp.ios.semcs.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0jCCArqgAwIBAgIJAMXnSzQszPKAMA0GCSqGSIb3DQEBBQUAMGsxCzAJBgNV\n\t\t\t\t\t\tBAYTAlVLMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIwEAYD\n\t\t\t\t\t\tVQQKEwlzZW1hbnRpY28xJDAiBgNVBAMTG3NoaWJib2xldGgyc3AuaW9zLnNlbWNz\n\t\t\t\t\t\tLm5ldDAeFw0xNTExMDcwOTMyMzNaFw0zNTExMDIwOTMyMzNaMGsxCzAJBgNVBAYT\n\t\t\t\t\t\tAlVLMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIwEAYDVQQK\n\t\t\t\t\t\tEwlzZW1hbnRpY28xJDAiBgNVBAMTG3NoaWJib2xldGgyc3AuaW9zLnNlbWNzLm5l\n\t\t\t\t\t\tdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKezfolPR7LUR0ybuc+k\n\t\t\t\t\t\tr0ukNjOC8i8gK/jIdwRtD+atxKPl8A70u7n1VK6L6FOIc0PzQDjbXSpnbiXzFR6p\n\t\t\t\t\t\tVjZeRaD26HM0jO/Ay+CVnlvTJ1aSV7QYyvLeiXTBjGjpynkQg3tM0uaLFCPg/lQh\n\t\t\t\t\t\t41JPb0KiYlwpPLXWYfhZowcddCkjcG4PJT35idLKMW14e62TbwXBKcMhJoFL5+qQ\n\t\t\t\t\t\t6cZu3g6nosrdGiObtMLzNOvaPL6Fe7cOCOeqUjkPxjus/c/0GTb+nG3wab8Vg+yz\n\t\t\t\t\t\trIPiafN8x9ghDjPPrvAk2KmP6B2jKfg8cEURk/I/+xJi2PpZRzKbIDUR+vkS67wR\n\t\t\t\t\t\td2UCAwEAAaN5MHcwVgYDVR0RBE8wTYIbc2hpYmJvbGV0aDJzcC5pb3Muc2VtY3Mu\n\t\t\t\t\t\tbmV0hi5odHRwczovL3NoaWJib2xldGgyc3AuaW9zLnNlbWNzLm5ldC9zaGliYm9s\n\t\t\t\t\t\tZXRoMB0GA1UdDgQWBBShAg8uyeZf4gR6yaU+f5smbQoAfjANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEApynAOguOlwgnYQltZTBeqrkw11mc6oWpTPNheiHLHmaekTD793y+3HNO\n\t\t\t\t\t\thMJHM/8uvcCYfQHZzMuIxaDldH0YZiFseFCuGPZpblagEYRhDPEdL9zuIZOBJ0jo\n\t\t\t\t\t\t81OTT27yp+ky5lls9Osmrzn85OTuFMLfSRkyq5Yz2jVfbsgeFG8ouw7roaxRzGLo\n\t\t\t\t\t\tTKzodl+uyX9+AuRk8pyMq1N3iOkoth8Zu44E67QMj5klvg8gjbHFgPuVYuhq83N+\n\t\t\t\t\t\tReOQ+FcpuO5hS7L0bhpYICYJYidKZFWCsEBrHYub2bDLlM57tbowVy/SPg65ftcv\n\t\t\t\t\t\t3PPCuNuaSO0bOCP/EsX2q+VJZ4T0rg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.ios.semcs.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.ios.semcs.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.ios.semcs.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.ios.semcs.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.ios.semcs.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth2sp.ios.semcs.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.ios.semcs.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth2sp.ios.semcs.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth2sp.ios.semcs.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth2sp.ios.semcs.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://sts.ait.dtu.dk/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tato@dtu.dk"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://sts.ait.dtu.dk/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2013-11-29T11:29:26Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Danmarks Tekniske Universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Technical University of Denmark"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dtu.dk/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dtu.dk/english"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Danmarks Tekniske Universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Technical University of Denmark"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sts.ait.dtu.dk/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Form\u00e5let er at give ansatte fra WAYF-tilsluttede institutioner personlig adgang til samarbejdssites oprettet af DTU-ansatte."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The purpose is to provide employees from WAYF-connected organisations personalised access to collaboration sites enabled by DTU employees."
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Share DTU"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Share DTU"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sts.ait.dtu.dk/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sts.ait.dtu.dk/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sts.ait.dtu.dk/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Form\u00e5let er at give ansatte fra WAYF-tilsluttede institutioner personlig adgang til samarbejdssites oprettet af DTU-ansatte."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The purpose is to provide employees from WAYF-connected organisations personalised access to collaboration sites enabled by DTU employees."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Share DTU"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Share DTU"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "organizationName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "gn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.exacteditions.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@exacteditions.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Exact Editions Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bruce"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tim.bruce@exacteditions.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.exacteditions.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Exact Editions Limited"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.exacteditions.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Exact Editions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEMDCCAxigAwIBAgIJAISCsINDzLsWMA0GCSqGSIb3DQEBBQUAMIGYMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEPMA0GA1UECBMGTG9uZG9uMQ8wDQYDVQQHEwZMb25kb24xGjAYBgNV\n\t\t\t\t\t\tBAoTEUV4YWN0RWRpdGlvbnMgTHRkMSAwHgYDVQQDExdsb2dpbi5leGFjdGVkaXRp\n\t\t\t\t\t\tb25zLmNvbTEpMCcGCSqGSIb3DQEJARYac3lzYWRtaW5AZXhhY3RlZGl0aW9ucy5j\n\t\t\t\t\t\tb20wHhcNMTIxMjA1MTA0NzE5WhcNMjIxMjAzMTA0NzE5WjCBmDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxDzANBgNVBAgTBkxvbmRvbjEPMA0GA1UEBxMGTG9uZG9uMRowGAYDVQQKExFF\n\t\t\t\t\t\teGFjdEVkaXRpb25zIEx0ZDEgMB4GA1UEAxMXbG9naW4uZXhhY3RlZGl0aW9ucy5j\n\t\t\t\t\t\tb20xKTAnBgkqhkiG9w0BCQEWGnN5c2FkbWluQGV4YWN0ZWRpdGlvbnMuY29tMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzooyLuz1P5Qs4C0CZddAq4Ck\n\t\t\t\t\t\tzkLR04FgM97g8h41A1zDl3LpoILduq/KhKALIBMT3PPoctapBQFMgDtqBWzlQKJQ\n\t\t\t\t\t\twIEF4JkZ7BAvSNg9+bDJs1uUMt0O2Q7vbpjEEX4yDDuQ/tayJKzC7Ak6LXuGPtuc\n\t\t\t\t\t\t5+t5Hf4WNLrzOBPgkR0il/ndUPLr7KJSV7M6LwUbfmGpgmtgY0h+Tw0E/WJqKnnb\n\t\t\t\t\t\t/raLTqzA8diyn4CflRG214ClyUiQ5Z4r6bQ77QkNTTHTXrrQNn5ldGri8ZcESmqu\n\t\t\t\t\t\tBrvFDHTH3CQWk4+d8XYZIRVNWen9gSrIs7NQ3de4JQ3CWkhtFXzalZnUOPwRqwID\n\t\t\t\t\t\tAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVy\n\t\t\t\t\t\tYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQURh5aI0DQPxc3lwxBVaRrOB4/Rzgw\n\t\t\t\t\t\tHwYDVR0jBBgwFoAURh5aI0DQPxc3lwxBVaRrOB4/RzgwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAKVhcW6weezQma6IkhLqLzfxtGuEe41Aky7KQyHC350hWgWs377WLBVpEcVH\n\t\t\t\t\t\tCba/IEGQFz0hJlXFXHPjI+htQSkIFREHuc1SmL9CBsYS1G/4+Rt3TukjzP/MogiU\n\t\t\t\t\t\tBdV2TmE10Y6f2Q1ZQfKQaUjOgPwr/odpUZoT5EBx1Z0/JybrDVmJxxKW5CT4sWvW\n\t\t\t\t\t\t1PaHcO6MXXTYXUFW10yGFGGkkd3mz6vCUjz2fW9AfybyEeexs3oSW9Icg95WxYdO\n\t\t\t\t\t\tROoLTRIDq01SmDnaiyOVTkGjNkNpR7PKj8Tr91upnrB0sE0u+R6JjEoI2bHoOQI0\n\t\t\t\t\t\twKxM0RWUQo8Ocu512fz2GE89mfQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEMDCCAxigAwIBAgIJAISCsINDzLsWMA0GCSqGSIb3DQEBBQUAMIGYMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEPMA0GA1UECBMGTG9uZG9uMQ8wDQYDVQQHEwZMb25kb24xGjAYBgNV\n\t\t\t\t\t\tBAoTEUV4YWN0RWRpdGlvbnMgTHRkMSAwHgYDVQQDExdsb2dpbi5leGFjdGVkaXRp\n\t\t\t\t\t\tb25zLmNvbTEpMCcGCSqGSIb3DQEJARYac3lzYWRtaW5AZXhhY3RlZGl0aW9ucy5j\n\t\t\t\t\t\tb20wHhcNMTIxMjA1MTA0NzE5WhcNMjIxMjAzMTA0NzE5WjCBmDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxDzANBgNVBAgTBkxvbmRvbjEPMA0GA1UEBxMGTG9uZG9uMRowGAYDVQQKExFF\n\t\t\t\t\t\teGFjdEVkaXRpb25zIEx0ZDEgMB4GA1UEAxMXbG9naW4uZXhhY3RlZGl0aW9ucy5j\n\t\t\t\t\t\tb20xKTAnBgkqhkiG9w0BCQEWGnN5c2FkbWluQGV4YWN0ZWRpdGlvbnMuY29tMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzooyLuz1P5Qs4C0CZddAq4Ck\n\t\t\t\t\t\tzkLR04FgM97g8h41A1zDl3LpoILduq/KhKALIBMT3PPoctapBQFMgDtqBWzlQKJQ\n\t\t\t\t\t\twIEF4JkZ7BAvSNg9+bDJs1uUMt0O2Q7vbpjEEX4yDDuQ/tayJKzC7Ak6LXuGPtuc\n\t\t\t\t\t\t5+t5Hf4WNLrzOBPgkR0il/ndUPLr7KJSV7M6LwUbfmGpgmtgY0h+Tw0E/WJqKnnb\n\t\t\t\t\t\t/raLTqzA8diyn4CflRG214ClyUiQ5Z4r6bQ77QkNTTHTXrrQNn5ldGri8ZcESmqu\n\t\t\t\t\t\tBrvFDHTH3CQWk4+d8XYZIRVNWen9gSrIs7NQ3de4JQ3CWkhtFXzalZnUOPwRqwID\n\t\t\t\t\t\tAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVy\n\t\t\t\t\t\tYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQURh5aI0DQPxc3lwxBVaRrOB4/Rzgw\n\t\t\t\t\t\tHwYDVR0jBBgwFoAURh5aI0DQPxc3lwxBVaRrOB4/RzgwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAKVhcW6weezQma6IkhLqLzfxtGuEe41Aky7KQyHC350hWgWs377WLBVpEcVH\n\t\t\t\t\t\tCba/IEGQFz0hJlXFXHPjI+htQSkIFREHuc1SmL9CBsYS1G/4+Rt3TukjzP/MogiU\n\t\t\t\t\t\tBdV2TmE10Y6f2Q1ZQfKQaUjOgPwr/odpUZoT5EBx1Z0/JybrDVmJxxKW5CT4sWvW\n\t\t\t\t\t\t1PaHcO6MXXTYXUFW10yGFGGkkd3mz6vCUjz2fW9AfybyEeexs3oSW9Icg95WxYdO\n\t\t\t\t\t\tROoLTRIDq01SmDnaiyOVTkGjNkNpR7PKj8Tr91upnrB0sE0u+R6JjEoI2bHoOQI0\n\t\t\t\t\t\twKxM0RWUQo8Ocu512fz2GE89mfQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID8DCCAtigAwIBAgIJAKxba9CqnWAUMA0GCSqGSIb3DQEBBQUAMHkxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMQ8wDQYDVQQIEwZMb25kb24xDzANBgNVBAcTBkxvbmRvbjEbMBkGA1UE\n\t\t\t\t\t\tChMSRXhhY3QgRWRpdGlvbnMgTHRkMQswCQYDVQQLEwJJVDEeMBwGA1UEAxMVd3d3\n\t\t\t\t\t\tLmV4YWN0ZWRpdGlvbnMuY29tMB4XDTEwMDkwNjExMTY0NVoXDTIwMDkwMzExMTY0\n\t\t\t\t\t\tNVoweTELMAkGA1UEBhMCR0IxDzANBgNVBAgTBkxvbmRvbjEPMA0GA1UEBxMGTG9u\n\t\t\t\t\t\tZG9uMRswGQYDVQQKExJFeGFjdCBFZGl0aW9ucyBMdGQxCzAJBgNVBAsTAklUMR4w\n\t\t\t\t\t\tHAYDVQQDExV3d3cuZXhhY3RlZGl0aW9ucy5jb20wggEiMA0GCSqGSIb3DQEBAQUA\n\t\t\t\t\t\tA4IBDwAwggEKAoIBAQDXxRMVhOzIQL1SIn7l2fbUOxi6uRY48V/owYArPGWRgRYz\n\t\t\t\t\t\tLvs97rM5O/4SHKgvwEcnr7cUA+4800RwNFZYAMwmAlsGZA5mY2pM51Gs07r/2ivX\n\t\t\t\t\t\tbfalA2AaXFje/VQ6IqvDWCvLaZyrGfW+kxJqAgZn7yQEZvmIIHkcwpLeWim2kpgx\n\t\t\t\t\t\tNrsfrsYa9Nypj2GRL1hNDyd9McQLtE+3BHZNBrgjoqVHBcaViutGaVm+NNzNoLQq\n\t\t\t\t\t\tN6Jmxts9rqxaO4uCi3GOSHF4Wq6kwZ6G4q+NLd2aHyU8m+bygTD1zTKInw8Va3ow\n\t\t\t\t\t\tEgctIZrtAgWeQMbcOu0K28X4eC6x+Nj2m6F/JppzAgMBAAGjezB5MAkGA1UdEwQC\n\t\t\t\t\t\tMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRl\n\t\t\t\t\t\tMB0GA1UdDgQWBBRM5kk9f2DeMFkEc2yiaG74jtrINzAfBgNVHSMEGDAWgBRM5kk9\n\t\t\t\t\t\tf2DeMFkEc2yiaG74jtrINzANBgkqhkiG9w0BAQUFAAOCAQEAwbyMXwjSBkutbny+\n\t\t\t\t\t\t1PxWMuIKhWCEkKh/yNAs/7DBJkg1ytRryV3nXYmn0AQ0TwEouebQzG3mxDNZBMF3\n\t\t\t\t\t\tem2+1p4MLUaEos0XTze3OhVECYo231fw1YrioW9M8LEJzkcytvA5WY2avsXOeJRa\n\t\t\t\t\t\tuPp/iZNz6/4v0Sap+vij1u+pMQ5rV5pPL5cLmF6I0BHS93L5ky8J3Hz4oJMA1rJa\n\t\t\t\t\t\tHivwzjz5aLgvSWrxrWj733BvjmE7+/i/CVRi3S73fP9SrY4jAwbyxVlVdmwA/Q0s\n\t\t\t\t\t\tA7ecb0GjcvX16ir1D/d6Y3/E0guV3Ri4GpJ8/K3sz65n6Gqiwfm5yuehIOvniQih\n\t\t\t\t\t\tBvmkLw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID8DCCAtigAwIBAgIJAKxba9CqnWAUMA0GCSqGSIb3DQEBBQUAMHkxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMQ8wDQYDVQQIEwZMb25kb24xDzANBgNVBAcTBkxvbmRvbjEbMBkGA1UE\n\t\t\t\t\t\tChMSRXhhY3QgRWRpdGlvbnMgTHRkMQswCQYDVQQLEwJJVDEeMBwGA1UEAxMVd3d3\n\t\t\t\t\t\tLmV4YWN0ZWRpdGlvbnMuY29tMB4XDTEwMDkwNjExMTY0NVoXDTIwMDkwMzExMTY0\n\t\t\t\t\t\tNVoweTELMAkGA1UEBhMCR0IxDzANBgNVBAgTBkxvbmRvbjEPMA0GA1UEBxMGTG9u\n\t\t\t\t\t\tZG9uMRswGQYDVQQKExJFeGFjdCBFZGl0aW9ucyBMdGQxCzAJBgNVBAsTAklUMR4w\n\t\t\t\t\t\tHAYDVQQDExV3d3cuZXhhY3RlZGl0aW9ucy5jb20wggEiMA0GCSqGSIb3DQEBAQUA\n\t\t\t\t\t\tA4IBDwAwggEKAoIBAQDXxRMVhOzIQL1SIn7l2fbUOxi6uRY48V/owYArPGWRgRYz\n\t\t\t\t\t\tLvs97rM5O/4SHKgvwEcnr7cUA+4800RwNFZYAMwmAlsGZA5mY2pM51Gs07r/2ivX\n\t\t\t\t\t\tbfalA2AaXFje/VQ6IqvDWCvLaZyrGfW+kxJqAgZn7yQEZvmIIHkcwpLeWim2kpgx\n\t\t\t\t\t\tNrsfrsYa9Nypj2GRL1hNDyd9McQLtE+3BHZNBrgjoqVHBcaViutGaVm+NNzNoLQq\n\t\t\t\t\t\tN6Jmxts9rqxaO4uCi3GOSHF4Wq6kwZ6G4q+NLd2aHyU8m+bygTD1zTKInw8Va3ow\n\t\t\t\t\t\tEgctIZrtAgWeQMbcOu0K28X4eC6x+Nj2m6F/JppzAgMBAAGjezB5MAkGA1UdEwQC\n\t\t\t\t\t\tMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRl\n\t\t\t\t\t\tMB0GA1UdDgQWBBRM5kk9f2DeMFkEc2yiaG74jtrINzAfBgNVHSMEGDAWgBRM5kk9\n\t\t\t\t\t\tf2DeMFkEc2yiaG74jtrINzANBgkqhkiG9w0BAQUFAAOCAQEAwbyMXwjSBkutbny+\n\t\t\t\t\t\t1PxWMuIKhWCEkKh/yNAs/7DBJkg1ytRryV3nXYmn0AQ0TwEouebQzG3mxDNZBMF3\n\t\t\t\t\t\tem2+1p4MLUaEos0XTze3OhVECYo231fw1YrioW9M8LEJzkcytvA5WY2avsXOeJRa\n\t\t\t\t\t\tuPp/iZNz6/4v0Sap+vij1u+pMQ5rV5pPL5cLmF6I0BHS93L5ky8J3Hz4oJMA1rJa\n\t\t\t\t\t\tHivwzjz5aLgvSWrxrWj733BvjmE7+/i/CVRi3S73fP9SrY4jAwbyxVlVdmwA/Q0s\n\t\t\t\t\t\tA7ecb0GjcvX16ir1D/d6Y3/E0guV3Ri4GpJ8/K3sz65n6Gqiwfm5yuehIOvniQih\n\t\t\t\t\t\tBvmkLw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.exacteditions.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.exacteditions.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.exacteditions.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.exacteditions.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.exacteditions.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.exacteditions.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.exacteditions.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.exacteditions.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.exacteditions.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://login.exacteditions.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.exacteditions.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.exacteditions.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://informationservice.idoxgroup.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@idoxgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ukfederation@idoxgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://informationservice.idoxgroup.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-03-19T15:37:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IDOX Information Services Ltd: PLANEX"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://iis.idoxgroup.com/infoservice/index.cfm"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IDOX Information Services Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://informationservice.idoxgroup.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://informationservice.idoxgroup.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://informationservice.idoxgroup.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://informationservice.idoxgroup.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://informationservice.idoxgroup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Online access to UK public policy bibliographic database, from the 1980s to today"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PLANEX, The Idox Information Service"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDljCCAn4CAQAwDQYJKoZIhvcNAQEEBQAwgZAxCzAJBgNVBAYTAkdCMREwDwYD\n\t\t\t\t\t\tVQQIEwhTY290bGFuZDEQMA4GA1UEBxMHR2xhc2dvdzETMBEGA1UEChMKSURPWCBH\n\t\t\t\t\t\tcm91cDEcMBoGA1UECxMTSW5mb3JtYXRpb24gU2VydmljZTEpMCcGA1UEAxMgaW5m\n\t\t\t\t\t\tb3JtYXRpb25zZXJ2aWNlLmlkb3hncm91cC5jb20wHhcNMTAwMzE5MTM0MzAyWhcN\n\t\t\t\t\t\tMjAwMzE2MTM0MzAyWjCBkDELMAkGA1UEBhMCR0IxETAPBgNVBAgTCFNjb3RsYW5k\n\t\t\t\t\t\tMRAwDgYDVQQHEwdHbGFzZ293MRMwEQYDVQQKEwpJRE9YIEdyb3VwMRwwGgYDVQQL\n\t\t\t\t\t\tExNJbmZvcm1hdGlvbiBTZXJ2aWNlMSkwJwYDVQQDEyBpbmZvcm1hdGlvbnNlcnZp\n\t\t\t\t\t\tY2UuaWRveGdyb3VwLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAJtxqpaLhnY5M+Op1rdKcu4Q+NKkG9xTyhrVyD3q6Ebd3F2z7Pq4Ul++dsMy+eWO\n\t\t\t\t\t\t4KSwYjAFnIMS8uuuGCa9sagt9xHs/K2F5nGB+rAfkbW11LikdL9fuEmUc44/Qh1z\n\t\t\t\t\t\tD85p0GLoMHVdfJJTK3atAbXY6MExGvYCrnB6GnmqU14HW2M6jR64pxopBRobpgHn\n\t\t\t\t\t\tz3fH+ShiI57swZ3PQNSlpUjTM8oYNiBE8aiA9/4LdyBXK3MCZd2B8v6+OIcoJbB8\n\t\t\t\t\t\tJ5Xaqt/aUkMhAPZOgYTnvSwuj1vDnq5aKLJefw/ot2PvrVB60+v+ImP3OlMZ74qG\n\t\t\t\t\t\tzCtl1ahe2V5j+d5uooOpZt0CAwEAATANBgkqhkiG9w0BAQQFAAOCAQEAYy1VOTwC\n\t\t\t\t\t\tgb3FghRYG9j/2TXGBb1bBzZqjadF3xll1j9mRyKr9AajSSVWg+UrZGUVY3XRvBfB\n\t\t\t\t\t\tJnNZwDWamqw0iFwv+leY3IazhRqSONOiJiRQSzwPbUBkRTiefjg2mUYQBXj3uZw+\n\t\t\t\t\t\tOW5/UBFrqYN63pRYS7bK9fuAzda/3bVX+ySwp+GFoEatDd+3S8J07HaHWxUVcd3q\n\t\t\t\t\t\tDYGFIWBoJhWGJbsYbjmnI+A4a1o356y+CnWR1Xz/EHtgkIt4ZRYtja1tUVh/F+wy\n\t\t\t\t\t\tx9gf6TLgM8FeLWuNj4AIxVItjjDM76EyP63uGcJpkuRoyBY2IPoIv+h6lREA5DdN\n\t\t\t\t\t\tS5PKEEUqwEK65g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDljCCAn4CAQAwDQYJKoZIhvcNAQEEBQAwgZAxCzAJBgNVBAYTAkdCMREwDwYD\n\t\t\t\t\t\tVQQIEwhTY290bGFuZDEQMA4GA1UEBxMHR2xhc2dvdzETMBEGA1UEChMKSURPWCBH\n\t\t\t\t\t\tcm91cDEcMBoGA1UECxMTSW5mb3JtYXRpb24gU2VydmljZTEpMCcGA1UEAxMgaW5m\n\t\t\t\t\t\tb3JtYXRpb25zZXJ2aWNlLmlkb3hncm91cC5jb20wHhcNMTAwMzE5MTM0MzAyWhcN\n\t\t\t\t\t\tMjAwMzE2MTM0MzAyWjCBkDELMAkGA1UEBhMCR0IxETAPBgNVBAgTCFNjb3RsYW5k\n\t\t\t\t\t\tMRAwDgYDVQQHEwdHbGFzZ293MRMwEQYDVQQKEwpJRE9YIEdyb3VwMRwwGgYDVQQL\n\t\t\t\t\t\tExNJbmZvcm1hdGlvbiBTZXJ2aWNlMSkwJwYDVQQDEyBpbmZvcm1hdGlvbnNlcnZp\n\t\t\t\t\t\tY2UuaWRveGdyb3VwLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAJtxqpaLhnY5M+Op1rdKcu4Q+NKkG9xTyhrVyD3q6Ebd3F2z7Pq4Ul++dsMy+eWO\n\t\t\t\t\t\t4KSwYjAFnIMS8uuuGCa9sagt9xHs/K2F5nGB+rAfkbW11LikdL9fuEmUc44/Qh1z\n\t\t\t\t\t\tD85p0GLoMHVdfJJTK3atAbXY6MExGvYCrnB6GnmqU14HW2M6jR64pxopBRobpgHn\n\t\t\t\t\t\tz3fH+ShiI57swZ3PQNSlpUjTM8oYNiBE8aiA9/4LdyBXK3MCZd2B8v6+OIcoJbB8\n\t\t\t\t\t\tJ5Xaqt/aUkMhAPZOgYTnvSwuj1vDnq5aKLJefw/ot2PvrVB60+v+ImP3OlMZ74qG\n\t\t\t\t\t\tzCtl1ahe2V5j+d5uooOpZt0CAwEAATANBgkqhkiG9w0BAQQFAAOCAQEAYy1VOTwC\n\t\t\t\t\t\tgb3FghRYG9j/2TXGBb1bBzZqjadF3xll1j9mRyKr9AajSSVWg+UrZGUVY3XRvBfB\n\t\t\t\t\t\tJnNZwDWamqw0iFwv+leY3IazhRqSONOiJiRQSzwPbUBkRTiefjg2mUYQBXj3uZw+\n\t\t\t\t\t\tOW5/UBFrqYN63pRYS7bK9fuAzda/3bVX+ySwp+GFoEatDd+3S8J07HaHWxUVcd3q\n\t\t\t\t\t\tDYGFIWBoJhWGJbsYbjmnI+A4a1o356y+CnWR1Xz/EHtgkIt4ZRYtja1tUVh/F+wy\n\t\t\t\t\t\tx9gf6TLgM8FeLWuNj4AIxVItjjDM76EyP63uGcJpkuRoyBY2IPoIv+h6lREA5DdN\n\t\t\t\t\t\tS5PKEEUqwEK65g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://informationservice.idoxgroup.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://informationservice.idoxgroup.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://informationservice.idoxgroup.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://informationservice.idoxgroup.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://informationservice.idoxgroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://informationservice.idoxgroup.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://informationservice.idoxgroup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://informationservice.idoxgroup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://informationservice.idoxgroup.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://informationservice.idoxgroup.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib.newbury-college.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Elwell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:r-elwell@newbury-college.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Elwell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:r-elwell@newbury-college.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.newbury-college.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-05-17T14:27:39Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUKgGFTl/wyIVoEZcrAuaNGJkaS4AwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJTEjMCEGA1UEAxMac2hpYi5uZXdidXJ5LWNvbGxlZ2UuYWMudWswHhcNMTQw\n\t\t\t\t\t\tNDMwMTU1OTUzWhcNMzQwNDMwMTU1OTUzWjAlMSMwIQYDVQQDExpzaGliLm5ld2J1\n\t\t\t\t\t\tcnktY29sbGVnZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tALEO9V52NgElGB2494w+RP0YGpV97JXNQa7mSeSgrExS6EYfC+xq6GpShPq2CxZG\n\t\t\t\t\t\tds8DqfA6A4SZ9Br6MVw65X/9vuDu2rN9caivpV9v/Q9MEgkOlJK9NzgKqdZYLz/X\n\t\t\t\t\t\tpkkL9sqN5L5SQ85+dRa3OaiV2WeqL+Op4Zljp0MEnJXYcA7rFvPcwZiSXrb56xTl\n\t\t\t\t\t\tbqMKMuAPlDQ+GB46Z63uGGnXg4lm5eIh5txkl7hDeHZhVnnGQ8BZfsBvtRjCOyUm\n\t\t\t\t\t\tx5oW7gUsD0tFzC1ZSXtM69Ufy5KsLN24tlfDmU2D3G0KCjpgRwypbgRNKOCavn2q\n\t\t\t\t\t\tafjRy10kfcAKg740DO0v4W8CAwEAAaN7MHkwWAYDVR0RBFEwT4Iac2hpYi5uZXdi\n\t\t\t\t\t\tdXJ5LWNvbGxlZ2UuYWMudWuGMWh0dHBzOi8vc2hpYi5uZXdidXJ5LWNvbGxlZ2Uu\n\t\t\t\t\t\tYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFHm3jrIqUdXgKqgeoSsHsYWg\n\t\t\t\t\t\ta0miMA0GCSqGSIb3DQEBBQUAA4IBAQB2vb7dzO3rVcbWlAffs2ssjty0vACBKm5M\n\t\t\t\t\t\t1WoSA1j0DGIr9s8LxWn+On/L+JzR6ymXfGkK7WdVmVMZcD/zTm4fjFJOviNHAUwl\n\t\t\t\t\t\t3jttuRJtG6FLibv72jFLFyIF7a02ezNKViNbsX0s89zIHLSW7RA64DBp6pgQXDes\n\t\t\t\t\t\tIICc/5SxQeg7BRlfLHwGFe6l6N7L6OpXJccvAiEgMum/l0HVtOIQC0qW3tgyUohj\n\t\t\t\t\t\tV0IUrFMXIcCZ7rucxgmvsdp3f31bscAZfyqW5OvpnkZbXndLSRhseVgeeeyUOl9k\n\t\t\t\t\t\tt13oLz/71kVuQ4KeP949T8BcB33uLI+rJpCvWPPa25DFQvaSMkGl"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "newbury-college.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.newbury-college.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.newbury-college.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.newbury-college.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.newbury-college.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.newbury-college.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.newbury-college.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.newbury-college.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.newbury-college.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "newbury-college.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUKgGFTl/wyIVoEZcrAuaNGJkaS4AwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJTEjMCEGA1UEAxMac2hpYi5uZXdidXJ5LWNvbGxlZ2UuYWMudWswHhcNMTQw\n\t\t\t\t\t\tNDMwMTU1OTUzWhcNMzQwNDMwMTU1OTUzWjAlMSMwIQYDVQQDExpzaGliLm5ld2J1\n\t\t\t\t\t\tcnktY29sbGVnZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tALEO9V52NgElGB2494w+RP0YGpV97JXNQa7mSeSgrExS6EYfC+xq6GpShPq2CxZG\n\t\t\t\t\t\tds8DqfA6A4SZ9Br6MVw65X/9vuDu2rN9caivpV9v/Q9MEgkOlJK9NzgKqdZYLz/X\n\t\t\t\t\t\tpkkL9sqN5L5SQ85+dRa3OaiV2WeqL+Op4Zljp0MEnJXYcA7rFvPcwZiSXrb56xTl\n\t\t\t\t\t\tbqMKMuAPlDQ+GB46Z63uGGnXg4lm5eIh5txkl7hDeHZhVnnGQ8BZfsBvtRjCOyUm\n\t\t\t\t\t\tx5oW7gUsD0tFzC1ZSXtM69Ufy5KsLN24tlfDmU2D3G0KCjpgRwypbgRNKOCavn2q\n\t\t\t\t\t\tafjRy10kfcAKg740DO0v4W8CAwEAAaN7MHkwWAYDVR0RBFEwT4Iac2hpYi5uZXdi\n\t\t\t\t\t\tdXJ5LWNvbGxlZ2UuYWMudWuGMWh0dHBzOi8vc2hpYi5uZXdidXJ5LWNvbGxlZ2Uu\n\t\t\t\t\t\tYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFHm3jrIqUdXgKqgeoSsHsYWg\n\t\t\t\t\t\ta0miMA0GCSqGSIb3DQEBBQUAA4IBAQB2vb7dzO3rVcbWlAffs2ssjty0vACBKm5M\n\t\t\t\t\t\t1WoSA1j0DGIr9s8LxWn+On/L+JzR6ymXfGkK7WdVmVMZcD/zTm4fjFJOviNHAUwl\n\t\t\t\t\t\t3jttuRJtG6FLibv72jFLFyIF7a02ezNKViNbsX0s89zIHLSW7RA64DBp6pgQXDes\n\t\t\t\t\t\tIICc/5SxQeg7BRlfLHwGFe6l6N7L6OpXJccvAiEgMum/l0HVtOIQC0qW3tgyUohj\n\t\t\t\t\t\tV0IUrFMXIcCZ7rucxgmvsdp3f31bscAZfyqW5OvpnkZbXndLSRhseVgeeeyUOl9k\n\t\t\t\t\t\tt13oLz/71kVuQ4KeP949T8BcB33uLI+rJpCvWPPa25DFQvaSMkGl"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Newbury College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.newbury-college.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Newbury College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.metropolia.fi/idp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kaljunen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jani.kaljunen@metropolia.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jani"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Veikkolainen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jukka.veikkolainen@metropolia.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jukka"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.metropolia.fi/idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEbzCCA1egAwIBAgIQCc/9tdLS4HQLd5HGhihrEDANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQxMTAwMDAwMFoXDTE3MDQxMDIzNTk1OVowPzEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRowGAYDVQQDExFpZHAubWV0cm9w\nb2xpYS5maTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMhuaEYcvTxQ\nwONs2/tCwUNGN3cvP03SK+v4Gm+y3gezXXrISULJjY+sAz4qbuCtyQjewsLe3QL/\nP+fgrF8iWwLxvFANqT0PU3NbiTfweYw4imGF71uB1+BTDeTkVisCbg3ki+owshif\naKFbO0ukOTUTx5vlBBkw1xFMAAMkttThMWZaAzTFDqnDuNhHnSP9botMOT7MDNJG\nYZh0cXRpyHRRSYmjvcI59iPJwC/zQIoGWskwc3+UyhlFFSX1zF5cKOLQXo1i+VBc\nbqf3/4VJiABIKPeyxsVvFIdo2pkylqUmm8E+wppKfPhnuK5dW8afApaqU/A4p8eh\n9hWDMofDicMCAwEAAaOCAW4wggFqMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdX\nR+qQ47ntMB0GA1UdDgQWBBTgVJX1n83Ge6l78jjijOdYXkXNhTAOBgNVHQ8BAf8E\nBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUH\nAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0fBDMw\nMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5j\ncmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50\nZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29j\nc3AudGNzLnRlcmVuYS5vcmcwHAYDVR0RBBUwE4IRaWRwLm1ldHJvcG9saWEuZmkw\nDQYJKoZIhvcNAQEFBQADggEBAL7QxHjz3sE9LRXAFbxufA3DLDOvlzotP/x01Czh\n7kVp5CdUsMFZU1lPQ9Kxc5kAa+doh9m4ZEamsBdLdGx3eFZEmzq41n86EImHZhGb\ntWiMfx2qRTWga8WcYgAXW+6TzYP5CAxKxY4eBKKpvE9fsKxE5rKfByt+ZTQ51LgG\nb8SiSXWGmD5k1VIVZ0Y0W2OTmOuAk52Sq4QwaAaJaHWRMvvmX7HxeIDLHpAqxDcc\nqgNggMzs4qK6OjBIA6gCWwre1eRyeS2H1vC0rOhqqmLO5Y6vXw2odVYnKfD5pZHJ\nG+Dx7F2feFhAdfZyEz66oAuniAeUWSFMijlxsqfDKgfg5YY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "metropolia.fi"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.metropolia.fi/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.metropolia.fi/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "true",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.metropolia.fi/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.metropolia.fi/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.metropolia.fi/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "metropolia.fi"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Helsinki Metropolia University of Applied Sciences"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Metropolia yrkesh\u00f6gskola"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Metropolia-ammattikorkeakoulu"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "kalmar"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "finland"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "tags",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEbzCCA1egAwIBAgIQCc/9tdLS4HQLd5HGhihrEDANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQxMTAwMDAwMFoXDTE3MDQxMDIzNTk1OVowPzEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRowGAYDVQQDExFpZHAubWV0cm9w\nb2xpYS5maTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMhuaEYcvTxQ\nwONs2/tCwUNGN3cvP03SK+v4Gm+y3gezXXrISULJjY+sAz4qbuCtyQjewsLe3QL/\nP+fgrF8iWwLxvFANqT0PU3NbiTfweYw4imGF71uB1+BTDeTkVisCbg3ki+owshif\naKFbO0ukOTUTx5vlBBkw1xFMAAMkttThMWZaAzTFDqnDuNhHnSP9botMOT7MDNJG\nYZh0cXRpyHRRSYmjvcI59iPJwC/zQIoGWskwc3+UyhlFFSX1zF5cKOLQXo1i+VBc\nbqf3/4VJiABIKPeyxsVvFIdo2pkylqUmm8E+wppKfPhnuK5dW8afApaqU/A4p8eh\n9hWDMofDicMCAwEAAaOCAW4wggFqMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdX\nR+qQ47ntMB0GA1UdDgQWBBTgVJX1n83Ge6l78jjijOdYXkXNhTAOBgNVHQ8BAf8E\nBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUH\nAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0fBDMw\nMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5j\ncmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50\nZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29j\nc3AudGNzLnRlcmVuYS5vcmcwHAYDVR0RBBUwE4IRaWRwLm1ldHJvcG9saWEuZmkw\nDQYJKoZIhvcNAQEFBQADggEBAL7QxHjz3sE9LRXAFbxufA3DLDOvlzotP/x01Czh\n7kVp5CdUsMFZU1lPQ9Kxc5kAa+doh9m4ZEamsBdLdGx3eFZEmzq41n86EImHZhGb\ntWiMfx2qRTWga8WcYgAXW+6TzYP5CAxKxY4eBKKpvE9fsKxE5rKfByt+ZTQ51LgG\nb8SiSXWGmD5k1VIVZ0Y0W2OTmOuAk52Sq4QwaAaJaHWRMvvmX7HxeIDLHpAqxDcc\nqgNggMzs4qK6OjBIA6gCWwre1eRyeS2H1vC0rOhqqmLO5Y6vXw2odVYnKfD5pZHJ\nG+Dx7F2feFhAdfZyEz66oAuniAeUWSFMijlxsqfDKgfg5YY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Metropolia-ammattikorkeakoulu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Helsinki Metropolia University of Applied Sciences"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Metropolia yrkesh\u00f6gskola"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.metropolia.fi"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.metropolia.fi"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.metropolia.fi"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Metropolia-ammattikorkeakoulu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Helsinki Metropolia University of Applied Sciences"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Metropolia yrkesh\u00f6gskola"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://se.timeedit.net/su-student-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@evolvera.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TimeEdit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://se.timeedit.net/su-student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://se.timeedit.net/web/su/db1/timeedit/ssoLogout/su_stud_saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TimeEdit, utvecklat av Evolvera AB"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TimeEdit, developed by Evolvera AB"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TimeEdit f\u00f6r studenter vid Stockholms universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TimeEdit for students at Stockholm university"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAggCCQDSfJxeKVOg3jANBgkqhkiG9w0BAQUFADBSMQswCQYDVQQGEwJTRTESMBAGA1UE\nBxQJR8O2dGVib3JnMRQwEgYDVQQKEwtUaW1lRWRpdCBBQjEZMBcGA1UEAxMQYXV0aC50aW1lZWRp\ndC5zZTAeFw0xMzA2MTQwNzE0MTlaFw0xNTA2MTQwNzE0MTlaMFIxCzAJBgNVBAYTAlNFMRIwEAYD\nVQQHFAlHw7Z0ZWJvcmcxFDASBgNVBAoTC1RpbWVFZGl0IEFCMRkwFwYDVQQDExBhdXRoLnRpbWVl\nZGl0LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoL+lyBleTM0UGwGPLXPcfBMr\nomnPqP8+qlE+rOs0mEbvNyXdEWT0Z5P/XoMVfERJQQ6v5DAJF4c3o1BiPshZL8cj6QdLuJXLfVNG\nu5mzq/lKpB/n38Y4cWYxIyNtBcV9vcKDIRUbQP/27nEPMsbs2IaCXf6V3l3yQqbymZTyd8nBfZZF\nG95zDKBTSD5UQ3XW+LbvjKSZY4qDjyFkeOfj8kVyltWTHRMvKTKGLeNrGyCFiaMY/vfyA22gOyz4\nO2cY/oqFs8+82AOs3Si4+eGkFAq3CdEWSE4c69oDrzEWk+bKgxw5qyhWQ/13eh8AiZMDeqhT7q32\nRthqEp8GfwPM1QIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCRsLvMI4OJ076STPIyxnwk6bXRG5RL\nMR1pJ3umMNCa1LR1RnH1feuvm9dxerUTow7bPIsarJarh0iEIj2kLtu/prPm+ZcAKeEjh27pSM7m\n1F0XBkDqeP1msR+7g0aHlt0MzrKm/Esb1JX9YCO3MHl1XFc8xSnv2bxKWvER+tmDWkFrC0y1u2+H\nB/CfyES8ntBP6F7aZ6UQ4GTrqF0MZNGBoWFyXecGe5XEwWJwP4otSrJ2q7cbQU33xEcri0dHiMMl\nTiN/6f25dSm5UFCxqWGGAQndGfn/tE5FSqJlrHnbF2M6x4eH3MEIbHebI+nJlk6ASPdgIssvsDcd\nGImnaeS4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://se.timeedit.net/web/su/db1/timeedit/ssoResponse/su_stud_saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "false"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://idp.yorksj.ac.uk/oala",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Green"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.green1@yorksj.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marcus"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Patterson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:s.patterson@yorksj.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.yorksj.ac.uk/oala",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-09-16T09:00:37Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.yorksj.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.yorksj.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "yorksj.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIIC/BGdv33SfYwDQYJKoZIhvcNAQEFBQAwPTEgMB4GA1UE\n\t\t\t\t\t\tCgwXWW9yayBTdCBKb2huIFVuaXZlcnNpdHkxGTAXBgNVBAMMEGlkcC55b3Jrc2ou\n\t\t\t\t\t\tYWMudWswHhcNMTQwNTA3MTEyMzUyWhcNMjQwNTA3MTEyMzUyWjA9MSAwHgYDVQQK\n\t\t\t\t\t\tDBdZb3JrIFN0IEpvaG4gVW5pdmVyc2l0eTEZMBcGA1UEAwwQaWRwLnlvcmtzai5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAI9vhp37rXZQ6N3J\n\t\t\t\t\t\tjMVnA5XL4e8R6BpZf8y9xKCDoxI2xBB5YlwLuXe0jDLQtLHkcQk1sOcQPlz5Ssi2\n\t\t\t\t\t\t5BaYCFnifo2yaf/TzqmaG6/+IODNySYbGT6AHTeRjagYLmv9ZEzfuoA1rDQ/AvLO\n\t\t\t\t\t\tzckx0qyR4UVwrlxo9QAXILlCzKiE/+2KN7FSzRW/pPm4iWcwpCR+MMtS6CGdb/cZ\n\t\t\t\t\t\tL8Eo91uQ1ErGKfD30PDCnDybCayqk6v8I+AHOoxHqcowGoUu4k8mcXS9wClrg9At\n\t\t\t\t\t\tU7jLzIpQCcq4Jjfne+vjy9uoUduD+X9IUTpWEU8XdSWHSRXyk4ujXLfcXkfIuat5\n\t\t\t\t\t\tDswQWfECAwEAAaNQME4wHQYDVR0OBBYEFLIOF+KbcmkO27fWS5ZicSri4/O7MB8G\n\t\t\t\t\t\tA1UdIwQYMBaAFLIOF+KbcmkO27fWS5ZicSri4/O7MAwGA1UdEwQFMAMBAf8wDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBAHEWHwnlsn47Vb8rfNZokD5DHDCiqWN5vx1A0Ed90bMJ\n\t\t\t\t\t\tP5rScA9fuhldvLSq1wxCMwStcLcm6ymUdRHmb0wvtG1j0vphDsiFKLJtlTZzEz42\n\t\t\t\t\t\tpG2u4LOQPW6TElrAQ+9xFaloFiNAsKNhEWz7YuQHm5zV8wi/7m5L1G9IlrBoIfjX\n\t\t\t\t\t\tx98jpfQS4yKUF7Koof9h8iWYz/T4Ma3pCfHzHGxstfMOcix+gPxuXaR6qtdxMtNg\n\t\t\t\t\t\tqFesPgoUZjD0AHqvtwrs2SlC6Etkfz3O/42U4C0rb0NXEP11Hkrlvlk7GVXY/4w3\n\t\t\t\t\t\tm8Ur8u4zqlfwsQpCaQSXMb3xNMZKyXm5bdoMQZWg5eI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIIC/BGdv33SfYwDQYJKoZIhvcNAQEFBQAwPTEgMB4GA1UE\n\t\t\t\t\t\tCgwXWW9yayBTdCBKb2huIFVuaXZlcnNpdHkxGTAXBgNVBAMMEGlkcC55b3Jrc2ou\n\t\t\t\t\t\tYWMudWswHhcNMTQwNTA3MTEyMzUyWhcNMjQwNTA3MTEyMzUyWjA9MSAwHgYDVQQK\n\t\t\t\t\t\tDBdZb3JrIFN0IEpvaG4gVW5pdmVyc2l0eTEZMBcGA1UEAwwQaWRwLnlvcmtzai5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAI9vhp37rXZQ6N3J\n\t\t\t\t\t\tjMVnA5XL4e8R6BpZf8y9xKCDoxI2xBB5YlwLuXe0jDLQtLHkcQk1sOcQPlz5Ssi2\n\t\t\t\t\t\t5BaYCFnifo2yaf/TzqmaG6/+IODNySYbGT6AHTeRjagYLmv9ZEzfuoA1rDQ/AvLO\n\t\t\t\t\t\tzckx0qyR4UVwrlxo9QAXILlCzKiE/+2KN7FSzRW/pPm4iWcwpCR+MMtS6CGdb/cZ\n\t\t\t\t\t\tL8Eo91uQ1ErGKfD30PDCnDybCayqk6v8I+AHOoxHqcowGoUu4k8mcXS9wClrg9At\n\t\t\t\t\t\tU7jLzIpQCcq4Jjfne+vjy9uoUduD+X9IUTpWEU8XdSWHSRXyk4ujXLfcXkfIuat5\n\t\t\t\t\t\tDswQWfECAwEAAaNQME4wHQYDVR0OBBYEFLIOF+KbcmkO27fWS5ZicSri4/O7MB8G\n\t\t\t\t\t\tA1UdIwQYMBaAFLIOF+KbcmkO27fWS5ZicSri4/O7MAwGA1UdEwQFMAMBAf8wDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBAHEWHwnlsn47Vb8rfNZokD5DHDCiqWN5vx1A0Ed90bMJ\n\t\t\t\t\t\tP5rScA9fuhldvLSq1wxCMwStcLcm6ymUdRHmb0wvtG1j0vphDsiFKLJtlTZzEz42\n\t\t\t\t\t\tpG2u4LOQPW6TElrAQ+9xFaloFiNAsKNhEWz7YuQHm5zV8wi/7m5L1G9IlrBoIfjX\n\t\t\t\t\t\tx98jpfQS4yKUF7Koof9h8iWYz/T4Ma3pCfHzHGxstfMOcix+gPxuXaR6qtdxMtNg\n\t\t\t\t\t\tqFesPgoUZjD0AHqvtwrs2SlC6Etkfz3O/42U4C0rb0NXEP11Hkrlvlk7GVXY/4w3\n\t\t\t\t\t\tm8Ur8u4zqlfwsQpCaQSXMb3xNMZKyXm5bdoMQZWg5eI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "York St John University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.yorksj.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "York St John University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.globaldata.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pinnireddy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jpinnireddy@globaldata.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeevan Kumar"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pinnireddy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jpinnireddy@globaldata.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeevan Kumar"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.globaldata.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GlobalData Ltd SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.globaldata.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GlobalData Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.globaldata.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.globaldata.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.globaldata.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.globaldata.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.globaldata.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.globaldata.com/Shibboleth.sso/SAML2/POST",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth.globaldata.com/Shibboleth.sso/SAML2/POST",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAItPz9n2+PuaMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\n\t\t\t\t\t\tBAMTF2RlZDA5Ni5tYXhpbXVtYXNwLmxvY2FsMB4XDTExMTEyODEwMTQxMFoXDTE2\n\t\t\t\t\t\tMTEyNjEwMTQxMFowIjEgMB4GA1UEAxMXZGVkMDk2Lm1heGltdW1hc3AubG9jYWww\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCwNeNpZKlWDp7GciyA162g\n\t\t\t\t\t\tVSy3uTRG2BT48mp/oB4Wh7DqNbPHx8PrWJrN0xw+c1o1OarYuaWK24H9F1n3ZI8g\n\t\t\t\t\t\ti/czA4Zi2JsIZmWksu5jYVgZQQnMyVCrA1fB4tjz2GTnrmy7HTt7axMAHlUyupDw\n\t\t\t\t\t\tgh/YcaJ84U1JssiLeSypkHeSyLv/Cew5HI6kARv99/oVSBR7kfOAUPg+fP8kjvlK\n\t\t\t\t\t\tdn6RShLwkY+9KQCK9lY6aaJHrNtRDfSQVZsZgfLwzK+HCGspWHFp7KirfdTBcCkR\n\t\t\t\t\t\tw+berqH4RmOPbcv4TxGva/XEefM9Ikw8FD1Yb7Hcum6avHcD/s02jYzvISUr56FT\n\t\t\t\t\t\tAgMBAAGjRTBDMCIGA1UdEQQbMBmCF2RlZDA5Ni5tYXhpbXVtYXNwLmxvY2FsMB0G\n\t\t\t\t\t\tA1UdDgQWBBQsoQCuifh3Q5K7lzut09/s9A3G8jANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tDyvSdKPdXmbCft4A6Bwqpw0Y1hMuyme8wOskJpQIJ7WXhdyCB3eOYz1dGcmFkeQU\n\t\t\t\t\t\taUJS6x9ZPLkRVX0e8Eoa/w1rYam5Zi3Fv0ZjLLKA7EFkX4aNzeE8vU0y/XZ9amRf\n\t\t\t\t\t\tfIZ/Tse7wvCJTHWNrw0eoTy2xNnPRWhLALF8nNaR66S5Usesosv0fKqpK20nrjmF\n\t\t\t\t\t\twtHuAhh4Jbh6mZZemqKOgcxs9JX5qTsO96plS+Rb2iH2oMP0PrqzjwvHyFAPv8gb\n\t\t\t\t\t\tRt8vBK4vYP16FHxWHw9TNnlQ93w4ozWNtnUHOrvoXghavIUg7MTOIQZ5awgMKr8U\n\t\t\t\t\t\tKRmv+oFXiBHlwyDVz3wIPg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.globaldata.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.globaldata.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.globaldata.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.globaldata.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.globaldata.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.globaldata.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.globaldata.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth.globaldata.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.globaldata.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.globaldata.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.richardtaunton.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Abbott"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:abbotts@richardtaunton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sharon"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Coxson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:syssco@richardtaunton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.richardtaunton.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-04-17T17:45:41Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.richardtaunton.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.richardtaunton.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "richardtaunton.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDcjCCAlqgAwIBAgIIP9vOoGDWheQwDQYJKoZIhvcNAQEFBQAwUDErMCkGA1UE\n\t\t\t\t\t\tCgwiUmljaGFyZCBUYXVudG9uIFNpeHRoIEZvcm0gQ29sbGVnZTEhMB8GA1UEAwwY\n\t\t\t\t\t\taWRwLnJpY2hhcmR0YXVudG9uLmFjLnVrMB4XDTE0MDIxMzE0MzI0MVoXDTI0MDIx\n\t\t\t\t\t\tMzE0MzI0MVowUDErMCkGA1UECgwiUmljaGFyZCBUYXVudG9uIFNpeHRoIEZvcm0g\n\t\t\t\t\t\tQ29sbGVnZTEhMB8GA1UEAwwYaWRwLnJpY2hhcmR0YXVudG9uLmFjLnVrMIIBIjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArrQrUbrEso92Y0nGePC9ddn0ZpZ+\n\t\t\t\t\t\tpYV39mnbr51NSHQlano4Arn8uBlMi9ALaLON4G6A9Q+S2B6OIorTgMTHyDbrOTya\n\t\t\t\t\t\tDw7d9gvlbvKWEnJMBstk+Wpm1G4OKmpm2VrTNzbuPpCTpHVFVqHa8j0XKqnXl4Da\n\t\t\t\t\t\tU7AU3jfIbpM8TYMZnVOcOTXlRhLKyX75bncjbYjFzbtX1ZsToSPmdLHL2Rl1MCgK\n\t\t\t\t\t\tsZhgEbx20wZuFatoOZ5MoxmUo8LSAW5HGrKsE9ms/pN+KT6uej4ygOtq1GBq9Lrv\n\t\t\t\t\t\tW3nKWrRzU/2gBKJKudP7avxS3n0t55ITaS8Emx/lj2uwOSSf7U8pnNBOKwIDAQAB\n\t\t\t\t\t\to1AwTjAdBgNVHQ4EFgQUSetuFJXmHRSav/PWbq+q7pA/BTwwHwYDVR0jBBgwFoAU\n\t\t\t\t\t\tSetuFJXmHRSav/PWbq+q7pA/BTwwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAl+DLXiM0SPpko0CalHgKey1WKm7kuM8yr0/SdybnM6SJ42oOoW90pJla\n\t\t\t\t\t\tGVkFcHsZx4T17MesjXrJyYoH7eTga6HkXCWd6t1Iv9XNL2ugx4BaZKM08n8wNvw1\n\t\t\t\t\t\te/rBVAVQQ+ChFQNqRI9W5hXxMcqjpZQQ1soNjQHs12SEzsHqrdL4w+J6YDdpXNzK\n\t\t\t\t\t\tIwSNoEAPg+maVh3q9qpm059erPkxPR48bp1gdZ75tjo/xiUF4r0aZ8lgFXBsJehF\n\t\t\t\t\t\tvJLm/3QphXsGgRuXU06Uv84xWffF1zyS74OgLq3xZ0kTWZ9MLfAz2lGiONkBfwUX\n\t\t\t\t\t\tqfAWYGdWHfXUpfYTT+9iNCwqnPTlvA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDcjCCAlqgAwIBAgIIP9vOoGDWheQwDQYJKoZIhvcNAQEFBQAwUDErMCkGA1UE\n\t\t\t\t\t\tCgwiUmljaGFyZCBUYXVudG9uIFNpeHRoIEZvcm0gQ29sbGVnZTEhMB8GA1UEAwwY\n\t\t\t\t\t\taWRwLnJpY2hhcmR0YXVudG9uLmFjLnVrMB4XDTE0MDIxMzE0MzI0MVoXDTI0MDIx\n\t\t\t\t\t\tMzE0MzI0MVowUDErMCkGA1UECgwiUmljaGFyZCBUYXVudG9uIFNpeHRoIEZvcm0g\n\t\t\t\t\t\tQ29sbGVnZTEhMB8GA1UEAwwYaWRwLnJpY2hhcmR0YXVudG9uLmFjLnVrMIIBIjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArrQrUbrEso92Y0nGePC9ddn0ZpZ+\n\t\t\t\t\t\tpYV39mnbr51NSHQlano4Arn8uBlMi9ALaLON4G6A9Q+S2B6OIorTgMTHyDbrOTya\n\t\t\t\t\t\tDw7d9gvlbvKWEnJMBstk+Wpm1G4OKmpm2VrTNzbuPpCTpHVFVqHa8j0XKqnXl4Da\n\t\t\t\t\t\tU7AU3jfIbpM8TYMZnVOcOTXlRhLKyX75bncjbYjFzbtX1ZsToSPmdLHL2Rl1MCgK\n\t\t\t\t\t\tsZhgEbx20wZuFatoOZ5MoxmUo8LSAW5HGrKsE9ms/pN+KT6uej4ygOtq1GBq9Lrv\n\t\t\t\t\t\tW3nKWrRzU/2gBKJKudP7avxS3n0t55ITaS8Emx/lj2uwOSSf7U8pnNBOKwIDAQAB\n\t\t\t\t\t\to1AwTjAdBgNVHQ4EFgQUSetuFJXmHRSav/PWbq+q7pA/BTwwHwYDVR0jBBgwFoAU\n\t\t\t\t\t\tSetuFJXmHRSav/PWbq+q7pA/BTwwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAl+DLXiM0SPpko0CalHgKey1WKm7kuM8yr0/SdybnM6SJ42oOoW90pJla\n\t\t\t\t\t\tGVkFcHsZx4T17MesjXrJyYoH7eTga6HkXCWd6t1Iv9XNL2ugx4BaZKM08n8wNvw1\n\t\t\t\t\t\te/rBVAVQQ+ChFQNqRI9W5hXxMcqjpZQQ1soNjQHs12SEzsHqrdL4w+J6YDdpXNzK\n\t\t\t\t\t\tIwSNoEAPg+maVh3q9qpm059erPkxPR48bp1gdZ75tjo/xiUF4r0aZ8lgFXBsJehF\n\t\t\t\t\t\tvJLm/3QphXsGgRuXU06Uv84xWffF1zyS74OgLq3xZ0kTWZ9MLfAz2lGiONkBfwUX\n\t\t\t\t\t\tqfAWYGdWHfXUpfYTT+9iNCwqnPTlvA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Richard Taunton Sixth Form College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.richardtaunton.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Richard Taunton Sixth Form College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://europe-stage.wiseflow.net",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tim@uniwise.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Administrator"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://europe-stage.wiseflow.net",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2015-07-15T15:12:01Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNIWISE ApS"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://uniwise.dk"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNIWISE ApS"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://europe-stage.wiseflow.net/simplesaml/module.php/saml/sp/saml2-logout.php/europe-stage_wayf",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Form\u00e5let er at facilitere digital h\u00e5ndtering af skriftlige eksaminer."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The purpose is to facilitate digital management of written exams."
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WISEflow europe-stage"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WISEflow europe-stage"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://europe-stage.wiseflow.net/simplesaml/module.php/saml/sp/saml2-acs.php/europe-stage_wayf",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Form\u00e5let er at facilitere digital h\u00e5ndtering af skriftlige eksaminer."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The purpose is to facilitate digital management of written exams."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "WISEflow europe-stage"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "WISEflow europe-stage"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrimaryAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.5",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "gn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "norEduPersonLIN",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.2428.90.1.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "preferredLanguage",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.39",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacPersonalUniqueID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.15",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://esdsdev01.ds.man.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:international@esds.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ESDS International Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mimas-shib-tech@listserv.manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mimas Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://esdsdev01.ds.man.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MIMAS ESDS Development Server"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.esds.ac.uk/international/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Manchester"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://esdsdev01.ds.man.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://esdsdev01.ds.man.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://esdsdev01.ds.man.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://esdsdev01.ds.man.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Online access to socio-economic time series datasets aggregated to the country or regional level."
                  }
                ],
                "logo": [
                  {
                    "text": "https://esdsdev01.ds.man.ac.uk/esdsint-med.gif",
                    "height": "350",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "161"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ESDS International (Development)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJAOegVyCLESWpMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\n\t\t\t\t\t\tBAMTFmVzZHNkZXYwMS5kcy5tYW4uYWMudWswHhcNMTEwNDE2MTQzNDUwWhcNMjEw\n\t\t\t\t\t\tNDEzMTQzNDUwWjAhMR8wHQYDVQQDExZlc2RzZGV2MDEuZHMubWFuLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArSSkzgeZ0lVbjh4jmzl6EwL+\n\t\t\t\t\t\tUmBfmiXE25AQdHm69bZ18Xi5Mq6ekkw/WuNIztu4p14Nj3bOCXvmrILQE3sV0TNr\n\t\t\t\t\t\tge7XAAvfhwhwW8P/0KSF3PPO2mN1yZToSWJKb04idjSLttNTrOchEAapCfwYu4JE\n\t\t\t\t\t\tr8uXNcccYNpuePE6wncoxWknWPJW4L+sarfQbAKmcksEiIwwlz/8gY0D4OhR+mhM\n\t\t\t\t\t\tq/OsLzY4Os4+1QwGbO99uQbbH3ni8wnXZZWPRp/VbdAYjavb2CihJE0gxbCwl2Sb\n\t\t\t\t\t\twXCy6cYXSz5APMoNbdmnHHMaBH8Wfr9Iqj0H/8Mf22qnGT9QZQHotKY9Jxs99wID\n\t\t\t\t\t\tAQABo0QwQjAhBgNVHREEGjAYghZlc2RzZGV2MDEuZHMubWFuLmFjLnVrMB0GA1Ud\n\t\t\t\t\t\tDgQWBBTBQrWo24UVCTROZnBZNmP+c+/ksjANBgkqhkiG9w0BAQUFAAOCAQEABr5E\n\t\t\t\t\t\tAteCYpWEIOSa2pd6O/J8RYs0eTev/erX86SOr9CzWVSbQWOOrGWIGGfzl6pr/InJ\n\t\t\t\t\t\tHMODUl83ef2aqCLSPQNvWzLZUhZRWjIlrM7HEy+mreLg8SvS+/rXbD5GY7SoIPK1\n\t\t\t\t\t\twkg/sCG2ySIT2ar5mhIGBlMa5VCOqTSp0jf5bgnYHiBRK31gHA0U61ELt2CwymGb\n\t\t\t\t\t\tAIcitktbUS8oKIi3s3VRVHS3gNmWDJheXPW3n1pOs59qvtKbgLaMKVik5TGCCDUL\n\t\t\t\t\t\tbQGCEE/TE6oiedAX5+v00cmtKcjecUniOHdq1YbFBKFbFreehIOQVpM0ElONGtVN\n\t\t\t\t\t\tN7ls4b7fnGvaF5RY9Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJAOegVyCLESWpMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\n\t\t\t\t\t\tBAMTFmVzZHNkZXYwMS5kcy5tYW4uYWMudWswHhcNMTEwNDE2MTQzNDUwWhcNMjEw\n\t\t\t\t\t\tNDEzMTQzNDUwWjAhMR8wHQYDVQQDExZlc2RzZGV2MDEuZHMubWFuLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArSSkzgeZ0lVbjh4jmzl6EwL+\n\t\t\t\t\t\tUmBfmiXE25AQdHm69bZ18Xi5Mq6ekkw/WuNIztu4p14Nj3bOCXvmrILQE3sV0TNr\n\t\t\t\t\t\tge7XAAvfhwhwW8P/0KSF3PPO2mN1yZToSWJKb04idjSLttNTrOchEAapCfwYu4JE\n\t\t\t\t\t\tr8uXNcccYNpuePE6wncoxWknWPJW4L+sarfQbAKmcksEiIwwlz/8gY0D4OhR+mhM\n\t\t\t\t\t\tq/OsLzY4Os4+1QwGbO99uQbbH3ni8wnXZZWPRp/VbdAYjavb2CihJE0gxbCwl2Sb\n\t\t\t\t\t\twXCy6cYXSz5APMoNbdmnHHMaBH8Wfr9Iqj0H/8Mf22qnGT9QZQHotKY9Jxs99wID\n\t\t\t\t\t\tAQABo0QwQjAhBgNVHREEGjAYghZlc2RzZGV2MDEuZHMubWFuLmFjLnVrMB0GA1Ud\n\t\t\t\t\t\tDgQWBBTBQrWo24UVCTROZnBZNmP+c+/ksjANBgkqhkiG9w0BAQUFAAOCAQEABr5E\n\t\t\t\t\t\tAteCYpWEIOSa2pd6O/J8RYs0eTev/erX86SOr9CzWVSbQWOOrGWIGGfzl6pr/InJ\n\t\t\t\t\t\tHMODUl83ef2aqCLSPQNvWzLZUhZRWjIlrM7HEy+mreLg8SvS+/rXbD5GY7SoIPK1\n\t\t\t\t\t\twkg/sCG2ySIT2ar5mhIGBlMa5VCOqTSp0jf5bgnYHiBRK31gHA0U61ELt2CwymGb\n\t\t\t\t\t\tAIcitktbUS8oKIi3s3VRVHS3gNmWDJheXPW3n1pOs59qvtKbgLaMKVik5TGCCDUL\n\t\t\t\t\t\tbQGCEE/TE6oiedAX5+v00cmtKcjecUniOHdq1YbFBKFbFreehIOQVpM0ElONGtVN\n\t\t\t\t\t\tN7ls4b7fnGvaF5RY9Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://esdsdev01.ds.man.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://esdsdev01.ds.man.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://esdsdev01.ds.man.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://esdsdev01.ds.man.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://esdsdev01.ds.man.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://esdsdev01.ds.man.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://esdsdev01.ds.man.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://esdsdev01.ds.man.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://esdsdev01.ds.man.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://esdsdev01.ds.man.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://login.ezproxy.library.qmul.ac.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lib-systems-team@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Library Systems Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Evans"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.d.t.evans@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Acland"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:j.acland@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeremy"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.ezproxy.library.qmul.ac.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-03-02T16:50:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Queen Mary, University of London: EZProxy Service"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qmul.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Queen Mary and Westfield College, University of London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFHzCCBAegAwIBAgIRANyZcMkOxifiYwLZXeooCQUwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xNDAyMTkwMDAwMDBaFw0xNzAyMjgyMzU5NTlaMIHiMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEPMA0GA1UEERMGRTEgNE5TMRcwFQYDVQQIEw5DZW50cmFsIExvbmRv\n\t\t\t\t\t\tbjEPMA0GA1UEBxMGTE9ORE9OMRowGAYDVQQJExEzMjcgTWlsZSBFbmQgUm9hZDE/\n\t\t\t\t\t\tMD0GA1UEChM2UXVlZW4gTWFyeSBhbmQgV2VzdGZpZWxkIENvbGxlZ2UsIFVuaXZl\n\t\t\t\t\t\tcnNpdHkgb2YgTG9uZG9uMRQwEgYDVQQLEwtJVCBTZXJ2aWNlczElMCMGA1UEAxQc\n\t\t\t\t\t\tKi5lenByb3h5LmxpYnJhcnkucW11bC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQAD\n\t\t\t\t\t\tggEPADCCAQoCggEBALSqVecWKa3l+sxPyi/CtJeCEGF9I4KPcF8uF7ICXpeWqg+q\n\t\t\t\t\t\t2FVP4drw1LLiChY2MWRxYOknYABhhMcF+FKPNu+NWDl3M5ic542GXcj2dSgMuc/M\n\t\t\t\t\t\tGQ+iK860WmthtPkCZ4PTuFRD1BTuLpJBU/vAhCIrh5fr5+CjJDlH4vNERFy34WXO\n\t\t\t\t\t\t+KZH1inY7sV5Pk/2ZO8HgMwVsf4YeSywGRH/LxViQ7UjhP1pq1oaL7CiwPGaJxTl\n\t\t\t\t\t\tKYhvW1IM7ePCCcTiGWodhN7c6HAA9hpQYgExDcyUMgzxSM4tPsKbVp81Y51fekNT\n\t\t\t\t\t\tkN5sY7rSxFaD/6WzWVa6wlbjfSAiNR9MsQJPfq8CAwEAAaOCAXkwggF1MB8GA1Ud\n\t\t\t\t\t\tIwQYMBaAFAy9k2gM896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBRy0dy6tqogk0Db\n\t\t\t\t\t\t1AZcyxh7b+l5+DAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUE\n\t\t\t\t\t\tFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQIC\n\t\t\t\t\t\tHTAIBgZngQwBAgIwOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVy\n\t\t\t\t\t\tZW5hLm9yZy9URVJFTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUF\n\t\t\t\t\t\tBzAChilodHRwOi8vY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAm\n\t\t\t\t\t\tBggrBgEFBQcwAYYaaHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwJwYDVR0RBCAw\n\t\t\t\t\t\tHoIcKi5lenByb3h5LmxpYnJhcnkucW11bC5hYy51azANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAav8++MEPaToHmyfXb1sn+ofaMyjtJjsvao8SSpPNYGzaQZl/OiDshe5h3fJs\n\t\t\t\t\t\tBadfZZrPkDvrmiMSAr2bUzEJ4jrL59sP7I0mCNFL+TzqJ4HulWFL01sshFheYg71\n\t\t\t\t\t\teBpXNBuP2/erRfdu1NHlYdURdYgWG9othpL+YmkEZy3S7t+ubmPoVMQuVc4YXGhC\n\t\t\t\t\t\tE6qofr4r607yV971dq5p3CSGzk8Pa/dKDBM24e/q9F1XIEXoGi2tSKZqINYhll14\n\t\t\t\t\t\tUZ2o8/8T3a5/nnOtrKtdKbqRTQovbmwX5GkAKwkej4VRwObcYRvAHsznE0yuILAT\n\t\t\t\t\t\tCn1oyuVnnArb5xKg2XoAllszmA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://login.ezproxy.library.qmul.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.ezproxy.library.qmul.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.rediris.es/sir/urvidp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sir@rediris.es"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SIR helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.rediris.es/sir/urvidp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.rediris.es/sir/edugain/SIR_MRPS.pdf"
              }
            ],
            "registration_instant": "2012-10-09T13:08:24Z",
            "registration_authority": "http://www.rediris.es/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "response_location": "http://sir.rediris.es/urv/saml2/idp/SingleLogoutService.php",
              "location": "http://sir.rediris.es/urv/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "http://sir.rediris.es/urv/shib13/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "http://sir.rediris.es/urv/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Identity Provider of URV"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "El proveedor de identidad de URV"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "URV - Rovira i Virgili University"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "URV - Universidad Rovira i Virgili"
                  },
                  {
                    "lang": "ca",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "URV - Universitat Rovira i Virgili"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "urv.cat"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEeTCCA2GgAwIBAgIQCP9faAGj247/+QVzgpX08zANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDcwMTAwMDAwMFoXDTE2MDYzMDIzNTk1OVowRDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMR8wHQYDVQQDExZzYW1saWRwLnNp\nci5yZWRpcmlzLmVzMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA5tO6\ntYAdozpFMDwS7QH1qm7eECkY05lG1sp14vcVOdyN0mAf8oai+M8dCQ5iyMxD/RaG\noSmhXfHUvJ+0x8Cp/NHYbKr0cXskANcYTI0JFMFypn9Uac62CGxUYZRhHQ/2LxiE\nvzNgKrm2JiXCvOQbWrbg0sZDEsONv2G1Ln3fvOLiSiO1AjWLvOeYFPNgkNy5dxxt\n7ms7mZ0bFth6Cj38BBL0I1RebVnMgAKZWSgICUXDx35nkB+iLtidIykBgz92ZQ5h\nUrVNndP5+lraoMRuIewESSFt+LBYVeUZFTBGlupiUZ/bi7rhtIuhMM8ahaKIstbu\nIgfQBHPqRkkiiKOJawIDAQABo4IBczCCAW8wHwYDVR0jBBgwFoAUDL2TaAzz3quj\nSWsrN1dH6pDjue0wHQYDVR0OBBYEFARoBLDWcsveEZQhaMVIR9mmJkUkMA4GA1Ud\nDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggr\nBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNV\nHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNT\nTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQu\ndGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRw\nOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAhBgNVHREEGjAYghZzYW1saWRwLnNpci5y\nZWRpcmlzLmVzMA0GCSqGSIb3DQEBBQUAA4IBAQB0gmr232YgpUC4HkwAHXaH91Zx\n8ZrwiEc8c4jGLh5VsaO0OqMfUEIXMuqZ+P9JNWVwlc6VLtmsypqTuqb9a06DS88q\n2o5sAUpbXZwhArhQs1bQnu5HJ6S84Ajn+NfMOyaO7NF8Colq/9lf3DihkT0jlD7i\nPHPMw2zauvtR/WPwdPszgfIOV/vkJ0rq9AjOXxSX7V2jpkxISGW/m93iahwXEoVF\nc8VXQhNjEfcm6uawmISjsyp6ta/U3e/8GJka2csDrF/bfipMBDSdWcLMscpYO8cb\nDC0L6vehZJ+lPz3wPH6YJmlstICZUdJIgDV3TUhmji6NNKa4p6by34QdYcDH"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "URV - Rovira i Virgili University"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "URV - Universidad Rovira i Virgili"
          },
          {
            "lang": "ca",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "URV - Universitat Rovira i Virgili"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rediris.es/index.php.en"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rediris.es/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "URV"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "URV"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.american.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "paterrov@american.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Saeed Pater-Rov"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "eric@american.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Eric Weakland"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.american.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.american.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.american.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.american.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.american.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.american.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "american.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "American University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAJDrEjwuZf7tKwar/iJcnJUpBaD3MA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEGlkcC5hbWVyaWNhbi5lZHUwHhcNMTEwNzA2MTc1NDA1\nWhcNMzEwNzA2MTc1NDA1WjAbMRkwFwYDVQQDExBpZHAuYW1lcmljYW4uZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAlMec/brVKO//Y6LSzqHWBOtO\n9HvX5R49417xn/3gXnC8OIFyJpZLFDITOPfze8FC8fzgNw7HIDkR9Qvb/sqZ6yys\nrH00gblENowjF7L6b+GnDfjZdGtTSxh72JxkY/Gc/zc1hsA0VwBir12YZxgKX4ta\nftC1lAeq5qgHDgkitQB8sbXyCdnj+iC1ZYQB2voNvX943W0Zoz9vtAzAYsmsxV3S\nLDvyN8MHBqipXWGWunloRke/JmugBOzYIZ4lGRWY0Upu24GqAhCOcS/tii3FwFZ1\nlxZ/w/wXrNyley32KoIPfY9awbZEMxQZvSWbZ78QXpvMj0m8a10Gloy7AL1n0QID\nAQABo2cwZTBEBgNVHREEPTA7ghBpZHAuYW1lcmljYW4uZWR1hidodHRwczovL2lk\ncC5hbWVyaWNhbi5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFIX7x6u7hEbE\nQV3quLr2nrucZDXxMA0GCSqGSIb3DQEBBQUAA4IBAQB3sqVb/IQToX7s/0xMxzEV\nBBG/IQtOiJla3BfOQrcLtakPNX5svAQusE7r2m5YrZlmjuznGg+riNFUYBm0u089\nzTtMuRrRCaxg3NUU2JuqTo17lFNguUB7+uzfop//nu+u7PyT6325o/Bla1iP4HNc\n0Y+NWgqsewCcbwAg9QHGrHef6SAFVkeEwevEEJRB7B3I0TQBPirj9BoZjUVwDwV1\nQld5H3yair/rrHPwpk3aH+torcKqdV/VlyPcgwXZ1LhqmgBIbQ6jGWZsniwh+xfs\nGSfLlV8bGtUawXlz2hsCK4EGIzVMeGanIBE/kozBqy3Ul6SVPZzxsU2nJCRuIHS5"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "American University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.american.edu/index1.html"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "American University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://its-pd0062.ad.umu.se/shibboleth-sp",
    {
      "entity_id": "https://its-pd0062.ad.umu.se/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/IDP",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/WAYF/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/WAYF/testc.ladok.umu.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/WAYF/testb.antagning.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/WAYF/testa.antagning.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "its-pd0062.ad.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAISQ+6OrrBvmMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFGl0cy1wZDAwNjIuYWQudW11LnNlMB4XDTEyMDQwNDEzNDQyNloXDTIyMDQw\nMjEzNDQyNlowHzEdMBsGA1UEAxMUaXRzLXBkMDA2Mi5hZC51bXUuc2UwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCV0RgOrba9T2uZM3oirmyK0pCuuE4G\nmBw0Xk1urDsI7SRZ86zZP+e0yZYPIHDO8W1O0ca2cTrWixg/mjSRUEHb84ja7pwE\nKdJ23uhEMpfVCG2wfOOWMoWsuPjsA+EwaV8Sd0wfOHnlHeiZnZfLPT6rX/r81hOe\nglFxZX/jYmhbATAx333CpCcCK4sE9PK6lilgMhBBTMqFQw0ORKpNk8MXYAc3ws+m\n0oJonE3R/1u7CuoRbC6ByOgv8ygF30Wsbxi1mew8schl/xdRZ827hI4Vpx3NsUlT\n4i4rN91L2WfaSjnzlXoV6Mgl+lrdnJEzlaBk+a2TnN4jQGUElCvj4tr1AgMBAAGj\nQjBAMB8GA1UdEQQYMBaCFGl0cy1wZDAwNjIuYWQudW11LnNlMB0GA1UdDgQWBBSt\noiK8tNwfMNNOo9CtJ+Ch28e9kzANBgkqhkiG9w0BAQUFAAOCAQEARczFJycPFM5g\ndZu0R/ET3IlhaLzam8np4HudzZG321dBuqy1kmJX11gCtT39gJJCFU4TJqTZZQN5\na3DgryGRz9+a/YsUwQSSQooFqeI7lgWdOsfjeRYxrj3IWYtK+1Djmv1FqCrKiY6I\nq33PJ7wIY9VmHLuZNRvnPJymJ96KXp1PGuzPf+D9EJAmLACahbtKQN4BPZRUY2W1\ngPYoStBXXQQMzgcSfcJ30uSYzJKp/xbjR+X8ATcrcy1rruzix+4nq7RuyZ9IVaTT\nx8KpMVoGa5QkJcKJqsqD0oBy6YCPuJiDcouhncPIU+cy5vTOG9YXjzBC/Td01ZLn\nXF6Xb2bzkg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=its-pd0062.ad.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://its-pd0062.ad.umu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:feide.no:services:com.itslearning.test",
    {
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.feide.no/files/feide/metadata-registration-practice-statement.pdf"
              }
            ],
            "registration_instant": "2011-11-30T08:58:46Z",
            "registration_authority": "http://feide.no/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute_value": [
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "kalmar"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "norway"
              }
            ],
            "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
            "name": "tags",
            "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "urn:mace:feide.no:services:com.itslearning.test",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://test.itslearning.com/elogin/logout.aspx",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "itslearning"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "itslearning is a virtual learning environment specifically designed for schools and universities."
                },
                {
                  "lang": "no",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "itslearning er et virtuelt l\u00e6ringsmilj\u00f8, spesielt utformet for skoler og universiteter."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.itslearning.com/elogin/default.aspx",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://zeroshell.irccs-stellamaris.it:12081/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Massimo Del Sarto"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ced@fsm.unipi.it"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ced@fsm.unipi.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://zeroshell.irccs-stellamaris.it:12081/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2014-06-04T10:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "WiFi provided by IRCCS Fondazione Stella Maris"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "WiFi erogato da IRCCS Fondazione Stella Maris"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fsm.unipi.it"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fsm.unipi.it"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IRCCS Fondazione Stella Maris"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IRCCS Fondazione Stella Maris"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.fsm.unipi.it/idem/servizio_wifi_en.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.fsm.unipi.it/idem/servizio_wifi.html"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IRCCS Fondazione Stella Maris, WiFi network access"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Accesso alla rete WiFi di IRCCS Fondazione Stella Maris"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.fsm.unipi.it/idem/servizio_wifi_en.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.fsm.unipi.it/idem/servizio_wifi.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WIFI powered by IRCCS Fondazione Stella Maris"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WIFI erogato da IRCCS Fondazione Stella Maris"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEpTCCA42gAwIBAgIRAK+9wyhwi2cPugqoTWMzt7wwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDA0MTAwMDAwMDBaFw0xNzA0MDkyMzU5NTlaMEwxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEnMCUGA1UEAxMeemVyb3NoZWxs\nLmlyY2NzLXN0ZWxsYW1hcmlzLml0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\nCgKCAQEAovLKJXlXtWpDN5QxJI/gsBNZb1qMKFC28k/8KNMWRK1J7iJnvSB10qxY\nDIp/N9f5KuOfE/LWEpn0CRYczS0lKvT9ZHxvu//dXF83+CTuwLdYLInlx98gS47K\neKoJkTSCS3i6nXXu5pkZ3r73eO4Q9F78kWhZp9VGO6FXcqpAWPDXPiX4tySlnZHE\nbVcgKzrop4mYMEwj6/etuqid2FIEE8cttyn0TSZIAqQpvQl6ny53Ew/zNYrfT2yY\noJhWt7tdGo+icZJ8ajJU1QTAZjGdrxZOcdrVTO8+2G3p6wXIBApEOlY1GtpVvSHy\ntQbatYv3lqykV7sU4fWYcAJ0c1XyIQIDAQABo4IBljCCAZIwHwYDVR0jBBgwFoAU\nDL2TaAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFBSOJjQD1lbPrYadWn8cPsv5\nC+CBMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsG\nAQUFBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeB\nDAECATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3Jn\nL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0\ndHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUF\nBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzBEBgNVHREEPTA7gh56ZXJv\nc2hlbGwuaXJjY3Mtc3RlbGxhbWFyaXMuaXSCGXdpZmkuaXJjY3Mtc3RlbGxhbWFy\naXMuaXQwDQYJKoZIhvcNAQEFBQADggEBABmEJgMv0YbYXVbsojatdIXj8AJo0E9Z\nsCjTrGicfPXMqCBo1/h+k2fKfkBEZHgMH+bg/VwSzwnU6LSMnMPZWsHQ6dof697Y\nRLeYr22GJWHkTrHWH+ur2FaB/VzMaRMpBnK084mSrnKmKI2hTHdrv7wYX8lnuYhs\n2k87PGWZAyyfdes9ciVS+wtLVpiauMYkvbdeiYwFkjQaRAWfxzfuXLlDfHT6OD/2\nCYFaxF/RoF9vvQeQQnKwXv3l6SZHei08SgLClw5oWXiwwv8i0cgKNmf0rvXooZJa\nEBqhfy4T1t3TB0ARzgnn8tJ8VwrzLlEJBiy/h77aZregVImJIX6t20M="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEpTCCA42gAwIBAgIRAK+9wyhwi2cPugqoTWMzt7wwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDA0MTAwMDAwMDBaFw0xNzA0MDkyMzU5NTlaMEwxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEnMCUGA1UEAxMeemVyb3NoZWxs\nLmlyY2NzLXN0ZWxsYW1hcmlzLml0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\nCgKCAQEAovLKJXlXtWpDN5QxJI/gsBNZb1qMKFC28k/8KNMWRK1J7iJnvSB10qxY\nDIp/N9f5KuOfE/LWEpn0CRYczS0lKvT9ZHxvu//dXF83+CTuwLdYLInlx98gS47K\neKoJkTSCS3i6nXXu5pkZ3r73eO4Q9F78kWhZp9VGO6FXcqpAWPDXPiX4tySlnZHE\nbVcgKzrop4mYMEwj6/etuqid2FIEE8cttyn0TSZIAqQpvQl6ny53Ew/zNYrfT2yY\noJhWt7tdGo+icZJ8ajJU1QTAZjGdrxZOcdrVTO8+2G3p6wXIBApEOlY1GtpVvSHy\ntQbatYv3lqykV7sU4fWYcAJ0c1XyIQIDAQABo4IBljCCAZIwHwYDVR0jBBgwFoAU\nDL2TaAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFBSOJjQD1lbPrYadWn8cPsv5\nC+CBMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsG\nAQUFBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeB\nDAECATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3Jn\nL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0\ndHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUF\nBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzBEBgNVHREEPTA7gh56ZXJv\nc2hlbGwuaXJjY3Mtc3RlbGxhbWFyaXMuaXSCGXdpZmkuaXJjY3Mtc3RlbGxhbWFy\naXMuaXQwDQYJKoZIhvcNAQEFBQADggEBABmEJgMv0YbYXVbsojatdIXj8AJo0E9Z\nsCjTrGicfPXMqCBo1/h+k2fKfkBEZHgMH+bg/VwSzwnU6LSMnMPZWsHQ6dof697Y\nRLeYr22GJWHkTrHWH+ur2FaB/VzMaRMpBnK084mSrnKmKI2hTHdrv7wYX8lnuYhs\n2k87PGWZAyyfdes9ciVS+wtLVpiauMYkvbdeiYwFkjQaRAWfxzfuXLlDfHT6OD/2\nCYFaxF/RoF9vvQeQQnKwXv3l6SZHei08SgLClw5oWXiwwv8i0cgKNmf0rvXooZJa\nEBqhfy4T1t3TB0ARzgnn8tJ8VwrzLlEJBiy/h77aZregVImJIX6t20M="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://zeroshell.irccs-stellamaris.it:12081/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://zeroshell.irccs-stellamaris.it:12081/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://zeroshell.irccs-stellamaris.it:12081/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://zeroshell.irccs-stellamaris.it:12081/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://zeroshell.irccs-stellamaris.it:12081/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://zeroshell.irccs-stellamaris.it:12081/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "WiFi IRCCS Fondazione Stella Maris"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "WiFi IRCCS Fondazione Stella Maris"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedId",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.holborncollege.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.holborncollege.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/holborncollege.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/holborncollege.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "holborncollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Holborn College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.holborncollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-demo-01.its.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-demo-01.its.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;demo-01"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;demo-01"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-demo-01.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-demo-01.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIJAMRYGhBhn5UuMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\nBAMTG2xhZG9rMy1kZW1vLTAxLmxhZG9rLnVtdS5zZTAeFw0xNDEwMDcxNDQ2MzVa\nFw0yNDEwMDQxNDQ2MzVaMCYxJDAiBgNVBAMTG2xhZG9rMy1kZW1vLTAxLmxhZG9r\nLnVtdS5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOalh/0b61hE\nOCTOh82ytTf3633I9ZrsKD1XGlCICIYNbgrqRwA/T2NqX6cnQh2hgTqlUUaVX7WZ\nq3VDCmi84v3RRoDC5mrP84vWejNzVMZKCwugp0KhnDQbWb1qzQnGTI5ezgjuXmIr\nqPlBPC0AaLTb+6jX9VRA+rJqiHuJATF+5fm1xwiJ5QR67DiVeHewcGP3r9Z3Fb5g\nKSmbd0GmkXZb4F10pmFGE7471ZTgcrL9soAaA8hlc2+jL1UVvtE7PY9VTcnD540Y\nkoL9kIfnMWIO/x06fWJQkphfrQu41Rh4UMt9e5qcJcUA/knmw/OWPH2/svDhv0mO\nrip3BLBPe+MCAwEAAaOBgzCBgDBfBgNVHREEWDBWghtsYWRvazMtZGVtby0wMS5s\nYWRvay51bXUuc2WGN2h0dHBzOi8vbGFkb2szLWRlbW8tMDEubGFkb2sudW11LnNl\nL3N0dWRlbnQtZnJvbnRlbmQtc3AwHQYDVR0OBBYEFLboAtPLn/yoa6dvPyfFZXlD\nPY9vMA0GCSqGSIb3DQEBBQUAA4IBAQBWwcRdfbwtKbNYHuI2mLxjoh2Zac/ns7BR\nuY/ZmbDJ/Yhk6vdiU0/jwP2TkIs0Z9/oXetVuQICtgRLdBBSBSNpUMsMqR+tJ6Ab\netzXToph/gvyv8XNjahPtOOLvtK/874r5JuqfktFcsTjhxoxvEsRq+H6xUnitw77\nIq/yhze6jvJn+5zRr/vkwpKJBLobXjytbvaahijlJxKgj+FBEkwUTotNnz5G4SsA\npYOMqd8nZEwrLoOlQXb5MKRDS0cdjiDGh7RDvQgs05MTMHQI/C7pwoAm8XWEfZlP\ndoapb4k+1TzJZ+MDX6jwvVMl0DN5+rmuHjkmu75L+UERnVJRSbIK"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-demo-01.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-demo-01.its.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ltcc.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "abiko@ltcc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bill Abiko"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ltcc.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ltcc.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ltcc.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAIw5vv7kNNzUAGMBYYmz7GBzIvGfMA0GCSqGSIb3DQEB\nCwUAMBcxFTATBgNVBAMMDGlkcC5sdGNjLmVkdTAeFw0xNjAyMDUyMjE3MjlaFw0z\nNjAyMDUyMjE3MjlaMBcxFTATBgNVBAMMDGlkcC5sdGNjLmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAICmrhRTaRE1n9PvBbHhfOQ1LQXkC53u+Qfu\nS5MzR6uU27Vls3tbF6k1zp4LlCNXLpKsDoUn0bwq8M4y3an/7csotxUOV+GB99me\nG8Pe+9ZZwqJP2eSHcqSFfC3uyxLZK0s0ZEVVncnifIwPH1MACzNBycTojmYDrVho\nOs3SYykRvqZQtRBf60gNXyTV2cQhLFVlewOpjDTw+OT5IrufGqZCF1/svFzsJ+6j\n5f8sGJEF0XyY9cbxPrEESL8qZ7Q+jlERuOgCwnW03lAAIXiUTrBP0RFf8A5pm9H2\nRPSawvoW3xk8hN+i6OpSJ2YjIXa1as3xktc4CkrL2oBxvWgpAB8CAwEAAaNfMF0w\nHQYDVR0OBBYEFANNbMJtiNQRpFKEU6d6KNMBIuWJMDwGA1UdEQQ1MDOCDGlkcC5s\ndGNjLmVkdYYjaHR0cHM6Ly9pZHAubHRjYy5lZHUvaWRwL3NoaWJib2xldGgwDQYJ\nKoZIhvcNAQELBQADggEBAE4Js/gpdnRMJpebt8ZfiCHXrI2pVq1xOY36jocDkBax\n05n4TSfECKlz38cp3kCaShtmtQoj2QGP/nlJxawaMwU3GiMXsUFso0P7l3L/aKzI\nvUUBLcWg70IIqIqKc4n6NKm4i5C/ochRVpZgvxV5y9RktW85SMUvGT+jam/nedfA\nDrTigu41S6+Dmyhk+E+NRkaTkub3xPQWGYdsw0/mLyxjSanD3xc0Cjs6kWjtc2ZN\n+eVZmbDE3zJB3uXLMSOsJePF4ETTk6zJzuubY128PKXUEzEr6znPIrBK3pOgaaNS\nn7xTN3O1UJMh8orWZerjJMZllHbVuSkTpkMebBf19ZY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ltcc.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lake Tahoe Community College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lake Tahoe Community College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://ltcc.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Lake Tahoe Community College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso.fh-salzburg.ac.at/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Admins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ssomaster@fh-salzburg.ac.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.fh-salzburg.ac.at/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2009-07-15T16:30:10Z",
            "registration_authority": "http://eduid.at",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso.fh-salzburg.ac.at/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.fh-salzburg.ac.at/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sso.fh-salzburg.ac.at/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.fh-salzburg.ac.at/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fh-salzburg.ac.at"
              },
              {
                "logo": [
                  {
                    "text": "https://sso.fh-salzburg.ac.at/images/fhs_logo_80_60.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://sso.fh-salzburg.ac.at/images/fhs_logo_16_16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Fachhochschule Salzburg"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Salzburg University of Applied Sciences"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUeFyQRjNS1xdQA/IhbscIB+iGNc0wDQYJKoZIhvcNAQEF\nBQAwIDEeMBwGA1UEAxMVc3NvLmZoLXNhbHpidXJnLmFjLmF0MB4XDTA5MDcwOTEz\nNDk0N1oXDTI5MDcwOTEzNDk0N1owIDEeMBwGA1UEAxMVc3NvLmZoLXNhbHpidXJn\nLmFjLmF0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuxeLIPUQcEUg\n38IFt3Gj3B9An6+kLFkoEAfM6LDgkjW/dL//P/e73DWuNpBUA86hqhUmW9hYBwbm\nxp/Wc9dWusIYQtAjUdtLXhitY+eylNjnx3onqMn2r8S9Go9j5IeQYBq6EBTYObq2\n9SBYn35PBq3qugyTua9UgvQwBJg6gcWJD6Kajvha59H2EGn6ayPH0+y09vTzKX2d\nWq217+AgW4mcve5nmmpXfSaBJTgKARSC1hvKdD6F4aAA1POyGnxOUwp59sxS1/St\n7kLWn2nzBNTB+LM7LgHl+Hh9UmO7jHByU+n3TvAIcln4MdlFg2yP9WrnsmqzVKQV\nD9lElEbnhwIDAQABo3EwbzBOBgNVHREERzBFghVzc28uZmgtc2FsemJ1cmcuYWMu\nYXSGLGh0dHBzOi8vc3NvLmZoLXNhbHpidXJnLmFjLmF0L2lkcC9zaGliYm9sZXRo\nMB0GA1UdDgQWBBRXF8WMjO3oWLjWjDoEQflppkFdsDANBgkqhkiG9w0BAQUFAAOC\nAQEAKRJ6BIo1ncQCtJMGBIEyqqM36wds49G6Xw/awi3wOUasPc7gyYQhb5IyOktt\nktuDWZIWYiqjPPtTvwkYjCN220qaX2ihH8LkMadmRasaQQA92LNnya4c9vCjGkWq\negJ9WMSbV3alBpo94ljPNl1Hl62Zr5rG/S03NvQj9s6P7o/B8Kbz72kKjRmY37BV\nAIxGRgnuyptAjR8b52K+b6ulQ7fmNZghE8/DgOWz+XiIed7Q6fNp+frTsHD2sP/t\n3AGZtUbc+1qY/MVys1XAryOD6xUrg3oNDgobviNeAaAyckNI/lYs7SqVkxGKmRB0\nnrHqzrR12bmzu2xBInQmirFzcg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Fachhochschule Salzburg"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Salzburg University of Applied Sciences"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fh-salzburg.ac.at/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fh-salzburg.ac.at/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Fachhochschule Salzburg GmbH"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Salzburg University of Applied Sciences"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp-campus-condorcet.renater.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Anass Chabli"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "anass.chabli@renater.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Johann Holland"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "johann.holland@campus-condorcet.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-campus-condorcet.renater.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-12-01T12:05:03Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-campus-condorcet.renater.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-campus-condorcet.renater.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-campus-condorcet.renater.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "campus-condorcet.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.renater.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Utilisateurs Campus Condorcet"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Utilisateurs Campus Condorcet"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAAXNSR0IArs4c6QAAAARnQU1BAACxjwv8YQUAAAAJcEhZcwAADsQAAA7EAZUrDhsAAACESURBVDhPY7jGIPufEkw9A25JGv8nBWAY8MAhDCpFHMAwgFj8uqEPuwHEuACk7uuB43A2dQ2AOQ1Ew8SwYZxeQDcARCNjkM0wDAIgF+M1gBCA6cPrApAt6BimHobhBsCcBqJhikGGYDMIZgmKASBBUgBOA5Bdgg3DXIVhALmYQgNk/wMAQ2Cys1X73UcAAAAASUVORK5CYII=",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CAMPUS CONDORCET"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CAMPUS CONDORCET"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CAMPUS CONDORCET"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.renater.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CAMPUS CONDORCET"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://rems.csc.fi",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lauros"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:janne.lauros@csc.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Janne"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lauros"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:janne.lauros@csc.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Janne"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://rems.csc.fi",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CSC - Tieteen tietotekniikan keskus Oy"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CSC - IT Center for Science Ltd."
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CSC - IT-centret f\u00f6r vetenskap"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csc.fi"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csc.fi"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csc.fi"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CSC - Tieteen tietotekniikan keskus Oy"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CSC - IT Center for Science Ltd."
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CSC - IT-centret f\u00f6r vetenskap"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://rems.csc.fi/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://rems.csc.fi/Shibboleth.sso/Login2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Resource Entitlement Management\n                    System"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "REMS-palvelun kautta tutkijat voivat hakea k\u00e4ytt\u00f6oikeuksia tutkimuksen tietoaineistoihin"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://rems.csc.fi/web/guest/privacy-policy"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://rems.csc.fi/web/guest/tietosuojaseloste"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "REMS"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "REMS"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6DCCAdCgAwIBAgIJAJNkHpbnqskZMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\n                        BAMTC3JlbXMuY3NjLmZpMB4XDTEyMTAwNDA2NDc1M1oXDTIyMTAwMjA2NDc1M1ow\n                        FjEUMBIGA1UEAxMLcmVtcy5jc2MuZmkwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n                        ggEKAoIBAQCti37oqpPuAfgsIAc7VwKA+3L99iuTlFG9jlGTJiurXW/ARwl5y8FX\n                        HWDYmdg5GECe7qHsvKAhgGnJ6x0qmhJZacbvBuhofGZBHliG6ykCX377HA09pDr1\n                        db9WRhRMwz/w46mZU/9n/r3BfXXNpmAsdHiC/nD+0lPoOEHfo9wN0JsqO4SQUbya\n                        0cyMle8YVlPeF+8voug2lNvcDRcx9CRvAMTHuJX9HBTYE0XtAgHZOymZ10KvBDnq\n                        Lw7z0bndgUuSAp5puWH1eKGZt1S6rslLeMVw7xlTlds4HmGc5CRkJyZ0WKkU0VI2\n                        THDKIHlWCkJ+X0i04TFYtiJKxwavAjoRAgMBAAGjOTA3MBYGA1UdEQQPMA2CC3Jl\n                        bXMuY3NjLmZpMB0GA1UdDgQWBBSTogtyEd5toTA7qpl65syr7UE9OzANBgkqhkiG\n                        9w0BAQUFAAOCAQEAkHuPNT6e9a3PG8dy/OcUfY+ln2NA1gThNFRc0ZdhsRML1MXk\n                        hTPyv6v04KsyfEH4OjkpyTqcVCvs6jjVZrQmPyzU3nXu1aPyM7lYvGikVM/oFRAV\n                        0H4Cz+Yj8mKCddTdxAAiNyuqjOf+eYlRv3SyNjIYYM6OmqD0mH/mPZ6ado41ALUN\n                        0iqdiwFeKwjOlKALGVW92ihgU8uX3ScC6jCbAdPTu2m+NBO42pKNVYasHI0PBJmB\n                        HCZKDHCPHeGmXn6ab0zU6GbvGrxAKWDwJNw9mgRfxKqvTpVI9hY8QOE4eAjH7UJz\n                        c3E0G+pYuKCVKHVH6HOcuVL23IneYlhKtmz+Kw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://rems.csc.fi/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Valtuutuuksien Hallinta\n                Jarjestelma"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Resource Entitlement Management\n                System"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "REMS"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "REMS"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "cn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganizationType",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://se.timeedit.net/kau-student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@evolvera.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TimeEdit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://se.timeedit.net/kau-student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://se.timeedit.net/web/kau/db1/timeedit/ssoLogout/student_saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TimeEdit, utvecklat av TimeEdit AB"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TimeEdit, developed by TimeEdit AB"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TimeEdit f\u00f6r studenter vid Karlstads universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TimeEdit for students at Karlstad University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDcDCCAlgCCQDVKUGzGrt/2jANBgkqhkiG9w0BAQsFADB6MQswCQYDVQQGEwJTRTEYMBYGA1UE\nCAwPVmFzdHJhIGdvdGFsYW5kMRMwEQYDVQQHDApHb3RoZW5idXJnMRQwEgYDVQQKDAtUaW1lRWRp\ndCBBQjELMAkGA1UECwwCSVQxGTAXBgNVBAMMEGF1dGgudGltZWVkaXQuc2UwHhcNMTUwNjE1MTAw\nMjEzWhcNMjUwNjEyMTAwMjEzWjB6MQswCQYDVQQGEwJTRTEYMBYGA1UECAwPVmFzdHJhIGdvdGFs\nYW5kMRMwEQYDVQQHDApHb3RoZW5idXJnMRQwEgYDVQQKDAtUaW1lRWRpdCBBQjELMAkGA1UECwwC\nSVQxGTAXBgNVBAMMEGF1dGgudGltZWVkaXQuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQCgv6XIGV5MzRQbAY8tc9x8Eyuiac+o/z6qUT6s6zSYRu83Jd0RZPRnk/9egxV8RElBDq/k\nMAkXhzejUGI+yFkvxyPpB0u4lct9U0a7mbOr+UqkH+ffxjhxZjEjI20FxX29woMhFRtA//bucQ8y\nxuzYhoJd/pXeXfJCpvKZlPJ3ycF9lkUb3nMMoFNIPlRDddb4tu+MpJljioOPIWR45+PyRXKW1ZMd\nEy8pMoYt42sbIIWJoxj+9/IDbaA7LPg7Zxj+ioWzz7zYA6zdKLj54aQUCrcJ0RZIThzr2gOvMRaT\n5sqDHDmrKFZD/Xd6HwCJkwN6qFPurfZG2GoSnwZ/A8zVAgMBAAEwDQYJKoZIhvcNAQELBQADggEB\nADv6hhEsCrpbERGv6rFlEvHmYtYrjgJBLF3a91PIvVGPENI6HwJhsges/5idijAIcJyeItd0+UAf\neTCMriyNnrqfOdOMaHMC+OXcS1+SV+ZLY6SlAWUzbNlwCTyjETfteMEX70fcKIT+Suv+4nA1ZS9o\ng3y728pny0W+yhYxgjs7mSfG2XZIjzV53qGqCscLu8ASWmlSsqtiUfGueWAfGWHEVDDIr95IMy/u\nTG/lyQTEzr6BTeWusqhm6UXKHguQTvdcpUfH+n4L34gCi0CwMcSfyeRecYdLYPbWKAksD570x5Rd\nYFMsQoFZQd+f5DZjuG5tfyWUpcNd+REWUddnOOM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://se.timeedit.net/web/kau/db1/timeedit/ssoResponse/student_saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "false"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://www.lsesu.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.lsesu.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-10-24T10:30:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "London School of Economics Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lsesu.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.lsesu.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.lsesu.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.lsesu.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.lsesu.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.lsesu.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.lsesu.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.lsesu.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.lsesu.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.lsesu.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.lsesu.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.lsesu.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.lsesu.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.lsesu.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ec1.educationcity.com/sso/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@educationcity.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Customer Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:InternalSystems@educationcity.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EdCity Systems Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ec1.educationcity.com/sso/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-08-20T14:23:02Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EducationCity"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.educationcity.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "EducationCity Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ec1.educationcity.com/sso/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEPTCCAyWgAwIBAgIJAIjiPhX9pD21MA0GCSqGSIb3DQEBBQUAMIG0MQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEQMA4GA1UECAwHUnV0bGFuZDEPMA0GA1UEBwwGT2FraGFtMRswGQYD\n\t\t\t\t\t\tVQQKDBJFZHVjYXRpb24gQ2l0eSBMdGQxEDAOBgNVBAsMB0lUIERlcHQxHjAcBgNV\n\t\t\t\t\t\tBAMMFWVjMS5lZHVjYXRpb25jaXR5LmNvbTEzMDEGCSqGSIb3DQEJARYkRUMuVUsu\n\t\t\t\t\t\tSVQuTGludXhUZWFtQEVkdWNhdGlvbkNpdHkuY29tMB4XDTE0MDgxOTA5NDA0M1oX\n\t\t\t\t\t\tDTI0MDgxODA5NDA0M1owgbQxCzAJBgNVBAYTAkdCMRAwDgYDVQQIDAdSdXRsYW5k\n\t\t\t\t\t\tMQ8wDQYDVQQHDAZPYWtoYW0xGzAZBgNVBAoMEkVkdWNhdGlvbiBDaXR5IEx0ZDEQ\n\t\t\t\t\t\tMA4GA1UECwwHSVQgRGVwdDEeMBwGA1UEAwwVZWMxLmVkdWNhdGlvbmNpdHkuY29t\n\t\t\t\t\t\tMTMwMQYJKoZIhvcNAQkBFiRFQy5VSy5JVC5MaW51eFRlYW1ARWR1Y2F0aW9uQ2l0\n\t\t\t\t\t\teS5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC5QxN9XYDVZTK0\n\t\t\t\t\t\tusU9h6obEuliBKYsE/qLoqFMsw0dco3OrsVJ3f9Pqi2a+CU3Y79QhvTlXZ+vnDbA\n\t\t\t\t\t\ttJJpuJeMWv2H+WIA7xg8n0fB06WptCyNTrJGLVbJV067y+ZVWccSHe79j61MSnT2\n\t\t\t\t\t\t5LGIVDOnk+tPn7GY6oi2ZTtYxblyzwkyILZwibzr7qL8eBSTq280MfKIh7HVBHXu\n\t\t\t\t\t\tw1B37r/xEx+WbCUh0jmMDOhbiqX55RFMJ3/QUyZ5MVbboBGeYPcFoYuUg7gpYdJ5\n\t\t\t\t\t\tpLmZ4Nh+7r6w1if5vEkBpxFKoK2xBHjbkb8bm+GBVqsoGJSvUi0++YwtvzamoItT\n\t\t\t\t\t\tNiKowoApAgMBAAGjUDBOMB0GA1UdDgQWBBT9bgLO7VbORM8dToe750exXs6tkzAf\n\t\t\t\t\t\tBgNVHSMEGDAWgBT9bgLO7VbORM8dToe750exXs6tkzAMBgNVHRMEBTADAQH/MA0G\n\t\t\t\t\t\tCSqGSIb3DQEBBQUAA4IBAQBTkg85PXmm+DmjVDQdiF8zqqOn8L4sdM+4Xsc07e9/\n\t\t\t\t\t\tPyKEgwB3sHIJXG7epi8TreT8tMx0Z00tQ/GyAlk9lWBlhq1ZGkbDxda9M8qavDWY\n\t\t\t\t\t\tOomRV6hd2tV4Gkz008oGhfY50f0Kc1zH0IBiirUV0UUk0tMgWCZS4xMUeIClFD0L\n\t\t\t\t\t\tRFZyAKocyTEPKFZQ4Por2e2Bjt/2YP62oJWzCTtFQU2PPtaLvSiMjq7V5WQxuIkc\n\t\t\t\t\t\tVWHrGzZgfMi1jKdxwyJ8oYZr7rpKviXgjOzQlEkUt2ncrEY75PMHk+bWjbNqNPds\n\t\t\t\t\t\tjpTxJAAZ5N53YVB4oS8yLRl13dJv1rY522iqlxTkvBz0"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEPTCCAyWgAwIBAgIJAIjiPhX9pD21MA0GCSqGSIb3DQEBBQUAMIG0MQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEQMA4GA1UECAwHUnV0bGFuZDEPMA0GA1UEBwwGT2FraGFtMRswGQYD\n\t\t\t\t\t\tVQQKDBJFZHVjYXRpb24gQ2l0eSBMdGQxEDAOBgNVBAsMB0lUIERlcHQxHjAcBgNV\n\t\t\t\t\t\tBAMMFWVjMS5lZHVjYXRpb25jaXR5LmNvbTEzMDEGCSqGSIb3DQEJARYkRUMuVUsu\n\t\t\t\t\t\tSVQuTGludXhUZWFtQEVkdWNhdGlvbkNpdHkuY29tMB4XDTE0MDgxOTA5NDA0M1oX\n\t\t\t\t\t\tDTI0MDgxODA5NDA0M1owgbQxCzAJBgNVBAYTAkdCMRAwDgYDVQQIDAdSdXRsYW5k\n\t\t\t\t\t\tMQ8wDQYDVQQHDAZPYWtoYW0xGzAZBgNVBAoMEkVkdWNhdGlvbiBDaXR5IEx0ZDEQ\n\t\t\t\t\t\tMA4GA1UECwwHSVQgRGVwdDEeMBwGA1UEAwwVZWMxLmVkdWNhdGlvbmNpdHkuY29t\n\t\t\t\t\t\tMTMwMQYJKoZIhvcNAQkBFiRFQy5VSy5JVC5MaW51eFRlYW1ARWR1Y2F0aW9uQ2l0\n\t\t\t\t\t\teS5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC5QxN9XYDVZTK0\n\t\t\t\t\t\tusU9h6obEuliBKYsE/qLoqFMsw0dco3OrsVJ3f9Pqi2a+CU3Y79QhvTlXZ+vnDbA\n\t\t\t\t\t\ttJJpuJeMWv2H+WIA7xg8n0fB06WptCyNTrJGLVbJV067y+ZVWccSHe79j61MSnT2\n\t\t\t\t\t\t5LGIVDOnk+tPn7GY6oi2ZTtYxblyzwkyILZwibzr7qL8eBSTq280MfKIh7HVBHXu\n\t\t\t\t\t\tw1B37r/xEx+WbCUh0jmMDOhbiqX55RFMJ3/QUyZ5MVbboBGeYPcFoYuUg7gpYdJ5\n\t\t\t\t\t\tpLmZ4Nh+7r6w1if5vEkBpxFKoK2xBHjbkb8bm+GBVqsoGJSvUi0++YwtvzamoItT\n\t\t\t\t\t\tNiKowoApAgMBAAGjUDBOMB0GA1UdDgQWBBT9bgLO7VbORM8dToe750exXs6tkzAf\n\t\t\t\t\t\tBgNVHSMEGDAWgBT9bgLO7VbORM8dToe750exXs6tkzAMBgNVHRMEBTADAQH/MA0G\n\t\t\t\t\t\tCSqGSIb3DQEBBQUAA4IBAQBTkg85PXmm+DmjVDQdiF8zqqOn8L4sdM+4Xsc07e9/\n\t\t\t\t\t\tPyKEgwB3sHIJXG7epi8TreT8tMx0Z00tQ/GyAlk9lWBlhq1ZGkbDxda9M8qavDWY\n\t\t\t\t\t\tOomRV6hd2tV4Gkz008oGhfY50f0Kc1zH0IBiirUV0UUk0tMgWCZS4xMUeIClFD0L\n\t\t\t\t\t\tRFZyAKocyTEPKFZQ4Por2e2Bjt/2YP62oJWzCTtFQU2PPtaLvSiMjq7V5WQxuIkc\n\t\t\t\t\t\tVWHrGzZgfMi1jKdxwyJ8oYZr7rpKviXgjOzQlEkUt2ncrEY75PMHk+bWjbNqNPds\n\t\t\t\t\t\tjpTxJAAZ5N53YVB4oS8yLRl13dJv1rY522iqlxTkvBz0"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ec1.educationcity.com/sso/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ec1.educationcity.com/sso/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ec1.educationcity.com/sso/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ec1.educationcity.com/sso/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.imperial.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McLennan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:n.mclennan@imperial.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Neil"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McLennan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:n.mclennan@imperial.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Neil"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.imperial.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-12-07T15:04:06Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYDCCAkgCCQDjJF1/WYnlsjANBgkqhkiG9w0BAQUFADByMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEPMA0GA1UEBwwGTG9uZG9uMSAwHgYDVQQKDBdJbXBlcmlhbCBDb2xsZWdlIExv\n\t\t\t\t\t\tbmRvbjEMMAoGA1UECwwDSUNUMSIwIAYDVQQDDBlzaGliYm9sZXRoLmltcGVyaWFs\n\t\t\t\t\t\tLmFjLnVrMB4XDTEzMDUwMjE1NDcyMVoXDTMzMDQyNzE1NDcyMVowcjELMAkGA1UE\n\t\t\t\t\t\tBhMCR0IxDzANBgNVBAcMBkxvbmRvbjEgMB4GA1UECgwXSW1wZXJpYWwgQ29sbGVn\n\t\t\t\t\t\tZSBMb25kb24xDDAKBgNVBAsMA0lDVDEiMCAGA1UEAwwZc2hpYmJvbGV0aC5pbXBl\n\t\t\t\t\t\tcmlhbC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMxAnDyn\n\t\t\t\t\t\tQHFHVPockHEPcWY70joBPv5GA7uT+SqC1z1wv3LBph6XcOhzAo9Xv7ZHK/GLjo7s\n\t\t\t\t\t\trUwZOeP34XDDKytxA7+suaxzyXvLieiw8DIauHZrFiX9DPEvmjJGAMAeQnStLrr/\n\t\t\t\t\t\tc62m8EvOmGrp0hjh9W8Lu/4NtWJuW2rUa2BZIPDskL9qZbYlyQ2RzPpG7yFNtUwG\n\t\t\t\t\t\t5qhNigg2h5S4nJP8fA3LbMcTxijg5Pr+P5L2sYxHaXoVORZLTM1Ntz7JObaNK27u\n\t\t\t\t\t\tVVFV0K7BdpnIjMrOV/uZhEJGgODdXG1qBzItxBLQNCq2AYGYeCFawd5wJfRLRcaD\n\t\t\t\t\t\tnCd0ayGrmasOvPsCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAKSFrP+8jjrpPD70+\n\t\t\t\t\t\tDYfQZCMZng6eoHfOsTaylUNHpfwrPGBITD1uu27OblMyw6KVncQHv86JBdVjDJ0T\n\t\t\t\t\t\tsoPNdUDNO/ive6jgRlHAKRN337IDAiyVLC7eNBBm5ofIECroy02r5ky32diX2GH8\n\t\t\t\t\t\tVMTm57mqOmOFgN0in1t2Nobl70hfHV4P+k6XKwVspjwAe4ZjfGdN83bOclR1LovF\n\t\t\t\t\t\tEGdpH3yR/c95KaT/pQDJjpgdv6EE2duDckyDDeFabHacXtUGuaMAb6vK0xAaA1V6\n\t\t\t\t\t\ttVAi5wjRyhiG7+DEjkBNazHUkzB6+116OvkouR3P7w//b8IGo70DoD6WpBAfQwWO\n\t\t\t\t\t\tLPc7Eg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "imperial.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.imperial.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.imperial.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.imperial.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.imperial.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.imperial.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.imperial.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.imperial.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.imperial.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "imperial.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYDCCAkgCCQDjJF1/WYnlsjANBgkqhkiG9w0BAQUFADByMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEPMA0GA1UEBwwGTG9uZG9uMSAwHgYDVQQKDBdJbXBlcmlhbCBDb2xsZWdlIExv\n\t\t\t\t\t\tbmRvbjEMMAoGA1UECwwDSUNUMSIwIAYDVQQDDBlzaGliYm9sZXRoLmltcGVyaWFs\n\t\t\t\t\t\tLmFjLnVrMB4XDTEzMDUwMjE1NDcyMVoXDTMzMDQyNzE1NDcyMVowcjELMAkGA1UE\n\t\t\t\t\t\tBhMCR0IxDzANBgNVBAcMBkxvbmRvbjEgMB4GA1UECgwXSW1wZXJpYWwgQ29sbGVn\n\t\t\t\t\t\tZSBMb25kb24xDDAKBgNVBAsMA0lDVDEiMCAGA1UEAwwZc2hpYmJvbGV0aC5pbXBl\n\t\t\t\t\t\tcmlhbC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMxAnDyn\n\t\t\t\t\t\tQHFHVPockHEPcWY70joBPv5GA7uT+SqC1z1wv3LBph6XcOhzAo9Xv7ZHK/GLjo7s\n\t\t\t\t\t\trUwZOeP34XDDKytxA7+suaxzyXvLieiw8DIauHZrFiX9DPEvmjJGAMAeQnStLrr/\n\t\t\t\t\t\tc62m8EvOmGrp0hjh9W8Lu/4NtWJuW2rUa2BZIPDskL9qZbYlyQ2RzPpG7yFNtUwG\n\t\t\t\t\t\t5qhNigg2h5S4nJP8fA3LbMcTxijg5Pr+P5L2sYxHaXoVORZLTM1Ntz7JObaNK27u\n\t\t\t\t\t\tVVFV0K7BdpnIjMrOV/uZhEJGgODdXG1qBzItxBLQNCq2AYGYeCFawd5wJfRLRcaD\n\t\t\t\t\t\tnCd0ayGrmasOvPsCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAKSFrP+8jjrpPD70+\n\t\t\t\t\t\tDYfQZCMZng6eoHfOsTaylUNHpfwrPGBITD1uu27OblMyw6KVncQHv86JBdVjDJ0T\n\t\t\t\t\t\tsoPNdUDNO/ive6jgRlHAKRN337IDAiyVLC7eNBBm5ofIECroy02r5ky32diX2GH8\n\t\t\t\t\t\tVMTm57mqOmOFgN0in1t2Nobl70hfHV4P+k6XKwVspjwAe4ZjfGdN83bOclR1LovF\n\t\t\t\t\t\tEGdpH3yR/c95KaT/pQDJjpgdv6EE2duDckyDDeFabHacXtUGuaMAb6vK0xAaA1V6\n\t\t\t\t\t\ttVAi5wjRyhiG7+DEjkBNazHUkzB6+116OvkouR3P7w//b8IGo70DoD6WpBAfQwWO\n\t\t\t\t\t\tLPc7Eg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Imperial College London"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.imperial.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Imperial College of Science, Technology and Medicine"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://grnetbox.duth.gr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@duth.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Democritus University of Thrace NOC"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+30-25410-79200"
            }
          ]
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@duth.gr"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Democritus University of Thrace NOC"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+30-25410-79200"
            }
          ]
        }
      ],
      "entity_id": "https://grnetbox.duth.gr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF/TCCBWagAwIBAgIBBzANBgkqhkiG9w0BAQUFADCBjjELMAkGA1UEBhMCR1Ix\n                            LjAsBgNVBAoTJUdyZWVrIFJlc2VhcmNoIGFuZCBUZWNobm9sb2d5IE5ldHdvcmsx\n                            LzAtBgNVBAMTJkdSTkVUIEdybmV0Ym94IENlcnRpZmljYXRpb24gQXV0aG9yaXR5\n                            MR4wHAYJKoZIhvcNAQkBFg9jYUBub2MuZ3JuZXQuZ3IwHhcNMTAwMTI3MTMxMDAw\n                            WhcNMTUwMTI2MTMxMDAwWjBYMQswCQYDVQQGEwJHUjEuMCwGA1UEChMlR3JlZWsg\n                            UmVzZWFyY2ggYW5kIFRlY2hub2xvZ3kgTmV0d29yazEZMBcGA1UEAxMQZ3JuZXRi\n                            b3guZHV0aC5ncjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMnj3Hsi\n                            yckz+IisKeI8KCCapb42qNVJ3qEm26dLQcSfz9EGL955L6dhlqEdsdtviml6to9w\n                            sVV/EgzZNw+9zGDD33Qbq770RCrGwj47VkTeN20ECB06PW0qUVZuYwL3D0jeq09U\n                            65MXFa0W3DinYGlH/0kj0NrYNutKqspQXgxj587CfiQEvNf52W3HYhI46ZpdafUZ\n                            txOGd6f33kFFtchkfs1K7WXNI2Myr18kWsGn+8UZdSrv6HRn3cx8KqDP23C4WeAa\n                            9CWqZCd0mQ9x7CTtpaGdptRrUKeaL7zmo/c7aGhbHyXnDszP+/GkbvFAsqqrgqFF\n                            b0qEEL7oTXrn7AECAwEAAaOCAxowggMWMAwGA1UdEwEB/wQCMAAwEQYJYIZIAYb4\n                            QgEBBAQDAgbAMIGPBglghkgBhvhCAQ0EgYEWf1RoaXMgY2VydGlmaWNhdGUgaXMg\n                            c3ViamVjdCB0byBHcmVlayBsYXdzIGFuZCBHUk5FVCdzIENQUyBhbmQgbXVzdCBv\n                            bmx5IGJlIHVzZWQgZm9yIEFjYWRlbWljLCBSZXNlYXJjaCBvciBFZHVjYXRpb25h\n                            bCBwdXJwb3Nlcy4wHQYDVR0OBBYEFOcrove1OrOCKMabX2D9cx4TP0IXMIG7BgNV\n                            HSMEgbMwgbCAFAoZMZ2th54nXoq9jp6+4FZvEvnPoYGUpIGRMIGOMQswCQYDVQQG\n                            EwJHUjEuMCwGA1UEChMlR3JlZWsgUmVzZWFyY2ggYW5kIFRlY2hub2xvZ3kgTmV0\n                            d29yazEzMDEGA1UEAxMqR1JuZXQgQ2VudHJhbCBDZXJ0aWZpY2F0aW9uIEF1dGhv\n                            cml0eSAyMDA5MRowGAYJKoZIhvcNAQkBFgtjYUBncm5ldC5ncoIBAzAgBgNVHSUB\n                            Af8EFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwDgYDVR0PAQH/BAQDAgTwMBsGA1Ud\n                            EQQUMBKCEGdybmV0Ym94LmR1dGguZ3IwPgYJYIZIAYb4QgECBDEWL2h0dHBzOi8v\n                            Y3JsdjEucGtpLmdybmV0LmdyL0dybmV0U2VydmVyc0NBLzIwMDkvMCMGCWCGSAGG\n                            +EIBBAQWFhRuc19yZXZva2VfcXVlcnkucGhwPzBPBglghkgBhvhCAQgEQhZAaHR0\n                            cDovL3d3dy5wa2kuZ3JuZXQuZ3IvZG9jdW1lbnRzL0dybmV0U2VydmVyc0NBLzIw\n                            MDkvQ1AxLjAuaHRtbDA1BggrBgEFBQcBAQQpMCcwJQYIKwYBBQUHMAGGGWh0dHA6\n                            Ly9vY3NwLnBraS5ncm5ldC5nci8wSAYDVR0fBEEwPzA9oDugOYY3aHR0cDovL2Ny\n                            bHYxLnBraS5ncm5ldC5nci9Hcm5ldFNlcnZlcnNDQS8yMDA5L2NybHYxLmNybDAN\n                            BgkqhkiG9w0BAQUFAAOBgQB2M+X92LGPeSzIHK32x2RCeo+j4tCazhkl7kSGd4NY\n                            eiWAYwH4cpOr5Xi0zLBG/vdCRuZGsRZgoRAeqMQO0mRhCSOK+s1APux6yDQLk+Yy\n                            pNBpS87jQzgaOP0J4JXKd+lcLNN+FYoA+PZX8zaPELVWTG1DYBK//D4qe0/GCAQt\n                            zg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "duth.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://grnetbox.duth.gr:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://grnetbox.duth.gr:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.duth.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.duth.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.duth.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.duth.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://grnetbox.duth.gr:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://grnetbox.duth.gr:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "duth.gr"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.duth.gr/"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.duth.gr/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://utopia.duth.gr/images/duth_logo_156x69.png",
                    "height": "69",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "156"
                  },
                  {
                    "text": "https://utopia.duth.gr/images/duth_logo_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Democritus University of Thrace"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u0394\u03b7\u03bc\u03bf\u03ba\u03c1\u03af\u03c4\u03b5\u03b9\u03bf \u03a0\u03b1\u03bd\u03b5\u03c0\u03b9\u03c3\u03c4\u03ae\u03bc\u03b9\u03bf \u0398\u03c1\u03ac\u03ba\u03b7\u03c2"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "duth.gr"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:41.136504, 25.372488"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.108.114.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "83.212.128.0/19"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "83.212.160.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:648:2e80::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF/TCCBWagAwIBAgIBBzANBgkqhkiG9w0BAQUFADCBjjELMAkGA1UEBhMCR1Ix\n                            LjAsBgNVBAoTJUdyZWVrIFJlc2VhcmNoIGFuZCBUZWNobm9sb2d5IE5ldHdvcmsx\n                            LzAtBgNVBAMTJkdSTkVUIEdybmV0Ym94IENlcnRpZmljYXRpb24gQXV0aG9yaXR5\n                            MR4wHAYJKoZIhvcNAQkBFg9jYUBub2MuZ3JuZXQuZ3IwHhcNMTAwMTI3MTMxMDAw\n                            WhcNMTUwMTI2MTMxMDAwWjBYMQswCQYDVQQGEwJHUjEuMCwGA1UEChMlR3JlZWsg\n                            UmVzZWFyY2ggYW5kIFRlY2hub2xvZ3kgTmV0d29yazEZMBcGA1UEAxMQZ3JuZXRi\n                            b3guZHV0aC5ncjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMnj3Hsi\n                            yckz+IisKeI8KCCapb42qNVJ3qEm26dLQcSfz9EGL955L6dhlqEdsdtviml6to9w\n                            sVV/EgzZNw+9zGDD33Qbq770RCrGwj47VkTeN20ECB06PW0qUVZuYwL3D0jeq09U\n                            65MXFa0W3DinYGlH/0kj0NrYNutKqspQXgxj587CfiQEvNf52W3HYhI46ZpdafUZ\n                            txOGd6f33kFFtchkfs1K7WXNI2Myr18kWsGn+8UZdSrv6HRn3cx8KqDP23C4WeAa\n                            9CWqZCd0mQ9x7CTtpaGdptRrUKeaL7zmo/c7aGhbHyXnDszP+/GkbvFAsqqrgqFF\n                            b0qEEL7oTXrn7AECAwEAAaOCAxowggMWMAwGA1UdEwEB/wQCMAAwEQYJYIZIAYb4\n                            QgEBBAQDAgbAMIGPBglghkgBhvhCAQ0EgYEWf1RoaXMgY2VydGlmaWNhdGUgaXMg\n                            c3ViamVjdCB0byBHcmVlayBsYXdzIGFuZCBHUk5FVCdzIENQUyBhbmQgbXVzdCBv\n                            bmx5IGJlIHVzZWQgZm9yIEFjYWRlbWljLCBSZXNlYXJjaCBvciBFZHVjYXRpb25h\n                            bCBwdXJwb3Nlcy4wHQYDVR0OBBYEFOcrove1OrOCKMabX2D9cx4TP0IXMIG7BgNV\n                            HSMEgbMwgbCAFAoZMZ2th54nXoq9jp6+4FZvEvnPoYGUpIGRMIGOMQswCQYDVQQG\n                            EwJHUjEuMCwGA1UEChMlR3JlZWsgUmVzZWFyY2ggYW5kIFRlY2hub2xvZ3kgTmV0\n                            d29yazEzMDEGA1UEAxMqR1JuZXQgQ2VudHJhbCBDZXJ0aWZpY2F0aW9uIEF1dGhv\n                            cml0eSAyMDA5MRowGAYJKoZIhvcNAQkBFgtjYUBncm5ldC5ncoIBAzAgBgNVHSUB\n                            Af8EFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwDgYDVR0PAQH/BAQDAgTwMBsGA1Ud\n                            EQQUMBKCEGdybmV0Ym94LmR1dGguZ3IwPgYJYIZIAYb4QgECBDEWL2h0dHBzOi8v\n                            Y3JsdjEucGtpLmdybmV0LmdyL0dybmV0U2VydmVyc0NBLzIwMDkvMCMGCWCGSAGG\n                            +EIBBAQWFhRuc19yZXZva2VfcXVlcnkucGhwPzBPBglghkgBhvhCAQgEQhZAaHR0\n                            cDovL3d3dy5wa2kuZ3JuZXQuZ3IvZG9jdW1lbnRzL0dybmV0U2VydmVyc0NBLzIw\n                            MDkvQ1AxLjAuaHRtbDA1BggrBgEFBQcBAQQpMCcwJQYIKwYBBQUHMAGGGWh0dHA6\n                            Ly9vY3NwLnBraS5ncm5ldC5nci8wSAYDVR0fBEEwPzA9oDugOYY3aHR0cDovL2Ny\n                            bHYxLnBraS5ncm5ldC5nci9Hcm5ldFNlcnZlcnNDQS8yMDA5L2NybHYxLmNybDAN\n                            BgkqhkiG9w0BAQUFAAOBgQB2M+X92LGPeSzIHK32x2RCeo+j4tCazhkl7kSGd4NY\n                            eiWAYwH4cpOr5Xi0zLBG/vdCRuZGsRZgoRAeqMQO0mRhCSOK+s1APux6yDQLk+Yy\n                            pNBpS87jQzgaOP0J4JXKd+lcLNN+FYoA+PZX8zaPELVWTG1DYBK//D4qe0/GCAQt\n                            zg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Democritus University of Thrace"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u0394\u03b7\u03bc\u03bf\u03ba\u03c1\u03af\u03c4\u03b5\u03b9\u03bf \u03a0\u03b1\u03bd\u03b5\u03c0\u03b9\u03c3\u03c4\u03ae\u03bc\u03b9\u03bf \u0398\u03c1\u03ac\u03ba\u03b7\u03c2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.duth.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.duth.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Democritus University of Thrace"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u0394\u03b7\u03bc\u03bf\u03ba\u03c1\u03af\u03c4\u03b5\u03b9\u03bf \u03a0\u03b1\u03bd\u03b5\u03c0\u03b9\u03c3\u03c4\u03ae\u03bc\u03b9\u03bf \u0398\u03c1\u03ac\u03ba\u03b7\u03c2"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.degruyter.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:service@degruyter.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "De Gruyter Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cipriano"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dgsupport@safaribooksonline.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Scott"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Warren"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dgsupport@safaribooksonline.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matt"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McCanne"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dgsupport@safaribooksonline.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Harlan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dgsupport@safaribooksonline.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "iFactory"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.degruyter.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Walter de Gruyter GmbH & Co KG: De Gruyter Online"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.degruyter.de/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Walter de Gruyter GmbH & Co KG"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIEJQQdIDANBgkqhkiG9w0BAQsFADAcMRowGAYDVQQDExF3\n\t\t\t\t\t\td3cuZGVncnV5dGVyLmNvbTAeFw0xNTAxMTUxNzE0MTdaFw0xODAyMDMxNzE0MTda\n\t\t\t\t\t\tMBwxGjAYBgNVBAMTEXd3dy5kZWdydXl0ZXIuY29tMIIBIjANBgkqhkiG9w0BAQEF\n\t\t\t\t\t\tAAOCAQ8AMIIBCgKCAQEAl4aKz3klp19cqVt/ayGr+UGIOBaROpLPEKlZtCUVq4rE\n\t\t\t\t\t\t/3X0LPEVOzmqWtxzRDhIsGBjuwgt1D/RFbY+1+YU3CL6B+wOOOBGOPcj1gr7ZLPK\n\t\t\t\t\t\tGTODNErwJCjzslISqbK9d1vpg5yI84bb8+IpYLb0XmsIoOkldxRHbmgcpfwt9GSm\n\t\t\t\t\t\tGngjsuMAbWc8L9a62iPeWlPBryCoYgQFH6FIhIACGJcrroP1+o+NZXFeQtbDXKCt\n\t\t\t\t\t\tv1gWTAPHvY2qLfc6qa+6DX+qMcWydtm46nNWrtvfkeQVnUxr0DcB68UafGbB3Vbu\n\t\t\t\t\t\ttbqU3afSodVKcsWgHaebgvoLhq/rmoeQ0PDPQVFKgwIDAQABo2UwYzBCBgNVHREE\n\t\t\t\t\t\tOzA5ghF3d3cuZGVncnV5dGVyLmNvbYYkaHR0cHM6Ly93d3cuZGVncnV5dGVyLmNv\n\t\t\t\t\t\tbS9zaGliYm9sZXRoMB0GA1UdDgQWBBSOhPCjGa1k6lBcSkwexlPasUaNjDANBgkq\n\t\t\t\t\t\thkiG9w0BAQsFAAOCAQEAFuKYNHwtCWU+iLXQRtat7nf0OpmjHiDwmi/BjVAt7OBZ\n\t\t\t\t\t\tzsgXQdfPk13YxlHlf++tvUnw2MOaIudtwZaITXRK6tSJ/I00PzNjofLVjsonz33O\n\t\t\t\t\t\tU5SmD94GNuBjcPJfvX7tHstOwlRYDmkIxMsdikfjyNLuahV0oRvh/igdKXH8ivv+\n\t\t\t\t\t\tCYuKzYRYn4wW24lUwj3CGbieBfOvnnpUEhCxRPDD12vdlWxI0/RDZzyERg82nYI7\n\t\t\t\t\t\t4YHNuVnvZuZuDKiJeM31WWr2LVjP15YoQ6S9lfsLo1NOHvlz/1/nV5y07MAHNEA1\n\t\t\t\t\t\tsS0svq7Jyv+IC8DB2S6yhH1Ew5R4ufZ887dEvMlJCQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://www.degruyter.com/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.degruyter.com/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.degruyter.com/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.degruyter.com/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.colchester.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.colchester.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/colchester.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/colchester.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "colchester.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Colchester Institute"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.colchester.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ipm.cas.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Van\u00ed\u010dek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vanicekp@utia.cas.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ipm.cas.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2014-05-02T15:43:18Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/avcr"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUHoc4WAOOS8FXFJOqANPx0dZofskwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOaWRwLmlwbS5jYXMuY3owHhcNMTQwMzMxMTEzNjMwWhcN\nMzQwMzMxMTEzNjMwWjAZMRcwFQYDVQQDEw5pZHAuaXBtLmNhcy5jejCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKtVmqQC+tS6991zGEb00Rpy9QTbyaqb\n/ImfelKGHYprdU+8gF7WQSldgVncAMSY+z2agvh4ojTqcGnDcMFp4MqLrK2+e2jF\n+9rNCGnj3NZoklOJbXDw3YAbqRgpAEeGqv7nribQEN0lkvwQHvSlU05oXmpqe2m+\nqgdMPznUxESq9hymiGfnINn3YRb57fYArbp1FaUvJ+S5sSjcREsvxvzmCrUfAcBZ\nxwK3gqrVrirVPAMFklKNLvIqHTOsnOqm+spc9OcdoyXDCGEpwOQ8868AY7Dat7SO\ngkrM0+zf1Ut9Fe/oRkMQ34Ozt07KsaV6P0rLXoT7elG5HoPAO8sWJRUCAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOaWRwLmlwbS5jYXMuY3qGJWh0dHBzOi8vaWRwLmlwbS5j\nYXMuY3ovaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFNmaGF8aU8MkTc6UkiWbbnad\n065mMA0GCSqGSIb3DQEBBQUAA4IBAQBQE0fUf6bV/7fscYI7zqh2nFV8qKcjP0jd\ndAKy17PaVFSkCGHgTX39K3kuacWA4a1SZBfN39KmQ9sj1GDF7Zci0V+tS/tbckbv\n1ME/Z+MyQTQTodGorOTdDsJKKdHbIIOVPOvO9IhX77ej4gFRX5+POQVSqtA/1Syp\n3oTa1zV9s/UD+WifYFmlUlF50Kw1hE9XXf/Mg4Aj664moUWKWk/ZoiEoa3fS4gyI\nU3lLI0Wpl9gNT3J89dwcansCYLHrppaXrp9ppEwnQe+gECcTLsGgytjJxS9vq5Qo\nHWJ2rutN+DemwFxa01O3ukfKoIRYNyWNajx2Ey8kS2kfoycp9Jgx"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ipm.cas.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ipm.cas.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ipm.cas.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ipm.cas.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ipm.cas.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ipm.cas.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ipm.cas.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ipm.cas.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ipm.cas.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ipm.cas.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ipm.cas.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ipm.cas.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ipm.cas.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ipm.cz/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ipm.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider IPM AV CR employees."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance \u00daFM AV \u010cR"
                  }
                ],
                "logo": [
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-ipm-44.png",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "74"
                  },
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-ipm-129.png",
                    "height": "411",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "960"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Physics of Materials of the AS CR"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u00dastav fyziky materi\u00e1l\u016f AV \u010cR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUHoc4WAOOS8FXFJOqANPx0dZofskwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOaWRwLmlwbS5jYXMuY3owHhcNMTQwMzMxMTEzNjMwWhcN\nMzQwMzMxMTEzNjMwWjAZMRcwFQYDVQQDEw5pZHAuaXBtLmNhcy5jejCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKtVmqQC+tS6991zGEb00Rpy9QTbyaqb\n/ImfelKGHYprdU+8gF7WQSldgVncAMSY+z2agvh4ojTqcGnDcMFp4MqLrK2+e2jF\n+9rNCGnj3NZoklOJbXDw3YAbqRgpAEeGqv7nribQEN0lkvwQHvSlU05oXmpqe2m+\nqgdMPznUxESq9hymiGfnINn3YRb57fYArbp1FaUvJ+S5sSjcREsvxvzmCrUfAcBZ\nxwK3gqrVrirVPAMFklKNLvIqHTOsnOqm+spc9OcdoyXDCGEpwOQ8868AY7Dat7SO\ngkrM0+zf1Ut9Fe/oRkMQ34Ozt07KsaV6P0rLXoT7elG5HoPAO8sWJRUCAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOaWRwLmlwbS5jYXMuY3qGJWh0dHBzOi8vaWRwLmlwbS5j\nYXMuY3ovaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFNmaGF8aU8MkTc6UkiWbbnad\n065mMA0GCSqGSIb3DQEBBQUAA4IBAQBQE0fUf6bV/7fscYI7zqh2nFV8qKcjP0jd\ndAKy17PaVFSkCGHgTX39K3kuacWA4a1SZBfN39KmQ9sj1GDF7Zci0V+tS/tbckbv\n1ME/Z+MyQTQTodGorOTdDsJKKdHbIIOVPOvO9IhX77ej4gFRX5+POQVSqtA/1Syp\n3oTa1zV9s/UD+WifYFmlUlF50Kw1hE9XXf/Mg4Aj664moUWKWk/ZoiEoa3fS4gyI\nU3lLI0Wpl9gNT3J89dwcansCYLHrppaXrp9ppEwnQe+gECcTLsGgytjJxS9vq5Qo\nHWJ2rutN+DemwFxa01O3ukfKoIRYNyWNajx2Ey8kS2kfoycp9Jgx"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Physics of Materials of the Academy of Sciences of the Czech Republic, v. v. i."
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u00dastav fyziky materi\u00e1l\u016f Akademie v\u011bd \u010cesk\u00e9 republiky, v.v.i."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ipm.cz/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ipm.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Physics of Materials"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u00dastav fyziky materi\u00e1l\u016f Akademie v\u011bd \u010cesk\u00e9 republiky"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-23.ladok.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-23.ladok.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;23"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;23"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-23.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-23.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJANMaJQIHvD4NMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0yMy5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTQ0NDI3WhcNMjQx\nMDA0MTQ0NDI3WjAhMR8wHQYDVQQDExZsYWRvazMtMjMubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2cGiumvjdyZKuwTntxWlX3x4\n5LV7nqUJGz0GlJ2qvKV2OD9DPc0as0BC5HvUpEd9T3gLojW0B7HOJDgOUVPEdgGB\nyGMyVdle/Ig3HD3S1AnupDL1bqvMZn/hU/sGRqDyJRUf8k+pFo39sAYqt5OeOXQu\nXJdCYfGCRBtu3kmG9kxNHjt/9FHzwiwefKZW0Nn0Wtc5cgMhDpx0iOCPc6Ckn0kq\n/KVcSlm8SnlGjMVzIJfUef2IkCw0qA0Wnt2CcCycK7OQXyP0YwLh9WPHZXRTKQxi\npaIeotdgZkccXEDFYA05l1deS1MtqiLoxarUFIgcM3X6kThHRmpOufMRLWBjKwID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMjMubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0yMy5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUODngsWRqAupbWEp7N9nRquKqkAQwDQYJKoZIhvcNAQEFBQADggEB\nAJmntLsSPqmmFcmrZJ4XixCDYsYlG88e0l0ii8FpEwCInneYjroLbrb5Od1JkHXR\nW+q6O1GMQfaFSW9YN5xcHoLtK20tRscCufVTlA5rj+Xks6vGT841Wf/pn8kEF6hW\n6RN+FBsEkFu1ACgbieyw4npngpYB8diJe5Ttcsvl/wRP7zjD7roP9K7cpvC5s694\nJO0lwUmaPXqAh5Jqh29w5EN+59O3xWJ9Ec37tCY5IkkcGnB5uAfP93K5eyMafX9V\ncA8Pb/ntxkRoZoGUw/oqpGrIpZMvGOFxehGdzOd+ZTpf9L0R37byGM94pTq6gz33\n69ezgM07kER3QrJpPLCrLT0="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-23.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-23.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://federacao.ifpi.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tercio de Andrade"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tercio@ifpi.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federacao.ifpi.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0DCCArgCAQAwDQYJKoZIhvcNAQEFBQAwga0xKjAoBgNVBAoTIUlGUEkgLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkbyBQaWF1aTEMMAoGA1UECxMDRFRJMSEwHwYJKoZI\nhvcNAQkBFhJ0ZXJjaW9AaWZwaS5lZHUuYnIxETAPBgNVBAcTCFRlcmVzaW5hMQ4w\nDAYDVQQIEwVQaWF1aTELMAkGA1UEBhMCQlIxHjAcBgNVBAMTFWZlZGVyYWNhby5p\nZnBpLmVkdS5icjAeFw0xNjAzMDIxOTM4NDJaFw0xOTAzMDIxOTM4NDJaMIGtMSow\nKAYDVQQKEyFJRlBJIC0gSW5zdGl0dXRvIEZlZGVyYWwgZG8gUGlhdWkxDDAKBgNV\nBAsTA0RUSTEhMB8GCSqGSIb3DQEJARYSdGVyY2lvQGlmcGkuZWR1LmJyMREwDwYD\nVQQHEwhUZXJlc2luYTEOMAwGA1UECBMFUGlhdWkxCzAJBgNVBAYTAkJSMR4wHAYD\nVQQDExVmZWRlcmFjYW8uaWZwaS5lZHUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQC/1EUfZJHbzLOdAqEtz8Uah+4VQUIEgrPl+VxDSVCgrJYJIrGi\nx2hSJ5iKdtA8Kt5S/n1+wzTb9Zqr2V2GAPLHO2pOZX4v7zIpr4CvKmVvelt2RqVK\nfj3uvXEekRMtagBOB5vsstZwfG3qXGBMyTAYmhb3V1G0pue28dp8PadOOG9QQo3R\n3FVOU+lB/aaAUdilDRd1pwpXMr8lreWVkf6g7kKOZpy6/dhRf59pzmm33Un042xo\nHVS+Hs7468RzHI4fVL3JYK1F7tau3y/CsHM8F2af2LcGBOIBIbQ0IxkaSA/J2NbF\n1cwE6IJlbeAQ/JRonafu4xl65ki1qMW4HzX/AgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBAA1nbQY2gwVbQ2VRZF9pQXtV4SqkR99cUQB+FbruqI+43LPiGWXvmvBdsJw+\nGbvqudEkTUGAF8QVN5WPY6cuv7c/K/h1EM3/yB1/7bwIyeiZ3hW6Va5pmVbvq37m\nDJ4FI0VULOyXvDMQCbeddKrVjcIaDCeevjx8dUtl/iJhZAGMdJOHMq4On1/k/zVU\nPtU6WNeXKNall08J8cfriXv3g9fCyQv7XGbBRb3lWqCrbjkZmHecs3uv+ysJvJnt\nxiJ1YdLyy8G6g2uhYcqFG+C2uVovnJi1i4qRci+wXwXlq4qxkgsO1mMujmvgZNHT\n1JIgJ0kLgW5FvD8OCs20PuBKBqc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://federacao.ifpi.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://federacao.ifpi.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://federacao.ifpi.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federacao.ifpi.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://federacao.ifpi.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federacao.ifpi.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://federacao.ifpi.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://federacao.ifpi.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifpi.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifpi.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFPI - Instituto Federal do Piaui"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFPI - Instituto Federal do Piaui"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFPI - Instituto Federal do Piaui"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFPI - Instituto Federal do Piaui"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0DCCArgCAQAwDQYJKoZIhvcNAQEFBQAwga0xKjAoBgNVBAoTIUlGUEkgLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkbyBQaWF1aTEMMAoGA1UECxMDRFRJMSEwHwYJKoZI\nhvcNAQkBFhJ0ZXJjaW9AaWZwaS5lZHUuYnIxETAPBgNVBAcTCFRlcmVzaW5hMQ4w\nDAYDVQQIEwVQaWF1aTELMAkGA1UEBhMCQlIxHjAcBgNVBAMTFWZlZGVyYWNhby5p\nZnBpLmVkdS5icjAeFw0xNjAzMDIxOTM4NDJaFw0xOTAzMDIxOTM4NDJaMIGtMSow\nKAYDVQQKEyFJRlBJIC0gSW5zdGl0dXRvIEZlZGVyYWwgZG8gUGlhdWkxDDAKBgNV\nBAsTA0RUSTEhMB8GCSqGSIb3DQEJARYSdGVyY2lvQGlmcGkuZWR1LmJyMREwDwYD\nVQQHEwhUZXJlc2luYTEOMAwGA1UECBMFUGlhdWkxCzAJBgNVBAYTAkJSMR4wHAYD\nVQQDExVmZWRlcmFjYW8uaWZwaS5lZHUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQC/1EUfZJHbzLOdAqEtz8Uah+4VQUIEgrPl+VxDSVCgrJYJIrGi\nx2hSJ5iKdtA8Kt5S/n1+wzTb9Zqr2V2GAPLHO2pOZX4v7zIpr4CvKmVvelt2RqVK\nfj3uvXEekRMtagBOB5vsstZwfG3qXGBMyTAYmhb3V1G0pue28dp8PadOOG9QQo3R\n3FVOU+lB/aaAUdilDRd1pwpXMr8lreWVkf6g7kKOZpy6/dhRf59pzmm33Un042xo\nHVS+Hs7468RzHI4fVL3JYK1F7tau3y/CsHM8F2af2LcGBOIBIbQ0IxkaSA/J2NbF\n1cwE6IJlbeAQ/JRonafu4xl65ki1qMW4HzX/AgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBAA1nbQY2gwVbQ2VRZF9pQXtV4SqkR99cUQB+FbruqI+43LPiGWXvmvBdsJw+\nGbvqudEkTUGAF8QVN5WPY6cuv7c/K/h1EM3/yB1/7bwIyeiZ3hW6Va5pmVbvq37m\nDJ4FI0VULOyXvDMQCbeddKrVjcIaDCeevjx8dUtl/iJhZAGMdJOHMq4On1/k/zVU\nPtU6WNeXKNall08J8cfriXv3g9fCyQv7XGbBRb3lWqCrbjkZmHecs3uv+ysJvJnt\nxiJ1YdLyy8G6g2uhYcqFG+C2uVovnJi1i4qRci+wXwXlq4qxkgsO1mMujmvgZNHT\n1JIgJ0kLgW5FvD8OCs20PuBKBqc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFPI - Instituto Federal do Piaui"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFPI - Instituto Federal do Piaui"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifpi.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifpi.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFPI - Instituto Federal do Piaui"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFPI - Instituto Federal do Piaui"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://prisma.research.se/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Borg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:peter.borg@vr.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Peter"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chrudina"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:robert.chrudina@tieto.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://prisma.research.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Prisma - prisma.research.se"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://prisma.research.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Prisma - prisma.research.se"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://prisma.research.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://prisma.research.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://prisma.research.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://prisma.research.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://prisma.research.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://prisma.research.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://prisma.research.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "I Prisma kan du ans\u00f6ka om forskningsmedel och hantera dina beviljade bidrag"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Prisma is a joint portal used by several research funders"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://prisma.research.se/Support?title=Personuppgifter&description=%5BSupport%5D%5BPersonalDetailsDescription%5D"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://prisma.research.se/Support?title=Privacy%20information&description=%5BSupport%5D%5BPersonalDetailsDescription%5D"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Prisma - prisma.research.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Prisma - prisma.research.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "prisma.research.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAPU2IVw8AYQPMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEnByaXNtYS5yZXNlYXJjaC5zZTAeFw0xNDA5MDMxNDIxMTlaFw0yNDA4MzEx\nNDIxMTlaMB0xGzAZBgNVBAMTEnByaXNtYS5yZXNlYXJjaC5zZTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALqrAUhqBgDhOW/hxr8dEk8nb8keS8ofEi1T\nFsq8ZHCA7kmulScKBEehlNF/vt/sLNV5OW2VCpqU308nhzB84nJfXOgq5vDw86jP\n8GZYRAaLp/Urvs7FpFBdTm+iCZ0j6Z0CxBkoZEyJydIkqTjwXnBVb3OpvRgI81W6\nga68vnzWxyFFsrfux/QQHTBaF+JD9a9Y6eQQks5eI1UwRbx5lh7PyEh+/+Ey5pnR\npsSBNfp7ooPtp0vO1No+7MG7XFZbkSxGBUvtzEBM/pTJaZwx1/PE46D1UgCDRetI\nipBqzEvt7/MFTpXDdj6ddWJ6UMivvhRw09I6wYM/RZHMB79Bw8kCAwEAAaNAMD4w\nHQYDVR0RBBYwFIIScHJpc21hLnJlc2VhcmNoLnNlMB0GA1UdDgQWBBQ9F/GdaD71\nnq1AcWdMt0lqlzXKOzANBgkqhkiG9w0BAQUFAAOCAQEAbM5ixtyeRLBc74m5enMi\nP6rpQ9Ech6nEs5/59eQ82k06ysD1FxoTd9udfoMMeYmzJtlVoTwfhr3ISNHybLUz\n1du5VrX5fxYIIz2C0awtunMbRQGlBbu3PDjJYKe5BACVGGOR5qfsAY8JJGOzb2a7\n2jKsShfCzBOdxPr3lxBpGJmhe/N9i11g9qdDR3htDXa2aUw/qnwlrUFjMrcnDtDy\nq6rkibKrh2uDmQ+BKvnBfSjuXfDTm2yvdPfk/WAG9f+besVy76dwUWx0GAZXhPm5\nkmPkqx0M3z4YLufx99FWaMygNYUnnge7O348i/SW7UvVALhU4391vqGw+XcSAMh6\nYw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=prisma.research.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://prisma.research.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://prisma.research.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://prisma.research.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://prisma.research.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://prisma.research.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Prisma - prisma.research.se"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eppn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.univ-paris-est.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "systeme-information@univ-paris-est.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.univ-paris-est.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-07-10T14:34:50Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.univ-paris-est.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.univ-paris-est.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.univ-paris-est.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-paris-est.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-paris-est.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 Paris - Est"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 Paris - Est"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDXDCCAkSgAwIBAgIVAN+DxU7o62WL7i36RkN6D6PRm0jqMA0GCSqGSIb3DQEB\nBQUAMCcxJTAjBgNVBAMTHHNoaWJib2xldGgudW5pdi1wYXJpcy1lc3QuZnIwHhcN\nMTIwNzA0MDcyMjAwWhcNMzIwNzA0MDcyMjAwWjAnMSUwIwYDVQQDExxzaGliYm9s\nZXRoLnVuaXYtcGFyaXMtZXN0LmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\nCgKCAQEAkrTsAnTcBP9CxCVbjCyA74Nl/zSOMm1L3Iy6DHDAKHvDdpj+RwrrhmQW\nsFBn6HqmSkCe6uO+7NwWfCIF5h0PdvRFNCfAQNLv6k5d3PU6Ala8gIKrUuviQUul\nAMd2JsGoVhbUB2ieQFWn8CrBkjFbvuLBd4Dlgmiw/mveqwiLapzmi/CRHcHQOSiP\neDl7p9bUXfpYkJN0974ptVB6phGMyVWpW1q1n61W/xN84NCOCeo0yMNqGRkhJfyN\nhrczmA5QFL3QF11imB3Y6kHZFkBRSSr0B+0FvKjxgfej3C7P0KWNmeYPPHxhYKmx\nG0Sii5++F5IdUiLgpA5b6SHVLrDHiwIDAQABo38wfTBcBgNVHREEVTBTghxzaGli\nYm9sZXRoLnVuaXYtcGFyaXMtZXN0LmZyhjNodHRwczovL3NoaWJib2xldGgudW5p\ndi1wYXJpcy1lc3QuZnIvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFCmKWcbQVqe7\nUnO+QpVcDdKOFRGzMA0GCSqGSIb3DQEBBQUAA4IBAQAEQTnWIsJCaKZp8hJvMkwp\n3TBuf0rF8MvQlF2zAXb6ZsWLl41tEYZxFOFMny0GR7JjfWQqKWr7Db/R13e6xFiy\nvlRibUEZS3cR/1TtOEj7PqttNuZrWJVAgBzAHHgJPyWz9C3Q8d474YVHwJsYCDIY\nmGObSSmyOTQAKqFYYNbPW0Y9X2jSWjS5D7JLhA6jECosQiFU212cSyCShHilp75V\n7qS8dXivDDTgSLzSTzOlPKj3qgR+6mmDYClqCaJe2iFfSMBCbk2aspn8+6hQceM4\nW1qZBfNF1cOpL5ceUG8MFu0NLSbSyFh+3TSWBJKFl6Ml3PqAQcMvfXRZ3QVZ+sWR"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 Paris - Est"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-paris-est.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 Paris - Est"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.reachoutcpd.com/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kemp"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pkemp@twig-world.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Patricia"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Munn"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dmunn@twig-world.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.reachoutcpd.com/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-13T11:02:22Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ReachOut CPD"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.reachoutcpd.com/about-us/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Twig World Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.reachoutcpd.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.reachoutcpd.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.reachoutcpd.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.reachoutcpd.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.reachoutcpd.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.reachoutcpd.com/Shibboleth.sso/Glow",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.reachoutcpd.com/Shibboleth.sso/shibtest",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.reachoutcpd.com/Shibboleth.sso/RMUnify",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.reachoutcpd.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Online access to ReachOutCPD"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.reachoutcpd.com/mdui-reachoutcpd-logo.png",
                    "height": "153",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "202"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ReachOut CPD"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIJALCh189m45NwMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\n\t\t\t\t\t\tBAMTE3d3dy5yZWFjaG91dGNwZC5jb20wHhcNMTUwNTA4MTYwMjE2WhcNMjUwNTA1\n\t\t\t\t\t\tMTYwMjE2WjAeMRwwGgYDVQQDExN3d3cucmVhY2hvdXRjcGQuY29tMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArk/tW7sQTr703EjMb/ToiW8W/nLHNQSU\n\t\t\t\t\t\tsy2eSI7tdsa6aX/0PJ7UARu+oyGRGc1COgK6mjD06vsKW628CoY4O+zZHX+rNsyp\n\t\t\t\t\t\tCYS2GiWWZl+g8J174WkqSSJb871wvc+koDxusFG6R3EhG6DA55RJpIq9rfMRMYiN\n\t\t\t\t\t\tcrQUMwa8U46XMjlN2o5y+2GrLfWlMKw/rMb5++dpYzR9r6F6C0Th5B0WxMlvmIfS\n\t\t\t\t\t\toZ9i/fzjtUzyGQTIqA00URIRvhCYX3XDcFeO/eFHkBNN67q4fOMLl7e+di2xtlT7\n\t\t\t\t\t\txMiWW0m8O+xlUwKVErm3RJkc25pSW9OG1RGd+/tavAc5+aIVjo77OQIDAQABo2ww\n\t\t\t\t\t\tajBJBgNVHREEQjBAghN3d3cucmVhY2hvdXRjcGQuY29thilodHRwczovL3d3dy5y\n\t\t\t\t\t\tZWFjaG91dGNwZC5jb20vc2hpYmJvbGV0aC1zcDAdBgNVHQ4EFgQUuYCQZejUVFjI\n\t\t\t\t\t\tzWNT5KgMlKihZPQwDQYJKoZIhvcNAQEFBQADggEBAGXMAaV7D7xBqNDEdHZT+wmN\n\t\t\t\t\t\tN5kx1L2eqcI09p3Fe+bD9E3k6hNTI3uCd7IOvmygzHhGYwegFrIx2sErGuzmhDDK\n\t\t\t\t\t\tMHX7jSf/HpVVTVtNSwBlQ+DbKqP9j1lWj7uaf3FVTE0MfuLz/5uaCybtQsAl/63/\n\t\t\t\t\t\tYayvxe8lc7XpPHA6yHEdeDz/9lhvXEF28RzNcexf2iROS028lHQGEi5uelZTyNyY\n\t\t\t\t\t\tmAvnSRd15cvz0L/XjDDwkE5VWWKwCDBeBJHCskUTW7ZMR+SqFuy7DsjFy+rf+P3M\n\t\t\t\t\t\tAO1OuZ4E2l0BT6E/ESj62z3SCnMnaDkE7z4n64cXe7oZanfB5Wf3D/vI1HIiCes="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.reachoutcpd.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.reachoutcpd.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.reachoutcpd.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.reachoutcpd.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.reachoutcpd.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.reachoutcpd.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.reachoutcpd.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.reachoutcpd.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.reachoutcpd.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.reachoutcpd.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://met.refeds.org/saml2/metadata/",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biancini"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:andrea.biancini@garr.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrea"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Malavolti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:marco.malavolti@garr.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marco"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Florio"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:licia.florio@geant.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Licia"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Harris"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nicole.harris@geant.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nicole"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Help"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem-help@garr.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IDEM"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://met.refeds.org/saml2/metadata/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2015-04-30T13:30:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Metadata Explorer Tool erogato da G\u00e9ant Association"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Metadata Explorer Tool provided by G\u00e9ant Association"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.geant.net"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.geant.net"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "G\u00e9ant Association"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "G\u00e9ant Association"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://met.refeds.org/saml2/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://met.refeds.org/static/info_en.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://met.refeds.org/static/info_it.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Metadata Explorer Tool"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Metadata Explorer Tool"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Metadata Explorer Tool is a fast way to find federations, entities and his relations through entity/federation metadata file information."
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Il Metadata Explorer Tool permette rapidamente di trovare le federazioni, le entit\u00e0 e le relazioni tra di esse nei metadati che le descrivono."
                  }
                ],
                "logo": [
                  {
                    "text": "https://met.refeds.org/static/logoMET_160x120.png",
                    "lang": "en",
                    "height": "120",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "160"
                  },
                  {
                    "text": "https://met.refeds.org/static/logoMET_160x120.png",
                    "lang": "it",
                    "height": "120",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "160"
                  },
                  {
                    "text": "https://met.refeds.org/static/logoMET_16x12.png",
                    "lang": "en",
                    "height": "12",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://met.refeds.org/static/logoMET_16x12.png",
                    "lang": "it",
                    "height": "12",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://met.refeds.org/static/privacy_en.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://met.refeds.org/static/privacy_it.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBTCCAe2gAwIBAgIJAJrz91xEwT1DMA0GCSqGSIb3DQEBCwUAMBkxFzAVBgNV\nBAMMDm1ldC5yZWZlZHMub3JnMB4XDTE1MDQyMDEwMDkzN1oXDTI1MDQxOTEwMDkz\nN1owGTEXMBUGA1UEAwwObWV0LnJlZmVkcy5vcmcwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQCxVA8KV2TUuTjmxoUZfq3tyJrMvP+pwbTpQFjpqN3Q3FbP\nRZKREdpp41GkTFhsHc7kGZ5RHa0NLjot8tl2XuSkd55LrOffsn/p3TSavAUXPUXo\n5CnJwGi6RecoW5+VAxTWcQCE9wgxEda4NNYKJ6PUH0GXA46tepNAKcbhjuCxupfh\n/fFO0XVdmM8h5J3GLZJEvzLF5s5LSUToE7yBd9M7XPDXxIl5DG0pZeZ3cDBmVEJm\nFJPxPgUJUxwXnc3A4qb/iCgPHXqq/M3lt2I/zM/QxMWRyhXWkvUm0K7cBxPhXD1I\nsRNx/Yiy66lvtNHfIFoAW+GTQAsGigsk3lgl0J/PAgMBAAGjUDBOMB0GA1UdDgQW\nBBS15ZRED2b8svkrJ/tFGSHUVhSzVTAfBgNVHSMEGDAWgBS15ZRED2b8svkrJ/tF\nGSHUVhSzVTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQCnVwczF6Hb\nbxLzHjXs4P4hLvxiYob+Rlt6lmNmLHez6QIMF/88Jn0PFmfMzRTRg9f3sI3u6G7J\nkwkfbQIj3ZJ3lk4VTQpZfoilkLhNEeo2ljyYgeUP4fbBrsC5az5VoEsUH8+QAtZ3\ncI8PbCmulGbtEgtJzs3jiRt7AjpBhiGot9HcblyF5R8V75iovFapU1sBLWTi+uZv\nw53UzzO6s6cSqo2rzA7QKuEUvsUnrB7NYy818riZ0ufFcZfWz6ApPLffVJa3M7tw\nOKtWkwuFNtGa6miYdAng9t0snIrLFqMYSooFliWMpFMiapQecEHhu8lwF9Xlrh5p\nBAK+sbIfUHvh"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBTCCAe2gAwIBAgIJAJrz91xEwT1DMA0GCSqGSIb3DQEBCwUAMBkxFzAVBgNV\nBAMMDm1ldC5yZWZlZHMub3JnMB4XDTE1MDQyMDEwMDkzN1oXDTI1MDQxOTEwMDkz\nN1owGTEXMBUGA1UEAwwObWV0LnJlZmVkcy5vcmcwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQCxVA8KV2TUuTjmxoUZfq3tyJrMvP+pwbTpQFjpqN3Q3FbP\nRZKREdpp41GkTFhsHc7kGZ5RHa0NLjot8tl2XuSkd55LrOffsn/p3TSavAUXPUXo\n5CnJwGi6RecoW5+VAxTWcQCE9wgxEda4NNYKJ6PUH0GXA46tepNAKcbhjuCxupfh\n/fFO0XVdmM8h5J3GLZJEvzLF5s5LSUToE7yBd9M7XPDXxIl5DG0pZeZ3cDBmVEJm\nFJPxPgUJUxwXnc3A4qb/iCgPHXqq/M3lt2I/zM/QxMWRyhXWkvUm0K7cBxPhXD1I\nsRNx/Yiy66lvtNHfIFoAW+GTQAsGigsk3lgl0J/PAgMBAAGjUDBOMB0GA1UdDgQW\nBBS15ZRED2b8svkrJ/tFGSHUVhSzVTAfBgNVHSMEGDAWgBS15ZRED2b8svkrJ/tF\nGSHUVhSzVTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQCnVwczF6Hb\nbxLzHjXs4P4hLvxiYob+Rlt6lmNmLHez6QIMF/88Jn0PFmfMzRTRg9f3sI3u6G7J\nkwkfbQIj3ZJ3lk4VTQpZfoilkLhNEeo2ljyYgeUP4fbBrsC5az5VoEsUH8+QAtZ3\ncI8PbCmulGbtEgtJzs3jiRt7AjpBhiGot9HcblyF5R8V75iovFapU1sBLWTi+uZv\nw53UzzO6s6cSqo2rzA7QKuEUvsUnrB7NYy818riZ0ufFcZfWz6ApPLffVJa3M7tw\nOKtWkwuFNtGa6miYdAng9t0snIrLFqMYSooFliWMpFMiapQecEHhu8lwF9Xlrh5p\nBAK+sbIfUHvh"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://met.refeds.org/saml2/acs/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Metadata Explorer Tool"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Metadata Explorer Tool"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Metadata Explorer Tool is a fast way to find federations, entities and his relations through entity/federation metadata file information."
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Il Metadata Explorer Tool permette rapidamente di trovare le federazioni, le entit\u00e0 e le relazioni tra di esse nei metadati che le descrivono."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.warwick.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Howes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:n.howes@warwick.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nick"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Howes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:n.howes@warwick.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nick"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.warwick.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-07-27T20:54:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.warwick.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.warwick.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAMUgGil9ReUGOng/Gws9DutReU1TMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBwxGjAYBgNVBAMTEWlkcC53YXJ3aWNrLmFjLnVrMB4XDTE0MDcwOTE0MDk0\n\t\t\t\t\t\tOFoXDTM0MDcwOTE0MDk0OFowHDEaMBgGA1UEAxMRaWRwLndhcndpY2suYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCebNiWX5f4B7Xgg1ukG04P\n\t\t\t\t\t\tGvuNRynjJnrGzFqrqpOhFSvljVhU8QBkkVj6+QNh4llB3wSSlNTBiPze9zd45/1l\n\t\t\t\t\t\trcPwzXQ5GsB2a//2Z8pS7B5s1qJKZH/zjLp+UIKCqXGjftYHHwPstAO8pMMSuk4M\n\t\t\t\t\t\tERYCWLKt892PmrgjOnvXS0VWY9ltqAvAAl/d9Mae0UXkIYKk3VJNfClAk8U3zOej\n\t\t\t\t\t\tNi25fAyEYwaGEfGcbBUHbxvMJlI1WaneOaoAPk20IjqrOfhK5OH9lRbR7vxR2/w5\n\t\t\t\t\t\tgya37LLhDRqADpp/dc8Qa35AzlOmgvzE3teQFwnpSHKL1BRIAotp4KTbu8xLDJEN\n\t\t\t\t\t\tAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEWlkcC53YXJ3aWNrLmFjLnVrhihodHRwczov\n\t\t\t\t\t\tL2lkcC53YXJ3aWNrLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQ8q27h\n\t\t\t\t\t\teoQoKE9yxN7Jt/YS7RIYOjANBgkqhkiG9w0BAQUFAAOCAQEAUCzlCcG5TVL1P+IR\n\t\t\t\t\t\t523VOgKUq8YRzwCqERqXNRD4x0WQy8EYCYCKbYWhl5FrJNpG992nlRS2fXfGe0el\n\t\t\t\t\t\ttd7Npy8vfBaroIgrOclREjYO+YBRC72ubIZKWGcU+Nq9C+RJZ2QjK+yMb76C1yUc\n\t\t\t\t\t\tTQEfw/lF/hSUofqgUSRketoCj80AOGrrG0wGV7oWuqW2MnvTIxnlosclSJgIpxW/\n\t\t\t\t\t\tRWShrJhBzCBHU5Nbz7+JEhFX3mSuBUMtSV1qsZbtwtdHVm977pOYrm5Nd35KBKNf\n\t\t\t\t\t\t+YK5ljnepO58isd09Xn1XGEqM7kySM4H55OhvBKzeIMSaKmNFJY3e8CJJmMl9u+j\n\t\t\t\t\t\tvOGPdg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "warwick.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.warwick.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.warwick.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.warwick.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.warwick.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.warwick.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.warwick.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "logo": [
                  {
                    "text": "https://idp.warwick.ac.uk/origin/static/images/idp-logo-90x26.png",
                    "height": "26",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "90"
                  },
                  {
                    "text": "https://idp.warwick.ac.uk/origin/static/images/idp-logo-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Warwick"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "warwick.ac.uk"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:52.381991,-1.562032"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:52.286432,-1.551475"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "137.205.0.0/16"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "warwick.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAMUgGil9ReUGOng/Gws9DutReU1TMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBwxGjAYBgNVBAMTEWlkcC53YXJ3aWNrLmFjLnVrMB4XDTE0MDcwOTE0MDk0\n\t\t\t\t\t\tOFoXDTM0MDcwOTE0MDk0OFowHDEaMBgGA1UEAxMRaWRwLndhcndpY2suYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCebNiWX5f4B7Xgg1ukG04P\n\t\t\t\t\t\tGvuNRynjJnrGzFqrqpOhFSvljVhU8QBkkVj6+QNh4llB3wSSlNTBiPze9zd45/1l\n\t\t\t\t\t\trcPwzXQ5GsB2a//2Z8pS7B5s1qJKZH/zjLp+UIKCqXGjftYHHwPstAO8pMMSuk4M\n\t\t\t\t\t\tERYCWLKt892PmrgjOnvXS0VWY9ltqAvAAl/d9Mae0UXkIYKk3VJNfClAk8U3zOej\n\t\t\t\t\t\tNi25fAyEYwaGEfGcbBUHbxvMJlI1WaneOaoAPk20IjqrOfhK5OH9lRbR7vxR2/w5\n\t\t\t\t\t\tgya37LLhDRqADpp/dc8Qa35AzlOmgvzE3teQFwnpSHKL1BRIAotp4KTbu8xLDJEN\n\t\t\t\t\t\tAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEWlkcC53YXJ3aWNrLmFjLnVrhihodHRwczov\n\t\t\t\t\t\tL2lkcC53YXJ3aWNrLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQ8q27h\n\t\t\t\t\t\teoQoKE9yxN7Jt/YS7RIYOjANBgkqhkiG9w0BAQUFAAOCAQEAUCzlCcG5TVL1P+IR\n\t\t\t\t\t\t523VOgKUq8YRzwCqERqXNRD4x0WQy8EYCYCKbYWhl5FrJNpG992nlRS2fXfGe0el\n\t\t\t\t\t\ttd7Npy8vfBaroIgrOclREjYO+YBRC72ubIZKWGcU+Nq9C+RJZ2QjK+yMb76C1yUc\n\t\t\t\t\t\tTQEfw/lF/hSUofqgUSRketoCj80AOGrrG0wGV7oWuqW2MnvTIxnlosclSJgIpxW/\n\t\t\t\t\t\tRWShrJhBzCBHU5Nbz7+JEhFX3mSuBUMtSV1qsZbtwtdHVm977pOYrm5Nd35KBKNf\n\t\t\t\t\t\t+YK5ljnepO58isd09Xn1XGEqM7kySM4H55OhvBKzeIMSaKmNFJY3e8CJJmMl9u+j\n\t\t\t\t\t\tvOGPdg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Warwick"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.warwick.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Warwick"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp-sicilia.izs.garr.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idpcloud-service@garr.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-sicilia.izs.garr.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2014-01-31T10:02:41Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAPEWcrJjf1McdVn5rw3nQ6Gim4w8MA0GCSqGSIb3DQEB\nBQUAMCIxIDAeBgNVBAMTF2lkcC1zaWNpbGlhLml6cy5nYXJyLml0MB4XDTE0MDIw\nNTE2MDMyM1oXDTM0MDIwNTE2MDMyM1owIjEgMB4GA1UEAxMXaWRwLXNpY2lsaWEu\naXpzLmdhcnIuaXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCR9Z1x\nJehS/JqknbxipZrecsFTPiFxJGZ5dAXv2zhWd8Qfz8QICRird41HMbm7KJlXYcrM\nP2t/mDZppK0RK1rQFk22Jl4ao/yTH9MDMZbQk6PVjv7xFwTvH8xUYa23rjAfQwxE\n7Q50pZ9SAkMP1kcMeVO7stnHxto3gs0aZOAq9FeeX+oYzcMkplhlz/eejVeeCUPM\nEMgt4cE43lvz1FHzyYa0njwgQpPGZCOqsKmTdCOaYMUK6iiKrY3YwAsdya1sWLW0\n4SWr9Ag5r6tZ+pGJ7Yz2cCumzdvOQbQDjqBrQC26MYib+uRqG4SrpukB/AsyVoTZ\nl/bw/Wedcd4QRG53AgMBAAGjdTBzMFIGA1UdEQRLMEmCF2lkcC1zaWNpbGlhLml6\ncy5nYXJyLml0hi5odHRwczovL2lkcC1zaWNpbGlhLml6cy5nYXJyLml0L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBTM1pPjW1tY7OE5cQFT6Dhr7DPhJjANBgkqhkiG\n9w0BAQUFAAOCAQEAPElPerHGkqU6Gla03PS5WccIUazEgyiG3bhQTl1iGBEeo0Lx\nZc9R7E5N+VX5UKIe2kkkAYXGdXBhgR8kLptTlbiS7ZdMm4g+iSnc4nrNw3BnXHog\nConqGhfg/9loGA83A69/axkSZIyaKBCIMq+lhBcuSJ0ug26WSDU4ujh3rfabFpyg\n7EOla/1MHSnxaxtglWwyk2EsCcqRKeaZvqeC7zDICxjP510OHp9SksmAMMK7fopr\npoPD+5Yg0WJ+wYjoy4BNVeCpElAPujBOSpd47amEWkGr13k6vtIy+9WLFEIlmJKD\nDXuwjmwjokkHQaTBMi+WlFlUWfdpPOQVT9f/Iw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "izssicilia.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-sicilia.izs.garr.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-sicilia.izs.garr.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-sicilia.izs.garr.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-sicilia.izs.garr.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-sicilia.izs.garr.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-sicilia.izs.garr.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-sicilia.izs.garr.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-sicilia.izs.garr.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "izssicilia.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idp-sicilia.izs.garr.it/idp/info.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idp-sicilia.izs.garr.it/idp/info.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IZS Sicilia"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IZS Sicilia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Istituto Zooprofilattico Sperimentale della Sicilia users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti dell'Istituto Zooprofilattico Sperimentale della Sicilia"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp-sicilia.izs.garr.it/idp/images/institutionLogo-32x32_en.png",
                    "lang": "en",
                    "height": "33",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "32"
                  },
                  {
                    "text": "https://idp-sicilia.izs.garr.it/idp/images/institutionLogo-160x120_en.png",
                    "lang": "en",
                    "height": "164",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "160"
                  },
                  {
                    "text": "https://idp-sicilia.izs.garr.it/idp/images/institutionLogo-32x32_it.png",
                    "lang": "it",
                    "height": "33",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "32"
                  },
                  {
                    "text": "https://idp-sicilia.izs.garr.it/idp/images/institutionLogo-160x120_it.png",
                    "lang": "it",
                    "height": "164",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "160"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://idp-sicilia.izs.garr.it/idp/privacy.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://idp-sicilia.izs.garr.it/idp/privacy.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAPEWcrJjf1McdVn5rw3nQ6Gim4w8MA0GCSqGSIb3DQEB\nBQUAMCIxIDAeBgNVBAMTF2lkcC1zaWNpbGlhLml6cy5nYXJyLml0MB4XDTE0MDIw\nNTE2MDMyM1oXDTM0MDIwNTE2MDMyM1owIjEgMB4GA1UEAxMXaWRwLXNpY2lsaWEu\naXpzLmdhcnIuaXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCR9Z1x\nJehS/JqknbxipZrecsFTPiFxJGZ5dAXv2zhWd8Qfz8QICRird41HMbm7KJlXYcrM\nP2t/mDZppK0RK1rQFk22Jl4ao/yTH9MDMZbQk6PVjv7xFwTvH8xUYa23rjAfQwxE\n7Q50pZ9SAkMP1kcMeVO7stnHxto3gs0aZOAq9FeeX+oYzcMkplhlz/eejVeeCUPM\nEMgt4cE43lvz1FHzyYa0njwgQpPGZCOqsKmTdCOaYMUK6iiKrY3YwAsdya1sWLW0\n4SWr9Ag5r6tZ+pGJ7Yz2cCumzdvOQbQDjqBrQC26MYib+uRqG4SrpukB/AsyVoTZ\nl/bw/Wedcd4QRG53AgMBAAGjdTBzMFIGA1UdEQRLMEmCF2lkcC1zaWNpbGlhLml6\ncy5nYXJyLml0hi5odHRwczovL2lkcC1zaWNpbGlhLml6cy5nYXJyLml0L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBTM1pPjW1tY7OE5cQFT6Dhr7DPhJjANBgkqhkiG\n9w0BAQUFAAOCAQEAPElPerHGkqU6Gla03PS5WccIUazEgyiG3bhQTl1iGBEeo0Lx\nZc9R7E5N+VX5UKIe2kkkAYXGdXBhgR8kLptTlbiS7ZdMm4g+iSnc4nrNw3BnXHog\nConqGhfg/9loGA83A69/axkSZIyaKBCIMq+lhBcuSJ0ug26WSDU4ujh3rfabFpyg\n7EOla/1MHSnxaxtglWwyk2EsCcqRKeaZvqeC7zDICxjP510OHp9SksmAMMK7fopr\npoPD+5Yg0WJ+wYjoy4BNVeCpElAPujBOSpd47amEWkGr13k6vtIy+9WLFEIlmJKD\nDXuwjmwjokkHQaTBMi+WlFlUWfdpPOQVT9f/Iw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IZS Sicilia"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IZS Sicilia"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.izssicilia.it/idem/idem-info-en"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.izssicilia.it"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IZS Sicilia"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IZS Sicilia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibidp.wsu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "its.iam@wsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IAM Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "its.iam@wsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IAM Team"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "its.iam@wsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IAM Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "security@wsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Security Team"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://shibidp.wsu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.wsu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.wsu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.wsu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.wsu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.wsu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wsu.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.wsu.edu/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Shibboleth Identity Provider for Washington State University"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://policies.wsu.edu/privacy-policy/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Washington State University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUfDyEVJT9ZZfmUITKqh/iiWittqowDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPc2hpYmlkcC53c3UuZWR1MB4XDTEyMDgwOTE5MzQzNFoX\nDTMyMDgwOTE5MzQzNFowGjEYMBYGA1UEAxMPc2hpYmlkcC53c3UuZWR1MIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAhPecq0Y/ZnVu5qSYglWqAAXuBBJD\nGqqvjQjCqMTvqIe0gwO9+LYuERFjBDeCR0EdR78W+z1CpeAX2uJK39o1EHvuFGKP\n2soMVmTyxX/RCPwPgNCBhLm8H9C/qSo9t0uy6OBuM8j8jLZEeogQMIFMhSQBb/sX\nxG6yf4HlBxUR4UwXt+1B2uPUyeuFb5d7cXiER0vypCVUOYTMoktJi2BhTPWwq0Uw\ngl8wIOdrGcYWA/TlM7kN7dbECSMQ7+vyjJcjmLl+S+uTP8XMBO++73cusWm9PcQQ\nh0YM4upH24fn1rgfDaz9hFSfh6YpoTd1jkZfuZ4LIAA+4qhmi2H4jirBAwIDAQAB\no2UwYzBCBgNVHREEOzA5gg9zaGliaWRwLndzdS5lZHWGJmh0dHBzOi8vc2hpYmlk\ncC53c3UuZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSH6+ewj1D+ZqZ0HqhD\nFjcDSZ9qnDANBgkqhkiG9w0BAQUFAAOCAQEACdd+0kvLvaK7066P0rk6cNvMZvhu\n/nwdn0nQwty/KDm7N95FWYCheijkcMD78DE+uzcUH/nwpTyULTJHVAhmwXJYJjoD\nLFKX3/QZr7f4L2ZYP80ic/6Ua45BFfHAOwp8ABO1XQlc34AQ4P226f3PSZQJmrb7\nEsSHjRpXbDNZcGr33nqSJ3nO1jM9pZziJfQK6pd20kRJL0SciAJlKcq3C/OHPDpW\nPN24xa2MgysJHH0EW8DeMX2qkmmXQcwOR+WITmYWm3gFNLSYGVuOQHVlMHr36Sgj\nyhBzX1IxZYmZwTPf9bX6fxdb1KoMOKPR09NUokT6l41eBJmpxiZQXLr3fw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Washington State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wsu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Washington State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibidp.uwo.ca/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NOC"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@uwo.ca"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibidp.uwo.ca/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.canarie.ca/templates/services/docs/CAF_join_en.pdf"
              }
            ],
            "registration_instant": "2015-04-08T00:00:00Z",
            "registration_authority": "http://www.canarie.ca",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUHu68aG+ypoAo35nJ065wP9seHlAwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOc2hpYmlkcC51d28uY2EwHhcNMTAxMjA5MTgzNzA2WhcN\nMzAxMjA5MTgzNzA2WjAZMRcwFQYDVQQDEw5zaGliaWRwLnV3by5jYTCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJjE2nZkhVprRxjFk/p9noiDzlJ+E9P5\n/5Xu4rvHl4MgS1HCKRaafPabQ/E1V/rxYfXWBnl8td8obnZgXz0letf6976F8+Vm\ntuJ/mkXaeqbH1tEd9yOHCvmsre42Hfjto1lsuRoa85fmRJIzaRoxmsNXfCEDj84N\nhNXvvdWafI56rEwM0dV/0+b0dfxGyUDGbfsMVgCwMUa4Ya8ojvQUksLE4Y36WDfv\nqthW620BefvPuGnS2NUO3Kl6Cg9qzqLIr1nzvZvNrfBAEeMCjE8Cgg5snNmmAY+H\nNiC+QtTZ3ZFgva6lHGn0JX/8mUd1NG6UqSsbVHMJ42JNcQm/QLe0xDcCAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOc2hpYmlkcC51d28uY2GGJWh0dHBzOi8vc2hpYmlkcC51\nd28uY2EvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFKKnJSjJugiONjm1ywm7/lDo\nuF1yMA0GCSqGSIb3DQEBBQUAA4IBAQCExnbVX0deoMmDW5tBYHy9tMmKCNCZiN3j\n+QH74ln4XCisGxy0gs8ZapVUP0X96bqhaGbym9ZJbFgHpwfXSElaMBEQbqhQokyq\nl7diPjKXjpU05Q5nhZZmNNY6a9dyPcyfKlvk5N8f95TbMf/yOY5eY7UHkP0O7YVa\nvp/ydJZ440q0UrF+OYk2/5e189gaN29GYDYA7EyDpytm9fZ8VYqI971jSOpL3kdn\n0fE7zOUe938KjLSx9YTJKthJHO+8pYGKHtS6d72LVaVSGtcQe6nLSPcP/k5Kvsmi\nM7uVja22Aj1EEVKZzF23JRNlkuqp1T6fi59hN+Y16Za36mfF1yTC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uwo.ca"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.uwo.ca:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.uwo.ca:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.uwo.ca/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.uwo.ca/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibidp.uwo.ca/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.uwo.ca/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.uwo.ca:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.uwo.ca:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uwo.ca"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uwo.ca"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Western Ontario"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Western Ontario"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUHu68aG+ypoAo35nJ065wP9seHlAwDQYJKoZIhvcNAQEF\nBQAwGTEXMBUGA1UEAxMOc2hpYmlkcC51d28uY2EwHhcNMTAxMjA5MTgzNzA2WhcN\nMzAxMjA5MTgzNzA2WjAZMRcwFQYDVQQDEw5zaGliaWRwLnV3by5jYTCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJjE2nZkhVprRxjFk/p9noiDzlJ+E9P5\n/5Xu4rvHl4MgS1HCKRaafPabQ/E1V/rxYfXWBnl8td8obnZgXz0letf6976F8+Vm\ntuJ/mkXaeqbH1tEd9yOHCvmsre42Hfjto1lsuRoa85fmRJIzaRoxmsNXfCEDj84N\nhNXvvdWafI56rEwM0dV/0+b0dfxGyUDGbfsMVgCwMUa4Ya8ojvQUksLE4Y36WDfv\nqthW620BefvPuGnS2NUO3Kl6Cg9qzqLIr1nzvZvNrfBAEeMCjE8Cgg5snNmmAY+H\nNiC+QtTZ3ZFgva6lHGn0JX/8mUd1NG6UqSsbVHMJ42JNcQm/QLe0xDcCAwEAAaNj\nMGEwQAYDVR0RBDkwN4IOc2hpYmlkcC51d28uY2GGJWh0dHBzOi8vc2hpYmlkcC51\nd28uY2EvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFKKnJSjJugiONjm1ywm7/lDo\nuF1yMA0GCSqGSIb3DQEBBQUAA4IBAQCExnbVX0deoMmDW5tBYHy9tMmKCNCZiN3j\n+QH74ln4XCisGxy0gs8ZapVUP0X96bqhaGbym9ZJbFgHpwfXSElaMBEQbqhQokyq\nl7diPjKXjpU05Q5nhZZmNNY6a9dyPcyfKlvk5N8f95TbMf/yOY5eY7UHkP0O7YVa\nvp/ydJZ440q0UrF+OYk2/5e189gaN29GYDYA7EyDpytm9fZ8VYqI971jSOpL3kdn\n0fE7zOUe938KjLSx9YTJKthJHO+8pYGKHtS6d72LVaVSGtcQe6nLSPcP/k5Kvsmi\nM7uVja22Aj1EEVKZzF23JRNlkuqp1T6fi59hN+Y16Za36mfF1yTC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:emailaddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailaddress"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Western Ontario"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uwo.ca"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Western Ontario"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ldf.data.kit.edu/sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hardt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hardt@kit.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marcus"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hayrapetyan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:arsen.hayrapetyan@kit.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Arsen"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ldf.data.kit.edu/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-02-03T14:28:35Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Karlsruher Institut f\u00fcr Technologie (KIT)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Karlsruhe Institute of Technology (KIT)"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.scc.kit.edu/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.scc.kit.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e148"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e148"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "LDF Data"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "LDF Data"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "LDF Data"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "LDF Data"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ldf.data.kit.edu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF6zCCBNOgAwIBAgIHGLIW1QWZrDANBgkqhkiG9w0BAQsFADCBvzELMAkGA1UE\nBhMCREUxGzAZBgNVBAgTEkJhZGVuLVd1ZXJ0dGVtYmVyZzESMBAGA1UEBxMJS2Fy\nbHNydWhlMSowKAYDVQQKEyFLYXJsc3J1aGUgSW5zdGl0dXRlIG9mIFRlY2hub2xv\nZ3kxJzAlBgNVBAsTHlN0ZWluYnVjaCBDZW50cmUgZm9yIENvbXB1dGluZzEPMA0G\nA1UEAxMGS0lULUNBMRkwFwYJKoZIhvcNAQkBFgpjYUBraXQuZWR1MB4XDTE0MTIx\nODA5MDcxN1oXDTE3MTIxNzA5MDcxN1owgYUxCzAJBgNVBAYTAkRFMRswGQYDVQQI\nExJCYWRlbi1XdWVydHRlbWJlcmcxEjAQBgNVBAcTCUthcmxzcnVoZTEqMCgGA1UE\nChMhS2FybHNydWhlIEluc3RpdHV0ZSBvZiBUZWNobm9sb2d5MRkwFwYDVQQDExBs\nZGYuZGF0YS5raXQuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\nw4Tlx9PXJ4wmH1qouc6BYZ7yj0k6Y63omGZt84db2VTEaBxZUb+1lZzzCxE3KS5t\npmpky6uVRuxbaxc3nDef+IGRKy0gzrQLilFYWXkPNOp4KZ6lMPg9L1ezLIrZTIqh\nnR7px/HK7ZRYnKG9B6ljmwQYrK/phYMX5eJCItsHO9TToBpyn4v6MXCA/7lzbEFz\nmKxH1qDrV0K7gTavryYWR6N5100mlQK5n6Mz3HWIXpcX8708JGrkGH6AQO01/4RZ\n+vdjoz/J0Zhwn34+jTC4+yBMNDhvIVLtxZyUtij+CCpu74pvGokqKBB8NP9M6WFA\nzjwiV2Eh/EKI+iXAzT7WLwIDAQABo4ICIjCCAh4wTwYDVR0gBEgwRjARBg8rBgEE\nAYGtIYIsAQEEAwMwEQYPKwYBBAGBrSGCLAIBBAMBMA8GDSsGAQQBga0hgiwBAQQw\nDQYLKwYBBAGBrSGCLB4wCQYDVR0TBAIwADALBgNVHQ8EBAMCBPAwEwYDVR0lBAww\nCgYIKwYBBQUHAwEwHQYDVR0OBBYEFHoFMKXIzPiHG76LnfVqmEJ7SJ1EMB8GA1Ud\nIwQYMBaAFB90ZfSaHXr2MenfYRtzKw1t0DNJMBsGA1UdEQQUMBKCEGxkZi5kYXRh\nLmtpdC5lZHUwdwYDVR0fBHAwbjA1oDOgMYYvaHR0cDovL2NkcDEucGNhLmRmbi5k\nZS9raXQtY2EvcHViL2NybC9jYWNybC5jcmwwNaAzoDGGL2h0dHA6Ly9jZHAyLnBj\nYS5kZm4uZGUva2l0LWNhL3B1Yi9jcmwvY2FjcmwuY3JsMIHHBggrBgEFBQcBAQSB\nujCBtzAzBggrBgEFBQcwAYYnaHR0cDovL29jc3AucGNhLmRmbi5kZS9PQ1NQLVNl\ncnZlci9PQ1NQMD8GCCsGAQUFBzAChjNodHRwOi8vY2RwMS5wY2EuZGZuLmRlL2tp\ndC1jYS9wdWIvY2FjZXJ0L2NhY2VydC5jcnQwPwYIKwYBBQUHMAKGM2h0dHA6Ly9j\nZHAyLnBjYS5kZm4uZGUva2l0LWNhL3B1Yi9jYWNlcnQvY2FjZXJ0LmNydDANBgkq\nhkiG9w0BAQsFAAOCAQEAjA1MbhMpdWsD9SUJ9uULTf+rbnsk6iBEFk+Soucq9szt\ni/KF4bq3qlK9nkuYbEZqrPR0dI0PuEgMIyLQgJrKiKp/NCkeg1FlW3tPgF4Kg4SQ\nIge0yNKN093nxdVvRoiHpitpOHaue100CBjYBBN9loCpmTTYhnrX2x1r5IU02VXj\nDFVFWaeUjYZI98zuQ4yODFpkp5CzGsP3DBuuRwka+xZPUkB5Tsl3feXNKTRrAGPg\nISJrWi9dzteo74ky9VlAWqA3QaTluyj/Ta51g1hi+v0iSL4pnbwHlbJa3Wow7MfY\nW2PUbu6ZE6ytGjWg3f7aijrOGqQaAnWJ/W7w7zywiw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ldf.data.kit.edu,O=Karlsruhe Institute of Technology,L=Karlsruhe,ST=Baden-Wuerttemberg,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ldf.data.kit.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ldf.data.kit.edu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "LDF Data"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "LDF Data"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "LDF Data"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "LDF Data"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-19.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-19.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;19"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;19"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-19.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-19.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJALJTVfD+H9mUMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0xOS5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTQ0MzQ4WhcNMjQx\nMDA0MTQ0MzQ4WjAhMR8wHQYDVQQDExZsYWRvazMtMTkubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzpB/1DSoezs6kRVeY7ulb12d\nqb67A7+tVjMF7r0wsyQAzZFKaSEAFSO6SI9xkDYAbZZoW01UCbTZxs5WHYGdy86U\nm9WzPmVPrehRFtzWV9UdgRM5TXHmxFWMRotIPIwaOl/XeCU0oNZgh4FOihJAyFPd\n+BwYVn2/BiAzvvstFU8NGMjqsNLZwt1agYnORoyRHxLMnZntKGi8azgRn/8nkiQf\nwnCBGpydsRLnbhsHKr3TYarG4/+jxK/EKP83uak2/acHGDSNKeYvvrnGoCfeHn3f\nPOrLBrFUx9sTTnIiwM+A4jm9LKYGRUq390WCmryHyjdzoRtY3NsE3dDqadHN7QID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMTkubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0xOS5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUL4u5ZAOrCjPwFL+5D/VNUKJvwNUwDQYJKoZIhvcNAQEFBQADggEB\nAG27SJJpfeTklLFyu/yz/GBz8sj3bo1XuohAEU2/XHYVdmFX0t+TH6JaVdv3QUYB\nv+1WZaG09pu2Zk+aSbshuiLNZero0qZglqBOyXSWcxtaRzrhyj/uNbN6IulqRdYh\n55sEGpEVPcsDF9MPERcYAEoPhLhujcdylCXt0SUv87KyWq/VtosjLJ0xdi05OwSL\nQzIZe74hia5hrlMTEIBHrYRbTeO2q3LZcpmQhlIbNBEGfzfWGUGMHMaxlXtmkatv\nNAiBKYQ60AYd/AS/yPrpk2llTUHfd6tdvC4SqKuiEYsy2pYvfN//PPFrdI9mr+Ir\n6ZrQ7PTbuSPLTA2boFcCHgk="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-19.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-19.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://aai-logon.ethz.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Nespor"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:vladislav.nespor@id.ethz.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Vladislav"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Nespor"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:vladislav.nespor@id.ethz.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Vladislav"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://aai-logon.ethz.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2016-01-14T15:01:23Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFojCCBIqgAwIBAgIUQV6//MsvpNeQ0A5F/aEZGwpWK9swDQYJKoZIhvcNAQEL\nBQAwTTELMAkGA1UEBhMCQk0xGTAXBgNVBAoTEFF1b1ZhZGlzIExpbWl0ZWQxIzAh\nBgNVBAMTGlF1b1ZhZGlzIEdsb2JhbCBTU0wgSUNBIEcyMB4XDTE1MDgxMTE1NTA0\nOVoXDTE3MDgxMTE1NTA0NVowYzELMAkGA1UEBhMCQ0gxEDAOBgNVBAgTB1p1ZXJp\nY2gxEDAOBgNVBAcTB1p1ZXJpY2gxFDASBgNVBAoTC0VUSCBadWVyaWNoMRowGAYD\nVQQDExFhYWktbG9nb24uZXRoei5jaDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBAM+Es3JJBpK6DNRjHcHcD1mPQOHKDnGfauHSbFuswybBJ5vaG/MNhKkT\nwEMU3I9seUkB6aMmFQ7Jb0h0L9chYzU4WQs87F5KHtDk7LUOPg23vLm0exArR1q9\nedcpju4wNXzT0Xs//5pBYfVtXBtqS1KDnR99hAn171PFOVgHyrAhZBiuthqnzKDx\nLXb8ZOcotrJf6w9KBryzE5N6iqJvsSblSobqNplFOJm19brnzaDvXs4XTdh590Gi\nOpGVnLIyzPnqc29vyFzXzQy+PnJSbA4rcH0WdZjb1QErl9SxRimp9Eu6FURuh2fz\nokqCXzkGYGapqnhbtacMpYU/55TXtZECAwEAAaOCAmIwggJeMHMGCCsGAQUFBwEB\nBGcwZTAqBggrBgEFBQcwAYYeaHR0cDovL29jc3AucXVvdmFkaXNnbG9iYWwuY29t\nMDcGCCsGAQUFBzAChitodHRwOi8vdHJ1c3QucXVvdmFkaXNnbG9iYWwuY29tL3F2\nc3NsZzIuY3J0MIHoBgNVHREEgeAwgd2CEWFhaS1sb2dvbi5ldGh6LmNogg92Y2lw\naGVyLmV0aHouY2iCD3ZjYWVzYXIuZXRoei5jaIIPdmN1cnRlci5ldGh6LmNogg92\nY29wcGVyLmV0aHouY2iCD3ZjZW5zb3IuZXRoei5jaIISbGRhcHMtaW5mby5ldGh6\nLmNogg92YmFnZ2VyLmV0aHouY2iCD2xpbnRlc3QuZXRoei5jaIIPdmtpa3V5dS5l\ndGh6LmNogg92a2FyYXRlLmV0aHouY2iBG3ZsYWRpc2xhdi5uZXNwb3JAaWQuZXRo\nei5jaDBRBgNVHSAESjBIMEYGDCsGAQQBvlgAAmQBATA2MDQGCCsGAQUFBwIBFiho\ndHRwOi8vd3d3LnF1b3ZhZGlzZ2xvYmFsLmNvbS9yZXBvc2l0b3J5MA4GA1UdDwEB\n/wQEAwIFoDAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwHwYDVR0jBBgw\nFoAUkRlirVsXpzD78N45JbG9jLm4UScwOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDov\nL2NybC5xdW92YWRpc2dsb2JhbC5jb20vcXZzc2xnMi5jcmwwHQYDVR0OBBYEFCu2\nn3cvVuUwhk5Trij3/AjY83eRMA0GCSqGSIb3DQEBCwUAA4IBAQBsieDeYEP421Ju\nvgGSCfFVz3COdaeApYbDVTrNgNXVz6SMJUtei4Am6Usn+LdS4T+JU2+XH9kwbMhs\ntB4HvrZ1B4knmP6HG3d3l5IFLKHOTsjaFi8iP1g5FScP4ZDU22gOmheBiUBxFWeg\nXlYNL0Oo0thjlEABy9xRhPKOOCPobph8yXNms3R26fNcWOr1vqrelgRliCCp+C8r\nXgNUpzJ27dWP55rM0g1xit7Yf70mLRYwhaIHqGoa1dLAzFgAUp09tRAh9e994HcE\nHZjdI2qJ9f74k5S+I+11iWbm0WPiClz0nKbzb2120cJp3DJuUwLFZUO75xFd1624\nQpo1uN+B"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ethz.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-logon.ethz.ch/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-logon.ethz.ch/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aai-logon.ethz.ch/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai-logon.ethz.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai-logon.ethz.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aai-logon.ethz.ch/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-logon.ethz.ch/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-logon.ethz.ch/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ethz.ch"
              },
              {
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Eidgen\u00f6ssische Technische Hochschule Z\u00fcrich"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Swiss Federal Institute of Technology Zurich"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ecole Polytechnique F\u00e9d\u00e9rale de Zurich"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ETHZ - ETH Z\u00fcrich"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ETHZ - ETH Zurich"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ETHZ - ETH Zurich"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "ethz.ch"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "cscs.ch"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.37646,8.54792"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.41039,8.50902"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.566087,7.602298"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:46.022244,8.916146"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.0.48/28"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.96.0/19"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "82.130.64.0/18"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "129.132.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "129.132.40.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.134.200.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.87.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.88.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.91.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.92.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.88.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.96.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.104.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.108.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.110.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:620:8::/48"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:620:1a0::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "error_url": "http://www.id.ethz.ch/servicedesk",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFojCCBIqgAwIBAgIUQV6//MsvpNeQ0A5F/aEZGwpWK9swDQYJKoZIhvcNAQEL\nBQAwTTELMAkGA1UEBhMCQk0xGTAXBgNVBAoTEFF1b1ZhZGlzIExpbWl0ZWQxIzAh\nBgNVBAMTGlF1b1ZhZGlzIEdsb2JhbCBTU0wgSUNBIEcyMB4XDTE1MDgxMTE1NTA0\nOVoXDTE3MDgxMTE1NTA0NVowYzELMAkGA1UEBhMCQ0gxEDAOBgNVBAgTB1p1ZXJp\nY2gxEDAOBgNVBAcTB1p1ZXJpY2gxFDASBgNVBAoTC0VUSCBadWVyaWNoMRowGAYD\nVQQDExFhYWktbG9nb24uZXRoei5jaDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBAM+Es3JJBpK6DNRjHcHcD1mPQOHKDnGfauHSbFuswybBJ5vaG/MNhKkT\nwEMU3I9seUkB6aMmFQ7Jb0h0L9chYzU4WQs87F5KHtDk7LUOPg23vLm0exArR1q9\nedcpju4wNXzT0Xs//5pBYfVtXBtqS1KDnR99hAn171PFOVgHyrAhZBiuthqnzKDx\nLXb8ZOcotrJf6w9KBryzE5N6iqJvsSblSobqNplFOJm19brnzaDvXs4XTdh590Gi\nOpGVnLIyzPnqc29vyFzXzQy+PnJSbA4rcH0WdZjb1QErl9SxRimp9Eu6FURuh2fz\nokqCXzkGYGapqnhbtacMpYU/55TXtZECAwEAAaOCAmIwggJeMHMGCCsGAQUFBwEB\nBGcwZTAqBggrBgEFBQcwAYYeaHR0cDovL29jc3AucXVvdmFkaXNnbG9iYWwuY29t\nMDcGCCsGAQUFBzAChitodHRwOi8vdHJ1c3QucXVvdmFkaXNnbG9iYWwuY29tL3F2\nc3NsZzIuY3J0MIHoBgNVHREEgeAwgd2CEWFhaS1sb2dvbi5ldGh6LmNogg92Y2lw\naGVyLmV0aHouY2iCD3ZjYWVzYXIuZXRoei5jaIIPdmN1cnRlci5ldGh6LmNogg92\nY29wcGVyLmV0aHouY2iCD3ZjZW5zb3IuZXRoei5jaIISbGRhcHMtaW5mby5ldGh6\nLmNogg92YmFnZ2VyLmV0aHouY2iCD2xpbnRlc3QuZXRoei5jaIIPdmtpa3V5dS5l\ndGh6LmNogg92a2FyYXRlLmV0aHouY2iBG3ZsYWRpc2xhdi5uZXNwb3JAaWQuZXRo\nei5jaDBRBgNVHSAESjBIMEYGDCsGAQQBvlgAAmQBATA2MDQGCCsGAQUFBwIBFiho\ndHRwOi8vd3d3LnF1b3ZhZGlzZ2xvYmFsLmNvbS9yZXBvc2l0b3J5MA4GA1UdDwEB\n/wQEAwIFoDAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwHwYDVR0jBBgw\nFoAUkRlirVsXpzD78N45JbG9jLm4UScwOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDov\nL2NybC5xdW92YWRpc2dsb2JhbC5jb20vcXZzc2xnMi5jcmwwHQYDVR0OBBYEFCu2\nn3cvVuUwhk5Trij3/AjY83eRMA0GCSqGSIb3DQEBCwUAA4IBAQBsieDeYEP421Ju\nvgGSCfFVz3COdaeApYbDVTrNgNXVz6SMJUtei4Am6Usn+LdS4T+JU2+XH9kwbMhs\ntB4HvrZ1B4knmP6HG3d3l5IFLKHOTsjaFi8iP1g5FScP4ZDU22gOmheBiUBxFWeg\nXlYNL0Oo0thjlEABy9xRhPKOOCPobph8yXNms3R26fNcWOr1vqrelgRliCCp+C8r\nXgNUpzJ27dWP55rM0g1xit7Yf70mLRYwhaIHqGoa1dLAzFgAUp09tRAh9e994HcE\nHZjdI2qJ9f74k5S+I+11iWbm0WPiClz0nKbzb2120cJp3DJuUwLFZUO75xFd1624\nQpo1uN+B"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ETHZ - ETH Z\u00fcrich"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ETHZ - ETH Zurich"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ETHZ - ETH Zurich"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ethz.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ethz.ch/"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ethz.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ethz.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso.loucoll.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bennett"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mick.bennett@loucoll.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mick"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bennett"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mick.bennett@loucoll.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mick"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.loucoll.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-07-22T11:31:30Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDaDCCAlACCQCHK+i1QORh+TANBgkqhkiG9w0BAQUFADB2MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEVMBMGA1UECBMMTG91Z2hib3JvdWdoMRUwEwYDVQQHEwxMb3VnaGJvcm91Z2gx\n\t\t\t\t\t\tHTAbBgNVBAoTFExvdWdoYm9yb3VnaCBDb2xsZWdlMRowGAYDVQQDExFzc28ubG91\n\t\t\t\t\t\tY29sbC5hYy51azAeFw0xNDA0MTUxMzU2MjZaFw0zNDA0MTAxMzU2MjZaMHYxCzAJ\n\t\t\t\t\t\tBgNVBAYTAkdCMRUwEwYDVQQIEwxMb3VnaGJvcm91Z2gxFTATBgNVBAcTDExvdWdo\n\t\t\t\t\t\tYm9yb3VnaDEdMBsGA1UEChMUTG91Z2hib3JvdWdoIENvbGxlZ2UxGjAYBgNVBAMT\n\t\t\t\t\t\tEXNzby5sb3Vjb2xsLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\n\t\t\t\t\t\tAQEAwQY7dDYZ1ca0Er7mJbTr/HINCIP66swXOlslbAoA7J7PNz9wnVUdasYtGzDL\n\t\t\t\t\t\tpf71DvYJ7A7gQN41bNJif1AwOfr9YMg4Nnp+F3WhPsZuvMV2bu6I+eNv2nJV2gVE\n\t\t\t\t\t\tNHcV4YrH1hYNX4lMUA3AgJUyXge5vyDnLloNbVdbBiap1gR/OHShe5c5rD1n6evm\n\t\t\t\t\t\t8F0anTKcpwp0PXHx8sZ1VKVzs51NamfDlNscDY6k+XEsQ62ypJaOCYNo1vtcA7Kw\n\t\t\t\t\t\tcIvLgQQ0zfi7nVkVJRoS58vR4ocTvQMItafdvp7GUgMAGolMcgWWILy5mp1qW9ZL\n\t\t\t\t\t\tQxBjsPnxVsKwRVzbv7LsiiVIfQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQC7Wd4k\n\t\t\t\t\t\tYLrM/UczkJ0T3jDB+dpFJtNu7BxmN7izPuIBk8ob+cw8w8mDcbjz0WiB3RhDtrMz\n\t\t\t\t\t\t5xJa57WZQg5ySFdObFyR1etzDBGFKqauCeFr1P+5n5emZUWyDM2bur9Bu2yQAsYI\n\t\t\t\t\t\toXv1PaY+Yr5MnYBTDHOLFPGmEigyX5GotJVFiwxXD3rcf8xD0WCMVZH1ovoH6k6p\n\t\t\t\t\t\tsquru7H3FR8QUPvycQl5i03k6V6R3dEVoZSEa9oZF9YvhcztQc/p/FYiSfGOcEms\n\t\t\t\t\t\tWfn32Jf8HxqrKO+YSsxnnTrquO7HI1d2vaN7N07YiycbQGv7YhPb/1xbVyIH6iCH\n\t\t\t\t\t\tyUtE78S0KocB9mjJ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "loucoll.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.loucoll.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.loucoll.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso.loucoll.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.loucoll.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sso.loucoll.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.loucoll.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.loucoll.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.loucoll.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "loucoll.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDaDCCAlACCQCHK+i1QORh+TANBgkqhkiG9w0BAQUFADB2MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEVMBMGA1UECBMMTG91Z2hib3JvdWdoMRUwEwYDVQQHEwxMb3VnaGJvcm91Z2gx\n\t\t\t\t\t\tHTAbBgNVBAoTFExvdWdoYm9yb3VnaCBDb2xsZWdlMRowGAYDVQQDExFzc28ubG91\n\t\t\t\t\t\tY29sbC5hYy51azAeFw0xNDA0MTUxMzU2MjZaFw0zNDA0MTAxMzU2MjZaMHYxCzAJ\n\t\t\t\t\t\tBgNVBAYTAkdCMRUwEwYDVQQIEwxMb3VnaGJvcm91Z2gxFTATBgNVBAcTDExvdWdo\n\t\t\t\t\t\tYm9yb3VnaDEdMBsGA1UEChMUTG91Z2hib3JvdWdoIENvbGxlZ2UxGjAYBgNVBAMT\n\t\t\t\t\t\tEXNzby5sb3Vjb2xsLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\n\t\t\t\t\t\tAQEAwQY7dDYZ1ca0Er7mJbTr/HINCIP66swXOlslbAoA7J7PNz9wnVUdasYtGzDL\n\t\t\t\t\t\tpf71DvYJ7A7gQN41bNJif1AwOfr9YMg4Nnp+F3WhPsZuvMV2bu6I+eNv2nJV2gVE\n\t\t\t\t\t\tNHcV4YrH1hYNX4lMUA3AgJUyXge5vyDnLloNbVdbBiap1gR/OHShe5c5rD1n6evm\n\t\t\t\t\t\t8F0anTKcpwp0PXHx8sZ1VKVzs51NamfDlNscDY6k+XEsQ62ypJaOCYNo1vtcA7Kw\n\t\t\t\t\t\tcIvLgQQ0zfi7nVkVJRoS58vR4ocTvQMItafdvp7GUgMAGolMcgWWILy5mp1qW9ZL\n\t\t\t\t\t\tQxBjsPnxVsKwRVzbv7LsiiVIfQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQC7Wd4k\n\t\t\t\t\t\tYLrM/UczkJ0T3jDB+dpFJtNu7BxmN7izPuIBk8ob+cw8w8mDcbjz0WiB3RhDtrMz\n\t\t\t\t\t\t5xJa57WZQg5ySFdObFyR1etzDBGFKqauCeFr1P+5n5emZUWyDM2bur9Bu2yQAsYI\n\t\t\t\t\t\toXv1PaY+Yr5MnYBTDHOLFPGmEigyX5GotJVFiwxXD3rcf8xD0WCMVZH1ovoH6k6p\n\t\t\t\t\t\tsquru7H3FR8QUPvycQl5i03k6V6R3dEVoZSEa9oZF9YvhcztQc/p/FYiSfGOcEms\n\t\t\t\t\t\tWfn32Jf8HxqrKO+YSsxnnTrquO7HI1d2vaN7N07YiycbQGv7YhPb/1xbVyIH6iCH\n\t\t\t\t\t\tyUtE78S0KocB9mjJ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Loughborough College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.loucoll.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Loughborough College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://jira.its.umu.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://jira.its.umu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jira.its.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://jira.its.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jira.its.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://jira.its.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jira.its.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://jira.its.umu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://jira.its.umu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://jira.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Jira, ITS, IT-st\u00f6d och systemutveckling, Ume\u00e5 universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Jira, ITS, ICT Services and System Development, Ume\u00e5 University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Jira, ITS, Ume\u00e5 universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Jira, ITS, Ume\u00e5 University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "jira-confluence.its.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFTCCAf2gAwIBAgIJANANTmUUPjEwMA0GCSqGSIb3DQEBBQUAMCUxIzAhBgNV\nBAMTGmppcmEtY29uZmx1ZW5jZS5pdHMudW11LnNlMB4XDTEzMDgxNTA1NTcxNloX\nDTIzMDgxMzA1NTcxNlowJTEjMCEGA1UEAxMaamlyYS1jb25mbHVlbmNlLml0cy51\nbXUuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDtbJysWzyFP5Br\nIO8hMNjwARMQcNKErQBjlOm+ZZx/dFKLMPwxdpOlwvwFDcHnn+AohVM5dUygkFwk\nvGciClOR6QCnnubp93rvjZHVTGRJ5ZlzraVCOCl5lUkKSNIzCqDGfCbvyRvHcg1t\nbGBVJJbwWbXaqb3ZT/p2OI7+XP9uTzazIkDNbA9JL6xjRBnE2AljfCnmKTrS81Su\n/x7lmG+4Ji/H37jcJAdbtda05t2ARURwFKIXFIYr8CJklCTAxnh+T5qaV4n8apq/\nAceIfYiTc8FYlK9ptMkEFy2VkyQm/9Q+RU5ZDHLqPzqWnwDlx4kjnyWRBaB63zOY\nRe+R2A2nAgMBAAGjSDBGMCUGA1UdEQQeMByCGmppcmEtY29uZmx1ZW5jZS5pdHMu\ndW11LnNlMB0GA1UdDgQWBBTQvicuhivjhvST66h9a8LuowqZMDANBgkqhkiG9w0B\nAQUFAAOCAQEAMwQCeECnIAKZTd4mwWumokjmTEHaPR7njWVHsIdJZ36pKv9eIYZ+\nVAddlrhUH7LoQF0RgxkN4zoAlyDYlmcdVtmA58WAPdUFxziMznSGsV4MKrWZosIa\niYMLbcnsX7O3TJydO9nZZf8X7MWOMPHLEHB8+cInXHnAZqT+kZOiACJ5MQr4oSk4\nABpmWvKs9qsEa0DqR7wnaV4f3fS3xwbwTUb25v4ATi9vi5wkIUJwatVMNvJV4g/B\ndb1zTPxnsz/JyD/9EGp3qd1utQPgn1XZv+wDtIJwQ+8Kx31za5Cxnc7bxP2yhitT\nkcpkPw96Zj9HfRw2XGwo0pM+nRwYuw9WpA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=jira-confluence.its.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://jira.its.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://jira.its.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jira.its.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://jira.its.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://jira.its.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://jira.its.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://jira.its.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://jira.its.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://jira.its.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://auth.univ-paris-diderot.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@univ-paris-diderot.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://auth.univ-paris-diderot.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-06-22T15:05:05Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.univ-paris-diderot.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.univ-paris-diderot.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://auth.univ-paris-diderot.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-paris-diderot.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-paris-diderot.fr/"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Paris 7 - Denis Diderot"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Paris 7 - Denis Diderot"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIJAN6STuFrAhxnMA0GCSqGSIb3DQEBBQUAMCUxIzAhBgNV\nBAMTGmF1dGgudW5pdi1wYXJpcy1kaWRlcm90LmZyMB4XDTE0MDMwNDEzMDA1NFoX\nDTE3MDMwMzEzMDA1NFowJTEjMCEGA1UEAxMaYXV0aC51bml2LXBhcmlzLWRpZGVy\nb3QuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCpIa57mIoE7c60\nvKjcad8J0NnF2PS6JunZVvCQxdoFn7M7bNHLXnzbR3eRy/YOvs5Lap/PAZYeefUB\nXN7jsge+V1iqrz464yZGbNYHrweqp8EZU2L8GLNhHI6gOHHDGVR9NbsYFtrfrYnP\nunzON0yI99fg+YKRKIjbzPPsAcsaC6EtztqCzdui/iXpG2jNlvWWWx2TSQR4Dxn/\ncKHABFOwMmoqL/yJ0nvk2zEmL0etBSUdoiGeAOy4YxlrtRWKP8A4xrOwYwCt/v5k\nKWeLb5FHUvLMTRszxd56422oQnAS//0Xjr6k3rIGy6x4QaDj2pnGfBVF7Bj8KzeV\n7LAqpDoZAgMBAAGjezB5MFgGA1UdEQRRME+CGmF1dGgudW5pdi1wYXJpcy1kaWRl\ncm90LmZyhjFodHRwczovL2F1dGgudW5pdi1wYXJpcy1kaWRlcm90LmZyL2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBQ77uGaL//q8VYtszQ2KFmuivP1fzANBgkqhkiG\n9w0BAQUFAAOCAQEAdmP3c/NNbbabPnpFeykRfkHIOLkVNsqwxR0a2Jr3LNSm9SE/\nUta0MubpVTrImYQ9Fj8d3/MbSJtFR83dQ7Ib3/JZ04RqHz1LThOga8Qjw7s/O4Do\nj0NW1Rv/3CDCeDM5nOJ+4QlCLu0NqoAKDURooIJf0VTr5LnOAKMeQMAejXrtFjZT\n2IjXihUHeROCpIja7zzo84eZbbZvmOmrIJBbtDIEVjqqq7v9cYAbsrFxRw7WZo8J\nAeQBiqc1r72+AtBF18BJnpvVviUUxNU+MWLbNl+SaWhuUOqKqpFYcmF2jUHrM+N4\nVMThjYGNfbI8izARv+4LCGkfOSrlpq/2KqJ+FQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Paris 7 - Denis Diderot"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-paris-diderot.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Paris 7 - Denis Diderot"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.figshare.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gavrila"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:danielduduta@figshare.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Daniel"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gavrila"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:danielduduta@figshare.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Daniel"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.figshare.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-03-26T09:27:39Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "figshare"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://figshare.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Figshare LLP"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.figshare.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.figshare.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.figshare.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.figshare.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.figshare.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Cloud based repository for citable and discoverable research outputs"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "figshare"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://login.figshare.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://login.figshare.com/Shibboleth.sso/DS-Tuakiri",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://login.figshare.com/Shibboleth.sso/DS-Tuakiri",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://login.figshare.com/Shibboleth.sso/DS-AAF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://login.figshare.com/Shibboleth.sso/DS-AAF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://login.figshare.com/Shibboleth.sso/DS-UKF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://login.figshare.com/Shibboleth.sso/DS-UKF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAK4oUXPZlUI6MA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\n\t\t\t\t\t\tBAMTEmxvZ2luLmZpZ3NoYXJlLmNvbTAeFw0xNTAyMjMxNzAxNTRaFw0yNTAyMjAx\n\t\t\t\t\t\tNzAxNTRaMB0xGzAZBgNVBAMTEmxvZ2luLmZpZ3NoYXJlLmNvbTCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBAPfl7JY916aYR+LDmqHdiO8qzoKe03BpfNV7\n\t\t\t\t\t\tvhzvnoXJndevJd83KawCi+1YM7ZaWRBMRAmrhyf1X1S4p4hJgh6bfvErlrti/oi+\n\t\t\t\t\t\tOiPS4xGQ1ZPctEKHrtaPgpk7377WY18b1UhQ5oRUeEE92SjbVbQCks3EN/FIb6ip\n\t\t\t\t\t\t3Nc2yQ+qYQlp3qRtXB2Pd98YgrpapXe3CKJWg0KYJ7azVfwtdYAeweF/Y1D2QoLL\n\t\t\t\t\t\t+5POdrTLqXSzkUGoYWlnKM7mnQQd6k2Pmh4cckMohOKT6hiV4aHfGQAjvwVeUJ7S\n\t\t\t\t\t\tVWPaEhLFeACrvJw4QJ2t7RMu4hOItOvvN/WHKFKfaaTfmkAhU0cCAwEAAaNAMD4w\n\t\t\t\t\t\tHQYDVR0RBBYwFIISbG9naW4uZmlnc2hhcmUuY29tMB0GA1UdDgQWBBS8OQF6shyu\n\t\t\t\t\t\tjMxScHP8Lytou/hpSjANBgkqhkiG9w0BAQUFAAOCAQEAiv3VTRQZ5+XlhL1k0mNS\n\t\t\t\t\t\tvwAJ04QTSrUZPx5BOIinr7Y8NzAu0H6WFIfN8Bx0bqlx+w0PUC7LCUFpq8eJs3d4\n\t\t\t\t\t\tAqosDHZoBIXaDML5o42xY03jxM+Z1LuEVMVljtkMw7xfkx8FUr/3nPdZy2Iud4e1\n\t\t\t\t\t\tYFmO+48vh9OdR0VYZD1Q+lFyrVui6vd2U9DRvVz6MuYxoHF/6+vcCOHfSDNcoz8U\n\t\t\t\t\t\tBep+TBej/kiQJjJ/tAkSaHpNHtuVI0zrziVVTHTVnC4YEcFmt1kfWwf7cpDeCrJ3\n\t\t\t\t\t\tmwc0DpOT1TgWrS49lmpDkxkz5ofJhh6T6Wd1DAqpn+fuQKwvcPbLCIChPVNRh22s\n\t\t\t\t\t\tLQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.figshare.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.figshare.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.figshare.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://login.figshare.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.figshare.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.figshare.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://tcs-escience-portal.terena.org/simplesamlphp/module.php/saml/sp/metadata.php/default-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "LIS Unix"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "na@example.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UvT"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://tcs-escience-portal.terena.org/simplesamlphp/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://tcs-escience-portal.terena.org/simplesamlphp/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://tcs-escience-portal.terena.org/simplesamlphp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://tcs-escience-portal.terena.org/simplesamlphp/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://tcs-escience-portal.terena.org/simplesamlphp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://tcs-escience-portal.terena.org/simplesamlphp/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:profiles:holder-of-key:SSO:browser",
              "location": "https://tcs-escience-portal.terena.org/simplesamlphp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.lyit.ie/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Byron"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:seamus.byron@lyit.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Seamus"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.lyit.ie/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2010-11-09T00:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.lyit.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.lyit.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.lyit.ie/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lyit.ie"
              },
              {
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/lyit.png",
                    "height": "96",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "159"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Letterkenny Institute of Technology"
                  },
                  {
                    "lang": "ga",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institi\u00faid Teicneola\u00edochta Leitir Ceanainn"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:54.95229943501583,-7.720813751220703"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:54.95186314818439,-7.721607685089111"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAIygXE7mgeFS1ogZQvsHmJd9TtAHMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2lkcC5seWl0LmllMB4XDTExMDYzMDE0MTg1N1oXDTMx\nMDYzMDE0MTg1N1owFjEUMBIGA1UEAxMLaWRwLmx5aXQuaWUwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCG8w8qqMb2AU+Rv/kYTrStDzTqqhUSc0sHK+bj\nS+R7CujOkxq/PRVxgI7eqMiui5meN6DpJHVHLUiBB08n8+c/Nt7Iaz58pzxZRBY8\n49W1oAlm6NMGrMN540et4AFbiiEUG8oLcokxZrxM9Y30nrS0e7j3ZABebcIAMkOc\nR/i52pCsE++OJ7cZuTI+NbI5uwWNDyum5CJMcgwrJyOrHbXYQZKgbWDfmFGBIegT\neBb0Mj/6hN/FSuMD8JoZaW/XlqP7uIC1sZk6g2VCEH40fzCFGHEa+1PJN1KuR1f5\n/VmzMfKscoYFnPMEcXGVS7uOULBTyZhibspDnczEeo0dDcp9AgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2lkcC5seWl0LmllhiJodHRwczovL2lkcC5seWl0LmllL2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBSlQM4axvPAB7cdNaJnC4Xy1Kq3qzANBgkqhkiG\n9w0BAQUFAAOCAQEAXHq2sHemC0iqJlcmPnxvHAUdGqCsqj+F0zKbvRk3Xf/JG8AH\nCAsZTvKSOZu0aiwlietUW3J6eCJ91IkVTVhrAX71jidAw7+C3d4zi31e+qNqY5Ci\nyb1AkaAt6mi++0BYUj01vzL6+MIuR4svv3R9cpyrg4wkuljt2MDsNpusXJlEpQft\nKuOUA77foIOtvbHY0cYNBcVj9gbQl0+OP78ZlBwvqGnnW1rlLPbtmVCZxz8PeJ2w\nrArDeKt+kQanlUaaYnFd6NVkmDcZH7KtD+/PxbAGs1WS24APYAzSEyc271mWoLBM\negBqflp2dlNsm6/6kKlbVEgTaD/+ZGSPjqLpgA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Letterkenny Institute of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://lyit.ie"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Letterkenny Institute of Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://xenosmilus2.umdc.umu.se:8086/re_hei/sp.xml",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://xenosmilus2.umdc.umu.se:8086/re_hei/sp.xml",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://xenosmilus2.umdc.umu.se:8086/disco",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICIzCCAYwCCQDFqR2p3amCSjANBgkqhkiG9w0BAQUFADBWMQswCQYDVQQGEwJT\nRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UECgwDVW1VMQwwCgYDVQQLDANJVFMxHDAa\nBgNVBAMME2xpbmdvbi5sYWRvay51bXUuc2UwHhcNMTMwNjE0MTY1MjAyWhcNMTQw\nNjE0MTY1MjAyWjBWMQswCQYDVQQGEwJTRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UE\nCgwDVW1VMQwwCgYDVQQLDANJVFMxHDAaBgNVBAMME2xpbmdvbi5sYWRvay51bXUu\nc2UwgZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGBAM8nCb97J2QNi/U+4EnR2vL/\nvGtUM44dyOrdQ4xdD/feHyu0kWoNal/8CXJTYtDVrbKMg90fakPfw6Lw5KxQTzGl\nR6qNRyuuMq7KIgRzlbZEWiAh1YKQMOn+C3qIM0HqkfjD/rnCokIpFhGFi+7886AD\nVNB5CnUQXrSTAkUJzVS7AgMBAAEwDQYJKoZIhvcNAQEFBQADgYEABfQAzyDkwIQZ\nHu3tPi7QvJbdTDH8F3q8iSQwOT7MvxmHmCO/DZFwYu5jjYg/FtBfpbh8mQTziCy8\nFyVMuMKNSZn2rEIJF1ghgQqtHwn08zsPPhD9XW0LXeP6Exl/xIguWJElU9JzmPU6\naZOix3ahmr0PwcIhFbWaZvsjL46MdHI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICIzCCAYwCCQDFqR2p3amCSjANBgkqhkiG9w0BAQUFADBWMQswCQYDVQQGEwJT\nRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UECgwDVW1VMQwwCgYDVQQLDANJVFMxHDAa\nBgNVBAMME2xpbmdvbi5sYWRvay51bXUuc2UwHhcNMTMwNjE0MTY1MjAyWhcNMTQw\nNjE0MTY1MjAyWjBWMQswCQYDVQQGEwJTRTENMAsGA1UEBwwEVW1lYTEMMAoGA1UE\nCgwDVW1VMQwwCgYDVQQLDANJVFMxHDAaBgNVBAMME2xpbmdvbi5sYWRvay51bXUu\nc2UwgZ8wDQYJKoZIhvcNAQEBBQADgY0AMIGJAoGBAM8nCb97J2QNi/U+4EnR2vL/\nvGtUM44dyOrdQ4xdD/feHyu0kWoNal/8CXJTYtDVrbKMg90fakPfw6Lw5KxQTzGl\nR6qNRyuuMq7KIgRzlbZEWiAh1YKQMOn+C3qIM0HqkfjD/rnCokIpFhGFi+7886AD\nVNB5CnUQXrSTAkUJzVS7AgMBAAEwDQYJKoZIhvcNAQEFBQADgYEABfQAzyDkwIQZ\nHu3tPi7QvJbdTDH8F3q8iSQwOT7MvxmHmCO/DZFwYu5jjYg/FtBfpbh8mQTziCy8\nFyVMuMKNSZn2rEIJF1ghgQqtHwn08zsPPhD9XW0LXeP6Exl/xIguWJElU9JzmPU6\naZOix3ahmr0PwcIhFbWaZvsjL46MdHI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://xenosmilus2.umdc.umu.se:8086/acs/re_hei/redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://xenosmilus2.umdc.umu.se:8086/acs/re_hei/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.univ-grenoble-alpes.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dgdsi-shibboleth@univ-grenoble.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.univ-grenoble-alpes.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2016-04-01T16:04:46Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.univ-grenoble-alpes.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.univ-grenoble-alpes.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.univ-grenoble-alpes.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-grenoble-alpes.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-grenoble-alpes.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Grenoble Alpes University staff and students"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "L'ensemble du personnel et des \u00e9tudiants de l'Universit\u00e9 Grenoble Alpes."
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University Grenoble Alpes - UGA"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 Grenoble Alpes - UGA"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDcTCCAlmgAwIBAgIUd4t2H5z9TaQY5iyAlE7kRfh/8FQwDQYJKoZIhvcNAQEL\nBQAwLDEqMCgGA1UEAwwhc2hpYmJvbGV0aC51bml2LWdyZW5vYmxlLWFscGVzLmZy\nMB4XDTE2MDMzMTE0MDExOFoXDTM2MDMzMTE0MDExOFowLDEqMCgGA1UEAwwhc2hp\nYmJvbGV0aC51bml2LWdyZW5vYmxlLWFscGVzLmZyMIIBIjANBgkqhkiG9w0BAQEF\nAAOCAQ8AMIIBCgKCAQEArnlbIfMiVLD6VWmeeeYxFdX8/Atz+Mnhe3GK/UgvqkBd\nm23wykUlDvzMc+PI29IPG7E2wqmaOedgvgllgW0LF7cIKQGzZuY/BXlQwqe9g8P3\nZOH+CX7Z4WaxEnVIDwzcTrBL/fpoeMuPYXGZtogZIdXtVvQdw+75Ahwbf3tfXQQb\nD/QfchS7Jxea4+rfhar3wkqwJwxPeryq3+hUkhveMifraAQeVB0Tbff8Q2cFkzuF\nc4/dOQsgXCNS7K0UcdJ5LA9OHGKctAQnIL1VPMRaGYxbDDYIMpZ7rMbL0hPeoyqA\nJpVj7njiEV6/JfWrKLE1PKtLm3h+0dWmJ8t0Wi/20wIDAQABo4GKMIGHMB0GA1Ud\nDgQWBBTwkI6QUcubGeOIWHWb+kETna8xOjBmBgNVHREEXzBdgiFzaGliYm9sZXRo\nLnVuaXYtZ3Jlbm9ibGUtYWxwZXMuZnKGOGh0dHBzOi8vc2hpYmJvbGV0aC51bml2\nLWdyZW5vYmxlLWFscGVzLmZyL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUA\nA4IBAQAdWH5bAvi6Uuc4aGWLz/RkxajpCb9GFdOt+FW2ZNRcg8ddB7euKRU0YBTN\ny/k4qppFsGuKmiH+jJmLHDnmb6kwvhEfEZ/aZnFbXXjYpZgqLnUl5i/dnFftxw62\nFFKVIoM5lLtE1xPTjl0c9n5LZbqcwsHcrl/uZcsvIhvbMcy/nBSN0nX3RMOPLCA3\nwLdAWYFV9qsWC8MlU02u8mSLj8kRQdd6QgOsWGxweHy6W4XuFku5AXdLhARpovY8\nCiaFfEll1J7dyf/C7Hmj3LDiK8CXX6alM4ZcbVZZXQEjiAxCgwbFTCb0+3ghEJr8\noO0zahDkkPQau5IyAPcgKkedumhq"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 Grenoble Alpes - UGA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-grenoble-alpes.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 Grenoble Alpes - UGA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://brandkeeper.se/wsfed",
    {
      "entity_id": "https://brandkeeper.se/wsfed",
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@brandkeeper.se"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 470 771 440"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Brandkeeper"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.brandkeeper.se/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Incited AB"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.brandkeeper.se"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "BrandKeeper \u00e4r ett webbaserat system f\u00f6r skapande av marknadsf\u00f6ringsmaterial (broschyrer, foldrar m.m.) och dagligt papper (visitkort, korrkort m.m.) till h\u00f6guppl\u00f6sta filer klara f\u00f6r tryck. I tj\u00e4nsten ing\u00e5r ocks\u00e5 en MediaBank (Digitalt bibliotek)."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "BrandKeeper is a web based system for creation of marketing materials (brochures, folders etc.) and stationery (business card, correspondence cards etc.) to high resolution files ready for print. The service also includes a MediaBank (Digital library)."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.incited.se/brandkeeper-logo-350.png",
                    "height": "61",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "BrandKeeper"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "BrandKeeper"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://www.incited.se/InSys/v2/AuthServices/Acs",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SP"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.grayzone.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.grayzone.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.grayzone.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.grayzone.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.grayzone.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.grayzone.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.grayzone.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.grayzone.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.grayzone.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.grayzone.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.grayzone.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.grayzone.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAJgL/UIUo864MA0GCSqGSIb3DQEBCwUAMCAxHjAcBgNV\nBAMTFXd3dy5ncmF5em9uZS5sYWRvay5zZTAeFw0xNjAzMTQxMTQ2MDhaFw0yNjAz\nMTIxMTQ2MDhaMCAxHjAcBgNVBAMTFXd3dy5ncmF5em9uZS5sYWRvay5zZTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK0c7tP+s8ifn2gZFh6FO6MIcFh7\npwHh9ZnS1c+zdSLcI+VzUu8koV0o4JMKqr/o9hKMDkrd2EXRUiTux3+k0ePLWBMq\n6PnSjnCO4U/Pr0+ZKRfVI1KzDv7BPyv0lP5+AtS1UeLUe9SLiCsAsDyNcchDXDQE\nKOo9GiAsVUXFfedshhdN1iSXWetyL1aCdqZ4lYFzjYygnZ3Y+YEfKbcEAAnJVUD5\njoBuUJxCFyTB1oceCAJ2GXwRV+LNn/ZqYzfr4NLTcx3SEmxCLn+6L7xxY6P1+6j5\nxMMDN1VOy3i+ErYcoOeiqKadL3KKIY0jt9Cg9++x7zG3sd+j9Fudu/zWHFMCAwEA\nAaNpMGcwRgYDVR0RBD8wPYIVd3d3LmdyYXl6b25lLmxhZG9rLnNlhiRodHRwczov\nL3d3dy5ncmF5em9uZS5sYWRvay5zZS9ndWktc3AwHQYDVR0OBBYEFD9mG85cKreL\n30kUPNS51OTXyhm8MA0GCSqGSIb3DQEBCwUAA4IBAQAMopCEYdbeBSVMLnqjJpgv\nGaQY1SNtI20IHcfzDKJogzjv/4UVcUFUO0VCI1RFmD8E7DfEUD3EZuYoX6+QkdEA\nPpL4bkfkcE1yfH2y7TYkt/7nbXqNYg/Rpg6tUYceXyriBKpuZia61Bx3moNtIKCO\n18S4vOyjGvh9MTuGMM81eRP4ZO6cCPxIimd4jyK9F7cqh8reB1skvO9+ghiak5sg\nYXMU0kj/IDNQQ9Hr2tj8e88rT15DRmjRI3dCCdrQ3geW+ZZkMm+bPdV1vfHGvG8+\n0yEVh0F2lpMEqdwLpcmqO8+/usorbJxs69tTG93PVbL3Oe3LfjV0EXKnwQkmlbRA"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.grayzone.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.grayzone.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.grayzone.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.grayzone.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.grayzone.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.grayzone.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.grayzone.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.grayzone.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.grayzone.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.grayzone.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://test-nais.i.uhr.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://test-nais.i.uhr.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test-nais.i.uhr.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://test-nais.i.uhr.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test-nais.i.uhr.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test-nais.i.uhr.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test-nais.i.uhr.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test-nais.i.uhr.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://test-nais.i.uhr.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "NAIS st\u00e5r f\u00f6r Nationellt Administrations- och Informationssystem f\u00f6r samordnare av s\u00e4rskilt pedagogiskt st\u00f6d"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "NAIS stands for National Administration- and Information system for coordination of pedagogical aid"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Test-NaisSP"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Test-NaisSP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "uhrval-test.i.uhr.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAKrvj/quXo0oMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFHVocnZhbC10ZXN0LmkudWhyLnNlMB4XDTE0MTIwODA5MTExMVoXDTI0MTIw\nNTA5MTExMVowHzEdMBsGA1UEAxMUdWhydmFsLXRlc3QuaS51aHIuc2UwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCtIWX5i6gPePK7nbap8snxwcLqlCID\nLWZkxbQGCVIgixRk1w87yUD882SSZjUATS8JV+8TeHNIsRSkBeXB1MQQopeDtm5C\nLDhh/RxHL3IRBlhesOE5zWcc4xeBzRIBKb1OC773XbSLx1lQhZmH+fiQvEk5FfWG\nri683HBCQq3gpc3hX2lY7C7oAxL7KST+37zLIBy7c83fzWr3eQ1myKZFfHBsmMOt\npNjBNMG8V924gaHWKAuqDa6lds53PszYZh27bN7dWXRrN0vXEZu6zfEioJVvg5RL\nc0lUqg/yu8Dk9JYYm9rQDj007livs9QllR54wsIxosVQWhAz36ZFafaNAgMBAAGj\nQjBAMB8GA1UdEQQYMBaCFHVocnZhbC10ZXN0LmkudWhyLnNlMB0GA1UdDgQWBBSG\nEGTlhQfKssjt+WgDPIKFHzzZEDANBgkqhkiG9w0BAQUFAAOCAQEAOHImN37aqOBU\nwicsP5vJ7X8yX6he/dAnRKhZbjWSlpFSZGwZrV/B6YeROAyRbzQH1fQRTup+angF\nB5m+vmxG0XjhUm8gXpMNqjgxaay72m2rPTVAkbqkMNTKNf44bRK5OGqPlJ0lwrnC\nWh1+2EdKahr4lzJaqiW2rXvX3moTYqrJlssglT+IRTzoNbL6eQLdqCVvZxXDjyUb\nD79D+ECq8yjkS4/8EQlvHdHozRMMplJTo+pXoZwV9KZgMMsxdT63VuJ/0HRCxCMC\nzcmOSN36LTlSIYY4q9pC8MCzt5YqZdnKJUIyjFy+Mmjeyw4t+ouUjjI6+AifCten\nBwquFopAQg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=uhrval-test.i.uhr.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test-nais.i.uhr.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://test-nais.i.uhr.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test-nais.i.uhr.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test-nais.i.uhr.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test-nais.i.uhr.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test-nais.i.uhr.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://test-nais.i.uhr.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://test-nais.i.uhr.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://test-nais.i.uhr.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://aleph.svkhk.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sklen\u00e1\u0159"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "petr.sklenar@svkhk.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://aleph.svkhk.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2014-01-09T13:46:49Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/library"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aleph.svkhk.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aleph.svkhk.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aleph.svkhk.cz/idp/profile/SAML2/POST-SimpleSign/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aleph.svkhk.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aleph.svkhk.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aleph.svkhk.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aleph.svkhk.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aleph.svkhk.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aleph.svkhk.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aleph.svkhk.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "svkhk.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.svkhk.cz/Uvodni-stranka.aspx?lang=en-US"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.svkhk.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for patrons and staff of the Research Library in Hradec Kr\u00e1lov\u00e9"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro \u010dten\u00e1\u0159e a zam\u011bstance Studijn\u00ed a v\u011bdeck\u00e9 knihovny v Hradci Kr\u00e1lov\u00e9"
                  }
                ],
                "logo": [
                  {
                    "text": "https://aleph.svkhk.cz/logo/logo_40.png",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "40"
                  },
                  {
                    "text": "https://aleph.svkhk.cz/logo/logo_90.png",
                    "height": "90",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "90"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The Research Library in Hradec Kr\u00e1lov\u00e9"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Studijn\u00ed a v\u011bdeck\u00e1 knihovna v Hradci Kr\u00e1lov\u00e9"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAJSFrXye/a/LtnzGg52l6Vv2aZ3AMA0GCSqGSIb3DQEB\nCwUAMBkxFzAVBgNVBAMMDmFsZXBoLnN2a2hrLmN6MB4XDTE1MDgyODE1MDgwMloX\nDTM1MDgyODE1MDgwMlowGTEXMBUGA1UEAwwOYWxlcGguc3ZraGsuY3owggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDk2YhfJ9dmOhNkAn3Bdr2L+ElDZ9Xl\nRQQIo+v18FD3ML99ZqS9y0NHGihDe3i8YTJjTYqV+Rg1aV8g7DdivWrqWJle23yf\nWRQLm+gl407hJ/XVyo5GfsafwIWdW/2gYq0y0wyFTROZsvzM5fYnBap1dpvf0UD7\newq5uCcQdSOtQ6hHajJnzn60uWG11sMAiQeaoeo7GdDuvpOH8oVuEMscvZtOHpv8\nc+USYcBMZ2n5H6Cp8/GqmIwJzHHrWbpSTwtcj0Qk/fdDHF/bKkukCpFJZmfF9/9O\noqN7xD872Fg65ZTVnNt6VcN336aZkXwPsjndtmZlGWyhLNUu3SsIUJvFAgMBAAGj\nYzBhMB0GA1UdDgQWBBSy9TOWhcL1moqEDeJaemfu/clcyTBABgNVHREEOTA3gg5h\nbGVwaC5zdmtoay5jeoYlaHR0cHM6Ly9hbGVwaC5zdmtoay5jei9pZHAvc2hpYmJv\nbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAAWjWUcrdsnu4coYaqXOPM89MOHqhmuel\nJv955SMGEVDr9nyyy9+ql8xbQbOdHjAJRwu0VgIPlk87mdikX0+H6Xk1c6cp4ud+\nBgQHJMtZObkAh2+fkkCxiqBUkYGPb+5GqvUBkzZbmO3nfQQ8GbxpelYse1tMeiaJ\ngKBxdaXrBBD2s33bOOZ89IMuDQeUszifVCxeofaS9B5N+wplX8J0svGM0ggxCJoM\nx/KI5F8aCCKoDnAD/I8tYu0fTuIwg04I9WwduYCoTxxzAVQ6Ta1QwqDRqRib8QvY\n6/ioV7XeMqtOSAqWrOwCClb0vDVOjUnKJTSU9O8E5/eBCYzfVrVKdA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUEJlCdI6O+jqGU7O1e2RkV53yqJIwDQYJKoZIhvcNAQEL\nBQAwGTEXMBUGA1UEAwwOYWxlcGguc3ZraGsuY3owHhcNMTUwODI4MTUwNzU4WhcN\nMzUwODI4MTUwNzU4WjAZMRcwFQYDVQQDDA5hbGVwaC5zdmtoay5jejCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKMBZOjdrxpmQqnkNeOqGdrSbB7YoV2M\nTWEsNm5lquQeV2zefrZVmjkolSeO1K0o3P4M4r12THBSsEFPIEWqbri7l0ti2GGh\nosSHaUMGGy73mznHgbSDXCW+WBc6hXMn5LFXkwQz88fTDRZ2tVfCIDT4bat07+gn\nVjYdokbBgVeoe+GXQEw4Oax1vjsGCvq3+e7kIw1rW7ieVGF8xAkyk9VFV3nEeIGm\n8aR/Bi3625PZO9F4n5JZ86rjVfI84rXaVig55z8nbH9kGYR4J2hHwM/BSO0vhBJC\ngQSvqdgNbO5SMOcKy0bbBKfPVkvANyKVt1FuE5GlCu/yA2Yb4oVgFKsCAwEAAaNj\nMGEwHQYDVR0OBBYEFFQTBSzOxH3LROx/bkBFyhuStmYrMEAGA1UdEQQ5MDeCDmFs\nZXBoLnN2a2hrLmN6hiVodHRwczovL2FsZXBoLnN2a2hrLmN6L2lkcC9zaGliYm9s\nZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQAwmzkKKSFElavD4lgIclbIn4TtjU0vkr2U\nokA6bfpYyG4YKJF1oYlIRANW0834HImncJ2p7zjVUDVOz4NG6L6P8+C2wq2b8m6u\nXsmlTHWoQq1uMK01weHzjkgRH7Ux/6MUBb/HWCB5o6TTf7QWGTnohudrsvw6rMvS\nkCOsKNdYHRUqduRImil9zI7oB3DgcMqKo+nc7ElXdpdZ+C14i+DmVOLsHyAdU/r+\nwI+5wsg5a318BqML9SybteAP3EtvV8gaDJNtDTtGxR26dUoxyfMBcr1pu0NWcbPx\nK6FU2egg9HD4BD1u6djYZV47aavLjJ0tSErfcHvrz5JMQrnbv3GZ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIzCCAgugAwIBAgIUHR8h609/l5ZaqJVRDkOVK6KQWccwDQYJKoZIhvcNAQEL\nBQAwGTEXMBUGA1UEAwwOYWxlcGguc3ZraGsuY3owHhcNMTUwODI4MTUwODAyWhcN\nMzUwODI4MTUwODAyWjAZMRcwFQYDVQQDDA5hbGVwaC5zdmtoay5jejCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBALNWuZY/XJorTyIeONFA6lhfBhhSOaYE\n2wtO0KNMlfqY0HPTDn2uPd2F06411wACW12RwyGErZRluedwaZeVdJfy05x3bXsu\noGDm1o/JI0hLiH82BupYWAZsMhv6XBiv9F8DC+nKDIOKETElJ7mc80fTLMNPH9Bm\nICvlXCNKdghfPZdAstZM4YpobGFk/0ZCjU5vWCew8ZOUTsMYtp52A4sGHpieGLXk\n0gejaQK8hG70K9GeaDaKm0UAE5780qM13NFBiBg+gIFYUXLxkVZsn7+hEA6YDewu\nYq4pKdiFI2M7Aj+m4UucRzO237txeznDKKmSnrrgRG9UV7c9vHkhfpUCAwEAAaNj\nMGEwHQYDVR0OBBYEFM27r6xs8sW5D9dl0IVjah5S9ZZAMEAGA1UdEQQ5MDeCDmFs\nZXBoLnN2a2hrLmN6hiVodHRwczovL2FsZXBoLnN2a2hrLmN6L2lkcC9zaGliYm9s\nZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQAfwgwA9/oEx1jnywTpE+I+7omw9RN1McfA\nEN+vJDuGt0Vz8TcjRHUOGxwXHtbw4/aOkK48Drg/kIKY7dghuNeGJgd31bNsgvBj\nZdecvn1G8TpRlTZXV71+EliO49zpNX8KSimobPkB+oHSMkt94HTljmka11yogiJi\nycotZyPq8kGjGrFRh0InfIDfRGd9zD0v698moP8FzNlvckl3jL7tzT95QAA9dO21\nMpM8yEEOmngDz+D/LJeNJVT5cbvIZ3gpfm5yX16PyvFMXr8g9NMf/OhAznAHrL90\nxDF332t8sZ0yvjOOmIVyk2NtktyqGSqA7pRQRUZvzMHw15kyMzEM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Studijn\u00ed a v\u011bdeck\u00e1 knihovna v Hradci Kr\u00e1lov\u00e9"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Research Library in Hradec Kr\u00e1lov\u00e9"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.svkhk.cz/Uvodni-stranka.aspx?lang=en-US"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.svkhk.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Studijn\u00ed a v\u011bdeck\u00e1 knihovna v Hradci Kr\u00e1lov\u00e9"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Research Library in Hradec Kr\u00e1lov\u00e9"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://fed.nebraska.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "csnidm@nebraska.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CSN IDM"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "csnidm@nebraska.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CSN IDM"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "csnidm@nebraska.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CSN IDM"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "csnidm@nebraska.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CSN IDM"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://fed.nebraska.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://fed.nebraska.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://fed.nebraska.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://fed.nebraska.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nebraska.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.nebraska.edu/about"
                  }
                ],
                "logo": [
                  {
                    "text": "https://fed.nebraska.edu/idp/images/un_master_bk_incommon.jpg",
                    "lang": "en",
                    "height": "75",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "284"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.nebraska.edu/bylaws-and-policies.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Nebraska"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVANWxMfp7iqhLfgIoE4ybKObKMdNvMA0GCSqGSIb3DQEB\nCwUAMBsxGTAXBgNVBAMMEGZlZC5uZWJyYXNrYS5lZHUwHhcNMTUxMTIzMjAyMDIy\nWhcNMzUxMTIzMjAyMDIyWjAbMRkwFwYDVQQDDBBmZWQubmVicmFza2EuZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAgaxH5xLCYFKK9hrcIqMRG6nF\nF0ejQeH+x6QoBUhJzuyj3dCBt8rzj119jNjlxXSC3h4eH6HtdkeyeNXa9goT30C6\nb86ITXCLeC+goMlMuWQhNBj/vlfTRes6P5g+/DDcfiwB2tMyJSwVaeVlq/zFaG2b\nHn7G8DMqgzIbdQ58vqNljyL7q0I3tXwn/CjnS5c+9pZkPTz9wgpp8zBh/LWehuRk\ngWK5zI09ewoDoHKFqYEAvhSZl2JKXLs2652wGFlll5U5LWgnZZuXd126c2RIwAEF\niRZ8T0A0pSxKRu4f2wU8v9IhnZmDs2ZkJ9l/3TUZ4yQHT13sYG47oo3DCNVRiQID\nAQABo2cwZTAdBgNVHQ4EFgQUGYCGTzzBmBu5yJKnzbHb5ms+TmQwRAYDVR0RBD0w\nO4IQZmVkLm5lYnJhc2thLmVkdYYnaHR0cHM6Ly9mZWQubmVicmFza2EuZWR1L2lk\ncC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQBLe5yYldy82qoYoaroy4gp\nwQYBfQjgFRtp9bFtcwBfvKa7NHTq6kq3mmsr3fR/P70skLsB5EIe/S8rzOHdUoZX\nOXqqRE44bp2Bt62D0EUhl6eWAcOIgC7mh7xWnv15qzfBeIS58MiLf60gx0qh9O70\nTH9NsEeaYMSXcQUgTjIDHot67m1bXeM7ChxeR+lbgO2gaHj6oYWOmyqJQ0LweftD\nGqGigFGF6ju7NEECJFYw8kEkTQfT7vJQG6rrf4jPzkMcR/ffBN+8Drfpaf1KqA+l\n733uBmoqANbCQ9377rwdpNB4ps/noJ2ELOxQ5RAG9JRX3O6rBv7yaJ67UkSASCM7"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Nebraska"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nebraska.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Nebraska"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.uttyler.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "itsupport@uttyler.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UT Tyler IT Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uttyler.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uttyler.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uttyler.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAOpfnxqWfUWwtPv2ziaZ442AjjmsMA0GCSqGSIb3DQEB\nBQUAMBoxGDAWBgNVBAMTD2lkcC51dHR5bGVyLmVkdTAeFw0xMDA0MTUyMDU3NDNa\nFw0zMDA0MTUyMDU3NDNaMBoxGDAWBgNVBAMTD2lkcC51dHR5bGVyLmVkdTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMomvGbLSrG+K7edLO8f6J4DvHd9\nNov48swblPvF62GATn1735now81aMjk3r5un0xUGSy8leUsoZfdf5n6mUC9FUeri\nnvPpQk1IKNWQFNtp1ytsyGdNU9OMi8zmA64deVp47lxpgPUZkReFT9wq4LX3bSni\nMb7x15NhaEnFfdAlJsnhfzNBdtz+RN72s5+ZySy8ICC4KHgFGrr7QKMREVMaWsaZ\n28Thb6UeOY+GBcMqY9WyAwfWAc1+19rNJyCZT9GuQr0YUOxv3bpR302Zxm2w+7bA\nQ70r2yA0uiFxLwO8tt+4ynkKXajdAtEPTADnScYGCizU34Y3PoaO1gGzky8CAwEA\nAaNlMGMwQgYDVR0RBDswOYIPaWRwLnV0dHlsZXIuZWR1hiZodHRwczovL2lkcC51\ndHR5bGVyLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUVWPBUi9jdIsM9VXZ\ncWzcPTz+dAEwDQYJKoZIhvcNAQEFBQADggEBAK7mAKIlWZQGGQTNV1UHXkeIarKc\nnSI6gQf9jmJEuHR+w9SHG5Z0HvAflzNlDTS374P/pZc2qcdz1hvx6TIb2h86GNCd\nWtF29eqrNieq3HTwM5N+zL4pIeVNR34zPNfo7+C/fYzSgPv5FeYNfu/CGZhOsH+g\n6NQ1opMz0ZiUVMQsrjjoxSntFuTrFvFyEuyGEI0uOJMzd27PtZUldp5FZAgN9IF8\nWEZoQCmdWaTQAmqzpHBokozccqLcD2+Hsa94Pa3+nYVeaCBGmXz3MK5ZHZnz8M7s\nRB4HWzgZih8IU3YLXsJ8IC6GU+UbJ3kj4kUG15mhFlI7j8b/VjZnp6akccM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uttyler.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.uttyler.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uttyler.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uttyler.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.uttyler.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uttyler.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uttyler.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uttyler.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Single Signon Service at The University of Texas at Tyler"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.uttyler.edu/images/utt-logo.gif",
                    "lang": "en",
                    "height": "45",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "63"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.uttyler.edu/privacy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Texas At Tyler"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAOpfnxqWfUWwtPv2ziaZ442AjjmsMA0GCSqGSIb3DQEB\nBQUAMBoxGDAWBgNVBAMTD2lkcC51dHR5bGVyLmVkdTAeFw0xMDA0MTUyMDU3NDNa\nFw0zMDA0MTUyMDU3NDNaMBoxGDAWBgNVBAMTD2lkcC51dHR5bGVyLmVkdTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMomvGbLSrG+K7edLO8f6J4DvHd9\nNov48swblPvF62GATn1735now81aMjk3r5un0xUGSy8leUsoZfdf5n6mUC9FUeri\nnvPpQk1IKNWQFNtp1ytsyGdNU9OMi8zmA64deVp47lxpgPUZkReFT9wq4LX3bSni\nMb7x15NhaEnFfdAlJsnhfzNBdtz+RN72s5+ZySy8ICC4KHgFGrr7QKMREVMaWsaZ\n28Thb6UeOY+GBcMqY9WyAwfWAc1+19rNJyCZT9GuQr0YUOxv3bpR302Zxm2w+7bA\nQ70r2yA0uiFxLwO8tt+4ynkKXajdAtEPTADnScYGCizU34Y3PoaO1gGzky8CAwEA\nAaNlMGMwQgYDVR0RBDswOYIPaWRwLnV0dHlsZXIuZWR1hiZodHRwczovL2lkcC51\ndHR5bGVyLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUVWPBUi9jdIsM9VXZ\ncWzcPTz+dAEwDQYJKoZIhvcNAQEFBQADggEBAK7mAKIlWZQGGQTNV1UHXkeIarKc\nnSI6gQf9jmJEuHR+w9SHG5Z0HvAflzNlDTS374P/pZc2qcdz1hvx6TIb2h86GNCd\nWtF29eqrNieq3HTwM5N+zL4pIeVNR34zPNfo7+C/fYzSgPv5FeYNfu/CGZhOsH+g\n6NQ1opMz0ZiUVMQsrjjoxSntFuTrFvFyEuyGEI0uOJMzd27PtZUldp5FZAgN9IF8\nWEZoQCmdWaTQAmqzpHBokozccqLcD2+Hsa94Pa3+nYVeaCBGmXz3MK5ZHZnz8M7s\nRB4HWzgZih8IU3YLXsJ8IC6GU+UbJ3kj4kUG15mhFlI7j8b/VjZnp6akccM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Texas At Tyler"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uttyler.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Texas At Tyler"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://shibboleth.bsu.edu/sso",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "abchalmers@bsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex Chalmers"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tmeister@bsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Todd Meister"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://shibboleth.bsu.edu/sso",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.bsu.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.bsu.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.bsu.edu/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bsu.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ball State University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIJAKAO80Hri578MA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEnNoaWJib2xldGguYnN1LmVkdTAeFw0xMTA0MTkxNzA3MjZaFw0yMTA0MTYx\nNzA3MjZaMB0xGzAZBgNVBAMTEnNoaWJib2xldGguYnN1LmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALJheSWlUoTPpr154iRhjkGdtfdvCeJr09z4\nFdzDnMpFaBHxPf58b2YH8IVdwamoC3AKyoCkCStobCttV+lVodYhH0SXFZap2Fzq\nT62NxpFHQLLW14El9uC+cwRYYEBUTnQ9fsftv8xOz7jv9DQzhTW8GwGX33P98Y5w\nQ1MWulryvWzH3Hcc7wRCyXRa91/oN9M3gDEi6CfUfeZgz8Omq21rBIxgWNi/FyH4\nVfuPMEUfzm5qTnPyBvKJvPDewQZ6g6RyMtrqkx3h0Z9v/TZyxWeqCZctBiVHGEW9\n/+vnDC+LxMOHqoV4TquV6l2reeqECEM7zIT2pANwYfWXrrAIRIcCAwEAAaN+MHww\nHQYDVR0OBBYEFHpRlcFJbr61YLvNmm0jauaLwEasME0GA1UdIwRGMESAFHpRlcFJ\nbr61YLvNmm0jauaLwEasoSGkHzAdMRswGQYDVQQDExJzaGliYm9sZXRoLmJzdS5l\nZHWCCQCgDvNB64ue/DAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBc\nkXZa/U7dQH6rSh8tdfp3RhoCo9f7e0qtysH2BLWQrl54SUqXhGP5FMbybhodQKFx\nJOj4zD9h9EM1gg4YkSjCHgL7X9w5TH/47+m0R6P/PPitwCYMLCdAFESrhpO/sGSe\nBohT0pLdmQg4S7qvBG5qWwnuF/XQlJauVxWzA/vzReQnmVjHeYiWboEHrF5/t83e\nv0WxHdbpa3yELcIkIy7cHaEza80jhLNLX2P3BeWMXpTjAhyzRKqOgFw51C2NkI/T\n+mWS+cDSy+uOrGHD9NYCQdO0pynSeNVxNkQeobYBU8l3E7oS4ThlsxKHEJifjarX\nlXYN/Vp1V8upHuz8zaF7"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "error_url": "http://shibboleth.bsu.edu/error.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ball State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://cms.bsu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ball State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.delval.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "michael.davis@delval.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael Davis"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "charles.scally@delval.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Charles Scally"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "michael.davis@delval.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael Davis"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "chris.shriver@delval.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris Shriver"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.delval.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.delval.edu:9443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.delval.edu:9443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjgCCQCCO+P3N8He3TANBgkqhkiG9w0BAQUFADBqMQswCQYDVQQGEwJV\nUzELMAkGA1UECAwCUEExEzARBgNVBAcMCkRveWxlc3Rvd24xIDAeBgNVBAoMF0Rl\nbGF3YXJlIFZhbGxleSBDb2xsZWdlMRcwFQYDVQQDDA5pZHAuZGVsdmFsLmVkdTAe\nFw0xNDA3MjUxNTA5MjZaFw0xOTA3MjUxNTA5MjZaMGoxCzAJBgNVBAYTAlVTMQsw\nCQYDVQQIDAJQQTETMBEGA1UEBwwKRG95bGVzdG93bjEgMB4GA1UECgwXRGVsYXdh\ncmUgVmFsbGV5IENvbGxlZ2UxFzAVBgNVBAMMDmlkcC5kZWx2YWwuZWR1MIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAw1YNCyTmA7Tt3//dWCRBryL2UTYG\nL5YCM2F/f0F//u9kWja7euowoVF8C6NIhPkFWxEeDaDNkVt+toesOGZS8lo/bVJ1\noQgWlcyqHcfzS8g14r9PoSTCZHcpgqSUyjsgCnBq0iLFRymKgEpLxroL2nGjm9BU\n+Cu4sMQ01zjeb68zGz+lycbtpeuDgRhtwuWxGJurHZPHsDdLpn3sfk6joCgaQHJd\nyCDNnRimZkSQa5/rFlaF7J1ERe6s1txC7R1RLz0k+7KcUoMn4IJIQFH0VoGorrDJ\n2mJMVcpNMHtFpc6z2gqeQS9KIzqr2KqckedItOjV6MSdbCI5Td+JLtgKnwIDAQAB\nMA0GCSqGSIb3DQEBBQUAA4IBAQAn+LUZmRsw35GenabcrwVqHJd8G+qp6IfZD6sX\nUH6Yh2G7TiH+V0GqqVhyvD8DC/ji3BDQeoBLpBUZQJ7rTjpC0Z4Hr8Wnv0jecqGs\nuCEbIY2EsXHYFYiyyR9XvvsS3KDpAU7teTY/Oy6BfE48ebZf+mp35V7znU8DXOBq\nwPniAvPRS3QU9fqinSDPLwrjTrTdwgyXODK/7+nQx5C/qtoIee4BsPYlbqsxvBNB\n1TMWJUVw23yBL0hC7l0gxswxbrIxAwKA7aWQyM1apS9ke9x9Xghw6Zk1g+UqW+3C\n9nVqTm0Sk6c7D6fSOhfvXFNGOQGYAUZLRWAQx7V6nwmQ8Xx1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "delval.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.delval.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.delval.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.delval.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.delval.edu:9443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.delval.edu:9443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "delval.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://idp.delval.edu/identity/servlet/logo",
                    "lang": "en",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "900"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Delaware Valley University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjgCCQCCO+P3N8He3TANBgkqhkiG9w0BAQUFADBqMQswCQYDVQQGEwJV\nUzELMAkGA1UECAwCUEExEzARBgNVBAcMCkRveWxlc3Rvd24xIDAeBgNVBAoMF0Rl\nbGF3YXJlIFZhbGxleSBDb2xsZWdlMRcwFQYDVQQDDA5pZHAuZGVsdmFsLmVkdTAe\nFw0xNDA3MjUxNTA5MjZaFw0xOTA3MjUxNTA5MjZaMGoxCzAJBgNVBAYTAlVTMQsw\nCQYDVQQIDAJQQTETMBEGA1UEBwwKRG95bGVzdG93bjEgMB4GA1UECgwXRGVsYXdh\ncmUgVmFsbGV5IENvbGxlZ2UxFzAVBgNVBAMMDmlkcC5kZWx2YWwuZWR1MIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAw1YNCyTmA7Tt3//dWCRBryL2UTYG\nL5YCM2F/f0F//u9kWja7euowoVF8C6NIhPkFWxEeDaDNkVt+toesOGZS8lo/bVJ1\noQgWlcyqHcfzS8g14r9PoSTCZHcpgqSUyjsgCnBq0iLFRymKgEpLxroL2nGjm9BU\n+Cu4sMQ01zjeb68zGz+lycbtpeuDgRhtwuWxGJurHZPHsDdLpn3sfk6joCgaQHJd\nyCDNnRimZkSQa5/rFlaF7J1ERe6s1txC7R1RLz0k+7KcUoMn4IJIQFH0VoGorrDJ\n2mJMVcpNMHtFpc6z2gqeQS9KIzqr2KqckedItOjV6MSdbCI5Td+JLtgKnwIDAQAB\nMA0GCSqGSIb3DQEBBQUAA4IBAQAn+LUZmRsw35GenabcrwVqHJd8G+qp6IfZD6sX\nUH6Yh2G7TiH+V0GqqVhyvD8DC/ji3BDQeoBLpBUZQJ7rTjpC0Z4Hr8Wnv0jecqGs\nuCEbIY2EsXHYFYiyyR9XvvsS3KDpAU7teTY/Oy6BfE48ebZf+mp35V7znU8DXOBq\nwPniAvPRS3QU9fqinSDPLwrjTrTdwgyXODK/7+nQx5C/qtoIee4BsPYlbqsxvBNB\n1TMWJUVw23yBL0hC7l0gxswxbrIxAwKA7aWQyM1apS9ke9x9Xghw6Zk1g+UqW+3C\n9nVqTm0Sk6c7D6fSOhfvXFNGOQGYAUZLRWAQx7V6nwmQ8Xx1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Delaware Valley University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.delval.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Delaware Valley University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.sheffcol.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Humphrey"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:michael.humphrey@sheffcol.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Humphrey"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:michael.humphrey@sheffcol.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.sheffcol.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-03-25T14:08:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID8DCCAtgCCQD+MvDrUqcVKDANBgkqhkiG9w0BAQUFADCBuTELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxGDAWBgNVBAgTD1NvdXRoIFlvcmtzaGlyZTESMBAGA1UEBxMJU2hlZmZpZWxk\n\t\t\t\t\t\tMR4wHAYDVQQKExVUaGUgU2hlZmZpZWxkIENvbGxlZ2UxFDASBgNVBAsTC0lUIFNl\n\t\t\t\t\t\tcnZpY2VzMRswGQYDVQQDExJpZHAuc2hlZmZjb2wuYWMudWsxKTAnBgkqhkiG9w0B\n\t\t\t\t\t\tCQEWGlJvYmluLkNvb2tlQHNoZWZmY29sLmFjLnVrMB4XDTE0MDIyNDE1NDAyOVoX\n\t\t\t\t\t\tDTI0MDIyMjE1NDAyOVowgbkxCzAJBgNVBAYTAkdCMRgwFgYDVQQIEw9Tb3V0aCBZ\n\t\t\t\t\t\tb3Jrc2hpcmUxEjAQBgNVBAcTCVNoZWZmaWVsZDEeMBwGA1UEChMVVGhlIFNoZWZm\n\t\t\t\t\t\taWVsZCBDb2xsZWdlMRQwEgYDVQQLEwtJVCBTZXJ2aWNlczEbMBkGA1UEAxMSaWRw\n\t\t\t\t\t\tLnNoZWZmY29sLmFjLnVrMSkwJwYJKoZIhvcNAQkBFhpSb2Jpbi5Db29rZUBzaGVm\n\t\t\t\t\t\tZmNvbC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK42vD+O\n\t\t\t\t\t\t5/NBZV9XPPzgFWaxthadM9TWqQ4FB/IkubIk4fTXehlHW05kkMH70Md15HCKA810\n\t\t\t\t\t\tMfEowgPFZZIytOc1xREIeDf+d/9FTt1/+htgIuCFoeVviyNK/nNkPogYvoIDNaqW\n\t\t\t\t\t\tGIMCGteHF29vzJI572/yTvKukMBUO4GpWmIDrLM7kdg6BdoyMaiH3m53BB6NAnXE\n\t\t\t\t\t\tbPobrt4lcnOfBE3pqZ1wBmkXoBkDryO2ZEAPIsHQbzmbMjQlnzRfugzDE4N6RnH3\n\t\t\t\t\t\tJWaKll+sLBo3sKIQ205v6jfYbS9txbGAtBbucunHcqXRuwkxK3MQPVF+/C1MSlXN\n\t\t\t\t\t\th1sNGRbKT81WHssCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAO+8MDZoiDNJY/Hvp\n\t\t\t\t\t\tjdm8xGSAiGkTdE4rk09HEfYJ7jH8Uoa9Ka3Fiur9YqSBayw6qkkWgD5iO3NlKVqt\n\t\t\t\t\t\t0ZEgxy5duc5JG3VjnkUX9M3jFZYRCd5Ow7qgK7Z+AXr1D8SDDWfFG9mSSYBAtkX4\n\t\t\t\t\t\tjRYaWGlcGAcB3ATBE4jM+7GxP7cwyBqQIG3pZkCAYjEEUm11TLnEVgE8u/u2ioT0\n\t\t\t\t\t\tqOqAFHs6u5F5SzOvpYSaYAwi2Z2z0YlAocZt2Gs6GWSydWpT39G/Jbyfm/1TSZqo\n\t\t\t\t\t\t7iyFOrc1qevyiD5j7phHJ3th6ePeplPOwpUS/AejrJ8MeeQO4ZobKumOahHt2wkJ\n\t\t\t\t\t\tx5QCzw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sheffcol.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sheffcol.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sheffcol.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.sheffcol.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sheffcol.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.sheffcol.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sheffcol.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sheffcol.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sheffcol.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sheffcol.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID8DCCAtgCCQD+MvDrUqcVKDANBgkqhkiG9w0BAQUFADCBuTELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxGDAWBgNVBAgTD1NvdXRoIFlvcmtzaGlyZTESMBAGA1UEBxMJU2hlZmZpZWxk\n\t\t\t\t\t\tMR4wHAYDVQQKExVUaGUgU2hlZmZpZWxkIENvbGxlZ2UxFDASBgNVBAsTC0lUIFNl\n\t\t\t\t\t\tcnZpY2VzMRswGQYDVQQDExJpZHAuc2hlZmZjb2wuYWMudWsxKTAnBgkqhkiG9w0B\n\t\t\t\t\t\tCQEWGlJvYmluLkNvb2tlQHNoZWZmY29sLmFjLnVrMB4XDTE0MDIyNDE1NDAyOVoX\n\t\t\t\t\t\tDTI0MDIyMjE1NDAyOVowgbkxCzAJBgNVBAYTAkdCMRgwFgYDVQQIEw9Tb3V0aCBZ\n\t\t\t\t\t\tb3Jrc2hpcmUxEjAQBgNVBAcTCVNoZWZmaWVsZDEeMBwGA1UEChMVVGhlIFNoZWZm\n\t\t\t\t\t\taWVsZCBDb2xsZWdlMRQwEgYDVQQLEwtJVCBTZXJ2aWNlczEbMBkGA1UEAxMSaWRw\n\t\t\t\t\t\tLnNoZWZmY29sLmFjLnVrMSkwJwYJKoZIhvcNAQkBFhpSb2Jpbi5Db29rZUBzaGVm\n\t\t\t\t\t\tZmNvbC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK42vD+O\n\t\t\t\t\t\t5/NBZV9XPPzgFWaxthadM9TWqQ4FB/IkubIk4fTXehlHW05kkMH70Md15HCKA810\n\t\t\t\t\t\tMfEowgPFZZIytOc1xREIeDf+d/9FTt1/+htgIuCFoeVviyNK/nNkPogYvoIDNaqW\n\t\t\t\t\t\tGIMCGteHF29vzJI572/yTvKukMBUO4GpWmIDrLM7kdg6BdoyMaiH3m53BB6NAnXE\n\t\t\t\t\t\tbPobrt4lcnOfBE3pqZ1wBmkXoBkDryO2ZEAPIsHQbzmbMjQlnzRfugzDE4N6RnH3\n\t\t\t\t\t\tJWaKll+sLBo3sKIQ205v6jfYbS9txbGAtBbucunHcqXRuwkxK3MQPVF+/C1MSlXN\n\t\t\t\t\t\th1sNGRbKT81WHssCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAO+8MDZoiDNJY/Hvp\n\t\t\t\t\t\tjdm8xGSAiGkTdE4rk09HEfYJ7jH8Uoa9Ka3Fiur9YqSBayw6qkkWgD5iO3NlKVqt\n\t\t\t\t\t\t0ZEgxy5duc5JG3VjnkUX9M3jFZYRCd5Ow7qgK7Z+AXr1D8SDDWfFG9mSSYBAtkX4\n\t\t\t\t\t\tjRYaWGlcGAcB3ATBE4jM+7GxP7cwyBqQIG3pZkCAYjEEUm11TLnEVgE8u/u2ioT0\n\t\t\t\t\t\tqOqAFHs6u5F5SzOvpYSaYAwi2Z2z0YlAocZt2Gs6GWSydWpT39G/Jbyfm/1TSZqo\n\t\t\t\t\t\t7iyFOrc1qevyiD5j7phHJ3th6ePeplPOwpUS/AejrJ8MeeQO4ZobKumOahHt2wkJ\n\t\t\t\t\t\tx5QCzw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Sheffield College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sheffcol.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Sheffield College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://webclass.uran.ua/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Preobrazhenskyi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:admins@uran.ua"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Yevhenii"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://webclass.uran.ua/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://peano.uran.ua/~eng/policy.htm"
              }
            ],
            "registration_instant": "2015-03-15T11:05:00Z",
            "registration_authority": "https://peano.uran.ua",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "URAN"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uran.ua/~eng/frames.htm"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Association URAN"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://webclass.uran.ua/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://webclass.uran.ua/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webclass.uran.ua/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://webclass.uran.ua/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://webclass.uran.ua/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://webclass.uran.ua/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://webclass.uran.ua/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://webclass.uran.ua/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Conference server and online learning system of PEANO federation"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://webclass.uran.ua/webclass_privacy_policy.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WEB-class"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://webclass.uran.ua/shibboleth"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "webclass.uran.ua"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIJAIE/TOjTP6h5MA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEHdlYmNsYXNzLnVyYW4udWEwHhcNMTUwMzEzMTQyOTE0WhcNMTgwMzEyMTQy\nOTE0WjAbMRkwFwYDVQQDExB3ZWJjbGFzcy51cmFuLnVhMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAykQQU5zDYaRiXs8NTHW9PSRz2JtrUgJC6GZoTgr6\nexC6CRPWvXPY9+Gbj4n7ASXWQOW04V6Sqie++iYNjq8hWLgKvY/gY9AykwtwzlxN\nhvE4WwCTplNbboPtBpRpOxXvrtqKMa7Y4lKQ4KKDxkCwaE2spE2Y5i62O7Y6uM8A\nysaenWm3vhmlQMeMrgu6hIirORFXlctv1JXh7G6hM5PrAlxgnNrE46Jt07yOsq6p\naY2iqXkJPVqF8fvCf4vuUpXV0J1SDcA7hzE8ePDHXYebFRR6N6fXi2XcgBzZMu4a\n9/5pKkJ0+KvZe20UcHJqQOZ8qGsZB9oGrYkfV8DRg8FapQIDAQABo2MwYTBABgNV\nHREEOTA3ghB3ZWJjbGFzcy51cmFuLnVhhiNodHRwczovL3dlYmNsYXNzLnVyYW4u\ndWEvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUp9tj8EP1CtFBOjRnZLMug1U6jbswDQYJ\nKoZIhvcNAQEFBQADggEBAEMWl5gaHzs2GtK5mWWF7+EdiCkrrZurG4G2PenIhXDT\nsjoGNWSO+ZdmxuPTMpWxPsCH3UtkTDDtscZ0lBnWC0lmxx2chf+0PTQddLp35j1s\ngBMv4fLtxAlBKDS0E7EulGBL+3j3Sp8l+2CLX2SSJED2whxY2b22h2nFtjdTMFV6\nqkHYLsLMUECsCuyBVC3sEnCyR/ZV0iXMLrXwmb1dY5oWev1WsO1bjtFTw+MjQ2uc\n54nKzfvAurdiaw0fmSiF/GTvuviifNLJiwYtQWcfJVIb1bCoQQwNPpWWkxFKbjc+\n3o/EQJNrHD5zELEvuKkmcc3+EqOT4ysmvAxLWrG0oT8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webclass.uran.ua/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://webclass.uran.ua/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://webclass.uran.ua/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://webclass.uran.ua/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://webclass.uran.ua/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://webclass.uran.ua/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "WEB-class"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Conference server and online learning system of PEANO federation"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "transientId",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.2.3.4.5.6.7.8.9.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cafe.upf.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "GTI/RNP"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "servnac@rnp.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.upf.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAKX43u2xOk6GZiZYCBjCZkKXx2/9MA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2NhZmUudXBmLmJyMB4XDTEyMDcxODEzMzMwMFoXDTMy\nMDcxODEzMzMwMFowFjEUMBIGA1UEAxMLY2FmZS51cGYuYnIwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDQ4M1p+I5ah6Aw+O5/z9Be++lnk9Vs/F1rXbKj\ntP4ZLt+1ubEXIstFvgYbaQegfjGCmbSTLjeAhoKqQa+9oqHztvJCyi8tAAxm+DkR\nYUVjK7jdg+WhLSIXXjUw8kLQ7/0j9WoR5kANYpb0zgLX5txa6ag0yuiy3SZJdem5\nOxWcRMIgM9IT93D0Vtn4KOy33LuT1nJnlfXRe0e/6Uk3io8eX/sU1bFbYGSIoaBC\nwavXQpYI6doyMwp6jQ0ZTHMgPveJ9RgJVI1UjxPNarlfpkD3tbBoMW6jKzysuNza\nfdE/zhufAdpf1dEJLvW6NqFQhV/IntZ9uikpaZb0qYfccb+FAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2NhZmUudXBmLmJyhiJodHRwczovL2NhZmUudXBmLmJyL2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBQzZ13hyDuXco93Ne8aOzsxQ7pkVDANBgkqhkiG\n9w0BAQUFAAOCAQEAxN0o+TiTOnQ9DyT3sLjL7t08L2DXXzZS808wUPm9gxAxaKBy\nRP6v52aY5JQl+5KDp4kcYWcJ2HbmY93pdJr/ySf38ZnfDhE8/VtxTPN8i8flLpo6\nhAXpIVHrpchg/6A6wG94q2hoJHJlkjdMAUaqRluRVqUf3LCh9z0L2JYggLMO8t4i\ndZva6wWLqVLrj290MtPM6VyBwky4PyopG92JhFkovN6fO+N0XBOXO95k7vRhXHMq\nQ7lzc5HBe7iHhhH8bMVnNU4rnC5y/mAtB8RlGKu9xkgHFzxpk+Rf8ZvvI6hdpmCD\nCiIzIL92AYqWu+1Ec6sT4NbrfVhJlpfh0jshog=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "upf.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.upf.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.upf.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.upf.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.upf.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.upf.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.upf.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.upf.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.upf.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "upf.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.upf.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.upf.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UPF - Universidade de Passo Fundo"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UPF - Universidade de Passo Fundo"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UPF - Universidade de Passo Fundo"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UPF - Universidade de Passo Fundo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAKX43u2xOk6GZiZYCBjCZkKXx2/9MA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2NhZmUudXBmLmJyMB4XDTEyMDcxODEzMzMwMFoXDTMy\nMDcxODEzMzMwMFowFjEUMBIGA1UEAxMLY2FmZS51cGYuYnIwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDQ4M1p+I5ah6Aw+O5/z9Be++lnk9Vs/F1rXbKj\ntP4ZLt+1ubEXIstFvgYbaQegfjGCmbSTLjeAhoKqQa+9oqHztvJCyi8tAAxm+DkR\nYUVjK7jdg+WhLSIXXjUw8kLQ7/0j9WoR5kANYpb0zgLX5txa6ag0yuiy3SZJdem5\nOxWcRMIgM9IT93D0Vtn4KOy33LuT1nJnlfXRe0e/6Uk3io8eX/sU1bFbYGSIoaBC\nwavXQpYI6doyMwp6jQ0ZTHMgPveJ9RgJVI1UjxPNarlfpkD3tbBoMW6jKzysuNza\nfdE/zhufAdpf1dEJLvW6NqFQhV/IntZ9uikpaZb0qYfccb+FAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2NhZmUudXBmLmJyhiJodHRwczovL2NhZmUudXBmLmJyL2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBQzZ13hyDuXco93Ne8aOzsxQ7pkVDANBgkqhkiG\n9w0BAQUFAAOCAQEAxN0o+TiTOnQ9DyT3sLjL7t08L2DXXzZS808wUPm9gxAxaKBy\nRP6v52aY5JQl+5KDp4kcYWcJ2HbmY93pdJr/ySf38ZnfDhE8/VtxTPN8i8flLpo6\nhAXpIVHrpchg/6A6wG94q2hoJHJlkjdMAUaqRluRVqUf3LCh9z0L2JYggLMO8t4i\ndZva6wWLqVLrj290MtPM6VyBwky4PyopG92JhFkovN6fO+N0XBOXO95k7vRhXHMq\nQ7lzc5HBe7iHhhH8bMVnNU4rnC5y/mAtB8RlGKu9xkgHFzxpk+Rf8ZvvI6hdpmCD\nCiIzIL92AYqWu+1Ec6sT4NbrfVhJlpfh0jshog=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UPF - Universidade de Passo Fundo"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UPF - Universidade de Passo Fundo"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.upf.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.upf.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UPF - Universidade de Passo Fundo"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UPF - Universidade de Passo Fundo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.servicedesk.its.umu.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.servicedesk.its.umu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.servicedesk.its.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.servicedesk.its.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.servicedesk.its.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.servicedesk.its.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.servicedesk.its.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.servicedesk.its.umu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "En samling av verktyg och tj\u00e4nster f\u00f6r studenter och anst\u00e4llda vid Ume\u00e5 universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "A collection of tools and services for students and staff at Ume\u00e5 University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ServiceDesk - IT-support vid Ume\u00e5 universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ServiceDesk - IT-support at Umea University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.servicedesk.its.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEDzCCAvegAwIBAgIJAK1n6INIIuwWMA0GCSqGSIb3DQEBBQUAMIGdMQswCQYD\nVQQGEwJTRTEVMBMGA1UECAwMVmFzdGVyYm90dGVuMQ0wCwYDVQQHDARVbWVhMQww\nCgYDVQQKDANJVFMxDDAKBgNVBAsMA0lUUzEjMCEGA1UEAwwad3d3LnNlcnZpY2Vk\nZXNrLml0cy51bXUuc2UxJzAlBgkqhkiG9w0BCQEWGHRvbW15LmxhcnNzb25AYWRt\nLnVtdS5zZTAeFw0xMTA1MTYwNjM4NTBaFw0xNDAzMjkwNjM4NTBaMIGdMQswCQYD\nVQQGEwJTRTEVMBMGA1UECAwMVmFzdGVyYm90dGVuMQ0wCwYDVQQHDARVbWVhMQww\nCgYDVQQKDANJVFMxDDAKBgNVBAsMA0lUUzEjMCEGA1UEAwwad3d3LnNlcnZpY2Vk\nZXNrLml0cy51bXUuc2UxJzAlBgkqhkiG9w0BCQEWGHRvbW15LmxhcnNzb25AYWRt\nLnVtdS5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANJEvTU6sPUf\n+QdTlHhSzEHHBraAqXnmBAtCH4PrpYZt5UBMnrDCfWMWI6rDQ0m5t/foWGMG/Eat\nEycsYbySEyDgiK7AK9ahC0Bpd6CyT1gYGOfBIdMDNOgCahr2GnnvNp78/sUaC7pU\nqDXOdMsB4iPiLtEYCa6XTJi/KVB487utrIMud4UpGojtXORSFHpPC45QHgZicj8R\n0jIL7VPCTgJBKWwqeMoOUtDl5iFgMXTkafXVKR+rrh8UFS4LmNNid0PbxofI/azG\nvc7CF0E59O184V6UnLHJwcLqaJkVzIdq1z5dUKxskPnm6xX1xZNC+DVW7ALEEfD8\nMZeVe3PJn9cCAwEAAaNQME4wHQYDVR0OBBYEFO3UOhgEKHKE36Id4OB/zbb73ZmK\nMB8GA1UdIwQYMBaAFO3UOhgEKHKE36Id4OB/zbb73ZmKMAwGA1UdEwQFMAMBAf8w\nDQYJKoZIhvcNAQEFBQADggEBABQZkJyN0sgb+pGxw+sSeYSLhZxdLOySKZSr7LV4\nGinxtO41dwXNmGFPavO4sYExqo2FWUo2RItwUorOHCtlpypfWf+xBThD2uRR44+a\ntb0wNbW7y/hGwCCe1as2lewrvPOzWVG51I4Xxw5hiNpz+7ayNRX+icYgONP1ZSN+\njrymeKjpHE9w443OiAkezSm2tXADbEugC+DhowF9PXnX2Gn8BfXrD1LPP1ze200S\n4tHrNMcpgz8mndg+eAvBnGxe/OdC+DuDO/33E559DYGi7Iw5GzGbCPLCuUsWvstm\nAk0+kMSVOzv6UoGDUEbEh2o5K1iQnOzUKyTJrfW1if1I8Wg="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=tommy.larsson@adm.umu.se,CN=www.servicedesk.its.umu.se,OU=ITS,O=ITS,L=Umea,ST=Vasterbotten,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.servicedesk.its.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEDzCCAvegAwIBAgIJAK1n6INIIuwWMA0GCSqGSIb3DQEBBQUAMIGdMQswCQYD\nVQQGEwJTRTEVMBMGA1UECAwMVmFzdGVyYm90dGVuMQ0wCwYDVQQHDARVbWVhMQww\nCgYDVQQKDANJVFMxDDAKBgNVBAsMA0lUUzEjMCEGA1UEAwwad3d3LnNlcnZpY2Vk\nZXNrLml0cy51bXUuc2UxJzAlBgkqhkiG9w0BCQEWGHRvbW15LmxhcnNzb25AYWRt\nLnVtdS5zZTAeFw0xMTA1MTYwNjM4NTBaFw0xNDAzMjkwNjM4NTBaMIGdMQswCQYD\nVQQGEwJTRTEVMBMGA1UECAwMVmFzdGVyYm90dGVuMQ0wCwYDVQQHDARVbWVhMQww\nCgYDVQQKDANJVFMxDDAKBgNVBAsMA0lUUzEjMCEGA1UEAwwad3d3LnNlcnZpY2Vk\nZXNrLml0cy51bXUuc2UxJzAlBgkqhkiG9w0BCQEWGHRvbW15LmxhcnNzb25AYWRt\nLnVtdS5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANJEvTU6sPUf\n+QdTlHhSzEHHBraAqXnmBAtCH4PrpYZt5UBMnrDCfWMWI6rDQ0m5t/foWGMG/Eat\nEycsYbySEyDgiK7AK9ahC0Bpd6CyT1gYGOfBIdMDNOgCahr2GnnvNp78/sUaC7pU\nqDXOdMsB4iPiLtEYCa6XTJi/KVB487utrIMud4UpGojtXORSFHpPC45QHgZicj8R\n0jIL7VPCTgJBKWwqeMoOUtDl5iFgMXTkafXVKR+rrh8UFS4LmNNid0PbxofI/azG\nvc7CF0E59O184V6UnLHJwcLqaJkVzIdq1z5dUKxskPnm6xX1xZNC+DVW7ALEEfD8\nMZeVe3PJn9cCAwEAAaNQME4wHQYDVR0OBBYEFO3UOhgEKHKE36Id4OB/zbb73ZmK\nMB8GA1UdIwQYMBaAFO3UOhgEKHKE36Id4OB/zbb73ZmKMAwGA1UdEwQFMAMBAf8w\nDQYJKoZIhvcNAQEFBQADggEBABQZkJyN0sgb+pGxw+sSeYSLhZxdLOySKZSr7LV4\nGinxtO41dwXNmGFPavO4sYExqo2FWUo2RItwUorOHCtlpypfWf+xBThD2uRR44+a\ntb0wNbW7y/hGwCCe1as2lewrvPOzWVG51I4Xxw5hiNpz+7ayNRX+icYgONP1ZSN+\njrymeKjpHE9w443OiAkezSm2tXADbEugC+DhowF9PXnX2Gn8BfXrD1LPP1ze200S\n4tHrNMcpgz8mndg+eAvBnGxe/OdC+DuDO/33E559DYGi7Iw5GzGbCPLCuUsWvstm\nAk0+kMSVOzv6UoGDUEbEh2o5K1iQnOzUKyTJrfW1if1I8Wg="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=tommy.larsson@adm.umu.se,CN=www.servicedesk.its.umu.se,OU=ITS,O=ITS,L=Umea,ST=Vasterbotten,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.servicedesk.its.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.servicedesk.its.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.servicedesk.its.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.servicedesk.its.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.servicedesk.its.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.servicedesk.its.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.servicedesk.its.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.servicedesk.its.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.servicedesk.its.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.servicedesk.its.umu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-07.ladok.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-07.ladok.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;07"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;07"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-07.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-07.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAOsgfFjj/hMdMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wNy5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTQ0MjQ5WhcNMjQx\nMDA0MTQ0MjQ5WjAhMR8wHQYDVQQDExZsYWRvazMtMDcubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA5DBg6PDwC4+C6CEkNGol26MB\neJsWIm5Ir1UnDZh23Ya3laVl6BJ7XPeqEriYDQhPEzhzVr6oI40SEzHGLxs8MoJZ\nCuMC+fLdwZePVTe3Egv03sK9fHmJ0OZT2zmr6GsfbdTT0GBKZQFVr8K0wTJp8Zb6\n9GAtlERKWb0XH9gA7xBcOAJP9SwRnbF0yPa8JLisAFAHTRnke1jfhAlbmzhdn7fe\nWWF7hwdmm6/H2fOWGRcj+D4TetrLZfe4oOgp0jqwePo40DQQl9HydvLks3wE8BoW\nIBtgueYzGAn9WQ5glfKGpOH+eIGX9f8xEWaeKymCHKLEAKC7Qgf2D9sX8U9+XwID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMDcubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0wNy5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUZwh/XMjxGo6c8it7PdID4xRpjRYwDQYJKoZIhvcNAQEFBQADggEB\nAFkbeTMkoGdJ8ORwMFJega9rncawdLSBwvOVP8oS3pCC+B1FUVgihDgBoFu/J6I+\nwndHcmlt8f2klO4J6AKIIHsC/wDRxdqez2sL6FzIPzAE/JbMAa5BCiIeJH10JNl0\n7p2ZJkS9nKYpBDbXVO5cdmaZcICPTJm28Bo2wI+krWIB1IgH1Qwi+LECBvvWpd2+\nSVM6b6Ht6z8aHkecEuUdNzpJ4yXmbC2GWsRmicYwYo5gT4olPPA6qLUq2SWxE3Va\ng4/6d9o3Ce9czm1s/j0Eeq97ZVGX6805iZmR4ne/rSkSt3w+bhhDjxo4R7lyyUau\nTf+bD9kP9t0LVFwEIee45FY="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-07.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-07.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://fedidp.bcm.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "afburton@bcm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Abigail Burton"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "afburton@bcm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Abigail Burton"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "it-security@bcm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "BCM IT Security and Compliance"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://fedidp.bcm.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://fedidp.bcm.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://fedidp.bcm.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIVAOG5n3plVD0k2za22rJhNB0cfOj6MA0GCSqGSIb3DQEB\nBQUAMCMxITAfBgNVBAMTGGh2bC1pZHAtZDAwMS5iZGMuYmNtLmVkdTAeFw0xMDAz\nMTIxNjU4MjNaFw0zMDAzMTIxNTU4MjNaMCMxITAfBgNVBAMTGGh2bC1pZHAtZDAw\nMS5iZGMuYmNtLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJIQ\nGwkzSpjlCCl+CAMGacoDktpB/1Twp3UShBMfv1bEo8hJzhZNK+QxH+cMAJuzRaF2\nfslr7wyPtRnH9soq5Usxli3V6PV93oHMNLcD9hNwiaifhisWdUOTHYyXx5+Fw1xT\nfhLFg2tRioMibtfjV8l4z2VN28LoXn2LoAlnA0J6rTHJGUfuPXcfSn8fMSQokblt\npAC+WLjbhIxQO6Reg4eC5Tz/WbZjVijEZEN8Opjh3KX9JL/jWAZCemsIZ0fvK83t\nVm+45N18PEYfzq0hXwfrgQYI1FK3tZs7fimtrAuF09ho2L+E/5WNLlYJcHorAeEu\nLdT2ZvldDtbi3/rwydcCAwEAAaN3MHUwVAYDVR0RBE0wS4IYaHZsLWlkcC1kMDAx\nLmJkYy5iY20uZWR1hi9odHRwczovL2h2bC1pZHAtZDAwMS5iZGMuYmNtLmVkdS9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU71kAUsprVqB8YdTiowM3yaMIzbwwDQYJ\nKoZIhvcNAQEFBQADggEBAGdGZ58nE5xF66dFQjINXF+eFfCyWkFXvIWypLxQYVr+\nXdIfxVN/VYgO+b8Qea4N21YOlxt3m9v/TdQsjF0Ai73SV1j6iPoq+tDGbotpzp1A\nnbq75QodfpBWsWIwqKRqeU/y2gUq5CEB38rdve5hzgyOcTeEosx77s0X22RGHJiO\nAObkVTRvapKDM9P1Z0cSzL+r4ofnrH9wk8pI4Sqky16ay+zvbLvW5GuGeQJz8yaB\nEm4kk7BwhJEPnrqnDKD1d9cdeE1ww3rTAxyZsd0C8zWwg/SRQXp7XcvoNANsIiv+\nkT/uinAHeX+T8m3KqLxJRfjBx4uQkIJOqjGIQSJyM5U="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bcm.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://fedidp.bcm.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://fedidp.bcm.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://fedidp.bcm.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://fedidp.bcm.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://fedidp.bcm.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://fedidp.bcm.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bcm.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Baylor College of Medicine"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIVAOG5n3plVD0k2za22rJhNB0cfOj6MA0GCSqGSIb3DQEB\nBQUAMCMxITAfBgNVBAMTGGh2bC1pZHAtZDAwMS5iZGMuYmNtLmVkdTAeFw0xMDAz\nMTIxNjU4MjNaFw0zMDAzMTIxNTU4MjNaMCMxITAfBgNVBAMTGGh2bC1pZHAtZDAw\nMS5iZGMuYmNtLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJIQ\nGwkzSpjlCCl+CAMGacoDktpB/1Twp3UShBMfv1bEo8hJzhZNK+QxH+cMAJuzRaF2\nfslr7wyPtRnH9soq5Usxli3V6PV93oHMNLcD9hNwiaifhisWdUOTHYyXx5+Fw1xT\nfhLFg2tRioMibtfjV8l4z2VN28LoXn2LoAlnA0J6rTHJGUfuPXcfSn8fMSQokblt\npAC+WLjbhIxQO6Reg4eC5Tz/WbZjVijEZEN8Opjh3KX9JL/jWAZCemsIZ0fvK83t\nVm+45N18PEYfzq0hXwfrgQYI1FK3tZs7fimtrAuF09ho2L+E/5WNLlYJcHorAeEu\nLdT2ZvldDtbi3/rwydcCAwEAAaN3MHUwVAYDVR0RBE0wS4IYaHZsLWlkcC1kMDAx\nLmJkYy5iY20uZWR1hi9odHRwczovL2h2bC1pZHAtZDAwMS5iZGMuYmNtLmVkdS9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU71kAUsprVqB8YdTiowM3yaMIzbwwDQYJ\nKoZIhvcNAQEFBQADggEBAGdGZ58nE5xF66dFQjINXF+eFfCyWkFXvIWypLxQYVr+\nXdIfxVN/VYgO+b8Qea4N21YOlxt3m9v/TdQsjF0Ai73SV1j6iPoq+tDGbotpzp1A\nnbq75QodfpBWsWIwqKRqeU/y2gUq5CEB38rdve5hzgyOcTeEosx77s0X22RGHJiO\nAObkVTRvapKDM9P1Z0cSzL+r4ofnrH9wk8pI4Sqky16ay+zvbLvW5GuGeQJz8yaB\nEm4kk7BwhJEPnrqnDKD1d9cdeE1ww3rTAxyZsd0C8zWwg/SRQXp7XcvoNANsIiv+\nkT/uinAHeX+T8m3KqLxJRfjBx4uQkIJOqjGIQSJyM5U="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://fedidp.bcm.edu/idp/shibboleth/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Baylor College of Medicine"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bcm.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Baylor College of Medicine"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://expert.testb.antagning.se/ecs-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://expert.testb.antagning.se/ecs-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://expert.testb.antagning.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://expert.testb.antagning.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://expert.testb.antagning.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://expert.testb.antagning.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://expert.testb.antagning.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://expert.testb.antagning.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "expert.testb.antagning.se/ecs-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://expert.testb.antagning.se/ecs-sp/ecs-sp"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkCgAwIBAgIJAOx7DRVE49sHMA0GCSqGSIb3DQEBBQUAMCsxKTAnBgNV\nBAMTIGV4cGVydC50ZXN0Yi5hbnRhZ25pbmcuc2UvZWNzLXNwMB4XDTExMDkyODEz\nNDQxM1oXDTIxMDkyNTEzNDQxM1owKzEpMCcGA1UEAxMgZXhwZXJ0LnRlc3RiLmFu\ndGFnbmluZy5zZS9lY3Mtc3AwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQDCYpAvcP4rcL/ykBE9V8kSDOlo9Zr+vxgzGQXfs8p2r/TnJJCYPovuVkGVTAfu\njx2k5cEULzrH0/Ulfg08mWIo7oSUC4rwvrgfYmoLiEZ5fYCtsO3Ah+xzRYgar62N\n9fmXqvhkRfXrCHLHrDyzxue1DidfaorYAfAppMeU2qtlWGFy7djoFemRH3ZGBv44\nMLpjVGdrFlFlU4r0gF+CYKxRPe5EsLS97txWOMbfBV3cWIpUFWgHZXz6eDCwxvaH\nPJiL+ITxvy3/7H+dQ7emWkjOCD2B/hMC1cVN+qsJcbtxY1MYtWTPW7EXIfosO+ws\nxQznRPgqU4mp0zmDUQHFhL+9AgMBAAGjfzB9MFwGA1UdEQRVMFOCIGV4cGVydC50\nZXN0Yi5hbnRhZ25pbmcuc2UvZWNzLXNwhi9odHRwczovL2V4cGVydC50ZXN0Yi5h\nbnRhZ25pbmcuc2UvZWNzLXNwL2Vjcy1zcDAdBgNVHQ4EFgQUNq5ePJm8LHbRzbUl\nFrb2PF1iG8gwDQYJKoZIhvcNAQEFBQADggEBAEdCaJ8KkVzQ93hYi5Lf1ODQ9W45\nf0mdQnML3Gkfft2RvmKuS9iUoFz5N/kLATY+60lzHYGLuoqMy2N6urcRbt9Ocsi7\nq9DhXQRpRYGtni5mu8bfPlzpyJunBhcUmUWGQP/smCpS8g4i63CMpXn7VNyN3NJW\nDM76OjYz/sAlKD7IN6ihFwi1Coh3VTcWWvi0bHy8fMlhoNBGwLa+BuDxVwodMmrY\n1wRPvBgfBwmv+Jj8bbd0IUOnw1gHAr4HwlvKQ0ZpjCbDfAu33EkYqc+OizGceP8s\n6719fw5PgpM3v/FwSB0ohRs6M0Ed5TV8EvR29RB9XyGUxx77tOo593X4uRo="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=expert.testb.antagning.se/ecs-sp"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://expert.testb.antagning.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://expert.testb.antagning.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://expert.testb.antagning.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://expert.testb.antagning.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://expert.testb.antagning.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://expert.testb.antagning.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://expert.testb.antagning.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://expert.testb.antagning.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://expert.testb.antagning.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://expert.testb.antagning.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibbolethv3.ac-limoges.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "l.das-ie@ac-limoges.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibbolethv3.ac-limoges.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-04-10T15:29:28Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibbolethv3.ac-limoges.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibbolethv3.ac-limoges.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibbolethv3.ac-limoges.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ac-limoges.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ac-limoges.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnel \u00e9ducation national"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnel \u00e9ducation national"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rectorat Limoges Test shib3"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rectorat Limoges Test shib3"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIVAIJ5CqGf8i3eeJ4z6EwaacBFom5OMA0GCSqGSIb3DQEB\nCwUAMCUxIzAhBgNVBAMMGnNoaWJib2xldGh2My5hYy1saW1vZ2VzLmZyMB4XDTE2\nMDMyMzEwNTI1MFoXDTM2MDMyMzEwNTI1MFowJTEjMCEGA1UEAwwac2hpYmJvbGV0\naHYzLmFjLWxpbW9nZXMuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQDL9vE2es5LkQYmAl8ho3XEiaxNb9V67n5iIxJ7zwIj/vNHGg8juo1U3tZbY70D\nAHUzKDgtIu2f4mO46Rzpkj7LJThVpzlfq8E+PuOt+4HfIBbJEpmWjtIV2Atxr2p4\nihCjolIPgKv3xpjvDuTKCKJmaryTT1lOzrpwnmnSPg9T7IQr5ospQsXDNIjNuub8\nr6/ELxrGoLlrh2gf30SeSK/+smcL7zT3wyyZaT07gCilq20i1KeR/4HiJuAIvY7F\nKrHqzAO/yOoSyqXBOz3rnmwrKUMSKg4nZGJJHeRE/IKjuT+4Sye38nwEGHkVl8Qy\noQU0V0kmc2ZJVjMWiEVLYxptAgMBAAGjezB5MB0GA1UdDgQWBBS/Pu8LmqS18Cbe\nJLPvl4VbUM/TZDBYBgNVHREEUTBPghpzaGliYm9sZXRodjMuYWMtbGltb2dlcy5m\ncoYxaHR0cHM6Ly9zaGliYm9sZXRodjMuYWMtbGltb2dlcy5mci9pZHAvc2hpYmJv\nbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAega66//txkNh0uAvMYos3wZxmYxPFdbr\nlzZIfp4X148v4fqZQJID/4oamnBY5v3t8M2UcskygHMj/2N13CRJf5WGsZQwJ+2Y\nw/HEbFqHJxnm1InpvGV4ICX/WT/rlfkZ3XiDG4/iv9SUxDanGN8QL0BB2sIv/en7\nEmIQZeG+ZQqerErfzzH6QYl6KZpNpvQKYY5u/PskHO9IxKixVf6vbyTIqHZOzhc0\nb4wzF3bsYpMFytKm/s30eB0y4TFS8yJenO3Hs0h/RVXJc5hyzeoFduTIM8/Caroc\nnny0Gc5o3vE90Pel8WhL9uZht7coxWkn7V349ALZl4yKygo5tKbhSQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Rectorat Limoges Test shib3"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ac-limoges.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Rectorat Limoges Test shib3"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibdev.shef.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Babraa"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:h.babraa@sheffield.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Harnomit"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gilbert"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:R.Gilbert@sheffield.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibdev.shef.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-10-14T17:56:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEcjCCA1qgAwIBAgIRAPsd0lQ3zA9qshZ/AtQzPukwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzA5MzAwMDAwMDBaFw0xNjA5MjkyMzU5NTlaMEAxITAfBgNV\n\t\t\t\t\t\tBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEbMBkGA1UEAxMSc2hpYmRldi5z\n\t\t\t\t\t\taGVmLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAq0TlVbOQ\n\t\t\t\t\t\tComVMFNLl1MPD2RkIrJXoaAZlR+ezoCmdec4rv5SadlGQSXFiGsiw9fhjkS/bb1p\n\t\t\t\t\t\tTfqxwdcBGJQ2FSw5Hig+vlVDiPo/BEA0H0ejnRZ7RwYe4q3gKentjhJ9OyI3qBkX\n\t\t\t\t\t\twPMFfX4x+CG0sML/SC26omReQUVLFBJR0tHlIOiKgsbvHPY2ih9FcvWYhckG/VMd\n\t\t\t\t\t\t0VwAhWzue7c6e/f6HASq1V4ovtlgmbbvaWgah01iPHiCzG/Yo9SbGewHObj5GR7K\n\t\t\t\t\t\tFC7ayORvM6tzKoR5JmJ8QX9IYuiH0wuoNFDz9kQtMvZJBjEGYq8hsYgJACC5S8Dt\n\t\t\t\t\t\tvF2JFzmsUM43hwIDAQABo4IBbzCCAWswHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsr\n\t\t\t\t\t\tN1dH6pDjue0wHQYDVR0OBBYEFB+0r9UYq6Ytp9e3hwqSARAVypaSMA4GA1UdDwEB\n\t\t\t\t\t\t/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEF\n\t\t\t\t\t\tBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8E\n\t\t\t\t\t\tMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENB\n\t\t\t\t\t\tLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNz\n\t\t\t\t\t\tLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8v\n\t\t\t\t\t\tb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJzaGliZGV2LnNoZWYuYWMu\n\t\t\t\t\t\tdWswDQYJKoZIhvcNAQEFBQADggEBADAWzwonR3Un1FKUk5dQyOe5ugNt+jqIQ8MX\n\t\t\t\t\t\t9CVYHWFpT76cH6jw9xRPooIigi+qUAMfdDhustmzMHJwapt1cKLCuwbsFXTQS4r4\n\t\t\t\t\t\tb9wWuemt/4hefT+Cv8h+oo4uCxEipD2H20c+I7bS0TcejN9/HeO378rSAAvI40Mo\n\t\t\t\t\t\teq4++mTN6M8HJRBOOtfwU0dpQ/ln6PkOSsXGvDcklLsMaMfM+IE+4vq1cF0jPZ2n\n\t\t\t\t\t\tEB/lCePMbGo0SM+B5SDGNNGksrW1LczHBsCSUBLDxaYEYbldDVeRybFNMc6N7y+x\n\t\t\t\t\t\t0OgEvEcrtOAwP6Jl4BujPGJZBytgiK6zu/8jG9xGys6DVheK5OA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sheffield.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibdev.shef.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibdev.shef.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibdev.shef.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibdev.shef.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibdev.shef.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibdev.shef.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibdev.shef.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibdev.shef.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sheffield.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEcjCCA1qgAwIBAgIRAPsd0lQ3zA9qshZ/AtQzPukwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzA5MzAwMDAwMDBaFw0xNjA5MjkyMzU5NTlaMEAxITAfBgNV\n\t\t\t\t\t\tBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEbMBkGA1UEAxMSc2hpYmRldi5z\n\t\t\t\t\t\taGVmLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAq0TlVbOQ\n\t\t\t\t\t\tComVMFNLl1MPD2RkIrJXoaAZlR+ezoCmdec4rv5SadlGQSXFiGsiw9fhjkS/bb1p\n\t\t\t\t\t\tTfqxwdcBGJQ2FSw5Hig+vlVDiPo/BEA0H0ejnRZ7RwYe4q3gKentjhJ9OyI3qBkX\n\t\t\t\t\t\twPMFfX4x+CG0sML/SC26omReQUVLFBJR0tHlIOiKgsbvHPY2ih9FcvWYhckG/VMd\n\t\t\t\t\t\t0VwAhWzue7c6e/f6HASq1V4ovtlgmbbvaWgah01iPHiCzG/Yo9SbGewHObj5GR7K\n\t\t\t\t\t\tFC7ayORvM6tzKoR5JmJ8QX9IYuiH0wuoNFDz9kQtMvZJBjEGYq8hsYgJACC5S8Dt\n\t\t\t\t\t\tvF2JFzmsUM43hwIDAQABo4IBbzCCAWswHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsr\n\t\t\t\t\t\tN1dH6pDjue0wHQYDVR0OBBYEFB+0r9UYq6Ytp9e3hwqSARAVypaSMA4GA1UdDwEB\n\t\t\t\t\t\t/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEF\n\t\t\t\t\t\tBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8E\n\t\t\t\t\t\tMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENB\n\t\t\t\t\t\tLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNz\n\t\t\t\t\t\tLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8v\n\t\t\t\t\t\tb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJzaGliZGV2LnNoZWYuYWMu\n\t\t\t\t\t\tdWswDQYJKoZIhvcNAQEFBQADggEBADAWzwonR3Un1FKUk5dQyOe5ugNt+jqIQ8MX\n\t\t\t\t\t\t9CVYHWFpT76cH6jw9xRPooIigi+qUAMfdDhustmzMHJwapt1cKLCuwbsFXTQS4r4\n\t\t\t\t\t\tb9wWuemt/4hefT+Cv8h+oo4uCxEipD2H20c+I7bS0TcejN9/HeO378rSAAvI40Mo\n\t\t\t\t\t\teq4++mTN6M8HJRBOOtfwU0dpQ/ln6PkOSsXGvDcklLsMaMfM+IE+4vq1cF0jPZ2n\n\t\t\t\t\t\tEB/lCePMbGo0SM+B5SDGNNGksrW1LczHBsCSUBLDxaYEYbldDVeRybFNMc6N7y+x\n\t\t\t\t\t\t0OgEvEcrtOAwP6Jl4BujPGJZBytgiK6zu/8jG9xGys6DVheK5OA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Sheffield TEST IDP (DO NOT USE!)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.shef.ac.uk/cics/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Sheffield"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://durin.sau.kau.se/simplesaml/module.php/saml/sp/metadata.php/default-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webbteknik@kau.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT-Avdelningen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://durin.sau.kau.se/simplesaml/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://durin.sau.kau.se/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Dev server f\u00f6r www.kau.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Dev server for www.kau.se"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Logga in i Kau Drupal 8 utvecklingsserver"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Login to Kau Drupal 8 development server"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://durin.sau.kau.se/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://durin.sau.kau.se/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://durin.sau.kau.se/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://durin.sau.kau.se/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.publicinformationonline.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cooper"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:barrie@nouver.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Barrie"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cooper"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:barrie@nouver.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Barrie"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.publicinformationonline.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-10-27T10:52:04Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Public Information Online"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dandybooksellers.com/acatalog/About_us.html"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Dandy Booksellers Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.publicinformationonline.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.publicinformationonline.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.publicinformationonline.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.publicinformationonline.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.publicinformationonline.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Collection of Parliamentary papers from the UK & Scottish Parliaments, Northern Ireland Assembly & Scottish Government."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.publicinformationonline.com/images/piologo_350_98.png",
                    "height": "98",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Public Information Online"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.publicinformationonline.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.publicinformationonline.com/Shibboleth.sso/WAYF/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEbDCCA1SgAwIBAgIJAKyY0ChRtdbhMA0GCSqGSIb3DQEBBQUAMIG2MQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEQMA4GA1UECAwHRW5nbGFuZDEPMA0GA1UEBwwGTG9uZG9uMRowGAYD\n\t\t\t\t\t\tVQQKDBFEYW5keSBCb29rc2VsbGVyczEaMBgGA1UECwwRRGFuZHkgQm9va3NlbGxl\n\t\t\t\t\t\tcnMxKDAmBgNVBAMMH3d3dy5wdWJsaWNpbmZvcm1hdGlvbm9ubGluZS5jb20xIjAg\n\t\t\t\t\t\tBgkqhkiG9w0BCQEWE2JhcnJpZUBtb2RlemVyby5uZXQwHhcNMTEwNDE1MTEyNjUw\n\t\t\t\t\t\tWhcNMzEwNDEwMTEyNjUwWjCBtjELMAkGA1UEBhMCR0IxEDAOBgNVBAgMB0VuZ2xh\n\t\t\t\t\t\tbmQxDzANBgNVBAcMBkxvbmRvbjEaMBgGA1UECgwRRGFuZHkgQm9va3NlbGxlcnMx\n\t\t\t\t\t\tGjAYBgNVBAsMEURhbmR5IEJvb2tzZWxsZXJzMSgwJgYDVQQDDB93d3cucHVibGlj\n\t\t\t\t\t\taW5mb3JtYXRpb25vbmxpbmUuY29tMSIwIAYJKoZIhvcNAQkBFhNiYXJyaWVAbW9k\n\t\t\t\t\t\tZXplcm8ubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA3dZdcWh2\n\t\t\t\t\t\tftVD3ymAbP2E+EgXwTu1nmYBzby4KA73men52OPI29lOSxloCZN/JMfJaOe49YI9\n\t\t\t\t\t\tQcdC484zzlCbOp8gkcdYTvjtatfA16j66IAiJHNW+BMPv9BAw9OO3iwZLlnGg5yt\n\t\t\t\t\t\tX7x4U4CQbpxr2s1KYlCqhuy1VEDem2I8C/B+TjKlvpoWuNIGuJ7p7J2CL5CAm+ao\n\t\t\t\t\t\tiQp/uQ7EYI2nLat0kq/6aXcOtVCZXFVBDYHEAytcUbMTkWKFKxohR6JtaD3p2RK2\n\t\t\t\t\t\t8OysXG1DGvi0A71Nhr5Lhw9GWM2IbayLv9u2bGA6aYam7dEhNA05/g5TqptgS69T\n\t\t\t\t\t\t0g9AwTg7Z2ku9QIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1P\n\t\t\t\t\t\tcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUkgXL/CZUCTeG\n\t\t\t\t\t\tEa4CYrPGxPRUIfIwHwYDVR0jBBgwFoAUkgXL/CZUCTeGEa4CYrPGxPRUIfIwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBAEbijLDE6hiyM6FE3XsojBOHJsgfAdR91aWZwIAEHZy8\n\t\t\t\t\t\tGZOU//mxolb+Jt9T35LQWMhGBqXEIOIQzXaSlWSU8GwSt8YkdpGkyXnRli/vC0mD\n\t\t\t\t\t\tOhMNkMc7EqndNiAKVlYXhBTH64fahWmwMJY7R3GHCP3fE19Dy4p8dQ/gRVpkgWVw\n\t\t\t\t\t\tdChnmk/ZIC4cagvNDe3gN9lxQCUODoZKgbAdI0PVJ/8TdxgTbT7G5wXo4sPyVXqE\n\t\t\t\t\t\tB51xhsr+EtVwsr9Ea/Q+uJUpwZIQY+s0LYY8rh7OmFzGdOdtfSG15nPJUvxh6RZV\n\t\t\t\t\t\tMVwZJsRD1V5Hwsyr2D4yEVTkAQxUN1ZFs9jYhUuckd0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.publicinformationonline.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.publicinformationonline.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.publicinformationonline.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.publicinformationonline.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.publicinformationonline.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.publicinformationonline.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.publicinformationonline.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.publicinformationonline.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.publicinformationonline.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.publicinformationonline.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idptl.telecom-lille.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tovo Rakotonavalona"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tovo.rakotonavalona@telecom-lille.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Martine Sion"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "martine.sion@telecom-lille.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idptl.telecom-lille.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-02-25T16:05:52Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idptl.telecom-lille.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idptl.telecom-lille.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idptl.telecom-lille.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "telecom-lille.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.telecom-lille.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Teachers, Researchers and students."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Enseignants, Chercheurs et Etudiants"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Telecom Lille"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "T\u00e9l\u00e9com Lille"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUdOTTpXbEHWneZrmj++dQu587hqYwDQYJKoZIhvcNAQEF\nBQAwITEfMB0GA1UEAxMWaWRwdGwudGVsZWNvbS1saWxsZS5mcjAeFw0xNDAyMjcw\nODMwMDJaFw0zNDAyMjcwODMwMDJaMCExHzAdBgNVBAMTFmlkcHRsLnRlbGVjb20t\nbGlsbGUuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCreLILg3MJ\nV8fODgvBqTtrkWJjc50DdyouRaBAxTojOPpydqeVP1QATqE+Wf0LenegWcmQGuui\noJU7VJ/Mn70qBzkTS17qKeAFxp+No7+7ehk65g4lUBxsWtOKWOysg2gJmdQsbz7l\nAF/Hn1+SprxyRe2BJ2s9o8n37sdie6N8zoHCS3e82PDi00yoFuXQ95PxbPpad5Cs\n9EOvAzlI3Aq3t7YU8RBvKePSj3I2sLrkMJZPc4VFMao06QnDP6Pa2GXQl2hZ76KE\nsEN4eGqtSkCbWY/k/QDX9NN8XU7sZSCFpYBzwnm+cCYrhB992+qciE/GKmzsM6tr\nRUKGaeupSS2/AgMBAAGjczBxMFAGA1UdEQRJMEeCFmlkcHRsLnRlbGVjb20tbGls\nbGUuZnKGLWh0dHBzOi8vaWRwdGwudGVsZWNvbS1saWxsZS5mci9pZHAvc2hpYmJv\nbGV0aDAdBgNVHQ4EFgQUt9JZDztpt1bjXPn0mJUj2aErjFowDQYJKoZIhvcNAQEF\nBQADggEBAH8xFBva7Sb5R8vIOyBlNQ57tcEXnsKClZEcYuiL5k3eu79BTH/xRqmx\n5WwQVOAKFiBUjFrcpEJTHGsAHcL1JWaxMIq0G/DW+GufAicNOUezx86ceewRIxJG\nRLzYX4oPKG10r+bUx6/K4CbzojgxysnoZNn9JKqaCH0BBg2Ddk9+0a3k7kML3tD/\nHTHjakbY9quIy8peLhmpjkl85T4mX53V2E90RzOPUhyk1GUzAHiN+O1YBP0n+PEr\n3sd4/75bHQK+6Ec/SBCJA86j/zbK8IPdSqZOWs/zbKYA0Qdava8bErtA5+Qje91C\nqdWukaTYTGYIy6blrFvq4vQQgLPbDGY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "T\u00e9l\u00e9com Lille"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.telecom-lille.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "T\u00e9l\u00e9com Lille"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayfa.efif.dk/zbc/module.php/saml/sp",
    {
      "entity_id": "https://birk.wayf.dk/birk.php/wayfa.efif.dk/zbc/module.php/saml/sp",
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayfa.efif.dk/zbc/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "zbc.dk"
              },
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Zealand Business College"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Zealand Business College"
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Zealand Business College"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Zealand Business College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4jCCAcoCAQcwDQYJKoZIhvcNAQELBQAwNzE1MDMGA1UEAwwsaHR0cHM6Ly93\nYXlmYS5lZmlmLmRrL3piYy9tb2R1bGUucGhwL3NhbWwvc3AwHhcNMTUwMTAxMDAw\nMDAwWhcNMjUxMjMxMjM1OTU5WjA3MTUwMwYDVQQDDCxodHRwczovL3dheWZhLmVm\naWYuZGsvemJjL21vZHVsZS5waHAvc2FtbC9zcDCCASIwDQYJKoZIhvcNAQEBBQAD\nggEPADCCAQoCggEBAMeIDApqEFO4jhn4gnWuA54SIILLdtH1Ah7cGkKx6MUJTmtL\nORYA2pW5zU8N+nQl0hmGs9eyYMlAyaJ08IY8gNAqj5uT5p/f4RQVL8j/7fmxIFfa\n9/6HUMe9lX2OzOealJWOnsdn9ag9YHKRYEk7QA5WbMHnOVqqRLfonvr7DF6vB2m4\nTFWdhI13vdL4DJP8Rn61cA77qVDwUv9gyUmdSRJpKotIcXLTUPaoE2ZhHAGkJLr9\n1RnLGLS3mPyCEpQPgEc5lVq+frknrZwl1eI5wxHJQAinnsZdCsvrcq2uMhxd12r4\nJnJnm3fsR1Q4jPjaOgVzLvcwU6e3KeUoS87DUEkCAwEAATANBgkqhkiG9w0BAQsF\nAAOCAQEAG88v39vzM+tQHBI5Yl3rE5I/InzDV6er8gJDQ6VO/n8xjV12AwKAgsdp\nlTPv1NbaphRMKzQh2mzFLg5oDrI6CxejA4xpcaRol1VkrZIjXb/uAdYbhUpopMwj\n2Pniy+T4zN4eG0v5Z1xtahPiLjhlNYiUJUb6yat6V4bO2BoBeLSkO60h4smuOlJs\nPYRqaZvaO1ocR6cZuGaWYqZVRIDnu5qVHEQpQQTEh/4am12aauELgYwgHG1G0ldf\npMlt8O2Lsy7KP3HJE7eAvCBTD57aBfP4tfqD9RurBSW+EsBP+AY930jxJYop2Xdi\n7Brk8LWiLkvExq3IH5VpXIbpmtd+7Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Zealand Business College"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Zealand Business College"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.zbc.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.zbc.dk/uddannelser/videregaaende/international-programmes.aspx"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Zealand Business College"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Zealand Business College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2011-02-16T15:27:33Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute_value": [
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "kalmar"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "denmark"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "iceland"
              }
            ],
            "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
            "name": "tags",
            "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      }
    }
  ],
  [
    "https://www.knodium.com/Shibboleth.sso/Metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webmaster@knodium.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Web Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webmaster@knodium.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Web Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.knodium.com/Shibboleth.sso/Metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-09-11T08:57:13Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Knodium"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.knodium.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Knodium Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.knodium.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.knodium.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.knodium.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.knodium.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.knodium.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.knodium.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.knodium.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Knodium is an online platform for collaboration."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.knodium.com/images/logo-shib.png",
                    "height": "158",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Knodium"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAMLknMjt03SjMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\n\t\t\t\t\t\tBAMTD3d3dy5rbm9kaXVtLmNvbTAeFw0xMjA5MTAxNTI2NTZaFw0yMjA5MDgxNTI2\n\t\t\t\t\t\tNTZaMBoxGDAWBgNVBAMTD3d3dy5rbm9kaXVtLmNvbTCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBAMS5B0GMXiaYkvtJDFNsrRNMfFF5WZOTdOdFh4VK2G1C\n\t\t\t\t\t\tc4Jo+WInPbjfB+l3gNji634Qc06ke0A74GyRTf19pIcKpmB6pyEtjt/0vgInT3Ax\n\t\t\t\t\t\tZI38HVgCk1WHwpg5LLzRI4FkzpIIX/SfB7KYB6WDA0AXbE8id2KXaxuCNrGYvoU6\n\t\t\t\t\t\torz7Gt+FERDUooNli1Z97ZQ6o6MogAeHizRTpWhWVqIVLKxvAZ42+OXw2OwGzOeL\n\t\t\t\t\t\tOkefcJ5l/AwJbmEM+19yqdSB4e6VqF+ApsR/NbJaE5kz7GhvitK0FWkrP31bVj5t\n\t\t\t\t\t\t0pFmyFwYRohge0FFw0wX/vojPZqqBjOM5HafUmDB4PUCAwEAAaM9MDswGgYDVR0R\n\t\t\t\t\t\tBBMwEYIPd3d3Lmtub2RpdW0uY29tMB0GA1UdDgQWBBQysHs0AHbWoM4U7GlNVirq\n\t\t\t\t\t\t6w1N4DANBgkqhkiG9w0BAQUFAAOCAQEAY9843vk3HlJssWlGnq5djjjzOeMZ6qPa\n\t\t\t\t\t\tGXNZBZGi9LI3P4xAkW0fCnUygcb5MZaHdB+RuINEdXj+npITszfLtnj2m4BCq2IN\n\t\t\t\t\t\tevmRUQRc7F27b9aoUuhYl0q6/Z9MFOjdjzQb6LT1duCDPq83kFp0gS57fqQP97F0\n\t\t\t\t\t\t8Hbzw5ZdLWALzsDuxU9FGRU5gdZNDmXkzymluKMZRchLuJrJhsRDPb34xmcH7RKF\n\t\t\t\t\t\tMsv4N8MBOk9nESf3jQTPgkCvZee2t6h9xijoRP+IH5VD3hfq+H3lNKX7w7DkRqlR\n\t\t\t\t\t\tdB55/ggB6okN6t5L8d+FUbKU3qI8VQmR8V4/NJ/F0EFmLzEklMUxsw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.knodium.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.knodium.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.knodium.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.knodium.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.knodium.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.knodium.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Knodium"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Knodium is an online platform for collaboration."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonTargetedID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "swissEduPersonUniqueID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:switch.ch:attribute-def:swissEduPersonUniqueID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrimaryAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrimaryAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrimaryAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.5",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonEntitlement",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganizationType",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduCourseMember",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.6.1.2",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduCourseOffering",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.6.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "organizationName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAssurance",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.11",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAssurance",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonAssurance",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "employeeType",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.2.840.113556.1.2.613",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduOrgLegalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.2.1.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:incommon:stanford.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth-team@lists.stanford.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:stanford.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.stanford.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.stanford.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDtTCCAp2gAwIBAgIJAPmWpLuXBmD6MA0GCSqGSIb3DQEBCwUAMHExCzAJBgNV\nBAYTAlVTMRMwEQYDVQQIDApDYWxpZm9ybmlhMREwDwYDVQQHDAhTdGFuZm9yZDEf\nMB0GA1UECgwWQWRtaW5pc3RyYXRpdmUgU3lzdGVtczEZMBcGA1UEAwwQaWRwLnN0\nYW5mb3JkLmVkdTAeFw0xNDEyMDEyMDUxMzZaFw0yNDExMzAyMDUxMzZaMHExCzAJ\nBgNVBAYTAlVTMRMwEQYDVQQIDApDYWxpZm9ybmlhMREwDwYDVQQHDAhTdGFuZm9y\nZDEfMB0GA1UECgwWQWRtaW5pc3RyYXRpdmUgU3lzdGVtczEZMBcGA1UEAwwQaWRw\nLnN0YW5mb3JkLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL+R\nPOrLUT4Pv/pJ4coD3lwOVhSJ5wqIVPo3D94SBaTH/zFOVJM5uIzq9bWwXqbQeuyT\nryuZc1Obv7aK4/vnOuEh6bQfW15ZEtqRfI0fl873aXqWYItxM69xhgw33BavFat+\nLLUbalvqfjLZvW0Qp7wQMO88RikcFbrS9qvILsJZhcemyH+UZ1oyQKg0OwLd2fpf\nIqs9Lksh9UiwvxH2/S8gYIZ/+p/Tyc2NluTQVRO53wmoPVv9edeH7ucaGi1OqH8q\nEDwTzd6lVKLjQHxBI3105Wmj5YZuiv8mWj4r50huCGfuw1+XgQVw2gwvDmzTupOA\nJfFRry8bDZp/lGUVZP0CAwEAAaNQME4wHQYDVR0OBBYEFDl+vvpPHz2jozJ83nTa\nXOBUWi7TMB8GA1UdIwQYMBaAFDl+vvpPHz2jozJ83nTaXOBUWi7TMAwGA1UdEwQF\nMAMBAf8wDQYJKoZIhvcNAQELBQADggEBAHVPjloOPKFxhzFH6BE55zRcxz/AKlHG\nf4SXLOEJ5QijZ10qdaB1jVgo5Dva8cxZSk+Y9iMCqgYgWLUJP8WqFsH0mqfrJ7Es\ndW+BdpecKCTOUmHlImjPp81W/hVDJSZXIe+wwzp77Rt+Bdhuhec5ZVYoE/3ug2PA\npFlfFNxtxYugIhRIcDyUdLUTMoWXmhKgVHbjNtUL9BGfJHkIIAtWSZZ4bsheOGUY\nIbtwXER+ihBU48YYjdAVC9bxdbR0GAJY5uLqG6k0FgEV/7vVHqFMqp31qJme3/ps\nSFqKGJNZvMvXzp89VM70lI2VewL/GVdm6c31p7PVmCfPJXdHmCOVVsY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDnzCCAoegAwIBAgIJAJl9YtyaxKsZMA0GCSqGSIb3DQEBBQUAMGYxCzAJBgNV\nBAYTAlVTMRMwEQYDVQQIDApDYWxpZm9ybmlhMREwDwYDVQQHDAhTdGFuZm9yZDEU\nMBIGA1UECgwLSVQgU2VydmljZXMxGTAXBgNVBAMMEGlkcC5zdGFuZm9yZC5lZHUw\nHhcNMTMwNDEwMTYzMTAwWhcNMzMwNDEwMTYzMTAwWjBmMQswCQYDVQQGEwJVUzET\nMBEGA1UECAwKQ2FsaWZvcm5pYTERMA8GA1UEBwwIU3RhbmZvcmQxFDASBgNVBAoM\nC0lUIFNlcnZpY2VzMRkwFwYDVQQDDBBpZHAuc3RhbmZvcmQuZWR1MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAm6466Bd6mDwNOR2qZZy1WRZdjyrG2/xW\namGEMekg38fyuoSCIiMcgeA9UIUbiRCpAN87yI9HPcgDEdrmCK3Ena3J2MdFZbRE\nb6fdRt76K+0FSl/CnyW9xaIlAhldXKbsgUDei3Xf/9P8H9Dxkk+PWd9Ha1RZ9Viz\ndOLe2S2iDKc1CJg2kdGQTuQu6mUEGrB9WJmrLHJS7GkGDqy96owFjRL/p0i9KBdR\nkgWG+GFHWkxzeNQ99yrQra3+C9FQXa/xLCdOY+BGOsAG7ej4094NZXRNTyXui4jR\nWCm2GVdIVl7YB9++XSntS7zQEJ9QBnC1D4bS0tljMfdOGAvdUuJY7QIDAQABo1Aw\nTjAdBgNVHQ4EFgQUJk4zcQ4JupEcAp0gEkob4YRDkckwHwYDVR0jBBgwFoAUJk4z\ncQ4JupEcAp0gEkob4YRDkckwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOC\nAQEAKvf9AO4+osJZOmkv6AVhNPm6JKoBSm9dr9NhwpSS5fpro6PrIjDZDLh/L5d/\n+CQTDzuVsw3xwDtlm89lrzbqw5rSa2+ghJk79ijysSC0zOcD6ka9c17zauCNmFx9\nlj9iddUw3aYHQcQRktWL8pvI2WCY6lTU+ouNM+owStya7umZ9rBdjg/fQerzaQxF\nT0yV3tYEonL3hXMzSqZxWirwsyZ0TnhWJsgEnqqG9tCFAcFu2p+glwXn1WL2GCRv\nBfuJMPzg7ZB419AEoeYnLktqAWiU+ISnVfbwFOJ+OM/O7VQOeHDm2AeYcwo12CAc\n4GC9KWTs3QtS3GREPKYDlHRNxQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stanford.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.stanford.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.stanford.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.stanford.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.stanford.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.stanford.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.stanford.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stanford.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://shibboleth.stanford.edu/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Stanford University's identity provider uses Stanford WebAuth to provide single sign-on functionality"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.stanford.edu/logo.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Stanford University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDtTCCAp2gAwIBAgIJAPmWpLuXBmD6MA0GCSqGSIb3DQEBCwUAMHExCzAJBgNV\nBAYTAlVTMRMwEQYDVQQIDApDYWxpZm9ybmlhMREwDwYDVQQHDAhTdGFuZm9yZDEf\nMB0GA1UECgwWQWRtaW5pc3RyYXRpdmUgU3lzdGVtczEZMBcGA1UEAwwQaWRwLnN0\nYW5mb3JkLmVkdTAeFw0xNDEyMDEyMDUxMzZaFw0yNDExMzAyMDUxMzZaMHExCzAJ\nBgNVBAYTAlVTMRMwEQYDVQQIDApDYWxpZm9ybmlhMREwDwYDVQQHDAhTdGFuZm9y\nZDEfMB0GA1UECgwWQWRtaW5pc3RyYXRpdmUgU3lzdGVtczEZMBcGA1UEAwwQaWRw\nLnN0YW5mb3JkLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL+R\nPOrLUT4Pv/pJ4coD3lwOVhSJ5wqIVPo3D94SBaTH/zFOVJM5uIzq9bWwXqbQeuyT\nryuZc1Obv7aK4/vnOuEh6bQfW15ZEtqRfI0fl873aXqWYItxM69xhgw33BavFat+\nLLUbalvqfjLZvW0Qp7wQMO88RikcFbrS9qvILsJZhcemyH+UZ1oyQKg0OwLd2fpf\nIqs9Lksh9UiwvxH2/S8gYIZ/+p/Tyc2NluTQVRO53wmoPVv9edeH7ucaGi1OqH8q\nEDwTzd6lVKLjQHxBI3105Wmj5YZuiv8mWj4r50huCGfuw1+XgQVw2gwvDmzTupOA\nJfFRry8bDZp/lGUVZP0CAwEAAaNQME4wHQYDVR0OBBYEFDl+vvpPHz2jozJ83nTa\nXOBUWi7TMB8GA1UdIwQYMBaAFDl+vvpPHz2jozJ83nTaXOBUWi7TMAwGA1UdEwQF\nMAMBAf8wDQYJKoZIhvcNAQELBQADggEBAHVPjloOPKFxhzFH6BE55zRcxz/AKlHG\nf4SXLOEJ5QijZ10qdaB1jVgo5Dva8cxZSk+Y9iMCqgYgWLUJP8WqFsH0mqfrJ7Es\ndW+BdpecKCTOUmHlImjPp81W/hVDJSZXIe+wwzp77Rt+Bdhuhec5ZVYoE/3ug2PA\npFlfFNxtxYugIhRIcDyUdLUTMoWXmhKgVHbjNtUL9BGfJHkIIAtWSZZ4bsheOGUY\nIbtwXER+ihBU48YYjdAVC9bxdbR0GAJY5uLqG6k0FgEV/7vVHqFMqp31qJme3/ps\nSFqKGJNZvMvXzp89VM70lI2VewL/GVdm6c31p7PVmCfPJXdHmCOVVsY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDnzCCAoegAwIBAgIJAJl9YtyaxKsZMA0GCSqGSIb3DQEBBQUAMGYxCzAJBgNV\nBAYTAlVTMRMwEQYDVQQIDApDYWxpZm9ybmlhMREwDwYDVQQHDAhTdGFuZm9yZDEU\nMBIGA1UECgwLSVQgU2VydmljZXMxGTAXBgNVBAMMEGlkcC5zdGFuZm9yZC5lZHUw\nHhcNMTMwNDEwMTYzMTAwWhcNMzMwNDEwMTYzMTAwWjBmMQswCQYDVQQGEwJVUzET\nMBEGA1UECAwKQ2FsaWZvcm5pYTERMA8GA1UEBwwIU3RhbmZvcmQxFDASBgNVBAoM\nC0lUIFNlcnZpY2VzMRkwFwYDVQQDDBBpZHAuc3RhbmZvcmQuZWR1MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAm6466Bd6mDwNOR2qZZy1WRZdjyrG2/xW\namGEMekg38fyuoSCIiMcgeA9UIUbiRCpAN87yI9HPcgDEdrmCK3Ena3J2MdFZbRE\nb6fdRt76K+0FSl/CnyW9xaIlAhldXKbsgUDei3Xf/9P8H9Dxkk+PWd9Ha1RZ9Viz\ndOLe2S2iDKc1CJg2kdGQTuQu6mUEGrB9WJmrLHJS7GkGDqy96owFjRL/p0i9KBdR\nkgWG+GFHWkxzeNQ99yrQra3+C9FQXa/xLCdOY+BGOsAG7ej4094NZXRNTyXui4jR\nWCm2GVdIVl7YB9++XSntS7zQEJ9QBnC1D4bS0tljMfdOGAvdUuJY7QIDAQABo1Aw\nTjAdBgNVHQ4EFgQUJk4zcQ4JupEcAp0gEkob4YRDkckwHwYDVR0jBBgwFoAUJk4z\ncQ4JupEcAp0gEkob4YRDkckwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOC\nAQEAKvf9AO4+osJZOmkv6AVhNPm6JKoBSm9dr9NhwpSS5fpro6PrIjDZDLh/L5d/\n+CQTDzuVsw3xwDtlm89lrzbqw5rSa2+ghJk79ijysSC0zOcD6ka9c17zauCNmFx9\nlj9iddUw3aYHQcQRktWL8pvI2WCY6lTU+ouNM+owStya7umZ9rBdjg/fQerzaQxF\nT0yV3tYEonL3hXMzSqZxWirwsyZ0TnhWJsgEnqqG9tCFAcFu2p+glwXn1WL2GCRv\nBfuJMPzg7ZB419AEoeYnLktqAWiU+ISnVfbwFOJ+OM/O7VQOeHDm2AeYcwo12CAc\n4GC9KWTs3QtS3GREPKYDlHRNxQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Stanford University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.stanford.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Stanford University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://qmulfed.simitive.com",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Latham"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:adrian.latham@simitive.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adrian"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Latham"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:adrian.latham@simitive.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adrian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://qmulfed.simitive.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-05-02T09:22:35Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "QMUL Simitive Test"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.simitive.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Simitive Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://qmulfed.simitive.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://qmulfed.simitive.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://qmulfed.simitive.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://qmulfed.simitive.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://qmulfed.simitive.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "authn_requests_signed": "1",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://qmulfed.simitive.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://qmulfed.simitive.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOTCCAiGgAwIBAgIJAPVp/A+epmGvMA0GCSqGSIb3DQEBBQUAMCcxJTAjBgNV\n\t\t\t\t\t\tBAMTHGh0dHBzOi8vcW11bGZlZC5zaW1pdGl2ZS5jb20wHhcNMTQwNDIzMTYyNTA5\n\t\t\t\t\t\tWhcNMjQwNDIwMTYyNTA5WjAnMSUwIwYDVQQDExxodHRwczovL3FtdWxmZWQuc2lt\n\t\t\t\t\t\taXRpdmUuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2LEXCwL6\n\t\t\t\t\t\tpyGXQKURhMSkMPWdAgyCTROyTahJM7C27+wAupRevc91r7c9cEk+ygo5Gf8meSxK\n\t\t\t\t\t\tNEMuZ2eM6Nc1eGMkauYrpmZLjfZW8CDrMiKjI+RPFVvvmVahgXAEfHzJiH5tpayv\n\t\t\t\t\t\tyNafBmRw5/OgwcvTNc8hg/tKF5GNvAd3B+KNdzIW4cAxiSnYw/oDMYNW6HSEGdID\n\t\t\t\t\t\thqWTZKBYJxcAZs4GKCNaqPsmobTK8yGvL4tGpyDwcM0iTn8YQqQQMPf25/qv/kDR\n\t\t\t\t\t\tROdmi/CyV/5EVZhKR/Dt8+VaOWgfAlnbdRGULf9Asuxjhr46wP9VmqpqFX6bbp2z\n\t\t\t\t\t\toLxzvmeJHYi8iwIDAQABo2gwZjBFBgNVHREEPjA8ghxodHRwczovL3FtdWxmZWQu\n\t\t\t\t\t\tc2ltaXRpdmUuY29thhxodHRwczovL3FtdWxmZWQuc2ltaXRpdmUuY29tMB0GA1Ud\n\t\t\t\t\t\tDgQWBBR77Asd02wLNO71ILyxI+RJ0/M0PjANBgkqhkiG9w0BAQUFAAOCAQEAyO6o\n\t\t\t\t\t\t3q+pL3igo8+wZfI2+p+4jxYfXs2iWaRl4pKTNED0rXnE30XIK5cYJrU5YIkfdNTB\n\t\t\t\t\t\tmYhaeWXt8McmkfDQxayIFSIFaLzBV5e/voE6sNcysuThCWkAEyLNP3wVsFlAVCcy\n\t\t\t\t\t\tPE8vdP8/SofL5jazCRqi2/LWq8gYdFoWJrkd0hhmXUL87WDgLKf8atdm+xQ0Ew+8\n\t\t\t\t\t\t3+xNT16PluCwsfg+6AU3NapfmTsG8iwxyOkQ6jgqAVS/wboDTOewKYbpjqnLNI3T\n\t\t\t\t\t\tE1XHMX2aZGJ2VM2bMhMJKKI4i2TxHU+qos3+NPRAJKbq7n7MwkKOK5olEp3xOr0z\n\t\t\t\t\t\tVsmquYm0Rppl3nzMmg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://qmulfed.simitive.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://qmulfed.simitive.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://qmulfed.simitive.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://qmulfed.simitive.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://qmulfed.simitive.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://qmulfed.simitive.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol"
        }
      ]
    }
  ],
  [
    "https://idp.shibboleth.qmul.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Services helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Evans"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.d.t.evans@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jordaan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steven.t.s.jordaan@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tom"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.shibboleth.qmul.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-09-13T20:40:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIHnTCCBoWgAwIBAgIQYq4ht/OC7BIxhYZg2e2WcDANBgkqhkiG9w0BAQsFADCB\n\t\t\t\t\t\tkjELMAkGA1UEBhMCR0IxGzAZBgNVBAgTEkdyZWF0ZXIgTWFuY2hlc3RlcjEQMA4G\n\t\t\t\t\t\tA1UEBxMHU2FsZm9yZDEaMBgGA1UEChMRQ09NT0RPIENBIExpbWl0ZWQxODA2BgNV\n\t\t\t\t\t\tBAMTL0NPTU9ETyBSU0EgRXh0ZW5kZWQgVmFsaWRhdGlvbiBTZWN1cmUgU2VydmVy\n\t\t\t\t\t\tIENBMB4XDTE1MDIxMzAwMDAwMFoXDTE3MDIxMjIzNTk1OVowggEoMREwDwYDVQQF\n\t\t\t\t\t\tEwhSQzAwMDcxMDETMBEGCysGAQQBgjc8AgEDEwJHQjEdMBsGA1UEDxMUUHJpdmF0\n\t\t\t\t\t\tZSBPcmdhbml6YXRpb24xCzAJBgNVBAYTAkdCMQ8wDQYDVQQREwZFMSA0TlMxDzAN\n\t\t\t\t\t\tBgNVBAgTBkxvbmRvbjEPMA0GA1UEBxMGTG9uZG9uMRYwFAYDVQQJEw1NaWxlIEVu\n\t\t\t\t\t\tZCBSb2FkMSgwJgYDVQQKEx9RdWVlbiBNYXJ5IFVuaXZlcnNpdHkgT2YgTG9uZG9u\n\t\t\t\t\t\tMRQwEgYDVQQLEwtJVCBTZXJ2aWNlczEjMCEGA1UECxMaQ09NT0RPIEVWIE11bHRp\n\t\t\t\t\t\tLURvbWFpbiBTU0wxIjAgBgNVBAMTGWlkcC5zaGliYm9sZXRoLnFtdWwuYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDh5MiNTEObfWslVrafeqmP\n\t\t\t\t\t\t1UD+0U4uUYuDMpX2OFiWRvPVdoIhNJK8InLjRGzM16rArF1VHTvw9L2hg+Mjksql\n\t\t\t\t\t\t1yaG0FuECmTUk9Jn1rgMo1RVmc036lp5eLAZAxOzj5T3pyiRKqs+QSMHWgwfg6HD\n\t\t\t\t\t\tU8YaldlqQM9bWtluzSQmx6df1m8DyolCnOBUTR35YwaVuQp9gnafy7i9smvSWhMM\n\t\t\t\t\t\t9j46BEEYGYJjm0REghRO/3WNRiKaIwiFn4utCGT9/oCu3Nl7yab8HQsAId39UuG9\n\t\t\t\t\t\tRE2FRJBTe7MuiQ13XllUwJGjCNrqgNldE4UrXHy0hjmFMlhYjY7cH2lCafYfuYTb\n\t\t\t\t\t\tAgMBAAGjggNUMIIDUDAfBgNVHSMEGDAWgBQ52v/KKBSKqHQTCLnkDqnS+n6daTAd\n\t\t\t\t\t\tBgNVHQ4EFgQUAlQbTUGQ8qFvPEcR9GoS6dzwfXswDgYDVR0PAQH/BAQDAgWgMAwG\n\t\t\t\t\t\tA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMEYGA1Ud\n\t\t\t\t\t\tIAQ/MD0wOwYMKwYBBAGyMQECAQUBMCswKQYIKwYBBQUHAgEWHWh0dHBzOi8vc2Vj\n\t\t\t\t\t\tdXJlLmNvbW9kby5jb20vQ1BTMFYGA1UdHwRPME0wS6BJoEeGRWh0dHA6Ly9jcmwu\n\t\t\t\t\t\tY29tb2RvY2EuY29tL0NPTU9ET1JTQUV4dGVuZGVkVmFsaWRhdGlvblNlY3VyZVNl\n\t\t\t\t\t\tcnZlckNBLmNybDCBhwYIKwYBBQUHAQEEezB5MFEGCCsGAQUFBzAChkVodHRwOi8v\n\t\t\t\t\t\tY3J0LmNvbW9kb2NhLmNvbS9DT01PRE9SU0FFeHRlbmRlZFZhbGlkYXRpb25TZWN1\n\t\t\t\t\t\tcmVTZXJ2ZXJDQS5jcnQwJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmNvbW9kb2Nh\n\t\t\t\t\t\tLmNvbTAkBgNVHREEHTAbghlpZHAuc2hpYmJvbGV0aC5xbXVsLmFjLnVrMIIBfwYK\n\t\t\t\t\t\tKwYBBAHWeQIEAgSCAW8EggFrAWkAdgBo9pj4H2SCvjqM7rkoHUz8cVFdZ5PURNEK\n\t\t\t\t\t\tZ6y7T0/7xAAAAUuDfKLAAAAEAwBHMEUCIAagnCAKc1skTr2wfGwSOzezQJViqYmn\n\t\t\t\t\t\tgN5+n6ek/kftAiEAhtqDNmjQM9DZWAxkkOpgHjX4vsM8Cah1O26zwqLbXNQAdwCk\n\t\t\t\t\t\tuQmQtBhYFIe7E6LMZ3AKPDWYBPkb37jjd80OyA3cEAAAAUuDfKLHAAAEAwBIMEYC\n\t\t\t\t\t\tIQCJANeMiBQF69/wczNISERwZ/4FVTHON1fD4BKgv/AGEwIhAI7zhnDGVs8p1Ccu\n\t\t\t\t\t\tOcq8ovoSLnF5KdVJ2n+Jf1PtTLrOAHYAVhQGmi/XwuzT9eG9RLI+x0Z2ubyZEVzA\n\t\t\t\t\t\t75SYVdaJ0N0AAAFLg3yhXgAABAMARzBFAiA66Y6PGzOrXZfGz56TSNaANr7yO/c7\n\t\t\t\t\t\t3r778k2gFOtwAAIhAJqdTx8fzxsbvpUvriFZCGVksMhdcIE8XqmoYz9dzTVSMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBCwUAA4IBAQBAMXgE6G4STF5JNF+hZi/aDHNDR0BSCGiAJ17wyOQI\n\t\t\t\t\t\trP2n5QmYU7q63eWAL4nM6IFjm9lekq9iPZxhC5K3XVgtDz4uEh4CVsPKLnkJlthm\n\t\t\t\t\t\t6uJcAWlpx6XO/JxcgvLkGLVxt3Ew6YASY9kp1lAps+r4Roy4JbpPY2PQ+G6gmdBN\n\t\t\t\t\t\tXbXYbayAgPnevhUWxVo4/DgWX9xv3UzF7RWbEEgiS5vRr4hb7pLxlbPHfoQI5KUP\n\t\t\t\t\t\txXV2KDU0rxMp4uv0an+P+O7ePMr9j6d5+heLkBoM+InoJAoh62GJnZXjr6H2bpJR\n\t\t\t\t\t\tfvD/ZPNVxn4N4iHxZDaxWwINXVwOgDHod2aU6e61XAve"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "qmul.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.shibboleth.qmul.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.shibboleth.qmul.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.shibboleth.qmul.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.shibboleth.qmul.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.shibboleth.qmul.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.shibboleth.qmul.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.shibboleth.qmul.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.shibboleth.qmul.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "qmul.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://idcheck.qmul.ac.uk/data/qmul_black.gif",
                    "height": "53",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "200"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Queen Mary, University of London"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIHnTCCBoWgAwIBAgIQYq4ht/OC7BIxhYZg2e2WcDANBgkqhkiG9w0BAQsFADCB\n\t\t\t\t\t\tkjELMAkGA1UEBhMCR0IxGzAZBgNVBAgTEkdyZWF0ZXIgTWFuY2hlc3RlcjEQMA4G\n\t\t\t\t\t\tA1UEBxMHU2FsZm9yZDEaMBgGA1UEChMRQ09NT0RPIENBIExpbWl0ZWQxODA2BgNV\n\t\t\t\t\t\tBAMTL0NPTU9ETyBSU0EgRXh0ZW5kZWQgVmFsaWRhdGlvbiBTZWN1cmUgU2VydmVy\n\t\t\t\t\t\tIENBMB4XDTE1MDIxMzAwMDAwMFoXDTE3MDIxMjIzNTk1OVowggEoMREwDwYDVQQF\n\t\t\t\t\t\tEwhSQzAwMDcxMDETMBEGCysGAQQBgjc8AgEDEwJHQjEdMBsGA1UEDxMUUHJpdmF0\n\t\t\t\t\t\tZSBPcmdhbml6YXRpb24xCzAJBgNVBAYTAkdCMQ8wDQYDVQQREwZFMSA0TlMxDzAN\n\t\t\t\t\t\tBgNVBAgTBkxvbmRvbjEPMA0GA1UEBxMGTG9uZG9uMRYwFAYDVQQJEw1NaWxlIEVu\n\t\t\t\t\t\tZCBSb2FkMSgwJgYDVQQKEx9RdWVlbiBNYXJ5IFVuaXZlcnNpdHkgT2YgTG9uZG9u\n\t\t\t\t\t\tMRQwEgYDVQQLEwtJVCBTZXJ2aWNlczEjMCEGA1UECxMaQ09NT0RPIEVWIE11bHRp\n\t\t\t\t\t\tLURvbWFpbiBTU0wxIjAgBgNVBAMTGWlkcC5zaGliYm9sZXRoLnFtdWwuYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDh5MiNTEObfWslVrafeqmP\n\t\t\t\t\t\t1UD+0U4uUYuDMpX2OFiWRvPVdoIhNJK8InLjRGzM16rArF1VHTvw9L2hg+Mjksql\n\t\t\t\t\t\t1yaG0FuECmTUk9Jn1rgMo1RVmc036lp5eLAZAxOzj5T3pyiRKqs+QSMHWgwfg6HD\n\t\t\t\t\t\tU8YaldlqQM9bWtluzSQmx6df1m8DyolCnOBUTR35YwaVuQp9gnafy7i9smvSWhMM\n\t\t\t\t\t\t9j46BEEYGYJjm0REghRO/3WNRiKaIwiFn4utCGT9/oCu3Nl7yab8HQsAId39UuG9\n\t\t\t\t\t\tRE2FRJBTe7MuiQ13XllUwJGjCNrqgNldE4UrXHy0hjmFMlhYjY7cH2lCafYfuYTb\n\t\t\t\t\t\tAgMBAAGjggNUMIIDUDAfBgNVHSMEGDAWgBQ52v/KKBSKqHQTCLnkDqnS+n6daTAd\n\t\t\t\t\t\tBgNVHQ4EFgQUAlQbTUGQ8qFvPEcR9GoS6dzwfXswDgYDVR0PAQH/BAQDAgWgMAwG\n\t\t\t\t\t\tA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMEYGA1Ud\n\t\t\t\t\t\tIAQ/MD0wOwYMKwYBBAGyMQECAQUBMCswKQYIKwYBBQUHAgEWHWh0dHBzOi8vc2Vj\n\t\t\t\t\t\tdXJlLmNvbW9kby5jb20vQ1BTMFYGA1UdHwRPME0wS6BJoEeGRWh0dHA6Ly9jcmwu\n\t\t\t\t\t\tY29tb2RvY2EuY29tL0NPTU9ET1JTQUV4dGVuZGVkVmFsaWRhdGlvblNlY3VyZVNl\n\t\t\t\t\t\tcnZlckNBLmNybDCBhwYIKwYBBQUHAQEEezB5MFEGCCsGAQUFBzAChkVodHRwOi8v\n\t\t\t\t\t\tY3J0LmNvbW9kb2NhLmNvbS9DT01PRE9SU0FFeHRlbmRlZFZhbGlkYXRpb25TZWN1\n\t\t\t\t\t\tcmVTZXJ2ZXJDQS5jcnQwJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmNvbW9kb2Nh\n\t\t\t\t\t\tLmNvbTAkBgNVHREEHTAbghlpZHAuc2hpYmJvbGV0aC5xbXVsLmFjLnVrMIIBfwYK\n\t\t\t\t\t\tKwYBBAHWeQIEAgSCAW8EggFrAWkAdgBo9pj4H2SCvjqM7rkoHUz8cVFdZ5PURNEK\n\t\t\t\t\t\tZ6y7T0/7xAAAAUuDfKLAAAAEAwBHMEUCIAagnCAKc1skTr2wfGwSOzezQJViqYmn\n\t\t\t\t\t\tgN5+n6ek/kftAiEAhtqDNmjQM9DZWAxkkOpgHjX4vsM8Cah1O26zwqLbXNQAdwCk\n\t\t\t\t\t\tuQmQtBhYFIe7E6LMZ3AKPDWYBPkb37jjd80OyA3cEAAAAUuDfKLHAAAEAwBIMEYC\n\t\t\t\t\t\tIQCJANeMiBQF69/wczNISERwZ/4FVTHON1fD4BKgv/AGEwIhAI7zhnDGVs8p1Ccu\n\t\t\t\t\t\tOcq8ovoSLnF5KdVJ2n+Jf1PtTLrOAHYAVhQGmi/XwuzT9eG9RLI+x0Z2ubyZEVzA\n\t\t\t\t\t\t75SYVdaJ0N0AAAFLg3yhXgAABAMARzBFAiA66Y6PGzOrXZfGz56TSNaANr7yO/c7\n\t\t\t\t\t\t3r778k2gFOtwAAIhAJqdTx8fzxsbvpUvriFZCGVksMhdcIE8XqmoYz9dzTVSMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBCwUAA4IBAQBAMXgE6G4STF5JNF+hZi/aDHNDR0BSCGiAJ17wyOQI\n\t\t\t\t\t\trP2n5QmYU7q63eWAL4nM6IFjm9lekq9iPZxhC5K3XVgtDz4uEh4CVsPKLnkJlthm\n\t\t\t\t\t\t6uJcAWlpx6XO/JxcgvLkGLVxt3Ew6YASY9kp1lAps+r4Roy4JbpPY2PQ+G6gmdBN\n\t\t\t\t\t\tXbXYbayAgPnevhUWxVo4/DgWX9xv3UzF7RWbEEgiS5vRr4hb7pLxlbPHfoQI5KUP\n\t\t\t\t\t\txXV2KDU0rxMp4uv0an+P+O7ePMr9j6d5+heLkBoM+InoJAoh62GJnZXjr6H2bpJR\n\t\t\t\t\t\tfvD/ZPNVxn4N4iHxZDaxWwINXVwOgDHod2aU6e61XAve"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Queen Mary, University of London"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qmul.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Queen Mary and Westfield College, University of London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.unimib.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@unimib.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.unimib.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2010-08-06T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unimib.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.unimib.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unimib.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unimib.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.si.unimib.it/idem-en/"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.si.unimib.it/idem/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Milano-Bicocca"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 di Milano-Bicocca"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for University of Milano-Bicocca users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti di Universit\u00e0 di Milano-Bicocca"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.unimib.it/unimib_16x16.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.unimib.it/unimib_16x16.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.unimib.it/unimib_50x50.png",
                    "lang": "en",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "https://idp.unimib.it/unimib_50x50.png",
                    "lang": "it",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "https://idp.unimib.it/unimib_80x60.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idp.unimib.it/unimib_80x60.png",
                    "lang": "it",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.si.unimib.it/idem-en/"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.si.unimib.it/idem/"
                  }
                ]
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "unimib.it"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:45.518965,9.214319"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:45.602745,9.254773"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:46.160489,9.910843"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:45.558355,9.214384"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:45.528174,9.243695"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "149.132.0.0/16"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID8jCCAtoCCQDRtfiml6XVzDANBgkqhkiG9w0BAQUFADCBujELMAkGA1UEBhMC\nSVQxDzANBgNVBAgMBk1pbGFubzEPMA0GA1UEBwwGTWlsYW5vMTQwMgYDVQQKDCtV\nbml2ZXJzaXTDg8KgIGRlZ2xpIFN0dWRpIGRpIE1pbGFuby1CaWNvY2NhMRwwGgYD\nVQQLDBNTaXN0ZW1pIEluZm9ybWF0aXZpMRYwFAYDVQQDDA1pZHAudW5pbWliLml0\nMR0wGwYJKoZIhvcNAQkBFg5pZGVtQHVuaW1pYi5pdDAeFw0xMzA4MjgxMzA0Mjla\nFw0yMzA4MjYxMzA0MjlaMIG6MQswCQYDVQQGEwJJVDEPMA0GA1UECAwGTWlsYW5v\nMQ8wDQYDVQQHDAZNaWxhbm8xNDAyBgNVBAoMK1VuaXZlcnNpdMODwqAgZGVnbGkg\nU3R1ZGkgZGkgTWlsYW5vLUJpY29jY2ExHDAaBgNVBAsME1Npc3RlbWkgSW5mb3Jt\nYXRpdmkxFjAUBgNVBAMMDWlkcC51bmltaWIuaXQxHTAbBgkqhkiG9w0BCQEWDmlk\nZW1AdW5pbWliLml0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzb96\n/j8SpXJ/QCu3HVZcdcSPUZTXkc3YJniHnPEm+J+R0YJaUui3sq3m7rG7HeOr0QMe\n+dSJQcAiUNWDLXlOq91rZvTmiXYreS3TqEpsEpNJOLbLdzfbD7NLwy9YNYqYXx+t\nITIhEhccMzGcYEBNuxKPRasvOC7QOKJWaed2IPP8ptBdFQ9XyggBL0Q+9ADDzGHl\nm+HYAocXZjQvN8demGDXALBx2SANliVftQQvouv/93q34u8gOJCCCfMA/PacrvtX\ngn29U3q5izvMmwLZmMNyJ5Lckpl/LcgStCT488bJJbLZrpGxMDSPTQamy/j3hQs/\nmz114w1omnc0OfmaqQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQAQIxQMg9qVYHGu\nfapH4AiFzwnqSNpjqewrdr/kOQv1RsnzNY5Xu8iyioe3jMIH2Nc1YYcUzfKYr9mV\n7S0DUhpu2GBSC3z9mhRlULkOmJvU+4GAaFCr4jt5fjRMl440toXDJLgGYpoWQmG8\ncvvl3Ysg9sYGbzmWXLFjZyrImJ6F5ZboiGZoTkG3HcXOAUExZA5gRzFk5Gdy65SQ\nCmLcMEs2lw9ZDHDbMwNHqvXrqiljRNowHzZ5v800zjMvoyVHmsVmRzyfqdbmLCnX\nSI8F0ix2bVu35o8sDuqmPkq/l2DwNvPr26l94ohEE6Fh1ZsnGG8ehJ9MuGbSUwf7\nfjKYky96"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Milano-Bicocca"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 di Milano-Bicocca"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unimib.it/go/102/Home/English"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unimib.it/go/101/Home/Italiano"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Milano-Bicocca"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 di Milano-Bicocca"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.bedford.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.bedford.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/bedford.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/bedford.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bedford.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bedford College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bedford.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idemfero.units.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@units.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Staff Tecnico"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idemfero.units.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2011-10-11T13:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAIPn0rci7ca2nc6Pd0a8kS35GFVlMA0GCSqGSIb3DQEB\nBQUAMBwxGjAYBgNVBAMTEWlkZW1mZXJvLnVuaXRzLml0MB4XDTExMDYzMDE1Mzgw\nNFoXDTMxMDYzMDE1MzgwNFowHDEaMBgGA1UEAxMRaWRlbWZlcm8udW5pdHMuaXQw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDm2d1TVod551/AHgSkFZa/\nDgfKePtHqC88H9qlcDGhhZfdhN1KCubG7H2sY1awLQ3HwonlfyCN+FjxL15jiTtS\nSGM3bE9tb8p6NoryPTtPSiF4JZraE5Y8PnWN7i49QhhOY/dzsYGUGzKWY8GzSaKB\nBJAA+XXbj2l6s/6Ksj/ii7KGjt/opcJ5rBE0+ttDanuC0w8upUAL29rQ5Yx6n7IG\nFMI7PS2W1IeKrU0Fm93ujdm3Itx9L+5bmd/WQyJInXt9DWQXBhek3oh5ZCK+H7Or\nh9Sk4ld8BxFlgsw96xjVX246jTCBgGcCOlRRW9d21tYmCEn/ew4JVtHHRktnblD3\nAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEWlkZW1mZXJvLnVuaXRzLml0hihodHRwczov\nL2lkZW1mZXJvLnVuaXRzLml0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQDNZRh\n1OdCXmX7+5k2XwRmfMQ4iDANBgkqhkiG9w0BAQUFAAOCAQEASeWVPZ+W5q+LxyZP\nuEpGw+uysbNIBbpxglKfli3QX9MQrBOG1S1Y5gQ5Rsi26ipWidgEORbX6mUKtax+\n85NYvi3faIcbLMf87Xbxmn+oYMv/ksfeoevZAkLPXb6DLNjoOEV2UbQuz/03o9bM\n05QJuuY1K9ioCMat4+WZ3XvLxNoKZwRLtERV5Ibr+ffOu1WhXkdoW1PX6K12p044\nIa4SBEhy9t8ZxoAe2sSE8TTww+wGzJ48+2Ek/Lr/JTCbT1wj3QGvN3vbE++aLrtY\nLWrKlDzFIKXv9Tk8LNWWOGxbRhw3x2OymWGfU9gDlQs0mAWuEKsjr3iUrsDGkkiy\naQYbJQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "units.it"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ds.units.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idemfero.units.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idemfero.units.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idemfero.units.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idemfero.units.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idemfero.units.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idemfero.units.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idemfero.units.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idemfero.units.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "units.it"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ds.units.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://international.units.it/"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.units.it/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for University of Trieste members"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti dell'Universit\u00e0 di Trieste"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idemfero.units.it/unilogo/sigillo16x16.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idemfero.units.it/unilogo/sigillo16x16.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idemfero.units.it/unilogo/sigillo60x80.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idemfero.units.it/unilogo/sigillo60x80.png",
                    "lang": "it",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Trieste"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 di Trieste"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "units.it"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "univ.trieste.it"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:45.659111,13.793918"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:45.654776,13.774515"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:45.644968,13.763675"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:45.645326,13.761110"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:45.643376,13.758256"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:45.625536,13.794341"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:45.939804,13.631546"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:45.774583,12.835801"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:45.952193,12.680840"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAIPn0rci7ca2nc6Pd0a8kS35GFVlMA0GCSqGSIb3DQEB\nBQUAMBwxGjAYBgNVBAMTEWlkZW1mZXJvLnVuaXRzLml0MB4XDTExMDYzMDE1Mzgw\nNFoXDTMxMDYzMDE1MzgwNFowHDEaMBgGA1UEAxMRaWRlbWZlcm8udW5pdHMuaXQw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDm2d1TVod551/AHgSkFZa/\nDgfKePtHqC88H9qlcDGhhZfdhN1KCubG7H2sY1awLQ3HwonlfyCN+FjxL15jiTtS\nSGM3bE9tb8p6NoryPTtPSiF4JZraE5Y8PnWN7i49QhhOY/dzsYGUGzKWY8GzSaKB\nBJAA+XXbj2l6s/6Ksj/ii7KGjt/opcJ5rBE0+ttDanuC0w8upUAL29rQ5Yx6n7IG\nFMI7PS2W1IeKrU0Fm93ujdm3Itx9L+5bmd/WQyJInXt9DWQXBhek3oh5ZCK+H7Or\nh9Sk4ld8BxFlgsw96xjVX246jTCBgGcCOlRRW9d21tYmCEn/ew4JVtHHRktnblD3\nAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEWlkZW1mZXJvLnVuaXRzLml0hihodHRwczov\nL2lkZW1mZXJvLnVuaXRzLml0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQDNZRh\n1OdCXmX7+5k2XwRmfMQ4iDANBgkqhkiG9w0BAQUFAAOCAQEASeWVPZ+W5q+LxyZP\nuEpGw+uysbNIBbpxglKfli3QX9MQrBOG1S1Y5gQ5Rsi26ipWidgEORbX6mUKtax+\n85NYvi3faIcbLMf87Xbxmn+oYMv/ksfeoevZAkLPXb6DLNjoOEV2UbQuz/03o9bM\n05QJuuY1K9ioCMat4+WZ3XvLxNoKZwRLtERV5Ibr+ffOu1WhXkdoW1PX6K12p044\nIa4SBEhy9t8ZxoAe2sSE8TTww+wGzJ48+2Ek/Lr/JTCbT1wj3QGvN3vbE++aLrtY\nLWrKlDzFIKXv9Tk8LNWWOGxbRhw3x2OymWGfU9gDlQs0mAWuEKsjr3iUrsDGkkiy\naQYbJQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 di Trieste"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Trieste"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.units.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://international.units.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli Studi di Trieste"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Trieste"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.lstonline.ac.uk/idp/pingfederate",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Taylor"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mike.taylor@lst.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Taylor"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mike.taylor@lst.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.lstonline.ac.uk/idp/pingfederate",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-09-03T11:48:22Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.lstonline.ac.uk:8443/idp/attrsvc.ssaml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.lstonline.ac.uk:8443/idp/soap.ssaml1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFrTCCBJWgAwIBAgIDBoSbMA0GCSqGSIb3DQEBCwUAMEcxCzAJBgNVBAYTAlVT\n\t\t\t\t\t\tMRYwFAYDVQQKEw1HZW9UcnVzdCBJbmMuMSAwHgYDVQQDExdSYXBpZFNTTCBTSEEy\n\t\t\t\t\t\tNTYgQ0EgLSBHMzAeFw0xNTA4MjUwNjUyMTlaFw0xNjA4MjcwMDQ2MzVaMIGZMRMw\n\t\t\t\t\t\tEQYDVQQLEwpHVDk0OTY4OTI4MTEwLwYDVQQLEyhTZWUgd3d3LnJhcGlkc3NsLmNv\n\t\t\t\t\t\tbS9yZXNvdXJjZXMvY3BzIChjKTE1MS8wLQYDVQQLEyZEb21haW4gQ29udHJvbCBW\n\t\t\t\t\t\tYWxpZGF0ZWQgLSBSYXBpZFNTTChSKTEeMBwGA1UEAxMVbG9naW4ubHN0b25saW5l\n\t\t\t\t\t\tLmFjLnVrMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAxrAkIUMp+9zE\n\t\t\t\t\t\tF27/7ShFVhGxwJDiQuEQih/86q32F/x2exva/aaPq2kMkeEfsf9iCoHYRRHMB9rv\n\t\t\t\t\t\t1GvUnvsyWKF1mcNXq79RgwrcJ0vQlN8DxODGS7ymo/Ki1m+TcF6e/j1Rao48LKHS\n\t\t\t\t\t\tJpYMDEUKV7LZ+sIytwnuLPVSFR6u9QprbQ7BsdXxvZiC/dPTPJe8IOgwE/YUYgL3\n\t\t\t\t\t\tNlnPCuAQSv/Eih3P4532cAfvSEy1TnS+KpOkPJVnRyRmsei0PbcOSgjlgdKyvTDp\n\t\t\t\t\t\tzti+Clsr8roZty3YVJT1rfo9UnU3vo5GJxDkwIPAUK9jPBAzx7AqGaazQRNKdxUJ\n\t\t\t\t\t\tlOl3sjEM+v4ruVMTM5EmExxc0XAqx/WAZ6GlYWaEP+Aezq5QgDBEORrBtGz8daOh\n\t\t\t\t\t\tl/xTjL6ZKuoDq2zKeQsIuzhLr8IVhFfGBpuhhMces0JulQzF9Rc+TtjHt/m/t/9A\n\t\t\t\t\t\tanSBWrFTM2EEeu6PaubGe70FIZaPbXjAceDtHTINSJUk+czok1lBFd5trz7wvn9/\n\t\t\t\t\t\tMalHHGI5JSyJ0DzfwfIpqDDH5QxmihQ3vVrzHJq4SNF58MoSouGSUWkcr+Otfstl\n\t\t\t\t\t\tN7Gt8l1LsV8on0Dkw99iRd17yN3Tz1j9l363k0IEMrB8enbqDqo4oYs1Zl4Gc3be\n\t\t\t\t\t\tjtcz3oEmUjI42jxf8vJKRcPK7hNsaWUCAwEAAaOCAU0wggFJMB8GA1UdIwQYMBaA\n\t\t\t\t\t\tFMOc8/zTRgg0u85Gf6B8W/PiCMtZMFcGCCsGAQUFBwEBBEswSTAfBggrBgEFBQcw\n\t\t\t\t\t\tAYYTaHR0cDovL2d2LnN5bWNkLmNvbTAmBggrBgEFBQcwAoYaaHR0cDovL2d2LnN5\n\t\t\t\t\t\tbWNiLmNvbS9ndi5jcnQwDgYDVR0PAQH/BAQDAgWgMB0GA1UdJQQWMBQGCCsGAQUF\n\t\t\t\t\t\tBwMBBggrBgEFBQcDAjAgBgNVHREEGTAXghVsb2dpbi5sc3RvbmxpbmUuYWMudWsw\n\t\t\t\t\t\tKwYDVR0fBCQwIjAgoB6gHIYaaHR0cDovL2d2LnN5bWNiLmNvbS9ndi5jcmwwDAYD\n\t\t\t\t\t\tVR0TAQH/BAIwADBBBgNVHSAEOjA4MDYGBmeBDAECATAsMCoGCCsGAQUFBwIBFh5o\n\t\t\t\t\t\tdHRwczovL3d3dy5yYXBpZHNzbC5jb20vbGVnYWwwDQYJKoZIhvcNAQELBQADggEB\n\t\t\t\t\t\tAHFxca8STxtCYEtDWZvAFWBMmNG3DnqbpMN5lHHAWOSg+ofLkHlOkm47gDxzx6MT\n\t\t\t\t\t\te8lMuGdqenUFNiq2Y1GWhAZ2oI0VSmpOvirzO+oR3rZCzV5ekgSrf+8rD3FwODha\n\t\t\t\t\t\tbutguX/U1Iiwq+si7+0gyHFlrSL6OEdJFDnNgqyzqOQRM+Z55+n/7vmMfsNRhDLM\n\t\t\t\t\t\tgeFMYTUZyt61YKHICtyarPE6Bgw+Z8ByiLHq2pvgq1R42P7++IHpWQl2lRQ5pv9r\n\t\t\t\t\t\tphaCPMAtesAXAd5ck0aKucQrgU+Oyag/hPpHaUBuz8Z5vYDCF7AkSTPQyK0zt4lR\n\t\t\t\t\t\tqG9o247BAjLhNj6N/rlcE2w="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lstonline.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.lstonline.ac.uk/idp/SSO.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.lstonline.ac.uk/idp/SSO.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.lstonline.ac.uk/idp/SSO.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.lstonline.ac.uk/idp/isx.saml1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.lstonline.ac.uk:8443/idp/soap.ssaml1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lstonline.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFrTCCBJWgAwIBAgIDBoSbMA0GCSqGSIb3DQEBCwUAMEcxCzAJBgNVBAYTAlVT\n\t\t\t\t\t\tMRYwFAYDVQQKEw1HZW9UcnVzdCBJbmMuMSAwHgYDVQQDExdSYXBpZFNTTCBTSEEy\n\t\t\t\t\t\tNTYgQ0EgLSBHMzAeFw0xNTA4MjUwNjUyMTlaFw0xNjA4MjcwMDQ2MzVaMIGZMRMw\n\t\t\t\t\t\tEQYDVQQLEwpHVDk0OTY4OTI4MTEwLwYDVQQLEyhTZWUgd3d3LnJhcGlkc3NsLmNv\n\t\t\t\t\t\tbS9yZXNvdXJjZXMvY3BzIChjKTE1MS8wLQYDVQQLEyZEb21haW4gQ29udHJvbCBW\n\t\t\t\t\t\tYWxpZGF0ZWQgLSBSYXBpZFNTTChSKTEeMBwGA1UEAxMVbG9naW4ubHN0b25saW5l\n\t\t\t\t\t\tLmFjLnVrMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAxrAkIUMp+9zE\n\t\t\t\t\t\tF27/7ShFVhGxwJDiQuEQih/86q32F/x2exva/aaPq2kMkeEfsf9iCoHYRRHMB9rv\n\t\t\t\t\t\t1GvUnvsyWKF1mcNXq79RgwrcJ0vQlN8DxODGS7ymo/Ki1m+TcF6e/j1Rao48LKHS\n\t\t\t\t\t\tJpYMDEUKV7LZ+sIytwnuLPVSFR6u9QprbQ7BsdXxvZiC/dPTPJe8IOgwE/YUYgL3\n\t\t\t\t\t\tNlnPCuAQSv/Eih3P4532cAfvSEy1TnS+KpOkPJVnRyRmsei0PbcOSgjlgdKyvTDp\n\t\t\t\t\t\tzti+Clsr8roZty3YVJT1rfo9UnU3vo5GJxDkwIPAUK9jPBAzx7AqGaazQRNKdxUJ\n\t\t\t\t\t\tlOl3sjEM+v4ruVMTM5EmExxc0XAqx/WAZ6GlYWaEP+Aezq5QgDBEORrBtGz8daOh\n\t\t\t\t\t\tl/xTjL6ZKuoDq2zKeQsIuzhLr8IVhFfGBpuhhMces0JulQzF9Rc+TtjHt/m/t/9A\n\t\t\t\t\t\tanSBWrFTM2EEeu6PaubGe70FIZaPbXjAceDtHTINSJUk+czok1lBFd5trz7wvn9/\n\t\t\t\t\t\tMalHHGI5JSyJ0DzfwfIpqDDH5QxmihQ3vVrzHJq4SNF58MoSouGSUWkcr+Otfstl\n\t\t\t\t\t\tN7Gt8l1LsV8on0Dkw99iRd17yN3Tz1j9l363k0IEMrB8enbqDqo4oYs1Zl4Gc3be\n\t\t\t\t\t\tjtcz3oEmUjI42jxf8vJKRcPK7hNsaWUCAwEAAaOCAU0wggFJMB8GA1UdIwQYMBaA\n\t\t\t\t\t\tFMOc8/zTRgg0u85Gf6B8W/PiCMtZMFcGCCsGAQUFBwEBBEswSTAfBggrBgEFBQcw\n\t\t\t\t\t\tAYYTaHR0cDovL2d2LnN5bWNkLmNvbTAmBggrBgEFBQcwAoYaaHR0cDovL2d2LnN5\n\t\t\t\t\t\tbWNiLmNvbS9ndi5jcnQwDgYDVR0PAQH/BAQDAgWgMB0GA1UdJQQWMBQGCCsGAQUF\n\t\t\t\t\t\tBwMBBggrBgEFBQcDAjAgBgNVHREEGTAXghVsb2dpbi5sc3RvbmxpbmUuYWMudWsw\n\t\t\t\t\t\tKwYDVR0fBCQwIjAgoB6gHIYaaHR0cDovL2d2LnN5bWNiLmNvbS9ndi5jcmwwDAYD\n\t\t\t\t\t\tVR0TAQH/BAIwADBBBgNVHSAEOjA4MDYGBmeBDAECATAsMCoGCCsGAQUFBwIBFh5o\n\t\t\t\t\t\tdHRwczovL3d3dy5yYXBpZHNzbC5jb20vbGVnYWwwDQYJKoZIhvcNAQELBQADggEB\n\t\t\t\t\t\tAHFxca8STxtCYEtDWZvAFWBMmNG3DnqbpMN5lHHAWOSg+ofLkHlOkm47gDxzx6MT\n\t\t\t\t\t\te8lMuGdqenUFNiq2Y1GWhAZ2oI0VSmpOvirzO+oR3rZCzV5ekgSrf+8rD3FwODha\n\t\t\t\t\t\tbutguX/U1Iiwq+si7+0gyHFlrSL6OEdJFDnNgqyzqOQRM+Z55+n/7vmMfsNRhDLM\n\t\t\t\t\t\tgeFMYTUZyt61YKHICtyarPE6Bgw+Z8ByiLHq2pvgq1R42P7++IHpWQl2lRQ5pv9r\n\t\t\t\t\t\tphaCPMAtesAXAd5ck0aKucQrgU+Oyag/hPpHaUBuz8Z5vYDCF7AkSTPQyK0zt4lR\n\t\t\t\t\t\tqG9o247BAjLhNj6N/rlcE2w="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "London School of Theology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lst.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "London School of Theology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://play.ltu.se",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "saml_admin@kaltura.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://play.ltu.se",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lule\u00e5 Tekniska Universitet (PROD)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://play.ltu.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Lule\u00e5 Tekniska Universitet (PROD)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://play.ltu.se/user/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is Lule\u00e5 University of Technology's streaming service."
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Detta \u00e4r Lule\u00e5 tekniska universitets play tj\u00e4nst"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lule\u00e5 University of Technology Play service"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lule\u00e5 tekniska universitets Play tj\u00e4nst"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.ltu.se/user/authenticate",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.lshtm.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Manning"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:christopher.manning@lshtm.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Christopher"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Whitbread"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steven.whitbread@lshtm.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.lshtm.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGMDCCBBigAwIBAgIJAIUFHfw4Gj9WMA0GCSqGSIb3DQEBBQUAMIGYMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEPMA0GA1UECBMGTG9uZG9uMQ8wDQYDVQQHEwZMb25kb24xNzA1BgNV\n\t\t\t\t\t\tBAoTLkxvbmRvbiBTY2hvb2wgb2YgSHlnaWVuZSBhbmQgVHJvcGljYWwgTWVkaWNp\n\t\t\t\t\t\tbmUxFDASBgNVBAsTC0lUIFNlcnZpY2VzMRgwFgYDVQQDEw9pZHAubHNodG0uYWMu\n\t\t\t\t\t\tdWswHhcNMTIxMTIxMTAwMjI4WhcNMjIxMTE5MTAwMjI4WjCBmDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxDzANBgNVBAgTBkxvbmRvbjEPMA0GA1UEBxMGTG9uZG9uMTcwNQYDVQQKEy5M\n\t\t\t\t\t\tb25kb24gU2Nob29sIG9mIEh5Z2llbmUgYW5kIFRyb3BpY2FsIE1lZGljaW5lMRQw\n\t\t\t\t\t\tEgYDVQQLEwtJVCBTZXJ2aWNlczEYMBYGA1UEAxMPaWRwLmxzaHRtLmFjLnVrMIIC\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAuTPyCuj1pH4dZ7MqyEruIQ69\n\t\t\t\t\t\teHqslz6CkseYXZypQGILVKF7i/QCdfE82mklM0GF5a8KaBvp6F1TNBpOVfe5Wx8y\n\t\t\t\t\t\t/CqIwfoLqTHtTOwIoBSQTCbcqje8lUR+oP7gA4a+uF7AVurnZOrNFvYJaMvDuYcb\n\t\t\t\t\t\tRmChofGrsUYUVPYVEC7cT+T4lEZkO7ntQ9SN7If0INa/E2uiHOAmrYTQ9+l6u/nN\n\t\t\t\t\t\tri9Lpc+N6Pg5BDwvgztDmQMiDhtMjHVZ4MxHqRlUiSY6m+IPot7YjSJ3XDOrXhrg\n\t\t\t\t\t\t0zIhmSj0Zm/0htH5jq3yGwbNiVgvf/9r2hM4LC+VyqwCXnk3cUWC1zQZeV6lCy9c\n\t\t\t\t\t\tihPen6r9qkShVRzIk788rJfCMDPggPIJXXVs7TosSH+lPgOIcSw18nMPCOb5/iUj\n\t\t\t\t\t\tnyqGTVrAKEft5o16HpYyivhkJTFoz2msPem1GUztLt+ueZmUir4RCk5Hu1sodoo5\n\t\t\t\t\t\tUDzRHtsjzBVZ7W3a3y5dYtyxtYkDWKLM46Zew8/qp34wT785zId1WkqYoj+RMFp/\n\t\t\t\t\t\t3p+zvJK9ykS/I1mW5/6yjZ5rLebw6vhfJzQq3aN40clFkXGAij/VLepgPY8T3F+G\n\t\t\t\t\t\tfa9UPPI+7s/3GLAGw20bHF3TLhbTPScUt/8uCfZsoHdrFFR9jIu47+RhF08phF2+\n\t\t\t\t\t\tS90ucfkr77Mka+ZVD4kCAwEAAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0E\n\t\t\t\t\t\tHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFEpDJ6JR\n\t\t\t\t\t\tdIQLh7IAXnC3xWabzxvcMB8GA1UdIwQYMBaAFEpDJ6JRdIQLh7IAXnC3xWabzxvc\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4ICAQBpoHHOOMfP6RopKhCLcLDIAfy2VRjv2xcPbyd+\n\t\t\t\t\t\tpvdti1mIlhdEhNeH7Nn2OekU8Ruh2eKfv9K+6T+zBdrRkYMsGelbtNFZXKkV/OZ3\n\t\t\t\t\t\tG9lV6KMy1YmvMOEfgf7S7CmIIBaPQ5XDlNI8lyT6If3MaG2p6Z/GsskPGWHMnQWS\n\t\t\t\t\t\teTs3dzFLCLCfYzXFBO5oOYJvqLtiXvkDGBj0hVCF3cbQIqICzcT2q3VVF2/EXdtY\n\t\t\t\t\t\tbClJsI0PXDbmuKqaVxSVBy2BfnkK9iB1QDw3SKvpUNd2ZFeNDRC0ggOwuHXu+fyp\n\t\t\t\t\t\tZKdiZ/0LkwtAhnYyYTSip/5d+4Plu6ymqr1ENTyRS8ij5zq8J5rF5DJ+AieBm9uk\n\t\t\t\t\t\tDSwjsWlCgKwsDdccuSNvapok2As29jGzYbT950jAbkNi4wHjhHDMbbWv5W4EPncU\n\t\t\t\t\t\t22QW7z+Z+wbR7DtCcoBhoVhHCtYFDzBrFv/emwSLMtdTV/CcCrT6yU7Ds8ogulmw\n\t\t\t\t\t\ta9gqoEHyBVMKxO2OdzPUtLKvGgr6CdTDJCVnb0b6N900lEJuNQaCMTiqH/C/yj4b\n\t\t\t\t\t\tfh6K0G6HKsASieVW3J4GUBjwzkcbbAGsJmJG08O6pgxvPPZdUOyF9Omna9aSblwb\n\t\t\t\t\t\tztKtqBRmGFEv+NdL7FW65bo+35Gp/Ajdh/bD+t3RPXBZwqNg4snlXRXRcfk2MKis\n\t\t\t\t\t\tclTSFw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lshtm.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.lshtm.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.lshtm.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.lshtm.ac.uk/shibboleth-idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.lshtm.ac.uk/shibboleth-idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.lshtm.ac.uk/shibboleth-idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.lshtm.ac.uk/shibboleth-idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.lshtm.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.lshtm.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lshtm.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGMDCCBBigAwIBAgIJAIUFHfw4Gj9WMA0GCSqGSIb3DQEBBQUAMIGYMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEPMA0GA1UECBMGTG9uZG9uMQ8wDQYDVQQHEwZMb25kb24xNzA1BgNV\n\t\t\t\t\t\tBAoTLkxvbmRvbiBTY2hvb2wgb2YgSHlnaWVuZSBhbmQgVHJvcGljYWwgTWVkaWNp\n\t\t\t\t\t\tbmUxFDASBgNVBAsTC0lUIFNlcnZpY2VzMRgwFgYDVQQDEw9pZHAubHNodG0uYWMu\n\t\t\t\t\t\tdWswHhcNMTIxMTIxMTAwMjI4WhcNMjIxMTE5MTAwMjI4WjCBmDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxDzANBgNVBAgTBkxvbmRvbjEPMA0GA1UEBxMGTG9uZG9uMTcwNQYDVQQKEy5M\n\t\t\t\t\t\tb25kb24gU2Nob29sIG9mIEh5Z2llbmUgYW5kIFRyb3BpY2FsIE1lZGljaW5lMRQw\n\t\t\t\t\t\tEgYDVQQLEwtJVCBTZXJ2aWNlczEYMBYGA1UEAxMPaWRwLmxzaHRtLmFjLnVrMIIC\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAuTPyCuj1pH4dZ7MqyEruIQ69\n\t\t\t\t\t\teHqslz6CkseYXZypQGILVKF7i/QCdfE82mklM0GF5a8KaBvp6F1TNBpOVfe5Wx8y\n\t\t\t\t\t\t/CqIwfoLqTHtTOwIoBSQTCbcqje8lUR+oP7gA4a+uF7AVurnZOrNFvYJaMvDuYcb\n\t\t\t\t\t\tRmChofGrsUYUVPYVEC7cT+T4lEZkO7ntQ9SN7If0INa/E2uiHOAmrYTQ9+l6u/nN\n\t\t\t\t\t\tri9Lpc+N6Pg5BDwvgztDmQMiDhtMjHVZ4MxHqRlUiSY6m+IPot7YjSJ3XDOrXhrg\n\t\t\t\t\t\t0zIhmSj0Zm/0htH5jq3yGwbNiVgvf/9r2hM4LC+VyqwCXnk3cUWC1zQZeV6lCy9c\n\t\t\t\t\t\tihPen6r9qkShVRzIk788rJfCMDPggPIJXXVs7TosSH+lPgOIcSw18nMPCOb5/iUj\n\t\t\t\t\t\tnyqGTVrAKEft5o16HpYyivhkJTFoz2msPem1GUztLt+ueZmUir4RCk5Hu1sodoo5\n\t\t\t\t\t\tUDzRHtsjzBVZ7W3a3y5dYtyxtYkDWKLM46Zew8/qp34wT785zId1WkqYoj+RMFp/\n\t\t\t\t\t\t3p+zvJK9ykS/I1mW5/6yjZ5rLebw6vhfJzQq3aN40clFkXGAij/VLepgPY8T3F+G\n\t\t\t\t\t\tfa9UPPI+7s/3GLAGw20bHF3TLhbTPScUt/8uCfZsoHdrFFR9jIu47+RhF08phF2+\n\t\t\t\t\t\tS90ucfkr77Mka+ZVD4kCAwEAAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0E\n\t\t\t\t\t\tHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFEpDJ6JR\n\t\t\t\t\t\tdIQLh7IAXnC3xWabzxvcMB8GA1UdIwQYMBaAFEpDJ6JRdIQLh7IAXnC3xWabzxvc\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4ICAQBpoHHOOMfP6RopKhCLcLDIAfy2VRjv2xcPbyd+\n\t\t\t\t\t\tpvdti1mIlhdEhNeH7Nn2OekU8Ruh2eKfv9K+6T+zBdrRkYMsGelbtNFZXKkV/OZ3\n\t\t\t\t\t\tG9lV6KMy1YmvMOEfgf7S7CmIIBaPQ5XDlNI8lyT6If3MaG2p6Z/GsskPGWHMnQWS\n\t\t\t\t\t\teTs3dzFLCLCfYzXFBO5oOYJvqLtiXvkDGBj0hVCF3cbQIqICzcT2q3VVF2/EXdtY\n\t\t\t\t\t\tbClJsI0PXDbmuKqaVxSVBy2BfnkK9iB1QDw3SKvpUNd2ZFeNDRC0ggOwuHXu+fyp\n\t\t\t\t\t\tZKdiZ/0LkwtAhnYyYTSip/5d+4Plu6ymqr1ENTyRS8ij5zq8J5rF5DJ+AieBm9uk\n\t\t\t\t\t\tDSwjsWlCgKwsDdccuSNvapok2As29jGzYbT950jAbkNi4wHjhHDMbbWv5W4EPncU\n\t\t\t\t\t\t22QW7z+Z+wbR7DtCcoBhoVhHCtYFDzBrFv/emwSLMtdTV/CcCrT6yU7Ds8ogulmw\n\t\t\t\t\t\ta9gqoEHyBVMKxO2OdzPUtLKvGgr6CdTDJCVnb0b6N900lEJuNQaCMTiqH/C/yj4b\n\t\t\t\t\t\tfh6K0G6HKsASieVW3J4GUBjwzkcbbAGsJmJG08O6pgxvPPZdUOyF9Omna9aSblwb\n\t\t\t\t\t\tztKtqBRmGFEv+NdL7FW65bo+35Gp/Ajdh/bD+t3RPXBZwqNg4snlXRXRcfk2MKis\n\t\t\t\t\t\tclTSFw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "London School of Hygiene & Tropical Medicine"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lshtm.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "London School of Hygiene and Tropical Medicine"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://samltest.swamid.se/coc/sp.xml",
    {
      "entity_id": "https://samltest.swamid.se/coc/sp.xml",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish Academic Identity Federation (SWAMID)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.swamid.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SWAMID"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://samltest.swamid.se/disco",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFcTCCBFmgAwIBAgIQIu7k1beHBKgWb27d90Ad9jANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQwODAwMDAwMFoXDTE3MDQwNzIzNTk1OVowQDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRswGQYDVQQDExJzYW1sdGVzdC5z\nd2FtaWQuc2UwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCcJfNqCJmM\nCWZ9+h9MAT9WbT/e+eRpGE9H8eucnnq4weTeFbT+2Ma15hY8hI6gP4GsDIZsaxTu\nDGgIYXctfnl9MTz+9rlANOo8Wjuz6CJ2trJ6BdhPvkoITuSqmIWkFbmP7/0NGkoG\n167CGp/Eq5yZnUOdiKXquH2S5OCw3mB4HGpjUk7T13cN0jOOPiK2cQhUTuUUMaVO\nei0QblIfK/+9fusfYOjd5uzNg1QZ9FvvbB/wTw4Z11eGcZWKpAprIrbx6iw119eL\nU7dvJhgA96VJmesDQejf96Xtpn7bCbxdyBqw2AtooamyrVjnAeQ8NDXW7td9MUuM\n4/yhN9H+fHTVJNs8dCX5FKayw5YoxF8eTMjRk0ObICMrLl8M/EiOG9Eqfc3TPGTF\ndn81sOGc3WzifRyG5fXUx/Xw9vXVkRAkVO6T4n6OUQxn2be9hwXR7yFw9tTplPIl\ndabhc7iWU7NgEBcBI3RWCcRNv0OVsXIMDeGZ64SOm4mpKbXMVebsnSLXxV69T1l4\nM8EegMpraRWHrbtF27FkKZPZgCbNaQbfW4vtJoN9rN07Flz8GLr200WXAepXT14L\ndGwXqjx6Cu2oilkl2OoNWQbRg3dvn1j6XqnRLbio4bvuiCYYEPpjuWcHOs/GwMnz\npml7EL51yz9PTwNZTQXsLH/xKlzWf1BuBQIDAQABo4IBbzCCAWswHwYDVR0jBBgw\nFoAUDL2TaAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFG40O0IHvLK2kXS6s4hN\nCq0DTtPLMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQG\nCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgG\nBmeBDAECATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEu\nb3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKG\nKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsG\nAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJz\nYW1sdGVzdC5zd2FtaWQuc2UwDQYJKoZIhvcNAQEFBQADggEBAHnWOLDwhrYWfd7q\n2fwTaiRP/x/tVPocNgi/wgwo6oZzC1Ru/HPjfUmnj11zkOOHeF8cf2BT2diRptPi\nqDc+7HN8GrM87+Deqvjj4pw7j4hwMpcfNd2AzqW4nPmw4LgiRehITtUtMxL9mkDh\neN0pgldD544xQRUdxYmD9nUWiIaTmuxNqusKkqUTD/kO41i+BxIeaWiXsw6IC7o6\nkPPUQHr1h2na805Kjoy5ML8K2EO+kcvFqfo42gtwa7mN38hKB+jbKF5VqqmoSb4m\nln/3lobOqcV8rrFKjvnjC6iNTbdpQ65o8CoOcfzhWmb/7RxkZ4a9fyzxVS8fMAi6\nu3Qzm3Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFcTCCBFmgAwIBAgIQIu7k1beHBKgWb27d90Ad9jANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQwODAwMDAwMFoXDTE3MDQwNzIzNTk1OVowQDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRswGQYDVQQDExJzYW1sdGVzdC5z\nd2FtaWQuc2UwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCcJfNqCJmM\nCWZ9+h9MAT9WbT/e+eRpGE9H8eucnnq4weTeFbT+2Ma15hY8hI6gP4GsDIZsaxTu\nDGgIYXctfnl9MTz+9rlANOo8Wjuz6CJ2trJ6BdhPvkoITuSqmIWkFbmP7/0NGkoG\n167CGp/Eq5yZnUOdiKXquH2S5OCw3mB4HGpjUk7T13cN0jOOPiK2cQhUTuUUMaVO\nei0QblIfK/+9fusfYOjd5uzNg1QZ9FvvbB/wTw4Z11eGcZWKpAprIrbx6iw119eL\nU7dvJhgA96VJmesDQejf96Xtpn7bCbxdyBqw2AtooamyrVjnAeQ8NDXW7td9MUuM\n4/yhN9H+fHTVJNs8dCX5FKayw5YoxF8eTMjRk0ObICMrLl8M/EiOG9Eqfc3TPGTF\ndn81sOGc3WzifRyG5fXUx/Xw9vXVkRAkVO6T4n6OUQxn2be9hwXR7yFw9tTplPIl\ndabhc7iWU7NgEBcBI3RWCcRNv0OVsXIMDeGZ64SOm4mpKbXMVebsnSLXxV69T1l4\nM8EegMpraRWHrbtF27FkKZPZgCbNaQbfW4vtJoN9rN07Flz8GLr200WXAepXT14L\ndGwXqjx6Cu2oilkl2OoNWQbRg3dvn1j6XqnRLbio4bvuiCYYEPpjuWcHOs/GwMnz\npml7EL51yz9PTwNZTQXsLH/xKlzWf1BuBQIDAQABo4IBbzCCAWswHwYDVR0jBBgw\nFoAUDL2TaAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFG40O0IHvLK2kXS6s4hN\nCq0DTtPLMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQG\nCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgG\nBmeBDAECATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEu\nb3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKG\nKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsG\nAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJz\nYW1sdGVzdC5zd2FtaWQuc2UwDQYJKoZIhvcNAQEFBQADggEBAHnWOLDwhrYWfd7q\n2fwTaiRP/x/tVPocNgi/wgwo6oZzC1Ru/HPjfUmnj11zkOOHeF8cf2BT2diRptPi\nqDc+7HN8GrM87+Deqvjj4pw7j4hwMpcfNd2AzqW4nPmw4LgiRehITtUtMxL9mkDh\neN0pgldD544xQRUdxYmD9nUWiIaTmuxNqusKkqUTD/kO41i+BxIeaWiXsw6IC7o6\nkPPUQHr1h2na805Kjoy5ML8K2EO+kcvFqfo42gtwa7mN38hKB+jbKF5VqqmoSb4m\nln/3lobOqcV8rrFKjvnjC6iNTbdpQ65o8CoOcfzhWmb/7RxkZ4a9fyzxVS8fMAi6\nu3Qzm3Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://samltest.swamid.se/acs/coc/redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://samltest.swamid.se/acs/coc/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sso.bl.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mulholand"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:janice.mulholland@bl.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Janice"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wicks"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Guy.Wicks@bl.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Guy"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.bl.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-08T10:16:08Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEDCCAfigAwIBAgIVALBlb0xD9RVnJc/iRBgGkyuuv6vzMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBQxEjAQBgNVBAMMCXNzby5ibC51azAeFw0xNTExMjUxNjA4MDZaFw0zNTEx\n\t\t\t\t\t\tMjUxNjA4MDZaMBQxEjAQBgNVBAMMCXNzby5ibC51azCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBALV1sBlNUZVsWVfQI38jlRlndRGuKVJkbKv0LAXkuCRW\n\t\t\t\t\t\t1yVfVzC481huMNTDX+3CYb1lkM9IpA3EQnK0PFB79ADvtlQuTAeLZnbHnSuNXtoO\n\t\t\t\t\t\tUw3klvdKWjUjB4QC6FI8XS9oYiBwnogW8IH8O40CAAJLgbFuyqeLkFGS4BBk5hKf\n\t\t\t\t\t\t3Q42eq2So0K4piamfZbMlhdwB1Eovd5YyAN8qISTiDKlEd+BL8ZnB2dvHliSf7BV\n\t\t\t\t\t\tSP9nxptQ9ncooTErBJhycTQhIB7OlBXPPD9/emJqlVm8njxGHCqufYI6oHSQdg2Z\n\t\t\t\t\t\t/+4lx2cRrpDKr7ROb/5W9gZBCXYDlUQhHYl2GOa7MRUCAwEAAaNZMFcwHQYDVR0O\n\t\t\t\t\t\tBBYEFIHLjm+wCv758W1MN5NooNkCbsM3MDYGA1UdEQQvMC2CCXNzby5ibC51a4Yg\n\t\t\t\t\t\taHR0cHM6Ly9zc28uYmwudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAAdklLJrCnZ7a42MWalgiF3Jxch554vKu672us0vIbC4YHOFg3znXGFMQN6s\n\t\t\t\t\t\tXgfQfwGZvvNvzf2SGvH8p20jjcn/WVKnTNtAUgRT/KQHnAktoASFoLHNY/x+HsWT\n\t\t\t\t\t\t/wHJw9Sr+eEFPet9lYN9JJu0U8sSC1NKf+kjRcJG7K/6kABscqRVTOJ8fVZzKoz/\n\t\t\t\t\t\twUBZw8uhw9U8kad0nyga7JCTMMqX5RvveFIAtnkK77XpJ1vm95VE1Udh03uXUvtN\n\t\t\t\t\t\tj4nMh5rBX6K6S1rOl7AkRyUW+Nv7ayWjWiU+ASMxnOeo7nfg1xHKLLTf4dUB23ot\n\t\t\t\t\t\tonq0e4aCSYwqgr4fh8WX2L9+Ncc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bl.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.bl.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.bl.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.bl.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.bl.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.bl.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso.bl.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.bl.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sso.bl.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.bl.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.bl.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.bl.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bl.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://www.bl.uk/britishlibrary/resources/global/images/bl_logo_100.gif",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "52"
                  },
                  {
                    "text": "https://www.bl.uk/britishlibrary/resources/global/images/favicon.ico",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "British Library"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEDCCAfigAwIBAgIVALBlb0xD9RVnJc/iRBgGkyuuv6vzMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBQxEjAQBgNVBAMMCXNzby5ibC51azAeFw0xNTExMjUxNjA4MDZaFw0zNTEx\n\t\t\t\t\t\tMjUxNjA4MDZaMBQxEjAQBgNVBAMMCXNzby5ibC51azCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBALV1sBlNUZVsWVfQI38jlRlndRGuKVJkbKv0LAXkuCRW\n\t\t\t\t\t\t1yVfVzC481huMNTDX+3CYb1lkM9IpA3EQnK0PFB79ADvtlQuTAeLZnbHnSuNXtoO\n\t\t\t\t\t\tUw3klvdKWjUjB4QC6FI8XS9oYiBwnogW8IH8O40CAAJLgbFuyqeLkFGS4BBk5hKf\n\t\t\t\t\t\t3Q42eq2So0K4piamfZbMlhdwB1Eovd5YyAN8qISTiDKlEd+BL8ZnB2dvHliSf7BV\n\t\t\t\t\t\tSP9nxptQ9ncooTErBJhycTQhIB7OlBXPPD9/emJqlVm8njxGHCqufYI6oHSQdg2Z\n\t\t\t\t\t\t/+4lx2cRrpDKr7ROb/5W9gZBCXYDlUQhHYl2GOa7MRUCAwEAAaNZMFcwHQYDVR0O\n\t\t\t\t\t\tBBYEFIHLjm+wCv758W1MN5NooNkCbsM3MDYGA1UdEQQvMC2CCXNzby5ibC51a4Yg\n\t\t\t\t\t\taHR0cHM6Ly9zc28uYmwudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAAdklLJrCnZ7a42MWalgiF3Jxch554vKu672us0vIbC4YHOFg3znXGFMQN6s\n\t\t\t\t\t\tXgfQfwGZvvNvzf2SGvH8p20jjcn/WVKnTNtAUgRT/KQHnAktoASFoLHNY/x+HsWT\n\t\t\t\t\t\t/wHJw9Sr+eEFPet9lYN9JJu0U8sSC1NKf+kjRcJG7K/6kABscqRVTOJ8fVZzKoz/\n\t\t\t\t\t\twUBZw8uhw9U8kad0nyga7JCTMMqX5RvveFIAtnkK77XpJ1vm95VE1Udh03uXUvtN\n\t\t\t\t\t\tj4nMh5rBX6K6S1rOl7AkRyUW+Nv7ayWjWiU+ASMxnOeo7nfg1xHKLLTf4dUB23ot\n\t\t\t\t\t\tonq0e4aCSYwqgr4fh8WX2L9+Ncc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "British Library"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bl.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The British Library"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.fucape.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Carlos Renato Souza"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "carlosrenato@fucape.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.fucape.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID9DCCAtwCAQAwDQYJKoZIhvcNAQEFBQAwgb8xMDAuBgNVBAoTJ0Z1bmRhY2Fv\nIEluc3RpdHV0byBDYXBpeGFiYSBkZSBQZXNxdWlzYTELMAkGA1UECxMCVEkxJTAj\nBgkqhkiG9w0BCQEWFmNhcmxvc3JlbmF0b0BmdWNhcGUuYnIxEjAQBgNVBAcTCUJv\nYSBWaXN0YTEXMBUGA1UECBMORXNwaXJpdG8gU2FudG8xCzAJBgNVBAYTAkJSMR0w\nGwYDVQQDExRzaGliYm9sZXRoLmZ1Y2FwZS5icjAeFw0xNTA1MTkxMTEyNTVaFw0x\nODA1MTgxMTEyNTVaMIG/MTAwLgYDVQQKEydGdW5kYWNhbyBJbnN0aXR1dG8gQ2Fw\naXhhYmEgZGUgUGVzcXVpc2ExCzAJBgNVBAsTAlRJMSUwIwYJKoZIhvcNAQkBFhZj\nYXJsb3NyZW5hdG9AZnVjYXBlLmJyMRIwEAYDVQQHEwlCb2EgVmlzdGExFzAVBgNV\nBAgTDkVzcGlyaXRvIFNhbnRvMQswCQYDVQQGEwJCUjEdMBsGA1UEAxMUc2hpYmJv\nbGV0aC5mdWNhcGUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCn\n3tnSlQ+G13XgIL+lq1AdNUVrGXs01C8Rhq6hnCN8RG7PNgkQKgaXdQ4cSsFEoj4j\n8JFYdBDBPQnzqZRrZA2an8IpX0iz4sU5tF/o2ege9LiAlt47VoBxXS3ca53QFbKB\nU7aqdVYWdJ3v1fMMoDgfDeTwzHG9mNIM/xzHmJTl/cn+as79zqV5SL80b5PvLLpT\n2zxJXGyBLWj36NBsUAF+8wWJDkgej1jFhmKeD4LrihTKG17769Gy5p7ZlyZRBdnn\nkeSi+eTVEv9d4kP5xpjtyBx2Kk6yK/j8fBL0m1LU2VC1iLbv/YRMLoba6Xi1rE5R\nxAJ8Zke8IohaSYQPY4aTAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAI47DxpRLjUC\nCUMOGHSe/LKTu6hFLDj0O7uCgjTgd18+kQGrPiwc6SOzWbulXi1jrrfKI6rnI1PO\nIvP3upcjS45jcMl3zBVljsVayHR/OWH7n6UJowexBLHmSiAcbrimdedQJkhlO55q\n90YLosc3+VpUqQQsig6/CZbAH8m++mtfXtXdhWVxi7JFKtbndQMRv0LkYxGd420a\n3rj++WpUOJeaKIN2SBP/EDVY5NHYz6ZYsD37K9QLlWuGR7jdJE4H6OftlRgAAU1E\nfH4ipdpb88WsxqPvxI40KormMp6Cp39pyQtMm5JzztVWLeP/pBjUMixByeDbwY4d\nHTlVjz7ufx0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fucape.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.fucape.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.fucape.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.fucape.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.fucape.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.fucape.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.fucape.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.fucape.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.fucape.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fucape.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.fucape.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.fucape.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "FUCAPE - Fundacao Instituto Capixaba de Pesquisa"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "FUCAPE - Fundacao Instituto Capixaba de Pesquisa"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FUCAPE - Fundacao Instituto Capixaba de Pesquisa"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "FUCAPE - Fundacao Instituto Capixaba de Pesquisa"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID9DCCAtwCAQAwDQYJKoZIhvcNAQEFBQAwgb8xMDAuBgNVBAoTJ0Z1bmRhY2Fv\nIEluc3RpdHV0byBDYXBpeGFiYSBkZSBQZXNxdWlzYTELMAkGA1UECxMCVEkxJTAj\nBgkqhkiG9w0BCQEWFmNhcmxvc3JlbmF0b0BmdWNhcGUuYnIxEjAQBgNVBAcTCUJv\nYSBWaXN0YTEXMBUGA1UECBMORXNwaXJpdG8gU2FudG8xCzAJBgNVBAYTAkJSMR0w\nGwYDVQQDExRzaGliYm9sZXRoLmZ1Y2FwZS5icjAeFw0xNTA1MTkxMTEyNTVaFw0x\nODA1MTgxMTEyNTVaMIG/MTAwLgYDVQQKEydGdW5kYWNhbyBJbnN0aXR1dG8gQ2Fw\naXhhYmEgZGUgUGVzcXVpc2ExCzAJBgNVBAsTAlRJMSUwIwYJKoZIhvcNAQkBFhZj\nYXJsb3NyZW5hdG9AZnVjYXBlLmJyMRIwEAYDVQQHEwlCb2EgVmlzdGExFzAVBgNV\nBAgTDkVzcGlyaXRvIFNhbnRvMQswCQYDVQQGEwJCUjEdMBsGA1UEAxMUc2hpYmJv\nbGV0aC5mdWNhcGUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCn\n3tnSlQ+G13XgIL+lq1AdNUVrGXs01C8Rhq6hnCN8RG7PNgkQKgaXdQ4cSsFEoj4j\n8JFYdBDBPQnzqZRrZA2an8IpX0iz4sU5tF/o2ege9LiAlt47VoBxXS3ca53QFbKB\nU7aqdVYWdJ3v1fMMoDgfDeTwzHG9mNIM/xzHmJTl/cn+as79zqV5SL80b5PvLLpT\n2zxJXGyBLWj36NBsUAF+8wWJDkgej1jFhmKeD4LrihTKG17769Gy5p7ZlyZRBdnn\nkeSi+eTVEv9d4kP5xpjtyBx2Kk6yK/j8fBL0m1LU2VC1iLbv/YRMLoba6Xi1rE5R\nxAJ8Zke8IohaSYQPY4aTAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAI47DxpRLjUC\nCUMOGHSe/LKTu6hFLDj0O7uCgjTgd18+kQGrPiwc6SOzWbulXi1jrrfKI6rnI1PO\nIvP3upcjS45jcMl3zBVljsVayHR/OWH7n6UJowexBLHmSiAcbrimdedQJkhlO55q\n90YLosc3+VpUqQQsig6/CZbAH8m++mtfXtXdhWVxi7JFKtbndQMRv0LkYxGd420a\n3rj++WpUOJeaKIN2SBP/EDVY5NHYz6ZYsD37K9QLlWuGR7jdJE4H6OftlRgAAU1E\nfH4ipdpb88WsxqPvxI40KormMp6Cp39pyQtMm5JzztVWLeP/pBjUMixByeDbwY4d\nHTlVjz7ufx0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "FUCAPE - Fundacao Instituto Capixaba de Pesquisa"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "FUCAPE - Fundacao Instituto Capixaba de Pesquisa"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fucape.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fucape.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "FUCAPE - Fundacao Instituto Capixaba de Pesquisa"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "FUCAPE - Fundacao Instituto Capixaba de Pesquisa"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idservice.zuyd.nl/nidp/saml2/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idservice.zuyd.nl/nidp/saml2/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-06-03T14:07:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/9b25cfa7cbe15117b1eca6b7f04fcf5d",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Zuyd Hogeschool"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Zuyd University"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/hszuyd.png",
                    "height": "48",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "45"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Zuyd Hogeschool"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Zuyd University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Zuyd Hogeschool"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Zuyd University"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.zuyd.nl/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.zuyd.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Zuyd Hogeschool"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Zuyd University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://saml.salesforce.com/sunet",
    {
      "entity_id": "https://saml.salesforce.com/sunet",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFYDCCBEigAwIBAgIQQ4KxN7E3aAGP1rpwQm6gZzANBgkqhkiG9w0BAQUFADCBvDELMAk\nGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMR8wHQYDVQQLExZWZXJpU2lnbi\nBUcnVzdCBOZXR3b3JrMTswOQYDVQQLEzJUZXJtcyBvZiB1c2UgYXQgaHR0cHM6Ly93d3cud\nmVyaXNpZ24uY29tL3JwYSAoYykxMDE2MDQGA1UEAxMtVmVyaVNpZ24gQ2xhc3MgMyBJbnRl\ncm5hdGlvbmFsIFNlcnZlciBDQSAtIEczMB4XDTEzMTAxODAwMDAwMFoXDTE3MTAxNzIzNTk\n1OVowgY8xCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpDYWxpZm9ybmlhMRYwFAYDVQQHFA1TYW\n4gRnJhbmNpc2NvMR0wGwYDVQQKFBRTYWxlc2ZvcmNlLmNvbSwgSW5jLjEVMBMGA1UECxQMQ\nXBwbGljYXRpb25zMR0wGwYDVQQDFBRwcm94eS5zYWxlc2ZvcmNlLmNvbTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALJtS/8tJmPZ/CKOz/dJ7MXrgz0MPQKxEAdgrdOFdRj\nsavTY+RviREe+zwjrKd9ZsCS3GltV2GBFD+YxXzuptQr+ZUDC8Vwx+49WQ13D55nmoUJVcB\n1nHlTXBICJQDo87cZ4AIViuSVkUfQRG7BeMfKTMngyGdAOIsnSFwp1ONmRqaIarWTfr2w0S\nNFNPikW9rQjehAF/eh6Ib4H3bJEE/kAwRS4mFJoxEKsiJQhnymqeoVgLMSb3UTS8J9R1RmQ\ni+kisC39NAzVwQjM1X677cdQt0FaF6GlZ97vCH/rpNAJnAVwaWiRNQ32AR2X39rp8DVpSk9\neynNGp1JI/6mIv3ECAwEAAaOCAYcwggGDMB8GA1UdEQQYMBaCFHByb3h5LnNhbGVzZm9yY2\nUuY29tMAkGA1UdEwQCMAAwDgYDVR0PAQH/BAQDAgWgMCgGA1UdJQQhMB8GCCsGAQUFBwMBB\nggrBgEFBQcDAgYJYIZIAYb4QgQBMEMGA1UdIAQ8MDowOAYKYIZIAYb4RQEHNjAqMCgGCCsG\nAQUFBwIBFhxodHRwczovL3d3dy52ZXJpc2lnbi5jb20vY3BzMB8GA1UdIwQYMBaAFNebfNg\nioBX33a1fzimbWMO8RgC1MEEGA1UdHwQ6MDgwNqA0oDKGMGh0dHA6Ly9TVlJJbnRsLUczLW\nNybC52ZXJpc2lnbi5jb20vU1ZSSW50bEczLmNybDByBggrBgEFBQcBAQRmMGQwJAYIKwYBB\nQUHMAGGGGh0dHA6Ly9vY3NwLnZlcmlzaWduLmNvbTA8BggrBgEFBQcwAoYwaHR0cDovL1NW\nUkludGwtRzMtYWlhLnZlcmlzaWduLmNvbS9TVlJJbnRsRzMuY2VyMA0GCSqGSIb3DQEBBQU\nAA4IBAQAEMsL4HAd5uYW3j0SQFX4Opl7p0Vo4o7HKBHCtV4ZjzkSFwvRR9+5zijYqlhe4ou\n1SL4WAWAsTKMTpKz0CL1S9Npt0IcKmIWeRsjJKKznFa8sxHhgEvm3O11a9uVfgvmnwn0VEp\nuTmGvXvIUSAZ5q0CVDgzbGsrjWnZXllgO6krwPonEg6MdFarA87bAkLCrLZ0HqWeUVlf2nt\nfvR7kjr0trUM/EBxPdcPxeMK70EJqku7GMEPOxkexTr2O0yD/2lZM0il+AUuOboZDl0Syfj\nU0N7YIKNKZq5hcoUP/sCpcReMNj0dAWeVYmADrV7LlOVvndgHKcLrUydS/9obQHen"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://sunet.my.salesforce.com?so=00D24000000IrNa",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Salesforce.com"
                }
              ],
              "requested_attribute": [
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.glew.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Love"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:charlie.love@compednet.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Charlie"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Love"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:charlie.love@compednet.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Charlie"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.glew.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-08-13T14:11:19Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Glew"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.glew.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Charles Love trading as Perfect Papers"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.glew.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.glew.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.glew.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.glew.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.glew.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.glew.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.glew.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Glew - Learning Made Simple"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.glew.org.uk/logosml.png",
                    "height": "117",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "256"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Glew"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIJAONwxil6WuG0MA0GCSqGSIb3DQEBBQUAMCsxKTAnBgNV\n\t\t\t\t\t\tBAMTIHMxNTQwNDg4Ni5vbmxpbmVob21lLXNlcnZlci5pbmZvMB4XDTEyMDcyNzEw\n\t\t\t\t\t\tMDQzNFoXDTIyMDcyNTEwMDQzNFowKzEpMCcGA1UEAxMgczE1NDA0ODg2Lm9ubGlu\n\t\t\t\t\t\tZWhvbWUtc2VydmVyLmluZm8wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDRvVh211zdEJqy++pyzLM4OrFLrCIaceSEZNHRM/NvhU3wpeaD3TjACHr96yhg\n\t\t\t\t\t\tFfpAtnwv2psto3uOGqtrRLFr5pEAxw+8j3FE3tCu896V3XTque8LrKbYTvBErWd0\n\t\t\t\t\t\tyYyU/38mX5roVlI6s8Jyl+sOox6BfQsy1slMD9EOL/8qd7rfE0uftvZ63SMJJRea\n\t\t\t\t\t\tUPP3oMJW6k5C+n1uHPUbfakcVjuxd32Cd6oPiEaVpBW6/um10tfdAV0xA2i7pQBr\n\t\t\t\t\t\tq8yfRantSUAUUOyGjLB19P63/r8BzkgVnkhkcJy/mzbju4240lZvNFzJEaqq7in0\n\t\t\t\t\t\tKFAa6GE9QmRySrx7J/aaRDqVAgMBAAGjTjBMMCsGA1UdEQQkMCKCIHMxNTQwNDg4\n\t\t\t\t\t\tNi5vbmxpbmVob21lLXNlcnZlci5pbmZvMB0GA1UdDgQWBBSn6CELRx3aEXbVPcA3\n\t\t\t\t\t\tZ5LHvXlUtDANBgkqhkiG9w0BAQUFAAOCAQEAw2OvHP2BT1/KtDrbojIQRjTHJgl/\n\t\t\t\t\t\tz2ufah7O8fc+u9Vms9hu6KTGytQYjs9R+mjI9Jh39QQn+Cgx63oq6p7lHxnb74dC\n\t\t\t\t\t\twmWYEq1ZVtj1O1YwWeZqN1JozQQPpnET3bDW3qK9H7e+LSdmpIr7fYC0vYFoSIpa\n\t\t\t\t\t\t0wgVD2/V6Km5hQbrFhvsmUSKgyuUZjlRPhiD3vE3UxGfKhAS3Y5aE8u43AwuPfXK\n\t\t\t\t\t\trHHEMaX104getbCsdeCtrOUdq+RwO6+hLEsBiNnIacKNOt1evrdDXDd02exSTXSe\n\t\t\t\t\t\t606yHgGge9GO5GNooVTWmR5/DXyoAlDSxbnZpXzwvczR4exkYd2lb9a7mA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.glew.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.glew.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.glew.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.glew.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.glew.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.glew.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.mit.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.mit.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.mit.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.mit.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.mit.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.mit.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.mit.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.mit.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.mit.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3-projektets Migrations-, Integrations- och Testmilj\u00f6 (MIT-milj\u00f6n)"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 MIT"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.mit.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.mit.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJANNcGylEJgt3MA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEHd3dy5taXQubGFkb2suc2UwHhcNMTMwNDExMDcwMDQ3WhcNMjMwNDA5MDcw\nMDQ3WjAbMRkwFwYDVQQDExB3d3cubWl0LmxhZG9rLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAswDSRA8IdF5WRRtQ9BPH2bscDtgLSzXAhk3JdshV\nBQN2zlrewF0FAulDEm7Lv4Ci1n9/mT0ITxvybvB0KD6WrS1ac0sWk8gXenT2Qs9l\ndgOJjRpF2lH2E5nK063xFauLngf1EGFiPxN7Gaiq58dk8NWchcfW3mHuN4gQZi1k\nUH6hBXuuaIyDWyigyUzEUsTVDFhcLeIfylDSoM4wcL0QuBqFYBb4MyF6XLBCcQLe\nA+ugJMNmn/I4AzIdXF3WuopCYp3UWwhwKSwN57vdHMvi3E/9tXVVKZS8q4bdV3vF\nNgfvBrwWW3Aoq2KRB9jXH2fV3uUsXA4Hfre3ZetxO6cW6wIDAQABo18wXTA8BgNV\nHREENTAzghB3d3cubWl0LmxhZG9rLnNlhh9odHRwczovL3d3dy5taXQubGFkb2su\nc2UvZ3VpLXNwMB0GA1UdDgQWBBQCB2VdO4d6ZY49UjaP0Wfm92LyJjANBgkqhkiG\n9w0BAQUFAAOCAQEAGO6QVRj8GjZNg0Z7wTVSQQVlTQhqp4OZIqNKgAFQNDd6sXc4\nXe8AtIwcE6U7afG1R1uC80XE2HumOL84GqExtz23aLDKenFxe6w/QVRKXgDqYDjE\nVABSgE00pa3zSaDlBu6GpmcXsSjVyB5x641Si9oxZf6rhvqW1Lu/Lp+0FmX1DWmK\nNZfFVjy4HWD10ZYih94AG1VYNvy9nb17V+8s64tLdjhMZYoDHoONPtxNIEal5uvQ\nvkwILAtVdnYhq7OrK0V41hm5A5BLnyDf/nJAJVEAt+FAn4TDZzMvqtO4x1r1gvPh\nhiXdvSpPHS4gwfMsYQ0SMmpyUlBMG0J8lN57vA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.mit.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.mit.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.mit.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.mit.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.mit.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.mit.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.mit.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.mit.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.mit.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.mit.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.cirrusidentity.com/idp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@cirrusidentity.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Cirrus Identity Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "security@cirrusidentity.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Cirrus Identity Security"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@cirrusidentity.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Patrick Radtke"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cirrusidentity.com/idp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cirrusidentity.com/idp/SLOService/HTTP-Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cirrusidentity.com/idp/SSOService/HTTP-Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cirrusidentity.com"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Cirrus Identity employees."
                  }
                ],
                "logo": [
                  {
                    "text": "https://apps.cirrusidentity.com/console/static/images/cirrusidentity-ipad-144.png",
                    "lang": "en",
                    "height": "144",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "144"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://cirrusidentity.com/about/privacy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Cirrus Identity, Inc."
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID+jCCAuICCQDuv6UDX8Sf4zANBgkqhkiG9w0BAQUFADCBvjELMAkGA1UEBhMC\nVVMxEzARBgNVBAgTCkNhbGlmb3JuaWExEDAOBgNVBAcTB09ha2xhbmQxHjAcBgNV\nBAoTFUNpcnJ1cyBJZGVudGl0eSwgSW5jLjEcMBoGA1UECxMTQ2lycnVzIElkZW50\naXR5IElkUDEfMB0GA1UEAxMWaWRwLmNpcnJ1c2lkZW50aXR5LmNvbTEpMCcGCSqG\nSIb3DQEJARYac3VwcG9ydEBjaXJydXNpZGVudGl0eS5jb20wHhcNMTQwMTIzMTky\nMjAwWhcNMzQwMTIyMTkyMjAwWjCBvjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCkNh\nbGlmb3JuaWExEDAOBgNVBAcTB09ha2xhbmQxHjAcBgNVBAoTFUNpcnJ1cyBJZGVu\ndGl0eSwgSW5jLjEcMBoGA1UECxMTQ2lycnVzIElkZW50aXR5IElkUDEfMB0GA1UE\nAxMWaWRwLmNpcnJ1c2lkZW50aXR5LmNvbTEpMCcGCSqGSIb3DQEJARYac3VwcG9y\ndEBjaXJydXNpZGVudGl0eS5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQC7Bcp2eHUniOxeNqM0RVZlfeS8p/7XfJBa/Gdp4CMrpxXNzgVqyXwwkSuQ\nmHE9syDuxrhlggk5qHBf19vyCh6GYgKdNJf/v+b4YJ7cp48hSniVVCKHEOq4gMb+\np5d8iAYPFITxU7juJjDbovb9togCo9bLTYTVomo1i/tEoCLmDWZ4NpJOwaDU0HJO\nxmMi3AuSbfnrZvEZNTIvI6Xs0h0Ix2pqI2uIfJrgGssRubV0sqNJBvzUWjEg2Ozz\nBFiuAR1xHiGQDM651EmSow0TzxW54osdQWmlq+TqWQeMbZalRCwhRG2PATip0rMm\nLsxxDxXXPpvbtEy9BxzKK3Vh+21rAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAHG1\niVl6WziIuLTA3F6sZ+C0rnESIVuvahJ1FHL6B0mPDKE2AazM+fzD6SIPgXxzFi/P\nhRHrhSa/XQ6i8gHqpACtURnJpPBy4mpM2ykA+40VJniwFpjeqe3t5PDYOsYxo4LZ\npavOLU3ty7oitsVi+P2rC0LOE7Nn4lslc7Ah1J2unfyzAx9GBdeGu3TXmeBh4P3g\nJvbaSUb9vNgYNja2LTw2akvA9sOZis5VSqOyG9kU/6jBONiKqioQzTTVb+H/Mw2v\n/RrmIthzClneATCN70+7IYQUKe+jIksRg7CnWLJAXdHOI1vHxF0TV8Zk6VXOvLYF\n2DR8dnwEcMytTiMxvGk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cirrus Identity, Inc."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://cirrusidentity.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cirrus Identity, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.serc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mulholland"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:emulholland@serc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Elaine"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Francis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mfrancis@serc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.serc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-08-18T10:34:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDdjCCAl4CCQCag8g+o0iWVDANBgkqhkiG9w0BAQUFADB9MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEUMBIGA1UECBMLQ291bnR5IERvd24xDzANBgNVBAcTBkJhbmdvcjEnMCUGA1UE\n\t\t\t\t\t\tChMeU291dGggRWFzdGVybiBSZWdpb25hbCBDb2xsZWdlMR4wHAYDVQQDExVzaGli\n\t\t\t\t\t\tYm9sZXRoLnNlcmMuYWMudWswHhcNMTQwMjI4MDkyNzQ3WhcNMzQwMjIzMDkyNzQ3\n\t\t\t\t\t\tWjB9MQswCQYDVQQGEwJHQjEUMBIGA1UECBMLQ291bnR5IERvd24xDzANBgNVBAcT\n\t\t\t\t\t\tBkJhbmdvcjEnMCUGA1UEChMeU291dGggRWFzdGVybiBSZWdpb25hbCBDb2xsZWdl\n\t\t\t\t\t\tMR4wHAYDVQQDExVzaGliYm9sZXRoLnNlcmMuYWMudWswggEiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tAQUAA4IBDwAwggEKAoIBAQDENh+SLa6LWOKed5gS07GYyu6+XW7RVMQ+hutgiqxO\n\t\t\t\t\t\trOnTzAmZTxJTIvwmaRsk37+z3n/rsU5YDosjMTlO0Wl1C7xruvOAHd2K44HHrb16\n\t\t\t\t\t\tX+A4pK7znx9FMt8n0i/stUVQMhh8ir/sZlOjQz0uat4y3HtioZybengGjkNL7iM9\n\t\t\t\t\t\ttG31fIwpOYBlfNVknslvVUFYLsnVOnlEcZ0O+5WlYnHa8Qd6Ay4XiA2VdkICAIdN\n\t\t\t\t\t\t10jIMe0hV/2hBnIIxSdGwRghNhcTMmN/80xV59XX6QkXtpZy/Gd9L5BQfabfQyFm\n\t\t\t\t\t\ttRF+hcMgW7tqqpp+KFnXjG/WMzuOhBJjSqfZGZcjQUThAgMBAAEwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBACrmmmqUQY1zCfiSNfeTPob6wNDyJh1XglgeR5hUuQRuHrNCT2D5\n\t\t\t\t\t\ttDERide7jZM0FYzXFuovuoMtHr7uHyK3qOEqYzWlS6Z9hwMqYZm5jXZ4zSfExu9p\n\t\t\t\t\t\tEyeDHLmQt0/PZPb25hQrWUHCvnqbu3d5ScAVVh9gJ4CpFmaustbEXckAdabDm5bR\n\t\t\t\t\t\tK69fc1XerX5HiEz1kSI0AGecOS4aHq5B1LgKWodL9JIvJi3de1GNSxG7OCOPINA7\n\t\t\t\t\t\tQ6PnTqInoOWw8Nbb9h640tVD/hxkUJcvfM+2bwOi5JSB4oRWCTgNeKxuf3K9YGYG\n\t\t\t\t\t\t/d3Km0PXmZriNGP8T6lbBW5Hx3qcVGcfoL8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "serc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.serc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.serc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.serc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.serc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.serc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.serc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.serc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.serc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "serc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDdjCCAl4CCQCag8g+o0iWVDANBgkqhkiG9w0BAQUFADB9MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEUMBIGA1UECBMLQ291bnR5IERvd24xDzANBgNVBAcTBkJhbmdvcjEnMCUGA1UE\n\t\t\t\t\t\tChMeU291dGggRWFzdGVybiBSZWdpb25hbCBDb2xsZWdlMR4wHAYDVQQDExVzaGli\n\t\t\t\t\t\tYm9sZXRoLnNlcmMuYWMudWswHhcNMTQwMjI4MDkyNzQ3WhcNMzQwMjIzMDkyNzQ3\n\t\t\t\t\t\tWjB9MQswCQYDVQQGEwJHQjEUMBIGA1UECBMLQ291bnR5IERvd24xDzANBgNVBAcT\n\t\t\t\t\t\tBkJhbmdvcjEnMCUGA1UEChMeU291dGggRWFzdGVybiBSZWdpb25hbCBDb2xsZWdl\n\t\t\t\t\t\tMR4wHAYDVQQDExVzaGliYm9sZXRoLnNlcmMuYWMudWswggEiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tAQUAA4IBDwAwggEKAoIBAQDENh+SLa6LWOKed5gS07GYyu6+XW7RVMQ+hutgiqxO\n\t\t\t\t\t\trOnTzAmZTxJTIvwmaRsk37+z3n/rsU5YDosjMTlO0Wl1C7xruvOAHd2K44HHrb16\n\t\t\t\t\t\tX+A4pK7znx9FMt8n0i/stUVQMhh8ir/sZlOjQz0uat4y3HtioZybengGjkNL7iM9\n\t\t\t\t\t\ttG31fIwpOYBlfNVknslvVUFYLsnVOnlEcZ0O+5WlYnHa8Qd6Ay4XiA2VdkICAIdN\n\t\t\t\t\t\t10jIMe0hV/2hBnIIxSdGwRghNhcTMmN/80xV59XX6QkXtpZy/Gd9L5BQfabfQyFm\n\t\t\t\t\t\ttRF+hcMgW7tqqpp+KFnXjG/WMzuOhBJjSqfZGZcjQUThAgMBAAEwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBACrmmmqUQY1zCfiSNfeTPob6wNDyJh1XglgeR5hUuQRuHrNCT2D5\n\t\t\t\t\t\ttDERide7jZM0FYzXFuovuoMtHr7uHyK3qOEqYzWlS6Z9hwMqYZm5jXZ4zSfExu9p\n\t\t\t\t\t\tEyeDHLmQt0/PZPb25hQrWUHCvnqbu3d5ScAVVh9gJ4CpFmaustbEXckAdabDm5bR\n\t\t\t\t\t\tK69fc1XerX5HiEz1kSI0AGecOS4aHq5B1LgKWodL9JIvJi3de1GNSxG7OCOPINA7\n\t\t\t\t\t\tQ6PnTqInoOWw8Nbb9h640tVD/hxkUJcvfM+2bwOi5JSB4oRWCTgNeKxuf3K9YGYG\n\t\t\t\t\t\t/d3Km0PXmZriNGP8T6lbBW5Hx3qcVGcfoL8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "South Eastern Regional College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.serc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "South Eastern Regional College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://edugate.heanet.ie/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wearen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:glenn.wearen@heanet.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Glenn"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "HEAnet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:noc@heanet.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NOC"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "HEAnet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:noc@heanet.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NOC"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://edugate.heanet.ie/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.heanet.ie/services/identity-access/edugate#join"
              }
            ],
            "registration_instant": "2010-11-01T00:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://edugate.heanet.ie/rr3/p/page/HEAnetInternalEC"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "HEAnet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://edugate.heanet.ie/rr3"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HEAnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://edugate.heanet.ie/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://edugate.heanet.ie/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://edugate.heanet.ie/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://edugate.heanet.ie/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "0"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://edugate.heanet.ie/rr3"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Edugate Resource Registry"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Edugate Resource Registry website is a central administration tool for managing the Edugate federation and additional bilateral relationships. This website also serves \nThe website will process your userid, name and email address to authorise access. Further data is used for the Whoami section of the website for troubleshooting purposes only and this additional data is not retained after you logout/leave the site."
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/edugate.png",
                    "height": "108",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "306"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://edugate.heanet.ie/rr3/p/page/privacy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFbjCCA1YCCQCB0T3DNIZANDANBgkqhkiG9w0BAQUFADB5MQswCQYDVQQGEwJJ\nRTEPMA0GA1UECBMGRHVibGluMQ8wDQYDVQQHEwZEdWJsaW4xEzARBgNVBAoTCkhF\nQW5ldCBMdGQxEDAOBgNVBAMTB0VkdWdhdGUxITAfBgkqhkiG9w0BCQEWEnN1cHBv\ncnRAZWR1Z2F0ZS5pZTAeFw0xMDAzMDUxMTEwMTdaFw0yMDAzMDIxMTEwMTdaMHkx\nCzAJBgNVBAYTAklFMQ8wDQYDVQQIEwZEdWJsaW4xDzANBgNVBAcTBkR1YmxpbjET\nMBEGA1UEChMKSEVBbmV0IEx0ZDEQMA4GA1UEAxMHRWR1Z2F0ZTEhMB8GCSqGSIb3\nDQEJARYSc3VwcG9ydEBlZHVnYXRlLmllMIICIjANBgkqhkiG9w0BAQEFAAOCAg8A\nMIICCgKCAgEA01w+k8x58Sqqs+X0a/vScGc2g4BMBO0KE9lXujcNpXX+fwkzAhLK\nkQuvMtp0sSn7/WrsGa5MNSm5Z6+U3yGV3VCNRlUuiPdPe4zzXaMV3lPGDPNZeSTD\nBMlDXGALtzWBlAriQhctfvjamBRYwXrC0KDFkUCNu6DphR8bjBHhWFx9V20oQ75o\n3wLC7irMa09JkJpc82SVg3PqJ3ogt9Y0BTuqUgoiSGZIoTCsLrkLUotSZOkzxRQq\nu3nVL7cEFEWRmVEkaD3qjq6epo4EHDSUO6HB6WCV5gDccgGb0A5yCIvQY7SjEaaY\nhKmVMixwdki44+hNFPP5Qv+4A5NPxUVlAB8WzdRsrTTc4wDW4XDDAF7+0NmNZECc\nwN9/tLZROATQiFg6Fsmzar39DZos5EUo+4L/ozL8yBXOqdTwrTKKwrWmaQQTDpO6\nASxGFWyXFbWIoun6/iUSpSgTnjRpgTnGVwFRmMV3bI7jd3egNemNhHZgwQ8js88N\neQK2Uq3kjNa33NSEjpFNYShR7Tg4d8OUmdCdR3olakF/W6huToc46Skfp783+yqo\nL6qQ5xwL6XCeeB9EFtuGyy/J578W70Y5N0QnlIO14ShfBhMH9DL+wxidVuriJlrM\nmx130sELvNIpPJHf4gXpGAWDhxn2QqMAu1QK0+EueWfZTddglzRrk70CAwEAATAN\nBgkqhkiG9w0BAQUFAAOCAgEAhImtRqXMbxZNIog0TgaQvy62DFtbABS0FCM/xMGo\nvuY5l7YF/ot5SNE4MqWYX1pyOQRVIELuvNByH+FLKDmF6jyU9U0c8w9c6Uhf7Zs/\n0lgIfpR8LGvTHiNjbSuy6aCK+0JxGugaZZloSmGkIir9Yi6MQr8HOLdCkRYCISZQ\npdGJFTwwDEoUDVr0szV4Aupm3wI/MtU80clwrHiVVyY0BoHc63gZ6j3Bn2BiuIb8\npnxV3nwDnU9pSxkaBAH8Mo6zTo3dM9kdfdXlKvU3VIZ60O/Y8E2FZIKgqUK3enab\nYnX59OpeUExsaEUYRav5CQQlnNoYTOfG5E/foM4ojZhDv8hfeJmnvTjlDvQF4IaC\nWzziDM/1e/mGLjUHShbjv+OaxWBOwQjmPrsqEHTg7iTMTxuHfxnIVnv5/efknDiA\n9QPAVCY5BHH61FMxYfEoIhnLc3qSBGhx1keledDoXRzTyycfZi88Dj2YDBzLCbbT\nKxocVWR5wlAkMpxpFHsLIRp+XYNdc1cG6NQO4eHwoAJ/y1qdGssA9RR9/TEnlKMT\nmUavwgBEqGeMh1w0GwTmXGruoBOZMJNks9WzCmp+3QKsVCjZd/KIxHITq+jNeFRf\nLzMJnF1row2YXqF4AYDluUyCMPo89glxvlX9lDJ3TW5Xz4OJWqrz4WvEyWJIAMZy\nUBY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFbjCCA1YCCQCB0T3DNIZANDANBgkqhkiG9w0BAQUFADB5MQswCQYDVQQGEwJJ\nRTEPMA0GA1UECBMGRHVibGluMQ8wDQYDVQQHEwZEdWJsaW4xEzARBgNVBAoTCkhF\nQW5ldCBMdGQxEDAOBgNVBAMTB0VkdWdhdGUxITAfBgkqhkiG9w0BCQEWEnN1cHBv\ncnRAZWR1Z2F0ZS5pZTAeFw0xMDAzMDUxMTEwMTdaFw0yMDAzMDIxMTEwMTdaMHkx\nCzAJBgNVBAYTAklFMQ8wDQYDVQQIEwZEdWJsaW4xDzANBgNVBAcTBkR1YmxpbjET\nMBEGA1UEChMKSEVBbmV0IEx0ZDEQMA4GA1UEAxMHRWR1Z2F0ZTEhMB8GCSqGSIb3\nDQEJARYSc3VwcG9ydEBlZHVnYXRlLmllMIICIjANBgkqhkiG9w0BAQEFAAOCAg8A\nMIICCgKCAgEA01w+k8x58Sqqs+X0a/vScGc2g4BMBO0KE9lXujcNpXX+fwkzAhLK\nkQuvMtp0sSn7/WrsGa5MNSm5Z6+U3yGV3VCNRlUuiPdPe4zzXaMV3lPGDPNZeSTD\nBMlDXGALtzWBlAriQhctfvjamBRYwXrC0KDFkUCNu6DphR8bjBHhWFx9V20oQ75o\n3wLC7irMa09JkJpc82SVg3PqJ3ogt9Y0BTuqUgoiSGZIoTCsLrkLUotSZOkzxRQq\nu3nVL7cEFEWRmVEkaD3qjq6epo4EHDSUO6HB6WCV5gDccgGb0A5yCIvQY7SjEaaY\nhKmVMixwdki44+hNFPP5Qv+4A5NPxUVlAB8WzdRsrTTc4wDW4XDDAF7+0NmNZECc\nwN9/tLZROATQiFg6Fsmzar39DZos5EUo+4L/ozL8yBXOqdTwrTKKwrWmaQQTDpO6\nASxGFWyXFbWIoun6/iUSpSgTnjRpgTnGVwFRmMV3bI7jd3egNemNhHZgwQ8js88N\neQK2Uq3kjNa33NSEjpFNYShR7Tg4d8OUmdCdR3olakF/W6huToc46Skfp783+yqo\nL6qQ5xwL6XCeeB9EFtuGyy/J578W70Y5N0QnlIO14ShfBhMH9DL+wxidVuriJlrM\nmx130sELvNIpPJHf4gXpGAWDhxn2QqMAu1QK0+EueWfZTddglzRrk70CAwEAATAN\nBgkqhkiG9w0BAQUFAAOCAgEAhImtRqXMbxZNIog0TgaQvy62DFtbABS0FCM/xMGo\nvuY5l7YF/ot5SNE4MqWYX1pyOQRVIELuvNByH+FLKDmF6jyU9U0c8w9c6Uhf7Zs/\n0lgIfpR8LGvTHiNjbSuy6aCK+0JxGugaZZloSmGkIir9Yi6MQr8HOLdCkRYCISZQ\npdGJFTwwDEoUDVr0szV4Aupm3wI/MtU80clwrHiVVyY0BoHc63gZ6j3Bn2BiuIb8\npnxV3nwDnU9pSxkaBAH8Mo6zTo3dM9kdfdXlKvU3VIZ60O/Y8E2FZIKgqUK3enab\nYnX59OpeUExsaEUYRav5CQQlnNoYTOfG5E/foM4ojZhDv8hfeJmnvTjlDvQF4IaC\nWzziDM/1e/mGLjUHShbjv+OaxWBOwQjmPrsqEHTg7iTMTxuHfxnIVnv5/efknDiA\n9QPAVCY5BHH61FMxYfEoIhnLc3qSBGhx1keledDoXRzTyycfZi88Dj2YDBzLCbbT\nKxocVWR5wlAkMpxpFHsLIRp+XYNdc1cG6NQO4eHwoAJ/y1qdGssA9RR9/TEnlKMT\nmUavwgBEqGeMh1w0GwTmXGruoBOZMJNks9WzCmp+3QKsVCjZd/KIxHITq+jNeFRf\nLzMJnF1row2YXqF4AYDluUyCMPo89glxvlX9lDJ3TW5Xz4OJWqrz4WvEyWJIAMZy\nUBY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://edugate.heanet.ie/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://edugate.heanet.ie/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://edugate.heanet.ie/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Edugate Resource Registry"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The Edugate Resource Registry website is a central administration tool for managing the Edugate federation and additional bilateral relationships. This website also serves \nThe website will process your userid, name and email address to authorise access. Further data is used for the Whoami section of the website for troubleshooting purposes only and this additional data is not retained after you logout/leave the site."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "organizationName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAssurance",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.11",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganizationType",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "commonName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://drive.asnet.am/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hayrapetyan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:andranik@ipia.sci.am"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andranik"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://drive.asnet.am/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2015-08-22T12:46:47Z",
            "registration_authority": "https://aai.asnet.am",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ASNET-AM"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.asnet.am/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Academic Scientific Network of Armenia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://drive.asnet.am/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://drive.asnet.am/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://drive.asnet.am/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://drive.asnet.am/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://drive.asnet.am/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://drive.asnet.am/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://drive.asnet.am/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://drive.asnet.am/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ASNET-AM Drive is an Internet service to store data in Armenian's cloud storage and retreive or work with these data at any time. It provides a simple web interface and a syncing and sharing capabilities for files, as well as native syncing clients for Mac OS X, iPhone, iPad and Windows. All this will be performed in a secure and rebust environment and free of charge."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ASNET-AM Drive"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "*.asnet.am"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "asnet.am"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFkTCCBHmgAwIBAgIRAJGxdi6BndHGs8GWsagMbaYwDQYJKoZIhvcNAQELBQAw\ngZAxCzAJBgNVBAYTAkdCMRswGQYDVQQIExJHcmVhdGVyIE1hbmNoZXN0ZXIxEDAO\nBgNVBAcTB1NhbGZvcmQxGjAYBgNVBAoTEUNPTU9ETyBDQSBMaW1pdGVkMTYwNAYD\nVQQDEy1DT01PRE8gUlNBIERvbWFpbiBWYWxpZGF0aW9uIFNlY3VyZSBTZXJ2ZXIg\nQ0EwHhcNMTUwNjAyMDAwMDAwWhcNMTgwNjAxMjM1OTU5WjCBoTEhMB8GA1UECxMY\nRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMUkwRwYDVQQLE0BIb3N0ZWQgYnkgSW5z\ndGl0dXRlIGZvciBJbmZvcm1hdGljcyBhbmQgQXV0b21hdGlvbiBQcm9ibGVtcyBO\nQVMuMRwwGgYDVQQLExNDT01PRE8gU1NMIFdpbGRjYXJkMRMwEQYDVQQDFAoqLmFz\nbmV0LmFtMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtYnlRhHME8WP\n4x/2SiMMV25dK9HnrJmrssJVi/A/3Om0cSMVyybohqMcWTLq4s6A1kBSy4pEK7Kl\n3M7qaTBUVOkXZZPn/vpOJoaHR71tG/CClNivpN5Q/a3RA6jRjT20pvUApNzQglwN\n23wYPu5Uz1iLjVT53Bq3HnbuYlI7FIjWKyfHonHnYw0CARJHRXeq/ykFngbxj1ie\nsdtVdrpI4hUDk1o85y4rDuvK1HYcMudI8kbfZ1a8l/3jiA4EnNeoe5fbKQDkP63V\ncN2f1cM3Noj1GGAGYX5sY9PY3d0UmBH/8Kzg4i58E8V4EJTwLLYpSfAXO04+e3Bb\nVKCUUz5vywIDAQABo4IB0TCCAc0wHwYDVR0jBBgwFoAUkK9qOpRaC9iQ6hJWc99D\ntDoo2ucwHQYDVR0OBBYEFKjnkZCHfwFjf2kkMGdeTAcM4Q8SMA4GA1UdDwEB/wQE\nAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcD\nAjBPBgNVHSAESDBGMDoGCysGAQQBsjEBAgIHMCswKQYIKwYBBQUHAgEWHWh0dHBz\nOi8vc2VjdXJlLmNvbW9kby5jb20vQ1BTMAgGBmeBDAECATBUBgNVHR8ETTBLMEmg\nR6BFhkNodHRwOi8vY3JsLmNvbW9kb2NhLmNvbS9DT01PRE9SU0FEb21haW5WYWxp\nZGF0aW9uU2VjdXJlU2VydmVyQ0EuY3JsMIGFBggrBgEFBQcBAQR5MHcwTwYIKwYB\nBQUHMAKGQ2h0dHA6Ly9jcnQuY29tb2RvY2EuY29tL0NPTU9ET1JTQURvbWFpblZh\nbGlkYXRpb25TZWN1cmVTZXJ2ZXJDQS5jcnQwJAYIKwYBBQUHMAGGGGh0dHA6Ly9v\nY3NwLmNvbW9kb2NhLmNvbTAfBgNVHREEGDAWggoqLmFzbmV0LmFtgghhc25ldC5h\nbTANBgkqhkiG9w0BAQsFAAOCAQEAAN5hdW1ipGLn9khP5UoSEHFJPuKzR4yzuWrF\nKc1UamsQLWA2SNvN3Lb+4vj+W7q++aBgmGEjfhw/BWQzFOXfeHHYb8YLBZuweesm\n5neG4kULC4Qpf6tc5LgK0V6geVNHzXnAchLn2KzBhjgMUmvHOJFPSwCJHKSyN2Qc\nlCrQol4CRGiKXH7428yGMgFi2kqdL9xlxxned0/13GfyMVQwUfwmLe2a/HH7nn4k\niNKDKTPbYWvuDjrIuKskC0uBwkvqEunCqE0beN5/bzfA/XiN7VFQm19o6T/8fwFO\nxAkgTb8s+nKQoqK0D7O7EXRzLd/m825ao8+E21sqAhwodilGeg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFkTCCBHmgAwIBAgIRAJGxdi6BndHGs8GWsagMbaYwDQYJKoZIhvcNAQELBQAw\ngZAxCzAJBgNVBAYTAkdCMRswGQYDVQQIExJHcmVhdGVyIE1hbmNoZXN0ZXIxEDAO\nBgNVBAcTB1NhbGZvcmQxGjAYBgNVBAoTEUNPTU9ETyBDQSBMaW1pdGVkMTYwNAYD\nVQQDEy1DT01PRE8gUlNBIERvbWFpbiBWYWxpZGF0aW9uIFNlY3VyZSBTZXJ2ZXIg\nQ0EwHhcNMTUwNjAyMDAwMDAwWhcNMTgwNjAxMjM1OTU5WjCBoTEhMB8GA1UECxMY\nRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMUkwRwYDVQQLE0BIb3N0ZWQgYnkgSW5z\ndGl0dXRlIGZvciBJbmZvcm1hdGljcyBhbmQgQXV0b21hdGlvbiBQcm9ibGVtcyBO\nQVMuMRwwGgYDVQQLExNDT01PRE8gU1NMIFdpbGRjYXJkMRMwEQYDVQQDFAoqLmFz\nbmV0LmFtMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtYnlRhHME8WP\n4x/2SiMMV25dK9HnrJmrssJVi/A/3Om0cSMVyybohqMcWTLq4s6A1kBSy4pEK7Kl\n3M7qaTBUVOkXZZPn/vpOJoaHR71tG/CClNivpN5Q/a3RA6jRjT20pvUApNzQglwN\n23wYPu5Uz1iLjVT53Bq3HnbuYlI7FIjWKyfHonHnYw0CARJHRXeq/ykFngbxj1ie\nsdtVdrpI4hUDk1o85y4rDuvK1HYcMudI8kbfZ1a8l/3jiA4EnNeoe5fbKQDkP63V\ncN2f1cM3Noj1GGAGYX5sY9PY3d0UmBH/8Kzg4i58E8V4EJTwLLYpSfAXO04+e3Bb\nVKCUUz5vywIDAQABo4IB0TCCAc0wHwYDVR0jBBgwFoAUkK9qOpRaC9iQ6hJWc99D\ntDoo2ucwHQYDVR0OBBYEFKjnkZCHfwFjf2kkMGdeTAcM4Q8SMA4GA1UdDwEB/wQE\nAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcD\nAjBPBgNVHSAESDBGMDoGCysGAQQBsjEBAgIHMCswKQYIKwYBBQUHAgEWHWh0dHBz\nOi8vc2VjdXJlLmNvbW9kby5jb20vQ1BTMAgGBmeBDAECATBUBgNVHR8ETTBLMEmg\nR6BFhkNodHRwOi8vY3JsLmNvbW9kb2NhLmNvbS9DT01PRE9SU0FEb21haW5WYWxp\nZGF0aW9uU2VjdXJlU2VydmVyQ0EuY3JsMIGFBggrBgEFBQcBAQR5MHcwTwYIKwYB\nBQUHMAKGQ2h0dHA6Ly9jcnQuY29tb2RvY2EuY29tL0NPTU9ET1JTQURvbWFpblZh\nbGlkYXRpb25TZWN1cmVTZXJ2ZXJDQS5jcnQwJAYIKwYBBQUHMAGGGGh0dHA6Ly9v\nY3NwLmNvbW9kb2NhLmNvbTAfBgNVHREEGDAWggoqLmFzbmV0LmFtgghhc25ldC5h\nbTANBgkqhkiG9w0BAQsFAAOCAQEAAN5hdW1ipGLn9khP5UoSEHFJPuKzR4yzuWrF\nKc1UamsQLWA2SNvN3Lb+4vj+W7q++aBgmGEjfhw/BWQzFOXfeHHYb8YLBZuweesm\n5neG4kULC4Qpf6tc5LgK0V6geVNHzXnAchLn2KzBhjgMUmvHOJFPSwCJHKSyN2Qc\nlCrQol4CRGiKXH7428yGMgFi2kqdL9xlxxned0/13GfyMVQwUfwmLe2a/HH7nn4k\niNKDKTPbYWvuDjrIuKskC0uBwkvqEunCqE0beN5/bzfA/XiN7VFQm19o6T/8fwFO\nxAkgTb8s+nKQoqK0D7O7EXRzLd/m825ao8+E21sqAhwodilGeg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://drive.asnet.am/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://drive.asnet.am/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://drive.asnet.am/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://drive.asnet.am/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://drive.asnet.am/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://drive.asnet.am/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ASNET-AM Drive"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "ASNET-AM Drive is an Internet service to store data in Armenian's cloud storage and retreive or work with these data at any time. It provides a simple web interface and a syncing and sharing capabilities for files, as well as native syncing clients for Mac OS X, iPhone, iPad and Windows. All this will be performed in a secure and rebust environment and free of charge."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "uid",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.liebertonline.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.liebertonline.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-02-17T17:28:20Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mary Ann Liebert, Inc. publishers"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.liebertpub.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://online.liebertpub.com/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://online.liebertpub.com/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://online.liebertpub.com/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJAKDOIiXpyPeZMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\n\t\t\t\t\t\tBAMTFW9ubGluZS5saWViZXJ0cHViLmNvbTAeFw0xNDAzMTQwNTAzNDlaFw0xNzAz\n\t\t\t\t\t\tMTMwNTAzNDlaMCAxHjAcBgNVBAMTFW9ubGluZS5saWViZXJ0cHViLmNvbTCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAM7/SYDfsaPbVYvAvpyFaTm0N9gF\n\t\t\t\t\t\tF3WclCufGBuJBHr985O6elVYWrANB0CLyIdUlHN6eCKTcZTv+aKD4gHX4ECDxnfj\n\t\t\t\t\t\tozWWL8e2xbAAWq7Q9e8Br9UQGMFcVe4n3gOoeazUDBXMDMR/XC9zX4SZgUij6Zk6\n\t\t\t\t\t\t1W3sNHXkT/+olQriyyWD9UmF+TZcqySxQaaiDXen3yVsqU542slFWHLCXN9DZGZ4\n\t\t\t\t\t\tPtmBPInLWFD1D9oyXwg7F+nlielFxbY2MlT01O4URSZb8cIOOgXDGqFhcL1EytTY\n\t\t\t\t\t\t3FTQXgoa3gVFVz00u/zHyCIT7HjoDUcUSrbR/FTy5l2JVomFwY6BeQLVRCkCAwEA\n\t\t\t\t\t\tAaNtMGswSgYDVR0RBEMwQYIVb25saW5lLmxpZWJlcnRwdWIuY29thihodHRwczov\n\t\t\t\t\t\tL29ubGluZS5saWViZXJ0cHViLmNvbS9zaGliYm9sZXRoMB0GA1UdDgQWBBTUYAZ/\n\t\t\t\t\t\tlW3+Qwv4itlnK8u9Mnus5jANBgkqhkiG9w0BAQUFAAOCAQEADCOUTrrLrH0I6BAO\n\t\t\t\t\t\taYbHu8hxIiwLKln0jUmCNcLhYfSDNErdCBkQ65FT7fuVFIBNFmvvmYbbelgVT5O+\n\t\t\t\t\t\tgRN63p56RN9YSHGm4vTz59WWKlce6db87ZYy5SJneyOsVSj1eQ3VXA2mTV/v7beH\n\t\t\t\t\t\tTvKOCRq1pLXrTW3CyvdBHbKCdXqN9JHXSc0Hw4afGEOecnrq3DoyBxh3/LX6i4Ty\n\t\t\t\t\t\tkphk7xLp8dhGzs767f6GflqekCETspWcenJAJkzztaZfVr5AUMU4/nzhCEbTb6L3\n\t\t\t\t\t\tH4DFy1CDquP13ggw0RaFwt090YnGMoTxkwIHbNHOk0b3ja9yD2qxqfNmnGPscktq\n\t\t\t\t\t\tghHcPQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.liebertpub.com/nv/company/about-us/1/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": ">Mary Ann Liebert publishes integrated media content in biotechnology, biomedical research, clinical medicine and surgery, among others."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mary Ann Liebert"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://www.cartoons.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@kent.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ferguson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:B.Ferguson@kent.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bonnie"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.cartoons.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-03-09T14:10:51Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Kent: British Cartoon Archive"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cartoons.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Kent"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cartoons.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.cartoons.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cartoons.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cartoons.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cartoons.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.cartoons.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.cartoons.ac.uk/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.cartoons.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.cartoons.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICzjCCAbagAwIBAgIBADANBgkqhkiG9w0BAQUFADAQMQ4wDAYDVQQDEwVjd3d3\n\t\t\t\t\t\tMTAeFw0xMDAyMjMxNjExMzVaFw0yMDAyMjExNjExMzVaMBAxDjAMBgNVBAMTBWN3\n\t\t\t\t\t\td3cxMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAwMqCZUo+LIGMYOD5\n\t\t\t\t\t\tRIfyspWlagIPIp81zGdqqM1rIEpM95QLHfssoJXY69P/Iojfdb/x8K3GJ+nWQNoe\n\t\t\t\t\t\tCANW8N5JRnZl+jKYqUcFMFUgxKmuccO/2zSiu9M8ad+fOgtm6wWWJq9F9yefYAuT\n\t\t\t\t\t\tRE+k9thXcilCIY681eBEuHdI1hjvldVXV+P61cdJp3L4WmjD2f7GR6TurFe1P94x\n\t\t\t\t\t\tpFsTYGptvxWPTp6w8g/WEdGi+UAmqYoKdBRv1rNLuiYOoRnlhDp9+CvPrOdBTijI\n\t\t\t\t\t\tGFqXlq/w0MaAIIJgZPgJTjFKrzN3rt/5dv3SDDfzhduoE5ox8WPZmNm21cIhCokF\n\t\t\t\t\t\tjv/8kwIDAQABozMwMTAQBgNVHREECTAHggVjd3d3MTAdBgNVHQ4EFgQU7CyjvMqG\n\t\t\t\t\t\t8d2QhxGXK+Xbt8Ppb2MwDQYJKoZIhvcNAQEFBQADggEBAAONU7dbP1sXpO9fIHn6\n\t\t\t\t\t\trYjQ1g5z8qoBHYGWnjJI6bnY687kxC6j4lGZ/aK2fhWSlXZet/Vazmhy8ZC2I8TI\n\t\t\t\t\t\tsg+YUsVBdgnFGZQXZtD/4I/Fn2pjFRfathgbsIll1nKOcJJApxXKYXimNcRHPbpo\n\t\t\t\t\t\t2IT6jesMavssckqXL+yrs+/Y93zD3LsKpv4JqCXlnd++WsQTrWiqfrlV2hUbeoj/\n\t\t\t\t\t\thQORVPgsCNo4frw2GhEgMf7x+2ExtEU2YOGoshYn2LgR8wSFVu4SqHOvUFXvpibY\n\t\t\t\t\t\tME7Ylv10JKK8LtZy3SD0t9MmDQewAgi5hIH4UbXYXx3mNGcidUnc42Due57YgYE2\n\t\t\t\t\t\tDXY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.cartoons.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.cartoons.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cartoons.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cartoons.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.cartoons.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.cartoons.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.cartoons.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.cartoons.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.cartoons.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.cartoons.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://demeter.wp.swov.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://demeter.wp.swov.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-04-03T16:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/e2a066fa3b3772e968e201eea790f925",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "swov.nl"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wp.swov.nl"
              },
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Stichting Wetenschappelijk Onderzoek Verkeersveiligheid SWOV"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SWOV Institute for Road Safety Research"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/swov.png",
                    "height": "118",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "425"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Stichting Wetenschappelijk Onderzoek Verkeersveiligheid SWOV"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SWOV Institute for Road Safety Research"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Stichting Wetenschappelijk Onderzoek Verkeersveiligheid SWOV"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SWOV Institute for Road Safety Research"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.swov.nl/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.swov.nl/index_uk.htm"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Stichting Wetenschappelijk Onderzoek Verkeersveiligheid SWOV"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SWOV Institute for Road Safety Research"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-13.ladok.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-13.ladok.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;13"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;13"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-13.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-13.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAMXbiREMrLiUMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0xMy5sYWRvay51bXUuc2UwHhcNMTUwMTIwMTExMTM2WhcNMjUw\nMTE3MTExMTM2WjAhMR8wHQYDVQQDExZsYWRvazMtMTMubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtRF7svmvMWTEPNaLtCif5dHs\nfCfLGEClaVF1tu0rSqO1pQ8S6/edCspkSQH0iQh6gD/F6mKjwjSAA0/PLxtPYPis\nz+X2g0QetDiyWzhJBw6V+9E5oRhq+aicQKTEsaRFP9A+dHIHkYakqfbiNIaRYYFp\nGOyXjvFi+c7lJrNCEyXtH0pMdTrmL1zsYSvw4NlDtdw6QBHK2N18cmZkdYKgRBms\n0TP2UKZw11WUxMaQPfQ3u46XlUzQJMRO1YDoLsVAXf33hl8iEjqo6rO5HpVRKT+r\njIOKuFaLJyr5AJ94AItwGq4BfJJOkfEo6momE8tJsX04O/hW3BWVKVG8QMLDcwID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMTMubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0xMy5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUxX3vj2H37MihBerj734SQJqS4LUwDQYJKoZIhvcNAQEFBQADggEB\nAJDaZCNDvYQS9YHULOb2gdRVwGUa2FvZX/UNXpVMfuQD7zS+2XA43kwu+sA+Z8zi\n4er1FcMqLznERGYuOwGM10We4Ym319GOPKx8j0T7gnZS2AvgxLzKW9rDNdwpS24d\naw9k/k8UKy20hfU8Jm1l/cx3rGefd4eucsVwd9Y3wB/Pm0DFjX7yQy+EKHymvy3n\nsi86rS+U2UG300QsYxRhE5JMgP/Od+yOuN0VVyko/j7d8yen22f+1mibrNAVksDC\nIPl4TnqugllClkqYMTdsv3PGbm44zu6DUTTzL4qo/SiXGmxNs9mKCrrIKqdlgN22\nzbxHPKCXMByJo3rJ0WuyUqY="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-13.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-13.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ehesp.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cap-dsit@ehesp.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ehesp.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-10-22T17:13:49Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ehesp.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ehesp.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ehesp.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ehesp.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ehesp.fr/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Staff, Teacher, Student"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnel, Enseignant, Apprenant"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/x-icon;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EHESP - Ecole des hautes \u00e9tudes en sant\u00e9 publique"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EHESP - Ecole des hautes \u00e9tudes en sant\u00e9 publique"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUVzjSNoGKH9lPNn7oKp8d2lcXhuAwDQYJKoZIhvcNAQEL\nBQAwFzEVMBMGA1UEAwwMaWRwLmVoZXNwLmZyMB4XDTE2MDExMjE1MjkxNFoXDTM2\nMDExMjE1MjkxNFowFzEVMBMGA1UEAwwMaWRwLmVoZXNwLmZyMIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmBPBf8tIms1Blh1mqIMdbqfPmbRasasRKJjv\nCsqdyYC1RlAv9x+HKW5gVVyzu5DbCdNZKvWUpKDRjjlaftG5y6tnTSwxDgMV/rUL\nTIvPi4BdYdWMM0NXDW3NccalKnOUh0DJafiQgYEL3CRxOdlN6r63WjL8YNR2tLqQ\nF2t7a2ab9iNF9r3bmzio5CBDRd8L4LmrwXt2cXx1WMnKnHTrX7jaU3IBdhuV5NAR\nr9AQ3ek54TLOxxkbu7tBBSm56ZEY5ZGdOka2IgY/d/u+3Z3YxFEAYrnkkFSSMn2B\nL04+gkR4aSq3nAl2k7JxkVW6WUodgbboNnXRH89LqGOGEtatnQIDAQABo18wXTAd\nBgNVHQ4EFgQUGo/7auDg3wdjcwsti7GubifPxWcwPAYDVR0RBDUwM4IMaWRwLmVo\nZXNwLmZyhiNodHRwczovL2lkcC5laGVzcC5mci9pZHAvc2hpYmJvbGV0aDANBgkq\nhkiG9w0BAQsFAAOCAQEATSMpwd/oRa1V4diqkLkwcZP3E1lcNMgWFZ/u2bDw+1Eb\n4rYwf+sVCwhXQiqV8QyWp6E6Ow+eHO4D1qvysc/kz/lSgwIB59HU0Q618NlyVi+J\ncaNGtByZmUyQ5H7BBP5xYLHETQREQDND5S4nmGvr7aekewycJW1z9c/A3lA/ENat\nMhgDF7/WDOjFCkoayZRZs62w0cWmNt50KultyIFMs/IMg9aOMehAPVmqO/vpfnh9\nTyWMNEjH9obmy5REmLRtu9bL42FTSXyM1b/HOiC24aeROfFrQog1MiWyo7FBl75U\nm33fYbmm0U4kgBvAfCSgiAps20WITEaEgl1Xwvwepw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EHESP - Ecole des hautes \u00e9tudes en sant\u00e9 publique"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ehesp.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "EHESP - Ecole des hautes \u00e9tudes en sant\u00e9 publique"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dlib-qwghlm.ucs.ed.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Glover"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve.glover@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Glover"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve.glover@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dlib-qwghlm.ucs.ed.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-07-03T20:24:07Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EDINA: SDSS test Service Provider"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://dlib-qwghlm.ucs.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-qwghlm.ucs.ed.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dlib-qwghlm.ucs.ed.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dlib-qwghlm.ucs.ed.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dlib-qwghlm.ucs.ed.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-qwghlm.ucs.ed.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dlib-qwghlm.ucs.ed.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dlib-qwghlm.ucs.ed.ac.uk/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dlib-qwghlm.ucs.ed.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dlib-qwghlm.ucs.ed.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAPiWVB4ghVD+MA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGGRsaWItcXdnaGxtLnVjcy5lZC5hYy51azAeFw0xMTEyMDgxMzI2NTNaFw0y\n\t\t\t\t\t\tMTEyMDUxMzI2NTNaMCMxITAfBgNVBAMTGGRsaWItcXdnaGxtLnVjcy5lZC5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMDDdsNDEYlcSwpD+3Qc\n\t\t\t\t\t\t9YREfCpy+qm6bLrSRfzfDZS2Dbxq3Hy1opl9HXM+ka+GQsGcLeKp8tSm/PUnjCh2\n\t\t\t\t\t\t/bQ2GZ0ICjQvDdQtRDjdwZ6mtEMrriCy3fX4/89iEbl7qf7m4YL5YZZ3sPjyfJ1n\n\t\t\t\t\t\t2dTIioIipvbxGbXqDb4gj+VcI2eYGiaZI/odZW4cTvICYB/iyiynJOMUAU/M0SB8\n\t\t\t\t\t\tRhrl9qJrpSKuSNarozLskbhb099GFDtHsH6znHRCa0ZpEJ5frNqovcj2GDXybB9P\n\t\t\t\t\t\tRVioL6x8jJoM6IPI4DcOzMjU5xGcXwWSXiltGYhQXuJTtDRicOX8iKKJNMCyZzNO\n\t\t\t\t\t\tlJsCAwEAAaNGMEQwIwYDVR0RBBwwGoIYZGxpYi1xd2dobG0udWNzLmVkLmFjLnVr\n\t\t\t\t\t\tMB0GA1UdDgQWBBTxK6XE5xyMz3j2z1AMA7uDBjGQ4DANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAHDLiFzDtoaKo49V2yWeLRNFTdxqs97iCSezJ9YWCbgWyMU/3M0nG4apsGgSI\n\t\t\t\t\t\tQ14yLjFNbgOws9JViEL6UMVL9TSpuqck2GQnwqWGsiF0oI7xRCVprkIBm3kNiWlb\n\t\t\t\t\t\tEL9dRcGybE8Awwa5K0yOyRI8w062x11gtH9Au4hhjwHsNsU52qOnNezlcpH1JXwI\n\t\t\t\t\t\t8QRfP8nk+TAYT+/w3oSeJ9pPGqRXO2IlfIz7Jtdoi2xhOtyCtY6DW9dTnf+FWSgi\n\t\t\t\t\t\t0JcZ85FvVPG9GICRkoKNHSNjysWh6qMMhgNQlQzxSXvkNqqJLKknmmvsQ9AhN7Z8\n\t\t\t\t\t\ttDpV2fo/EP8RfABm/v+Xb8gZ5Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-qwghlm.ucs.ed.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dlib-qwghlm.ucs.ed.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dlib-qwghlm.ucs.ed.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dlib-qwghlm.ucs.ed.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dlib-qwghlm.ucs.ed.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dlib-qwghlm.ucs.ed.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dlib-qwghlm.ucs.ed.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dlib-qwghlm.ucs.ed.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dlib-qwghlm.ucs.ed.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dlib-qwghlm.ucs.ed.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.edina.ac.uk/shibboleth/m2m",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:edina@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EDINA Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Soares"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ben.soares@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ben"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.edina.ac.uk/shibboleth/m2m",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-08-28T13:09:20Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EDINA M2M Authentication"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://edina.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vsp2.edina.ac.uk/m2m/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vsp2.edina.ac.uk/m2m/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vsp2.edina.ac.uk/m2m/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vsp2.edina.ac.uk/m2m/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://auth.edina.ac.uk/m2m/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.edina.ac.uk/m2m/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.edina.ac.uk/m2m/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://auth.edina.ac.uk/m2m/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vsp2.edina.ac.uk/m2m/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://auth.edina.ac.uk/m2m/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vsp2.edina.ac.uk/m2m/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vsp2.edina.ac.uk/m2m/Shibboleth.sso/WAYF/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vsp2.edina.ac.uk/m2m/Shibboleth.sso/WAYF/UKall",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "EDINA M2M Authentication"
                  }
                ],
                "logo": [
                  {
                    "text": "https://auth.edina.ac.uk/public/images/splogos/edina.png",
                    "height": "65",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "150"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EDINA M2M Authentication"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIESDCCAzCgAwIBAgIJAKrBnZO7TvNTMA0GCSqGSIb3DQEBBQUAMIGkMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjERMA8GA1UECBMIU2NvdGxhbmQxEjAQBgNVBAcTCUVkaW5idXJnaDEk\n\t\t\t\t\t\tMCIGA1UEChMbVGhlIFVuaXZlcnNpdHkgb2YgRWRpbmJ1cmdoMQ4wDAYDVQQLEwVF\n\t\t\t\t\t\tRElOQTEZMBcGA1UEAxMQdnNwMi5lZGluYS5hYy51azEdMBsGCSqGSIb3DQEJARYO\n\t\t\t\t\t\tZWRpbmFAZWQuYWMudWswHhcNMTAwMjAxMTY0OTI1WhcNMjAwMTMwMTY0OTI1WjCB\n\t\t\t\t\t\tpDELMAkGA1UEBhMCR0IxETAPBgNVBAgTCFNjb3RsYW5kMRIwEAYDVQQHEwlFZGlu\n\t\t\t\t\t\tYnVyZ2gxJDAiBgNVBAoTG1RoZSBVbml2ZXJzaXR5IG9mIEVkaW5idXJnaDEOMAwG\n\t\t\t\t\t\tA1UECxMFRURJTkExGTAXBgNVBAMTEHZzcDIuZWRpbmEuYWMudWsxHTAbBgkqhkiG\n\t\t\t\t\t\t9w0BCQEWDmVkaW5hQGVkLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAynwMFgT8x37YBNpxAGTtLJxF3iG1adpqRmin40XS86HdJP21dzsH7JD1\n\t\t\t\t\t\tRanxUJJOWU8wud9e//ZZTC58TZbc8Zp0JRc5hlTOmLRksYt4B0QxrCqJ4EmFKlIM\n\t\t\t\t\t\tigE5ZNgoR+lwS1ENKikIHibnVcNF9IpIkX8sTzCY18JcileM8Yz5b+R91yoha1MU\n\t\t\t\t\t\tasRefMf2j7RR6kldAJw2Xj63aFtN0NXL6Z+HiLyg4JNslJTH9c3Ha88tI+6Ce1Q6\n\t\t\t\t\t\trG7rztkpHAD5Rd+ovQMysk9ihA3RN18X0Uu8LqExH2tUqq51Fmd+KQ04hyjE4gx+\n\t\t\t\t\t\tw2T6MwPmdp6zLQSXFf6x9CeRai7MwwIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCG\n\t\t\t\t\t\tSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4E\n\t\t\t\t\t\tFgQU59hHQ8+jwnn2x3Yz4BDaEaDHUrswHwYDVR0jBBgwFoAU59hHQ8+jwnn2x3Yz\n\t\t\t\t\t\t4BDaEaDHUrswDQYJKoZIhvcNAQEFBQADggEBAB5CEE4B61l2mn/sBlc7+qN+obOW\n\t\t\t\t\t\tgZURJvs/EeIlfR7LpWRITMSn4pE5mPR4R96tL0vNXc1jl5c2sTV9dtztazWmU+Z1\n\t\t\t\t\t\tu3rniEM6jETPFqlmYhOPFzYWoQTB0LGv3Id0NR4dCFDtFNl+EPaQAug9C39gkOCN\n\t\t\t\t\t\tiLZJlzOZxUALuUvebPbZMfqSTo8SdFT1Cv2No0hQIBjvlO1OimSjAWgkFR3snW8b\n\t\t\t\t\t\txzZ/lWUqrLDZYSo5LXQad3yNfhwi4dMJ5PRuAuTH1akdwlVf4AIeIQDm3QBKJIhj\n\t\t\t\t\t\tTOGrFRiCdlp4cIQwN66UelzUH2KjlI/iQXYLbq5uUHN/EI47I/E0gpnYr5E="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vsp2.edina.ac.uk/m2m/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vsp2.edina.ac.uk/m2m/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vsp2.edina.ac.uk/m2m/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vsp2.edina.ac.uk/m2m/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://auth.edina.ac.uk/m2m/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.edina.ac.uk/m2m/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.edina.ac.uk/m2m/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://auth.edina.ac.uk/m2m/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vsp2.edina.ac.uk/m2m/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vsp2.edina.ac.uk/m2m/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vsp2.edina.ac.uk/m2m/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vsp2.edina.ac.uk/m2m/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vsp2.edina.ac.uk/m2m/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vsp2.edina.ac.uk/m2m/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://auth.edina.ac.uk/m2m/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://auth.edina.ac.uk/m2m/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://auth.edina.ac.uk/m2m/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://auth.edina.ac.uk/m2m/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.edina.ac.uk/m2m/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://auth.edina.ac.uk/m2m/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.knovel.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Crisler"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mcrisler@knovel.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cheung"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jcheung@knovel.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Johnny"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.knovel.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-07-04T16:52:54Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Knovel Corporation: Production"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.knovel.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Knovel Corporation"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.knovel.com/saml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sso.knovel.com/saml/module.php/saml/sp/discoresp.php",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Knovel website integrates technical reference information with analytical and search tools for engineers."
                  }
                ],
                "logo": [
                  {
                    "text": "https://content.knovel.com/web/integration/ukfed/images/logo_350_115.png",
                    "height": "115",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Knovel Corporation: Production"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEGDCCAwCgAwIBAgIJAPOXUUi71HxhMA0GCSqGSIb3DQEBCwUAMIGMMQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzELMAkGA1UECAwCTlkxDDAKBgNVBAcMA05ZQzEUMBIGA1UECgwLS25v\n\t\t\t\t\t\tdmVsIENvcnAxCzAJBgNVBAsMAklUMR8wHQYDVQQDDBZodHRwczovL3Nzby5rbm92\n\t\t\t\t\t\tZWwuY29tMR4wHAYJKoZIhvcNAQkBFg9rb3BzQGtub3ZlbC5jb20wHhcNMTUwODE5\n\t\t\t\t\t\tMTkxNjIyWhcNMjUwODE2MTkxNjIyWjCBjDELMAkGA1UEBhMCVVMxCzAJBgNVBAgM\n\t\t\t\t\t\tAk5ZMQwwCgYDVQQHDANOWUMxFDASBgNVBAoMC0tub3ZlbCBDb3JwMQswCQYDVQQL\n\t\t\t\t\t\tDAJJVDEfMB0GA1UEAwwWaHR0cHM6Ly9zc28ua25vdmVsLmNvbTEeMBwGCSqGSIb3\n\t\t\t\t\t\tDQEJARYPa29wc0Brbm92ZWwuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAvbVY22BR9u0z5Ymu8dhGgGtHF11CHW+4og/cfmEApsF5vjT+weE2irNl\n\t\t\t\t\t\t7bqZ7nFqp30aCTUlFz2+WbaGtG7tV9jAKn7XhIx5e3HFpYUof3ziHuCiSo83olaw\n\t\t\t\t\t\t6pj7cXM0zXonUypLSL4HXIafU1KdIsbeKC10PlKchQLFba1OJqLFudN/xOMmh+Sx\n\t\t\t\t\t\tq7xcT//54s2TqvtE3B7eAowfB3VYTe69Iuru9F9HuZSCVnSy1q+cqlmdkKjHX5r4\n\t\t\t\t\t\tVRs07UzyprTyqOKBy5fehwj1YrXHoYZhwTsiISJ9fI1OGcrioaousHYb0YagNRyg\n\t\t\t\t\t\tcIUxgBvy1zSb6TRGQsfdKsHlF9UXuwIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCG\n\t\t\t\t\t\tSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4E\n\t\t\t\t\t\tFgQUqBniZ9JiN6KqodktdnHmlizjn6kwHwYDVR0jBBgwFoAUqBniZ9JiN6Kqodkt\n\t\t\t\t\t\tdnHmlizjn6kwDQYJKoZIhvcNAQELBQADggEBAApSwJ0PMw+Ijt5t9+sQqPn3PXo3\n\t\t\t\t\t\tZvniUj2W8VA9ob4O72WAuvanHlxz6IeDeiLfB6MKx4nayv+l6W5CP8wRAGupiIZ0\n\t\t\t\t\t\tRIYJEutE9EspbwUTLgKhv0EaUc1GA0JbcBU0VqUjZlWmo/IqNjDLpxBfaPxVRH35\n\t\t\t\t\t\twAuGnN87uouRUz6vYPAb6csBDu+muqQ92ZI40rWgDvjv9qfbkv3cE8Ef0yaInIAG\n\t\t\t\t\t\tmTMHFxRkoi2aJF+B3KjGkOKSMQLDvsxYwbengNEmH8GE1j/vSLWMt2uAuGNOVjO+\n\t\t\t\t\t\tX788brUQmk13D8HngKAkCA5GLH4TKsfbNOmD28c8fkYf2tZhOddOdXNjNm0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEGDCCAwCgAwIBAgIJAPOXUUi71HxhMA0GCSqGSIb3DQEBCwUAMIGMMQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzELMAkGA1UECAwCTlkxDDAKBgNVBAcMA05ZQzEUMBIGA1UECgwLS25v\n\t\t\t\t\t\tdmVsIENvcnAxCzAJBgNVBAsMAklUMR8wHQYDVQQDDBZodHRwczovL3Nzby5rbm92\n\t\t\t\t\t\tZWwuY29tMR4wHAYJKoZIhvcNAQkBFg9rb3BzQGtub3ZlbC5jb20wHhcNMTUwODE5\n\t\t\t\t\t\tMTkxNjIyWhcNMjUwODE2MTkxNjIyWjCBjDELMAkGA1UEBhMCVVMxCzAJBgNVBAgM\n\t\t\t\t\t\tAk5ZMQwwCgYDVQQHDANOWUMxFDASBgNVBAoMC0tub3ZlbCBDb3JwMQswCQYDVQQL\n\t\t\t\t\t\tDAJJVDEfMB0GA1UEAwwWaHR0cHM6Ly9zc28ua25vdmVsLmNvbTEeMBwGCSqGSIb3\n\t\t\t\t\t\tDQEJARYPa29wc0Brbm92ZWwuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEAvbVY22BR9u0z5Ymu8dhGgGtHF11CHW+4og/cfmEApsF5vjT+weE2irNl\n\t\t\t\t\t\t7bqZ7nFqp30aCTUlFz2+WbaGtG7tV9jAKn7XhIx5e3HFpYUof3ziHuCiSo83olaw\n\t\t\t\t\t\t6pj7cXM0zXonUypLSL4HXIafU1KdIsbeKC10PlKchQLFba1OJqLFudN/xOMmh+Sx\n\t\t\t\t\t\tq7xcT//54s2TqvtE3B7eAowfB3VYTe69Iuru9F9HuZSCVnSy1q+cqlmdkKjHX5r4\n\t\t\t\t\t\tVRs07UzyprTyqOKBy5fehwj1YrXHoYZhwTsiISJ9fI1OGcrioaousHYb0YagNRyg\n\t\t\t\t\t\tcIUxgBvy1zSb6TRGQsfdKsHlF9UXuwIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCG\n\t\t\t\t\t\tSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4E\n\t\t\t\t\t\tFgQUqBniZ9JiN6KqodktdnHmlizjn6kwHwYDVR0jBBgwFoAUqBniZ9JiN6Kqodkt\n\t\t\t\t\t\tdnHmlizjn6kwDQYJKoZIhvcNAQELBQADggEBAApSwJ0PMw+Ijt5t9+sQqPn3PXo3\n\t\t\t\t\t\tZvniUj2W8VA9ob4O72WAuvanHlxz6IeDeiLfB6MKx4nayv+l6W5CP8wRAGupiIZ0\n\t\t\t\t\t\tRIYJEutE9EspbwUTLgKhv0EaUc1GA0JbcBU0VqUjZlWmo/IqNjDLpxBfaPxVRH35\n\t\t\t\t\t\twAuGnN87uouRUz6vYPAb6csBDu+muqQ92ZI40rWgDvjv9qfbkv3cE8Ef0yaInIAG\n\t\t\t\t\t\tmTMHFxRkoi2aJF+B3KjGkOKSMQLDvsxYwbengNEmH8GE1j/vSLWMt2uAuGNOVjO+\n\t\t\t\t\t\tX788brUQmk13D8HngKAkCA5GLH4TKsfbNOmD28c8fkYf2tZhOddOdXNjNm0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDujCCAqKgAwIBAgIJANDf/KbdI37xMA0GCSqGSIb3DQEBBQUAMF4xCzAJBgNV\n\t\t\t\t\t\tBAYTAlVTMQswCQYDVQQIEwJOWTEMMAoGA1UEBxMDTllDMRswGQYDVQQKExJLbm92\n\t\t\t\t\t\tZWwgQ29ycG9yYXRpb24xFzAVBgNVBAMTDnNzby5rbm92ZWwuY29tMB4XDTE0MDQx\n\t\t\t\t\t\tNDEzMTQxNVoXDTM0MDQwOTEzMTQxNVowXjELMAkGA1UEBhMCVVMxCzAJBgNVBAgT\n\t\t\t\t\t\tAk5ZMQwwCgYDVQQHEwNOWUMxGzAZBgNVBAoTEktub3ZlbCBDb3Jwb3JhdGlvbjEX\n\t\t\t\t\t\tMBUGA1UEAxMOc3NvLmtub3ZlbC5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQCiA2U/scRrpv+vAMjajlfo6VL+7LbLAbFwf/B+Irwb6+tqNgE7KhZx\n\t\t\t\t\t\tfFb7gTQE4zaDnhBEtlHoJtR0mKz0Lnh2XK09EijA3Z1Rtu7sWbJIlIfZxA6PxPzp\n\t\t\t\t\t\tOXY6tuTOzjPYM90I4fpHHLd04lGwWiJyRcx02tKAPUSxMXcmFYXFDaa9jAXRXYxe\n\t\t\t\t\t\tQjvpg9uZhmRd8qyA3MraLTSva/Qx6iXpT7G50RJvMIuZ91wW654/BSWSBdaCFzoL\n\t\t\t\t\t\tPNLEb1Wda08XmNPebfdi5fDyZV6ePvYNLQZnjxtIWwy13QMop7bmCqbYf4hC13Rh\n\t\t\t\t\t\tSvd/rtye0RZp900uxpNrBghIPPnR91obAgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJ\n\t\t\t\t\t\tYIZIAYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1Ud\n\t\t\t\t\t\tDgQWBBT/FCscZUqNjJQkE+P0/Z8imgrKGTAfBgNVHSMEGDAWgBT/FCscZUqNjJQk\n\t\t\t\t\t\tE+P0/Z8imgrKGTANBgkqhkiG9w0BAQUFAAOCAQEAVRTsaVKqAMLTv6iYqf5KDPSU\n\t\t\t\t\t\t6BQssDlhy249VNVAdQ3kX1flTxmLcCrRVQVCZ9oB4U67mixsro+vCcs04cZ+aoQM\n\t\t\t\t\t\tuZGBE7ikRv3sOn0uwc5JJ1en4jF4CxzSlESZZt/REnCYecmsnzUFHgwezQoRFArV\n\t\t\t\t\t\tbiQRRQxr3A4va92z/pjASq8J0R4rJ50j5aQi0ay1zE6aAiyXiws8450D0lBg6+Te\n\t\t\t\t\t\tdMhYTbb+4y+nzT090QiHVgHltgGXTdmhtJo+WPRqMB4Ph+vadtYkQHEHZZiIdjqX\n\t\t\t\t\t\t/Zic8mF3byatILMfu6OlNXJpueeEC1uAhgScLuk92REdd7PipJ0Dum8QWgwzlg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.knovel.com/saml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sso.knovel.com/saml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sso.knovel.com/saml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sso.knovel.com/saml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayf.supportcenter.dk/aip/saml2/idp/metadata.php?unit=aip",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayf.supportcenter.dk/aip/saml2/idp/metadata.php?unit=aip",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2010-08-17T13:52:57Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayf.supportcenter.dk/aip/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aip.itsf.dk"
              },
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Paderup Gymnasium"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Paderup Gymnasium"
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Paderup Gymnasium"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Paderup Gymnasium"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "aip.itsf.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfQCAQcwDQYJKoZIhvcNAQELBQAwTDFKMEgGA1UEAwxBaHR0cHM6Ly93\nYXlmLnN1cHBvcnRjZW50ZXIuZGsvYWlwL3NhbWwyL2lkcC9tZXRhZGF0YS5waHA/\ndW5pdD1haXAwHhcNMTUwMTAxMDAwMDAwWhcNMjUxMjMxMjM1OTU5WjBMMUowSAYD\nVQQDDEFodHRwczovL3dheWYuc3VwcG9ydGNlbnRlci5kay9haXAvc2FtbDIvaWRw\nL21ldGFkYXRhLnBocD91bml0PWFpcDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBAMeIDApqEFO4jhn4gnWuA54SIILLdtH1Ah7cGkKx6MUJTmtLORYA2pW5\nzU8N+nQl0hmGs9eyYMlAyaJ08IY8gNAqj5uT5p/f4RQVL8j/7fmxIFfa9/6HUMe9\nlX2OzOealJWOnsdn9ag9YHKRYEk7QA5WbMHnOVqqRLfonvr7DF6vB2m4TFWdhI13\nvdL4DJP8Rn61cA77qVDwUv9gyUmdSRJpKotIcXLTUPaoE2ZhHAGkJLr91RnLGLS3\nmPyCEpQPgEc5lVq+frknrZwl1eI5wxHJQAinnsZdCsvrcq2uMhxd12r4JnJnm3fs\nR1Q4jPjaOgVzLvcwU6e3KeUoS87DUEkCAwEAATANBgkqhkiG9w0BAQsFAAOCAQEA\nENMWqISdcyWIaMg3lcXf8kl3wIHaocFfiullJuRB6djyKnByl4EVlCotP+HnG6eF\nxZtBzFNuNRg/hz/LBELt5iOTt0gd9h5tGFDLPSnMrzxF76D/ADadWa4Gktt12uby\n3v9xYWLW7uqj6IGl4SIZhZ63qAAbbpTE64NK8mg/kSEU+NMu9ZYAg5YcvzK3mxs3\n9fK0dQimQEjUqy7rOxBT6o+o9i6/xJT8rpaiTazuWr8SCj68C6a6SL/H60a9YJ47\nd3ZispCdiYlQdT1JwH/6d63lu90u8okGG1m6phSmW+68cIFZTnWMBApMW8ei9rqh\nLV8Nl3w74u1j520EDfu3HQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Paderup Gymnasium"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Paderup Gymnasium"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.paderup-gym.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.paderup-gym.dk"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Paderup Gymnasium"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Paderup Gymnasium"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth-idp.dti.ufv.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Harley Balduino Saraiva"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "harley.saraiva@ufv.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth-idp.dti.ufv.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKDCCAxACAQAwDQYJKoZIhvcNAQEFBQAwgdkxLTArBgNVBAoTJFVGViAtIFVu\naXZlcnNpZGFkZSBGZWRlcmFsIGRlIFZpY29zYTE0MDIGA1UECxMrRFRJIC0gRGly\nZXRvcmlhIGRlIFRlY25vbG9naWEgZGUgSW5mb3JtYWNhbzEZMBcGCSqGSIb3DQEJ\nARYKZHRpQHVmdi5icjEPMA0GA1UEBxMGVmljb3NhMRUwEwYDVQQIEwxNaW5hcyBH\nZXJhaXMxCzAJBgNVBAYTAkJSMSIwIAYDVQQDExlzaGliYm9sZXRoLWlkcC5kdGku\ndWZ2LmJyMB4XDTE0MDQxNDExMzc1N1oXDTE5MDQxMzExMzc1N1owgdkxLTArBgNV\nBAoTJFVGViAtIFVuaXZlcnNpZGFkZSBGZWRlcmFsIGRlIFZpY29zYTE0MDIGA1UE\nCxMrRFRJIC0gRGlyZXRvcmlhIGRlIFRlY25vbG9naWEgZGUgSW5mb3JtYWNhbzEZ\nMBcGCSqGSIb3DQEJARYKZHRpQHVmdi5icjEPMA0GA1UEBxMGVmljb3NhMRUwEwYD\nVQQIEwxNaW5hcyBHZXJhaXMxCzAJBgNVBAYTAkJSMSIwIAYDVQQDExlzaGliYm9s\nZXRoLWlkcC5kdGkudWZ2LmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAwHXw5lxhsUVVy9cHSvvnkanv1HyyMZz6lmeY76rh79I2bopDPgZlbdHnTAYn\n8vDrHts9RZOOOUXHYsJR2D0jm4lcVRxczZD5P4qDLpYp28kY3OfsOQ9TMZJ8HmnN\nRyjAmR8CofBG1ZHN2xi7tWqMI4HVEJfZw/ZvSWfX4eNBQsvv5oTa1v5eOw1YQQ6A\naHB6p/Xp7tccGX0+OgTVty2Bq20xEZNBJeJtz2SBYxbiRUE+vaiYTyCJVxDeyNcN\nYIkiOUCUu2pEvgFciuzjhlG7UuUsq7S19HqOEjtUiqdH72gDRGvLNRhwpQ+u22vd\nWBOsXDXZeHB/5MfcOQImtgkYUQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCm0AKL\nBmP26xPlCqtrHLg2jUVBieOXLlF9hwc9TT6XQe1oMFHNaYYTEuw6/5To0xBkAWEl\nDrxKfa2qriSd6HBbn33RlWGpkfbMTqI52EgKvq+aUqcHjZfEQIKzdMA+ROIRdNgh\nj5pN94R1x14OARIvBnoYUXTDr/RajPVTs44HPmIKFviSVtkEC0o2pxt44/z1/jcq\n9gDbQO3dHyy+s3Twv7TBBPSECaFM8h3hescyO8I5bU4HJ1SrfjwwOX3jA+f6/U7f\nHGGRxpdKwLluWxlRst23AsG4nQFcIUsisbxQzd0mj29uAfmaQfxGAb+trbAAvZRr\nqTc5UxmPC7Yhv6hM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufv.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-idp.dti.ufv.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth-idp.dti.ufv.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth-idp.dti.ufv.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth-idp.dti.ufv.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth-idp.dti.ufv.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth-idp.dti.ufv.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-idp.dti.ufv.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth-idp.dti.ufv.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufv.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufv.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufv.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFV - universidade Federal de Vicosa"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFV - universidade Federal de Vicosa"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFV - universidade Federal de Vicosa"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFV - universidade Federal de Vicosa"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKDCCAxACAQAwDQYJKoZIhvcNAQEFBQAwgdkxLTArBgNVBAoTJFVGViAtIFVu\naXZlcnNpZGFkZSBGZWRlcmFsIGRlIFZpY29zYTE0MDIGA1UECxMrRFRJIC0gRGly\nZXRvcmlhIGRlIFRlY25vbG9naWEgZGUgSW5mb3JtYWNhbzEZMBcGCSqGSIb3DQEJ\nARYKZHRpQHVmdi5icjEPMA0GA1UEBxMGVmljb3NhMRUwEwYDVQQIEwxNaW5hcyBH\nZXJhaXMxCzAJBgNVBAYTAkJSMSIwIAYDVQQDExlzaGliYm9sZXRoLWlkcC5kdGku\ndWZ2LmJyMB4XDTE0MDQxNDExMzc1N1oXDTE5MDQxMzExMzc1N1owgdkxLTArBgNV\nBAoTJFVGViAtIFVuaXZlcnNpZGFkZSBGZWRlcmFsIGRlIFZpY29zYTE0MDIGA1UE\nCxMrRFRJIC0gRGlyZXRvcmlhIGRlIFRlY25vbG9naWEgZGUgSW5mb3JtYWNhbzEZ\nMBcGCSqGSIb3DQEJARYKZHRpQHVmdi5icjEPMA0GA1UEBxMGVmljb3NhMRUwEwYD\nVQQIEwxNaW5hcyBHZXJhaXMxCzAJBgNVBAYTAkJSMSIwIAYDVQQDExlzaGliYm9s\nZXRoLWlkcC5kdGkudWZ2LmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAwHXw5lxhsUVVy9cHSvvnkanv1HyyMZz6lmeY76rh79I2bopDPgZlbdHnTAYn\n8vDrHts9RZOOOUXHYsJR2D0jm4lcVRxczZD5P4qDLpYp28kY3OfsOQ9TMZJ8HmnN\nRyjAmR8CofBG1ZHN2xi7tWqMI4HVEJfZw/ZvSWfX4eNBQsvv5oTa1v5eOw1YQQ6A\naHB6p/Xp7tccGX0+OgTVty2Bq20xEZNBJeJtz2SBYxbiRUE+vaiYTyCJVxDeyNcN\nYIkiOUCUu2pEvgFciuzjhlG7UuUsq7S19HqOEjtUiqdH72gDRGvLNRhwpQ+u22vd\nWBOsXDXZeHB/5MfcOQImtgkYUQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCm0AKL\nBmP26xPlCqtrHLg2jUVBieOXLlF9hwc9TT6XQe1oMFHNaYYTEuw6/5To0xBkAWEl\nDrxKfa2qriSd6HBbn33RlWGpkfbMTqI52EgKvq+aUqcHjZfEQIKzdMA+ROIRdNgh\nj5pN94R1x14OARIvBnoYUXTDr/RajPVTs44HPmIKFviSVtkEC0o2pxt44/z1/jcq\n9gDbQO3dHyy+s3Twv7TBBPSECaFM8h3hescyO8I5bU4HJ1SrfjwwOX3jA+f6/U7f\nHGGRxpdKwLluWxlRst23AsG4nQFcIUsisbxQzd0mj29uAfmaQfxGAb+trbAAvZRr\nqTc5UxmPC7Yhv6hM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFV - universidade Federal de Vicosa"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFV - universidade Federal de Vicosa"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufv.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufv.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFV - Universidade Federal de Vicosa"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFV - Universidade Federal de Vicosa"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://gihidentity01.ihs.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 8 12053734"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fredrik Nilsson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:fredrik.nilsson@gih.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "The Swedish School of Sport and Health Sciences"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 8 12053807"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Michael Thunell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:michael.thunell@gih.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "The Swedish School of Sport and Health Sciences"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 8 12053792"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Charlie Skog"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:charlie.skog@gih.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "The Swedish School of Sport and Health Sciences"
          }
        }
      ],
      "entity_id": "https://gihidentity01.ihs.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUX4LM+yBFUKdFziHUCVyiPPGiL8YwDQYJKoZIhvcNAQEF\nBQAwHzEdMBsGA1UEAxMUZ2loaWRlbnRpdHkwMS5paHMuc2UwHhcNMTMwOTIwMTA1\nNTIzWhcNMzMwOTIwMTA1NTIzWjAfMR0wGwYDVQQDExRnaWhpZGVudGl0eTAxLmlo\ncy5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKjZBXC3TcY47KYX\nt3n4IH6X8Jszyeinq+Zo6mtsJgzu9JPikIiG9jDJj+ylQiTDSSTBMSAUZ3p6ola/\n+/IlDu0q5oLFCMEe3m9AdJIwyT6CjIJOiLSzeaTOqQNtXowLFCxj+PPrVRaqJiYc\n+7f3+5SMwn2iOLkr6/ZFW5cuhw9flzR/Qp7m9ByTIcs73XK1JcQPP1UoPgo8mUXj\n/IHbxB/+P0NzjMXbKZEFEnZQzDoxNYDbARh6T/hJreIKBr+B0KnKogZnM9WgdJof\nO6GKR1lETrGgmCITblP7dbrRIL2VxMmXQEMhdS78Y5GNRPnGxp00kT2h/tTA1Reb\n52sROA0CAwEAAaNvMG0wTAYDVR0RBEUwQ4IUZ2loaWRlbnRpdHkwMS5paHMuc2WG\nK2h0dHBzOi8vZ2loaWRlbnRpdHkwMS5paHMuc2UvaWRwL3NoaWJib2xldGgwHQYD\nVR0OBBYEFIzCrjaWTfLensnYqTm/G3CNWsbNMA0GCSqGSIb3DQEBBQUAA4IBAQB7\npVQO0Su0rB9WHWpitL0kNNfFQgapWHHZ8hYUDFWxiON7IGG6GlVsqgvwGCQwYgci\nE+WrKirES8+tE/EWhNfSvydlBuHwkvBP2WqsjUVbG0U4xbguE3C1ZrcfKcjBkSDH\nYmMuoYqX6RkHuwExl0xLr1ApVz8l2D9HVXdVi3aG31gMpo4/G1GukY8Pny8ZSbNP\ncb9+7g88/LLBLc5cx1iccfK4h0Er5QAFjNd3uKD3p0sxQYKPGs5X2ZwOxJlmeAiU\n3Ujhy7jzfaV7bFtz+GL8WTHoi2OfI1YqES5Jr3sQnlArhemcYUxnpBN4yvDF2QK1\nicptKTpDxrRjfCXibBT1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ihs.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://gihidentity01.ihs.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://gihidentity01.ihs.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://gihidentity01.ihs.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gihidentity01.ihs.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://gihidentity01.ihs.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://gihidentity01.ihs.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://gihidentity01.ihs.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://gihidentity01.ihs.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gih.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://gihidentity01.ihs.se/idp/Authn/UserPassword"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://gihidentity01.ihs.se/idp/Authn/UserPassword"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identitetsutgivare f\u00f6r Gymnastik- och Idrottsh\u00f6gskolan vid Stockholms Stadion"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for The Swedish School of Sport and Health Sciences"
                  }
                ],
                "logo": [
                  {
                    "text": "https://gihidentity01.ihs.se/idp/images/gihlogo.gif",
                    "lang": "sv",
                    "height": "107",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "204"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Gymnastik- och idrottsh\u00f6gskolan"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The Swedish School of Sport and Health Sciences"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "gih.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:59.3467350,18.0811920"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUX4LM+yBFUKdFziHUCVyiPPGiL8YwDQYJKoZIhvcNAQEF\nBQAwHzEdMBsGA1UEAxMUZ2loaWRlbnRpdHkwMS5paHMuc2UwHhcNMTMwOTIwMTA1\nNTIzWhcNMzMwOTIwMTA1NTIzWjAfMR0wGwYDVQQDExRnaWhpZGVudGl0eTAxLmlo\ncy5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKjZBXC3TcY47KYX\nt3n4IH6X8Jszyeinq+Zo6mtsJgzu9JPikIiG9jDJj+ylQiTDSSTBMSAUZ3p6ola/\n+/IlDu0q5oLFCMEe3m9AdJIwyT6CjIJOiLSzeaTOqQNtXowLFCxj+PPrVRaqJiYc\n+7f3+5SMwn2iOLkr6/ZFW5cuhw9flzR/Qp7m9ByTIcs73XK1JcQPP1UoPgo8mUXj\n/IHbxB/+P0NzjMXbKZEFEnZQzDoxNYDbARh6T/hJreIKBr+B0KnKogZnM9WgdJof\nO6GKR1lETrGgmCITblP7dbrRIL2VxMmXQEMhdS78Y5GNRPnGxp00kT2h/tTA1Reb\n52sROA0CAwEAAaNvMG0wTAYDVR0RBEUwQ4IUZ2loaWRlbnRpdHkwMS5paHMuc2WG\nK2h0dHBzOi8vZ2loaWRlbnRpdHkwMS5paHMuc2UvaWRwL3NoaWJib2xldGgwHQYD\nVR0OBBYEFIzCrjaWTfLensnYqTm/G3CNWsbNMA0GCSqGSIb3DQEBBQUAA4IBAQB7\npVQO0Su0rB9WHWpitL0kNNfFQgapWHHZ8hYUDFWxiON7IGG6GlVsqgvwGCQwYgci\nE+WrKirES8+tE/EWhNfSvydlBuHwkvBP2WqsjUVbG0U4xbguE3C1ZrcfKcjBkSDH\nYmMuoYqX6RkHuwExl0xLr1ApVz8l2D9HVXdVi3aG31gMpo4/G1GukY8Pny8ZSbNP\ncb9+7g88/LLBLc5cx1iccfK4h0Er5QAFjNd3uKD3p0sxQYKPGs5X2ZwOxJlmeAiU\n3Ujhy7jzfaV7bFtz+GL8WTHoi2OfI1YqES5Jr3sQnlArhemcYUxnpBN4yvDF2QK1\nicptKTpDxrRjfCXibBT1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Gymnastik- och idrottsh\u00f6gskolan"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Swedish School of Sport and Health Sciences"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gih.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Swedish School of sport and health sciences"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://soton.co-tutor.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chung"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ray.chung@lboro.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ray"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Newman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:p.m.newman@lboro.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://soton.co-tutor.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-06-05T10:16:47Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Co-Tutor at Southampton"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.co-tutor.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Loughborough University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://soton.co-tutor.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://soton.co-tutor.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://soton.co-tutor.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://soton.co-tutor.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://soton.co-tutor.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://soton.co-tutor.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://soton.co-tutor.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAJlCEOj+nIZfMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEGlwLTE3Mi0zMS0xMS0yMTcwHhcNMTUwNjAzMTEyMTUxWhcNMjUwNTMxMTEy\n\t\t\t\t\t\tMTUxWjAbMRkwFwYDVQQDExBpcC0xNzItMzEtMTEtMjE3MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAvMun7yeyVxinfRuL0WvIR788UHIvTr6Zbom8LQam\n\t\t\t\t\t\tgtgo529uQpxyz7qfiU9Ze8TJlNpo2ySw36J5sozy7cZgm2yXJ0H1GZh4BivzMlQC\n\t\t\t\t\t\tius0rgsmHQzE3vFurix4x7J8W+MnLRSB4fPg2Ha2FjmojoBOs7q9YOSfnXp78sQI\n\t\t\t\t\t\tUEpcpTdOJhQ8cEZwYRIpcoMtUIbwE9i74IpNwsrmBTLLXkRvOrlEYEMU6IkT1OZc\n\t\t\t\t\t\taTvWWtL5Qz9+NvPaacw71H8+OerdUYjalM6uIFP6fKlrm7PhLRRZM7iQxxzHY8+n\n\t\t\t\t\t\tG4yORfN3jxMTuF9XWWdE6wirPIs6ydE7Hgz5Fbj+AFYwWwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghBpcC0xNzItMzEtMTEtMjE3MB0GA1UdDgQWBBSbRvcZTdr07G0ki1fn\n\t\t\t\t\t\tJ8zCQ7dVQzANBgkqhkiG9w0BAQUFAAOCAQEAZ/w7dbDACwEk7CIx7KRtIO/PJd5l\n\t\t\t\t\t\tRCvUEIL9MW/KMXXM33qD5sgPdjRMoDv/fgdchdzmOrk/rkwANJmtfSBK3EqYdjgF\n\t\t\t\t\t\tRYs39si4FTlTvY1ojOH14j26WBSRhBouex6SzeTminuS7T6tlpi3h/hwqefSFzt5\n\t\t\t\t\t\tCrlUrZMBJ+tlAT7UvY76fLcl5c/dAUxjiEYAEI03ceCVQLSAARqmGbaO2QWqcMVX\n\t\t\t\t\t\tLPLV8uxLejPBzqHqJAhWFluXzd5zQ+/EOiC7V7mTAnoAVDrAUNkBL0dbeAHUTnyC\n\t\t\t\t\t\tKDAVvSt52LmVV8PEOmxkTjVwJnTlE5Acb3D+aIHu/YwRkSeyeVdUvdYlJw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://soton.co-tutor.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://soton.co-tutor.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://soton.co-tutor.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://soton.co-tutor.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://soton.co-tutor.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://soton.co-tutor.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://beta.lobber.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://beta.lobber.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://beta.lobber.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://beta.lobber.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://beta.lobber.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://beta.lobber.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SUNET Lobber (BETA)"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "SUNET Lobber (BETA) - a BitTorrent data distribution service"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://beta.lobber.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://beta.lobber.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://beta.lobber.se/Shibboleth.sso/DS/kalmar2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "beta.lobber.se"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://beta.lobber.se/shibboleth-sp"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIJAK3WrSSve3L0MA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDmJldGEubG9iYmVyLnNlMB4XDTEwMDQxNjA4MzUyNVoXDTIwMDQxMzA4MzUy\nNVowGTEXMBUGA1UEAxMOYmV0YS5sb2JiZXIuc2UwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDUL7NU/brgRsoszEetP0BPY9XcmjSY9BymFpvOn09zLvoY\nJDUgRa5Y54ob3vZZ6dkIBhqZulbTM1/8OMyOFk3zL/SkJJK4Ga7xVelT3JdQGwIU\nTvSuxg2p8CXVijurqVtYp8wWsVyelrpLiQh1X7JSqLlSordJBsFJrKlj7Y8eTqy6\nCuEaWXV4E6pqTmlM2Q+WILSG0G7j8YYw9FVlzTDaF5xM4FhQsYa3DWHNZUZlmB/E\nBBUJmcPpZCDOQP/n5dZnQrDQYSuDudy3UpkuHQHf4B8yiffdOKMFzHcTfQDuMJXw\nh6sA5Xrq1WpsOwn9kgONyDm8ML3IFJC3AYLOLvfdAgMBAAGjYjBgMD8GA1UdEQQ4\nMDaCDmJldGEubG9iYmVyLnNlhiRodHRwczovL2JldGEubG9iYmVyLnNlL3NoaWJi\nb2xldGgtc3AwHQYDVR0OBBYEFEWVLP4kBg/gV79XUV32F6dX7kKBMA0GCSqGSIb3\nDQEBBQUAA4IBAQA666NJBd3xPuNy6PRToyJvGmltOxIsn2HFHANX5xqc7GK9v6vw\nzVhVTpx64sZFC6/B/laF9RNmtr9IxiI2wk43ZkdFtoADGlXMKevQ4+CjdLbqb4VP\nTisAp2vpojnlXtmdj3UCzOmiMjgLlRQY8WN1/vMVBNeYKtJSyXfl4mWVNUTBxnAq\nD46Wa7GYLUVqlWdkWDHBznr4QA4MRxhJDOsm9aVVDq4yAOwCQrHdY+xDokcx4mdN\n5dNwkP7gqpYuryKTfnI32kaRKL+kMXotFg6r+qAaIEo67D3LMnWJE75aZb16HVwz\n/MAyn2Vwd/VAgvtvblNu62vT9+d6mW7zQqTZ"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=beta.lobber.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "beta.lobber.se"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://beta.lobber.se/shibboleth-sp"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIJAK3WrSSve3L0MA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDmJldGEubG9iYmVyLnNlMB4XDTEwMDQxNjA4MzUyNVoXDTIwMDQxMzA4MzUy\nNVowGTEXMBUGA1UEAxMOYmV0YS5sb2JiZXIuc2UwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDUL7NU/brgRsoszEetP0BPY9XcmjSY9BymFpvOn09zLvoY\nJDUgRa5Y54ob3vZZ6dkIBhqZulbTM1/8OMyOFk3zL/SkJJK4Ga7xVelT3JdQGwIU\nTvSuxg2p8CXVijurqVtYp8wWsVyelrpLiQh1X7JSqLlSordJBsFJrKlj7Y8eTqy6\nCuEaWXV4E6pqTmlM2Q+WILSG0G7j8YYw9FVlzTDaF5xM4FhQsYa3DWHNZUZlmB/E\nBBUJmcPpZCDOQP/n5dZnQrDQYSuDudy3UpkuHQHf4B8yiffdOKMFzHcTfQDuMJXw\nh6sA5Xrq1WpsOwn9kgONyDm8ML3IFJC3AYLOLvfdAgMBAAGjYjBgMD8GA1UdEQQ4\nMDaCDmJldGEubG9iYmVyLnNlhiRodHRwczovL2JldGEubG9iYmVyLnNlL3NoaWJi\nb2xldGgtc3AwHQYDVR0OBBYEFEWVLP4kBg/gV79XUV32F6dX7kKBMA0GCSqGSIb3\nDQEBBQUAA4IBAQA666NJBd3xPuNy6PRToyJvGmltOxIsn2HFHANX5xqc7GK9v6vw\nzVhVTpx64sZFC6/B/laF9RNmtr9IxiI2wk43ZkdFtoADGlXMKevQ4+CjdLbqb4VP\nTisAp2vpojnlXtmdj3UCzOmiMjgLlRQY8WN1/vMVBNeYKtJSyXfl4mWVNUTBxnAq\nD46Wa7GYLUVqlWdkWDHBznr4QA4MRxhJDOsm9aVVDq4yAOwCQrHdY+xDokcx4mdN\n5dNwkP7gqpYuryKTfnI32kaRKL+kMXotFg6r+qAaIEo67D3LMnWJE75aZb16HVwz\n/MAyn2Vwd/VAgvtvblNu62vT9+d6mW7zQqTZ"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=beta.lobber.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://beta.lobber.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://beta.lobber.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://beta.lobber.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://beta.lobber.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://beta.lobber.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://beta.lobber.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://beta.lobber.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://beta.lobber.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://beta.lobber.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://beta.lobber.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.2simple.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barnett"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sam@2simple.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sam"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barnett"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sam@2simple.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sam"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.2simple.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-05-30T17:24:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "2Simple Software"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.2simple.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "2Simple Software Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.2simple.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.2simple.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.2simple.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.2simple.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.2simple.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.2simple.com/Shibboleth.sso/E2BN",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.2simple.com/Shibboleth.sso/GLOW",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.2simple.com/Shibboleth.sso/LCC",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.2simple.com/Shibboleth.sso/RM",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.2simple.com/Shibboleth.sso/EMBC",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.2simple.com/Shibboleth.sso/SWGFL",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.2simple.com/Shibboleth.sso/WAYFlondon",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.2simple.com/Shibboleth.sso/netmedia",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.2simple.com/Shibboleth.sso/protectnetwork",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.2simple.com/Shibboleth.sso/fronter",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.2simple.com/Shibboleth.sso/networcs",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.2simple.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.2simple.com/Shibboleth.sso/kidder",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.2simple.com/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDXjCCAkYCCQDmolVNvs2UvTANBgkqhkiG9w0BAQUFADBxMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEYMBYGA1UECBMPIEdyZWF0ZXIgTG9uZG9uMQ8wDQYDVQQHEwZMb25kb24xHTAb\n\t\t\t\t\t\tBgNVBAoTFDJTaW1wbGUgU29mdHdhcmUgTHRkMRgwFgYDVQQDEw93d3cuMnNpbXBs\n\t\t\t\t\t\tZS5jb20wHhcNMTEwNTE5MTcyMjA1WhcNMjEwNTE2MTcyMjA1WjBxMQswCQYDVQQG\n\t\t\t\t\t\tEwJHQjEYMBYGA1UECBMPIEdyZWF0ZXIgTG9uZG9uMQ8wDQYDVQQHEwZMb25kb24x\n\t\t\t\t\t\tHTAbBgNVBAoTFDJTaW1wbGUgU29mdHdhcmUgTHRkMRgwFgYDVQQDEw93d3cuMnNp\n\t\t\t\t\t\tbXBsZS5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCgNPBDxQsr\n\t\t\t\t\t\t2fBkIAAonSWIntDbWMJz9nqUmvcDUe66MaktRpJlWzPwf8PY8uRY11fLqURcbuhi\n\t\t\t\t\t\tlXU0r3flglnosshwR3NmngKvHeGN0xPt9HE5zbEfNGGameP8i3f3UpvjI2Kzqnf1\n\t\t\t\t\t\tVa/E+pvYYyH5rMsxi6LhCyKBpA4GDIXobJL/nACuYW1bmshrzBPfsEkUqmd0X5k0\n\t\t\t\t\t\t83fPz68XzXcLnH8cRq9jXPphrjrkFEJzBM7fA05EwNa/r1Qauzydsfvew+KoLaH4\n\t\t\t\t\t\tw7aAqZ/C5WQFFnp4HdiRJZVplcnRsBT239COpcfyChsn6twDd3RqZNWajP12uJbD\n\t\t\t\t\t\t1D8Nn84Y7ojDAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBACTk9iu5EEUrwqm0mgL6\n\t\t\t\t\t\t/X8Yrw3SCFKIKoWFzGD6JeCmTZmWx/Of53yhszBqa8xWZVtKDRaR9gCC6aKDN+aK\n\t\t\t\t\t\tHn35J4H91FNmBH4LxihBhYRvM0Tf4EgFea0ybQuz/nxhCW+d5qZ+7UEtY++EEffU\n\t\t\t\t\t\t8ptlZ2lX1ZdafBKsFJhFscQaaC1EdY/k/IoIC0BQ2gDVj+UpfVHEci5c2S/uxCI/\n\t\t\t\t\t\tHwFwogiOsSg4OoO2CK/iSqv5aYbb1sg33VbMO2nKp/s+v6g201aU0d05Ap9e5hQh\n\t\t\t\t\t\tktlw6l0ChTv1LWlcCHKpbW8yUqzBzMq+xubbpw6T1bcfN70zz9s0CPzv6b36idbh\n\t\t\t\t\t\t1UE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.2simple.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.2simple.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.2simple.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.2simple.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.2simple.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.2simple.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.2simple.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.2simple.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.2simple.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.2simple.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cas.conncoll.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "atilling@conncoll.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew Tillinghast"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jdailey@conncoll.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jean Dailey"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lbsch@conncoll.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Laurie Schaeffer"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jsch@conncoll.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Schaeffer"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://cas.conncoll.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cas.conncoll.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cas.conncoll.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cas.conncoll.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cas.conncoll.edu:443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cas.conncoll.edu:443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "conncoll.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Connecticut College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAPUEeM0abFXGCIdEOlAW+9wmzXf4MA0GCSqGSIb3DQEB\nBQUAMB4xHDAaBgNVBAMTE2Nhc3RzdC5jb25uY29sbC5lZHUwHhcNMTMxMDI4MTYw\nNzU1WhcNMzMxMDI4MTYwNzU1WjAeMRwwGgYDVQQDExNjYXN0c3QuY29ubmNvbGwu\nZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoIFDuBMCiM4YbPZC\nm3ezj4xircODZvGjqjy06237XEsGT8oKZBbciJKyuNzASg6FropxbyX3i+4/6+E3\nlgxgs1hqqzHGiS6B5R0ilQBkIZHdCNhNXFp65380XwTQswn+9FrmZsrOVGcxWfnu\nQbS28Tp69D3mq8CFjQ+L3LUt3CgzX3SlvdeH8WCX7fsJisN6VkAg/LuNPO/wIUhW\nmaInVIPBfMLgmT2pWSAXVanmGhbpmriOa/PMvw57VQX1jPAktbfNQvwcVmwkOS+e\nqLP4zmKDx09AQui5X+tAShB/Fu0GhcsrSBiK5MbtjuQcOSH1R8uZV/9/Ku2le3oK\nUi7jfQIDAQABo20wazBKBgNVHREEQzBBghNjYXN0c3QuY29ubmNvbGwuZWR1hipo\ndHRwczovL2Nhc3RzdC5jb25uY29sbC5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0O\nBBYEFM0pR2d0wY/alMsBiZDCxRt34lzpMA0GCSqGSIb3DQEBBQUAA4IBAQBVfUXC\ncNA6+xYP28WbWxZmrIvWZvDRyHWU/GiM4fOj+pSV1SfuQ/CBUI/3BDTOe+kxjMM5\nA5gbTLSemQz0hg435PNUfqfbjjfWyBeNmEnyIWgbH+onJJfxfclDRPsmkfNpzZfq\n+NGIlWBQqg4TiqP6eWteaLpR6JTrZvNHByQayM+5gc3BbFCEAbp5mxy5ZTARYRed\nx6203y+SNmiQJbanlMD+Zc7Dy5XmEMoGZjxNqa+9hj1O7oD2wyU4aGciOIkX6txH\n4e/vvoM57//T3rGxWRAUJwD5uYM0Dmkj2UhVU9xPPTsHIEoN38w2FWQi1UhTM2mN\nZw7lDmCUxzGbtrzP"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Connecticut College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.conncoll.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Connecticut College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.leyton.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.leyton.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/leyton.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/leyton.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "leyton.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Leyton Sixth Form College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.leyton.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://informationservice-test.idoxgroup.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@idoxgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ukfederation@idoxgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://informationservice-test.idoxgroup.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-01-24T15:55:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IDOX Information Services Ltd: PLANEX Test site"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://informationservice-test.idoxgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IDOX Information Services Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://informationservice-test.idoxgroup.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://informationservice-test.idoxgroup.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://informationservice-test.idoxgroup.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://informationservice-test.idoxgroup.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://informationservice-test.idoxgroup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDljCCAn4CAQAwDQYJKoZIhvcNAQEEBQAwgZAxCzAJBgNVBAYTAkdCMREwDwYD\n\t\t\t\t\t\tVQQIEwhTY290bGFuZDEQMA4GA1UEBxMHR2xhc2dvdzETMBEGA1UEChMKSURPWCBH\n\t\t\t\t\t\tcm91cDEcMBoGA1UECxMTSW5mb3JtYXRpb24gU2VydmljZTEpMCcGA1UEAxMgaW5m\n\t\t\t\t\t\tb3JtYXRpb25zZXJ2aWNlLmlkb3hncm91cC5jb20wHhcNMTAwMzE5MTM0MzAyWhcN\n\t\t\t\t\t\tMjAwMzE2MTM0MzAyWjCBkDELMAkGA1UEBhMCR0IxETAPBgNVBAgTCFNjb3RsYW5k\n\t\t\t\t\t\tMRAwDgYDVQQHEwdHbGFzZ293MRMwEQYDVQQKEwpJRE9YIEdyb3VwMRwwGgYDVQQL\n\t\t\t\t\t\tExNJbmZvcm1hdGlvbiBTZXJ2aWNlMSkwJwYDVQQDEyBpbmZvcm1hdGlvbnNlcnZp\n\t\t\t\t\t\tY2UuaWRveGdyb3VwLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAJtxqpaLhnY5M+Op1rdKcu4Q+NKkG9xTyhrVyD3q6Ebd3F2z7Pq4Ul++dsMy+eWO\n\t\t\t\t\t\t4KSwYjAFnIMS8uuuGCa9sagt9xHs/K2F5nGB+rAfkbW11LikdL9fuEmUc44/Qh1z\n\t\t\t\t\t\tD85p0GLoMHVdfJJTK3atAbXY6MExGvYCrnB6GnmqU14HW2M6jR64pxopBRobpgHn\n\t\t\t\t\t\tz3fH+ShiI57swZ3PQNSlpUjTM8oYNiBE8aiA9/4LdyBXK3MCZd2B8v6+OIcoJbB8\n\t\t\t\t\t\tJ5Xaqt/aUkMhAPZOgYTnvSwuj1vDnq5aKLJefw/ot2PvrVB60+v+ImP3OlMZ74qG\n\t\t\t\t\t\tzCtl1ahe2V5j+d5uooOpZt0CAwEAATANBgkqhkiG9w0BAQQFAAOCAQEAYy1VOTwC\n\t\t\t\t\t\tgb3FghRYG9j/2TXGBb1bBzZqjadF3xll1j9mRyKr9AajSSVWg+UrZGUVY3XRvBfB\n\t\t\t\t\t\tJnNZwDWamqw0iFwv+leY3IazhRqSONOiJiRQSzwPbUBkRTiefjg2mUYQBXj3uZw+\n\t\t\t\t\t\tOW5/UBFrqYN63pRYS7bK9fuAzda/3bVX+ySwp+GFoEatDd+3S8J07HaHWxUVcd3q\n\t\t\t\t\t\tDYGFIWBoJhWGJbsYbjmnI+A4a1o356y+CnWR1Xz/EHtgkIt4ZRYtja1tUVh/F+wy\n\t\t\t\t\t\tx9gf6TLgM8FeLWuNj4AIxVItjjDM76EyP63uGcJpkuRoyBY2IPoIv+h6lREA5DdN\n\t\t\t\t\t\tS5PKEEUqwEK65g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDljCCAn4CAQAwDQYJKoZIhvcNAQEEBQAwgZAxCzAJBgNVBAYTAkdCMREwDwYD\n\t\t\t\t\t\tVQQIEwhTY290bGFuZDEQMA4GA1UEBxMHR2xhc2dvdzETMBEGA1UEChMKSURPWCBH\n\t\t\t\t\t\tcm91cDEcMBoGA1UECxMTSW5mb3JtYXRpb24gU2VydmljZTEpMCcGA1UEAxMgaW5m\n\t\t\t\t\t\tb3JtYXRpb25zZXJ2aWNlLmlkb3hncm91cC5jb20wHhcNMTAwMzE5MTM0MzAyWhcN\n\t\t\t\t\t\tMjAwMzE2MTM0MzAyWjCBkDELMAkGA1UEBhMCR0IxETAPBgNVBAgTCFNjb3RsYW5k\n\t\t\t\t\t\tMRAwDgYDVQQHEwdHbGFzZ293MRMwEQYDVQQKEwpJRE9YIEdyb3VwMRwwGgYDVQQL\n\t\t\t\t\t\tExNJbmZvcm1hdGlvbiBTZXJ2aWNlMSkwJwYDVQQDEyBpbmZvcm1hdGlvbnNlcnZp\n\t\t\t\t\t\tY2UuaWRveGdyb3VwLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAJtxqpaLhnY5M+Op1rdKcu4Q+NKkG9xTyhrVyD3q6Ebd3F2z7Pq4Ul++dsMy+eWO\n\t\t\t\t\t\t4KSwYjAFnIMS8uuuGCa9sagt9xHs/K2F5nGB+rAfkbW11LikdL9fuEmUc44/Qh1z\n\t\t\t\t\t\tD85p0GLoMHVdfJJTK3atAbXY6MExGvYCrnB6GnmqU14HW2M6jR64pxopBRobpgHn\n\t\t\t\t\t\tz3fH+ShiI57swZ3PQNSlpUjTM8oYNiBE8aiA9/4LdyBXK3MCZd2B8v6+OIcoJbB8\n\t\t\t\t\t\tJ5Xaqt/aUkMhAPZOgYTnvSwuj1vDnq5aKLJefw/ot2PvrVB60+v+ImP3OlMZ74qG\n\t\t\t\t\t\tzCtl1ahe2V5j+d5uooOpZt0CAwEAATANBgkqhkiG9w0BAQQFAAOCAQEAYy1VOTwC\n\t\t\t\t\t\tgb3FghRYG9j/2TXGBb1bBzZqjadF3xll1j9mRyKr9AajSSVWg+UrZGUVY3XRvBfB\n\t\t\t\t\t\tJnNZwDWamqw0iFwv+leY3IazhRqSONOiJiRQSzwPbUBkRTiefjg2mUYQBXj3uZw+\n\t\t\t\t\t\tOW5/UBFrqYN63pRYS7bK9fuAzda/3bVX+ySwp+GFoEatDd+3S8J07HaHWxUVcd3q\n\t\t\t\t\t\tDYGFIWBoJhWGJbsYbjmnI+A4a1o356y+CnWR1Xz/EHtgkIt4ZRYtja1tUVh/F+wy\n\t\t\t\t\t\tx9gf6TLgM8FeLWuNj4AIxVItjjDM76EyP63uGcJpkuRoyBY2IPoIv+h6lREA5DdN\n\t\t\t\t\t\tS5PKEEUqwEK65g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://informationservice-test.idoxgroup.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://informationservice-test.idoxgroup.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://informationservice-test.idoxgroup.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://informationservice-test.idoxgroup.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://informationservice-test.idoxgroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://informationservice-test.idoxgroup.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://informationservice-test.idoxgroup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://informationservice-test.idoxgroup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://informationservice-test.idoxgroup.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://informationservice-test.idoxgroup.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://adfs3host.proxy.rocmn.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs3host.proxy.rocmn.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-06-17T16:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/bbde5129d0d6c08aefc07ed679db3145",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ROC Midden Nederland is een onderwijsorganisatie voor middelbaar beroepsonderwijs, voortgezet onderwijs voor volwassen (VAVO Lyceum), bedrijfsopleidingen en participatieonderwijs in de provincie Utrecht."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ROC Midden Nederland is een onderwijsorganisatie voor middelbaar beroepsonderwijs, voortgezet onderwijs voor volwassen (VAVO Lyceum), bedrijfsopleidingen en participatieonderwijs in de provincie Utrecht."
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/ROCMNlogo.png",
                    "height": "70",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "130"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ROC Midden Nederland"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ROC Midden Nederland"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ROC Midden Nederland"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ROC Midden Nederland"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rocmn.nl"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rocmn.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ROC Midden Nederland"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ROC Midden Nederland"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://unicos.cirqahosting.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Orchard"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lee@isoxford.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lee"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Salvesen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:david@isoxford.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://unicos.cirqahosting.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-11-27T13:52:11Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University College School"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.isoxford.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IS Oxford Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://unicos.cirqahosting.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://unicos.cirqahosting.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://unicos.cirqahosting.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://unicos.cirqahosting.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://unicos.cirqahosting.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://unicos.cirqahosting.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHjCCAgagAwIBAgIJAI69JgucdSaEMA0GCSqGSIb3DQEBBQUAMCgxJjAkBgNV\n\t\t\t\t\t\tBAMTHXVuaWNvcy5pc294Zm9yZC1ob3N0aW5nLmxvY2FsMB4XDTE1MDcwODEzNTQz\n\t\t\t\t\t\tMVoXDTI1MDcwNTEzNTQzMVowKDEmMCQGA1UEAxMddW5pY29zLmlzb3hmb3JkLWhv\n\t\t\t\t\t\tc3RpbmcubG9jYWwwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCgHQ3c\n\t\t\t\t\t\t0LnjZ3dzAjpblQeJa9vagyWKVXbSH5AMgiJ0IyqAOosEbMpr8IunPsBDOUHRk1T1\n\t\t\t\t\t\tPEQxmsm4oZgqQq98Hu7N1NTNONw3awjqrexrx12dAl8VKdeCA1064Zp/G91zHWhO\n\t\t\t\t\t\tGORr3CNpogSKqGgELQmpM/j8UufQy9OY9rnkSWGqZwJX1Iux/tnvAJw8vXZLjtCa\n\t\t\t\t\t\tJkBAfSCs/GFiuUVKOgdBqDSERdBd/tQCyFcn+yvsNsK6LKoDWpoKGxw05Ty9F5Bb\n\t\t\t\t\t\tmZj3Cukv+JCeU42AjZ8u+sMMZYXeS1K31U0Symd1LxKMYjfHLxAO1HgB2VCaaMeM\n\t\t\t\t\t\thCS02XsYS3TfdtR1AgMBAAGjSzBJMCgGA1UdEQQhMB+CHXVuaWNvcy5pc294Zm9y\n\t\t\t\t\t\tZC1ob3N0aW5nLmxvY2FsMB0GA1UdDgQWBBS58/SjLZWTJZDMtuPsucYe7PoqAjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAjDAB0udHtjoXlaNpcbWKquYPza9p0Wh0AaMKz5jt\n\t\t\t\t\t\tL7DCgazgDfXMpwY3J+M0ysH33s9mdd4vRe0ARro+Ec1VwY4yHjz4AvQDcGBwqZLr\n\t\t\t\t\t\t4AM0AK3ICpoGHBosozp8vzB1vdY9duH2n7lXGyPsiS9hZKj6oQ/gSjEIfCpwMVd8\n\t\t\t\t\t\tS6Dr5k2bhtxjFQlZdF1ofUXQTs63rE5iQ11mYGSXd0FUeJnaEmWhpkp+kTsgn3Uj\n\t\t\t\t\t\t5Fx8nzqsHxkDaZC+DVGajwkzDDgsz1saH15dOOIDoHcdW3snMD3jBWuT7Yq/Kj6B\n\t\t\t\t\t\tRH7xD7LtoPdX1VlnCjvUQILdhc/mJ9MddLSOW6r9JubXgg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://unicos.cirqahosting.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://unicos.cirqahosting.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://unicos.cirqahosting.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://unicos.cirqahosting.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://unicos.cirqahosting.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://unicos.cirqahosting.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.cwu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp-admins@networks.cwu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CWU Identity Provider Administrators"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cwu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.cwu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cwu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cwu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.cwu.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cwu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cwu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cwu.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://idp.cwu.edu/images/cwulogo.png",
                    "lang": "en",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "153"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Central Washington University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAPt8x8FtcfDVuV6N/QbiW4L+1GRpMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2lkcC5jd3UuZWR1MB4XDTEzMTIwOTE3NDEyMVoXDTMz\nMTIwOTE3NDEyMVowFjEUMBIGA1UEAxMLaWRwLmN3dS5lZHUwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCyMIfTzVuFDgmSsKioh1W0EtU9/W8/RMnj9Lug\nRc+5ncjiv5fM9ZRFu/iMiNpXDcjD9eeR7RK+jkbN50A/b3PBNLrUjfMljncT924O\nmfZ6BB1Z4Ih+XBB7BM0Y0hXUb+OcyvA9h9vfbWkheShbxkaXMZFLQykQdPUY3acl\nMjrBiFsuaWapIrctNNk8ie5pNN9lTXvULxlqxvmwrexRqTGjYZ+FHfUajdODw7Q+\nCBK4pnVwlln5PNvOK7NGZjFIaNVIcQh5inSCXi5hWK0+rhI1x/JojuHg63d24TLk\nBHgzORK0FCoAQEI3OxQA+6IMxsceYVQddC9rXWHvgZayIXtJAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2lkcC5jd3UuZWR1hiJodHRwczovL2lkcC5jd3UuZWR1L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBS+taocgWGI+SqvSzy4cJpnL9Uf2DANBgkqhkiG\n9w0BAQUFAAOCAQEAOYxelqkSners+2VJvi9pJmU6xPAL74OYZhhRtPtuRL1Mvjan\nhvrZjtx2lsqZkhUKEEn7IQtVFR5Gw3lW7vNZ2tcNx+aKmXWEhrTqLtuZxM6Zp0oz\n4+J1OGLC4U4V1vcPptSEmdh+0gz9pm+hD1WQkMSYS9QQ3Ik5hTKnKd/vb5/KdPys\nXvhjWr8zU3ZEJPyUIub9bVyhDhX6RxPZU1oelWxaU3+9LI7bShYb6FMnbZh4dDvC\n3jj2YybUOSZmNTOILtnCYiSVeTKwVvGEuzLk1ipBjR+L1ACsmT2WBeKraszHpDMr\nuh7Ac/yv6fmgKvc2SYn3Z6ZzsAmMrUUZyQ4A4g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Central Washington University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cwu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Central Washington University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.demo.researchspace.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@researchspace.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Research Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kowalski"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:matthias@researchspace.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matthias"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.demo.researchspace.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-08-27T09:25:01Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RSpace ELN Demo"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.researchspace.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Research Innovations Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://demo.researchspace.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://demo.researchspace.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://demo.researchspace.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://demo.researchspace.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://demo.researchspace.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://demo.researchspace.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://demo.researchspace.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "RSpace is an enterprise grade Electronic Lab Notebook designed for use in research universities"
                  }
                ],
                "logo": [
                  {
                    "text": "https://demo.researchspace.com/images/biggerLogo.png",
                    "height": "158",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "246"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RSpace ELN Demo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDITCCAgmgAwIBAgIJANwZ+u5yyYcuMA0GCSqGSIb3DQEBBQUAMCkxJzAlBgNV\n\t\t\t\t\t\tBAMTHmlwLTEwLTE4My0yMDQtMTEyLmVjMi5pbnRlcm5hbDAeFw0xNjAxMjgxMzI5\n\t\t\t\t\t\tMTFaFw0yNjAxMjUxMzI5MTFaMCkxJzAlBgNVBAMTHmlwLTEwLTE4My0yMDQtMTEy\n\t\t\t\t\t\tLmVjMi5pbnRlcm5hbDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN+R\n\t\t\t\t\t\tQrD+/rGvxp/lV23XELO+46UXlpF21JN2QzYCulmK/OdWIveXSMVX5GyJr2qNOLQ+\n\t\t\t\t\t\tWaJiY/22IYBT6y+JBNSG0Y1035Dt9NWvZiZwhpaRQLvolrVQ54NtNzEI3OW+fEyO\n\t\t\t\t\t\tZi+jpCRLjMjRbym5pbQI0In5ObPSO9yMu8PeUAvAOTQiF07yH/+V1CKIyHzW9KwT\n\t\t\t\t\t\t9hBzUr4oLqTcHIGQt2k7TiQojAUUx+r6UjE5zFha9IBO+w0RBvzfIjhLCcJ1NbJe\n\t\t\t\t\t\t6H30hCTA6o4VFfP4EIDnDi39TDj8uZwa6WpZB/unSfWJDrIoio7Nv+V+ri3Q69Rc\n\t\t\t\t\t\t9OuHqKyVq0G0sBMWKTkCAwEAAaNMMEowKQYDVR0RBCIwIIIeaXAtMTAtMTgzLTIw\n\t\t\t\t\t\tNC0xMTIuZWMyLmludGVybmFsMB0GA1UdDgQWBBQXYjoNhygtiSsX3YWZ4gjruh5Y\n\t\t\t\t\t\t+DANBgkqhkiG9w0BAQUFAAOCAQEAnQeRbKocV6Kle4vZnYGTlLc83FbjyHJx9CvB\n\t\t\t\t\t\tdDunWGEs9pX2P5F8j2jOr+U0n/UsABXlIWRDWvtUb8uE6uByDJ+C2gIUCPSiUQmc\n\t\t\t\t\t\toOEUZSdnw0896U9U+u8Z7rb0p1ymcSb8nHMKDFRmerAc42HMAdXXHk2x11z9jDFT\n\t\t\t\t\t\tTQA2PGw8r3gVx7CYNYH6cpPcnpqw+oJdq9aJZuPPiiQxLsKcfZRdP0QWVB7OFeov\n\t\t\t\t\t\tcmZfEyO7pK5jDrtmAk9LcGMBQ/rDcI0oMgTdDPfmdI2vlIx+ubcdE26jzllYOWUF\n\t\t\t\t\t\tgxcqTxdxZ1uOBFCZBpakANq368HS3vm1rFISGY2Vup0tTCkolw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://demo.researchspace.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://demo.researchspace.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://demo.researchspace.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://demo.researchspace.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://demo.researchspace.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://demo.researchspace.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://dundee.alma.exlibrisgroup.com/mng/login",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Benoit.Ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Benoit.Ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dundee.alma.exlibrisgroup.com/mng/login",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-15T11:15:29Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Dundee - Alma"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://exlibrisgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ex Libris (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dundee.alma.exlibrisgroup.com/mng/samlSingleLogout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Dundee - Alma"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEUDCCArigAwIBAgIEUWQ+bzANBgkqhkiG9w0BAQUFADBqMQswCQYDVQQGEwJJ\n\t\t\t\t\t\tTDESMBAGA1UECBMJSmVydXNhbGVtMRIwEAYDVQQHEwlKZXJ1c2FsZW0xETAPBgNV\n\t\t\t\t\t\tBAoTCEV4bGlicmlzMQ0wCwYDVQQLEwRBbG1hMREwDwYDVQQDEwhTQU1MIEpLUzAe\n\t\t\t\t\t\tFw0xMzA0MDkxNjE0MzlaFw0yMzA0MDcxNjE0MzlaMGoxCzAJBgNVBAYTAklMMRIw\n\t\t\t\t\t\tEAYDVQQIEwlKZXJ1c2FsZW0xEjAQBgNVBAcTCUplcnVzYWxlbTERMA8GA1UEChMI\n\t\t\t\t\t\tRXhsaWJyaXMxDTALBgNVBAsTBEFsbWExETAPBgNVBAMTCFNBTUwgSktTMIIBojAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQEFAAOCAY8AMIIBigKCAYEAkZEP11/7z1BnlfvByEfwmvkEeWdS\n\t\t\t\t\t\t4h0500whQeaSyLAeIQLnBvv0AL+yrnHUCQhdXtuKcB2KP1hHkORujT/AoyX5KaV6\n\t\t\t\t\t\tiO+afUWdMfePg6nHRXhg/Efpkg4pzq1suDRNlY36nloFU39LHMTDOm6fc6cli5/h\n\t\t\t\t\t\tv0mSgEI3rwTQRYKxe3gt7Yx2HCnyehxdEMYxxLgTUst+fnDvlJ8XSeLcIgwMe8S6\n\t\t\t\t\t\t5tDQJDxCSumDG9gLv4mHIeIWKbAaX3boeDKXM0cj7k1MA0ppDjXZiYeTeM11c3A9\n\t\t\t\t\t\tYNHnosQPN03vKl2Z38Qtg5wBJfGKxbI9mmO517iLpZWw0ppnW0VuxOuzUoIRRgM8\n\t\t\t\t\t\tH9Ic4MdrHrOBpdkjTdiC5P6Dy9CvPsKAf53L2olwlWtv0fAljQ1Zd7tABvUjzOHD\n\t\t\t\t\t\tI+oGLmP5JKt42Pr1xQtA3HEm6Gdi7CMclBAFqOb//xt9fmCh6o8Elxr4p70qU48S\n\t\t\t\t\t\thZAXj5G1oykPWWL0Z9/Jf106wQ4fK5ePxhapAgMBAAEwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggGBAIfkCOJbJuchcJJOQVa1Ryw6T5MDdOS81uZW8MyFRlBI9bB0CfcM0BcddzFs\n\t\t\t\t\t\tWAGslqQra8XWpTQXUrkyY+Uqt5pM1fIupPciVoeCJcK899u+5RM5D6gP5HpC/yc3\n\t\t\t\t\t\tIKyHg91SiGq3nUynaMsRUgGPHZ5rjsXoFg+wYbfT6fDcO+ca4y8OI/mrGczTRjWb\n\t\t\t\t\t\tWWDkVX4RzUZgk8DqwTMytfOdUzhml7qKfdoJyP7+ScfhEkwri1ZinIJ+Drn7lQdw\n\t\t\t\t\t\txCofIkXeJ/2llGWekavHYf+wCINX2m7zrsl7u0pBdbvOrqB54xJ9Jd03tKlyFs7k\n\t\t\t\t\t\t87lAj02qwCOxkOQ1PmbzjBji8NOq05yfUEHzKG/l3mPfj25HTLqLQ8M8Qs87S/H/\n\t\t\t\t\t\t2lA7QhxVaWc0V7kPWo1yIE0KYVnXbHy4Hw2on+dcwH7wPLItCneryp8rM1WRSE+X\n\t\t\t\t\t\ts7Q3F7NVAvvfPrcXUfxw67jc3NQEGPGESn2ZCdcD8SQNPBymdG0572nebb4AhmBR\n\t\t\t\t\t\t2PN4Eg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://dundee.alma.exlibrisgroup.com/mng/pdsHandleLogin",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://www.jusp.mimas.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Meehan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Paul.Meehan@manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Meehan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Paul.Meehan@manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.jusp.mimas.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MIMAS: JISC Usage Stats Portal"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://mimas.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Manchester"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.jusp.mimas.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.jusp.mimas.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.jusp.mimas.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.jusp.mimas.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "JUSP offers centralised access to journal usage data. \n\t\t\t\t\tIRUS-UK enables IRs to share and expose COUNTER statistics."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.jusp.mimas.ac.uk/images/jusp-irus.gif",
                    "height": "165",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "630"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "JUSP and IRUS-UK"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEMTCCAxmgAwIBAgIJALKqYz/D1BgYMA0GCSqGSIb3DQEBBQUAMIGNMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjETMBEGA1UECBMKTWFuY2hlc3RlcjETMBEGA1UEBxMKTWFuY2hlc3Rl\n\t\t\t\t\t\tcjElMCMGA1UEChMcVGhlIFVuaXZlcnNpdHkgb2YgTWFuY2hlc3RlcjEOMAwGA1UE\n\t\t\t\t\t\tCxMFTWltYXMxHTAbBgNVBAMTFHd3dy5qdXNwLm1pbWFzLmFjLnVrMB4XDTEzMDUy\n\t\t\t\t\t\tMDEzMTcxOFoXDTIzMDUxODEzMTcxOFowgY0xCzAJBgNVBAYTAkdCMRMwEQYDVQQI\n\t\t\t\t\t\tEwpNYW5jaGVzdGVyMRMwEQYDVQQHEwpNYW5jaGVzdGVyMSUwIwYDVQQKExxUaGUg\n\t\t\t\t\t\tVW5pdmVyc2l0eSBvZiBNYW5jaGVzdGVyMQ4wDAYDVQQLEwVNaW1hczEdMBsGA1UE\n\t\t\t\t\t\tAxMUd3d3Lmp1c3AubWltYXMuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQDz5+7xpkieZXmqZ6NQcjLc0cPLnyqjHYKO/qJEmBOeSQ4SuHO3cblq\n\t\t\t\t\t\tNRZHc0Ee/OnwGG+Z95qJLb3sJcg87sFaEpokcpQg6QAmAQx6TJTw3EibdPbTmlcp\n\t\t\t\t\t\tsh6jeNuZ8jzLwj6LS4Q3Gsta9R0gWzoHsy2uaXkHBWjLDRDXSM5ykYbsH9uv5G+r\n\t\t\t\t\t\tzpSPLzmzRfCSep5kIXkYNEAO6YFCpWmuxrnhmH37K26ufyTNFLsa/nFaDzHRFvOB\n\t\t\t\t\t\tLqp/kGEoCobHQRkVpWIA30NkNHf3xTdRim8cf2fTbLAMvTvLwk15hEhsofx5vm17\n\t\t\t\t\t\tPsnuzOJz0p7hLl+UgQjDkT4cC8RKTrNBAgMBAAGjgZEwgY4wCQYDVR0TBAIwADAL\n\t\t\t\t\t\tBgNVHQ8EBAMCBLAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMB8GA1Ud\n\t\t\t\t\t\tEQQYMBaCFHd3dy5qdXNwLm1pbWFzLmFjLnVrMDQGA1UdEgQtMCuBKW1pbWFzLXNo\n\t\t\t\t\t\taWItdGVjaEBsaXN0c2Vydi5tYW5jaGVzdGVyLmFjLnVrMA0GCSqGSIb3DQEBBQUA\n\t\t\t\t\t\tA4IBAQAaJrZS+hCYXWz1OhLpLBmrXwGeFFMe6atZiAol0iqFEEI5lxRPUCv//mcj\n\t\t\t\t\t\tzGl7ckpj3QGnGNK/yy0Iw1f8ozDqYQc15EKXrr4ysRLDIiHmV6vp6t0E42KufUr8\n\t\t\t\t\t\tCCuGWOApwh0G9MLGC/L/nT1ktlA7QpwAu2i/pwIwtmzxka45H6UTBH6+nZcV68+c\n\t\t\t\t\t\tlKacUeUUWaQPSU6xX7nZQ8RAxL/rk9YampkcmMl9jjXKZxPfEHh/FcoX7McEmVOB\n\t\t\t\t\t\tHc6B9zDGUrAOwbap5IBazxgixzhlNLvnLBorLMTMtZNAQ5I8r9q1etiGsMwQxcbo\n\t\t\t\t\t\tXSDkRlSDzotmgLAQd0N3B9PAolHl"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEMTCCAxmgAwIBAgIJALKqYz/D1BgYMA0GCSqGSIb3DQEBBQUAMIGNMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjETMBEGA1UECBMKTWFuY2hlc3RlcjETMBEGA1UEBxMKTWFuY2hlc3Rl\n\t\t\t\t\t\tcjElMCMGA1UEChMcVGhlIFVuaXZlcnNpdHkgb2YgTWFuY2hlc3RlcjEOMAwGA1UE\n\t\t\t\t\t\tCxMFTWltYXMxHTAbBgNVBAMTFHd3dy5qdXNwLm1pbWFzLmFjLnVrMB4XDTEzMDUy\n\t\t\t\t\t\tMDEzMTcxOFoXDTIzMDUxODEzMTcxOFowgY0xCzAJBgNVBAYTAkdCMRMwEQYDVQQI\n\t\t\t\t\t\tEwpNYW5jaGVzdGVyMRMwEQYDVQQHEwpNYW5jaGVzdGVyMSUwIwYDVQQKExxUaGUg\n\t\t\t\t\t\tVW5pdmVyc2l0eSBvZiBNYW5jaGVzdGVyMQ4wDAYDVQQLEwVNaW1hczEdMBsGA1UE\n\t\t\t\t\t\tAxMUd3d3Lmp1c3AubWltYXMuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQDz5+7xpkieZXmqZ6NQcjLc0cPLnyqjHYKO/qJEmBOeSQ4SuHO3cblq\n\t\t\t\t\t\tNRZHc0Ee/OnwGG+Z95qJLb3sJcg87sFaEpokcpQg6QAmAQx6TJTw3EibdPbTmlcp\n\t\t\t\t\t\tsh6jeNuZ8jzLwj6LS4Q3Gsta9R0gWzoHsy2uaXkHBWjLDRDXSM5ykYbsH9uv5G+r\n\t\t\t\t\t\tzpSPLzmzRfCSep5kIXkYNEAO6YFCpWmuxrnhmH37K26ufyTNFLsa/nFaDzHRFvOB\n\t\t\t\t\t\tLqp/kGEoCobHQRkVpWIA30NkNHf3xTdRim8cf2fTbLAMvTvLwk15hEhsofx5vm17\n\t\t\t\t\t\tPsnuzOJz0p7hLl+UgQjDkT4cC8RKTrNBAgMBAAGjgZEwgY4wCQYDVR0TBAIwADAL\n\t\t\t\t\t\tBgNVHQ8EBAMCBLAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMB8GA1Ud\n\t\t\t\t\t\tEQQYMBaCFHd3dy5qdXNwLm1pbWFzLmFjLnVrMDQGA1UdEgQtMCuBKW1pbWFzLXNo\n\t\t\t\t\t\taWItdGVjaEBsaXN0c2Vydi5tYW5jaGVzdGVyLmFjLnVrMA0GCSqGSIb3DQEBBQUA\n\t\t\t\t\t\tA4IBAQAaJrZS+hCYXWz1OhLpLBmrXwGeFFMe6atZiAol0iqFEEI5lxRPUCv//mcj\n\t\t\t\t\t\tzGl7ckpj3QGnGNK/yy0Iw1f8ozDqYQc15EKXrr4ysRLDIiHmV6vp6t0E42KufUr8\n\t\t\t\t\t\tCCuGWOApwh0G9MLGC/L/nT1ktlA7QpwAu2i/pwIwtmzxka45H6UTBH6+nZcV68+c\n\t\t\t\t\t\tlKacUeUUWaQPSU6xX7nZQ8RAxL/rk9YampkcmMl9jjXKZxPfEHh/FcoX7McEmVOB\n\t\t\t\t\t\tHc6B9zDGUrAOwbap5IBazxgixzhlNLvnLBorLMTMtZNAQ5I8r9q1etiGsMwQxcbo\n\t\t\t\t\t\tXSDkRlSDzotmgLAQd0N3B9PAolHl"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.jusp.mimas.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.jusp.mimas.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.jusp.mimas.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.jusp.mimas.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.jusp.mimas.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.jusp.mimas.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.jusp.mimas.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.jusp.mimas.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.jusp.mimas.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.jusp.mimas.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.eblib.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Watson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:drew.watson@eblib.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Drew"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bharadwaj"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:vinay.bharadwaj@ebooks.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Vinay"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dhrolia"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ashmir.dhrolia@eblib.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ashmir"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.eblib.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EBL - Ebook Library"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eblib.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ebooks Corporation Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.eblib.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.eblib.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.eblib.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.eblib.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.eblib.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCzCCAfOgAwIBAgIJALoCnTVhq1IhMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\n\t\t\t\t\t\tBAMTDHNwLmVibGliLmNvbTAeFw0xMjAxMDUwMDIyMzZaFw0yMjAxMDIwMDIyMzZa\n\t\t\t\t\t\tMBcxFTATBgNVBAMTDHNwLmVibGliLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBAL7h4T/JsESXBRIXlPdeBLB5L9UAYCBdvpvPtqiksWkphoujeqjk\n\t\t\t\t\t\tmBO2NT98USIRwg6ktP4KYTBlQxItfniFx/lt4xeS8TboN+sTlW6LnY05j9UPL5kN\n\t\t\t\t\t\trnIpFmtbhKseIfDEEbO3m8h0+SZKE/RmfS6+l4/yTePoIhvtTKISDajr2GhdhJoa\n\t\t\t\t\t\t/fjng0lHMikaFzfdd39DfKg/v73v8X9UvtH14ZkSrn4bTRvBCrKHSaMNneAH5N1G\n\t\t\t\t\t\tPopSv+eVkrTPuQMse/w3JplYk08jujhv5Y24YvP9FCpgbQClxXbDn6OxMmejIpEk\n\t\t\t\t\t\tRi3EU2qqEN6N0BSN3N1PeuDOiaViOhbCAoUCAwEAAaNaMFgwNwYDVR0RBDAwLoIM\n\t\t\t\t\t\tc3AuZWJsaWIuY29thh5odHRwOi8vc3AuZWJsaWIuY29tL3NoaWJib2xldGgwHQYD\n\t\t\t\t\t\tVR0OBBYEFH/f6xMjqy+Ci9ctWA+7FStjJwNoMA0GCSqGSIb3DQEBBQUAA4IBAQC8\n\t\t\t\t\t\ty6IkTzJqruNKtOZno4GswDkszRcDYMNx1w+JfMVJZG2YkVkPvWkP9JTCN/tVjKEZ\n\t\t\t\t\t\ta5H4kq2jMUrBndjdu1W+v5jio8mXY8kDCp7Sly5eUtWrqE2q/1iTmJ4oWCHydRcD\n\t\t\t\t\t\tEz+X0sxSnQqxmcFe4ssS8EFzs1WPvinbhz71JZbnkOadPf//1epRxqJlDTq41p0e\n\t\t\t\t\t\tmllYEt3rXPJBv1vCEbjLcZ8d1CTzPc8iveaNjU5h/rglqvDFwoIL870yMJg0n9bK\n\t\t\t\t\t\t4elyV6s5HxPWucc0hyO4eUkbyMnP9QKLAemBKJUgU4SzTVSPLfiFdbe1x4zUMsSO\n\t\t\t\t\t\t3yQ7F/pT44mChEK7mdRw"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.eblib.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.eblib.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.eblib.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.eblib.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.eblib.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp.eblib.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.eblib.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp.eblib.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp.eblib.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp.eblib.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp-preprod.cardiff.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idman@cardiff.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Identity Management"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smart"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:smartp@cardiff.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Philip"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-preprod.cardiff.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-11-25T18:02:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIErDCCA5SgAwIBAgIRAOYsRgGmDwZDq4ktIsUqyQQwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzAxMTAwMDAwMDBaFw0xNjAxMTAyMzU5NTlaMHgxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMQ4wDAYDVQQIEwVXYWxlczEbMBkGA1UEChMSQ2FyZGlmZiBVbml2ZXJz\n\t\t\t\t\t\taXR5MR0wGwYDVQQLExRJbmZvcm1hdGlvbiBTZXJ2aWNlczEdMBsGA1UEAxMUaWRw\n\t\t\t\t\t\tLXByZXByb2QuY2YuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDQK7+T3U6Nj6Vc3XKjyiY1fzXA8j1vN91RbPV96DJGnr0vQnls/S5qqY5U8VJi\n\t\t\t\t\t\t+qzS61+V8TqcpjGUViPYsRnlXISGHnQ7KWccZB2f9lApnJsMhNH6BxCzOYwcLbJw\n\t\t\t\t\t\tsLbwVoJ11Wxv+O8n3dsO5vr4QSHkXen36WbS1YuVQI9rCri0lzdriB5oy+8J7aQq\n\t\t\t\t\t\tGh0azuz7iBc+yFA5RROl7g0cPPXwGpo3p3beWgiVERVdO9Kz5z6sTN306TkT/RKL\n\t\t\t\t\t\tB5mqHnEN/1GNh8BLJcLPJcYt5CkxJLk+YMiNHs7ssv9QLk7mRzq2OAuQFtbMOlyL\n\t\t\t\t\t\tTzFBk3EVKcEHYQlWDaSOlQxfAgMBAAGjggFxMIIBbTAfBgNVHSMEGDAWgBQMvZNo\n\t\t\t\t\t\tDPPeq6NJays3V0fqkOO57TAdBgNVHQ4EFgQUVcZWoy8Sj9k5JJOCpW7IY/XjKYIw\n\t\t\t\t\t\tDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUH\n\t\t\t\t\t\tAwEGCCsGAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIC\n\t\t\t\t\t\tMDoGA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVS\n\t\t\t\t\t\tRU5BU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDov\n\t\t\t\t\t\tL2NydC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGG\n\t\t\t\t\t\tGmh0dHA6Ly9vY3NwLnRjcy50ZXJlbmEub3JnMB8GA1UdEQQYMBaCFGlkcC1wcmVw\n\t\t\t\t\t\tcm9kLmNmLmFjLnVrMA0GCSqGSIb3DQEBBQUAA4IBAQBttEXXeJl3ORiixGzvb3bk\n\t\t\t\t\t\tB1I4hjBX8lQ+U/W7AytyWOsvF8Qzs7mz6an5bakjinYkl5dIRm4eUzTt2KkS8N4a\n\t\t\t\t\t\tJ7dkThSzTAotQ8QgzsrakajH9twHMcccO0Ol5bt/J6dTJ4LhNMc/ULjcApiRjgl/\n\t\t\t\t\t\t8Fh6kwPdGEkRjN7q3xzcJuKJPbfPOVq5HVINafV65BR+r41DlJ05Cll7WxZZ4+zy\n\t\t\t\t\t\tQMstqkzxj6/vm9ycaoWoz2ODk/5GFfWq3OMllgLQoFv+4A/sMH6M5UCgRF/CwFm0\n\t\t\t\t\t\tPOJV6rCq1voBGTr2gforlIfCCsWXBl6BpB8mF2lUzzNRAYrez2/QEO8MceHqR4C7"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cardiff.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-preprod.cf.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-preprod.cf.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-preprod.cf.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-preprod.cf.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-preprod.cf.ac.uk/idp/profile/SAML2/POST-SimpleSign/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-preprod.cf.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-preprod.cf.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-preprod.cf.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-preprod.cf.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-preprod.cf.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-preprod.cf.ac.uk/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-preprod.cf.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-preprod.cf.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cardiff.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://iam.cf.ac.uk/images/CU-Dev-logo-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://iam.cf.ac.uk/images/CU-Dev-logo-80x60.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Cardiff University (Test - Preprod)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIErDCCA5SgAwIBAgIRAOYsRgGmDwZDq4ktIsUqyQQwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xMzAxMTAwMDAwMDBaFw0xNjAxMTAyMzU5NTlaMHgxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMQ4wDAYDVQQIEwVXYWxlczEbMBkGA1UEChMSQ2FyZGlmZiBVbml2ZXJz\n\t\t\t\t\t\taXR5MR0wGwYDVQQLExRJbmZvcm1hdGlvbiBTZXJ2aWNlczEdMBsGA1UEAxMUaWRw\n\t\t\t\t\t\tLXByZXByb2QuY2YuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDQK7+T3U6Nj6Vc3XKjyiY1fzXA8j1vN91RbPV96DJGnr0vQnls/S5qqY5U8VJi\n\t\t\t\t\t\t+qzS61+V8TqcpjGUViPYsRnlXISGHnQ7KWccZB2f9lApnJsMhNH6BxCzOYwcLbJw\n\t\t\t\t\t\tsLbwVoJ11Wxv+O8n3dsO5vr4QSHkXen36WbS1YuVQI9rCri0lzdriB5oy+8J7aQq\n\t\t\t\t\t\tGh0azuz7iBc+yFA5RROl7g0cPPXwGpo3p3beWgiVERVdO9Kz5z6sTN306TkT/RKL\n\t\t\t\t\t\tB5mqHnEN/1GNh8BLJcLPJcYt5CkxJLk+YMiNHs7ssv9QLk7mRzq2OAuQFtbMOlyL\n\t\t\t\t\t\tTzFBk3EVKcEHYQlWDaSOlQxfAgMBAAGjggFxMIIBbTAfBgNVHSMEGDAWgBQMvZNo\n\t\t\t\t\t\tDPPeq6NJays3V0fqkOO57TAdBgNVHQ4EFgQUVcZWoy8Sj9k5JJOCpW7IY/XjKYIw\n\t\t\t\t\t\tDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUH\n\t\t\t\t\t\tAwEGCCsGAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIC\n\t\t\t\t\t\tMDoGA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVS\n\t\t\t\t\t\tRU5BU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDov\n\t\t\t\t\t\tL2NydC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGG\n\t\t\t\t\t\tGmh0dHA6Ly9vY3NwLnRjcy50ZXJlbmEub3JnMB8GA1UdEQQYMBaCFGlkcC1wcmVw\n\t\t\t\t\t\tcm9kLmNmLmFjLnVrMA0GCSqGSIb3DQEBBQUAA4IBAQBttEXXeJl3ORiixGzvb3bk\n\t\t\t\t\t\tB1I4hjBX8lQ+U/W7AytyWOsvF8Qzs7mz6an5bakjinYkl5dIRm4eUzTt2KkS8N4a\n\t\t\t\t\t\tJ7dkThSzTAotQ8QgzsrakajH9twHMcccO0Ol5bt/J6dTJ4LhNMc/ULjcApiRjgl/\n\t\t\t\t\t\t8Fh6kwPdGEkRjN7q3xzcJuKJPbfPOVq5HVINafV65BR+r41DlJ05Cll7WxZZ4+zy\n\t\t\t\t\t\tQMstqkzxj6/vm9ycaoWoz2ODk/5GFfWq3OMllgLQoFv+4A/sMH6M5UCgRF/CwFm0\n\t\t\t\t\t\tPOJV6rCq1voBGTr2gforlIfCCsWXBl6BpB8mF2lUzzNRAYrez2/QEO8MceHqR4C7"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cardiff University (Test - Preprod)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cardiff.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cardiff University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://cafe.ufba.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Luiz Claudio Mendonca"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mendonca@ufba.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.ufba.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID1TCCAr2gAwIBAgIJAIiwOzCHMwd+MA0GCSqGSIb3DQEBCwUAMIGAMQswCQYD\nVQQGEwJCUjEOMAwGA1UECAwFQmFoaWExETAPBgNVBAcMCFNhbHZhZG9yMQ0wCwYD\nVQQKDARVRkJBMQwwCgYDVQQLDANTVEkxFTATBgNVBAMMDGNhZmUudWZiYS5icjEa\nMBgGCSqGSIb3DQEJARYLc3RpQHVmYmEuYnIwHhcNMTUxMDE5MTYyNTUyWhcNMjAx\nMDE3MTYyNTUyWjCBgDELMAkGA1UEBhMCQlIxDjAMBgNVBAgMBUJhaGlhMREwDwYD\nVQQHDAhTYWx2YWRvcjENMAsGA1UECgwEVUZCQTEMMAoGA1UECwwDU1RJMRUwEwYD\nVQQDDAxjYWZlLnVmYmEuYnIxGjAYBgkqhkiG9w0BCQEWC3N0aUB1ZmJhLmJyMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA58V0mSKG7+AAJyz2mFDWWgDM\n26rLv667Z2wprnsvPgmLXnp2p2tRtoA/3cmILA8gCO9YXlXD9tPxDRsq2tmZhMgl\nK3dyxYA7FtsJdLURYThMJ5HdHS2cKZpeSfyTELoABH0TDo3/WeAPUyra9Hs8y7Il\nrDDjBewMq8xSQmiRNf8sVlke0iWGjOK1Wm6XZm4F6Ww8N9gFRkD0OzdZINiEF4EJ\n1M5yMkRKsK4mfAemEgW5ipT8OGXvEuiNiGZdy7tTLBpUMkfry3TqJeSGOHS0Wt8Y\nikxaC3zz/sv+B8BcpUKuDSD5ykuWI5qPF6dHP2gSxJ3/52p2nvkissocnhprywID\nAQABo1AwTjAdBgNVHQ4EFgQUKhtZnHP563+jSKkAz8ZNEhY0WyowHwYDVR0jBBgw\nFoAUKhtZnHP563+jSKkAz8ZNEhY0WyowDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0B\nAQsFAAOCAQEAJdV75YTcywT4Z08RUcXUQ1COUdFWPijB39AVeOz9rpG956SNlSh3\n8SLWbTfOseQ8FzDG5mt9toHKnoSo/7CtqvzlQG7YYBVapGxMy7F1R5IFFCHdnb/k\nECqhyWTU4vn3wB3CNOsI68hBfjZ8EjVvHI9QOzAzerFJ9vpCcXORZ2CjvFiNAmTu\nLpdH6JDSu9UTt4htAVse2eXjeS4pAaNnHsiQq9wmv5hVU693IlDxT8wjiLckKPrp\niPZuKlqQQ20kKcY9bdviJpryceHvW5OmwxP5X0huSAFqzrFLLxGbxwucwtEgWv2v\nIf0w9eTfY0ltoPGddjbkgTmrReY9T8zNdQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.ufba.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.ufba.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.ufba.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.ufba.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.ufba.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.ufba.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.ufba.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.ufba.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufba.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufba.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFBA - Universidade Federal da Bahia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFBA - Universidade Federal da Bahia"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFBA - Universidade Federal da Bahia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFBA - Universidade Federal da Bahia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID1TCCAr2gAwIBAgIJAIiwOzCHMwd+MA0GCSqGSIb3DQEBCwUAMIGAMQswCQYD\nVQQGEwJCUjEOMAwGA1UECAwFQmFoaWExETAPBgNVBAcMCFNhbHZhZG9yMQ0wCwYD\nVQQKDARVRkJBMQwwCgYDVQQLDANTVEkxFTATBgNVBAMMDGNhZmUudWZiYS5icjEa\nMBgGCSqGSIb3DQEJARYLc3RpQHVmYmEuYnIwHhcNMTUxMDE5MTYyNTUyWhcNMjAx\nMDE3MTYyNTUyWjCBgDELMAkGA1UEBhMCQlIxDjAMBgNVBAgMBUJhaGlhMREwDwYD\nVQQHDAhTYWx2YWRvcjENMAsGA1UECgwEVUZCQTEMMAoGA1UECwwDU1RJMRUwEwYD\nVQQDDAxjYWZlLnVmYmEuYnIxGjAYBgkqhkiG9w0BCQEWC3N0aUB1ZmJhLmJyMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA58V0mSKG7+AAJyz2mFDWWgDM\n26rLv667Z2wprnsvPgmLXnp2p2tRtoA/3cmILA8gCO9YXlXD9tPxDRsq2tmZhMgl\nK3dyxYA7FtsJdLURYThMJ5HdHS2cKZpeSfyTELoABH0TDo3/WeAPUyra9Hs8y7Il\nrDDjBewMq8xSQmiRNf8sVlke0iWGjOK1Wm6XZm4F6Ww8N9gFRkD0OzdZINiEF4EJ\n1M5yMkRKsK4mfAemEgW5ipT8OGXvEuiNiGZdy7tTLBpUMkfry3TqJeSGOHS0Wt8Y\nikxaC3zz/sv+B8BcpUKuDSD5ykuWI5qPF6dHP2gSxJ3/52p2nvkissocnhprywID\nAQABo1AwTjAdBgNVHQ4EFgQUKhtZnHP563+jSKkAz8ZNEhY0WyowHwYDVR0jBBgw\nFoAUKhtZnHP563+jSKkAz8ZNEhY0WyowDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0B\nAQsFAAOCAQEAJdV75YTcywT4Z08RUcXUQ1COUdFWPijB39AVeOz9rpG956SNlSh3\n8SLWbTfOseQ8FzDG5mt9toHKnoSo/7CtqvzlQG7YYBVapGxMy7F1R5IFFCHdnb/k\nECqhyWTU4vn3wB3CNOsI68hBfjZ8EjVvHI9QOzAzerFJ9vpCcXORZ2CjvFiNAmTu\nLpdH6JDSu9UTt4htAVse2eXjeS4pAaNnHsiQq9wmv5hVU693IlDxT8wjiLckKPrp\niPZuKlqQQ20kKcY9bdviJpryceHvW5OmwxP5X0huSAFqzrFLLxGbxwucwtEgWv2v\nIf0w9eTfY0ltoPGddjbkgTmrReY9T8zNdQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFBA - Universidade Federal da Bahia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFBA - Universidade Federal da Bahia"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufba.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufba.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFBA - Universidade Federal da Bahia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFBA - Universidade Federal da Bahia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://auth.kanopystreaming.com/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@kanopystreaming.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@kanopystreaming.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://auth.kanopystreaming.com/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-03-02T14:50:33Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Kanopy"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.kanopystreaming.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Kanopy LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.kanopystreaming.com/module.php/saml/sp/saml2-logout.php/kanopy-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.kanopystreaming.com/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kanopy"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Kanopy provides students access to one of the largest collections of films in the world."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.kanopystreaming.com/images/logo.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "244"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.kanopystreaming.com/privacy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDXTCCAkWgAwIBAgIJAMd4bsRevC6eMA0GCSqGSIb3DQEBCwUAMEUxCzAJBgNV\n\t\t\t\t\t\tBAYTAkFVMRMwEQYDVQQIDApTb21lLVN0YXRlMSEwHwYDVQQKDBhJbnRlcm5ldCBX\n\t\t\t\t\t\taWRnaXRzIFB0eSBMdGQwHhcNMTYwMTI3MjA1NzA0WhcNMjYwMTI2MjA1NzA0WjBF\n\t\t\t\t\t\tMQswCQYDVQQGEwJBVTETMBEGA1UECAwKU29tZS1TdGF0ZTEhMB8GA1UECgwYSW50\n\t\t\t\t\t\tZXJuZXQgV2lkZ2l0cyBQdHkgTHRkMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEA6lr1KenL+8NIIFF1O/ZYr7QM2iPCzTyoKYQFBkytxhCl2QI4/dGnvNEI\n\t\t\t\t\t\t6j7jO+g+rAsuDV93xzl0Q0U++ePCCbXNk5xmicDsseKphm8zRWBs2qX/Fc7j+xj1\n\t\t\t\t\t\toHStGOdR6mNCbVPwHGfxt1hexl7OuYc68g99rGvNyxsC3btKxXFqqocRJjOzN3mC\n\t\t\t\t\t\tSK9iYOANuUd0/uVZfLSamFdy4vppvx+07uJpOP5MjURhak23J2fEakJlespb0Rnx\n\t\t\t\t\t\tto7jlr0XtYRVAcrmtAzCPH6+odpEcvKQW6aNNjptWDydyHI51CwtMWtLFRo9kG7a\n\t\t\t\t\t\t+Cv09QfMFnUAW4dsDM1uj4b1zbYofwIDAQABo1AwTjAdBgNVHQ4EFgQUQyzngqZY\n\t\t\t\t\t\tdgiY8mUuEXKGsx1yrucwHwYDVR0jBBgwFoAUQyzngqZYdgiY8mUuEXKGsx1yrucw\n\t\t\t\t\t\tDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAQEAhWVyteEFaXyderai93CH\n\t\t\t\t\t\tvXZx0H7UAHjNxzoKekcAxLp6w4WyS8Zey9I+27sE+yBpTeczrarvHOpVsurLQGW3\n\t\t\t\t\t\tLltH7N5ae9YHjtPZt3HDtbiPi/il4ZNiYgo0SoBqMZWRV+4rLkiWgyk43rq67CmK\n\t\t\t\t\t\tLH9RwXbOi54xJTD9lMUu8uOCl9pH2Rp+j3oDAYCaBTfoKXZ8JhW0q8a66xhrAlvA\n\t\t\t\t\t\tBCm1dhF2Jcp66Ar/Jp2GBoEznO1K6ZC/Clyp8PVQWy30tjJIDIBbjGA4UaIa1svr\n\t\t\t\t\t\tyNrRd5CscUpJtErU643z2X4xxjTsyEj8LBM2jWzjp/8dI7e5kJoOeQ/CzeD9K8v5\n\t\t\t\t\t\teQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDXTCCAkWgAwIBAgIJAMd4bsRevC6eMA0GCSqGSIb3DQEBCwUAMEUxCzAJBgNV\n\t\t\t\t\t\tBAYTAkFVMRMwEQYDVQQIDApTb21lLVN0YXRlMSEwHwYDVQQKDBhJbnRlcm5ldCBX\n\t\t\t\t\t\taWRnaXRzIFB0eSBMdGQwHhcNMTYwMTI3MjA1NzA0WhcNMjYwMTI2MjA1NzA0WjBF\n\t\t\t\t\t\tMQswCQYDVQQGEwJBVTETMBEGA1UECAwKU29tZS1TdGF0ZTEhMB8GA1UECgwYSW50\n\t\t\t\t\t\tZXJuZXQgV2lkZ2l0cyBQdHkgTHRkMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEA6lr1KenL+8NIIFF1O/ZYr7QM2iPCzTyoKYQFBkytxhCl2QI4/dGnvNEI\n\t\t\t\t\t\t6j7jO+g+rAsuDV93xzl0Q0U++ePCCbXNk5xmicDsseKphm8zRWBs2qX/Fc7j+xj1\n\t\t\t\t\t\toHStGOdR6mNCbVPwHGfxt1hexl7OuYc68g99rGvNyxsC3btKxXFqqocRJjOzN3mC\n\t\t\t\t\t\tSK9iYOANuUd0/uVZfLSamFdy4vppvx+07uJpOP5MjURhak23J2fEakJlespb0Rnx\n\t\t\t\t\t\tto7jlr0XtYRVAcrmtAzCPH6+odpEcvKQW6aNNjptWDydyHI51CwtMWtLFRo9kG7a\n\t\t\t\t\t\t+Cv09QfMFnUAW4dsDM1uj4b1zbYofwIDAQABo1AwTjAdBgNVHQ4EFgQUQyzngqZY\n\t\t\t\t\t\tdgiY8mUuEXKGsx1yrucwHwYDVR0jBBgwFoAUQyzngqZYdgiY8mUuEXKGsx1yrucw\n\t\t\t\t\t\tDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAQEAhWVyteEFaXyderai93CH\n\t\t\t\t\t\tvXZx0H7UAHjNxzoKekcAxLp6w4WyS8Zey9I+27sE+yBpTeczrarvHOpVsurLQGW3\n\t\t\t\t\t\tLltH7N5ae9YHjtPZt3HDtbiPi/il4ZNiYgo0SoBqMZWRV+4rLkiWgyk43rq67CmK\n\t\t\t\t\t\tLH9RwXbOi54xJTD9lMUu8uOCl9pH2Rp+j3oDAYCaBTfoKXZ8JhW0q8a66xhrAlvA\n\t\t\t\t\t\tBCm1dhF2Jcp66Ar/Jp2GBoEznO1K6ZC/Clyp8PVQWy30tjJIDIBbjGA4UaIa1svr\n\t\t\t\t\t\tyNrRd5CscUpJtErU643z2X4xxjTsyEj8LBM2jWzjp/8dI7e5kJoOeQ/CzeD9K8v5\n\t\t\t\t\t\teQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.kanopystreaming.com/module.php/saml/sp/saml2-acs.php/kanopy-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://auth.kanopystreaming.com/module.php/saml/sp/saml1-acs.php/kanopy-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://auth.kanopystreaming.com/module.php/saml/sp/saml2-acs.php/kanopy-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://auth.kanopystreaming.com/module.php/saml/sp/saml1-acs.php/kanopy-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Kanopy"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonTargetedID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.lnu.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it.idp@lnu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Linn\u00e6us University"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.lnu.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEmzCCA4OgAwIBAgILAQAAAAABJCUIvfswDQYJKoZIhvcNAQEFBQAwXzELMAkG\nA1UEBhMCQkUxEzARBgNVBAoTCkN5YmVydHJ1c3QxFzAVBgNVBAsTDkVkdWNhdGlv\nbmFsIENBMSIwIAYDVQQDExlDeWJlcnRydXN0IEVkdWNhdGlvbmFsIENBMB4XDTA5\nMTAwNTEzMzEwNVoXDTEyMTAwNTEzMzEwNVowTDELMAkGA1UEBhMCU0UxGzAZBgNV\nBAoTEkhvZ3Nrb2xhbiBpIEthbG1hcjELMAkGA1UECxMCSVQxEzARBgNVBAMTCmlk\ncC5sbnUuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDRORVY50+Y\n2rmvFJS4HSE3EZKXb0UpVj2CfW9D4Vlww78CiqV0KV8HW53XHYlOUK7S+I94adaG\nXoXq19HjqjRi8979qfqzKwICRlkVFBnWkY7N5vo//pStClwdTNv+OihlDY+IA9HN\nQXrWjWTzHCbRguYBEmR0gp7l4tlqILkOCCx1yT5uia4EiJvrSFoIV/iYTQBLaGkc\nZdO109GqUx5UJB5XxgUoT0k0rOgg1OHsOvkNGOV4/HzkwWUGIaJy462LlLBcmlXg\nIHfDCMH6lg9pBLig4nDlM2W0KzvMID7zagxFJG+K3eMjdkoK1mK12TTz24bifDpf\nXPnbSRKpkLYpAgMBAAGjggFpMIIBZTBQBgNVHSAESTBHMEUGByqGSLE+AQAwOjA4\nBggrBgEFBQcCARYsaHR0cDovL3d3dy5nbG9iYWxzaWduLm5ldC9yZXBvc2l0b3J5\nL2Nwcy5jZm0wDgYDVR0PAQH/BAQDAgWgMB8GA1UdIwQYMBaAFGVloz3XOxGjCgcl\nN8lCSlt2d1DhMB0GA1UdDgQWBBQCNc1rrFMLNldAEde83Hr98intIzA6BgNVHR8E\nMzAxMC+gLaArhilodHRwOi8vY3JsLmdsb2JhbHNpZ24ubmV0L2VkdWNhdGlvbmFs\nLmNybDBPBggrBgEFBQcBAQRDMEEwPwYIKwYBBQUHMAKGM2h0dHA6Ly9zZWN1cmUu\nZ2xvYmFsc2lnbi5uZXQvY2FjZXJ0L2VkdWNhdGlvbmFsLmNydDAdBgNVHSUEFjAU\nBggrBgEFBQcDAQYIKwYBBQUHAwIwFQYDVR0RBA4wDIIKaWRwLmxudS5zZTANBgkq\nhkiG9w0BAQUFAAOCAQEAkvJr6ePi1/sSyKtaf1xdOGwde1AteooA0Z9CxG6Ddz2v\nfPbpffm08gnhXr8T2zFnjZN6r1ac3kBFSKQRWOfJiLWwjmJ6wbRYCVDjeTN++Tdf\nIZVsj7l5uyGfM2FjKwRd79Qy33KOb4KtcwgkUs6yqScb0Eeew9q+flkJItaEloaL\nnsANXWIYSHmsKeMX/1M+TqMOmUCOExgqTr4yHou54m2SdxcMGJgJp2jcmdF6gbjo\n091ewSnuK+fccVratYgDd4EX3J6uZQnICjIAJ9e44Ab1WhBPQ0Aa+W/52qjbT4yK\n1qXbJLIBEw2yRiL7ayAgirIbuJUR/7+zQVxYX9NyJw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lnu.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.lnu.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.lnu.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.lnu.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.lnu.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.lnu.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.lnu.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.lnu.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.lnu.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lnu.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://lnu.se/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://lnu.se/?l=en"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r anst\u00e4llda och studenter vid Linn\u00e9universitetet."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Linn\u00e6us University Identity Provider is used by employees and students at the university."
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.qa.lnu.se/logo_swamid.png",
                    "height": "55",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "361"
                  },
                  {
                    "text": "https://idp.qa.lnu.se/logo_swamid.png",
                    "lang": "sv",
                    "height": "55",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "361"
                  },
                  {
                    "text": "https://idp.qa.lnu.se/logo_swamid.png",
                    "lang": "en",
                    "height": "55",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "361"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Linn\u00e9universitetet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Linn\u00e6us University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "lnu.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:56.6661,16.3484"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:56.8546,14.8304"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "194.47.64.0/18"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "194.47.160.0/19"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "194.47.192.0/20"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEmzCCA4OgAwIBAgILAQAAAAABJCUIvfswDQYJKoZIhvcNAQEFBQAwXzELMAkG\nA1UEBhMCQkUxEzARBgNVBAoTCkN5YmVydHJ1c3QxFzAVBgNVBAsTDkVkdWNhdGlv\nbmFsIENBMSIwIAYDVQQDExlDeWJlcnRydXN0IEVkdWNhdGlvbmFsIENBMB4XDTA5\nMTAwNTEzMzEwNVoXDTEyMTAwNTEzMzEwNVowTDELMAkGA1UEBhMCU0UxGzAZBgNV\nBAoTEkhvZ3Nrb2xhbiBpIEthbG1hcjELMAkGA1UECxMCSVQxEzARBgNVBAMTCmlk\ncC5sbnUuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDRORVY50+Y\n2rmvFJS4HSE3EZKXb0UpVj2CfW9D4Vlww78CiqV0KV8HW53XHYlOUK7S+I94adaG\nXoXq19HjqjRi8979qfqzKwICRlkVFBnWkY7N5vo//pStClwdTNv+OihlDY+IA9HN\nQXrWjWTzHCbRguYBEmR0gp7l4tlqILkOCCx1yT5uia4EiJvrSFoIV/iYTQBLaGkc\nZdO109GqUx5UJB5XxgUoT0k0rOgg1OHsOvkNGOV4/HzkwWUGIaJy462LlLBcmlXg\nIHfDCMH6lg9pBLig4nDlM2W0KzvMID7zagxFJG+K3eMjdkoK1mK12TTz24bifDpf\nXPnbSRKpkLYpAgMBAAGjggFpMIIBZTBQBgNVHSAESTBHMEUGByqGSLE+AQAwOjA4\nBggrBgEFBQcCARYsaHR0cDovL3d3dy5nbG9iYWxzaWduLm5ldC9yZXBvc2l0b3J5\nL2Nwcy5jZm0wDgYDVR0PAQH/BAQDAgWgMB8GA1UdIwQYMBaAFGVloz3XOxGjCgcl\nN8lCSlt2d1DhMB0GA1UdDgQWBBQCNc1rrFMLNldAEde83Hr98intIzA6BgNVHR8E\nMzAxMC+gLaArhilodHRwOi8vY3JsLmdsb2JhbHNpZ24ubmV0L2VkdWNhdGlvbmFs\nLmNybDBPBggrBgEFBQcBAQRDMEEwPwYIKwYBBQUHMAKGM2h0dHA6Ly9zZWN1cmUu\nZ2xvYmFsc2lnbi5uZXQvY2FjZXJ0L2VkdWNhdGlvbmFsLmNydDAdBgNVHSUEFjAU\nBggrBgEFBQcDAQYIKwYBBQUHAwIwFQYDVR0RBA4wDIIKaWRwLmxudS5zZTANBgkq\nhkiG9w0BAQUFAAOCAQEAkvJr6ePi1/sSyKtaf1xdOGwde1AteooA0Z9CxG6Ddz2v\nfPbpffm08gnhXr8T2zFnjZN6r1ac3kBFSKQRWOfJiLWwjmJ6wbRYCVDjeTN++Tdf\nIZVsj7l5uyGfM2FjKwRd79Qy33KOb4KtcwgkUs6yqScb0Eeew9q+flkJItaEloaL\nnsANXWIYSHmsKeMX/1M+TqMOmUCOExgqTr4yHou54m2SdxcMGJgJp2jcmdF6gbjo\n091ewSnuK+fccVratYgDd4EX3J6uZQnICjIAJ9e44Ab1WhBPQ0Aa+W/52qjbT4yK\n1qXbJLIBEw2yRiL7ayAgirIbuJUR/7+zQVxYX9NyJw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Linn\u00e9universitetet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Linn\u00e6us University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lnu.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LNU"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.barnetsouthgate.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Waters"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:garry.waters@barnetsouthgate.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Garry"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jones"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Richard.Jones@barnetsouthgate.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.barnetsouthgate.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-01-15T09:44:10Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVALtgf/tnX8POhw6lNPBrB0KlwpZ6MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCQxIjAgBgNVBAMTGWlkcC5iYXJuZXRzb3V0aGdhdGUuYWMudWswHhcNMTMw\n\t\t\t\t\t\tMTE0MTI0MzQ4WhcNMzMwMTE0MTI0MzQ4WjAkMSIwIAYDVQQDExlpZHAuYmFybmV0\n\t\t\t\t\t\tc291dGhnYXRlLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tr+e9wCL7JCdkcPekUVtvWeyGBt9ZmEbhfpqp6iGU8k4V648rLJ+WgcdmG8ySslRW\n\t\t\t\t\t\tnwC9arYzJe0CKxr2a2Ym2/Zr+FQfC8/N4fC8gGyofCWKMraP96+DuP9s2f8cpuG9\n\t\t\t\t\t\txZ739oFkWYINupeHRamXQQunTXUahLpG1gho7qZwMsscPT0LKTevGOYisnyZ3U5+\n\t\t\t\t\t\tyQNCPqftvM9LXyr+NOoPEOFm+VBHBSmoe2S8WkG9ZzchC87LXmrpibMAPk8UOsQT\n\t\t\t\t\t\t3ccwonJznnKmwXxV8WK1BGrhXGtQzKnCsoPtz22gvA56svSIiGsrCeUp/K1cq1mu\n\t\t\t\t\t\txKGZWCfPV0Wd1LsCyrgAsQIDAQABo3kwdzBWBgNVHREETzBNghlpZHAuYmFybmV0\n\t\t\t\t\t\tc291dGhnYXRlLmFjLnVrhjBodHRwczovL2lkcC5iYXJuZXRzb3V0aGdhdGUuYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFI5dJH5PCJgmNc6UAyQicW7aF6Tr\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQBez0X0P76l74nbqKmG5TDpPnkC+J3T1Gagpp6X\n\t\t\t\t\t\tgg1GC85s41bASa2ZnRnJfILR4aWxU0OsZalJUULbloG82iamTiT5ziS5a+zB7wel\n\t\t\t\t\t\t8BXuVVvIaT2KUZqpVm/katlQwWRbrq1HwcoyxKV8i/Yph4SyK0fn/ZX/3Btvp2+j\n\t\t\t\t\t\t45yt334InrF0dzqxTGy3dIEfig3KuEvgJYZlX5sA2v7Ru08VfjD/8ufLRxxaFwoD\n\t\t\t\t\t\tiRZLwturU+9n8xCFM9j8todbW0nwgCvPdBLfyqIxXN/CljNpF9kZKCKIMV4HJAzi\n\t\t\t\t\t\tY+/goLkSyma0k8zstnZ+JNmISHaATJXpLgfl0CsNZay6C3od"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "barnetsouthgate.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.barnetsouthgate.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.barnetsouthgate.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.barnetsouthgate.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.barnetsouthgate.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.barnetsouthgate.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.barnetsouthgate.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.barnetsouthgate.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.barnetsouthgate.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "barnetsouthgate.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVALtgf/tnX8POhw6lNPBrB0KlwpZ6MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCQxIjAgBgNVBAMTGWlkcC5iYXJuZXRzb3V0aGdhdGUuYWMudWswHhcNMTMw\n\t\t\t\t\t\tMTE0MTI0MzQ4WhcNMzMwMTE0MTI0MzQ4WjAkMSIwIAYDVQQDExlpZHAuYmFybmV0\n\t\t\t\t\t\tc291dGhnYXRlLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tr+e9wCL7JCdkcPekUVtvWeyGBt9ZmEbhfpqp6iGU8k4V648rLJ+WgcdmG8ySslRW\n\t\t\t\t\t\tnwC9arYzJe0CKxr2a2Ym2/Zr+FQfC8/N4fC8gGyofCWKMraP96+DuP9s2f8cpuG9\n\t\t\t\t\t\txZ739oFkWYINupeHRamXQQunTXUahLpG1gho7qZwMsscPT0LKTevGOYisnyZ3U5+\n\t\t\t\t\t\tyQNCPqftvM9LXyr+NOoPEOFm+VBHBSmoe2S8WkG9ZzchC87LXmrpibMAPk8UOsQT\n\t\t\t\t\t\t3ccwonJznnKmwXxV8WK1BGrhXGtQzKnCsoPtz22gvA56svSIiGsrCeUp/K1cq1mu\n\t\t\t\t\t\txKGZWCfPV0Wd1LsCyrgAsQIDAQABo3kwdzBWBgNVHREETzBNghlpZHAuYmFybmV0\n\t\t\t\t\t\tc291dGhnYXRlLmFjLnVrhjBodHRwczovL2lkcC5iYXJuZXRzb3V0aGdhdGUuYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFI5dJH5PCJgmNc6UAyQicW7aF6Tr\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQBez0X0P76l74nbqKmG5TDpPnkC+J3T1Gagpp6X\n\t\t\t\t\t\tgg1GC85s41bASa2ZnRnJfILR4aWxU0OsZalJUULbloG82iamTiT5ziS5a+zB7wel\n\t\t\t\t\t\t8BXuVVvIaT2KUZqpVm/katlQwWRbrq1HwcoyxKV8i/Yph4SyK0fn/ZX/3Btvp2+j\n\t\t\t\t\t\t45yt334InrF0dzqxTGy3dIEfig3KuEvgJYZlX5sA2v7Ru08VfjD/8ufLRxxaFwoD\n\t\t\t\t\t\tiRZLwturU+9n8xCFM9j8todbW0nwgCvPdBLfyqIxXN/CljNpF9kZKCKIMV4HJAzi\n\t\t\t\t\t\tY+/goLkSyma0k8zstnZ+JNmISHaATJXpLgfl0CsNZay6C3od"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Barnet and Southgate College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.barnetsouthgate.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Barnet and Southgate College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibbserver.preston.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Greenwood"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:JGreenwood@preston.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Greenwood"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:JGreenwood@preston.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibbserver.preston.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYDCCAkgCCQDkmtqgfo843jANBgkqhkiG9w0BAQUFADByMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjETMBEGA1UECBMKTGFuY2FzaGlyZTEQMA4GA1UEBxMHUHJlc3RvbjEYMBYGA1UE\n\t\t\t\t\t\tChMPUHJlc3RvbiBDb2xsZWdlMSIwIAYDVQQDExlzaGliYnNlcnZlci5wcmVzdG9u\n\t\t\t\t\t\tLmFjLnVrMB4XDTEzMDYyMTExNTYxNVoXDTMzMDYxNjExNTYxNVowcjELMAkGA1UE\n\t\t\t\t\t\tBhMCR0IxEzARBgNVBAgTCkxhbmNhc2hpcmUxEDAOBgNVBAcTB1ByZXN0b24xGDAW\n\t\t\t\t\t\tBgNVBAoTD1ByZXN0b24gQ29sbGVnZTEiMCAGA1UEAxMZc2hpYmJzZXJ2ZXIucHJl\n\t\t\t\t\t\tc3Rvbi5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKirj7Jb\n\t\t\t\t\t\tE0a0tk0wGm4kACMfzDGVLCpovdU4TKE0a40zGy77oJugnCwdYPkeGFRTXL6mp64A\n\t\t\t\t\t\t6jSJKG2PwAKsqgZ8kBlYSmsPAEqWpKGukqEVmNubJuZjlSGQW6/03/ILRP1v2FBR\n\t\t\t\t\t\tYPa5QVL+iZDQnOabgD0xHA+5TOeyF+ncACMR6CVbf67b04nTUfMSMdPfALJmKB9t\n\t\t\t\t\t\tLaKqb5IkNVc0UyN66BnH+KZfXyex5c8qtPTc9d6dRkpPT2OawbvhZv94U9kYzzwI\n\t\t\t\t\t\t0UeARnr6h4dcmUjmP2KsXXpdEzyNb6H5cBYavz9+Ah2c2fQowMRe1BAaxFsYqpq7\n\t\t\t\t\t\tc9CUEf0f37JXRnsCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAjcuAywnWMGSntE85\n\t\t\t\t\t\t+1TM+UZ9C30HujCptlqpPq9TatZLNn5Epbn9c9OFeap5yfz1T0cMF+Uj6l/+Hgbg\n\t\t\t\t\t\tjpWIrGeD+Q3IaZ2Ogk1UbezOsHvz6TLdLnZ+TdxlVaRs500HboPa4vRb5f8tYy3p\n\t\t\t\t\t\tHwUtkElhKcKebgtaSh48WyztxtXq3rS6FiDGrri8JKXCudW9OIsbRdOjqliPKAxf\n\t\t\t\t\t\tRNVnEXmfbv4cN/YlvFrKtrMPOPc8PDI8GPtHap8DHTyVLrw+0PGX8P4tJ+m8GUMC\n\t\t\t\t\t\tLwVxuog72RAqDyvj84SV+ihyvitlwBEs3Q9/qecTCl9zvdYuhUrdqQ/CiWut7Vhu\n\t\t\t\t\t\tjPVaDg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "preston.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibbserver.preston.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibbserver.preston.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibbserver.preston.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibbserver.preston.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibbserver.preston.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibbserver.preston.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibbserver.preston.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibbserver.preston.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "preston.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYDCCAkgCCQDkmtqgfo843jANBgkqhkiG9w0BAQUFADByMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjETMBEGA1UECBMKTGFuY2FzaGlyZTEQMA4GA1UEBxMHUHJlc3RvbjEYMBYGA1UE\n\t\t\t\t\t\tChMPUHJlc3RvbiBDb2xsZWdlMSIwIAYDVQQDExlzaGliYnNlcnZlci5wcmVzdG9u\n\t\t\t\t\t\tLmFjLnVrMB4XDTEzMDYyMTExNTYxNVoXDTMzMDYxNjExNTYxNVowcjELMAkGA1UE\n\t\t\t\t\t\tBhMCR0IxEzARBgNVBAgTCkxhbmNhc2hpcmUxEDAOBgNVBAcTB1ByZXN0b24xGDAW\n\t\t\t\t\t\tBgNVBAoTD1ByZXN0b24gQ29sbGVnZTEiMCAGA1UEAxMZc2hpYmJzZXJ2ZXIucHJl\n\t\t\t\t\t\tc3Rvbi5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKirj7Jb\n\t\t\t\t\t\tE0a0tk0wGm4kACMfzDGVLCpovdU4TKE0a40zGy77oJugnCwdYPkeGFRTXL6mp64A\n\t\t\t\t\t\t6jSJKG2PwAKsqgZ8kBlYSmsPAEqWpKGukqEVmNubJuZjlSGQW6/03/ILRP1v2FBR\n\t\t\t\t\t\tYPa5QVL+iZDQnOabgD0xHA+5TOeyF+ncACMR6CVbf67b04nTUfMSMdPfALJmKB9t\n\t\t\t\t\t\tLaKqb5IkNVc0UyN66BnH+KZfXyex5c8qtPTc9d6dRkpPT2OawbvhZv94U9kYzzwI\n\t\t\t\t\t\t0UeARnr6h4dcmUjmP2KsXXpdEzyNb6H5cBYavz9+Ah2c2fQowMRe1BAaxFsYqpq7\n\t\t\t\t\t\tc9CUEf0f37JXRnsCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAjcuAywnWMGSntE85\n\t\t\t\t\t\t+1TM+UZ9C30HujCptlqpPq9TatZLNn5Epbn9c9OFeap5yfz1T0cMF+Uj6l/+Hgbg\n\t\t\t\t\t\tjpWIrGeD+Q3IaZ2Ogk1UbezOsHvz6TLdLnZ+TdxlVaRs500HboPa4vRb5f8tYy3p\n\t\t\t\t\t\tHwUtkElhKcKebgtaSh48WyztxtXq3rS6FiDGrri8JKXCudW9OIsbRdOjqliPKAxf\n\t\t\t\t\t\tRNVnEXmfbv4cN/YlvFrKtrMPOPc8PDI8GPtHap8DHTyVLrw+0PGX8P4tJ+m8GUMC\n\t\t\t\t\t\tLwVxuog72RAqDyvj84SV+ihyvitlwBEs3Q9/qecTCl9zvdYuhUrdqQ/CiWut7Vhu\n\t\t\t\t\t\tjPVaDg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Preston College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.preston.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Preston College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://shibboleth.ebscohost.com",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "http://shibboleth.ebscohost.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.ebscohost.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.ebscohost.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth.ebscohost.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "New cert SWAMIDOPS-8093"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shibboleth.ebscohost.com"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFjzCCBHegAwIBAgIJALgyIfD0A59WMA0GCSqGSIb3DQEBCwUAMIG0MQswCQYD\nVQQGEwJVUzEQMA4GA1UECBMHQXJpem9uYTETMBEGA1UEBxMKU2NvdHRzZGFsZTEa\nMBgGA1UEChMRR29EYWRkeS5jb20sIEluYy4xLTArBgNVBAsTJGh0dHA6Ly9jZXJ0\ncy5nb2RhZGR5LmNvbS9yZXBvc2l0b3J5LzEzMDEGA1UEAxMqR28gRGFkZHkgU2Vj\ndXJlIENlcnRpZmljYXRlIEF1dGhvcml0eSAtIEcyMB4XDTE2MDMxMDE1MjczOFoX\nDTE5MDMxMDE1MjczOFowdzELMAkGA1UEBhMCVVMxEDAOBgNVBAgTB0FsYWJhbWEx\nEzARBgNVBAcTCkJpcm1pbmdoYW0xHjAcBgNVBAoTFUVCU0NPIEluZHVzdHJpZXMg\nSW5jLjEhMB8GA1UEAxMYc2hpYmJvbGV0aC5lYnNjb2hvc3QuY29tMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2gPcVVfIToXQoIDCHnpMExhkoTWQfctB\nTZ6cLbk6/bWJLybaml5l17TXsVrOL4mE/eqog6ws5q86GQD0md/cosu7I/Jk1fSV\nZDyolgAELvsybjp+Tqv5KHqvNyOdVLVJHOcDB09KbBtWMhfRXjzHe8vSOiBe4/dI\njpwPnUyPv1nl2v/yx57BUeiLU8CL+LTcQGoVpkoaSyfDYmmkOyJI43jifdGXHxml\nCMfEVVFyHasnS7iRn2xDD5XSb2ZbdKZncoOXVQzsbmVFS4zlX7RYzmwr+K38sXJ4\nJfxQQmrXFiBU7fAJEoqsmNlxtD7X7bFmmVjOYMBQ44lK9GZG6kcBhQIDAQABo4IB\n3jCCAdowDAYDVR0TAQH/BAIwADApBgNVHSUEIjAgBggrBgEFBQcDAQYIKwYBBQUH\nAwIGCmCGSAGG+E0BAgMwDgYDVR0PAQH/BAQDAgWgMDUGA1UdHwQuMCwwKqAooCaG\nJGh0dHA6Ly9jcmwuZ29kYWRkeS5jb20vZ2RpZzJzMi0yLmNybDBdBgNVHSAEVjBU\nMEgGC2CGSAGG/W0BBxcCMDkwNwYIKwYBBQUHAgEWK2h0dHA6Ly9jZXJ0aWZpY2F0\nZXMuZ29kYWRkeS5jb20vcmVwb3NpdG9yeS8wCAYGZ4EMAQICMHYGCCsGAQUFBwEB\nBGowaDAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AuZ29kYWRkeS5jb20vMEAGCCsG\nAQUFBzAChjRodHRwOi8vY2VydGlmaWNhdGVzLmdvZGFkZHkuY29tL3JlcG9zaXRv\ncnkvZ2RpZzIuY3J0MB8GA1UdIwQYMBaAFEDCvSeOzDSDMKIz1/tss/C0LIDOMEEG\nA1UdEQQ6MDiCGHNoaWJib2xldGguZWJzY29ob3N0LmNvbYIcd3d3LnNoaWJib2xl\ndGguZWJzY29ob3N0LmNvbTAdBgNVHQ4EFgQUX5a2VOhuB9OZJV9M6FG7Zy+YYYIw\nDQYJKoZIhvcNAQELBQADggEBAApcPOeAAcYKBDL3L6ysJoukwn0vu812N9aPoKQg\nlWwenSV9IgyonbNsGmRQkeE1OEkL8NLZbR8qWHH3nmoUnn/3wHAyBl9jQDk5N0ki\nPGJup923dPOzp9uIHANwPLozwjXxMhelGgARJ6fmrmfKkBqmMpKgC7JLvCNLlDoO\nvm2DNlICTcXGmAigFmZKsi37uVSkFGNiZLlfT9KlucKnmYLxhRczovMumui1tt5R\nFhWhQnewAV8knm60yrMTxcG0VGqbsxiLqacCKuNJvSZIGuCwGwCqWTVPza+7k7Xa\nGXN6t76L1hd4Ant9KFynMa+RET9Mf26Fffpuhk09MVUJqcc="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "C=US, ST=Alabama, L=Birmingham, O=EBSCO Industries Inc., CN=shibboleth.ebscohost.com"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "incommoncredsnew"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shibboleth.ebscohost.com"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID+jCCAuICCQCN6ul8OXeRnjANBgkqhkiG9w0BAQUFADCBvjELMAkGA1UEBhMC\nVVMxFjAUBgNVBAgMDU1hc3NhY2h1c2V0dHMxEDAOBgNVBAcMB0lwc3dpY2gxHzAd\nBgNVBAoMFkVCU0NPIEluZHVzdHJpZXMsIEluYy4xGTAXBgNVBAsMEEVCU0NPIFB1\nYmxpc2hpbmcxITAfBgNVBAMMGHNoaWJib2xldGguZWJzY29ob3N0LmNvbTEmMCQG\nCSqGSIb3DQEJARYXc2hpYi10ZWNoQGVic2NvaG9zdC5jb20wHhcNMTIxMDI0MjAw\nNzAwWhcNMjIxMDIyMjAwNzAwWjCBvjELMAkGA1UEBhMCVVMxFjAUBgNVBAgMDU1h\nc3NhY2h1c2V0dHMxEDAOBgNVBAcMB0lwc3dpY2gxHzAdBgNVBAoMFkVCU0NPIElu\nZHVzdHJpZXMsIEluYy4xGTAXBgNVBAsMEEVCU0NPIFB1Ymxpc2hpbmcxITAfBgNV\nBAMMGHNoaWJib2xldGguZWJzY29ob3N0LmNvbTEmMCQGCSqGSIb3DQEJARYXc2hp\nYi10ZWNoQGVic2NvaG9zdC5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQCjIYRPb85WJX50IR6Qg8Li39JUTBRNLQ2hR2BjZMUOwmp1HK9sbNP6nxV5\nhgjF2IIQpe64C+7fQmIBfaktl7rmbc81q/NcWU2wKAE8gazOqe+trT1dO/5VauTG\nrIP1keX1j717RAPDWZSJAu79+ntuh+cZc+XevNvQ4HjCpzUW6tt6+Vap7MoG74sv\nFrkwsfnuWZ6QcUEDen8ZY/cixSYZWyYLFo5x6s0ygsClZrQOQh5HPDeCTUBQ2q88\nmHvHBbt8a59/AxiAek3IjFtc4syKGNXcfCuaxn+2K/zrsnuimm0htbAkXKC+14cM\nVCxFjeqM+LpnKWPUmt1yNYTWf3cVAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAJS9\n+Icdhh+ETDVuEqVMmODssPnrNoSOJaIe3PBj37QEc32J5egWU47FoKbzhtIK1bwV\nAcnhBjPbBp3ZCe/KrhKpay0QDt+w457tzkqSXW3b9n9BslaOtSt2bMlLjWkjsnrl\nbxqARgHozFZjPiHXtLataNcXgFqhtNTmQgGXCsCTO7L/WxbhWkecLcGPM7WPOBnI\nYgIe4osalc7B9BM2Gy1E8TZNEzqG+7F/d7hMLAtfFKAfhG8ml9kLq02gdRvkLFw/\n1vFACe0zh8uQTJhT4llYgRRxkHJYllpGKakbYh8sBy67iOxpnEbR05mp/cH5Ekdz\nk5jIkSdNqd6yle/CCEc="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=shib-tech@ebscohost.com,CN=shibboleth.ebscohost.com,OU=EBSCO Publishing,O=EBSCO Industries\\, Inc.,L=Ipswich,ST=Massachusetts,C=US"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.ebscohost.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.ebscohost.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth.ebscohost.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.ebscohost.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.ebscohost.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.pitt.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "crk4@pitt.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Christopher Keslar"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@pitt.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technology Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@pitt.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technology Help Desk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.pitt.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.pitt.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.pitt.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKTCCAhGgAwIBAgIJAK/m2puIvEaPMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDGlkcC5waXR0LmVkdTAeFw0xMDAyMjQyMTE1NDRaFw0xMzAyMjMyMTE1NDRa\nMBcxFTATBgNVBAMTDGlkcC5waXR0LmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAPf6lCv9nQN+Fn7ebs+68OhI804i1tn4STw9D9guwsE7Me1bGd4F\nFcIIniLFpt2rj8mmgtZ2klLNiAQlnx/GXpn/76BjSj4YvMEzW/dMmaBIP76bAnQ7\ncKmbFk8leBYGaunz6tqZWmaUFxEGr5ahleS4YWe+dVX86P3+/waPhiXklNeLLM2W\nZNa1dEDbvMbSuXFKuFWtiaayIiACIhi02pzIVBc/VO7z/uZKkN4g87wGVrlvwSmU\neI2jchW+CggBVQttF1TNBd+HTHb3J+MONZBGrWA4ZGXhlzFXeP9/PqmrpxRR2soW\nqryVCPr5EsIgJzQVSUXdgDXlrtpR4LZbdpcCAwEAAaN4MHYwHQYDVR0OBBYEFLKs\n08YJmnk/5jSuFpS3fjD6EZMqMEcGA1UdIwRAMD6AFLKs08YJmnk/5jSuFpS3fjD6\nEZMqoRukGTAXMRUwEwYDVQQDEwxpZHAucGl0dC5lZHWCCQCv5tqbiLxGjzAMBgNV\nHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBR8/mBNuAza6eX2kPXul2zVRzr\nksZQsPuShBYEp+FN84/gvg55sY2ZOLkGVH55toyyMcouhepsCtqZg/qHsxAv2qaG\npUNRzRlUBhr5WjMQSmGC1SxeFO8EIZCv/prDi8jvARJwC85Q4mixs/mR8Ys0GWFk\nYhVUcKSUzBNlGJdSYl4CDXWt+e6EVvnyWvAmk4psrqlXeGzBxhSjHrJGQqEDuBjZ\nRf8ZaY9CbLGbOm/g++Szj1E+1s1cyiBQ5D316JimJ3U5Io2NHV+nSUdYOC8256+j\ndalrcnm0K9z3483QueZhUmPtapzeJz617znahr+cgz1fLZJTtP34AmIUOiVu"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEdDCCA1ygAwIBAgIJAIPyxwkgHIJiMA0GCSqGSIb3DQEBBQUAMIGCMQswCQYD\nVQQGEwJVUzEVMBMGA1UECBMMUGVubnN5bHZhbmlhMRMwEQYDVQQHEwpQaXR0c2J1\ncmdoMSEwHwYDVQQKExhVbml2ZXJzaXR5IE9mIFBpdHRzYnVyZ2gxDTALBgNVBAsT\nBENTU0QxFTATBgNVBAMTDGlkcC5waXR0LmVkdTAeFw0xMzAyMTMyMDA0MTVaFw0z\nMzAyMTMyMDA0MTVaMIGCMQswCQYDVQQGEwJVUzEVMBMGA1UECBMMUGVubnN5bHZh\nbmlhMRMwEQYDVQQHEwpQaXR0c2J1cmdoMSEwHwYDVQQKExhVbml2ZXJzaXR5IE9m\nIFBpdHRzYnVyZ2gxDTALBgNVBAsTBENTU0QxFTATBgNVBAMTDGlkcC5waXR0LmVk\ndTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK9j5BRYQlGalJvTJ8AI\nTJ0jphLF4kRQNhZpTSLp54z0XBn78DLAVHSbxwQ7X0CkFoDipglzFPi7svxO+zd0\nNEGMBml/xoxgRafVeebAPcFCzjIudfNXKp/nv8eeCygjH7syjf/Z4SnZWSKRKlpa\ndZMfgw72ATcVBh7ml6iA7/T7Bms7xAFByPxVyHTK2CUFyx0zCS96jvFLIG3+0lo9\nlUe6tQ5M1QFpSYkCibaIupno6peKceJQxBu1payaGKLWTgAo1vylMF+m0qXBQ6W+\nCX3CsQQnmOrEjQPSJdenFD3O8BoZMrAGT1j/5dZQcXnHjcW1GYa7Imt7P9DNsp1o\nU4sCAwEAAaOB6jCB5zAdBgNVHQ4EFgQU/IWtjcdU4BFSyI92E3kgfh4PdUQwgbcG\nA1UdIwSBrzCBrIAU/IWtjcdU4BFSyI92E3kgfh4PdUShgYikgYUwgYIxCzAJBgNV\nBAYTAlVTMRUwEwYDVQQIEwxQZW5uc3lsdmFuaWExEzARBgNVBAcTClBpdHRzYnVy\nZ2gxITAfBgNVBAoTGFVuaXZlcnNpdHkgT2YgUGl0dHNidXJnaDENMAsGA1UECxME\nQ1NTRDEVMBMGA1UEAxMMaWRwLnBpdHQuZWR1ggkAg/LHCSAcgmIwDAYDVR0TBAUw\nAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAMRihZtUIhu4nStkrlEH2ZHeh32jdgvp7\nf8BPJXsmjwQRLfmiSHY0qX2WdJm3+P79EmA17HLla9S6277RteguH8wzfBgglRVq\njlVyiKeS6z5doIoKJZwSne0x01kIeeOE9ytr09aQTWbkfXCBwnTjjmwHWhTUpPJv\nkxZC6m7oRw+a9ApJBWV6DB/QKAslvD45aifKijte3plakx2gzbukNhkahUxf+erg\nWSvG0BUC/zdv9BpJuwgRCUq6l58xfgHSXlrbc3gYc74pa/xMHIu82xhZFzmsMnIV\nIBWDyMtrjsnhtDNz0G0ydy2irh47nkM5oANXm5wVre55cfB6zPhK5Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pitt.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.pitt.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.pitt.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.pitt.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.pitt.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.pitt.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pitt.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://www.pitt.edu/seal/seal-400x400-72rgb.png",
                    "lang": "en",
                    "height": "400",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "400"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://technology.pitt.edu/research-computing/rc-incommon-shibboleth/privacy.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Pittsburgh"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKTCCAhGgAwIBAgIJAK/m2puIvEaPMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDGlkcC5waXR0LmVkdTAeFw0xMDAyMjQyMTE1NDRaFw0xMzAyMjMyMTE1NDRa\nMBcxFTATBgNVBAMTDGlkcC5waXR0LmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAPf6lCv9nQN+Fn7ebs+68OhI804i1tn4STw9D9guwsE7Me1bGd4F\nFcIIniLFpt2rj8mmgtZ2klLNiAQlnx/GXpn/76BjSj4YvMEzW/dMmaBIP76bAnQ7\ncKmbFk8leBYGaunz6tqZWmaUFxEGr5ahleS4YWe+dVX86P3+/waPhiXklNeLLM2W\nZNa1dEDbvMbSuXFKuFWtiaayIiACIhi02pzIVBc/VO7z/uZKkN4g87wGVrlvwSmU\neI2jchW+CggBVQttF1TNBd+HTHb3J+MONZBGrWA4ZGXhlzFXeP9/PqmrpxRR2soW\nqryVCPr5EsIgJzQVSUXdgDXlrtpR4LZbdpcCAwEAAaN4MHYwHQYDVR0OBBYEFLKs\n08YJmnk/5jSuFpS3fjD6EZMqMEcGA1UdIwRAMD6AFLKs08YJmnk/5jSuFpS3fjD6\nEZMqoRukGTAXMRUwEwYDVQQDEwxpZHAucGl0dC5lZHWCCQCv5tqbiLxGjzAMBgNV\nHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBR8/mBNuAza6eX2kPXul2zVRzr\nksZQsPuShBYEp+FN84/gvg55sY2ZOLkGVH55toyyMcouhepsCtqZg/qHsxAv2qaG\npUNRzRlUBhr5WjMQSmGC1SxeFO8EIZCv/prDi8jvARJwC85Q4mixs/mR8Ys0GWFk\nYhVUcKSUzBNlGJdSYl4CDXWt+e6EVvnyWvAmk4psrqlXeGzBxhSjHrJGQqEDuBjZ\nRf8ZaY9CbLGbOm/g++Szj1E+1s1cyiBQ5D316JimJ3U5Io2NHV+nSUdYOC8256+j\ndalrcnm0K9z3483QueZhUmPtapzeJz617znahr+cgz1fLZJTtP34AmIUOiVu"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEdDCCA1ygAwIBAgIJAIPyxwkgHIJiMA0GCSqGSIb3DQEBBQUAMIGCMQswCQYD\nVQQGEwJVUzEVMBMGA1UECBMMUGVubnN5bHZhbmlhMRMwEQYDVQQHEwpQaXR0c2J1\ncmdoMSEwHwYDVQQKExhVbml2ZXJzaXR5IE9mIFBpdHRzYnVyZ2gxDTALBgNVBAsT\nBENTU0QxFTATBgNVBAMTDGlkcC5waXR0LmVkdTAeFw0xMzAyMTMyMDA0MTVaFw0z\nMzAyMTMyMDA0MTVaMIGCMQswCQYDVQQGEwJVUzEVMBMGA1UECBMMUGVubnN5bHZh\nbmlhMRMwEQYDVQQHEwpQaXR0c2J1cmdoMSEwHwYDVQQKExhVbml2ZXJzaXR5IE9m\nIFBpdHRzYnVyZ2gxDTALBgNVBAsTBENTU0QxFTATBgNVBAMTDGlkcC5waXR0LmVk\ndTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK9j5BRYQlGalJvTJ8AI\nTJ0jphLF4kRQNhZpTSLp54z0XBn78DLAVHSbxwQ7X0CkFoDipglzFPi7svxO+zd0\nNEGMBml/xoxgRafVeebAPcFCzjIudfNXKp/nv8eeCygjH7syjf/Z4SnZWSKRKlpa\ndZMfgw72ATcVBh7ml6iA7/T7Bms7xAFByPxVyHTK2CUFyx0zCS96jvFLIG3+0lo9\nlUe6tQ5M1QFpSYkCibaIupno6peKceJQxBu1payaGKLWTgAo1vylMF+m0qXBQ6W+\nCX3CsQQnmOrEjQPSJdenFD3O8BoZMrAGT1j/5dZQcXnHjcW1GYa7Imt7P9DNsp1o\nU4sCAwEAAaOB6jCB5zAdBgNVHQ4EFgQU/IWtjcdU4BFSyI92E3kgfh4PdUQwgbcG\nA1UdIwSBrzCBrIAU/IWtjcdU4BFSyI92E3kgfh4PdUShgYikgYUwgYIxCzAJBgNV\nBAYTAlVTMRUwEwYDVQQIEwxQZW5uc3lsdmFuaWExEzARBgNVBAcTClBpdHRzYnVy\nZ2gxITAfBgNVBAoTGFVuaXZlcnNpdHkgT2YgUGl0dHNidXJnaDENMAsGA1UECxME\nQ1NTRDEVMBMGA1UEAxMMaWRwLnBpdHQuZWR1ggkAg/LHCSAcgmIwDAYDVR0TBAUw\nAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAMRihZtUIhu4nStkrlEH2ZHeh32jdgvp7\nf8BPJXsmjwQRLfmiSHY0qX2WdJm3+P79EmA17HLla9S6277RteguH8wzfBgglRVq\njlVyiKeS6z5doIoKJZwSne0x01kIeeOE9ytr09aQTWbkfXCBwnTjjmwHWhTUpPJv\nkxZC6m7oRw+a9ApJBWV6DB/QKAslvD45aifKijte3plakx2gzbukNhkahUxf+erg\nWSvG0BUC/zdv9BpJuwgRCUq6l58xfgHSXlrbc3gYc74pa/xMHIu82xhZFzmsMnIV\nIBWDyMtrjsnhtDNz0G0ydy2irh47nkM5oANXm5wVre55cfB6zPhK5Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idp.pitt.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Pittsburgh"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.pitt.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Pittsburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ukfed.one-test2.contrail.rl.ac.uk/portal/sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ketley"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cheney.ketley@stfc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Cheney"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ketley"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cheney.ketley@stfc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Cheney"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ukfed.one-test2.contrail.rl.ac.uk/portal/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-04-28T13:24:07Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Contrail project, STFC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://stfc.ac.uk/scd/default.aspx"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Science and Technology Facilities Council"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federation.one-test2.contrail.rl.ac.uk/simplesaml/module.php/saml/sp/saml2-logout.php/uk-federation",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID5DCCAsygAwIBAgIJALS9Y48v9modMA0GCSqGSIb3DQEBBQUAMHMxCzAJBgNV\n\t\t\t\t\t\tBAYTAlVLMQ0wCwYDVQQIDARPeG9uMRAwDgYDVQQHDAdDaGlsdG9uMQ0wCwYDVQQK\n\t\t\t\t\t\tDARTVEZDMQwwCgYDVQQLDANTQ0QxJjAkBgNVBAMMHSoub25lLXRlc3QyLmNvbnRy\n\t\t\t\t\t\tYWlsLnJsLmFjLnVrMB4XDTE0MDMyMTExMDMxN1oXDTI0MDMyMTExMDMxN1owczEL\n\t\t\t\t\t\tMAkGA1UEBhMCVUsxDTALBgNVBAgMBE94b24xEDAOBgNVBAcMB0NoaWx0b24xDTAL\n\t\t\t\t\t\tBgNVBAoMBFNURkMxDDAKBgNVBAsMA1NDRDEmMCQGA1UEAwwdKi5vbmUtdGVzdDIu\n\t\t\t\t\t\tY29udHJhaWwucmwuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDExxwHlrNj6qpRM+sfph0089TyUUke0ygR4088OhXfUIUnYo4TfFLm9xGuzG1x\n\t\t\t\t\t\tubfmJWLAhynRSuu6xYAALo3ArMPCcBm3/dVviXjZ9rolhikpLso7a9kGefpAo0Qb\n\t\t\t\t\t\taBSow1ANeRNIlw4ADnjxqAF083qzbUx3BLNHrQJ8S1vhXXxV1uCxzCUoeBcptrr9\n\t\t\t\t\t\tEYH01nue5+URc2c7gH9hGb9vu3AJgMURD7BWE6eC8YoQdK52CaEfnlXPmhgaG9vZ\n\t\t\t\t\t\tm+orn2ytJdl0FMxadEzmW2OtvkkyCZAH8PzB7GrZzOHXV3y30TFpKow4jIof+z0j\n\t\t\t\t\t\tJF+4uzI26YdaKInXMw5G9YnhAgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4\n\t\t\t\t\t\tQgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBRK\n\t\t\t\t\t\tsVJ3ilHlVQpjnfG284PH5J6P4TAfBgNVHSMEGDAWgBRKsVJ3ilHlVQpjnfG284PH\n\t\t\t\t\t\t5J6P4TANBgkqhkiG9w0BAQUFAAOCAQEAmQX0Q/YZW5/sSDHz7c+wvqhfWRzbh49m\n\t\t\t\t\t\tls5MnJ2jYgU87tpG123xg3QKfqCZ9spN1SHs7Q8cbqYE2/HihCBZ2Gw6tNAVkAQM\n\t\t\t\t\t\tRZgpdCJti0Pjy9kZg/k0DL7aww6DyHLycQBSvHF0xa8JMo+fgwbaYlNAK/uLF8nP\n\t\t\t\t\t\t0vMwDcGlsvd0KKM80qbxrTvNLp9jbp1QnV1bEFqWWpViEMHWtlhtKTzKKiL+k0rQ\n\t\t\t\t\t\tzUl6YNvn0L7djY34CHGKVQVtiV0F8PMyrYRpAMmOBUR+DsW14y8isnBcQVBjSwvA\n\t\t\t\t\t\t/kVnQYMEPEQjewc0WBDer1g4xo/Nulo66UwgSE1rJqLUSiU/TZznhA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID5DCCAsygAwIBAgIJALS9Y48v9modMA0GCSqGSIb3DQEBBQUAMHMxCzAJBgNV\n\t\t\t\t\t\tBAYTAlVLMQ0wCwYDVQQIDARPeG9uMRAwDgYDVQQHDAdDaGlsdG9uMQ0wCwYDVQQK\n\t\t\t\t\t\tDARTVEZDMQwwCgYDVQQLDANTQ0QxJjAkBgNVBAMMHSoub25lLXRlc3QyLmNvbnRy\n\t\t\t\t\t\tYWlsLnJsLmFjLnVrMB4XDTE0MDMyMTExMDMxN1oXDTI0MDMyMTExMDMxN1owczEL\n\t\t\t\t\t\tMAkGA1UEBhMCVUsxDTALBgNVBAgMBE94b24xEDAOBgNVBAcMB0NoaWx0b24xDTAL\n\t\t\t\t\t\tBgNVBAoMBFNURkMxDDAKBgNVBAsMA1NDRDEmMCQGA1UEAwwdKi5vbmUtdGVzdDIu\n\t\t\t\t\t\tY29udHJhaWwucmwuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDExxwHlrNj6qpRM+sfph0089TyUUke0ygR4088OhXfUIUnYo4TfFLm9xGuzG1x\n\t\t\t\t\t\tubfmJWLAhynRSuu6xYAALo3ArMPCcBm3/dVviXjZ9rolhikpLso7a9kGefpAo0Qb\n\t\t\t\t\t\taBSow1ANeRNIlw4ADnjxqAF083qzbUx3BLNHrQJ8S1vhXXxV1uCxzCUoeBcptrr9\n\t\t\t\t\t\tEYH01nue5+URc2c7gH9hGb9vu3AJgMURD7BWE6eC8YoQdK52CaEfnlXPmhgaG9vZ\n\t\t\t\t\t\tm+orn2ytJdl0FMxadEzmW2OtvkkyCZAH8PzB7GrZzOHXV3y30TFpKow4jIof+z0j\n\t\t\t\t\t\tJF+4uzI26YdaKInXMw5G9YnhAgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4\n\t\t\t\t\t\tQgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBRK\n\t\t\t\t\t\tsVJ3ilHlVQpjnfG284PH5J6P4TAfBgNVHSMEGDAWgBRKsVJ3ilHlVQpjnfG284PH\n\t\t\t\t\t\t5J6P4TANBgkqhkiG9w0BAQUFAAOCAQEAmQX0Q/YZW5/sSDHz7c+wvqhfWRzbh49m\n\t\t\t\t\t\tls5MnJ2jYgU87tpG123xg3QKfqCZ9spN1SHs7Q8cbqYE2/HihCBZ2Gw6tNAVkAQM\n\t\t\t\t\t\tRZgpdCJti0Pjy9kZg/k0DL7aww6DyHLycQBSvHF0xa8JMo+fgwbaYlNAK/uLF8nP\n\t\t\t\t\t\t0vMwDcGlsvd0KKM80qbxrTvNLp9jbp1QnV1bEFqWWpViEMHWtlhtKTzKKiL+k0rQ\n\t\t\t\t\t\tzUl6YNvn0L7djY34CHGKVQVtiV0F8PMyrYRpAMmOBUR+DsW14y8isnBcQVBjSwvA\n\t\t\t\t\t\t/kVnQYMEPEQjewc0WBDer1g4xo/Nulo66UwgSE1rJqLUSiU/TZznhA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.one-test2.contrail.rl.ac.uk/simplesaml/module.php/saml/sp/saml2-acs.php/uk-federation",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://federation.one-test2.contrail.rl.ac.uk/simplesaml/module.php/saml/sp/saml1-acs.php/uk-federation",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://federation.one-test2.contrail.rl.ac.uk/simplesaml/module.php/saml/sp/saml2-acs.php/uk-federation",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://federation.one-test2.contrail.rl.ac.uk/simplesaml/module.php/saml/sp/saml1-acs.php/uk-federation/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ukfed-connector"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonTargetedID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib.wit.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sabourinj@wit.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Justin Sabourin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ragsdalej@wit.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Justin Ragsdale"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@wit.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "DTS Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "knightsj@wit.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Knights"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://shib.wit.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.wit.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.wit.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.wit.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.wit.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.wit.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wit.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.wit.edu/dts/network-services"
                  }
                ],
                "logo": [
                  {
                    "text": "https://shib.wit.edu/logo.gif",
                    "lang": "en",
                    "height": "85",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "274"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.wit.edu/dts/policies/incommon.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Wentworth Institute of Technology"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAL4gPAI3pps+1dKHkSSIGxbUOJQVMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDHNoaWIud2l0LmVkdTAeFw0xMzA3MDIyMDQ1MDVaFw0z\nMzA3MDIyMDQ1MDVaMBcxFTATBgNVBAMTDHNoaWIud2l0LmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBANBosjBBQW8kEhdpr+RhZ4quqdVvhFfyoha8\n8iG6SyRX+U04180c8XWcIKJqn2s6VZyRf7iTFvRXPQLdryN0yGV+lPLBW5KsvbyO\nibf5LdAweeKOvs9bbLQtH6FCuZB5stkk2/rAf/LbOyFMwrT5KWajAobVP5Aseddz\n+UZzkW6FieB2I9BDVYpJhWiNrtZXRi2tCJrSWg69E+opq5CP0vUKuRiIuMcBCZHJ\npCdmlMgx2dr3Brn5BuSLIolKh/WLQGD6IqLLd3WthD/MvDIQ+EkSejfNyUgsnqIj\nekanbU0B7TQyqSh2dwUGE5gfS88UtAISCVtXc4UhxIe3juFoVC8CAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMc2hpYi53aXQuZWR1hiNodHRwczovL3NoaWIud2l0LmVkdS9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUPZPH3e6ZQYadGo00kbpfVT9kMXQwDQYJ\nKoZIhvcNAQEFBQADggEBAFT8KC7nfTQtOu4QJ9Z+D8Zf379GauJdRxohP0BP9zuG\niCUZMdSrMPq61/jLTafF8tu8hNn1EkcLuTWbasksgxWdgCCYbiuyPkG3+dCRj/yX\nGqidPO/07veu9/SXf3DcMM5zA8QW2eawhvwds9txIY7gLxfSjbeQ0BcjpGthKMKB\ny6QzabIS0ZwYXcX++WTIQeRCenro+0AvjvYOw6ZPKdrTuzImGdPk37eXuXgqj1a1\nA6dXswKkeOmY7Ky2OFtCmKzgXiwzoUyAwijdkkpEKqKF+gl9kyef3H6pcYHr8/dJ\npDCw7VYeZA86FY+O/OlnlcceJZkWJb7rRITUEVvQYz8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Wentworth Institute of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wit.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Wentworth Institute of Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://api.credoreference.com/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@credoreference.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@credoreference.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://api.credoreference.com/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-07-03T15:30:08Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Credo Reference Production RESTful API"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://corp.credoreference.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Credo Reference Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://api.credoreference.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://api.credoreference.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://api.credoreference.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://api.credoreference.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://api.credoreference.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://api.credoreference.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://api.credoreference.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Credo Reference Production RESTful API. Contact support@credoreference.com for details."
                  }
                ],
                "logo": [
                  {
                    "text": "https://corp.credoreference.com/images/credo_horz_transparent_200w.gif",
                    "height": "36",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "200"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Credo Reference Production RESTful API"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIJAOsnADaxwuwdMA0GCSqGSIb3DQEBBQUAMDMxMTAvBgNV\n\t\t\t\t\t\tBAMTKGF3cy11cy1lYS1wcm9kLWRlbW8tMS5jcmVkb3JlZmVyZW5jZS5jb20wHhcN\n\t\t\t\t\t\tMTQwNDEwMTYwNjQxWhcNMjQwNDA3MTYwNjQxWjAzMTEwLwYDVQQDEyhhd3MtdXMt\n\t\t\t\t\t\tZWEtcHJvZC1kZW1vLTEuY3JlZG9yZWZlcmVuY2UuY29tMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAybu7QT+tSyTzBm4XgUzTRH8fU2N7Iqve9z3pHFJK\n\t\t\t\t\t\tkqxB7x8PG2Tsg5h8PTxkRHbHlvCeK41u72nhUhgD8AGrSwxhGvFJS6ML6m+HgjuC\n\t\t\t\t\t\tOpoVYrgQFkH7ba7s48nv5iZjWm3PA8EPyhH6+71VdJvCArjPTVhJiBVCTVr4GlRQ\n\t\t\t\t\t\taZCFT4DEfgkFSRMm63hGUjvyLNtQeaF3lodVcfseZf5rKshh72T56LADwk2gc3gD\n\t\t\t\t\t\tRTFELvHLRunml5ocj+hocCc4pahjaI7Wvxxfmq30/9oQSOW/sIAYjBrCCLANPo62\n\t\t\t\t\t\tZXwHnpdaq/IK85dIJIWJo97C2Q8OrPDjm60MIGerf/LN7wIDAQABo1YwVDAzBgNV\n\t\t\t\t\t\tHREELDAqgihhd3MtdXMtZWEtcHJvZC1kZW1vLTEuY3JlZG9yZWZlcmVuY2UuY29t\n\t\t\t\t\t\tMB0GA1UdDgQWBBSb0bm0aAM/mcTdCLP6Bd7fVhZEIDANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAWIr7gg8AYViRX60K6x6nCgTfqsc8FEzZevBYgeOpljhxRVu4raHp1e+ycckk\n\t\t\t\t\t\tJYPzuuJFA/RPHH37xOthxrXUhb6lbOR2bmqOudji/l8m0njEWvlfK1O9APKnzIFK\n\t\t\t\t\t\tDXo6w1tE/EzL30F2sDKO3z9X2N2bRVfm7i4aBH2G8ksM5gEDiNLXFEBjll/cFgGj\n\t\t\t\t\t\tsQiZqRpyrEiu1DNYWR7cekhJ76MQ9vRAg+sRi+4+YcJqecm3uSAvfdi06Z50neEI\n\t\t\t\t\t\tx4if+VFo6Qgx/Kc4nRLASPV0BQMywJZJ8tzI0HmZ8kdgloMtSsEAik7xdZ2qhYUU\n\t\t\t\t\t\t6PpbbkDoIuMrrMqEbFW6Rk+q/Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://api.credoreference.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://api.credoreference.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://api.credoreference.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://api.credoreference.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://api.credoreference.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://api.credoreference.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.lamlash.edina.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hopkins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sara.hopkins@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sara"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hopkins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sara.hopkins@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sara"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.lamlash.edina.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-09-20T14:18:43Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lamlash UK fed support test SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://ukfederation.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lamlash.edina.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lamlash.edina.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lamlash.edina.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lamlash.edina.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lamlash.edina.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://lamlash.edina.ac.uk/Shibboleth.sso/UKFedDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://lamlash.edina.ac.uk/Shibboleth.sso/UKFedDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Lamlash UK fed support test SP"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lamlash UK fed support test SP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJAIz7KDvHw5ORMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\n\t\t\t\t\t\tBAMTE2xhbWxhc2guZWRpbmEuYWMudWswHhcNMTMwOTEzMTc1NDI1WhcNMjMwOTEx\n\t\t\t\t\t\tMTc1NDI1WjAeMRwwGgYDVQQDExNsYW1sYXNoLmVkaW5hLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAq0M2cjdOzJJBxoIEWtP6SCapbrGLQ7zv\n\t\t\t\t\t\tdJ2U2jqufS02CUDkFB33MRPayOq/PVIRLVjfQMaA2D34LkWHhnF6VzF1ERXAFHjj\n\t\t\t\t\t\tQ5/Nkkb5EVQMJ6C1hNe3MVo0uns+V13WzYhsImPpwJhIIB6SoRu/EQdS9p9lsqdd\n\t\t\t\t\t\twCg90AYObN1BNTLPVMW5e1OsN1YNHEt8DEtNEm7FRG+5tkAj4wXQZ8pun2GtZUdi\n\t\t\t\t\t\tdYR88kvsNpXMje5xtZg4u+6LGJxfJns9/ad6RERT7fVYCE4vNMpozuB6ByjaOmbE\n\t\t\t\t\t\thHwumZM7cFJtnT4HU92sPOIMnE392jEhrYpzq+mLNEqCmDwJ5kwnQwIDAQABo0Ew\n\t\t\t\t\t\tPzAeBgNVHREEFzAVghNsYW1sYXNoLmVkaW5hLmFjLnVrMB0GA1UdDgQWBBT6y7VG\n\t\t\t\t\t\t2F3VKyvXjJzKhFVQg+AT5zANBgkqhkiG9w0BAQUFAAOCAQEAVJkvK0y+0nwvIvQ3\n\t\t\t\t\t\tuI7UVmmgVpGxhAcVdid30WtLnAR+zrUUzkiLEYNm6wQuatAHie5vYrfYmxs8p/K7\n\t\t\t\t\t\thBeUJ9h/htCyeZpLtlP6qr//cUmrSDSOtngy088Mhn4dZKv2Hn3UHCcdtYe4cSAC\n\t\t\t\t\t\twbv5STfw1XddQNVMFCDuWhqWkHaYCqLuF1ExtNf4NreTTeBaLXzgBJ2WbMd3Hhzo\n\t\t\t\t\t\tYbQr28qsBfKqUHOwiol2Lc3fnnGTMuy+tVQEkotuPX+11atM4tke4UiyQe2nt4SH\n\t\t\t\t\t\txaFW7FiB0FShlypmGvWvjIC6h4+oxI3D7fVMoX7MElb5+Xmy4qdTKZIXFBRSTLnt\n\t\t\t\t\t\tfbyOPg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lamlash.edina.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lamlash.edina.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lamlash.edina.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lamlash.edina.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lamlash.edina.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://lamlash.edina.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lamlash.edina.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://lamlash.edina.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://lamlash.edina.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://lamlash.edina.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://tucana.sai.kau.se/simplesaml/module.php/saml/sp/metadata.php/default-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ugh@kau.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "sysapp"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://tucana.sai.kau.se/simplesaml/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://tucana.sai.kau.se/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://tucana.sai.kau.se/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Utv. plats f\u00f6r externwebb."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Dev for external webb."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Logga in p\u00e5 kau.se(utv)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Login to kau.se(dev)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://tucana.sai.kau.se/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://tucana.sai.kau.se/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://tucana.sai.kau.se/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://tucana.sai.kau.se/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://weblogon.ltu.se/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Servicedesk"
          },
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Lule\u00e5 University of Technology"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 920 491 664"
            }
          ]
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 920 492396"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mattias Pantzare"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mattias.pantzare@ltu.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Lule\u00e5 University of Technology"
          }
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Servicedesk"
          },
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Lule\u00e5 University of Technology"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 920 491 664"
            }
          ]
        }
      ],
      "entity_id": "https://weblogon.ltu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lule\u00e5 tekniska universitet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lule\u00e5 University of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ltu.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LTU"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://weblogon.ltu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://weblogon.ltu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://weblogon.ltu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://weblogon.ltu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://weblogon.ltu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://weblogon.ltu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://weblogon.ltu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Kontohantering f\u00f6r Lule\u00e5 Tekniska Universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Account management for Lule\u00e5 University of Technology"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kontohantering f\u00f6r Lule\u00e5 tekniska universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Account management for Lule\u00e5 University of Technology"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "wc-auth.its.ltu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAOFOTnFcVFnNMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEndjLWF1dGguaXRzLmx0dS5zZTAeFw0xNDA4MTExNDAyNDlaFw0yNDA4MDgx\nNDAyNDlaMB0xGzAZBgNVBAMTEndjLWF1dGguaXRzLmx0dS5zZTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAKU1PSUSJ05wB09JUJun+CViVYLrEoFJ1HEw\nzplsgl/55yIHUER06nu+tnFpTAeRpa2dt6TwORQMQNcGHKK4hxKZzsp62uhXkZAj\nZvj+SQ/FMFHoK8AwKB43VafZ+/LY8uL4G9FINula2y/0TJNt/F/IB/KuSxuIec4W\n6XwIUCWjV5AZOTP3DxHv7xGEOb1I/DF0mmQPRN6aPbKpIItyHSO0KJ38sklxpVVf\ntm1pKJ7cQWNe3LWh8vqPkWTWNc8o7g8g8+E5NBkE5D+WjCUqEHouZiJXtWxgCC7m\nUEon+O8UsD5eVVwCZci5RDDWThVppzr+E3Fv5kx6LtUTLRia/20CAwEAAaNAMD4w\nHQYDVR0RBBYwFIISd2MtYXV0aC5pdHMubHR1LnNlMB0GA1UdDgQWBBTIvdGbMies\nr4W/9kewVtGgwWLSaDANBgkqhkiG9w0BAQUFAAOCAQEAE94b5Z/adSeFTSMGhIiD\n7Nz0C1osM70dKPSjvmpGBsyC0xtjOr3Ll73n4d43VMd75xNmi/xberJO3+3Ud/c/\nswH+8tjAtP0BHtxTJ7Xcs0m/ElNNaVXwEl34CinYxDJNMEEWYicBTkaBD90FrnbO\nQm5ytFnItYZER8g5/AifXFS0iC1KLhxGszt+5XnDIkGWgWqYp51ZkImzWtOdSWT6\nMrOIEeyy/KCb2tabQqNayvuGKwMuIga9uEnwJqd1tJ1CCAP3HWbiSsTUPrknQXiS\njkJPDEVvBZykn1K/4ufG2lsZofp3vg8dmZKysmwokwHKg9Jb7cY2xTiVb51uOUJ5\nJQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=wc-auth.its.ltu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://weblogon.ltu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://weblogon.ltu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://weblogon.ltu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://weblogon.ltu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://weblogon.ltu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "www.lararlyftet-validering.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "www.lararlyftet-validering.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.lararlyftet-validering.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.lararlyftet-validering.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.lararlyftet-validering.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.lararlyftet-validering.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.lararlyftet-validering.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.lararlyftet-validering.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.lararlyftet-validering.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Valideringssystemet f\u00f6r L\u00e4rarlyftet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service is the validation system for L\u00e4rarlyftet"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "L\u00e4rarlyftet Validering"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "L\u00e4rarlyftet Validation"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "sto-pola.sto.netlight.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAM8E1VkC2/D7MA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\nBAMTGHN0by1wb2xhLnN0by5uZXRsaWdodC5zZTAeFw0xNDEyMTIxNDM3MzRaFw0y\nNDEyMDkxNDM3MzRaMCMxITAfBgNVBAMTGHN0by1wb2xhLnN0by5uZXRsaWdodC5z\nZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMe7IeD13RcALx46boeu\nXqi1RI4czNsDBSt7O5CmYdI9V1SuVMLxX1pg/xqX2E7UquxmgOKDSk37ELzCvllI\nLiajuaTFJB2piIgOuty24TVVdPKu3d9MSONguAinoee3+EQVAAGv1PeqJddVKZR2\nWcWHm8+gaw30f031hPDxdkAmfH6aj9DYpAvR0X++uDBXCTzLSSs4EqBFCxce5pHN\nfWzft0k5M/eSozzu7SiS0GS/HbQoXRVwcW2LHayULlbeLMDfnybhm/nD9bgC1+y0\nQMDYmTnP6QFMKfrlnoSzJwdgexn6WlC1ot+EMWebt0h2LOsyAplAZW+xnX/yf+VV\nRM0CAwEAAaNGMEQwIwYDVR0RBBwwGoIYc3RvLXBvbGEuc3RvLm5ldGxpZ2h0LnNl\nMB0GA1UdDgQWBBSBXAMCdz4oSN4hX5oOoKNTrFXt9TANBgkqhkiG9w0BAQUFAAOC\nAQEAfXL0K8J7WCSSzMN+3mC6dl2sou6zw8QNGfXRo41vB+kBqtLLI1VZZg1cWAf0\nyopwPtwz9KseMSJvoQgcW+UuSXJgTEQmrkD6hJJhcZZpFSqAt9cNfbrXY6m5YDHj\nWBGYLC1USzLHiC1LP73IbiATvEPi8r3jS1Vm/Sg82bkkxbSXMkN3GmxjvKpFZkZH\nFpgh9wz7R/qlZTrKGWoBsIApiSNJB4BBMc8AaaF6v26IZy2FsFhXQjX7fHG5OpIZ\nABP8HAePligOwIdfjCyp+kw/tvzVOE6mcGZUibXvNXBSnQoykuV8dPZe4yWzpbzg\nMViWUqDxKicGyuokDNf3hpcc9w=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=sto-pola.sto.netlight.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.lararlyftet-validering.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.lararlyftet-validering.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.lararlyftet-validering.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.lararlyftet-validering.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.lararlyftet-validering.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.lararlyftet-validering.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.lararlyftet-validering.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.lararlyftet-validering.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.lararlyftet-validering.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://heinonline.org/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:techsupport@wshein.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Marisa"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rjm2@cornell.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tramp"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:atramp@wshein.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Daving"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kdaving@wshein.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kyle"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://heinonline.org/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-06-21T15:27:59Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "William S. Hein & Co., Inc.: HeinOnline"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wshein.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "William S. Hein & Co., Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The World's Largest Image-based Legal Research Database"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "HeinOnline"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID1jCCAr6gAwIBAgIJAKKIx7G8Se2XMA0GCSqGSIb3DQEBBQUAMGwxCzAJBgNV\n\t\t\t\t\t\tBAYTAlVTMREwDwYDVQQIEwhOZXcgWW9yazEPMA0GA1UEBxMGSXRoYWNhMSAwHgYD\n\t\t\t\t\t\tVQQKExdXUyBIZWluIGFuZCBDb21wYW55IEluYzEXMBUGA1UEAxMOaGVpbm9ubGlu\n\t\t\t\t\t\tZS5vcmcwHhcNMTEwNTIwMTYzNjEzWhcNMjEwNTE3MTYzNjEzWjBsMQswCQYDVQQG\n\t\t\t\t\t\tEwJVUzERMA8GA1UECBMITmV3IFlvcmsxDzANBgNVBAcTBkl0aGFjYTEgMB4GA1UE\n\t\t\t\t\t\tChMXV1MgSGVpbiBhbmQgQ29tcGFueSBJbmMxFzAVBgNVBAMTDmhlaW5vbmxpbmUu\n\t\t\t\t\t\tb3JnMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2w2m3RnHsi1LOOmJ\n\t\t\t\t\t\tcbxPV/qCPbUoG7J6MqodKyKB3cLpGTvTk1u+iFh/TpYGe2jvUZywoW7fH6cc6rZM\n\t\t\t\t\t\tQC3Ix9BODKBIFuvMs5XYqdwIHq3kZ1st8FubN6sQZ9dEf9IKDflvHSMYzxzsZnfR\n\t\t\t\t\t\tY5XsEnQRU9R9M91NEabXF4SMCyn45obWpKhBdLzX435I41AFtRLBYIr46bq89lWE\n\t\t\t\t\t\tVHkc8ic/w4Q+QB1f1q5ej37ogiuiPbSLDpvscUTpUipUHzOj1oE7/zvAoZ48WYqx\n\t\t\t\t\t\t8x01C8xVtwiIy8p3new658A7rwrveq8CbeglUE1uaXq+swePZMH57TIT1SB4Hrnu\n\t\t\t\t\t\t97sWEwIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NM\n\t\t\t\t\t\tIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUrKKkqy079i1m8wc8+kyp\n\t\t\t\t\t\tJne7OtMwHwYDVR0jBBgwFoAUrKKkqy079i1m8wc8+kypJne7OtMwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBADFtM86JUBLYkundSv7WlNQK7HDi76ZHeYg4PcHMVQhdOHTvQm9J\n\t\t\t\t\t\tWqwyHRB7Lk+eOl2DQDXMjWjh+FgvM7VNHqGzldR+uLgLShJgZrb6pYZYuxXNrK6l\n\t\t\t\t\t\tMxfOkN2YPwIsI+jK1DEKArjZ+Z0QlH8osJTR1HtWjbLEqi7Vy3k6jXq7rDD+QTiV\n\t\t\t\t\t\tL/+tbPcnYvRa54AKEdoHGsnFlw/WTWT/umc330g9aAGFeD1KlI1cSW2naSUqRnvK\n\t\t\t\t\t\twCfR0ocvN3eEaulmUByr3AB7NwgjLjLHplwRPBz8O/cRJfCM1PzP6updCHhQX3em\n\t\t\t\t\t\tut67QhF+oJkUpBvydg21h7fQUnuSK9KlI9k="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID1jCCAr6gAwIBAgIJAKKIx7G8Se2XMA0GCSqGSIb3DQEBBQUAMGwxCzAJBgNV\n\t\t\t\t\t\tBAYTAlVTMREwDwYDVQQIEwhOZXcgWW9yazEPMA0GA1UEBxMGSXRoYWNhMSAwHgYD\n\t\t\t\t\t\tVQQKExdXUyBIZWluIGFuZCBDb21wYW55IEluYzEXMBUGA1UEAxMOaGVpbm9ubGlu\n\t\t\t\t\t\tZS5vcmcwHhcNMTEwNTIwMTYzNjEzWhcNMjEwNTE3MTYzNjEzWjBsMQswCQYDVQQG\n\t\t\t\t\t\tEwJVUzERMA8GA1UECBMITmV3IFlvcmsxDzANBgNVBAcTBkl0aGFjYTEgMB4GA1UE\n\t\t\t\t\t\tChMXV1MgSGVpbiBhbmQgQ29tcGFueSBJbmMxFzAVBgNVBAMTDmhlaW5vbmxpbmUu\n\t\t\t\t\t\tb3JnMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2w2m3RnHsi1LOOmJ\n\t\t\t\t\t\tcbxPV/qCPbUoG7J6MqodKyKB3cLpGTvTk1u+iFh/TpYGe2jvUZywoW7fH6cc6rZM\n\t\t\t\t\t\tQC3Ix9BODKBIFuvMs5XYqdwIHq3kZ1st8FubN6sQZ9dEf9IKDflvHSMYzxzsZnfR\n\t\t\t\t\t\tY5XsEnQRU9R9M91NEabXF4SMCyn45obWpKhBdLzX435I41AFtRLBYIr46bq89lWE\n\t\t\t\t\t\tVHkc8ic/w4Q+QB1f1q5ej37ogiuiPbSLDpvscUTpUipUHzOj1oE7/zvAoZ48WYqx\n\t\t\t\t\t\t8x01C8xVtwiIy8p3new658A7rwrveq8CbeglUE1uaXq+swePZMH57TIT1SB4Hrnu\n\t\t\t\t\t\t97sWEwIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NM\n\t\t\t\t\t\tIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUrKKkqy079i1m8wc8+kyp\n\t\t\t\t\t\tJne7OtMwHwYDVR0jBBgwFoAUrKKkqy079i1m8wc8+kypJne7OtMwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBADFtM86JUBLYkundSv7WlNQK7HDi76ZHeYg4PcHMVQhdOHTvQm9J\n\t\t\t\t\t\tWqwyHRB7Lk+eOl2DQDXMjWjh+FgvM7VNHqGzldR+uLgLShJgZrb6pYZYuxXNrK6l\n\t\t\t\t\t\tMxfOkN2YPwIsI+jK1DEKArjZ+Z0QlH8osJTR1HtWjbLEqi7Vy3k6jXq7rDD+QTiV\n\t\t\t\t\t\tL/+tbPcnYvRa54AKEdoHGsnFlw/WTWT/umc330g9aAGFeD1KlI1cSW2naSUqRnvK\n\t\t\t\t\t\twCfR0ocvN3eEaulmUByr3AB7NwgjLjLHplwRPBz8O/cRJfCM1PzP6updCHhQX3em\n\t\t\t\t\t\tut67QhF+oJkUpBvydg21h7fQUnuSK9KlI9k="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://heinonline.org/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://heinonline.org/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://identityprovider.anl.gov/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@anl.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Help Desk - Shibboleth"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "volmer@anl.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Volmer"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "deengert@anl.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Doug Engert"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://identityprovider.anl.gov/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.anl.gov/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.anl.gov/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.anl.gov/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.anl.gov:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.anl.gov:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "anl.gov"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.anl.gov"
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.anl.gov/idp/images/argonne_header_logo_white.jpg",
                    "lang": "en",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "227"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.anl.gov/notice.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Argonne National Laboratory"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSzCCAjOgAwIBAgIUd1lQByK+80eHKNHL1oZcQacjU9EwDQYJKoZIhvcNAQEF\nBQAwIzEhMB8GA1UEAxMYaWRlbnRpdHlwcm92aWRlci5hbmwuZ292MB4XDTExMDYw\nMzE0Mjk1N1oXDTMxMDYwMzE0Mjk1N1owIzEhMB8GA1UEAxMYaWRlbnRpdHlwcm92\naWRlci5hbmwuZ292MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAs/yy\ntOLCEwBO6AzixU7TRPutPRZ5/sdzQkGNfyP7JPO5+oI+MIuVqwqrx74RujsOxMpb\nBn+ndYmreuJpDqXPFUezGD/AQ08zOXH53/J6IKOHvDD2MfDOKUNjsh5wGXtcKxSU\nkl6g/tM2/0VOfYR653ZkawPxtGk9Rpl5Pqq+s5RFuVNFMb0NPhbeyAk/PrltkRTU\nYJRqh0vCCm2plkiZ+g3A8fxyNpYCRYG//guGIk/sVkYiu8Z/sten1CTlmxWvJJRB\n27U/PhIQFnj762x3sgTJidibKS/zYa2WVYHv2u4ufuKgZK6SiUUvOGFTu+6NZIr3\nu3FlWCGXrw3fRIu8QQIDAQABo3cwdTBUBgNVHREETTBLghhpZGVudGl0eXByb3Zp\nZGVyLmFubC5nb3aGL2h0dHBzOi8vaWRlbnRpdHlwcm92aWRlci5hbmwuZ292L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBTOVxBosibb45yMEFFWzP8mHovAkjANBgkq\nhkiG9w0BAQUFAAOCAQEACjYGMFjNayjnIXjx+rjmejNgJCrddjJVLm0NRsf6ZRtX\nib3OHwGysSEd/DQUTuf1UGrQXOYH2ifK/KZMUJ5Mcg7XHbmzMYX0OdbQi5oYgUJY\nR4nIN4BlwlxsE9RhNCJ2VzcNQF/CL9LvuVPQlJpD8TLBswqBvM/e6ifx6DdIP0MG\nmMoA4tvGzp293Lo3UoNpvdRtr6+GRTdOKggPQjKqu3V2jzOELGq7CIxn59/XasoU\np0zxTYpUGhmHWBe5HmeezrYkX34iEAvmHaTN9Fbji9HnfdlWGDvzDjK9T3jgdyuV\nmftOvQo7MiSZrcQLClWSbNfouzKanesq48qbGPLLXg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://login.anl.gov/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Argonne National Laboratory"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.anl.gov/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Argonne National Laboratory"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.stvincent.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Grochowicz"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lukasz@stvincent.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lukasz"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Grochowicz"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lukasz@stvincent.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lukasz"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.stvincent.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-11-16T17:32:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID+zCCAuOgAwIBAgIJAPVJaPGZ6hp0MA0GCSqGSIb3DQEBBQUAMIGTMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjESMBAGA1UECAwJSGFtcHNoaXJlMRAwDgYDVQQHDAdHb3Nwb3J0MRww\n\t\t\t\t\t\tGgYDVQQKDBNTdC4gVmluY2VudCBDb2xsZWdlMRswGQYDVQQLDBJDb21wdXRpbmcg\n\t\t\t\t\t\tU2VydmljZXMxIzAhBgNVBAMMGnNoaWJib2xldGguc3R2aW5jZW50LmFjLnVrMB4X\n\t\t\t\t\t\tDTE0MDQyMjA4NTEzOVoXDTI0MDQxOTA4NTEzOVowgZMxCzAJBgNVBAYTAkdCMRIw\n\t\t\t\t\t\tEAYDVQQIDAlIYW1wc2hpcmUxEDAOBgNVBAcMB0dvc3BvcnQxHDAaBgNVBAoME1N0\n\t\t\t\t\t\tLiBWaW5jZW50IENvbGxlZ2UxGzAZBgNVBAsMEkNvbXB1dGluZyBTZXJ2aWNlczEj\n\t\t\t\t\t\tMCEGA1UEAwwac2hpYmJvbGV0aC5zdHZpbmNlbnQuYWMudWswggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDnZN2BAOnzT6khf5iV7SoGU+o5T0gZUqi06pWN\n\t\t\t\t\t\tt9QBYAcls5EtcX1Use0V9o3T6eolbTAuTEtLb4rA2XTl3GdC0Kxp47+FpxQPl+eE\n\t\t\t\t\t\tT5FKpm4JtsSGwSlOTWlpVB5tM5MHgo08OXCJvheFYalwHJwTSJq9iJRl3k1z/7iu\n\t\t\t\t\t\tawm0mwfrL7WkoGqsxByzuPzVOeVjcwcCu6vqPD0FdSnbgtdhUooEPH5Z9UxGmLkz\n\t\t\t\t\t\tJTsswUt4HgoZ8wfpOF8rMmWx3q2j6AlWouDZ2e+09/Da6P+OzZc3MuLI0p5RsL5g\n\t\t\t\t\t\tFZbZAd9ug3co9kat8Dv8lpgAbOD7rKnpypSd0vYQvlFnHiADAgMBAAGjUDBOMB0G\n\t\t\t\t\t\tA1UdDgQWBBRLo6YHlfQdXHuHAgwUecCZHW5n+jAfBgNVHSMEGDAWgBRLo6YHlfQd\n\t\t\t\t\t\tXHuHAgwUecCZHW5n+jAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCF\n\t\t\t\t\t\tfCPtuwRUOtWh/CW45ut5124QgxvCuSz6fhINBWUAJ+MM0jwq+IXwyfPZrdHYfSSR\n\t\t\t\t\t\tibIfAW15EHT+aDnHNGLkvmWN6E4OBzHiN5kepH4ANrSp2WSIwYEzTBvYSxhzc8Tf\n\t\t\t\t\t\tB1OGqzI4O9v3sTAnoh0MgUa0/8Bl6dhhVfvZ2VCyPSpem42FBLrrZS08MPogLkSJ\n\t\t\t\t\t\tjxpoy684e6jQDX0X1mn+f5o9syml1pEXHgsZrnWrW71xBngBKc7NdUf3GhdDNIYL\n\t\t\t\t\t\tFKaMmHp4zIQhAhM6MoWEzMJloMkRZjwa85MIVdCr7Ffyi4qhd/SlMgEsjP8Aqtih\n\t\t\t\t\t\tXptt+IaBrxyoISOIgH+z"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stvincent.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.stvincent.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.stvincent.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.stvincent.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.stvincent.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.stvincent.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.stvincent.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.stvincent.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.stvincent.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stvincent.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID+zCCAuOgAwIBAgIJAPVJaPGZ6hp0MA0GCSqGSIb3DQEBBQUAMIGTMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjESMBAGA1UECAwJSGFtcHNoaXJlMRAwDgYDVQQHDAdHb3Nwb3J0MRww\n\t\t\t\t\t\tGgYDVQQKDBNTdC4gVmluY2VudCBDb2xsZWdlMRswGQYDVQQLDBJDb21wdXRpbmcg\n\t\t\t\t\t\tU2VydmljZXMxIzAhBgNVBAMMGnNoaWJib2xldGguc3R2aW5jZW50LmFjLnVrMB4X\n\t\t\t\t\t\tDTE0MDQyMjA4NTEzOVoXDTI0MDQxOTA4NTEzOVowgZMxCzAJBgNVBAYTAkdCMRIw\n\t\t\t\t\t\tEAYDVQQIDAlIYW1wc2hpcmUxEDAOBgNVBAcMB0dvc3BvcnQxHDAaBgNVBAoME1N0\n\t\t\t\t\t\tLiBWaW5jZW50IENvbGxlZ2UxGzAZBgNVBAsMEkNvbXB1dGluZyBTZXJ2aWNlczEj\n\t\t\t\t\t\tMCEGA1UEAwwac2hpYmJvbGV0aC5zdHZpbmNlbnQuYWMudWswggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDnZN2BAOnzT6khf5iV7SoGU+o5T0gZUqi06pWN\n\t\t\t\t\t\tt9QBYAcls5EtcX1Use0V9o3T6eolbTAuTEtLb4rA2XTl3GdC0Kxp47+FpxQPl+eE\n\t\t\t\t\t\tT5FKpm4JtsSGwSlOTWlpVB5tM5MHgo08OXCJvheFYalwHJwTSJq9iJRl3k1z/7iu\n\t\t\t\t\t\tawm0mwfrL7WkoGqsxByzuPzVOeVjcwcCu6vqPD0FdSnbgtdhUooEPH5Z9UxGmLkz\n\t\t\t\t\t\tJTsswUt4HgoZ8wfpOF8rMmWx3q2j6AlWouDZ2e+09/Da6P+OzZc3MuLI0p5RsL5g\n\t\t\t\t\t\tFZbZAd9ug3co9kat8Dv8lpgAbOD7rKnpypSd0vYQvlFnHiADAgMBAAGjUDBOMB0G\n\t\t\t\t\t\tA1UdDgQWBBRLo6YHlfQdXHuHAgwUecCZHW5n+jAfBgNVHSMEGDAWgBRLo6YHlfQd\n\t\t\t\t\t\tXHuHAgwUecCZHW5n+jAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCF\n\t\t\t\t\t\tfCPtuwRUOtWh/CW45ut5124QgxvCuSz6fhINBWUAJ+MM0jwq+IXwyfPZrdHYfSSR\n\t\t\t\t\t\tibIfAW15EHT+aDnHNGLkvmWN6E4OBzHiN5kepH4ANrSp2WSIwYEzTBvYSxhzc8Tf\n\t\t\t\t\t\tB1OGqzI4O9v3sTAnoh0MgUa0/8Bl6dhhVfvZ2VCyPSpem42FBLrrZS08MPogLkSJ\n\t\t\t\t\t\tjxpoy684e6jQDX0X1mn+f5o9syml1pEXHgsZrnWrW71xBngBKc7NdUf3GhdDNIYL\n\t\t\t\t\t\tFKaMmHp4zIQhAhM6MoWEzMJloMkRZjwa85MIVdCr7Ffyi4qhd/SlMgEsjP8Aqtih\n\t\t\t\t\t\tXptt+IaBrxyoISOIgH+z"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "St Vincent College: Computing Services"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.stvincent.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "St Vincent College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://hidp.ucc.ie/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "O'Sullivan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:denis@ucc.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Denis"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "UCC"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Hostmaster@ucc.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hostmaster"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "sne@ucc.ie"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sne@ucc.ie"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://hidp.ucc.ie/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2011-10-25T00:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://hidp.ucc.ie/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hidp.ucc.ie/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://hidp.ucc.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hidp.ucc.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://hidp.ucc.ie/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://hidp.ucc.ie/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucc.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ucc.ie/en/sit/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/ucc.png",
                    "height": "71",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "200"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University College Cork"
                  },
                  {
                    "lang": "ga",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Col\u00e1iste na hOllscoile Corcaigh"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.893285131676606,-8.492431640625"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUJ3jATJ9q82dE+ma0p9zSXbsubOUwDQYJKoZIhvcNAQEF\nBQAwGzEZMBcGA1UEAxMQbWFlbHN0cm9tLnVjYy5pZTAeFw0xMDEyMjAxMTQ0MDRa\nFw0zMDEyMjAxMTQ0MDRaMBsxGTAXBgNVBAMTEG1hZWxzdHJvbS51Y2MuaWUwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCB90H3EcbGIbs1MYIbcGF8RAT8\nJZyn4G6XUBrgBebshGsiPqO/9bJ5om/vvO+fgIyrMFHVKRYyH9coSJgGSWN+FWDT\ny/ez3/s9X5kZ2rniZUpbS/7g1wezuxpDfBvaPoOfIIEtVpW9rbVGXTpSrQnMrIRb\ndF1wBJgi9s8dVgGzz6qIVYJdmTMnOxI7iX2OhxYFOXzF6vSkiKKujWGT1q/ty9Hf\nv3ZNzZeiQcpEbaXyFCyLiTFyJqYpLhEH6F4JKnNwpGsBrRVzuYErvQRGBFQxJYSg\nNq4Vh7yfSc3vS19DsSIBvXK/9scjb0RmB2u0j+jN+gfMireDZJ/a974/yil7AgMB\nAAGjZzBlMEQGA1UdEQQ9MDuCEG1hZWxzdHJvbS51Y2MuaWWGJ2h0dHBzOi8vbWFl\nbHN0cm9tLnVjYy5pZS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUysqfxq96kxiv\nchu/icPiuQA+YB0wDQYJKoZIhvcNAQEFBQADggEBABZETTa2/zk6c4gzvI7v+P/z\nbPEud4kXGZaXMO+ISMwXFra+xq961++7609SXklwW2UMatcwPl4H+72ionc69Cel\nlMnV3tNNkJsc+a5YNFw6sBmlQAoQoyKcZPYrghcFf9YUuuzyKMSyoHFibsPfDiQq\nsCOjwT0V8PGx79b88ZJp1Na/QBrsl3UWpCDtQCxgCu/PWDE23tWc9s29XIOIUEO1\nsUm5ezY/tfP6H2REvnOkBZ4Y1zDFoEjJojHOQQgRHOagmeItT/XhBP1bVOPKoyMd\njtlb4YINkQ8aWIF5en7doTGXzvLeD5H1Oj8gm9iB2J+5eSzcj0g3ONNkBjSscoE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University College Cork"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ucc.ie/en/sit/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University College Cork"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://bmthmedia.sisoshibboleth.co.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Info"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Oates"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bmthmedia.sisoshibboleth.co.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-06-06T10:17:26Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SiSo Bournemouth University ~ BmthMedia, Online Resource Booking"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.siso.uk.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "TechEthika Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bmth.siso.co/bmthmedia/sso/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://bmth.siso.co/bmthmedia/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://bmth.siso.co/bmthmedia/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SiSo Bournemouth University ~ BmthMedia, Online Resource Booking"
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth.siso.co/siso-logo60x60.jpg",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SiSo Bournemouth University ~ BmthMedia, Online Resource Booking"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAOSUhyDXVj7AMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB3Npc28uY28wHhcNMTMwMTA3MTYzMTIxWhcNMjMwMTA1MTYzMTIxWjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdzaXNvLmNvMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\txDnj9YFJVXclawo/8rs1aWYAgk6rKi8A/Cyycq0mW5yOKLLh8MUIgDeOGL7bLl7p\n\t\t\t\t\t\tMBeZM4ILlNaeJhICWm1tuLB6SYzREnXwpO7+lvx13xsRHW2TjCPGV3yUgz55vRYj\n\t\t\t\t\t\tbseFrwFHJ8IrL24UTLcpX/R//9cMkZpSqM+77Hn22dxbYvGUOQCHOQzL78AO91qz\n\t\t\t\t\t\tdUaxKzYWyWM7w2U4APP41Zvd0flyUtRZXp8W+WwlUDffFoNndsjR4L/9wuXvOcrH\n\t\t\t\t\t\t+VZtMLy60+cB9bpvVlaQVlt+1stEABdMVvuGNkJ9wIjRjP2b9OLUI76QmgwIDtdE\n\t\t\t\t\t\t5BS0Bv0Puz66L96r2MunRQIDAQABozUwMzASBgNVHREECzAJggdzaXNvLmNvMB0G\n\t\t\t\t\t\tA1UdDgQWBBRRosxNbUQXXwtWDl/kYMScRImh5TANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tgrfjza9Btcz+9WvzcjDTZ+KSrWWvrthA3zc6Q+C/MIBG8CCuxMO+uwFBnXIopGlX\n\t\t\t\t\t\tbLa/QtVLjOugsnizFxjaEFTG4jGndtPJ8+9V8Eja5RlOazuM2LT738+Um8/1Frhr\n\t\t\t\t\t\tGXa0Hdv9ZWEbIhil65fFqZNOmOteja6xxAQ9NgGG/XUnTVTbr7msihEAYTTcS40/\n\t\t\t\t\t\tGSYpT9nQwiryfSWDNJ17Zyl44389kSw+FCUsu8Ns9VSDEDWr/R+97ZMcjN6hAfJL\n\t\t\t\t\t\tdji3X1aaAC/JbnJl/v+yR1TH/sdHyObVaM7FToUGKiyjX9VpfOe64d0hjogzEr0x\n\t\t\t\t\t\tfirJubLNu96jbGctasqcpQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bmth.siso.co/bmthmedia/sso/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://bmth.siso.co/bmthmedia/sso/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bmth.siso.co/bmthmedia/sso/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://bmth.siso.co/bmthmedia/sso/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://bmth.siso.co/bmthmedia/sso/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://bmth.siso.co/bmthmedia/sso/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibidp.oca.eu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dsi@oca.eu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibidp.oca.eu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2010-10-12T19:40:58Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.oca.eu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.oca.eu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.oca.eu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oca.eu"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.oca.eu"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "People with an OCA account."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnes ayant un compte OCA."
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/x-icon;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Observatoire de la C\u00f4te d'Azur"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Observatoire de la C\u00f4te d'Azur"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQTCCAimgAwIBAgIJAOV7bDK2kJs0MA0GCSqGSIb3DQEBDQUAMDcxCzAJBgNV\nBAYTAkZSMQ8wDQYDVQQKDAZvY2EuZXUxFzAVBgNVBAMMDnNoaWJpZHAub2NhLmV1\nMB4XDTE1MDcyMDE3NDQzNVoXDTE4MDcxOTE3NDQzNVowNzELMAkGA1UEBhMCRlIx\nDzANBgNVBAoMBm9jYS5ldTEXMBUGA1UEAwwOc2hpYmlkcC5vY2EuZXUwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDPrcMzEvozMviR0Ux2TDQJ/IRM63bF\nKRhOTpY6DxVS2U3QShAgSfXCJ7vtcZuKsNkjDbItYOyrO2Qlz98dXKd3F5HYfH9E\nmpWuE9Y6R2LNTiC2rfuyzVSoNQthj3JkRFEjUlmU4V25wa+6tEC/+qL336MBsMCM\nK6SVjMh9Io8ypPhcvwa9fk0pjN62cEhB+oHBrKQhNUzw6QMw9eK7ES+MvrWdlmg0\niAWXAnTvUkuHCCU9gHMSRwvrpBn7wEsBUftIvQJ4EycZqQe+y1PV/tGlKcUOoHva\nBxepDCXDMGOskD8UkroMxGk9mS/SKYvTnSjzzsctMf2cRSXlQAC+Z/zrAgMBAAGj\nUDBOMB0GA1UdDgQWBBQ2M1IiOnEUkA/Dad0vZnqEYzKVhTAfBgNVHSMEGDAWgBQ2\nM1IiOnEUkA/Dad0vZnqEYzKVhTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBDQUA\nA4IBAQAy/EICYQABN8gfoQbg40tAEtboKbgRVrTOGEDn3YIP8zkIx46YOvt1jPEL\nElnJuCkgFLaP5BcqIa3Ao2JqhKc0vt9NB2+iFAoXLlKnX1qA9GQynclA2adrIlFs\n2CEIZNs37ch1jm8VN0h3kvUBGJPf6uwspnEbGhU7+iUpzBDMt1lhq5aC12IGtcYB\nKhTmiD1DrndtsdMrD9T69ra2BSW/MgUhuUOUisMqqJZNWDnrVG1bb1OBoC8zx1kV\n22klzEX/n1uKYUj1tmLdD8PgS+xD4qsYc4dUwdSc1Ee+jzy6Fw+IDlZWXETbwsd3\n4cPhU/7ZhxoTQe+Vryc61Cs97o5u"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIJAKyLcn7sL8vlMA0GCSqGSIb3DQEBDQUAMDAxCzAJBgNV\nBAYTAkZSMQ8wDQYDVQQKDAZvY2EuZXUxEDAOBgNVBAMMB3NoaWJpZHAwHhcNMTUw\nNzIwMTY0ODQyWhcNMTgwNzE5MTY0ODQyWjAwMQswCQYDVQQGEwJGUjEPMA0GA1UE\nCgwGb2NhLmV1MRAwDgYDVQQDDAdzaGliaWRwMIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEA86IDYElbcap9Jqk0pDhsu7EeOztWPT/9FHXBLk7F5MhEbtf8\nOl+qpr/2iTFLAkFEmSFBeH3/GZAlCcHhqFK0jsX7CN4jD6YWGxBsW7ei83g96XzC\n68o7NwAhAOFXej8B91uKq57SE+yDHKfH5iijbmliedvyJp4D0vlHZam+wxOqCwlf\nwQ+ju4ObLWXhAJwBYrP1O61LLX67sXaucLlybNS2OCE42KuCXyKaf43Vvlqwqh+b\nMdrrQ31A3iZba/yNlAKlaFxaKRXh82lteUUlj+r1vEEMUs9vd2kNX5MMUnqG2c7J\n9eO38zQQFufw4jMUpTV5Yt+lNxfUZbRADbbzjQIDAQABo1AwTjAdBgNVHQ4EFgQU\n0TJHupykS7kfEFgzvKWOqD6jtaMwHwYDVR0jBBgwFoAU0TJHupykS7kfEFgzvKWO\nqD6jtaMwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQ0FAAOCAQEAq1TPf+MQaFpU\n64zcP87Cea1Ox9aWlR7UARjo1f0ygghpK1dgAZAJRa6huXaQ5YqJFWGDl1JE39oC\n4RUvVnVo+sR2Lzt2Zih/NoDrV9lhvtszef7GsW6TYsNrUWnI/le9LrM4B9VgBkBm\nwNKbN68s2jw/u0c3NPLAI1EQYG5Z6qOXAuyBnAaKWlJ5UhhhIMLNVpgK+VjBfVmG\nNaSpjU0SpU2lWAsJWS7mfWjO9ZyNnhjhmlUatHEq9qjDMKdtlCfd4Mg6v3Sf5YiM\nHi8WsKvOPJRSWmD7niI3qfMF07UU0OgCQ6eFhvh19E2MOi9lD6D10gd76QYZjAbg\nUfiJZdPA+g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Observatoire de la C\u00f4te d'Azur"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oca.eu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Observatoire de la C\u00f4te d'Azur"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.task.gda.pl/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "TASK"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@task.gda.pl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAI"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.task.gda.pl/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.pionier.net.pl/en/index.php?page=rps"
              }
            ],
            "registration_instant": "2015-06-22T00:00:00Z",
            "registration_authority": "https://aai.pionier.net.pl",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.task.gda.pl/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.task.gda.pl/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.task.gda.pl/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.task.gda.pl/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.task.gda.pl:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.task.gda.pl:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "task.gda.pl"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Academic Computer Center TASK Identity Provider"
                  },
                  {
                    "lang": "pl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Dostawca To\u017csamo\u015bci Centrum Informatycznego TASK"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.task.gda.pl/idp/images/logo_citask.png",
                    "lang": "en",
                    "height": "45",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "109"
                  },
                  {
                    "text": "https://idp.task.gda.pl/idp/images/logo_citask.png",
                    "lang": "pl",
                    "height": "45",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "109"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TASK Gdansk"
                  },
                  {
                    "lang": "pl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TASK Gda\u0144sk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "task.gda.pl"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:54.371860,18.612700"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "153.19.0.0/16"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIURF5LPwZ/QXjVB9iJ7Kz0mzeHll0wDQYJKoZIhvcNAQEL\nBQAwGjEYMBYGA1UEAwwPaWRwLnRhc2suZ2RhLnBsMB4XDTE1MDQwMzA4Mzk1OFoX\nDTM1MDQwMzA4Mzk1OFowGjEYMBYGA1UEAwwPaWRwLnRhc2suZ2RhLnBsMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoDhbNawOVOWO4A/VWUKiNnP6CmGj\nDW6Q3eJH35bIM15MOUm4bsPgZlv2GJ83TV4MPU+m9lvZs7PwawaaJtIslzIiq1TF\nfcolHmrjzw+EqPnv/2/HH9yUJKSusXFNadqC/yPayv0UNMUgkGl1/Rz7EFZRuClM\n3rE4a7CgrhcGue5D8LnW0lPo8gYdrPY0YntT/lVLS3JSooeuEAZCbdfj6mJ0anUR\nAgl8Iy5gTrZ6p1mf6Wc2SqKW60aNWqBUpMAI7LwzkwJPtDAPZ4jITN/gc30iEzfS\n8yw0aoQJ1VuB1AecpQj/d1Jy54q76UV2IC4ELo0heaFDPX0Zkn6klvCqzwIDAQAB\no2UwYzAdBgNVHQ4EFgQUcUVjQ8rdgeB+mQz7Xa54TmYYkRYwQgYDVR0RBDswOYIP\naWRwLnRhc2suZ2RhLnBshiZodHRwczovL2lkcC50YXNrLmdkYS5wbC9pZHAvc2hp\nYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAlPyHV9yROpDobbr+AtdQPRPnEiDl\n/AVORvbh1kizmapzK5DS8ROmi/tEKWoGv1S85dg5MREosL4BbfQDzZIpmbWNPCBi\n4LfRWsAXmzxExEslW5NpVfYvz5/+hv/V7sML86m7eVpWULSsTH0JC4QYfN+m33Ba\nXbsFGH7eCthi2IwQls+B93v4EUkWtTM6P/nZlqZi8Y3asX9i5EHrMsdcl2nwzdol\nEY/syGwYwfajAEI1c7RcNujuQty1fraXpRDF/kzhy6oiBCecqpSowKy/QEBlV9wh\nBp0cQldS1u/LcLeFWQq32HbT9OpVBMoqx7VsL8PEkE+592rLCCTvwDXFng=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVANy+gCUM8Wyxo9utTnW0xq8dzG5ZMA0GCSqGSIb3DQEB\nCwUAMBoxGDAWBgNVBAMMD2lkcC50YXNrLmdkYS5wbDAeFw0xNTA0MDMwODM5NTZa\nFw0zNTA0MDMwODM5NTZaMBoxGDAWBgNVBAMMD2lkcC50YXNrLmdkYS5wbDCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAISQv8+20Dt+F22y+/0LwXlrH5Ld\n3ZU0E5L8nY1W3nkdnRJkc8VRAj+EgeGnEHHQeb/xhpYiSFWYwjDbM9nkE6a2OLpU\n1tsSax3clNpYGXlRsbqg/XdVZg38j19C45JQOXAdDskLMyWhzhKqPFniUGHsd0Wn\nyq32uC8uohlgAD69fgSs9KxEl6kyDlZBg8fv5w28HianLp0EiTv6gwZ2ZQThIkqi\nnIYK3yZccjzauhGW6yRtvEoRIY3HZuiSGcgVcoBcqKSepSjCA3PYzCWX1MrZyLYw\nwq1utQb3PAcXiHyFd6mm3bkoKCLYByyPgV1GXzRsyHp33FCAJpGuix78bRECAwEA\nAaNlMGMwHQYDVR0OBBYEFHwRZRLbErBc55nrd4dcRSwKY4x6MEIGA1UdEQQ7MDmC\nD2lkcC50YXNrLmdkYS5wbIYmaHR0cHM6Ly9pZHAudGFzay5nZGEucGwvaWRwL3No\naWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAE5rcoiYYQN8cSqmRXD6q301rqnB\nPPmwTS9auHQkqTGMezpPV+UK5PLR8MxGKOs5XHxo+klixekYti0VgqBKpO+c9Jsh\n5TM62+mePv9SJL0YapvgzQcXSdfTuR0QTDKLoS/aUSwO5yR8PDf5JOdTspygfrzx\nR5rWGWSCMoq/sl687jlylzovRLzQn6opFKoeXlBIBwWdZCG/CNwq3DQeMCWrkgt9\nrUkBt8hYMPOjHcJx2nl+2Ue6vcevZkudqxBpV5tpioX6Q2F/XsQCiCYpGue9aWcQ\ng12oVQa4JuIHhKSmvZfVZIu1QfcMadj27vchQXWqttvarQO7NWRRimE9OII="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUH/PXFUwlqT8+OMaMthWJ3kkOYJ0wDQYJKoZIhvcNAQEL\nBQAwGjEYMBYGA1UEAwwPaWRwLnRhc2suZ2RhLnBsMB4XDTE1MDQwMzA4Mzk1N1oX\nDTM1MDQwMzA4Mzk1N1owGjEYMBYGA1UEAwwPaWRwLnRhc2suZ2RhLnBsMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnxLDEWcL+qc///wbesB7tizhsqMi\nUb8s8+dbJkFvWl4htkzfiHi76L+M7L4eXfv1gsgdNXk0mm1kZWa/6XafDPy80zkL\n4ro4UH46LXOu8wMeoy6eLeJDlurX+CzFbPiGdx1FqQF1QIU8jf1bBS7OhpYJ7Ex6\nq7iM/VU2j5i8momKTk4Ktsc+GaVXeO9CWjOb2+U2QNoVxXYX+8NJNcQXyIIxir00\n3e4pl8W7WPxPBz0Ex/+xJPzb75qrSjx9YfadzfE3uoyGomOzODRodOszSSUXnd4J\ncdRZKdA+R8xUZnctuUncLaMUopg3SoBE3VIyl99mvQkmk/Skue4o0PJqoQIDAQAB\no2UwYzAdBgNVHQ4EFgQUeUfa/bgMdBy0o6JP0hLwgNSuXNowQgYDVR0RBDswOYIP\naWRwLnRhc2suZ2RhLnBshiZodHRwczovL2lkcC50YXNrLmdkYS5wbC9pZHAvc2hp\nYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAaXFnZPlBAehUrHnfb3TU61b2J+y3\n8ng8l1tzFa/3g7aDTlYxVV9RHrz48mLt23n1LPz90wAixCQKgSqt3jaCqeH59Uaj\nxNUZwqDJJqRZB5a/7z6OEBSeQiKnc3H1PjgdrtgWPgEdvoC+ggGYsbitLdZ+455t\nDg/6nZ/C6vt40XtJyBMXB8HA4na6IXAFRzr++6QmG4ib8umoPS20cCT2sSUtpz7S\nh1QrFPZQWQRe67fPZlX2aOyu8h5OrEhGoyS95BW/2Hw+nWJFvkn5H12/YYW65qTJ\n/TMpaKEsJ2bRiqVKhW5kntRDcca3KqqIiZ+g4102DKmk44R/y8Yjk9BIxg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Academic Computer Center TASK in Gdansk"
          },
          {
            "lang": "pl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Centrum Informatyczne TASK w Gda\u0144sku"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.task.gda.pl"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Academic Computer Center TASK in Gdansk"
          },
          {
            "lang": "pl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Centrum Informatyczne TASK w Gda\u0144sku"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://grouper.its.uu.se/shibboleth",
    {
      "entity_id": "https://grouper.its.uu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://grouper.its.uu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://grouper.its.uu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://grouper.its.uu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://grouper.its.uu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://grouper.its.uu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://grouper.its.uu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Uppsala universitets IT-avdelnings interna Grouper"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The internal Grouper for the IT Department at Uppsala University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UU GROUPER"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UU GROUPER"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "lory.its.uu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJAL1RGIih2dp/MA0GCSqGSIb3DQEBBQUAMBkxFzAVBgNV\nBAMTDmxvcnkuaXRzLnV1LnNlMB4XDTEyMDIyMjE1MDgzOVoXDTIyMDIxOTE1MDgz\nOVowGTEXMBUGA1UEAxMObG9yeS5pdHMudXUuc2UwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQDfaJDQjzXaGpYLPN8oiu76Ck6yPiKT2mzXNLDC6gl6qcKd\nB8q7eBu7QW4/WqYD69XdhUkIiPiG1eNu1uXEuF/lBDmOGQ9O9sQoMOaNYWQofwtF\n6yKUgnm4T42rNHYZ5mGFt7RfH+380s+d2M7HMh+OApCbRuu5FMVyITKmtroTkYof\n+86LJDq7GzktkGaRHn+5mXDg201c5LsCfDG27V+eIAxjeN0a4BlAzNDwynmX7Tmq\nVacNvFdreBIAXjU4CNQ+fPccUd8Dyst0Bb2mPMCUqlyxn0cILDc+Q9Iv4KO7czoG\nXdkANIfqS7YWgaxtnBFVtu25vps/h8hihwE/RcobAgMBAAGjPDA6MBkGA1UdEQQS\nMBCCDmxvcnkuaXRzLnV1LnNlMB0GA1UdDgQWBBR7usKPvDlmkEuaKS1bVoLokZAx\n8zANBgkqhkiG9w0BAQUFAAOCAQEAJeHoL4LRFh2W5WUrLH6o2BjezwajXIZxNtHH\nOBIbdU6zGebAFVMd8ILlZJCWceOYb8aT2NpZsNBt6Of+bXRgT95vk8P3rgfghAAm\nm4RVMmI0E3Sg7upppdp0UvUdff/01QP4jMEif9zqO1CB8HwDe7qPd2zIlSg4hVXA\nVTYITlhc2HTLdhLLeqq2kkO8uoh7Deb2+om56Wq2UG8JFLDiwQuTiil9bmDs7635\nJ97muJOIk72pZ7M+z7aRmbGqaZmX7lVcn2ipqR01Wt86IncZ8N4+KHvL1bd8Ot+e\n0C2Qlb5+9FE8h6CiVCxRMBaxUsVFR6knlay131nUecMwLC3G7w=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=lory.its.uu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://grouper.its.uu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://grouper.its.uu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://grouper.its.uu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://grouper.its.uu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.phlu.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41 41 228 21 21"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "(Hotline)"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:informatikhotline@hslu.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hochschule Luzern - IT Services"
          }
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "(AAI Technician)"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@hslu.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hochschule Luzern - IT Services"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.phlu.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2016-03-03T15:20:29Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAMz6yMoxs++OMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC2lkcC5waGx1LmNoMB4XDTE0MDQxMTA4MjMwMloXDTE3MDQxMDA4MjMwMlow\nFjEUMBIGA1UEAxMLaWRwLnBobHUuY2gwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQDN8Hd2rr6FkYwObqy/Hech8EU5TAiPdel9S4aV4G8cTFpF6dCQyKs8\ntvQPMIz5rsQrtN7Hkf+Oeyy12hZsPDDBk7Y+UCGt4kFhqE1H9ZAlMRi1Ja1Gywdf\ncmZNLVgKgR+njH0AT3gFTjGae1X3Eg1wpbfg5ooJ3Ch8PHxCJsDNP4WgcX4AU+Ss\n1T/ZEzUqfmmqDpq10UPluFDgXujGlRwWqiC8oQGc2Z3PgpJnt8lxWMOhdPGgxEFv\n4TJxUAMyYve3lpkBGk8IN/LWkcsWa8cuks5LzQXralxRofbDFMm6IWdpnaxJ6iZm\nXxlgoU9Qaw+Vd7R0AZ9WsAy2rjkBuWNjAgMBAAGjXTBbMDoGA1UdEQQzMDGCC2lk\ncC5waGx1LmNohiJodHRwczovL2lkcC5waGx1LmNoL2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBSkYIdFzSjghnTX5XR6eSSUqOdeTTANBgkqhkiG9w0BAQUFAAOCAQEA\nB1dxA2mQJ6A4Pm5YJdWETk0TCbXKD10r1ymx8Hzj4Bn0NV56Mh6WwVRqdU0CQB+h\nO/hDRztPNkO3HAlMSUlRbYtoRJsAdR0GqQAjXmi6uBuTvi4I/XSwc/MZ+o92HY2c\ncoea/JiP9MbEBiuLjlzrNEamEdKLUkr7K6zSXjQJefN+7Gn4JwUf7ppMqtrSW+PI\nIjzb+o+OlesBN5vYLw/gdf7F2UBQGwTPw3sjkwb13E3w/9fEVIj6gVhj+LAHsXu2\nmZkGrkn8dxV7P3DW8tZZeobO1hevdx/r6POebiXSAWvC9sztV9c7XRv/+KDUrM0z\nUJeTOp8z5dn7ZqOHT7wP8w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "phlu.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.phlu.ch/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.phlu.ch/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.phlu.ch/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.phlu.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.phlu.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "phlu.ch"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.phlu.ch/ph-lucerne/"
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.phlu.ch"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "P\u00e4dagogische Hochschule Luzern"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Teacher Education Lucerne"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAAXNSR0IArs4c6QAAAARnQU1BAACxjwv8YQUAAAAJcEhZcwAADsQAAA7EAZUrDhsAAAB2SURBVDhPnczbCYAwDIXhLuebU/ngGkUXaUHco91CEIkcEPGStkl+OE8Jn0vB0zJ05rlj3yjHmT1K5ugqx4l9aO0GkAV5AUiL/ACkQVgASZEigCRIFUAtpAmgGiICUAkRA4hDVAD6ImoAPRETgICsY28HUAqeToLAQo/m8xMUAAAAAElFTkSuQmCC",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "33",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PHLU - P\u00e4dagogische Hochschule Luzern"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PHLU - University of Teacher Education Lucerne"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "phlu.ch"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.051064,8.302218"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAMz6yMoxs++OMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC2lkcC5waGx1LmNoMB4XDTE0MDQxMTA4MjMwMloXDTE3MDQxMDA4MjMwMlow\nFjEUMBIGA1UEAxMLaWRwLnBobHUuY2gwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQDN8Hd2rr6FkYwObqy/Hech8EU5TAiPdel9S4aV4G8cTFpF6dCQyKs8\ntvQPMIz5rsQrtN7Hkf+Oeyy12hZsPDDBk7Y+UCGt4kFhqE1H9ZAlMRi1Ja1Gywdf\ncmZNLVgKgR+njH0AT3gFTjGae1X3Eg1wpbfg5ooJ3Ch8PHxCJsDNP4WgcX4AU+Ss\n1T/ZEzUqfmmqDpq10UPluFDgXujGlRwWqiC8oQGc2Z3PgpJnt8lxWMOhdPGgxEFv\n4TJxUAMyYve3lpkBGk8IN/LWkcsWa8cuks5LzQXralxRofbDFMm6IWdpnaxJ6iZm\nXxlgoU9Qaw+Vd7R0AZ9WsAy2rjkBuWNjAgMBAAGjXTBbMDoGA1UdEQQzMDGCC2lk\ncC5waGx1LmNohiJodHRwczovL2lkcC5waGx1LmNoL2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBSkYIdFzSjghnTX5XR6eSSUqOdeTTANBgkqhkiG9w0BAQUFAAOCAQEA\nB1dxA2mQJ6A4Pm5YJdWETk0TCbXKD10r1ymx8Hzj4Bn0NV56Mh6WwVRqdU0CQB+h\nO/hDRztPNkO3HAlMSUlRbYtoRJsAdR0GqQAjXmi6uBuTvi4I/XSwc/MZ+o92HY2c\ncoea/JiP9MbEBiuLjlzrNEamEdKLUkr7K6zSXjQJefN+7Gn4JwUf7ppMqtrSW+PI\nIjzb+o+OlesBN5vYLw/gdf7F2UBQGwTPw3sjkwb13E3w/9fEVIj6gVhj+LAHsXu2\nmZkGrkn8dxV7P3DW8tZZeobO1hevdx/r6POebiXSAWvC9sztV9c7XRv/+KDUrM0z\nUJeTOp8z5dn7ZqOHT7wP8w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "error_url": "http://hotline.hslu.ch"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PHLU - P\u00e4dagogische Hochschule Luzern"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PHLU - University of Teacher Education Lucerne"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.phlu.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.phlu.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "phlu.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.llandrillo.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.llandrillo.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/llandrillo.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/llandrillo.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "llandrillo.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Grwp Llandrillo Menai"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.llandrillo.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://testshib.msacademicverify.com/shibboleth-sp",
    {
      "entity_id": "https://testshib.msacademicverify.com/shibboleth-sp",
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Gerry.OBrien@microsoft.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gerry O'Brien"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Jhansi.reddy@microsoft.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jhansi Reddy"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Microsoft"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.microsoft.com/en/us/default.aspx"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Microsoft"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Microsoft Academic Verification Engine"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIJAJh4QX82u2pTMA0GCSqGSIb3DQEBBQUAMCgxJjAkBgNV\nBAMTHXRlc3RzaGliLm1zYWNhZGVtaWN2ZXJpZnkuY29tMB4XDTEzMDMyNjEzMTIw\nN1oXDTE2MDMyNTEzMTIwN1owKDEmMCQGA1UEAxMddGVzdHNoaWIubXNhY2FkZW1p\nY3ZlcmlmeS5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCsLIq+\nKl9aCXy3gkjyDv1YWqWVL3c6S+G5aCnCwtlbwU9q5R9lo7r5pjxScujS+kwRRYfO\nKJ5jg6M6T1oZOEkcMjAcx0hF5fat7a3z02zvL4eaZcZAnd4Jrn8xizKX363lE+mj\nNGu38+xpEyknMNpybsFeqA9S+tbZDteMihHi4x+rkis5Cno9m4OXEN3fGrl6sa2L\n+d5XHH/IlUa0LA0cpKP8ONMYNR4g+7lUy+SHuo9iQJZesEX16cCMNkbknNuexRH+\n2FhGx3q6WB87KhgLjpdmb5ZPcPFAbdZSrbpZTMny2RDFMbpyQefYEMYlTETYwJ4S\n3sSa4EhqIbri+CZzAgMBAAGjgYAwfjBdBgNVHREEVjBUgh10ZXN0c2hpYi5tc2Fj\nYWRlbWljdmVyaWZ5LmNvbYYzaHR0cHM6Ly90ZXN0c2hpYi5tc2FjYWRlbWljdmVy\naWZ5LmNvbS9zaGliYm9sZXRoLXNwMB0GA1UdDgQWBBQKuJJcwHX2m6nuzSaqFlE9\nNdEF/jANBgkqhkiG9w0BAQUFAAOCAQEAIUWZZuPR/N4BY2LeeHKQ5GCArl7ZPM50\n6Znt2T7vw/D6JKNmUx1v9PVyt4GzleFCrWhWgX4mKlUfrT1EcGYblKj6YUKErERk\npRbaJp8mZ/X5Ugi00lpv0GlNtdvvrYv5R1V5wTUSyLd6L+Ci3jhhugkd5cTL3ttk\ns/JNkMFd0eHEeJKi2jcI1jrhF9aWncdGup/MNdm0wPxmtnoylkuXUY0CIlmMYuas\nZCjBzPpPM2QIOXiuXypVLjuP32AirgS8h/uL+mY4z8pv68loW8C0ulYqmj6lPjDR\nwWE+vceD2r7oFUYHr1E07cyX20HwNU1LL3TthPaNhs7M2ImLlYHapw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://testshib.msacademicverify.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://testshib.msacademicverify.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://testshib.msacademicverify.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://testshib.msacademicverify.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://testshib.msacademicverify.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://testshib.msacademicverify.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Microsoft Academic Verification Engine"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.havant.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.havant.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/havant.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/havant.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "havant.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Havant College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.havant.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://graduateland.com/simplesaml/module.php/saml/sp/metadata.php/gl_gateway",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Petersen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "morten@graduateland.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Morten"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://graduateland.com/simplesaml/module.php/saml/sp/metadata.php/gl_gateway",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "http://graduateland.com/simplesaml/module.php/saml/sp/saml2-logout.php/gl_gateway",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://graduateland.com/simplesaml/module.php/saml/sp/saml2-acs.php/gl_gateway",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "http://graduateland.com/simplesaml/module.php/saml/sp/saml1-acs.php/gl_gateway",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "http://graduateland.com/simplesaml/module.php/saml/sp/saml2-acs.php/gl_gateway",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "http://graduateland.com/simplesaml/module.php/saml/sp/saml1-acs.php/gl_gateway/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.univ-paris4.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "MARIR Brahim"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "brahim.marir@paris-sorbonne.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.univ-paris4.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2010-03-15T16:19:04Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univ-paris4.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univ-paris4.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.univ-paris4.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "paris-sorbonne.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-paris4.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.paris-sorbonne.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Paris IV - Sorbonne"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Paris IV - Sorbonne"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfjCCA2agAwIBAgIQDoytgyQXDrxQwdffQSgBNTANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEwMDIxOTAwMDAwMFoXDTEzMDIxODIzNTk1OVowVzELMAkGA1UE\nBhMCRlIxDjAMBgNVBAcTBVBBUklTMRswGQYDVQQKExJVTklWRVJTSVRFIFBBUklT\nIDQxGzAZBgNVBAMTEmlkcC51bml2LXBhcmlzNC5mcjCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAKqttSIJz1BQxcIHy3dNdnJd+0iaQlWU31Y2zsGckNjR\nYbW4lwMq5xcnqHwrgUp8PiaFBy6/jioXDpHs5ByrrLLE052hfeEB0W5AO5mN7Yqd\nURorS4LHo9JsUFrULl0haEF6FFoDD6ABR7djwerDccIebVoICvj9W1ypN8vPmo/P\nqaXZ0QKcJJjmbuxYxt+JnYQyQhqxZXgbGfelyclhfrCNZsjFmoLL2hvpIINAv3Al\n7xFBv1DlKpRImWAjHkqZtWzyGHNU3EryVBrjeoxlRQfVjCMqTnZ5O57bTZc7TK5Y\neMlvB0syEnzC68HJ02baPgf1T94S2gD3nvFjfcNcJu8CAwEAAaOCAWUwggFhMB8G\nA1UdIwQYMBaAFAy9k2gM896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBQ+ho3P8U/1\n4zqg7ukFkfl9eCelZDAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNV\nHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwGAYDVR0gBBEwDzANBgsrBgEEAbIx\nAQICHTA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3Jn\nL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0\ndHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUF\nBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJpZHAu\ndW5pdi1wYXJpczQuZnIwDQYJKoZIhvcNAQEFBQADggEBAHwUYz+yFi2FBkcFN3Km\n2qfIfiBsLFWB6IfkmQ67R1grVxUSlRIIyJ7L4IWrnzlSfua51Z8UJPvcu69n9eBX\nqZziEXS4ZAlDKF7w3eLV8lIy3PX35/k6MQeju9XutriZXn/d6j7tN3sn7hYp+2i3\n+FffOhUyk30j9dUG3P17NpJBQ8vWjily3GNDwcjkZhWnoNLy23BssXqN7vkrc/8k\nLsZ2ycJNxU+3DFaLplq4s2S7llycn+QoR2FGFQYbRxEIkEExzPEjcoHxO9Z9NWiX\nmWTayZwzt0iJJtgUTa8Lr+vSHx2pY70ZHgzsmbwKd1gEn1+u7ltx/5nUar5lRokB\nbz0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Paris IV - Sorbonne"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.paris-sorbonne.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Paris IV - Sorbonne"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://incommon.sunycnse.com/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "krosher@sunycnse.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kyle Rosher"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rgartner@sunycnse.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ralph Gartner"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "krosher@sunycnse.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kyle Rosher"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "krosher@sunycnse.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kyle Rosher"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://incommon.sunycnse.com/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://incommon.sunycnse.com/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://incommon.sunycnse.com/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://incommon.sunycnse.com/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://incommon.sunycnse.com:443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://incommon.sunycnse.com:443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sunycnse.com"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SUNY Polytechnic Institute"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUNlPRT/wyMz9vjHRYl0MkLeoK0zwwDQYJKoZIhvcNAQEF\nBQAwJTEjMCEGA1UEAwwaaW5jb21tb24udW5pdi5zdW55Y25zZS5jb20wHhcNMTQw\nOTI5MTczNDQzWhcNMzQwOTI5MTczNDQzWjAlMSMwIQYDVQQDDBppbmNvbW1vbi51\nbml2LnN1bnljbnNlLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAIT0Usp7YH9IFLQL5xKeRxHTpej08j6tuqXCCpj8RarjFbcrDraC09npHqWeutTz\nUyvMNea69E+UAn28uzg2ftsMX15Nrb+LCYPEGnqtsrabwgGXHewr7nf8WyPdjcWC\nDBhFcDAqhLjUHGhBGx4NhD/a6BYWKXHjAolgopZOwWvSR1FYgQUQjT7R83g407c/\n6L26FDAqxEufkg4x4TwihBRoC3j8kV6dyuz7tlzMAyAlRXnq3JuYTvEeNlDY5FxJ\ncxWPuNB4WSJKTiAzB9qavI6qUQUABgPHD0d6qYZg07UCIUm8k3bJU0J3M9fAsbXG\n0i0KS6iLN3gzsoGCrc7sRT0CAwEAAaN7MHkwHQYDVR0OBBYEFGcvUxpFLbbgtsle\ns4lFedorhKjAMFgGA1UdEQRRME+CGmluY29tbW9uLnVuaXYuc3VueWNuc2UuY29t\nhjFodHRwczovL2luY29tbW9uLnVuaXYuc3VueWNuc2UuY29tL2lkcC9zaGliYm9s\nZXRoMA0GCSqGSIb3DQEBBQUAA4IBAQByJw4667jgC8l27quq1YCeukkkMuMj/46n\nl688gKpD4PL6nDKQzeHlUXUC8js7dmDrfuK+F/eRlPo4QOadf0wO2h4PdzxPJzV6\ncdwQaLf7ZdiHNlG+WIgfSbzurEEESk35DVsNxtriHyeHU+7tcpfqjEMAP2K7sZHv\nCghk6dXYhVpYc5fakaOcDNM7tIsG9AfPL37Piisn1eg5BNuHb6TzthxbJW8gq9Q5\nX/5/NVPkxIZlwfd1UUjHO0T0OrkWTgIsesPGvBkRIJO6hUmSUI6YZHA5FmSEVYB1\nBvvZMKZ3B0ygTK7PIe0RRTPUMFgtZNMUNNgqywHDyDbt+y+REp9K"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SUNY Polytechnic Institute"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sunyit.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SUNY Polytechnic Institute"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://mds-test.sunet.se/shibboleth",
    {
      "entity_id": "https://mds-test.sunet.se/shibboleth",
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish University Network (SUNET)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sunet.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SUNET"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mds-test.sunet.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mds-test.sunet.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mds-test.sunet.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mds-test.sunet.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mds-test.sunet.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://mds-test.sunet.se/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://mds-test.sunet.se/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "mds-test.sunet.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDTCCAfWgAwIBAgIJAM5Yhbpd3TmcMA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\nBAMTEW1kcy10ZXN0LnN1bmV0LnNlMB4XDTExMTExNzE0NTUyMVoXDTIxMTExNDE0\nNTUyMVowHDEaMBgGA1UEAxMRbWRzLXRlc3Quc3VuZXQuc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDCqEcLC0Zdpy/RH2bhjc149216gnMdiz1q8agv\neZNbww+9f6DNvQzevyr1U7nnKzY3mZRsMoLXCbgYSfe7d7GXv/fRyx3Nx9g1sG5F\nC3ydosS2/1aWWLwMjFRYr/QIqTZa7ihWLQhetJ+dObCGPO43PmIC0fIvBUJ/KX7B\nDJXNKbA+PR2Xyiavv153DoT46/KVsPIgkCMlMTltLUB5030Bm3IwMs+sHFhnVx8Y\nTZ7phNR7kGrgmody+YIvoAz4vtuuvlPHO8l0d3HTO4M9Z4H7OufTN6ivxdPIcfsn\nz0baiuQpWziayeeAHrLwC09RS3FMFeadR5ZTcDW0eY0ralsNAgMBAAGjUjBQMC8G\nA1UdEQQoMCaCEW1kcy10ZXN0LnN1bmV0LnNlhhFtZHMtdGVzdC5zdW5ldC5zZTAd\nBgNVHQ4EFgQUokBRRHpa+5pznLea5K03GSgBG80wDQYJKoZIhvcNAQEFBQADggEB\nAAEucvMd1uSQnSDcMkd9jVS9rtTy9R32Zik2OWjYzW6HbM2/8jU7XFscqlgmunuA\n0+k3i9BtmSc+SbI3n3QejeUleINWah19CJ+VdKUJGN9GKiGPaK3EGz8OLqhXHIpN\nHGCYy1/df0OtdqptbrRiVMlqXIBJhLmenczTb9fw6ercngudu3ftIu2/+85ZER3p\notlxWXhbXhBVUmi89hDXmtUL4ulDy3Ufx1zAtuxf5CWTmMQukSSSg2m+QYraFyPL\nZNCOgNyiOFcrqr9kcDc2fsyVUlAKmm/sG2P+mCEj/zRhLCpUWbG2vg3r84H3lNKv\nVtHMCV6pEmWvRxvRGMxUfw8="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=mds-test.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mds-test.sunet.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mds-test.sunet.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mds-test.sunet.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mds-test.sunet.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mds-test.sunet.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://mds-test.sunet.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mds-test.sunet.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://mds-test.sunet.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://mds-test.sunet.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://mds-test.sunet.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://www.clarin-pl.eu/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pol"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:marcin.pol@pwr.edu.pl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marcin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pol"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dspace@clarin-pl.eu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marcin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pol"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dspace@clarin-pl.eu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marcin"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://www.clarin-pl.eu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-06-15T16:33:40Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://clarin.eu/category/clarin-member"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://clarin-pl.eu/shibboleth/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://clarin-pl.eu/shibboleth/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://clarin-pl.eu/shibboleth/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://clarin-pl.eu/shibboleth/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://clarin-pl.eu/shibboleth/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://clarin-pl.eu/en/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CLARIN-PL Repository"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CLARIN-PL repository"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CLARIN-PL digitales Langzeitarchiv - Polnische Sektion des CLARIN ERIC"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CLARIN-PL digital repository - Polish section of CLARIN ERIC"
                  }
                ],
                "logo": [
                  {
                    "text": "https://clarin-pl.eu/dspace/themes/ClarinPlHomeTheme/images/favicon.ico",
                    "height": "32",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "32"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://clarin-pl.eu/en/privacy-policy/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.clarin-pl.eu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIJAJY4k9BoCNIOMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEHd3dy5jbGFyaW4tcGwuZXUwHhcNMTQwMTA5MTA0ODE2WhcNMTcwMTA4MTA0\nODE2WjAbMRkwFwYDVQQDExB3d3cuY2xhcmluLXBsLmV1MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAvBHhZZZVue2D/m6KEnfbL/wufElA6XgLs0SqfGMh\nVILjElWD80BG7KElkqQxrwEBf09i+z9nBbZARvVi9JnonuCa6+rHIz3e6/IoXKrA\njRlUJcUJp0FKLYmG+WlTWUNO+y2OtSWWMSe7ZeHnxDkRYXwY3lLXniOClXhdplso\nvVc3u2BjUXPH0zCVn7ajU7IczsemoA6iy2JFKHACC4OTDxFGUPEUK0mRjyd8Ovyx\nKh3QdkPrUpHZ/6aBnmiztYV1wa3mZTtk3TOrxdA+/+x4UodG6K/WSo3TIs5h9s/4\nc9IZyfi/8q9V3EODO8IBTCM+zDZ8fm7g1VJ9CYFEs8et/QIDAQABo2MwYTBABgNV\nHREEOTA3ghB3d3cuY2xhcmluLXBsLmV1hiNodHRwczovL3d3dy5jbGFyaW4tcGwu\nZXUvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUx34UwYpPZgJBTVqSl3Xfn/d+XrEwDQYJ\nKoZIhvcNAQEFBQADggEBAFwYzUrC7K9CpxBpnD6WjqyKiMoSR+vnoZZq3+ZUiG/O\nuwiTwcErddkQLonV9L2eSuY6NQn+aFebaozIS/Zj5yXjwDo8fGEKSk4tSVUc4H+f\nRML3XnJ25XmaSi2myy5PIh97o/NZAil8/1ArHV4PGNzMic1UNzmZymzB6AdmOrVn\nW3DPk2honcInege0lU7RLULmgdtMVl/QCbEWDrJ8oq0bxYwoFrVCnZXFM7SHqEba\nW7A4zk79hxNAxNoqlUSnX0Tk2fQQXdSTjLXEF9WLUwfW86QlQdLLkaY9hco+w8NM\nSvKPZd5tNDWO1hE00kzKJDPhhJZs1wFS7Tf3SJ1M1D8="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.clarin-pl.eu"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://clarin-pl.eu/shibboleth/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://clarin-pl.eu/shibboleth/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://clarin-pl.eu/shibboleth/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://clarin-pl.eu/shibboleth/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://clarin-pl.eu/shibboleth/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://clarin-pl.eu/shibboleth/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CLARIN-PL Repository"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CLARIN-PL repository"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "CLARIN-PL digitales Langzeitarchiv - Polnische Sektion des CLARIN ERIC"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "CLARIN-PL digital repository - Polish section of CLARIN ERIC"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp4.halesowen.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Crees"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tcrees@halesowen.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Priest"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jpriest@halesowen.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jonathan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp4.halesowen.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-06-07T09:48:34Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUK9oe82/zsqUqklJuya/xb+7Fj7swDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAxMUaWRwNC5oYWxlc293ZW4uYWMudWswHhcNMTIwNjA2MDky\n\t\t\t\t\t\tNjQ4WhcNMzIwNjA2MDkyNjQ4WjAfMR0wGwYDVQQDExRpZHA0LmhhbGVzb3dlbi5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ2STl9SssEcCIdJ\n\t\t\t\t\t\tTOOLkqRtw7yeG3rQMdqUS7cKflWKfxoXwxLlSs0RJTPO2HubTUuzENfE2XF96gE+\n\t\t\t\t\t\tVfZSDN+R2hKJvTUFlt49YN7Wfu8bUDeVAiLbv1eVs9syHtMQEa7CtFXssrXuQxJ6\n\t\t\t\t\t\tiGA7eeL9llbnN4WoGsDNUIYrkKrKo25hPkiFgkxXGFr4IcnJAO4Ftjvu0m/v0YQL\n\t\t\t\t\t\tJGbHeCSwOL3/giBUHQsTQLxzPibc1rfVZv7r3ZdF4QMivb93nxKjO1WNtAH/9YRZ\n\t\t\t\t\t\tBbGknDfG5QeFCNFqIRPSeO98U0/WSwK/+Rz05xSEdHp8rWIEpwNuUpPQjUYg+QDm\n\t\t\t\t\t\tCrlEAPUCAwEAAaNvMG0wTAYDVR0RBEUwQ4IUaWRwNC5oYWxlc293ZW4uYWMudWuG\n\t\t\t\t\t\tK2h0dHBzOi8vaWRwNC5oYWxlc293ZW4uYWMudWsvaWRwL3NoaWJib2xldGgwHQYD\n\t\t\t\t\t\tVR0OBBYEFHJgh1AYz5+Z2R0MUD13TjbR55T1MA0GCSqGSIb3DQEBBQUAA4IBAQAz\n\t\t\t\t\t\t+5Fks4TIm7jqC4pEP7rjaugHhh6eZfvpcpOcyu3W0LdSrJIKCEn+3qRJZ+g/7OFX\n\t\t\t\t\t\tHLwytVyzttZlLqkErt0YqD/T721wn6Jl2DNzzX/v0a9ZOsoc31VyF5/QSX7uemK7\n\t\t\t\t\t\tnMNDB9tIa5f8vFQfhm1NV+ylIklSs2grP7V4bwggOQLiHfHIYW+E+Jza8QonqLjO\n\t\t\t\t\t\tfUPwUBv6HaTHNbY7emeX8d6vb9mURX5kiPlel75zRuSDe3j2XaBNdzJ6djtWPMqa\n\t\t\t\t\t\t5nzipbC1Y36S60xTelCkQz/bkQxdhGpeXAyGcjmVKESSPY5ZhIhQ5wIsD/HJhSCx\n\t\t\t\t\t\tqdnuw21SDaBFMMFsh10J"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "halesowen.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp4.halesowen.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp4.halesowen.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp4.halesowen.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp4.halesowen.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp4.halesowen.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp4.halesowen.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp4.halesowen.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp4.halesowen.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "halesowen.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUK9oe82/zsqUqklJuya/xb+7Fj7swDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAxMUaWRwNC5oYWxlc293ZW4uYWMudWswHhcNMTIwNjA2MDky\n\t\t\t\t\t\tNjQ4WhcNMzIwNjA2MDkyNjQ4WjAfMR0wGwYDVQQDExRpZHA0LmhhbGVzb3dlbi5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ2STl9SssEcCIdJ\n\t\t\t\t\t\tTOOLkqRtw7yeG3rQMdqUS7cKflWKfxoXwxLlSs0RJTPO2HubTUuzENfE2XF96gE+\n\t\t\t\t\t\tVfZSDN+R2hKJvTUFlt49YN7Wfu8bUDeVAiLbv1eVs9syHtMQEa7CtFXssrXuQxJ6\n\t\t\t\t\t\tiGA7eeL9llbnN4WoGsDNUIYrkKrKo25hPkiFgkxXGFr4IcnJAO4Ftjvu0m/v0YQL\n\t\t\t\t\t\tJGbHeCSwOL3/giBUHQsTQLxzPibc1rfVZv7r3ZdF4QMivb93nxKjO1WNtAH/9YRZ\n\t\t\t\t\t\tBbGknDfG5QeFCNFqIRPSeO98U0/WSwK/+Rz05xSEdHp8rWIEpwNuUpPQjUYg+QDm\n\t\t\t\t\t\tCrlEAPUCAwEAAaNvMG0wTAYDVR0RBEUwQ4IUaWRwNC5oYWxlc293ZW4uYWMudWuG\n\t\t\t\t\t\tK2h0dHBzOi8vaWRwNC5oYWxlc293ZW4uYWMudWsvaWRwL3NoaWJib2xldGgwHQYD\n\t\t\t\t\t\tVR0OBBYEFHJgh1AYz5+Z2R0MUD13TjbR55T1MA0GCSqGSIb3DQEBBQUAA4IBAQAz\n\t\t\t\t\t\t+5Fks4TIm7jqC4pEP7rjaugHhh6eZfvpcpOcyu3W0LdSrJIKCEn+3qRJZ+g/7OFX\n\t\t\t\t\t\tHLwytVyzttZlLqkErt0YqD/T721wn6Jl2DNzzX/v0a9ZOsoc31VyF5/QSX7uemK7\n\t\t\t\t\t\tnMNDB9tIa5f8vFQfhm1NV+ylIklSs2grP7V4bwggOQLiHfHIYW+E+Jza8QonqLjO\n\t\t\t\t\t\tfUPwUBv6HaTHNbY7emeX8d6vb9mURX5kiPlel75zRuSDe3j2XaBNdzJ6djtWPMqa\n\t\t\t\t\t\t5nzipbC1Y36S60xTelCkQz/bkQxdhGpeXAyGcjmVKESSPY5ZhIhQ5wIsD/HJhSCx\n\t\t\t\t\t\tqdnuw21SDaBFMMFsh10J"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Halesowen College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.halesowen.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Halesowen College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.its.fz-juelich.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Heidb\u00fcchel"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:j.heidbuechel@fz-juelich.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jens"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Heidb\u00fcchel"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:j.heidbuechel@fz-juelich.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jens"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Forschungszentrum J\u00fclich GmbH"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it-services@fz-juelich.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ITS Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.its.fz-juelich.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2010-08-13T10:04:08Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.its.fz-juelich.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF5TCCBM2gAwIBAgIHGFschQrLkzANBgkqhkiG9w0BAQsFADCBgzELMAkGA1UE\nBhMCREUxJzAlBgNVBAoTHkZvcnNjaHVuZ3N6ZW50cnVtIEp1ZWxpY2ggR21iSDEq\nMCgGA1UEAxMhRlpKIENlcnRpZmljYXRpb24gQXV0aG9yaXR5IC0gRzAyMR8wHQYJ\nKoZIhvcNAQkBFhBjYUBmei1qdWVsaWNoLmRlMB4XDTE0MTAxMzA5NDQyMVoXDTE5\nMDcwOTIzNTkwMFowga4xCzAJBgNVBAYTAkRFMRwwGgYDVQQIExNOb3JkcmhlaW4t\nV2VzdGZhbGVuMRAwDgYDVQQHEwdKdWVsaWNoMScwJQYDVQQKEx5Gb3JzY2h1bmdz\nemVudHJ1bSBKdWVsaWNoIEdtYkgxHjAcBgNVBAMTFWlkcC5pdHMuZnotanVlbGlj\naC5kZTEmMCQGCSqGSIb3DQEJARYXd2VibWFzdGVyQGZ6LWp1ZWxpY2guZGUwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC5t9fIu0COttZeG5Xo6y/zqMfv\nvIwH5FNJaX0kelKKx49rxcxUxbt2gOEcrAemc+KMsTI4xmOSEzJIkInQUoXXkAkR\nqI7KaUZ/ZzZFLiIdVT7DdTx1cQkzj6Q/yDZA9vv/yHTocq66ujPJZngtemu7PWWo\nnqxd11bkMuCbFOsWUhZ8tTCwiDAOdpXCZH+mqLZCSNu2cr55zO+bHdHlQegOrPeF\n8/GDyMtPVk9ByPcW9msCAhiKsGGYU85Q650/IO6IIDZddCwr1zHNu+QeO/4U52Kg\nA2PWoxBsr2VTqfJPDQBupxm1nuxjL89UnRYqmI4WxcTCtP7abFlsGSEjMrkJAgMB\nAAGjggIvMIICKzBPBgNVHSAESDBGMBEGDysGAQQBga0hgiwBAQQDAjARBg8rBgEE\nAYGtIYIsAgEEAwEwDwYNKwYBBAGBrSGCLAEBBDANBgsrBgEEAYGtIYIsHjAJBgNV\nHRMEAjAAMAsGA1UdDwQEAwIE8DATBgNVHSUEDDAKBggrBgEFBQcDATAdBgNVHQ4E\nFgQUNlyp1PKKm1tbM/BJ6zblU9W9IocwHwYDVR0jBBgwFoAUIL1xiaXJKjMvEeAf\n5ZQmVg8RAiUwIAYDVR0RBBkwF4IVaWRwLml0cy5mei1qdWVsaWNoLmRlMHsGA1Ud\nHwR0MHIwN6A1oDOGMWh0dHA6Ly9jZHAxLnBjYS5kZm4uZGUvZnpqLWNhL3B1Yi9j\ncmwvZ19jYWNybC5jcmwwN6A1oDOGMWh0dHA6Ly9jZHAyLnBjYS5kZm4uZGUvZnpq\nLWNhL3B1Yi9jcmwvZ19jYWNybC5jcmwwgcsGCCsGAQUFBwEBBIG+MIG7MDMGCCsG\nAQUFBzABhidodHRwOi8vb2NzcC5wY2EuZGZuLmRlL09DU1AtU2VydmVyL09DU1Aw\nQQYIKwYBBQUHMAKGNWh0dHA6Ly9jZHAxLnBjYS5kZm4uZGUvZnpqLWNhL3B1Yi9j\nYWNlcnQvZ19jYWNlcnQuY3J0MEEGCCsGAQUFBzAChjVodHRwOi8vY2RwMi5wY2Eu\nZGZuLmRlL2Z6ai1jYS9wdWIvY2FjZXJ0L2dfY2FjZXJ0LmNydDANBgkqhkiG9w0B\nAQsFAAOCAQEAjQatrjj9D0sreu0Dj3GsN3NLBiBxwTxyRAApzAiZuGu1960JhtvL\nDsnGukFCe++xd6qco82ZIrwCWrbjK2SQoAexiQqH4TXWqQaPcIr8zDwj0WKv63mN\nLhzmBIePWsND5pIb6qS3a4RvRK9u9BViQllWSQYUlkBNoA8HtulmqNkgVCgt7De9\nZhDGRZAiGhA+N67ts/h9zW6fT6SqHgCgcTSG6mVSMX2ZR9XTocoAXCfwEV7VkGl7\nL9aUnCact8MBZGMgWHR8NVFyhEofMTBIiXwGawBgzB+bU/xOcBp/3ulxy2K3mfEK\nWsS4+1PQhtDqnQMdqkPWm1zlseEGiXqFtw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=webmaster@fz-juelich.de,CN=idp.its.fz-juelich.de,O=Forschungszentrum Juelich GmbH,L=Juelich,ST=Nordrhein-Westfalen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fz-juelich.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.its.fz-juelich.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.its.fz-juelich.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.its.fz-juelich.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.its.fz-juelich.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.its.fz-juelich.de/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.its.fz-juelich.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.its.fz-juelich.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.its.fz-juelich.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fz-juelich.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.fz-juelich.de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.fz-juelich.de"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity-Provider der Forschungszentrum J\u00fclich GmbH"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity-Provider der Forschungszentrum J\u00fclich GmbH"
                  }
                ],
                "logo": [
                  {
                    "text": "https://apps.fz-juelich.de/logos/Juelich-J-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://apps.fz-juelich.de/logos/Logo_FZ_Juelich_350x114.png",
                    "height": "114",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Forschungszentrum J\u00fclich GmbH"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Forschungszentrum J\u00fclich GmbH"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.its.fz-juelich.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF5TCCBM2gAwIBAgIHGFschQrLkzANBgkqhkiG9w0BAQsFADCBgzELMAkGA1UE\nBhMCREUxJzAlBgNVBAoTHkZvcnNjaHVuZ3N6ZW50cnVtIEp1ZWxpY2ggR21iSDEq\nMCgGA1UEAxMhRlpKIENlcnRpZmljYXRpb24gQXV0aG9yaXR5IC0gRzAyMR8wHQYJ\nKoZIhvcNAQkBFhBjYUBmei1qdWVsaWNoLmRlMB4XDTE0MTAxMzA5NDQyMVoXDTE5\nMDcwOTIzNTkwMFowga4xCzAJBgNVBAYTAkRFMRwwGgYDVQQIExNOb3JkcmhlaW4t\nV2VzdGZhbGVuMRAwDgYDVQQHEwdKdWVsaWNoMScwJQYDVQQKEx5Gb3JzY2h1bmdz\nemVudHJ1bSBKdWVsaWNoIEdtYkgxHjAcBgNVBAMTFWlkcC5pdHMuZnotanVlbGlj\naC5kZTEmMCQGCSqGSIb3DQEJARYXd2VibWFzdGVyQGZ6LWp1ZWxpY2guZGUwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC5t9fIu0COttZeG5Xo6y/zqMfv\nvIwH5FNJaX0kelKKx49rxcxUxbt2gOEcrAemc+KMsTI4xmOSEzJIkInQUoXXkAkR\nqI7KaUZ/ZzZFLiIdVT7DdTx1cQkzj6Q/yDZA9vv/yHTocq66ujPJZngtemu7PWWo\nnqxd11bkMuCbFOsWUhZ8tTCwiDAOdpXCZH+mqLZCSNu2cr55zO+bHdHlQegOrPeF\n8/GDyMtPVk9ByPcW9msCAhiKsGGYU85Q650/IO6IIDZddCwr1zHNu+QeO/4U52Kg\nA2PWoxBsr2VTqfJPDQBupxm1nuxjL89UnRYqmI4WxcTCtP7abFlsGSEjMrkJAgMB\nAAGjggIvMIICKzBPBgNVHSAESDBGMBEGDysGAQQBga0hgiwBAQQDAjARBg8rBgEE\nAYGtIYIsAgEEAwEwDwYNKwYBBAGBrSGCLAEBBDANBgsrBgEEAYGtIYIsHjAJBgNV\nHRMEAjAAMAsGA1UdDwQEAwIE8DATBgNVHSUEDDAKBggrBgEFBQcDATAdBgNVHQ4E\nFgQUNlyp1PKKm1tbM/BJ6zblU9W9IocwHwYDVR0jBBgwFoAUIL1xiaXJKjMvEeAf\n5ZQmVg8RAiUwIAYDVR0RBBkwF4IVaWRwLml0cy5mei1qdWVsaWNoLmRlMHsGA1Ud\nHwR0MHIwN6A1oDOGMWh0dHA6Ly9jZHAxLnBjYS5kZm4uZGUvZnpqLWNhL3B1Yi9j\ncmwvZ19jYWNybC5jcmwwN6A1oDOGMWh0dHA6Ly9jZHAyLnBjYS5kZm4uZGUvZnpq\nLWNhL3B1Yi9jcmwvZ19jYWNybC5jcmwwgcsGCCsGAQUFBwEBBIG+MIG7MDMGCCsG\nAQUFBzABhidodHRwOi8vb2NzcC5wY2EuZGZuLmRlL09DU1AtU2VydmVyL09DU1Aw\nQQYIKwYBBQUHMAKGNWh0dHA6Ly9jZHAxLnBjYS5kZm4uZGUvZnpqLWNhL3B1Yi9j\nYWNlcnQvZ19jYWNlcnQuY3J0MEEGCCsGAQUFBzAChjVodHRwOi8vY2RwMi5wY2Eu\nZGZuLmRlL2Z6ai1jYS9wdWIvY2FjZXJ0L2dfY2FjZXJ0LmNydDANBgkqhkiG9w0B\nAQsFAAOCAQEAjQatrjj9D0sreu0Dj3GsN3NLBiBxwTxyRAApzAiZuGu1960JhtvL\nDsnGukFCe++xd6qco82ZIrwCWrbjK2SQoAexiQqH4TXWqQaPcIr8zDwj0WKv63mN\nLhzmBIePWsND5pIb6qS3a4RvRK9u9BViQllWSQYUlkBNoA8HtulmqNkgVCgt7De9\nZhDGRZAiGhA+N67ts/h9zW6fT6SqHgCgcTSG6mVSMX2ZR9XTocoAXCfwEV7VkGl7\nL9aUnCact8MBZGMgWHR8NVFyhEofMTBIiXwGawBgzB+bU/xOcBp/3ulxy2K3mfEK\nWsS4+1PQhtDqnQMdqkPWm1zlseEGiXqFtw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=webmaster@fz-juelich.de,CN=idp.its.fz-juelich.de,O=Forschungszentrum Juelich GmbH,L=Juelich,ST=Nordrhein-Westfalen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Forschungszentrum J\u00fclich GmbH"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Forschungszentrum J\u00fclich GmbH"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fz-juelich.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fz-juelich.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e234"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e234"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://fid.mnhn.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "zyxad@mnhn.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://fid.mnhn.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-12-31T13:57:42Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://fid.mnhn.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://fid.mnhn.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://fid.mnhn.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mnhn.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mnhn.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Research and students"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Les chercheurs et \u00e9tudiants"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mus\u00e9um National d'Histoire Naturelle (MNHN)"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mus\u00e9um National d'Histoire Naturelle (MNHN)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUDlRdBDkJESYW6n2HShweS3jdr8swDQYJKoZIhvcNAQEF\nBQAwFjEUMBIGA1UEAwwLZmlkLm1uaG4uZnIwHhcNMTQxMjAxMTQxMzEzWhcNMzQx\nMjAxMTQxMzEzWjAWMRQwEgYDVQQDDAtmaWQubW5obi5mcjCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBALaoJeXjuTBCZdOtdlxs0/5ZHzxjTJP9zOtAYQOe\n6enHOV4diw5kEQRW0P8vB18yO3GkdzfUBMizbF6Q7wzh2QIYY9AZq4eWn858qyy2\nWgzi06c3vox3pcnJMoMTTxe87kSXUwEjDdGFqpkzyEXKHLBJHvUllq7UOhT8EJeb\nq1lFoQk+P5XXoiaqFT3djyqVYgBqNf6M1KPTgK8YpaziAeXqGPLIya9wQNSXw7SX\nk933EOXd61SxxBDMIgpnU4eZH0OqtcsWEz2+iMT2DTRBGkFg4Sw9YfjZwKrQceao\nEtebvucPR1l65WtHkbBEgn1j1Kn/A0VuWnpLkfEWtjgwoD8CAwEAAaNdMFswHQYD\nVR0OBBYEFC3y0NSAMWWxMPbIbU6jPAUNjsvBMDoGA1UdEQQzMDGCC2ZpZC5tbmhu\nLmZyhiJodHRwczovL2ZpZC5tbmhuLmZyL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3\nDQEBBQUAA4IBAQArN80LjEyavMOC3fqbILBkByDBaMyfx0G0Tar+v38pa+Yw3PUO\nH9KJlucttn9gauL4T6KK0lpY54D+mldhmQMuGjWuP9/L3kbysU1/rQ+iTK6K3Va5\ndmnqSXiMZpMroaV9yoAiM4v1KfYj92MWg5T6JghWcqQfS/nePGYETcsSiHOgSH4O\ny3+b1691vR2PbgGl29/bdRGHWShN5UxvmWg4H96JzVkhAMkbRNZZBo/hWpLf7Wzo\n5QHuZrX7Nn5+lJG0MtXdClgXYtGbg72ThCCXvovoQtYVY9TEBqJBGNe3VAs2/kDG\n/7NmLRYW0sbMhZeKGTdr7qth0ZOX+aj3+nnZ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAN2WCywAfMl5MJ8cVRoKFLyV+pBoMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2lkcC5tbmhuLmZyMB4XDTExMDUyMzA4NTUyNloXDTMx\nMDUyMzA4NTUyNlowFjEUMBIGA1UEAxMLaWRwLm1uaG4uZnIwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCmAwtKt4Gn/OnH/ER/RWlu+XXXicirD/hyUooa\nK5KKEsbiRAr//R+vzCwC3svUQJ5F6f9mMaLoPC06cALnyMmylUJhT1D7XW2mJQMX\nXroZC1fa+UCmxtdvZIM7qjesRIfLYEZMoa4/weBEbEElUfuqPkoqShTp5kbO/L5Y\n/phmvhYV0MnReY5UYOH59yzCHcZ1N9vDu4K5HwvaK56nYTc/yVfAlhK7T2KTZldP\n+yf8tU2UBdhympcm4WCaH2wbZSlVt5Vr4V0CgQmF3AkkSmmr+l2z0WmIyj5DqYc5\nUwVu5q/YteHRNqy2HD0BpyFnWd+OumQRRtMLOQYqqTmMVtBHAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2lkcC5tbmhuLmZyhiJodHRwczovL2lkcC5tbmhuLmZyL2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBTwc9EzS0upzHexvPHSjyyBXtJRzzANBgkqhkiG\n9w0BAQUFAAOCAQEAUjcVU43UjPS2yZa2B98B2GixtGn5JcBnE1QLt5pgGsnr4CIx\nI8cC/jZT5L7NXrTNt/6nPGMCycxAWv7tlueZ0WdzZ+UGtB/rRYkL2r469oLZ3rYa\n+UjhcWk/BF913fSK/FsRHrdp/Ml4qKsgePY0XovshBV95lfyRSfO2fOYkOE9DqWi\nxFPoC+FB1H96Xlqm9MNJTjVHOlK/dsWepngeGtSThDfw6Zu2YBffGKmjUxZupnz/\nx1tBulh4y7eU//huta68Wi6YRz4yzVlzbowBI/RxtKs0bme6vXeCkL1b5TCJBpHy\nvRrHv8r51u7XXy3b5wfo2T+mRkq36Qzb3+UX7w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mus\u00e9um National d'Histoire Naturelle (MNHN)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mnhn.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Mus\u00e9um National d'Histoire Naturelle (MNHN)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth-dev.derby.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Handley"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:g.handley@derby.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Glenn"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Handley"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:g.handley@derby.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Glenn"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Webb"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:D.Webb@derby.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth-dev.derby.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_instant": "2013-06-24T12:03:26Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIVAIS5CSZypB0N/9WAdPoZcaHvhD9FMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCUxIzAhBgNVBAMTGnNoaWJib2xldGgtZGV2LmRlcmJ5LmFjLnVrMB4XDTEz\n\t\t\t\t\t\tMDYyMDExMjUxN1oXDTMzMDYyMDExMjUxN1owJTEjMCEGA1UEAxMac2hpYmJvbGV0\n\t\t\t\t\t\taC1kZXYuZGVyYnkuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDAhN9QbYsdN4nENW2bozesyzvCnPKGADL66kcw7+SIXbUcmpiLZctfG2pk8Myq\n\t\t\t\t\t\tb42n1RQlHcQ9QXcH0DD0bJWNiiiVkBciVtY7WcfxkyTlioc8IfgncHergH0uBVfE\n\t\t\t\t\t\tYRINrSSbss5l657QRbnbJVJ8R2c0WHS4Pw8Nm40hkbO7GqYkht/MiRL6utW2yrA5\n\t\t\t\t\t\tID2o/dXX7NqUr/9NUtvtczfd12reoyradlg7DkqfCHCE8S5Q8CWbj68nbZN+eEK8\n\t\t\t\t\t\twdiRnVmyvsC6htWN9HsnYMQAEAqQBA9KHbVsVFAdZsYlIGvjirTDD3n4TLPppfDE\n\t\t\t\t\t\tYY5HoNYNe1nJJnXAqE/OpBJLAgMBAAGjezB5MFgGA1UdEQRRME+CGnNoaWJib2xl\n\t\t\t\t\t\tdGgtZGV2LmRlcmJ5LmFjLnVrhjFodHRwczovL3NoaWJib2xldGgtZGV2LmRlcmJ5\n\t\t\t\t\t\tLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSqUMV7MJKbA3K8FtQY5Ern\n\t\t\t\t\t\tkVp6BzANBgkqhkiG9w0BAQUFAAOCAQEAXkonAxu78/1gNxTeBdASryyipP8T56v7\n\t\t\t\t\t\tBptkFIG8pjymWe5JpBFANjePMUrlyYisC3qfivdEJxP51Igw+TEf/rbRL+HFElWC\n\t\t\t\t\t\tnRgEkUmLAicNpCsDujXAw7J9ID28kcM+Ut8uQqRQs+/potj1TN4WInzjasH2R+Lw\n\t\t\t\t\t\tyrDOv2opvCGUupfH/dkIGHNdgs0iQRRgp0rUv9OCwwWYcQazmovxHPuXd0yd7uXR\n\t\t\t\t\t\t0xKNdvCIJ2yeny2x5Bzm3aHXncUn6STA2SZYBOYHZjpFitBpAIc9oASCeMwu2Z18\n\t\t\t\t\t\tOa45E8Q95Tq7yvmGFuSBvH0K3ijY+V1yq+oNwRqKaX5QIvNAufFfMw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "derby.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth-dev.derby.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-dev.derby.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth-dev.derby.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth-dev.derby.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth-dev.derby.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth-dev.derby.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth-dev.derby.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-dev.derby.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "derby.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIVAIS5CSZypB0N/9WAdPoZcaHvhD9FMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCUxIzAhBgNVBAMTGnNoaWJib2xldGgtZGV2LmRlcmJ5LmFjLnVrMB4XDTEz\n\t\t\t\t\t\tMDYyMDExMjUxN1oXDTMzMDYyMDExMjUxN1owJTEjMCEGA1UEAxMac2hpYmJvbGV0\n\t\t\t\t\t\taC1kZXYuZGVyYnkuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDAhN9QbYsdN4nENW2bozesyzvCnPKGADL66kcw7+SIXbUcmpiLZctfG2pk8Myq\n\t\t\t\t\t\tb42n1RQlHcQ9QXcH0DD0bJWNiiiVkBciVtY7WcfxkyTlioc8IfgncHergH0uBVfE\n\t\t\t\t\t\tYRINrSSbss5l657QRbnbJVJ8R2c0WHS4Pw8Nm40hkbO7GqYkht/MiRL6utW2yrA5\n\t\t\t\t\t\tID2o/dXX7NqUr/9NUtvtczfd12reoyradlg7DkqfCHCE8S5Q8CWbj68nbZN+eEK8\n\t\t\t\t\t\twdiRnVmyvsC6htWN9HsnYMQAEAqQBA9KHbVsVFAdZsYlIGvjirTDD3n4TLPppfDE\n\t\t\t\t\t\tYY5HoNYNe1nJJnXAqE/OpBJLAgMBAAGjezB5MFgGA1UdEQRRME+CGnNoaWJib2xl\n\t\t\t\t\t\tdGgtZGV2LmRlcmJ5LmFjLnVrhjFodHRwczovL3NoaWJib2xldGgtZGV2LmRlcmJ5\n\t\t\t\t\t\tLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSqUMV7MJKbA3K8FtQY5Ern\n\t\t\t\t\t\tkVp6BzANBgkqhkiG9w0BAQUFAAOCAQEAXkonAxu78/1gNxTeBdASryyipP8T56v7\n\t\t\t\t\t\tBptkFIG8pjymWe5JpBFANjePMUrlyYisC3qfivdEJxP51Igw+TEf/rbRL+HFElWC\n\t\t\t\t\t\tnRgEkUmLAicNpCsDujXAw7J9ID28kcM+Ut8uQqRQs+/potj1TN4WInzjasH2R+Lw\n\t\t\t\t\t\tyrDOv2opvCGUupfH/dkIGHNdgs0iQRRgp0rUv9OCwwWYcQazmovxHPuXd0yd7uXR\n\t\t\t\t\t\t0xKNdvCIJ2yeny2x5Bzm3aHXncUn6STA2SZYBOYHZjpFitBpAIc9oASCeMwu2Z18\n\t\t\t\t\t\tOa45E8Q95Tq7yvmGFuSBvH0K3ijY+V1yq+oNwRqKaX5QIvNAufFfMw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Derby Shibboleth (Test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://ulib.derby.ac.uk/library/homelib.php"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Derby"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://openwiki.uninett.no/simplesaml/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@feide.no"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Feide Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://openwiki.uninett.no/simplesaml/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.feide.no/files/feide/metadata-registration-practice-statement.pdf"
              }
            ],
            "registration_instant": "2011-08-09T11:34:54Z",
            "registration_authority": "http://feide.no/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNINETT"
          },
          {
            "lang": "no",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNINETT"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uninett.no/english"
          },
          {
            "lang": "no",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uninett.no/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNINETT"
          },
          {
            "lang": "no",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNINETT"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://openwiki.uninett.no/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNINETT OpenWiki is a set of wikis, as a collaboration platform across domains."
                  },
                  {
                    "lang": "no",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNINETT OpenWiki er en wikil\u00f8sning, for samarbeid p\u00e5 kryss av organisajoner."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNINETT OpenWiki"
                  },
                  {
                    "lang": "no",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNINETT OpenWiki"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://openwiki.uninett.no/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "UNINETT OpenWiki"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "UNINETT OpenWiki is a set of wikis, as a collaboration platform across domains."
                },
                {
                  "lang": "no",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "UNINETT OpenWiki er en wikil\u00f8sning, for samarbeid p\u00e5 kryss av organisajoner."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "preferredLanguage",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.39",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-08.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-08.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-08.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-08.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-08.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-08.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-08.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-08.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-08.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;08"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;08"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-08.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-08.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJAO+EZXmznxmtMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wOC5sYWRvay51bXUuc2UwHhcNMTIwNjI5MTIwODEyWhcNMjIw\nNjI3MTIwODEyWjAhMR8wHQYDVQQDExZsYWRvazMtMDgubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAv8nfrfVZ7TnvQgRRXJEZowbO\n3vkDb6MenmraW2xYLfdn5j0bL+gFxMpa7WDIizo6JnEEidR5a/6xtqSiVRpOJxdq\nnraCu3sRT+olX/KtS7appB4Vn1BNwEyTxF/nAyofVZagygSb4eNHsbLm6MQCGTAl\n1Wg7tNPw+bJUbTLHZuiJJKS+UJJ+tL0Rw+W5NHd8jIpdV53zygO8bk/cWC7Ua0Mg\n/0Yhe8pL8trjzItyWS56h4xoACS4SNdJ4XoMGKrNvdQFFXIiRZhBayPENVVJCbA1\n7uwJ7ZhFTkATs40sc8qHmjsvquN0HhJ+2omUKMVcXXUyTyHSyvrVEHbfW8/6eQID\nAQABo2swaTBIBgNVHREEQTA/ghZsYWRvazMtMDgubGFkb2sudW11LnNlhiVodHRw\nczovL2xhZG9rMy0wOC5sYWRvay51bXUuc2UvZ3VpLXNwMB0GA1UdDgQWBBSWFhOQ\n81n5zVJUDnIHuNuaJMcC+jANBgkqhkiG9w0BAQUFAAOCAQEAFnLVLW8ENWOeYaYv\nEyKXmwndeagEBvN9MSFJqCmxe/m2HAcDJdOiXv6h31KndZL2DEGIr+qlXBMRIJUT\n6vJQ5pL4K2bnFPTKcnrKpLeguxxj9AT8zLUrYg2tHqoRVWiOCLq5QJDSz9VsZelD\n69VA2Xw9wO+4yLyH8JXngId+7d49wmJ0QfxI3lbiwV2hzVAFk4lTfZC90Rm7lOGM\n6gfXr5KnZOETbq2p4PWHn6zYIAn5hQNn/1tu7yj5jymyI2MWFQFi8tR1dNj76xg5\n8km3byhc201hWx7aRcr/skljVphTbHlLYyACjpPtVpG/rXjAJgtkBNYY9n+c95i8\nMTpiVw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-08.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-08.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-08.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-08.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-08.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-08.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-08.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-08.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-08.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-08.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://rtrvirshib.ifmt.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lilian Maria Goncalves"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "infra@ifmt.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://rtrvirshib.ifmt.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDjjCCAnYCAQAwDQYJKoZIhvcNAQEFBQAwgYwxDTALBgNVBAoTBElGTVQxDTAL\nBgNVBAsTBERHVEkxIDAeBgkqhkiG9w0BCQEWEWluZnJhQGlmbXQuZWR1LmJyMQ8w\nDQYDVQQHEwZDdWlhYmExCzAJBgNVBAgTAk1UMQswCQYDVQQGEwJCUjEfMB0GA1UE\nAxMWcnRydmlyc2hpYi5pZm10LmVkdS5icjAeFw0xNjAzMDMxODI4MjRaFw0xOTAz\nMDMxODI4MjRaMIGMMQ0wCwYDVQQKEwRJRk1UMQ0wCwYDVQQLEwRER1RJMSAwHgYJ\nKoZIhvcNAQkBFhFpbmZyYUBpZm10LmVkdS5icjEPMA0GA1UEBxMGQ3VpYWJhMQsw\nCQYDVQQIEwJNVDELMAkGA1UEBhMCQlIxHzAdBgNVBAMTFnJ0cnZpcnNoaWIuaWZt\ndC5lZHUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDNX6T/Opvv\nXZ1/PzN5zfKZAVJiOAk6YagbAWXgRSkB5roPqFRZItqzzFrbC62wwPB98mTRHs40\nLMnhBNIjBcrG4qH9lwNtMOR3XSBZbCivBDAZbdjEoursxYulZmOxecHSYKlsJKiZ\njSJzGFbZ7cUAjjBCoQgIn+Ez52RGJ+CHtneT+mJsrrkVZPITWPz/YO2GL5z4xiuP\nNXEY6XMR9Wv9aOncNs4Gmv/EHHwZhZVyJd5V6XwdOagxUjUrnrBAlqlKMayJaIlB\n/ci/RHKS0RfWCkTlO8Xr/Fvw0ovbZhSfvdfMqxSLw/Bo6kTcAEq9kkfXCfsK516y\nlDuDBQWai0E7AgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAEz5Is1zebR+nTq90FSv\nnhKc9e0yk++LyPE9/VjADDlQJ35lfOBKSflhCdIlRjIRqLN2zcEfpZD1aMoWFpe+\nLH7W41NvJiij4HsSQasSJVwkOI6AQc0oUjB9UOXXb7bekOVIvXg4uzJkjXG9ezRJ\nDeXBdf4vEbKuXxnTlB82nvOds5GuuK00phGGtkgovGhTnCyWIGE1XBfpNy7ULD6D\nQczEBrduaMxIw8IVtOGcg6N8xRErRcgO8KLeyjre6Xp/ZX8YYUcYQG0vHpdBRBtx\n9n+qjMNpXSrafOqfJ86ch4VF7jmn+PZZmLiGGlfZUyoo2pKztiDEXEwhdHkMBohY\n16U="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://rtrvirshib.ifmt.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://rtrvirshib.ifmt.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://rtrvirshib.ifmt.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://rtrvirshib.ifmt.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://rtrvirshib.ifmt.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://rtrvirshib.ifmt.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://rtrvirshib.ifmt.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://rtrvirshib.ifmt.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifmt.edu.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifmt.edu.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFMT - Instituto Federal de Mato Grosso"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFMT - Instituto Federal de Mato Grosso"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFMT - Instituto Federal de Mato Grosso"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFMT - Instituto Federal de Mato Grosso"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDjjCCAnYCAQAwDQYJKoZIhvcNAQEFBQAwgYwxDTALBgNVBAoTBElGTVQxDTAL\nBgNVBAsTBERHVEkxIDAeBgkqhkiG9w0BCQEWEWluZnJhQGlmbXQuZWR1LmJyMQ8w\nDQYDVQQHEwZDdWlhYmExCzAJBgNVBAgTAk1UMQswCQYDVQQGEwJCUjEfMB0GA1UE\nAxMWcnRydmlyc2hpYi5pZm10LmVkdS5icjAeFw0xNjAzMDMxODI4MjRaFw0xOTAz\nMDMxODI4MjRaMIGMMQ0wCwYDVQQKEwRJRk1UMQ0wCwYDVQQLEwRER1RJMSAwHgYJ\nKoZIhvcNAQkBFhFpbmZyYUBpZm10LmVkdS5icjEPMA0GA1UEBxMGQ3VpYWJhMQsw\nCQYDVQQIEwJNVDELMAkGA1UEBhMCQlIxHzAdBgNVBAMTFnJ0cnZpcnNoaWIuaWZt\ndC5lZHUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDNX6T/Opvv\nXZ1/PzN5zfKZAVJiOAk6YagbAWXgRSkB5roPqFRZItqzzFrbC62wwPB98mTRHs40\nLMnhBNIjBcrG4qH9lwNtMOR3XSBZbCivBDAZbdjEoursxYulZmOxecHSYKlsJKiZ\njSJzGFbZ7cUAjjBCoQgIn+Ez52RGJ+CHtneT+mJsrrkVZPITWPz/YO2GL5z4xiuP\nNXEY6XMR9Wv9aOncNs4Gmv/EHHwZhZVyJd5V6XwdOagxUjUrnrBAlqlKMayJaIlB\n/ci/RHKS0RfWCkTlO8Xr/Fvw0ovbZhSfvdfMqxSLw/Bo6kTcAEq9kkfXCfsK516y\nlDuDBQWai0E7AgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAEz5Is1zebR+nTq90FSv\nnhKc9e0yk++LyPE9/VjADDlQJ35lfOBKSflhCdIlRjIRqLN2zcEfpZD1aMoWFpe+\nLH7W41NvJiij4HsSQasSJVwkOI6AQc0oUjB9UOXXb7bekOVIvXg4uzJkjXG9ezRJ\nDeXBdf4vEbKuXxnTlB82nvOds5GuuK00phGGtkgovGhTnCyWIGE1XBfpNy7ULD6D\nQczEBrduaMxIw8IVtOGcg6N8xRErRcgO8KLeyjre6Xp/ZX8YYUcYQG0vHpdBRBtx\n9n+qjMNpXSrafOqfJ86ch4VF7jmn+PZZmLiGGlfZUyoo2pKztiDEXEwhdHkMBohY\n16U="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFMT - Instituto Federal de Mato Grosso"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFMT - Instituto Federal de Mato Grosso"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifmt.edu.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifmt.edu.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFMT - Instituto Federal de Mato Grosso"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFMT - Instituto Federal de Mato Grosso"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://meals.st-annes.ox.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it-support@st-annes.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it-support@st-annes.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://meals.st-annes.ox.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-02-17T12:11:47Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "St Anne's College Meal Booking System"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.st-annes.ox.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Oxford"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://meals.st-annes.ox.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://meals.st-annes.ox.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://meals.st-annes.ox.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://meals.st-annes.ox.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://meals.st-annes.ox.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://meals.st-annes.ox.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIJANnoZzkReWmMMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\n\t\t\t\t\t\tBAMTF21lYWxzLnN0LWFubmVzLm94LmFjLnVrMB4XDTE2MDIxNTEwMzk0N1oXDTI2\n\t\t\t\t\t\tMDIxMjEwMzk0N1owIjEgMB4GA1UEAxMXbWVhbHMuc3QtYW5uZXMub3guYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCq1w+5nFcQhgXjM6P3DAjw\n\t\t\t\t\t\tRsswHr7DEXk+LQVgrXgTmmfZge97FZfRgWVkX7X/GA9JQ/ElZQyJDW8i4tGTHijv\n\t\t\t\t\t\td2V8zZojifmzzi3aFjCNJrn2jDq/dp8KwU4mQsPn3/Rz4wToiWulYA07UHpuTFSc\n\t\t\t\t\t\tqrIfMNeU1NGPAdBjVfXq+koYEK6p7u0hyhodPagOCAOO7sTzcj6SBSHwbm4OnArZ\n\t\t\t\t\t\tmRQ7h+53Gy8fux+kMTN/2mZsTa4YwkUzhVqCf/8G2Yib9AdwhVGcKWeaJ2HwzsJk\n\t\t\t\t\t\tLeGmS8gwE5nRWJtjw7bkVTMuCINmPm6AqURXO4MFrfzaXF+rD+w1GSuIiQfknThV\n\t\t\t\t\t\tAgMBAAGjcTBvME4GA1UdEQRHMEWCF21lYWxzLnN0LWFubmVzLm94LmFjLnVrhipo\n\t\t\t\t\t\tdHRwczovL21lYWxzLnN0LWFubmVzLm94LmFjLnVrL3NoaWJib2xldGgwHQYDVR0O\n\t\t\t\t\t\tBBYEFLL/qY1+dvjgNBjg5b+6AXuSZbd+MA0GCSqGSIb3DQEBBQUAA4IBAQAAoo0M\n\t\t\t\t\t\t5drTzXE3RtAacm9eN+vQ7CqaampTOZOk25WldvhhIfSR1a4d3RuOyXmRKNMVe+TA\n\t\t\t\t\t\t2Wb3SRsJDKJ5WQcor+HxF7hqPtti98gSK3AZS91fxvVaqG3s9jUXMnuWT/NQTsLW\n\t\t\t\t\t\tjd67nNsuTXQXecYzIddL21Uzo7FHWeQG2uMT7CIqTvAi08OkXeyaz8H8BBbEtfqm\n\t\t\t\t\t\teV5cOObxvtH8wLIPlmS00zEudfMoENvAUa3tQQxEsnf7hzxKHxIz3dRur+PCa9JH\n\t\t\t\t\t\txaT+oU99+9miYEx5nhl/x6DeOO1y7q0LxVSORUF/IQWs4SkAVcysWi/Md4a2y547\n\t\t\t\t\t\t7jdTc8yMtlEy+bEY"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://meals.st-annes.ox.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://meals.st-annes.ox.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://meals.st-annes.ox.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://meals.st-annes.ox.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://meals.st-annes.ox.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://meals.st-annes.ox.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.telecom-bretagne.eu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp-contact@telecom-bretagne.eu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.telecom-bretagne.eu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2010-02-10T18:09:45Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.telecom-bretagne.eu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.telecom-bretagne.eu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.telecom-bretagne.eu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "telecom-bretagne.eu"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.telecom-bretagne.eu/"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "T\u00e9l\u00e9com Bretagne"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "T\u00e9l\u00e9com Bretagne"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAMDsjMGGzs74lgEgGP3m2lZR6SMhMA0GCSqGSIb3DQEB\nBQUAMCIxIDAeBgNVBAMTF2lkcC50ZWxlY29tLWJyZXRhZ25lLmV1MB4XDTEwMDIx\nMDA5NTgyNFoXDTMwMDIxMDA5NTgyNFowIjEgMB4GA1UEAxMXaWRwLnRlbGVjb20t\nYnJldGFnbmUuZXUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDDyA3F\nPUpmxBhBziOEouQX8lgfErTEM0EFV5Fg0lNc8NPn/nWmBtyQxbY1yqkmf34Te5ef\nSdNp39QQ9X6W+y3/p+9k+x6GgVwtvDcGB6fPPtncPHBVMo5V+EeoIE20vUN6TW4H\ng/RJHoqpZEn1x/G01bprZWCBdadbr2BaZcE5jabTB11wu1zu/7mBXVUtBPMTdHh7\nn4M872F8vTeTPVce4WcoDm5ac7qJOnE55t1RyYj7rryDrwThT//NY3sg2IguJn4B\n+SGImQDS3C688SsdM42OiOD2xnmwgWU+dkLuPLz1w/fZmK5l5Vb2YWdyyHKshU4+\nFcIQFwgXpnKgTREJAgMBAAGjdTBzMFIGA1UdEQRLMEmCF2lkcC50ZWxlY29tLWJy\nZXRhZ25lLmV1hi5odHRwczovL2lkcC50ZWxlY29tLWJyZXRhZ25lLmV1L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBSzMnv76CtVAByMD9L8/3CVVLT2WjANBgkqhkiG\n9w0BAQUFAAOCAQEAa5ho6vHycEIXOcmcfgpj60G6tS9vNKWLJ+H5zdXf+BcsLuky\nW5xQkgM519BghwJ72xDo4YVyEdp4kEGVKMo6+Vu0bz4AREb4SmMm+N2FCamhK6D8\n+9YLDw76+x5xlUVaV0bVGkDAG9IlOzg6gPhoRiJrwg3pzgAiFiysBTTZSPLorTgU\nBqA6X8hXjbPat/Ry48AOmlkbSSuPKbc8Ij78VcDg9HlAurDJ8lyPKL72VBJdT0JY\nf7EOBt1e8Cf7GwVdtvHq3LW88y9UTshQMpZtNxk9lXr6FMwcMG0wM1aOn5HRlGSs\nbm2IAM4xlcyiwzG22vG6NmR4y7NYNG9q6YyiOw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "T\u00e9l\u00e9com Bretagne"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.telecom-bretagne.eu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "T\u00e9l\u00e9com Bretagne"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://service.projectplace.com/saml/metadata.xml",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@projectplace.com"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "saml@projectplace.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://service.projectplace.com/saml/metadata.xml",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Projectplace International AB"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.projectplace.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Projectplace International AB"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "service.projectplace.com"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIJAIE8f+suTt+LMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\nBAMTGHNlcnZpY2UucHJvamVjdHBsYWNlLmNvbTAeFw0xNDExMDUxMzE0NTNaFw0y\nNDExMDIxMzE0NTNaMCMxITAfBgNVBAMTGHNlcnZpY2UucHJvamVjdHBsYWNlLmNv\nbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANpUDYAKCNjdMJVgeIMs\nBdV/8NNcjmiEy1QI3lIsofqCVlPCe6iKB7QIhwYwHEsswGJ56QUfWS9RJB/xXRcl\nL1DBE6mgrS4kwifXnYt567J0MfXw1xZ6ecf/JULz34FfFNyvRxC8AILmnkgV7hR5\nbBEzmHIOfrfpx9k9Jnc1SzVooxujVywhAlV8HV9687CFSW6YCN8CS2duukJToYZt\nmuK/Qvk0MLK4QybMD/25bBzAwKmkvAM203C5ZGB4LDt0acv0lS73mwWolhAP2rsH\nJmrj+Sfs4ANzbyH7jx+C1n4jV0/3Ilfy1vWfDrj+8yOGGxKngqLoIybox/a4C11I\nwccCAwEAAaN6MHgwVwYDVR0RBFAwToIYc2VydmljZS5wcm9qZWN0cGxhY2UuY29t\nhjJodHRwczovL3NlcnZpY2UucHJvamVjdHBsYWNlLmNvbS9zYW1sL21ldGFkYXRh\nLnhtbDAdBgNVHQ4EFgQUPSM47nWzqUF7VqXY79PAzSBhWr4wDQYJKoZIhvcNAQEF\nBQADggEBAFRfKN/3q2rFPcU4cDVKMilNvwl05bEyZS1433C/JL3WivqtAX/3p1my\nepoxQU5aasZvCt/mcaCgdp7SUS9WMSJIXf93Fy1ZdwLp5O1rwUHVjyyeIpllIWm2\nPuET3JVqftiq5vlGCbzcGAyZ3Gra39q4DhkV90m/taaz1V/4tQR99Eg8mblzFFot\nN/9/JHUv4hZr3aBpc6DvXv9Lu7xjeY03k/Bp3GEK+th9wePZaBnnrPTIDYsNqfR2\nqn0pH3p8ik4RiHD3Od8k9acHCj/dO4PyTbAjgYuUS23yUBbJOmow6eje/HNpQs9E\n2dDN26Ytpx0W4SfsIWp9tuO9CYst0dU="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=service.projectplace.com"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "want_assertions_signed": "true",
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://service.projectplace.com/saml/login",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.grenoble-inp.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "federation.sos@grenoble-inp.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.grenoble-inp.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-07-11T10:36:51Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.grenoble-inp.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.grenoble-inp.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.grenoble-inp.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "grenoble-inp.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.grenoble-inp.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Grenoble INP - Institut polytechnique de Grenoble"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Grenoble INP - Institut polytechnique de Grenoble"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIVAO/QaN+dR8TZXZ6cNFwn8jJiB3QdMA0GCSqGSIb3DQEB\nBQUAMCUxIzAhBgNVBAMTGnNoaWJib2xldGguZ3Jlbm9ibGUtaW5wLmZyMB4XDTEy\nMDEwOTA5MzY1NVoXDTMyMDEwOTA5MzY1NVowJTEjMCEGA1UEAxMac2hpYmJvbGV0\naC5ncmVub2JsZS1pbnAuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQDKu60J1wRxU9drIKvmtJJfsJ/w+Xmdd+PQOxz0+mIwpdUSpkMbkXWoiYTsj2nf\nBorFExB0qYHAUJTdPVBJL1LVSqOBK8k1w7BopKJnQ/XYujiSPuodTifKRYjiGyiB\nrDKs+pNLawv8jzWTtqnM8NYsfa0+25kdVDwHhKqmSmypB6leLyjNr9MKdHDQ38ca\nq3tKlKz0Mif1iZ0BZdo5eQSzZwO67pzU/4YUgmN2HpJxrwRsk9U98oILg2NVW+0U\nBNcheLXY2XrRd+fTbbPbTTMA4RNcYLCS0EPJ6YA77+wZ5YfD1FGu/hxBKUbCP8b8\nhhQ5O7Y//nWY3w5MlGqLAPjbAgMBAAGjezB5MFgGA1UdEQRRME+CGnNoaWJib2xl\ndGguZ3Jlbm9ibGUtaW5wLmZyhjFodHRwczovL3NoaWJib2xldGguZ3Jlbm9ibGUt\naW5wLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTAG7NXFV8rO7re+ySoBXuv\n3FrnkDANBgkqhkiG9w0BAQUFAAOCAQEAIFBwVqbJE++ODmHmwh6E3ScDv+LDM3q3\nGBpZKQ6I+g5uVdM1r5TRKZBxKL59J51wHBQ2+AmDhlNEeqUszaw42GXFJhWLf8RU\n5hnqyBQawD8NpztjyoNgHg1dLdg6uz8k1YHXTw3mG4eWaqxmeeUKspv+XXyBg7Sw\nxVox8mkoixLKQpOZ20xTOK41X+bAockt816dkuSR2ZV+v8fwE4BZbFunf9XZRJmD\neyd91K5Q48y3V66rM3lnwlbdRFcBD9QC8vL+kHL1L5RIUSiClWuSm4J6adU29spC\nOXNNpafFw7y4uune6Y8Jq542pO0I1Hlx1rcd9u0vZ3P+ewZdQP5kkw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Grenoble INP - Institut polytechnique de Grenoble"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.grenoble-inp.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Grenoble INP - Institut polytechnique de Grenoble"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dev.pf.adidas.com",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:CRM-Support@adidas-group.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CRM-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:CRM-Support@adidas-group.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CRM-Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Olivo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Deborah.Olivo@externals.adidas-group.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Deborah"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dev.pf.adidas.com",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-09-25T13:35:45Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "adidas UK"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.adidas.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Adidas International Trading B.V."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev.pf.adidas.com/sp/SLO.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.pf.adidas.com/sp/SLO.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.pf.adidas.com/sp/SLO.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.pf.adidas.com/sp/SLO.ssaml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dev.pf.adidas.com/sp/ARS.ssaml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDdjCCAl6gAwIBAgIGAUAaKOiMMA0GCSqGSIb3DQEBBQUAMHwxCzAJBgNVBAYT\n\t\t\t\t\t\tAkRFMQ8wDQYDVQQIEwZCYXllcm4xFzAVBgNVBAcTDkhlcnpvZ2VuYXVyYWNoMQ8w\n\t\t\t\t\t\tDQYDVQQKEwZhZGlkYXMxHzAdBgNVBAsTFkNDIE1hcmtldGluZyBHbG9iYWwgSVQx\n\t\t\t\t\t\tETAPBgNVBAMMCHBpbmdfZGV2MB4XDTEzMDcyNjA4NDcwM1oXDTIzMDcyNDA4NDcw\n\t\t\t\t\t\tM1owfDELMAkGA1UEBhMCREUxDzANBgNVBAgTBkJheWVybjEXMBUGA1UEBxMOSGVy\n\t\t\t\t\t\tem9nZW5hdXJhY2gxDzANBgNVBAoTBmFkaWRhczEfMB0GA1UECxMWQ0MgTWFya2V0\n\t\t\t\t\t\taW5nIEdsb2JhbCBJVDERMA8GA1UEAwwIcGluZ19kZXYwggEiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tAQUAA4IBDwAwggEKAoIBAQCCDhQHa7AiG64TEr9I+GCjnBq3dUybpS7R8JI3JkHO\n\t\t\t\t\t\txaWXCDxOvuPcoi9xA9PW4TooQgD5QXz+eIyQ2Arb5tyOBmKekWPq4f5KkqYa6qyt\n\t\t\t\t\t\tpJJTqUuoVbqjQjNP1NVHZmwFsL3Kadnes+87LsgbVtQnpiqYHz3s2WT7YfmlSqXR\n\t\t\t\t\t\tmMrQt5iVSTX0Tdm5m7wA6Xyzq21faqb6CDYCFZXUe0f/G9WrbJTITN5yc4p8T7NW\n\t\t\t\t\t\tyeRFVj2v0PFXdv+aAiqkv1W5781M8F5OfBNripwXfT12RONbYvgY8sUFDY6BDlNh\n\t\t\t\t\t\tvDDKKBQRvTILTKL1QIsRPWvUti5vW9ySDXjFgLvS5DsvAgMBAAEwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAGMrOehUiULVhakwr/l9gIiKaw1txHUYlsVZ740an0vt6y+A2O8L\n\t\t\t\t\t\tbzPaI2my/y0aV6ddk78ERK2bRkSKVgkLevu/SKTdrE+ClTccCsZquUPK8C/Rbqvd\n\t\t\t\t\t\tG3trHaSjO91LKgbcA/IQZc3rojZShIsLp0CQ05HBOtB5EzSeLK67gEFiOOTXj49i\n\t\t\t\t\t\tUOWl9vrHP5khiXkqjhYK2PwoM+wOGDm2PepftBEKb6fCv0IJH6+057xDOhE+rWHN\n\t\t\t\t\t\tSn9dCpFe0yTtmyASrOPeHHUbS8wqDEQQjWiA8UO+PKkFESfXduO7eqT/wve5Toj5\n\t\t\t\t\t\tdkrEwvqRvyw71CgkUBhrKtFp+tc8WVA3MXw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dev.pf.adidas.com/sp/acs.saml1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dev.pf.adidas.com/sp/acs.saml1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.pf.adidas.com/sp/ACS.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.pf.adidas.com/sp/ACS.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dev.pf.adidas.com/sp/ACS.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.macclesfield.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "White"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:scott.white@macclesfield.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Scott"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "White"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:scott.white@macclesfield.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Scott"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.macclesfield.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDbDCCAlQCCQD/7vODco0h7zANBgkqhkiG9w0BAQUFADB4MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjERMA8GA1UECBMIQ2hlc2hpcmUxFTATBgNVBAcTDE1hY2NsZXNmaWVsZDEdMBsG\n\t\t\t\t\t\tA1UEChMUTWFjY2xlc2ZpZWxkIENvbGxlZ2UxIDAeBgNVBAMTF2lkcDIubWFjY2xl\n\t\t\t\t\t\tc2ZpZWxkLmFjLnVrMB4XDTEzMDIwNzExMjYwOFoXDTMzMDIwMjExMjYwOFoweDEL\n\t\t\t\t\t\tMAkGA1UEBhMCR0IxETAPBgNVBAgTCENoZXNoaXJlMRUwEwYDVQQHEwxNYWNjbGVz\n\t\t\t\t\t\tZmllbGQxHTAbBgNVBAoTFE1hY2NsZXNmaWVsZCBDb2xsZWdlMSAwHgYDVQQDExdp\n\t\t\t\t\t\tZHAyLm1hY2NsZXNmaWVsZC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\n\t\t\t\t\t\tAQoCggEBAMDM05odoeteSlOjg3QAARLG25Ze052B7oef9N8SJe9qktTJsCp8lrzo\n\t\t\t\t\t\tQXR/CN/8XCRGiysNEtD5+dts4Vt16EU5eB3oknVjFwJ2tm14fAsOJkhYxEeL89oQ\n\t\t\t\t\t\tmGBS0DR5H+O8JFHwTVgYWaMK8Biei81MISIWo0QFgY/lhM4msVbJLmNfbWKvp2bU\n\t\t\t\t\t\tRQBOIv+zUYiLvESt1ZlXOiFZdJHvXJBhN5xV834x28KJMhsPtuGNI/NcHOpJ7gfy\n\t\t\t\t\t\tQIS2aDn03hws2UmfFSaNo5Fbv69FmF1b1RNzdl/E91aj2xrwq/kCslBd0qvGVBQS\n\t\t\t\t\t\tB3zaZvXN+zkvmfm6oqvrzo+ohdozk1kCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tCbl1ic6Me2HZNOyy42mLGWip6BRF3AmyRlAjYEnGOWjrbjnljF40C2ggFNFnpZZt\n\t\t\t\t\t\tTiRd7Ovzvbm+xJJiA3TiHiEZcmTH00DG6mEiqpan71wxkMvDrGD3c1KTVk4ALXwb\n\t\t\t\t\t\taSPz1JNIrw9XlX+JD6rXr9rH6aUPx7ckWi5nrodY6fW89WDiEtx7WOkDc1Zj77Gq\n\t\t\t\t\t\tJDpIl002iw2tQp+TRHDUD4Kc73JKc8IuJBDhxSedztn/jyZFfciIHBNMjaBQsd3n\n\t\t\t\t\t\t9/dIxdTe1CnRSzW8XzAbJPUdaYjy5ORlYKJ28OqKs/11N2llbaTuAwZqm3Ps9bKL\n\t\t\t\t\t\tURTAw0QV//xFG86AyPeEYg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "macclesfield.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.macclesfield.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.macclesfield.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp2.macclesfield.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.macclesfield.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp2.macclesfield.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2.macclesfield.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.macclesfield.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.macclesfield.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "macclesfield.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDbDCCAlQCCQD/7vODco0h7zANBgkqhkiG9w0BAQUFADB4MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjERMA8GA1UECBMIQ2hlc2hpcmUxFTATBgNVBAcTDE1hY2NsZXNmaWVsZDEdMBsG\n\t\t\t\t\t\tA1UEChMUTWFjY2xlc2ZpZWxkIENvbGxlZ2UxIDAeBgNVBAMTF2lkcDIubWFjY2xl\n\t\t\t\t\t\tc2ZpZWxkLmFjLnVrMB4XDTEzMDIwNzExMjYwOFoXDTMzMDIwMjExMjYwOFoweDEL\n\t\t\t\t\t\tMAkGA1UEBhMCR0IxETAPBgNVBAgTCENoZXNoaXJlMRUwEwYDVQQHEwxNYWNjbGVz\n\t\t\t\t\t\tZmllbGQxHTAbBgNVBAoTFE1hY2NsZXNmaWVsZCBDb2xsZWdlMSAwHgYDVQQDExdp\n\t\t\t\t\t\tZHAyLm1hY2NsZXNmaWVsZC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\n\t\t\t\t\t\tAQoCggEBAMDM05odoeteSlOjg3QAARLG25Ze052B7oef9N8SJe9qktTJsCp8lrzo\n\t\t\t\t\t\tQXR/CN/8XCRGiysNEtD5+dts4Vt16EU5eB3oknVjFwJ2tm14fAsOJkhYxEeL89oQ\n\t\t\t\t\t\tmGBS0DR5H+O8JFHwTVgYWaMK8Biei81MISIWo0QFgY/lhM4msVbJLmNfbWKvp2bU\n\t\t\t\t\t\tRQBOIv+zUYiLvESt1ZlXOiFZdJHvXJBhN5xV834x28KJMhsPtuGNI/NcHOpJ7gfy\n\t\t\t\t\t\tQIS2aDn03hws2UmfFSaNo5Fbv69FmF1b1RNzdl/E91aj2xrwq/kCslBd0qvGVBQS\n\t\t\t\t\t\tB3zaZvXN+zkvmfm6oqvrzo+ohdozk1kCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tCbl1ic6Me2HZNOyy42mLGWip6BRF3AmyRlAjYEnGOWjrbjnljF40C2ggFNFnpZZt\n\t\t\t\t\t\tTiRd7Ovzvbm+xJJiA3TiHiEZcmTH00DG6mEiqpan71wxkMvDrGD3c1KTVk4ALXwb\n\t\t\t\t\t\taSPz1JNIrw9XlX+JD6rXr9rH6aUPx7ckWi5nrodY6fW89WDiEtx7WOkDc1Zj77Gq\n\t\t\t\t\t\tJDpIl002iw2tQp+TRHDUD4Kc73JKc8IuJBDhxSedztn/jyZFfciIHBNMjaBQsd3n\n\t\t\t\t\t\t9/dIxdTe1CnRSzW8XzAbJPUdaYjy5ORlYKJ28OqKs/11N2llbaTuAwZqm3Ps9bKL\n\t\t\t\t\t\tURTAw0QV//xFG86AyPeEYg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Macclesfield College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.macclesfield.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Macclesfield College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:osu.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "8help@osu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "webauth-admin@lists.service.ohio-state.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Authentication Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "webauth-admin@lists.service.ohio-state.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Authentication Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "security@osu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Security Response Team"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "urn:mace:incommon:osu.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://webauth.service.ohio-state.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://webauth.service.ohio-state.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webauth.service.ohio-state.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://webauth.service.ohio-state.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://webauth.service.ohio-state.edu/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osu.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://webauth.service.ohio-state.edu/info.html"
                  }
                ],
                "logo": [
                  {
                    "text": "https://webauth.service.ohio-state.edu/images/osu_mdui.png",
                    "lang": "en",
                    "height": "83",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "83"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://ocio.osu.edu/policy/policies"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ohio State University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDITCCAgmgAwIBAgIJAKu+jRod+TYIMA0GCSqGSIb3DQEBBQUAMCkxJzAlBgNV\nBAMTHndlYmF1dGguc2VydmljZS5vaGlvLXN0YXRlLmVkdTAeFw0xMDAyMDkyMDA3\nMzdaFw0zMDAyMDQyMDA3MzdaMCkxJzAlBgNVBAMTHndlYmF1dGguc2VydmljZS5v\naGlvLXN0YXRlLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMpZ\nP+xV7kNCuuUtg4X8MTxTnS2TSU/tompvYjI0af4q7N5od7uzEqHBD9FMvh9bZ7GS\nCACX5yYjBYZCb59i0tstfpCsDBho2Wi497EjmaTw81EQ1AjM6EhRb/we0MLj0er8\n8q+vnVC7Jb7DoStoNIEFoOTv8LvKldrrXVX3yHZR3bEVtvblZbGMSYtPdH/TYMDQ\ncmqkpzldfz9rQFDLSM8mqBqf56zmB8uzkZKhujTXOzb4STvaq7hhAnDwT3z9c00O\nXbDBWxd1CplgHwZvrbWxYxf5gTCaPvHuLY5WeA8Ky5SUZifO/szEDvEm8K0rHStK\nH/blQiX5fUQ6t3SfxbsCAwEAAaNMMEowKQYDVR0RBCIwIIIed2ViYXV0aC5zZXJ2\naWNlLm9oaW8tc3RhdGUuZWR1MB0GA1UdDgQWBBR70C49vjOa/Ikk86hkX998wqQt\nUDANBgkqhkiG9w0BAQUFAAOCAQEAlgMMaTIwrly4U896lUa92iif3bLGADPjc0Is\n6a6k6RytjJm/r0lbtjCWW6zs1T6L7458Ow+57fyF0Oh/iXvj65m+dvCBWXnag7hN\n1yMBJQMRpSjH7dLko7y0EJ/ZrKEYQwYnBGmCILvJB/MIj2eEkq2Z47uWpvrehJfb\nzsEeAbjNqw1V/AJN7E4paw8aYg8TXEXAdOvNL5h7KRQw8Ui0kCw2DeTTIXExSxZd\nbqw6ldfQD2fVYnLxDGTFqITCi1a9TidA4xCXD95F7uQaEao3O8ArZcyag62uiMtv\ni24RvCRvD/vsnUhI82pV/DK+2icz6UDtiiKrFNAmIiR14TanfA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "error_url": "https://webauth.service.ohio-state.edu/support.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ohio State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.osu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Ohio State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://hotfixpub1.imodules.com/sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jwicoff@imodules.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Josh Wicoff"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://hotfixpub1.imodules.com/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Imodules Software, Inc."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.imodules.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Imodules Software, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hotfixpubsecure.imodules.com/controls/login/AssertionConsumerService.aspx?sid=6&gid=2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBDCCAeygAwIBAgIQzEDukSw9R5BHpxVmr1UwFjANBgkqhkiG9w0BAQQFADAX\nMRUwEwYDVQQDEwxpbW9kdWxlcy5jb20wHhcNMTQwNjEwMjExODU3WhcNMzQwNjEw\nMjExODU2WjAXMRUwEwYDVQQDEwxpbW9kdWxlcy5jb20wggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQDC5hlDfEQ7RoqQgtcZjOxN2FdUOMu4MI8hIeydiFDy\n1fT1t1jJHmFF5V4JDGpITIapK2caenljBcGl7CGC+Z6EXID8i0lxc7lLWOOrYkJb\n8PeuVOpbxTZfOxfkC3jf4IfLZPtBfDvWjYtVUPwDCpwLLE/GQzz6HySoMIcWAkQ9\nbPoAIITTRnDpo1f4J6nO81DKx0XjBVIbz6aTsF60pcXQzLJ69KGI5Jkh3DjmNbeq\nEXH6ENtq823q4JGXRrKvCPrTlt+79EI1p+ECSaRUx006raAYHktUTT2KY1oUlsuk\nqVA+LMmhX/+jF1fgOehHEurOiKQp2aGmeV4PnJ8pXKM9AgMBAAGjTDBKMEgGA1Ud\nAQRBMD+AEG94Y5yfOU4e+OzhpzVt1UyhGTAXMRUwEwYDVQQDEwxpbW9kdWxlcy5j\nb22CEMxA7pEsPUeQR6cVZq9VMBYwDQYJKoZIhvcNAQEEBQADggEBAFDDvIjK8eJO\nYjDqnY9DfzUEN6Vp80w3ZLhT/K49/McNbbGkt0bgg45MeJ78IxLdclTIhOEeHACN\nF71+XLb9PjRfISiB37V157w0nKF5MsMYU1dathFrVOzCIxvhERgoD4lMNtwZiKKH\nJ/xYeczpnHz5iFpoiCvsvPTP5sZqAKvf5ovpermVcLyqEPJJHvLHe+TbwdwTuGMS\npF2w1WQGpSgdbcxWWwmwpbeiF5ADI6UTS5txOfG0p8L2RTxgRJ6Nb7lNrelIEcup\n6nWHUla/60ENe+AN9qsqYh1vnknLi7kSMHwvtyzFQDHnXhwhLa9mkpsZVkeLEGsR\nMJlfQnuceWY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "iModules Hotfix Test"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://login.cedia.org.ec",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chacon"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "neg@cedia.org.ec"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Claudio"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.cedia.org.ec",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.cedia.org.ec/minga"
              },
              {
                "lang": "es",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.cedia.org.ec/minga"
              }
            ],
            "registration_instant": "2014-11-27T00:00:00Z",
            "registration_authority": "https://minga.cedia.org.ec",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.cedia.org.ec/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.cedia.org.ec/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cedia.org.ec"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "epn.edu.ec"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tecnologicoitca.edu.ec"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucuenca.edu.ec"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uta.edu.ec"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utb.edu.ec"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.cedia.org.ec"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.cedia.org.ec"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "redCEDIA - Ecuadorian National Research and Education Network"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "redCEDIA - Red nacional de Investigaci\u00f3n y Educaci\u00f3n del Ecuador"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "redCEDIA - Ecuadorian National Research and Education Network"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "redCEDIA - Red nacional de Investigaci\u00f3n y Educaci\u00f3n del Ecuador"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.cedia.org.ec/logocedia400x200.png",
                    "lang": "en",
                    "height": "200",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "400"
                  },
                  {
                    "text": "https://www.cedia.org.ec/images/logoredcediaweb.png",
                    "height": "103",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "376"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.cedia.org.ec"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.cedia.org.ec"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "redCEDIA"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "redCEDIA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.cedia.org.ec"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "redCEDIA"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "redCEDIA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.westking.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chaggar"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Inderpal.Chaggar@westking.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Inderpal"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chaggar"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Inderpal.Chaggar@westking.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Inderpal"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.westking.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-08-03T14:58:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDijCCAnICCQDsX92sZyIapDANBgkqhkiG9w0BAQUFADCBhjELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxDzANBgNVBAgTBkxvbmRvbjEbMBkGA1UEBxMSMjExIEdyYXlzIElubiBSb2Fk\n\t\t\t\t\t\tMSUwIwYDVQQKExxXZXN0bWluc3RlciBLaW5nc3dheSBDb2xsZWdlMSIwIAYDVQQD\n\t\t\t\t\t\tExlzaGliYm9sZXRoLndlc3RraW5nLmFjLnVrMB4XDTE0MDQwOTA5NTIzMVoXDTM0\n\t\t\t\t\t\tMDQwNDA5NTIzMVowgYYxCzAJBgNVBAYTAkdCMQ8wDQYDVQQIEwZMb25kb24xGzAZ\n\t\t\t\t\t\tBgNVBAcTEjIxMSBHcmF5cyBJbm4gUm9hZDElMCMGA1UEChMcV2VzdG1pbnN0ZXIg\n\t\t\t\t\t\tS2luZ3N3YXkgQ29sbGVnZTEiMCAGA1UEAxMZc2hpYmJvbGV0aC53ZXN0a2luZy5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN7zCFR0dysInbEU\n\t\t\t\t\t\tt/zyXqB++zmwMY8p6aZqQQ3lvHWVLPOTXNqXpEXygu6v+mlg2fV3SJhnJJcZU/uS\n\t\t\t\t\t\tluUn9pAZooB5ROZv8I/IpPl2UH0d0v5qf0FNwnebH9RmGhtElkFSdplGEN1j8hux\n\t\t\t\t\t\tX1jx6/693zj99WZPSWNpYMdFezMYnXjpVvU92GHO0C6iC6hwIaI+7RECgP0Ly8oy\n\t\t\t\t\t\tRTvba+OAcPivfED7dTfFMj6H4vjC6nNjP71mqAjhd0yRr+4piJm0q94fREi2HvzZ\n\t\t\t\t\t\tHpu97MC717l3FOgtytKycjrOuw/YpVOuXaOdbUnEPlnc2BYg1h+1QFx+Rr1l0Py9\n\t\t\t\t\t\tJh1MPfUCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAHj/mYxaOUqQyhiTnJrDAAfrj\n\t\t\t\t\t\tzgUA6Eoiba5DDqQnKXh33wcQms3fAXRgAX05gzFWg3u8Vdhsy1ZqTpciehiJ1fLF\n\t\t\t\t\t\tM8Xx1VkrRL5tfPGg/yVYCN5Xu8FQTzrlZ0LwVLXt92DjzaibfWDzFeraUXDdswFT\n\t\t\t\t\t\tbKSORgtYFUWhQUplo8lZ5o/eDOyrhxktqBlRzfm6E8McZraYSEK67MGgKC+7npdD\n\t\t\t\t\t\tVMItRsiEAyRjKrCKpI3OKMVlG7zIXsT9NHJhdgswP9F0aSZMqshJlwqzLo+JojfZ\n\t\t\t\t\t\ti8cWVtd1PUDIV3RJapAS+tcUTOFIirh1kTv4pD5VvRfSPYabAuXCAvU9jfnlsQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "westking.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.westking.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.westking.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.westking.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.westking.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.westking.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.westking.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.westking.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.westking.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "westking.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDijCCAnICCQDsX92sZyIapDANBgkqhkiG9w0BAQUFADCBhjELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxDzANBgNVBAgTBkxvbmRvbjEbMBkGA1UEBxMSMjExIEdyYXlzIElubiBSb2Fk\n\t\t\t\t\t\tMSUwIwYDVQQKExxXZXN0bWluc3RlciBLaW5nc3dheSBDb2xsZWdlMSIwIAYDVQQD\n\t\t\t\t\t\tExlzaGliYm9sZXRoLndlc3RraW5nLmFjLnVrMB4XDTE0MDQwOTA5NTIzMVoXDTM0\n\t\t\t\t\t\tMDQwNDA5NTIzMVowgYYxCzAJBgNVBAYTAkdCMQ8wDQYDVQQIEwZMb25kb24xGzAZ\n\t\t\t\t\t\tBgNVBAcTEjIxMSBHcmF5cyBJbm4gUm9hZDElMCMGA1UEChMcV2VzdG1pbnN0ZXIg\n\t\t\t\t\t\tS2luZ3N3YXkgQ29sbGVnZTEiMCAGA1UEAxMZc2hpYmJvbGV0aC53ZXN0a2luZy5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN7zCFR0dysInbEU\n\t\t\t\t\t\tt/zyXqB++zmwMY8p6aZqQQ3lvHWVLPOTXNqXpEXygu6v+mlg2fV3SJhnJJcZU/uS\n\t\t\t\t\t\tluUn9pAZooB5ROZv8I/IpPl2UH0d0v5qf0FNwnebH9RmGhtElkFSdplGEN1j8hux\n\t\t\t\t\t\tX1jx6/693zj99WZPSWNpYMdFezMYnXjpVvU92GHO0C6iC6hwIaI+7RECgP0Ly8oy\n\t\t\t\t\t\tRTvba+OAcPivfED7dTfFMj6H4vjC6nNjP71mqAjhd0yRr+4piJm0q94fREi2HvzZ\n\t\t\t\t\t\tHpu97MC717l3FOgtytKycjrOuw/YpVOuXaOdbUnEPlnc2BYg1h+1QFx+Rr1l0Py9\n\t\t\t\t\t\tJh1MPfUCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAHj/mYxaOUqQyhiTnJrDAAfrj\n\t\t\t\t\t\tzgUA6Eoiba5DDqQnKXh33wcQms3fAXRgAX05gzFWg3u8Vdhsy1ZqTpciehiJ1fLF\n\t\t\t\t\t\tM8Xx1VkrRL5tfPGg/yVYCN5Xu8FQTzrlZ0LwVLXt92DjzaibfWDzFeraUXDdswFT\n\t\t\t\t\t\tbKSORgtYFUWhQUplo8lZ5o/eDOyrhxktqBlRzfm6E8McZraYSEK67MGgKC+7npdD\n\t\t\t\t\t\tVMItRsiEAyRjKrCKpI3OKMVlG7zIXsT9NHJhdgswP9F0aSZMqshJlwqzLo+JojfZ\n\t\t\t\t\t\ti8cWVtd1PUDIV3RJapAS+tcUTOFIirh1kTv4pD5VvRfSPYabAuXCAvU9jfnlsQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Westminster Kingsway College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.westking.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Westminster Kingsway College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp-unitus-prod.cineca.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Menicacci"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webmaster@unitus.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Maurizio"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-unitus-prod.cineca.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2015-04-20T08:30:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE8zCCA9ugAwIBAgICB58wDQYJKoZIhvcNAQEFBQAwgbUxCzAJBgNVBAYTAklU\nMQ4wDAYDVQQIEwVJdGFseTEhMB8GA1UEBxMYQ2FzYWxlY2NoaW8gZGkgUmVubyAo\nQk8pMSwwKgYDVQQKEyNDSU5FQ0EgQ29uc29yemlvIEludGVydW5pdmVyc2l0YXJp\nbzENMAsGA1UECxMERFNFVDEQMA4GA1UEAxMHRFNFVCBDQTEkMCIGCSqGSIb3DQEJ\nARYVc2VydmljZWRlc2tAY2luZWNhLml0MB4XDTE1MDMwOTE2NTgwMVoXDTE4MDMw\nODE2NTgwMVowgaYxCzAJBgNVBAYTAklUMQ4wDAYDVQQIEwVJdGFseTEhMB8GA1UE\nBxMYQ2FzYWxlY2NoaW8gZGkgUmVubyAoQk8pMSwwKgYDVQQKEyNDSU5FQ0EgQ29u\nc29yemlvIEludGVydW5pdmVyc2l0YXJpbzENMAsGA1UECxMERFNFVDEnMCUGA1UE\nAxMec2FtbC11bml0dXMtaWRwLXByb2QuY2luZWNhLml0MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAosNTObNDAdBrEkQ/EkdHvTeD5XYXGQp3O4LEyXwk\nwfZHMTF3Ve0uFgNcRlj65KkcMHaldnXne4KjbtLSBONMrc7QSmruPhr3plJlqxK6\n3SbQAQSOYEjEwFn889LDdYXTX7hfduF0Y379tsTfHqiixhj+HF2/fTWYjQOKLLBf\nztcs3qRZThG4vbUfQk2qyErzNwyH1bBum8tkTSlgO1URvRt69d+WIpDV82kvjTAf\nnzqEiNrOtlKhqWQyHpe9He3a34np0KpCyW2m/uPDyubVjTIdGfA1NjVJWzmDD5XY\nruNFkceohNcaInKz/OzKzXjh08MNM+GHSgiJ92XldG0h6wIDAQABo4IBGDCCARQw\nCQYDVR0TBAIwADARBglghkgBhvhCAQEEBAMCBkAwHQYDVR0OBBYEFFGdL7ioyAYY\npmlePOrulCSc5O+HMIHUBgNVHSMEgcwwgcmhgbukgbgwgbUxCzAJBgNVBAYTAklU\nMQ4wDAYDVQQIEwVJdGFseTEhMB8GA1UEBxMYQ2FzYWxlY2NoaW8gZGkgUmVubyAo\nQk8pMSwwKgYDVQQKEyNDSU5FQ0EgQ29uc29yemlvIEludGVydW5pdmVyc2l0YXJp\nbzENMAsGA1UECxMERFNFVDEQMA4GA1UEAxMHRFNFVCBDQTEkMCIGCSqGSIb3DQEJ\nARYVc2VydmljZWRlc2tAY2luZWNhLml0ggkAj5pklc/pVTswDQYJKoZIhvcNAQEF\nBQADggEBANPIDlafdZ/9lcfZ5X/UMJdVNFZuWSJxJAiHJK10Q2+9IN1XDaoBWGOV\na7/HPzgOd2oYMCpAm/yu/9zg74M0sSMvjODAa6y1kVTEjLx+UCjsyWyPVZD3Xj97\nZJ9x9ZgTf0HOH1GRdQuOhTKa2F4esWEpvNgud0unSEt5/l8Qhz3ejHsAPuMJymb+\nqdwba7WvaoL4eyGeUMFwFyg2wQdNeMW7/APQFMGz9qX2yq4vnnwjwFzeWR+euXPs\nLWxendzaDigSKZxGj2JNiAySgZ2su+k2h07itO1VPGi/HhlbC+Cd+AndH8zGjFHf\nN2UAjpeR7GCIUbqf35pg6y/RlJFI46w="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unitus.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unitus.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unitus.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unitus.it:443/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unitus.it:443/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.unitus.it:443/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unitus.it:443/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.unitus.it:443/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unitus.it:443/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unitus.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unitus.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unitus.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idp.unitus.it/static/help.html"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idp.unitus.it/static/help.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universita' Studi della Tuscia"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universita' Studi della Tuscia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider di produzione utenti Tuscia"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider production users Tuscia"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.unitus.it/static/logo.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://idp.unitus.it/static/help.html"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://idp.unitus.it/static/help.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE8zCCA9ugAwIBAgICB58wDQYJKoZIhvcNAQEFBQAwgbUxCzAJBgNVBAYTAklU\nMQ4wDAYDVQQIEwVJdGFseTEhMB8GA1UEBxMYQ2FzYWxlY2NoaW8gZGkgUmVubyAo\nQk8pMSwwKgYDVQQKEyNDSU5FQ0EgQ29uc29yemlvIEludGVydW5pdmVyc2l0YXJp\nbzENMAsGA1UECxMERFNFVDEQMA4GA1UEAxMHRFNFVCBDQTEkMCIGCSqGSIb3DQEJ\nARYVc2VydmljZWRlc2tAY2luZWNhLml0MB4XDTE1MDMwOTE2NTgwMVoXDTE4MDMw\nODE2NTgwMVowgaYxCzAJBgNVBAYTAklUMQ4wDAYDVQQIEwVJdGFseTEhMB8GA1UE\nBxMYQ2FzYWxlY2NoaW8gZGkgUmVubyAoQk8pMSwwKgYDVQQKEyNDSU5FQ0EgQ29u\nc29yemlvIEludGVydW5pdmVyc2l0YXJpbzENMAsGA1UECxMERFNFVDEnMCUGA1UE\nAxMec2FtbC11bml0dXMtaWRwLXByb2QuY2luZWNhLml0MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAosNTObNDAdBrEkQ/EkdHvTeD5XYXGQp3O4LEyXwk\nwfZHMTF3Ve0uFgNcRlj65KkcMHaldnXne4KjbtLSBONMrc7QSmruPhr3plJlqxK6\n3SbQAQSOYEjEwFn889LDdYXTX7hfduF0Y379tsTfHqiixhj+HF2/fTWYjQOKLLBf\nztcs3qRZThG4vbUfQk2qyErzNwyH1bBum8tkTSlgO1URvRt69d+WIpDV82kvjTAf\nnzqEiNrOtlKhqWQyHpe9He3a34np0KpCyW2m/uPDyubVjTIdGfA1NjVJWzmDD5XY\nruNFkceohNcaInKz/OzKzXjh08MNM+GHSgiJ92XldG0h6wIDAQABo4IBGDCCARQw\nCQYDVR0TBAIwADARBglghkgBhvhCAQEEBAMCBkAwHQYDVR0OBBYEFFGdL7ioyAYY\npmlePOrulCSc5O+HMIHUBgNVHSMEgcwwgcmhgbukgbgwgbUxCzAJBgNVBAYTAklU\nMQ4wDAYDVQQIEwVJdGFseTEhMB8GA1UEBxMYQ2FzYWxlY2NoaW8gZGkgUmVubyAo\nQk8pMSwwKgYDVQQKEyNDSU5FQ0EgQ29uc29yemlvIEludGVydW5pdmVyc2l0YXJp\nbzENMAsGA1UECxMERFNFVDEQMA4GA1UEAxMHRFNFVCBDQTEkMCIGCSqGSIb3DQEJ\nARYVc2VydmljZWRlc2tAY2luZWNhLml0ggkAj5pklc/pVTswDQYJKoZIhvcNAQEF\nBQADggEBANPIDlafdZ/9lcfZ5X/UMJdVNFZuWSJxJAiHJK10Q2+9IN1XDaoBWGOV\na7/HPzgOd2oYMCpAm/yu/9zg74M0sSMvjODAa6y1kVTEjLx+UCjsyWyPVZD3Xj97\nZJ9x9ZgTf0HOH1GRdQuOhTKa2F4esWEpvNgud0unSEt5/l8Qhz3ejHsAPuMJymb+\nqdwba7WvaoL4eyGeUMFwFyg2wQdNeMW7/APQFMGz9qX2yq4vnnwjwFzeWR+euXPs\nLWxendzaDigSKZxGj2JNiAySgZ2su+k2h07itO1VPGi/HhlbC+Cd+AndH8zGjFHf\nN2UAjpeR7GCIUbqf35pg6y/RlJFI46w="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universita' Studi della Tuscia"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universita' Studi della Tuscia"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www3.unitus.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www3.unitus.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universita' degli Studi della Tuscia"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universita' degli Studi della TusciaTuscia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/wayfa.efif.dk/vor/module.php/saml/sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/wayfa.efif.dk/vor/module.php/saml/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2011-08-31T12:35:39Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/wayfa.efif.dk/vor/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vordingborg-gym.dk"
              },
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Vordingborg Gymnasium & HF"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Vordingborg Gymnasium and Higher Prep Exam"
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Vordingborg Gymnasium & HF"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Vordingborg Gymnasium and Higher Prep Exam"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "vordingborg-gym.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4jCCAcoCAQcwDQYJKoZIhvcNAQELBQAwNzE1MDMGA1UEAwwsaHR0cHM6Ly93\nYXlmYS5lZmlmLmRrL3Zvci9tb2R1bGUucGhwL3NhbWwvc3AwHhcNMTUwMTAxMDAw\nMDAwWhcNMjUxMjMxMjM1OTU5WjA3MTUwMwYDVQQDDCxodHRwczovL3dheWZhLmVm\naWYuZGsvdm9yL21vZHVsZS5waHAvc2FtbC9zcDCCASIwDQYJKoZIhvcNAQEBBQAD\nggEPADCCAQoCggEBAMeIDApqEFO4jhn4gnWuA54SIILLdtH1Ah7cGkKx6MUJTmtL\nORYA2pW5zU8N+nQl0hmGs9eyYMlAyaJ08IY8gNAqj5uT5p/f4RQVL8j/7fmxIFfa\n9/6HUMe9lX2OzOealJWOnsdn9ag9YHKRYEk7QA5WbMHnOVqqRLfonvr7DF6vB2m4\nTFWdhI13vdL4DJP8Rn61cA77qVDwUv9gyUmdSRJpKotIcXLTUPaoE2ZhHAGkJLr9\n1RnLGLS3mPyCEpQPgEc5lVq+frknrZwl1eI5wxHJQAinnsZdCsvrcq2uMhxd12r4\nJnJnm3fsR1Q4jPjaOgVzLvcwU6e3KeUoS87DUEkCAwEAATANBgkqhkiG9w0BAQsF\nAAOCAQEAJUgv1wvoIuG7a8ojCGkBrbBDaUCkxIjXk5zICqrxAklwntByXEBowyo7\n6IxjXe0bYDz75kqf4l0yQQN/ENGAfdOf/Q1+pwKamQgCAVdPp/DIXppEci2KCuKh\ncTuIlPq5d15eDDc1nmmNwAxno/rbZrJfcTYFhilIVrh8SeOWUR4aaH/7lt5DaUoU\nwg1jaKgOGwDpiDMjm32YgZshdcKFnuJnHHYVbNY/6eKq8e79ynXV813+syVgnHkE\nvENDaE1u+5vQCZMkedatnmEe4tkT9LYoSD3l9/S8so1kgGfHsNk7Dv25wXZiKX+o\nAKktIsPch1tYllp+fb1/Be5pd2o+Aw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Vordingborg Gymnasium & HF"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Vordingborg Gymnasium and Higher Prep Exam"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vordingborg-gym.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vordingborg-gym.dk/in-english"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Vordingborg Gymnasium & HF"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Vordingborg Gymnasium and Higher Prep Exam"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://tonga.univ-tlse2.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sos-ent@univ-tlse2.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://tonga.univ-tlse2.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2011-05-16T16:09:53Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://tonga.univ-tlse2.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://tonga.univ-tlse2.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://tonga.univ-tlse2.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "etu.univ-tlse2.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-tlse2.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-tlse2.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 Toulouse 2 - Mirail"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 Toulouse 2 - Mirail"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUQbZllpbGntiDN9DdmDU44ciWEDswDQYJKoZIhvcNAQEF\nBQAwHjEcMBoGA1UEAxMTdG9uZ2EudW5pdi10bHNlMi5mcjAeFw0xNjAxMTMxMDUx\nNDJaFw0zNjAxMTMxMDUxNDJaMB4xHDAaBgNVBAMTE3RvbmdhLnVuaXYtdGxzZTIu\nZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCA0T3HP65ZGC0a/vYR\n0I+1PbrKIESr9B9GR+o5Xp0tZrWrfIicruZN9MQegbNFGljZZD7Rh+K+lAc88ldg\nvVtHQ4/TyKoQdJ9vr7pZulpX8GZvjqW5tzEKffgodD5DD5puavdOzZfjPpn9AfGn\nZlh9j3Ieix8T6ljyXal0D6CKkDoSEh1UbR4qoPfKZMw03FnPhHqrrsh/rHCvnvay\ndq1oImc13egyht8doHXAiUV5dJVlZLM6cMhPG/CZaWKElRiRDousClWuW+oycuiE\nyGTfGux6Cx0XemrgcOsxfeLa21W5CgmsHlXU0TUoB46mogwQmEeadkVffES4KjTe\nF33rAgMBAAGjbTBrMEoGA1UdEQRDMEGCE3RvbmdhLnVuaXYtdGxzZTIuZnKGKmh0\ndHBzOi8vdG9uZ2EudW5pdi10bHNlMi5mci9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4E\nFgQUF1ZOiJWk610K3A3j3LD4dZnaNR4wDQYJKoZIhvcNAQEFBQADggEBAHMW515o\npdz7jP3Zh3WL28+DKd3aHimRKPYVfj1A32BYwUo8WA1eDTwV0DZQ2fKG/UbEI74x\nxQMNMnXKw4vwAVpHPb0mqg/ggiFcwlCtNluVb/eIttP3IkIiL7fC1nHvJZuGXrrB\n4Fl+/rbzwXdoHdGbYU00pGFLjNo8tysxkUrPVM5Zay0J7BDovAsgPQpU2mda4fjU\ndsHfixpvq7vbAS6Oo+UR0zrKG8BEjeP2tFQ8Y7U7DLrATeJZvMn1qVbNB9X274Vu\nEDB2WEO1/Lcq5hSZZVBL8UGwoDmsn6qOW9t5/cyg/PUwB1ekdNWJvf6ctNIN1Xem\nFy4XmXwhuCgSQF4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEczCCA1ugAwIBAgIQbZHE6LrL3tqFs4H2fek89zANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDIyNTAwMDAwMFoXDTE2MDIyNTIzNTk1OVowQTEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRwwGgYDVQQDExN0b25nYS51bml2\nLXRsc2UyLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA7uSHCtcm\nnpL8YfTCrzbfh/cn2+8KrKbkwXmvc08AEmB/KjifNxaSpnwDCe51yj4efbX/A2KC\nF6UkV9aebsg0yf57+dWVtkAdJZNxtKkj3X/vxa/8DLrFLUNuMrA0K2C+UvT4iahM\nZ7Wn61vXYuyVcjH1akY/zjDOEAGcLCw4PsEfBOyamQ3rjddnJydD2c7swQgWmKA9\nuq8bZ94uHoiEIxGUHx3LwsHeS83mBqCPE1VHFeqGkT5KvUlyXyVNiD4YuIzYhLPo\nOUN5l5VL9DTYJfl1XGTdJ3OETIsgckzzPQuAT7BPqV/063tRKfxs8OVz2af6S85L\nxRbt6XYYPrRbjwIDAQABo4IBcDCCAWwwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsr\nN1dH6pDjue0wHQYDVR0OBBYEFKgyHfbTQ+G2wcZU0Xm2N40iXCg4MA4GA1UdDwEB\n/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEF\nBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8E\nMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENB\nLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNz\nLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8v\nb2NzcC50Y3MudGVyZW5hLm9yZzAeBgNVHREEFzAVghN0b25nYS51bml2LXRsc2Uy\nLmZyMA0GCSqGSIb3DQEBBQUAA4IBAQBW18y/vhfzJr590f4NlYZFpKQdxuM3wrz0\nLwyt8I0It1K5Axlb+0nCJcx1Wq9U5A7ZSJ/3R9LuhiYJYYeRGcgC12ecrO2JudXZ\n7+6WxjxuO+cfOMAx5Z2ymnLhRlSJlUhg4rSxEgWghxHtoXd/WFrgwv1Redy+fJSB\nyYOY5hOM9Nzxqq7dlvX91gr6aVTxS7Jke9Aje0Ti9jvas0RX5oJB3ItgVEqCIWRH\n4mlCAjYakzm6ucPqhPmbAupbA8CrMDl37ubPxFKnlDUqp02A1MwDJdUJ80A0f6Ce\n2CYly5GL5m70YorIGMbI46RWO/CgfsNzyphB/QHvtodxSrW/3YYs"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 Toulouse 2 - Mirail"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-tlse2.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 Toulouse 2 - Mirail"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.silverchair.com/esbates/production/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ShibbolethAdmin@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hirst"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:khirst@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kevin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.silverchair.com/esbates/production/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-03-05T09:19:39Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Silverchair Production: Wolters Kluwer Bates Visual Guide Spanish"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://batesguiavisual.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Silverchair Science + Communications, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://batesguiavisual.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://batesguiavisual.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://batesguiavisual.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://batesguiavisual.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://batesguiavisual.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://batesguiavisual.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJALin0XFwb82yMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\n\t\t\t\t\t\tBAMTFXNjbS1wcm9kd2ViMDEuc2lzLmxhbjAeFw0xNTAzMDMxNTQyNDJaFw0yNTAy\n\t\t\t\t\t\tMjgxNTQyNDJaMCAxHjAcBgNVBAMTFXNjbS1wcm9kd2ViMDEuc2lzLmxhbjCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALsi9y2ljlDuMGn64lhRsO1Q7MYo\n\t\t\t\t\t\tppIQ2Mm49zT3/7b9eEW+8DLIdhJocmwturiTb7Z+3LqVhuoRsBtAFq2xb3rh7Tv3\n\t\t\t\t\t\txc9jAeig/M3Sf4lEdr51hkQMZ2lfIyQNXEwCejKt8/al3i3CBAedBf/M3GeU53AC\n\t\t\t\t\t\tlAKWbfs6jHbN2kE2rWbex8YxazX1tJARdbtBx9tujie7W/tOj2iVd5C6eqpsU5Zu\n\t\t\t\t\t\tPvKKsmUQ8I0jIJa+eF/FSp+cKW8uXWLWx1l2S9HJme4vOBi1XGtLpjSn4VGOsF2p\n\t\t\t\t\t\tbs5sHMyV5eApcSLVBaqZnHcE9HMoHhsjKLnme6JbJ826rtaCxLRXqr59lF0CAwEA\n\t\t\t\t\t\tAaNDMEEwIAYDVR0RBBkwF4IVc2NtLXByb2R3ZWIwMS5zaXMubGFuMB0GA1UdDgQW\n\t\t\t\t\t\tBBS2/5NIi4BwDPX6NXCg/cdzKP1RYjANBgkqhkiG9w0BAQUFAAOCAQEAcfRfLZgf\n\t\t\t\t\t\tsZJ4U3auPGf6GCBzs1QjJUzNgIiL7IZOEHPE1ezvRMbBpxu5iXfuXU8mxFPTDtXE\n\t\t\t\t\t\tKgRl0qPEZrtW5h/LZd97CcbA71WohAznkjzIAUOCHVBSfOCcstr3HbnCQ3LglCrC\n\t\t\t\t\t\tYJQNwFhNRu0e2gbapN4xlKap+YS9akyd4i+ODD3Rj5jbxDbqlErDkwII6923Jo+s\n\t\t\t\t\t\tHeKVBNQD3godVRJn/UlzOYvLfN4l3aS8VpRv1plf9gMPe1TF2ei+1LX1sRspFqqm\n\t\t\t\t\t\tbCcqOJmtKjzk1/DIfnKQ4av6pqbdsJCtZI2gFo2qTPtZK3mJJjew8qOmIqUnbEIj\n\t\t\t\t\t\tj3IeauG38pyehw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://batesguiavisual.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://batesguiavisual.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://batesguiavisual.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://batesguiavisual.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://batesguiavisual.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://batesguiavisual.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.gla.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@it.gla.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "User Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Anderson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:d.anderson@compserv.gla.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.gla.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2007-09-19T15:05:41Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIJALu/c0dZr5HvMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGG1pbG5nYXZpZS5jZW50LmdsYS5hYy51azAeFw0xNTA3MDgwOTMwMDRaFw0y\n\t\t\t\t\t\tNTA3MDUwOTMwMDRaMCMxITAfBgNVBAMTGG1pbG5nYXZpZS5jZW50LmdsYS5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMCmMFy3+cEAbb32fmt1\n\t\t\t\t\t\tKKDupzffR58n1wxNVxVl6pOvaoLAQMpNL0bmZ+tVQFyNwqrMf9fWqcGgOks8q3PL\n\t\t\t\t\t\tAJfgki/J8Aee9ZmYmJjcTHA6C1SPGG7CyUHoea1CWuhOWPl9zI2AhfCZlse57CuL\n\t\t\t\t\t\tWBkMnK+cTZ2wV3UXnUYf6UqsFsD76l+/twGitqyyBO1HDS/r26jhRz0kdxYUaP1q\n\t\t\t\t\t\t5TKqgbGcfGsBFVek9CuRCb6scDxEqwRT2g5ilktBoMLQ8CUlZ/By5t4Iq7juoWw3\n\t\t\t\t\t\tzcMxD3QOkenQSBakYWTHpuxMzloJLnZq/7tKKq8EtHLlWFTOELvE75Naco7vsdxH\n\t\t\t\t\t\t+3sCAwEAAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBH\n\t\t\t\t\t\tZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFL36+xUfcTRDzqjdEkeBHLK3\n\t\t\t\t\t\tnLjIMB8GA1UdIwQYMBaAFL36+xUfcTRDzqjdEkeBHLK3nLjIMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQAm2mIyoqYsTh+xG2JM1JMBh9XYHcv3an0m1hJKr9LBpUsGF0z4LZOT\n\t\t\t\t\t\tUspSvK/uCMrjM7+Ga1PyAzd0MZsH/QCSYIlA7MtDSneWkOkib2pxMygxBSyMkxKo\n\t\t\t\t\t\t1+OKUrSrnqNFZSYyQe82L4wGet3UibP82tQJNAr15f3KCy0p5C7adRLWxDyoIjit\n\t\t\t\t\t\tHVKZLW3laxlBiiUBLY3jmaeZ0biLM3KIFgDSL2M1aBDHqquexHoZst4EQXpam9aI\n\t\t\t\t\t\tRlkVhC02pga9ohbCFw4Hv0ZfqMvRxDS5J+KsZpudx17DXrPjkBxTHWtZ02t/WOyS\n\t\t\t\t\t\t37U4ys02cmPuuNCVlsTarDiF2R1ZNCMt"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gla.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://milngavie.cent.gla.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://milngavie.cent.gla.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://milngavie.cent.gla.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://milngavie.cent.gla.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://milngavie.cent.gla.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://milngavie.cent.gla.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://milngavie.cent.gla.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://milngavie.cent.gla.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gla.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://milngavie.cent.gla.ac.uk/UoG_colour_80x60.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://milngavie.cent.gla.ac.uk/UoG_colour_16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Glasgow"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "gla.ac.uk"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:55.8719,4.2875"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.209.0.0/16"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIJALu/c0dZr5HvMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGG1pbG5nYXZpZS5jZW50LmdsYS5hYy51azAeFw0xNTA3MDgwOTMwMDRaFw0y\n\t\t\t\t\t\tNTA3MDUwOTMwMDRaMCMxITAfBgNVBAMTGG1pbG5nYXZpZS5jZW50LmdsYS5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMCmMFy3+cEAbb32fmt1\n\t\t\t\t\t\tKKDupzffR58n1wxNVxVl6pOvaoLAQMpNL0bmZ+tVQFyNwqrMf9fWqcGgOks8q3PL\n\t\t\t\t\t\tAJfgki/J8Aee9ZmYmJjcTHA6C1SPGG7CyUHoea1CWuhOWPl9zI2AhfCZlse57CuL\n\t\t\t\t\t\tWBkMnK+cTZ2wV3UXnUYf6UqsFsD76l+/twGitqyyBO1HDS/r26jhRz0kdxYUaP1q\n\t\t\t\t\t\t5TKqgbGcfGsBFVek9CuRCb6scDxEqwRT2g5ilktBoMLQ8CUlZ/By5t4Iq7juoWw3\n\t\t\t\t\t\tzcMxD3QOkenQSBakYWTHpuxMzloJLnZq/7tKKq8EtHLlWFTOELvE75Naco7vsdxH\n\t\t\t\t\t\t+3sCAwEAAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0EHxYdT3BlblNTTCBH\n\t\t\t\t\t\tZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFL36+xUfcTRDzqjdEkeBHLK3\n\t\t\t\t\t\tnLjIMB8GA1UdIwQYMBaAFL36+xUfcTRDzqjdEkeBHLK3nLjIMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQAm2mIyoqYsTh+xG2JM1JMBh9XYHcv3an0m1hJKr9LBpUsGF0z4LZOT\n\t\t\t\t\t\tUspSvK/uCMrjM7+Ga1PyAzd0MZsH/QCSYIlA7MtDSneWkOkib2pxMygxBSyMkxKo\n\t\t\t\t\t\t1+OKUrSrnqNFZSYyQe82L4wGet3UibP82tQJNAr15f3KCy0p5C7adRLWxDyoIjit\n\t\t\t\t\t\tHVKZLW3laxlBiiUBLY3jmaeZ0biLM3KIFgDSL2M1aBDHqquexHoZst4EQXpam9aI\n\t\t\t\t\t\tRlkVhC02pga9ohbCFw4Hv0ZfqMvRxDS5J+KsZpudx17DXrPjkBxTHWtZ02t/WOyS\n\t\t\t\t\t\t37U4ys02cmPuuNCVlsTarDiF2R1ZNCMt"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Glasgow"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gla.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Glasgow"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://uk-coventry-shibboleth.moveon4.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tabassum"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kamran@zeptosystems.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kamran"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Latif"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mubashar.latif@zeptosystems.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mubashar"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://uk-coventry-shibboleth.moveon4.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-11-02T10:53:16Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "qsu-unisolution"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qs-unisolution.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "QS unisolution GmbH"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uk-coventry-shibboleth.moveon4.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://uk-coventry-shibboleth.moveon4.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uk-coventry-shibboleth.moveon4.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uk-coventry-shibboleth.moveon4.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uk-coventry-shibboleth.moveon4.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://uk-coventry-shibboleth.moveon4.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://uk-coventry-shibboleth.moveon4.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "qsu-unisolution"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFgzCCA2ugAwIBAgIJAJdEyesPxkXQMA0GCSqGSIb3DQEBCwUAMFgxCzAJBgNV\n\t\t\t\t\t\tBAYTAkRFMRwwGgYDVQQKDBNRUyB1bmlzb2x1dGlvbiBHbWJIMSswKQYDVQQDDCJ1\n\t\t\t\t\t\tay1jb3ZlbnRyeS1zaGliYm9sZXRoLm1vdmVvbjQuY29tMB4XDTE1MTAyODEyMDIw\n\t\t\t\t\t\tNloXDTIwMTAyNjEyMDIwNlowWDELMAkGA1UEBhMCREUxHDAaBgNVBAoME1FTIHVu\n\t\t\t\t\t\taXNvbHV0aW9uIEdtYkgxKzApBgNVBAMMInVrLWNvdmVudHJ5LXNoaWJib2xldGgu\n\t\t\t\t\t\tbW92ZW9uNC5jb20wggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQDrZPOQ\n\t\t\t\t\t\ts9BEz57wgnQ0TI3bRWQcGrgeSkRqAubsKN2gcQ3133JKDcH9rPaaF0nlGMjAIokl\n\t\t\t\t\t\tODSukuEE8lGIu4dx4k7W7mkhvHW3JI2PrrA7DmjMaWDGHU8zxCKdQ7GVFUMeVPp+\n\t\t\t\t\t\t/b+NJQJA3sbCEwQTCbMGokfL3ZWt7xUGzy5xOl1KMfUzJ+pF6c1Wild33NJDzdGJ\n\t\t\t\t\t\tCVwC19HbvFYeqagWdk1yEQrdJh4fQJMiG2yIoTyhVadsZGUXS5fyWLStWhqiwkEA\n\t\t\t\t\t\tFz8YoZHYcSi8yFLp5fn8uIMSEeQXycyiZy+ZgRXvpE7t/Ped/EL7T58eHF28QNFm\n\t\t\t\t\t\tasbiTvBtPm0kuEYbG5GDP/d4W6cL+3JozKa6QgfaJoxIvTYdpp/dzb0bfTKCrsSz\n\t\t\t\t\t\tgdetdeQ377OtXmDKeqyx/WsMqniRNe+VWwCJjohEORyugrRRq+W+TcWoNNSe/ZFM\n\t\t\t\t\t\tS6VPJsu8XANUDnN1s9DPdrVa6MnmGQ9+s6nkm0Sj6EGMLorPGz2oshxWBvOoMyD1\n\t\t\t\t\t\tA9hPtfyIfECH5tR5Pr0NEGroAnX1LKqloxyyOolcik4911KS6GKMAv9F2gGL4Que\n\t\t\t\t\t\tjv5VPoyNU2CMUW+0/ZshWrIYXA+KQo6ixXBNSPe3U7bShdTWGAB8AziSu3yOt5B0\n\t\t\t\t\t\tPsW4L0ZQg6OlRYUFxrDFnvxozk2q6YwLxlGbpwIDAQABo1AwTjAdBgNVHQ4EFgQU\n\t\t\t\t\t\tlYTaUSoJnH4kEfvwarbIEIZapAMwHwYDVR0jBBgwFoAUlYTaUSoJnH4kEfvwarbI\n\t\t\t\t\t\tEIZapAMwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAgEAGgfwVha2xpwd\n\t\t\t\t\t\tCcCHobXVrvFJGaoszbD1NQRJ27MkOiikz5EWew54AlWrh+ghxecQRu0fuCTLF9OM\n\t\t\t\t\t\tslQmrQn4+/4phy4AJTXNbBBHzyj5Y2MRfSRKfcVpgdyYIQwMS0wHJmcP2r8GyK+X\n\t\t\t\t\t\tMgl2N/IsQfrQ2KbHX2b/NMRNxmvDCdqfo5ILmYFudfjYOUgAsiHeagaWwfjyJvgx\n\t\t\t\t\t\ttiBMuAbgGC7yjFY05rSNa6rnQlwgciEyRPFEg7eHIRsxGiZld4xHA+b99VT67Wew\n\t\t\t\t\t\tRJfzCPDBkKfoy388bc/CWAX4ycoIJC0Y8NnjmA+D3VEu6/Tku2Nzz+TckoT0AhSF\n\t\t\t\t\t\tikq7jYt0tDumNlHkv7gBGzMT0Rl/wW5Ea37bk4NsZrJ/5lZfQ+CZqYsw1w/QQOPW\n\t\t\t\t\t\tKL9yw9lTf9VHxx42HsE2WfGR1318Ir9ohhJcK2UN0azgXqqN1yEGzC8qmPvPCaA2\n\t\t\t\t\t\tP7ej3f82MyeTrBWyPEEvLc9DQ3stZafkkTrprc325VTbp2f2HZxaU/UbPgUdzLBr\n\t\t\t\t\t\toAdxBx3N0zXQW/uD8JEOypC/KIpNx4OAAupQpQ7pBrgX2VKJWakx3tNzl7vRqRhU\n\t\t\t\t\t\tbqjPiPhgc3heOqonB6c8fDLtu9JzNAl6TGHyw9j8Yb4etgH8HlmkPa9THXXtrewY\n\t\t\t\t\t\tVBmw7O2i/F60fXVEf7AtB1a2KZfQ/Lw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uk-coventry-shibboleth.moveon4.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://uk-coventry-shibboleth.moveon4.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uk-coventry-shibboleth.moveon4.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://uk-coventry-shibboleth.moveon4.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://uk-coventry-shibboleth.moveon4.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://uk-coventry-shibboleth.moveon4.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://colreg.de.dariah.eu/colreg",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gradl"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tobias.gradl@uni-bamberg.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tobias"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:register@dariah.eu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dariah"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://colreg.de.dariah.eu/colreg",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-01-12T10:39:23Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Gesellschaft f\u00fcr wissenschaftliche Datenverarbeitung mbH"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Gesellschaft f\u00fcr wissenschaftliche Datenverarbeitung mbH"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gwdg.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gwdg.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e112"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e112"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://colreg.de.dariah.eu:443/colreg/saml/SingleLogout/alias/colreg.de.dariah.eu",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://colreg.de.dariah.eu:443/colreg/saml/SingleLogout/alias/colreg.de.dariah.eu",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://colreg.de.dariah.eu:443/colreg/saml/login/alias/colreg.de.dariah.eu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://dariah.eu/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://dariah.eu/"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Collection Registry"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Collection Registry"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://de.dariah.eu/ServicePrivacyPolicy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Collection Registry"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Collection Registry"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "colreg.de.dariah.eu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGAjCCBOqgAwIBAgIHFwXXzebkpDANBgkqhkiG9w0BAQUFADCBrjELMAkGA1UE\nBhMCREUxFjAUBgNVBAgTDU5pZWRlcnNhY2hzZW4xEzARBgNVBAcTCkdvZXR0aW5n\nZW4xLTArBgNVBAoTJEdlb3JnLUF1Z3VzdC1Vbml2ZXJzaXRhZXQgR29ldHRpbmdl\nbjEjMCEGA1UEAxMaVW5pdmVyc2l0YWV0LUdvZXR0aW5nZW4gQ0ExHjAcBgkqhkiG\n9w0BCQEWD2d3ZGctY2FAZ3dkZy5kZTAeFw0xNDAxMjcxMzA4MTRaFw0xOTAxMjYx\nMzA4MTRaMIGHMQswCQYDVQQGEwJERTEWMBQGA1UECBMNTmllZGVyc2FjaHNlbjET\nMBEGA1UEBxMKR29ldHRpbmdlbjEtMCsGA1UEChMkR2VvcmctQXVndXN0LVVuaXZl\ncnNpdGFldCBHb2V0dGluZ2VuMRwwGgYDVQQDExNjb2xyZWcuZGUuZGFyaWFoLmV1\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApXYpUGfB4grgZ+pP1qQR\nJKoSxfMrmmlt3F6gJuoe8vaun+GDn0j3AOhviZ+/HiasTMQv1VJ9/Zvc8rJEp/Sm\n9cYq15OoZo9LNC+kQsJo5jNpyljERgZniMN3NylNPUBiK9YPSt/oApycg1teAwif\nP0D85gmX5LtZPN4NKUa9ofEIjZARnOgNuS9uvWUiMYLRc+MUeXsbMlcijHs4rNwh\nPjQD4T1q/zX9rwcqqoqRfJQLsSRHjCXL8gFqcoA15ggis6gU1EZqm1mk7Ajb0Bpw\ntnJnfhRN/7n2CPthDUThf4lHcR84G4kchRwa/rT2RuydzW3fxTeNm9VbIqLPRrWZ\n2QIDAQABo4ICSDCCAkQwOQYDVR0gBDIwMDARBg8rBgEEAYGtIYIsAQEEAwEwEQYP\nKwYBBAGBrSGCLAIBBAMBMAgGBmeBDAECAjAJBgNVHRMEAjAAMAsGA1UdDwQEAwIE\n8DAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwHQYDVR0OBBYEFHEEs1fV\ng2shQl4/1DvRorTIy4bRMB8GA1UdIwQYMBaAFB29c8xt7m4cdHDZoxs6uqgn3rzr\nMB4GA1UdEQQXMBWCE2NvbHJlZy5kZS5kYXJpYWguZXUwgY8GA1UdHwSBhzCBhDBA\noD6gPIY6aHR0cDovL2NkcDEucGNhLmRmbi5kZS91bmktZ29ldHRpbmdlbi1jYS9w\ndWIvY3JsL2NhY3JsLmNybDBAoD6gPIY6aHR0cDovL2NkcDIucGNhLmRmbi5kZS91\nbmktZ29ldHRpbmdlbi1jYS9wdWIvY3JsL2NhY3JsLmNybDCB3QYIKwYBBQUHAQEE\ngdAwgc0wMwYIKwYBBQUHMAGGJ2h0dHA6Ly9vY3NwLnBjYS5kZm4uZGUvT0NTUC1T\nZXJ2ZXIvT0NTUDBKBggrBgEFBQcwAoY+aHR0cDovL2NkcDEucGNhLmRmbi5kZS91\nbmktZ29ldHRpbmdlbi1jYS9wdWIvY2FjZXJ0L2NhY2VydC5jcnQwSgYIKwYBBQUH\nMAKGPmh0dHA6Ly9jZHAyLnBjYS5kZm4uZGUvdW5pLWdvZXR0aW5nZW4tY2EvcHVi\nL2NhY2VydC9jYWNlcnQuY3J0MA0GCSqGSIb3DQEBBQUAA4IBAQArMbCKkxkHsDeW\nC9CIVjoHqiYBNssKRbj1PECib/UkUsKYlKAyYl1UZ+BnZsyyVzXyKxXjkVgxIShX\n8ejR+rX2TAzweW5eJ9fUU+556HTTz2dLcSkv4uX5aVbd349F/3tavsyeaH8HTpiv\n8rA27qnqAih/4vbHV7WksLaLlqeCWskk8bh83NhpwEvMawuFH6CSRdJ+Ci04utIg\nNUFnuv92ZKKPuVTZNLN24s3fOiD9zotzRbDZ9p1yRVhFgCk+WK3HCMRLN0Oz60F+\nH7llf2BUo5B61cwTXmpYDfXTCTPO6x/L5lp6vnbRdeQWDVcDVXuNh4QNSzBoxAPg\nn+48kUsN"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=colreg.de.dariah.eu,O=Georg-August-Universitaet Goettingen,L=Goettingen,ST=Niedersachsen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "colreg.de.dariah.eu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGAjCCBOqgAwIBAgIHFwXXzebkpDANBgkqhkiG9w0BAQUFADCBrjELMAkGA1UE\nBhMCREUxFjAUBgNVBAgTDU5pZWRlcnNhY2hzZW4xEzARBgNVBAcTCkdvZXR0aW5n\nZW4xLTArBgNVBAoTJEdlb3JnLUF1Z3VzdC1Vbml2ZXJzaXRhZXQgR29ldHRpbmdl\nbjEjMCEGA1UEAxMaVW5pdmVyc2l0YWV0LUdvZXR0aW5nZW4gQ0ExHjAcBgkqhkiG\n9w0BCQEWD2d3ZGctY2FAZ3dkZy5kZTAeFw0xNDAxMjcxMzA4MTRaFw0xOTAxMjYx\nMzA4MTRaMIGHMQswCQYDVQQGEwJERTEWMBQGA1UECBMNTmllZGVyc2FjaHNlbjET\nMBEGA1UEBxMKR29ldHRpbmdlbjEtMCsGA1UEChMkR2VvcmctQXVndXN0LVVuaXZl\ncnNpdGFldCBHb2V0dGluZ2VuMRwwGgYDVQQDExNjb2xyZWcuZGUuZGFyaWFoLmV1\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApXYpUGfB4grgZ+pP1qQR\nJKoSxfMrmmlt3F6gJuoe8vaun+GDn0j3AOhviZ+/HiasTMQv1VJ9/Zvc8rJEp/Sm\n9cYq15OoZo9LNC+kQsJo5jNpyljERgZniMN3NylNPUBiK9YPSt/oApycg1teAwif\nP0D85gmX5LtZPN4NKUa9ofEIjZARnOgNuS9uvWUiMYLRc+MUeXsbMlcijHs4rNwh\nPjQD4T1q/zX9rwcqqoqRfJQLsSRHjCXL8gFqcoA15ggis6gU1EZqm1mk7Ajb0Bpw\ntnJnfhRN/7n2CPthDUThf4lHcR84G4kchRwa/rT2RuydzW3fxTeNm9VbIqLPRrWZ\n2QIDAQABo4ICSDCCAkQwOQYDVR0gBDIwMDARBg8rBgEEAYGtIYIsAQEEAwEwEQYP\nKwYBBAGBrSGCLAIBBAMBMAgGBmeBDAECAjAJBgNVHRMEAjAAMAsGA1UdDwQEAwIE\n8DAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwHQYDVR0OBBYEFHEEs1fV\ng2shQl4/1DvRorTIy4bRMB8GA1UdIwQYMBaAFB29c8xt7m4cdHDZoxs6uqgn3rzr\nMB4GA1UdEQQXMBWCE2NvbHJlZy5kZS5kYXJpYWguZXUwgY8GA1UdHwSBhzCBhDBA\noD6gPIY6aHR0cDovL2NkcDEucGNhLmRmbi5kZS91bmktZ29ldHRpbmdlbi1jYS9w\ndWIvY3JsL2NhY3JsLmNybDBAoD6gPIY6aHR0cDovL2NkcDIucGNhLmRmbi5kZS91\nbmktZ29ldHRpbmdlbi1jYS9wdWIvY3JsL2NhY3JsLmNybDCB3QYIKwYBBQUHAQEE\ngdAwgc0wMwYIKwYBBQUHMAGGJ2h0dHA6Ly9vY3NwLnBjYS5kZm4uZGUvT0NTUC1T\nZXJ2ZXIvT0NTUDBKBggrBgEFBQcwAoY+aHR0cDovL2NkcDEucGNhLmRmbi5kZS91\nbmktZ29ldHRpbmdlbi1jYS9wdWIvY2FjZXJ0L2NhY2VydC5jcnQwSgYIKwYBBQUH\nMAKGPmh0dHA6Ly9jZHAyLnBjYS5kZm4uZGUvdW5pLWdvZXR0aW5nZW4tY2EvcHVi\nL2NhY2VydC9jYWNlcnQuY3J0MA0GCSqGSIb3DQEBBQUAA4IBAQArMbCKkxkHsDeW\nC9CIVjoHqiYBNssKRbj1PECib/UkUsKYlKAyYl1UZ+BnZsyyVzXyKxXjkVgxIShX\n8ejR+rX2TAzweW5eJ9fUU+556HTTz2dLcSkv4uX5aVbd349F/3tavsyeaH8HTpiv\n8rA27qnqAih/4vbHV7WksLaLlqeCWskk8bh83NhpwEvMawuFH6CSRdJ+Ci04utIg\nNUFnuv92ZKKPuVTZNLN24s3fOiD9zotzRbDZ9p1yRVhFgCk+WK3HCMRLN0Oz60F+\nH7llf2BUo5B61cwTXmpYDfXTCTPO6x/L5lp6vnbRdeQWDVcDVXuNh4QNSzBoxAPg\nn+48kUsN"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=colreg.de.dariah.eu,O=Georg-August-Universitaet Goettingen,L=Goettingen,ST=Niedersachsen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://colreg.de.dariah.eu:443/colreg/saml/SSO/alias/colreg.de.dariah.eu",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://colreg.de.dariah.eu:443/colreg/saml/SSO/alias/colreg.de.dariah.eu",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Collection Registry"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Collection Registry"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Collection Registry"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Collection Registry"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://test.qmplus.qmul.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:its-aa@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Academic Applications"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:moodle-support@ulcc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Moodle Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:its-aa@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Academic Applications"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test.qmplus.qmul.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-07-07T11:59:17Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Queen Mary and Westfield College: Test QMPlus service"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qmul.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Queen Mary and Westfield College, University of London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.qmplus.qmul.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.qmplus.qmul.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCTCCAfGgAwIBAgIJAI8TavPBUIURMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\n\t\t\t\t\t\tBAMTFnRlc3QucW1wbHVzLnFtdWwuYWMudWswHhcNMTIwNjA3MTQ1MTAzWhcNMjIw\n\t\t\t\t\t\tNjA1MTQ1MTAzWjAhMR8wHQYDVQQDExZ0ZXN0LnFtcGx1cy5xbXVsLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuLs2cygGGnUNJWfWftkRzDk5\n\t\t\t\t\t\tYnIqq6NP13SZ+zNa64WVuLvnwsbhvyfdVrfAQEPH2tyDtlp2qc51o+62liBhI6JS\n\t\t\t\t\t\tLMtx6gVFf+58UE+tx8iU0Y5NyC1x7rbLH1ZtyjQt242IydqM62d4dxPogqdiF9vp\n\t\t\t\t\t\tKy+2hMR1h1q3Gj/xwkhwJK0750wWbh4ICEgzHUDhlsD5E+aIaONsrGoI7Su2aZP/\n\t\t\t\t\t\tr9rHoMP4cGjLavmGWwbgrrOkhiFo363yLLGyvl0o5lhZpHNcMqfcbWY27fcnpvXG\n\t\t\t\t\t\thudYtAC4bDzdRBhSVLIatap33e3Ufib4FPaNfhyKRBzGXCoJypGCXcVIvp31HwID\n\t\t\t\t\t\tAQABo0QwQjAhBgNVHREEGjAYghZ0ZXN0LnFtcGx1cy5xbXVsLmFjLnVrMB0GA1Ud\n\t\t\t\t\t\tDgQWBBQzEI79jYpibhVQM4hk+a/kRUW1ZzANBgkqhkiG9w0BAQUFAAOCAQEArXfT\n\t\t\t\t\t\t8CbMm1xmDrSXqfitHZUaLlPKEQD123WPfstSqCPjWxpEifgBtGzCKk5N8ZjYd7SJ\n\t\t\t\t\t\tUpDsyz+x2jaZ8M+mlDtAAjt3KAz9YqlfSIHyOb4ZyI+2/h0zdkLXBnU8jR65701o\n\t\t\t\t\t\tRjrK4QVCQOFrwkVHjbJyb4QcBEfhxtmUCwNyPlEu++4KpRyzaFtF3FiG1ZU0oYdF\n\t\t\t\t\t\tjSRvU0UJgprAvhB2c5WoJ+uYGxUCq72HNy6dvU5cWEvQgdGJ9jQJdtU79L7T4UKD\n\t\t\t\t\t\t1VdfmxX2wDjXzO43DSdmkvNEIPVrt4BLWwu9ZfK3fmnXyzpqhaJ0Be3sJ3KbLi7B\n\t\t\t\t\t\tXZ0xC3fsbFJvZqOC1w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://test.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://test.qmplus.qmul.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://test.qmplus.qmul.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://test.qmplus.qmul.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://test-auth.galegroup.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mathews"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Joe.Mathews@cengage.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Joe"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rengarajan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Selva.Kumar@cengage.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Selva"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test-auth.galegroup.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Gale Databases from Cengage Learning - Test"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cengage.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cengage Learning Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "authn_requests_signed": "1",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTzCCAjegAwIBAgIJAJeid8J1f6CuMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHNoaWJib2xldGguZ2FsZWdyb3VwLmNvbTAeFw0xMjAzMTIxNzMwMjNaFw0z\n\t\t\t\t\t\tMjAzMDcxNzMwMjNaMCMxITAfBgNVBAMTGHNoaWJib2xldGguZ2FsZWdyb3VwLmNv\n\t\t\t\t\t\tbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAN2Qn+1FW/n+4ZZGA0lv\n\t\t\t\t\t\tz9F+I5FdDnX35oD5M7JuN6cbprWA4F8EHir6bYAuvU5lK0knO4w56aiH0uhbWXu1\n\t\t\t\t\t\tSlUlxSbAIaJombApnC5AtCJ6WFOs+NaTi/gFlAyIh7w169ZhwfsLjQE/hkdplpWT\n\t\t\t\t\t\txjFUNpt12ZyU8LL1yEJmfkeBUN3oK2fa7Qe+oqnyY0eOHHTKVO9IIr9/SvzdhoA0\n\t\t\t\t\t\tc8a2kXy4qM2T+qKGi7SGz3/Qhwpial3ZDGqeZ3m25n57h3I7BhxVSJGzzbSeOcib\n\t\t\t\t\t\tjbWRk5VjYalmG0V+XGjEJtN4oUdAgnkvJMj+yOQ8IXzDws4OR+KWGYl5lEAijXce\n\t\t\t\t\t\tqNcCAwEAAaOBhTCBgjAdBgNVHQ4EFgQUC3bQ/Jx1yAhQgWVLRtPePx/ipxYwUwYD\n\t\t\t\t\t\tVR0jBEwwSoAUC3bQ/Jx1yAhQgWVLRtPePx/ipxahJ6QlMCMxITAfBgNVBAMTGHNo\n\t\t\t\t\t\taWJib2xldGguZ2FsZWdyb3VwLmNvbYIJAJeid8J1f6CuMAwGA1UdEwQFMAMBAf8w\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBABAvL5eepD3fliAIefJ/4pDBxKBcCynRXLlmUWir\n\t\t\t\t\t\t1majii1tK0WEbDdF1a24njlftvCVDNDrrfdhu1rvXZ3UhyyiOS7fBpBvRPjCmzlf\n\t\t\t\t\t\tDdvGiMuar/T+uNzbiNqcLsVeKvwZJfzMt9Y1T7MXDABez8BD3CkdFt05j+hPK0t5\n\t\t\t\t\t\t3PLIZfOir72LoRAtXmilZs4ZAvvTL/BTTxYn4t165Vp5yBRPCLrdSAMIdTIENBZ7\n\t\t\t\t\t\t/tapXMzigHNS/YoxpEmtKkUrnkBm3nrWeF0Z6sqYEz49xS6NdnKLTSVQHyJ413LZ\n\t\t\t\t\t\tWQSvXs7RDm/214HIimD/TkaDp1Yv0Yk2iQAeO7fucXAIAv4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://tg-dxpres1.oh.ggtest.com:8445/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.dev1.ggdev.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.qa.ggtest.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://gada.oh.gale.com:8445/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.qa.gghybrid.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.dev.ggtest.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.qa.gghybrid.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.galegroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://secure.anatomy.tv/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Shah"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:deepesh@primalpictures.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Deepesh"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Shah"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:deepesh@primalpictures.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Deepesh"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://secure.anatomy.tv/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-11-22T16:57:23Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Primal Pictures - Anatomy.tv"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.primalpictures.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Primal Pictures Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The most comprehensive, accurate and detailed 3D models of the human body. Our range of medical software covers anatomy for every region of the body plus specialised titles that focus on muscle function, injuries and more, providing over 6,500 3D anatomical structures, clinical slides, dissections, illustrations, animations and much more."
                  }
                ],
                "logo": [
                  {
                    "text": "https://secure.anatomy.tv/images/Anatomy-TV-logo-Athens.png",
                    "height": "85",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Primal Pictures - Anatomy.tv"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDrzCCApegAwIBAgIJAP7Ws37fxxA8MA0GCSqGSIb3DQEBBQUAMEMxJTAjBgNV\n\t\t\t\t\t\tBAoTHFByaW1hbCBQaWN0dXJlcyAtIEFuYXRvbXkudHYxGjAYBgNVBAMTEXNlY3Vy\n\t\t\t\t\t\tZS5hbmF0b215LnR2MB4XDTEzMTEyMjEzNDY1OVoXDTIzMTEyMDEzNDY1OVowQzEl\n\t\t\t\t\t\tMCMGA1UEChMcUHJpbWFsIFBpY3R1cmVzIC0gQW5hdG9teS50djEaMBgGA1UEAxMR\n\t\t\t\t\t\tc2VjdXJlLmFuYXRvbXkudHYwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDAJdYIxLYxyV/0MqpVRYZhafOPVAbv/BmBL+1RrxBA4SUv0jiSnJiBSPnE0/YX\n\t\t\t\t\t\toSgyFI8UDshYX5bf78Uk0YFPQ9W9lRZaElZ2RuYqfZjZLbfM8EAtB1WSpFXim6gq\n\t\t\t\t\t\t9rIKHBLh8jhtTZSWinAezthfpvMJWHEArEjbReJF2+dzc6bXTsKZMf84VtC4t7eh\n\t\t\t\t\t\tdwbMCq84D8PNtBR5B4YCcIWKrTGxdTuclb/oU+hiUR8/x9DKj/QIIVgb2g/eDEmv\n\t\t\t\t\t\tfHXrUrwUECqXCi+TLhIFEOe8eNw+cIueOkqtsg02qzTr7ThIW/LGlcprdOS+1Me1\n\t\t\t\t\t\tGm/0Hal/v3x79JSOaZ1ZOy2xAgMBAAGjgaUwgaIwHQYDVR0OBBYEFMPJgV8IFMbg\n\t\t\t\t\t\tJ+I6xIAIsgAZxRrtMHMGA1UdIwRsMGqAFMPJgV8IFMbgJ+I6xIAIsgAZxRrtoUek\n\t\t\t\t\t\tRTBDMSUwIwYDVQQKExxQcmltYWwgUGljdHVyZXMgLSBBbmF0b215LnR2MRowGAYD\n\t\t\t\t\t\tVQQDExFzZWN1cmUuYW5hdG9teS50doIJAP7Ws37fxxA8MAwGA1UdEwQFMAMBAf8w\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAEVvZ6kazfA45CuWgSeHvBvwfotPTQ1L0I5LQm2Z\n\t\t\t\t\t\t8eniR7GRXHoe8ARm0KeKkOI0RPDH7P7ovvdTaBWjbESxwa/LybHUKNGKikJBnmpW\n\t\t\t\t\t\tkD+04h6aOISdCNM5gK7arXSdymnw8tBDDcD4InhaUjpb16lKzLOg9MrEflKxYGvt\n\t\t\t\t\t\tsRNksXgJ/NXz72RR6e2XBJc/GcJLYqtE9GUa+9WBBywVjKxCfkTchtKZJJ5671gt\n\t\t\t\t\t\tAtuEdQrTeTQPFL40SxAPy//3f8yoCvleohvzN6T8GUPIt2F74Tapoj941DJeHWtZ\n\t\t\t\t\t\txhknE0CxeTWhHOBRY2zULtp+XeSN+EskWe1jPdY+1Houu4s="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDrzCCApegAwIBAgIJAP7Ws37fxxA8MA0GCSqGSIb3DQEBBQUAMEMxJTAjBgNV\n\t\t\t\t\t\tBAoTHFByaW1hbCBQaWN0dXJlcyAtIEFuYXRvbXkudHYxGjAYBgNVBAMTEXNlY3Vy\n\t\t\t\t\t\tZS5hbmF0b215LnR2MB4XDTEzMTEyMjEzNDY1OVoXDTIzMTEyMDEzNDY1OVowQzEl\n\t\t\t\t\t\tMCMGA1UEChMcUHJpbWFsIFBpY3R1cmVzIC0gQW5hdG9teS50djEaMBgGA1UEAxMR\n\t\t\t\t\t\tc2VjdXJlLmFuYXRvbXkudHYwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDAJdYIxLYxyV/0MqpVRYZhafOPVAbv/BmBL+1RrxBA4SUv0jiSnJiBSPnE0/YX\n\t\t\t\t\t\toSgyFI8UDshYX5bf78Uk0YFPQ9W9lRZaElZ2RuYqfZjZLbfM8EAtB1WSpFXim6gq\n\t\t\t\t\t\t9rIKHBLh8jhtTZSWinAezthfpvMJWHEArEjbReJF2+dzc6bXTsKZMf84VtC4t7eh\n\t\t\t\t\t\tdwbMCq84D8PNtBR5B4YCcIWKrTGxdTuclb/oU+hiUR8/x9DKj/QIIVgb2g/eDEmv\n\t\t\t\t\t\tfHXrUrwUECqXCi+TLhIFEOe8eNw+cIueOkqtsg02qzTr7ThIW/LGlcprdOS+1Me1\n\t\t\t\t\t\tGm/0Hal/v3x79JSOaZ1ZOy2xAgMBAAGjgaUwgaIwHQYDVR0OBBYEFMPJgV8IFMbg\n\t\t\t\t\t\tJ+I6xIAIsgAZxRrtMHMGA1UdIwRsMGqAFMPJgV8IFMbgJ+I6xIAIsgAZxRrtoUek\n\t\t\t\t\t\tRTBDMSUwIwYDVQQKExxQcmltYWwgUGljdHVyZXMgLSBBbmF0b215LnR2MRowGAYD\n\t\t\t\t\t\tVQQDExFzZWN1cmUuYW5hdG9teS50doIJAP7Ws37fxxA8MAwGA1UdEwQFMAMBAf8w\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAEVvZ6kazfA45CuWgSeHvBvwfotPTQ1L0I5LQm2Z\n\t\t\t\t\t\t8eniR7GRXHoe8ARm0KeKkOI0RPDH7P7ovvdTaBWjbESxwa/LybHUKNGKikJBnmpW\n\t\t\t\t\t\tkD+04h6aOISdCNM5gK7arXSdymnw8tBDDcD4InhaUjpb16lKzLOg9MrEflKxYGvt\n\t\t\t\t\t\tsRNksXgJ/NXz72RR6e2XBJc/GcJLYqtE9GUa+9WBBywVjKxCfkTchtKZJJ5671gt\n\t\t\t\t\t\tAtuEdQrTeTQPFL40SxAPy//3f8yoCvleohvzN6T8GUPIt2F74Tapoj941DJeHWtZ\n\t\t\t\t\t\txhknE0CxeTWhHOBRY2zULtp+XeSN+EskWe1jPdY+1Houu4s="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://secure.anatomy.tv/shibboleth/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://secure.anatomy.tv/shibboleth/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://secure.anatomy.tv/shibboleth/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://secure.anatomy.tv/shibboleth/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://clarin.ids-mannheim.de/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Schonefeld"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:schonefeld@ids-mannheim.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Oliver"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Witt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:witt@ids-mannheim.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andreas"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@ids-mannheim.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAI"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://clarin.ids-mannheim.de/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2013-10-24T13:14:25Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://clarin.eu/category/clarin-member"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institut f\u00fcr Deutsche Sprache (IDS)"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institut f\u00fcr Deutsche Sprache (IDS)"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ids-mannheim.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ids-mannheim.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e217"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e217"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://clarin.ids-mannheim.de/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://clarin.ids-mannheim.de/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://clarin.ids-mannheim.de/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://clarin.ids-mannheim.de/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://clarin.ids-mannheim.de/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ids-mannheim.de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ids-mannheim.de"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CLARIN Dienste"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CLARIN services"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Verschiedene Dienste des Institut f\u00fcr Deutsche Sprache (IDS) im Rahmen der CLARIN-Initiative."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Various services provided by the Institut f\u00fcr Deutsche Sprache (IDS) in the context of the CLARIN initiative."
                  }
                ],
                "logo": [
                  {
                    "text": "https://clarin.ids-mannheim.de/logos/ids-logo-small.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://clarin.ids-mannheim.de/logos/ids-logo-large.png",
                    "height": "63",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "318"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://clarin.ids-mannheim.de/privacy.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "clarin.ids-mannheim.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGKTCCBRGgAwIBAgIHGHGxHhl3eDANBgkqhkiG9w0BAQsFADCBoDELMAkGA1UE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"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=aai@ids-mannheim.de,CN=clarin.ids-mannheim.de,O=Institut fuer Deutsche Sprache,L=Mannheim,ST=Baden-Wuerttemberg,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://clarin.ids-mannheim.de/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://clarin.ids-mannheim.de/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://clarin.ids-mannheim.de/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://clarin.ids-mannheim.de/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://clarin.ids-mannheim.de/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://clarin.ids-mannheim.de/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CLARIN Dienste"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CLARIN services"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Verschiedene Dienste des Institut f\u00fcr Deutsche Sprache (IDS) im Rahmen der CLARIN-Initiative."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Various services provided by the Institut f\u00fcr Deutsche Sprache (IDS) in the context of the CLARIN initiative."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://spaces.internet2.edu/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "techsupport@internet2.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "techsupport@internet2.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "techsupport@internet2.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://spaces.internet2.edu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Internet2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.internet2.edu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Internet2"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://spaces.internet2.edu/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://spaces.internet2.edu/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://spaces.internet2.edu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://spaces.internet2.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.internet2.edu/about/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Internet2 Collaboration Wiki Spaces"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Collaboration spaces to support the activities of Internet2 projects and working groups."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.internet2.edu/media/medialibrary/2013/12/02/internet2_logo_colorpos.gif",
                    "lang": "en",
                    "height": "122",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "91"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.internet2.edu/privacy.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID9TCCAt2gAwIBAgIBADANBgkqhkiG9w0BAQQFADBAMQswCQYDVQQGEwJVUzES\nMBAGA1UEChMJSW50ZXJuZXQyMR0wGwYDVQQDExRzcGFjZXMuaW50ZXJuZXQyLmVk\ndTAeFw0wNjEyMTMxNzQwMjdaFw0xNjEyMTAxNzQwMjdaMEAxCzAJBgNVBAYTAlVT\nMRIwEAYDVQQKEwlJbnRlcm5ldDIxHTAbBgNVBAMTFHNwYWNlcy5pbnRlcm5ldDIu\nZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxfZWpU5/8rgfFbxh\nDOwYuQ4/TNycAQ/VQ5DFMU3M3bvF52WktUtfwBDozdXQt/tOIlBFvPVHH/pdp0q6\nRrzjXP5pQFZoKKc+p9cGdxHqKlx7RWAnFycNaKFZyV9kUTUvSHDjQk00i5gJUGEt\nD1j8NLE9o0y68x+5jK3onhQs3IXkHVYDslXHNXPovcv7OQuWIL69oBxyTxeTBUIA\nWoIiSZh6XrjGmNUid2ZnFFk7YtY1UNGV18LbfVhnxBlIxIq5v9KQgK9T0P5pogYs\n6N7Ki4eMK3cKCJkAibrbo8iPcOJnwbCXTlLmnhv5yd/W8Bk8A/pluNX7kbsSYr1f\n7P6YqQIDAQABo4H5MIH2MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5T\nU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBQ8t+Ty3BI/EncjTRX+\nJB8jn/SU0zBoBgNVHSMEYTBfgBQ8t+Ty3BI/EncjTRX+JB8jn/SU06FEpEIwQDEL\nMAkGA1UEBhMCVVMxEjAQBgNVBAoTCUludGVybmV0MjEdMBsGA1UEAxMUc3BhY2Vz\nLmludGVybmV0Mi5lZHWCAQAwMgYDVR0RBCswKYYnaHR0cHM6Ly9zcGFjZXMuaW50\nZXJuZXQyLmVkdS9zaGliYm9sZXRoMA0GCSqGSIb3DQEBBAUAA4IBAQCd2JE3zSY3\nJLYBdr/WhFphpMHavrXpcK8GYro0YYfPN0QDxjBUSGkGgw0QzKAGmthqJWJ6yeip\nHt36uzobQ2iQtFU08LKiK2jPNegSU3uW/LsmnweFCDmWDyacmK91q+m3oNfY631l\n+vLX82GQYRssQbis1CJbrD/XE1W+2sEnGHc4eNRJZYNzMRvfSatNavCgI1IoOFEC\ngBAD9negf1qiDeouxjXCiixAMR5XnVd7lyZ7VN3goXIN//4SdCLT5fd1tIspaOOy\nBPE4P/6N3KmAMY7VNejGcpoRKvb0R0Yd7a8aMR7xImUNsycFlthz+sl26fTVNNmz\n/n0PiqFXEkFy"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://spaces.internet2.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://spaces.internet2.edu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://spaces.internet2.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://spaces.internet2.edu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://spaces.internet2.edu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://spaces.internet2.edu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Internet2 Collaboration Wiki Spaces"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Collaboration spaces to support the activities of Internet2 projects and working groups."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.warrington.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Helpdesk@Warrington.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Robinson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:GRobinson@Warrington.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Graham"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.warrington.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-11-25T15:09:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFFzCCA/+gAwIBAgIQMjinXVJxXZDuVUOslVHWJzANBgkqhkiG9w0BAQUFADA2\n\t\t\t\t\t\tMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n\t\t\t\t\t\tU1NMIENBMB4XDTEzMTEwNjAwMDAwMFoXDTE2MTEwNTIzNTk1OVowgeMxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRAwDgYDVQQREwdXQTIgOFFBMREwDwYDVQQIEwhDaGVzaGlyZTETMBEG\n\t\t\t\t\t\tA1UEBxMKV0FSUklOR1RPTjEQMA4GA1UECRMHV2lud2ljazEVMBMGA1UECRMMV2lu\n\t\t\t\t\t\td2ljayBSb2FkMRwwGgYDVQQJExNXaW53aWNrIFJvYWQgQ2FtcHVzMR4wHAYDVQQK\n\t\t\t\t\t\tExVXYXJyaW5ndG9uIENvbGxlZ2lhdGUxFDASBgNVBAsTC0lUIFNlcnZpY2VzMR0w\n\t\t\t\t\t\tGwYDVQQDExRpZHAud2FycmluZ3Rvbi5hYy51azCCASIwDQYJKoZIhvcNAQEBBQAD\n\t\t\t\t\t\tggEPADCCAQoCggEBAKyqFQr4F107oAM805XCaRDWpXFlGkT2l6HRRxn/cGht/Wgn\n\t\t\t\t\t\tBu3wgxxdH+DZnqEUNs2fkrIvRRPxN1QcJ2Bg9dyi1aqM2ZPKUgVLSBoJo1YT29gv\n\t\t\t\t\t\tRp95RtHccpRHjeKNCN7Y0fDYQaGzOhfQ1MJ1arguQBvKgDpiRoQ/SQR3QWicWYqJ\n\t\t\t\t\t\tN+vltT+IPOmvT4PuyWIVvWs3Us4ESRFvGn3V8u7Sm+A4tjSOZq3ZJjZVI0ixWVPa\n\t\t\t\t\t\tSBcb418sxQNnMaydJokgoM+UnL21H70YnKHmgvHJu4L4HzX3AHWf4CZLVmS1AT7j\n\t\t\t\t\t\tOfSqvh20bBwVfwaDiIAzUHeWAeLPjfmb64RZbRcCAwEAAaOCAXEwggFtMB8GA1Ud\n\t\t\t\t\t\tIwQYMBaAFAy9k2gM896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBTLdHJeiw7kogwc\n\t\t\t\t\t\tsVR6BNc9JC0urzAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUE\n\t\t\t\t\t\tFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQIC\n\t\t\t\t\t\tHTAIBgZngQwBAgIwOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVy\n\t\t\t\t\t\tZW5hLm9yZy9URVJFTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUF\n\t\t\t\t\t\tBzAChilodHRwOi8vY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAm\n\t\t\t\t\t\tBggrBgEFBQcwAYYaaHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwHwYDVR0RBBgw\n\t\t\t\t\t\tFoIUaWRwLndhcnJpbmd0b24uYWMudWswDQYJKoZIhvcNAQEFBQADggEBAAGRcCuf\n\t\t\t\t\t\tCXbp7sAivclytw0cMO1xrGmMEi4wVjpjkyPtttmkngZRYa21gLeExdxr+fs1P/5G\n\t\t\t\t\t\tLAaFhLCtosj7W6iUtehMDwMNQPs1Lin5MDqhOQLSnEtT8WVDWjf25cRxdbpxf1ti\n\t\t\t\t\t\tdAmU9mX4HT93FMWn/RGgfEoi6wc0VPW37j1kRruqHTU9Wxyujjyw6RZQ9CWx8y8g\n\t\t\t\t\t\tntmhLWOveV9P5ID6Sh3QWzMcE005NKjiHdO8RfBrhg5FfTj9dOsee9Kbx6GH6gVj\n\t\t\t\t\t\tOBbEtsqTq+EVBcim7XZmEbVslQwu0iH1nM/HWebqfo4Acugy7Isy6oc43HVnD/W7\n\t\t\t\t\t\tJzDQd9U2/1ntIS0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "warrington.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.warrington.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.warrington.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.warrington.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.warrington.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.warrington.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.warrington.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.warrington.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.warrington.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "warrington.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFFzCCA/+gAwIBAgIQMjinXVJxXZDuVUOslVHWJzANBgkqhkiG9w0BAQUFADA2\n\t\t\t\t\t\tMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n\t\t\t\t\t\tU1NMIENBMB4XDTEzMTEwNjAwMDAwMFoXDTE2MTEwNTIzNTk1OVowgeMxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRAwDgYDVQQREwdXQTIgOFFBMREwDwYDVQQIEwhDaGVzaGlyZTETMBEG\n\t\t\t\t\t\tA1UEBxMKV0FSUklOR1RPTjEQMA4GA1UECRMHV2lud2ljazEVMBMGA1UECRMMV2lu\n\t\t\t\t\t\td2ljayBSb2FkMRwwGgYDVQQJExNXaW53aWNrIFJvYWQgQ2FtcHVzMR4wHAYDVQQK\n\t\t\t\t\t\tExVXYXJyaW5ndG9uIENvbGxlZ2lhdGUxFDASBgNVBAsTC0lUIFNlcnZpY2VzMR0w\n\t\t\t\t\t\tGwYDVQQDExRpZHAud2FycmluZ3Rvbi5hYy51azCCASIwDQYJKoZIhvcNAQEBBQAD\n\t\t\t\t\t\tggEPADCCAQoCggEBAKyqFQr4F107oAM805XCaRDWpXFlGkT2l6HRRxn/cGht/Wgn\n\t\t\t\t\t\tBu3wgxxdH+DZnqEUNs2fkrIvRRPxN1QcJ2Bg9dyi1aqM2ZPKUgVLSBoJo1YT29gv\n\t\t\t\t\t\tRp95RtHccpRHjeKNCN7Y0fDYQaGzOhfQ1MJ1arguQBvKgDpiRoQ/SQR3QWicWYqJ\n\t\t\t\t\t\tN+vltT+IPOmvT4PuyWIVvWs3Us4ESRFvGn3V8u7Sm+A4tjSOZq3ZJjZVI0ixWVPa\n\t\t\t\t\t\tSBcb418sxQNnMaydJokgoM+UnL21H70YnKHmgvHJu4L4HzX3AHWf4CZLVmS1AT7j\n\t\t\t\t\t\tOfSqvh20bBwVfwaDiIAzUHeWAeLPjfmb64RZbRcCAwEAAaOCAXEwggFtMB8GA1Ud\n\t\t\t\t\t\tIwQYMBaAFAy9k2gM896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBTLdHJeiw7kogwc\n\t\t\t\t\t\tsVR6BNc9JC0urzAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUE\n\t\t\t\t\t\tFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQIC\n\t\t\t\t\t\tHTAIBgZngQwBAgIwOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVy\n\t\t\t\t\t\tZW5hLm9yZy9URVJFTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUF\n\t\t\t\t\t\tBzAChilodHRwOi8vY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAm\n\t\t\t\t\t\tBggrBgEFBQcwAYYaaHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwHwYDVR0RBBgw\n\t\t\t\t\t\tFoIUaWRwLndhcnJpbmd0b24uYWMudWswDQYJKoZIhvcNAQEFBQADggEBAAGRcCuf\n\t\t\t\t\t\tCXbp7sAivclytw0cMO1xrGmMEi4wVjpjkyPtttmkngZRYa21gLeExdxr+fs1P/5G\n\t\t\t\t\t\tLAaFhLCtosj7W6iUtehMDwMNQPs1Lin5MDqhOQLSnEtT8WVDWjf25cRxdbpxf1ti\n\t\t\t\t\t\tdAmU9mX4HT93FMWn/RGgfEoi6wc0VPW37j1kRruqHTU9Wxyujjyw6RZQ9CWx8y8g\n\t\t\t\t\t\tntmhLWOveV9P5ID6Sh3QWzMcE005NKjiHdO8RfBrhg5FfTj9dOsee9Kbx6GH6gVj\n\t\t\t\t\t\tOBbEtsqTq+EVBcim7XZmEbVslQwu0iH1nM/HWebqfo4Acugy7Isy6oc43HVnD/W7\n\t\t\t\t\t\tJzDQd9U2/1ntIS0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Warrington Collegiate (via IdP)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.warrington.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Warrington Collegiate Institute"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://testakt.it.ki.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://testakt.it.ki.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://testakt.it.ki.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://testakt.it.ki.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://testakt.it.ki.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://testakt.it.ki.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://testakt.it.ki.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://testakt.it.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://testakt.it.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Test f\u00f6r Kontoaktiveringstj\u00e4nst p\u00e5 Karolinska Institutet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Test for Account activation service at Karolinska Institutet"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kontoaktivering Karolinska Institutet (test)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Account activation Karolinska Institutet (test)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "testakt.it.ki.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAM3DTvphmyUaMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEHRlc3Rha3QuaXQua2kuc2UwHhcNMTMwMTE0MTMxMzAyWhcNMjMwMTEyMTMx\nMzAyWjAbMRkwFwYDVQQDExB0ZXN0YWt0Lml0LmtpLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAy4YOjmQB9kSZvz0c1Z6XH4AgfrKrTrx/Wnd8Nid3\nh1Mqpa07HvZtL7dZKsyhspvbx/AJpbLCzr3yCXVWgohUe+MJWn2/hCfymggN+yrV\nUS9fuMGTErSCQ9VZ7BmmvEPclhWMBvA8r2Po5Nzcz+exVI09Ww9rKO0oNyaxxwPv\nig2thOgQgd7/GNZweyevb1YDIxLmpTxI2OwK3E4ikx8InVSqEqTNu9q6se6bjHeo\nBmTQORnTeyz542hRu0cjOV5AcuvMreMXG4N+qW/cToFdjc3JutqKfi3irBJGF0pc\nfBpTbb2/MhAtDviCAwCJzqazHnqYRgjhStDMFAe9Ip97zQIDAQABoz4wPDAbBgNV\nHREEFDASghB0ZXN0YWt0Lml0LmtpLnNlMB0GA1UdDgQWBBQNLiq+j2EVv4KpAbSO\nYb8ANJv3pTANBgkqhkiG9w0BAQUFAAOCAQEAaW8+I6eqKO0mpQ1OHvLjOngaFdzy\nQYi/vkE5eenu10aG7pz0QprIv+9QarNgNEkG9fWS7FzjqzMksTqg+C0ZxXwk8QP5\nXOTTrfOIYw9yfn/AxodLSImxibvC8vt2mFF4xLe9FC42Ur8Fb5TiIBTviE81nCLP\nhYX1kyL7fAUVecAwkn33Bwb0QCO6i0rq3XLSB+hS0qJb5qePPJLc+jfmSdjLlPtx\nagf3dT6iLUDOMQhLG3qA2QZqhjEbpzvcGXUjF4Z2nf+OtplAI2nTcDz8x45nIwnY\nMUoo/uwKQn4shjggip2k4jZ7JH/EBCXLYrptWqr7YPmos4JHpYwZwAwhFg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=testakt.it.ki.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://testakt.it.ki.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://testakt.it.ki.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://testakt.it.ki.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://testakt.it.ki.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://testakt.it.ki.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://testakt.it.ki.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.knowsleycollege.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McDonald"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:amcdonald@knowsleycollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McDonald"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:amcdonald@knowsleycollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.knowsleycollege.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-02-01T17:22:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEgDCCA2igAwIBAgIRAJp6NZY3oZd2UzczIfqpV5UwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xNDAxMDkwMDAwMDBaFw0xNzAxMDgyMzU5NTlaMEcxITAfBgNV\n\t\t\t\t\t\tBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEiMCAGA1UEAxMZaWRwLmtub3dz\n\t\t\t\t\t\tbGV5Y29sbGVnZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAKRJddwlsUcpb0Wx0i00fAhJCsUmCTfTtmT49JRyCoTYchZlSp7ZS2OAQssFDYiD\n\t\t\t\t\t\tRHLClkSw+iUgIFCbal1bDSDDFJosZJv4JD4U0FD4q8twDw48bfS3k1+JBPR/M0eU\n\t\t\t\t\t\t+wd4A0siZf0WcTItiU3MmzLv4I9mOW5IZ8akjZiLCdnkR1zjAbAAoX18mYsld9xA\n\t\t\t\t\t\tLOSO4NydM08pRLOtWJFtVKlLnQ0tn+cG0NoYELpMueVopSUM7+K5fLaEOqqd5smO\n\t\t\t\t\t\teb11WyHbZuxuR1C40Xpb6OsWiNQYoyF7m1G+x3F8GiUvaqiejhSmXm0VkNv1QbHj\n\t\t\t\t\t\tko0ygft+w/V2dTQNYdrwqckCAwEAAaOCAXYwggFyMB8GA1UdIwQYMBaAFAy9k2gM\n\t\t\t\t\t\t896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBSx+f3A3ueD76o4IG5ZlByOeLnGmjAO\n\t\t\t\t\t\tBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcD\n\t\t\t\t\t\tAQYIKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEw\n\t\t\t\t\t\tOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJF\n\t\t\t\t\t\tTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8v\n\t\t\t\t\t\tY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYa\n\t\t\t\t\t\taHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwJAYDVR0RBB0wG4IZaWRwLmtub3dz\n\t\t\t\t\t\tbGV5Y29sbGVnZS5hYy51azANBgkqhkiG9w0BAQUFAAOCAQEAaizqm9abK5mC4yKi\n\t\t\t\t\t\tkAVp7Y2DBzjXB1PUtguSOCx0EbfIX8/OK6PrRa3o45eMSEo5eecwpFJwCSDqg+V0\n\t\t\t\t\t\tkCJp6lbIz37iP3WaJjaeYCqkBedphtFBSh1QKcrrKjQXvHlezgiNhVie+qcvEyT2\n\t\t\t\t\t\tF28YSP2Bb3Yyb/LRNX3g8Om9EYUeg1TKy/ECyOwS7Bbqk7I37A8S2c1G0YnbdiFT\n\t\t\t\t\t\thkA+eu7b2/C1cZr3ETLYuR5ZQ83pLNmAJRIM89lMukuSeIYrYELOm+o97rw4wqrD\n\t\t\t\t\t\tPvraWXaWABehzvK7oqqu/SZiVYri54k4w8UA8CL16ME3tL6UGql/05Sl0Q6aQZmT\n\t\t\t\t\t\t8HV+cQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "knowsleycollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.knowsleycollege.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.knowsleycollege.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.knowsleycollege.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.knowsleycollege.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.knowsleycollege.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.knowsleycollege.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.knowsleycollege.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.knowsleycollege.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "knowsleycollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEgDCCA2igAwIBAgIRAJp6NZY3oZd2UzczIfqpV5UwDQYJKoZIhvcNAQEFBQAw\n\t\t\t\t\t\tNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\n\t\t\t\t\t\tIFNTTCBDQTAeFw0xNDAxMDkwMDAwMDBaFw0xNzAxMDgyMzU5NTlaMEcxITAfBgNV\n\t\t\t\t\t\tBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEiMCAGA1UEAxMZaWRwLmtub3dz\n\t\t\t\t\t\tbGV5Y29sbGVnZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAKRJddwlsUcpb0Wx0i00fAhJCsUmCTfTtmT49JRyCoTYchZlSp7ZS2OAQssFDYiD\n\t\t\t\t\t\tRHLClkSw+iUgIFCbal1bDSDDFJosZJv4JD4U0FD4q8twDw48bfS3k1+JBPR/M0eU\n\t\t\t\t\t\t+wd4A0siZf0WcTItiU3MmzLv4I9mOW5IZ8akjZiLCdnkR1zjAbAAoX18mYsld9xA\n\t\t\t\t\t\tLOSO4NydM08pRLOtWJFtVKlLnQ0tn+cG0NoYELpMueVopSUM7+K5fLaEOqqd5smO\n\t\t\t\t\t\teb11WyHbZuxuR1C40Xpb6OsWiNQYoyF7m1G+x3F8GiUvaqiejhSmXm0VkNv1QbHj\n\t\t\t\t\t\tko0ygft+w/V2dTQNYdrwqckCAwEAAaOCAXYwggFyMB8GA1UdIwQYMBaAFAy9k2gM\n\t\t\t\t\t\t896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBSx+f3A3ueD76o4IG5ZlByOeLnGmjAO\n\t\t\t\t\t\tBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcD\n\t\t\t\t\t\tAQYIKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEw\n\t\t\t\t\t\tOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJF\n\t\t\t\t\t\tTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8v\n\t\t\t\t\t\tY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYa\n\t\t\t\t\t\taHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwJAYDVR0RBB0wG4IZaWRwLmtub3dz\n\t\t\t\t\t\tbGV5Y29sbGVnZS5hYy51azANBgkqhkiG9w0BAQUFAAOCAQEAaizqm9abK5mC4yKi\n\t\t\t\t\t\tkAVp7Y2DBzjXB1PUtguSOCx0EbfIX8/OK6PrRa3o45eMSEo5eecwpFJwCSDqg+V0\n\t\t\t\t\t\tkCJp6lbIz37iP3WaJjaeYCqkBedphtFBSh1QKcrrKjQXvHlezgiNhVie+qcvEyT2\n\t\t\t\t\t\tF28YSP2Bb3Yyb/LRNX3g8Om9EYUeg1TKy/ECyOwS7Bbqk7I37A8S2c1G0YnbdiFT\n\t\t\t\t\t\thkA+eu7b2/C1cZr3ETLYuR5ZQ83pLNmAJRIM89lMukuSeIYrYELOm+o97rw4wqrD\n\t\t\t\t\t\tPvraWXaWABehzvK7oqqu/SZiVYri54k4w8UA8CL16ME3tL6UGql/05Sl0Q6aQZmT\n\t\t\t\t\t\t8HV+cQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Knowsley College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.knowsleycollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Knowsley Community College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp0.essex.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibadmin@essex.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wolton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:awolton@essex.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alexis"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp0.essex.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEZjCCA06gAwIBAgIJAITsUwOrZ0UiMA0GCSqGSIb3DQEBBQUAMIGzMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEOMAwGA1UECBMFRXNzZXgxEzARBgNVBAcTCkNvbGNoZXN0ZXIxHDAa\n\t\t\t\t\t\tBgNVBAoTE1VuaXZlcnNpdHkgb2YgRXNzZXgxJTAjBgNVBAsTHEluZm9ybWF0aW9u\n\t\t\t\t\t\tIFN5c3RlbXMgU2VydmljZXMxGTAXBgNVBAMTEGlkcDEuZXNzZXguYWMudWsxHzAd\n\t\t\t\t\t\tBgkqhkiG9w0BCQEWEHNhbWlAZXNzZXguYWMudWswHhcNMTMwNjA2MTMwODM0WhcN\n\t\t\t\t\t\tMjMwNjA0MTMwODM0WjCBszELMAkGA1UEBhMCR0IxDjAMBgNVBAgTBUVzc2V4MRMw\n\t\t\t\t\t\tEQYDVQQHEwpDb2xjaGVzdGVyMRwwGgYDVQQKExNVbml2ZXJzaXR5IG9mIEVzc2V4\n\t\t\t\t\t\tMSUwIwYDVQQLExxJbmZvcm1hdGlvbiBTeXN0ZW1zIFNlcnZpY2VzMRkwFwYDVQQD\n\t\t\t\t\t\tExBpZHAxLmVzc2V4LmFjLnVrMR8wHQYJKoZIhvcNAQkBFhBzYW1pQGVzc2V4LmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtkqXuVUogstt2A/6\n\t\t\t\t\t\tcQ2hQxac8XIUhMRtWF7Rp8hoYawRFsD1QD/ppyutOHQTmdTes1THp9RFOxv/frFX\n\t\t\t\t\t\tloVZSCgnk74wY98h9dJVT/aZGtbGBEi8CDeJOyMgopt8xhmt8GGuzLXZz65vdb1z\n\t\t\t\t\t\tvXyYD5YjB94ECCLOkBXovkln4qSLOaDeOpwGADjQ+hEtsEYQ8Cob04cbZNhRJYBT\n\t\t\t\t\t\tlTeGTcQhSQToPiiVHG1jupDkawkAg0wJyqjxGjdcFWAn5jdK5Qixc1EOhrwcVnEp\n\t\t\t\t\t\tFEBJT8JFOS/Mek9YWc29//8BpVByeubbd/hv9fr9N2M9Z+AEJsIkNNYkrp2KybIW\n\t\t\t\t\t\trB7jhwIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NM\n\t\t\t\t\t\tIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQURnWjhBTuD3SjqSu9ob68\n\t\t\t\t\t\tDpVgGOIwHwYDVR0jBBgwFoAURnWjhBTuD3SjqSu9ob68DpVgGOIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAAkvvTQ6RacwMk6ru/Kjd7tS8O+pCnXkJeAc+Q5/ELEfqwct5hE/\n\t\t\t\t\t\tN6FhudmH/SrISQmJdWsJvUh5bkpT0tby/V2+9vKB+Bz/q8MaYdAB6p8wrrCl3qL6\n\t\t\t\t\t\tI9pX1wL0QeuDemObq7DDySo59A/UD/4hv/hiM6XbORFyAPjCkvHmmgr9VkoUPcwv\n\t\t\t\t\t\tEKqT60bX7dI9Nxr9/pAYexrSBSwyuk92JNJTpKqRmaBcV9AqPSA28JNJlZZJ4PRd\n\t\t\t\t\t\trDfLmgn2f37l6f6mhHyPGIcmzCSsjV0MYBq9awtuqAV746ZN28lWPKx39LkiO74f\n\t\t\t\t\t\tkwWCZNtxVk+q/aU+Vrpk7mXhvFD3JBQn07Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "essex.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.essex.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.essex.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp1.essex.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp1.essex.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp1.essex.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp1.essex.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.essex.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.essex.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "essex.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEZjCCA06gAwIBAgIJAITsUwOrZ0UiMA0GCSqGSIb3DQEBBQUAMIGzMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEOMAwGA1UECBMFRXNzZXgxEzARBgNVBAcTCkNvbGNoZXN0ZXIxHDAa\n\t\t\t\t\t\tBgNVBAoTE1VuaXZlcnNpdHkgb2YgRXNzZXgxJTAjBgNVBAsTHEluZm9ybWF0aW9u\n\t\t\t\t\t\tIFN5c3RlbXMgU2VydmljZXMxGTAXBgNVBAMTEGlkcDEuZXNzZXguYWMudWsxHzAd\n\t\t\t\t\t\tBgkqhkiG9w0BCQEWEHNhbWlAZXNzZXguYWMudWswHhcNMTMwNjA2MTMwODM0WhcN\n\t\t\t\t\t\tMjMwNjA0MTMwODM0WjCBszELMAkGA1UEBhMCR0IxDjAMBgNVBAgTBUVzc2V4MRMw\n\t\t\t\t\t\tEQYDVQQHEwpDb2xjaGVzdGVyMRwwGgYDVQQKExNVbml2ZXJzaXR5IG9mIEVzc2V4\n\t\t\t\t\t\tMSUwIwYDVQQLExxJbmZvcm1hdGlvbiBTeXN0ZW1zIFNlcnZpY2VzMRkwFwYDVQQD\n\t\t\t\t\t\tExBpZHAxLmVzc2V4LmFjLnVrMR8wHQYJKoZIhvcNAQkBFhBzYW1pQGVzc2V4LmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtkqXuVUogstt2A/6\n\t\t\t\t\t\tcQ2hQxac8XIUhMRtWF7Rp8hoYawRFsD1QD/ppyutOHQTmdTes1THp9RFOxv/frFX\n\t\t\t\t\t\tloVZSCgnk74wY98h9dJVT/aZGtbGBEi8CDeJOyMgopt8xhmt8GGuzLXZz65vdb1z\n\t\t\t\t\t\tvXyYD5YjB94ECCLOkBXovkln4qSLOaDeOpwGADjQ+hEtsEYQ8Cob04cbZNhRJYBT\n\t\t\t\t\t\tlTeGTcQhSQToPiiVHG1jupDkawkAg0wJyqjxGjdcFWAn5jdK5Qixc1EOhrwcVnEp\n\t\t\t\t\t\tFEBJT8JFOS/Mek9YWc29//8BpVByeubbd/hv9fr9N2M9Z+AEJsIkNNYkrp2KybIW\n\t\t\t\t\t\trB7jhwIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NM\n\t\t\t\t\t\tIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQURnWjhBTuD3SjqSu9ob68\n\t\t\t\t\t\tDpVgGOIwHwYDVR0jBBgwFoAURnWjhBTuD3SjqSu9ob68DpVgGOIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAAkvvTQ6RacwMk6ru/Kjd7tS8O+pCnXkJeAc+Q5/ELEfqwct5hE/\n\t\t\t\t\t\tN6FhudmH/SrISQmJdWsJvUh5bkpT0tby/V2+9vKB+Bz/q8MaYdAB6p8wrrCl3qL6\n\t\t\t\t\t\tI9pX1wL0QeuDemObq7DDySo59A/UD/4hv/hiM6XbORFyAPjCkvHmmgr9VkoUPcwv\n\t\t\t\t\t\tEKqT60bX7dI9Nxr9/pAYexrSBSwyuk92JNJTpKqRmaBcV9AqPSA28JNJlZZJ4PRd\n\t\t\t\t\t\trDfLmgn2f37l6f6mhHyPGIcmzCSsjV0MYBq9awtuqAV746ZN28lWPKx39LkiO74f\n\t\t\t\t\t\tkwWCZNtxVk+q/aU+Vrpk7mXhvFD3JBQn07Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Essex"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.essex.ac.uk/iss/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Essex"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://tandfqa.literatumonline.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://tandfqa.literatumonline.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Atypon Systems: Atypon T and F QA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.atypon.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIJAMO9zKBOInK0MA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\n\t\t\t\t\t\tBAMTE3d3dy50YW5kZm9ubGluZS5jb20wHhcNMTQwMzE0MDUwNDAyWhcNMTcwMzEz\n\t\t\t\t\t\tMDUwNDAyWjAeMRwwGgYDVQQDExN3d3cudGFuZGZvbmxpbmUuY29tMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA+7mPo1QcQmquZzEQh1lPd0/52x3tUmeS\n\t\t\t\t\t\th+BnInF0Ddi412jA/73bOkJw8DUCeFMpyDLq5KIEh5hpWko/hiN2MV440jHOOz4c\n\t\t\t\t\t\tC6q6FIKo0VbnIG1J8W3llePya/7RgXMApLZIO9JlTbru2qcCibgk9cjnKdLYGRLQ\n\t\t\t\t\t\tOQYZJs4QyA9nN9n53e7Ov7JVOb7R1y77o8h39JhLNCvDlySfhDTeggal2yNb24xf\n\t\t\t\t\t\teL4Ee5cKOWdgyo6g5FkHmXn5jsIeBhdI26PyJa46s2/v+3vRzYg/7SpXPj5jZ5JH\n\t\t\t\t\t\t9VmweGU01MjqvHQVYd7Bfi0Ndik4otfE5nneOQngI3fR5nWV5oGngwIDAQABo2kw\n\t\t\t\t\t\tZzBGBgNVHREEPzA9ghN3d3cudGFuZGZvbmxpbmUuY29thiZodHRwczovL3d3dy50\n\t\t\t\t\t\tYW5kZm9ubGluZS5jb20vc2hpYmJvbGV0aDAdBgNVHQ4EFgQUTh9Dhbn3dZ+Os2eC\n\t\t\t\t\t\tRsJIDjh7+mowDQYJKoZIhvcNAQEFBQADggEBABhElasaAVvlbl3ZvZQlhEcQpqQD\n\t\t\t\t\t\tTvZRxncGrz6moC3pHnUho0L3ZphAnMyHUQlZfg8uZuJBeWTOPYCIYuqQXn+pQ+Si\n\t\t\t\t\t\tS9n2L8UnoCgNI3df9DDYb7tzpSipYGEXGOw2RUWr1PUD8GQtzP5jkzMPs0eAm/U3\n\t\t\t\t\t\tpmChGsS7HZbNle9fyBUha2UFebCWFhjUm2iLsN2+kCOkfxEpwLTy26cz1MBqkhDN\n\t\t\t\t\t\thNI51amuMNcL46a8+E1IW8L59W656YzJnJ8I2A9nuHdmWQGs5jICuG4dr7+70wCP\n\t\t\t\t\t\tLv0VNFSwnTxjA5Rocmae95yzHIE0I4tW7VD+q+yeEStXHCCN1rWHgLWJb/U="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://tandfqa.literatumonline.com/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://tandfqa.literatumonline.com/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://tandfqa.literatumonline.com/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://se.timeedit.net/saimia-generic-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@evolvera.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TimeEdit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://se.timeedit.net/saimia-generic-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://fi.timeedit.net/web/saimia/db1/timeedit/ssoLogout/saml2-generic",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TimeEdit, palvelun tarjoaa Evolvera AB"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TimeEdit, utvecklat av Evolvera AB"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TimeEdit, developed by Evolvera AB"
                  }
                ],
                "display_name": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TimeEdit Saimin ammattikorkeakoulun henkil\u00f6kunnalle ja opiskelijoille."
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TimeEdit f\u00f6r anst\u00e4llda och studenter vid Saimaa University of Applied Sciences"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TimeEdit for staff and students at Saimaa University of Applied Sciences"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAggCCQDSfJxeKVOg3jANBgkqhkiG9w0BAQUFADBSMQswCQYDVQQGEwJTRTESMBAGA1UE\nBxQJR8O2dGVib3JnMRQwEgYDVQQKEwtUaW1lRWRpdCBBQjEZMBcGA1UEAxMQYXV0aC50aW1lZWRp\ndC5zZTAeFw0xMzA2MTQwNzE0MTlaFw0xNTA2MTQwNzE0MTlaMFIxCzAJBgNVBAYTAlNFMRIwEAYD\nVQQHFAlHw7Z0ZWJvcmcxFDASBgNVBAoTC1RpbWVFZGl0IEFCMRkwFwYDVQQDExBhdXRoLnRpbWVl\nZGl0LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoL+lyBleTM0UGwGPLXPcfBMr\nomnPqP8+qlE+rOs0mEbvNyXdEWT0Z5P/XoMVfERJQQ6v5DAJF4c3o1BiPshZL8cj6QdLuJXLfVNG\nu5mzq/lKpB/n38Y4cWYxIyNtBcV9vcKDIRUbQP/27nEPMsbs2IaCXf6V3l3yQqbymZTyd8nBfZZF\nG95zDKBTSD5UQ3XW+LbvjKSZY4qDjyFkeOfj8kVyltWTHRMvKTKGLeNrGyCFiaMY/vfyA22gOyz4\nO2cY/oqFs8+82AOs3Si4+eGkFAq3CdEWSE4c69oDrzEWk+bKgxw5qyhWQ/13eh8AiZMDeqhT7q32\nRthqEp8GfwPM1QIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCRsLvMI4OJ076STPIyxnwk6bXRG5RL\nMR1pJ3umMNCa1LR1RnH1feuvm9dxerUTow7bPIsarJarh0iEIj2kLtu/prPm+ZcAKeEjh27pSM7m\n1F0XBkDqeP1msR+7g0aHlt0MzrKm/Esb1JX9YCO3MHl1XFc8xSnv2bxKWvER+tmDWkFrC0y1u2+H\nB/CfyES8ntBP6F7aZ6UQ4GTrqF0MZNGBoWFyXecGe5XEwWJwP4otSrJ2q7cbQU33xEcri0dHiMMl\nTiN/6f25dSm5UFCxqWGGAQndGfn/tE5FSqJlrHnbF2M6x4eH3MEIbHebI+nJlk6ASPdgIssvsDcd\nGImnaeS4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://fi.timeedit.net/web/saimia/db1/timeedit/ssoResponse/saml2-generic",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "false"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "TimeEdit Lapin ammattikorkeakoulun henkil\u00f6kunnalle ja opiskelijoille."
                },
                {
                  "lang": "sv",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "TimeEdit f\u00f6r anst\u00e4llda och studenter vid Saimaa University of Applied Sciences"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "TimeEdit for staff and students at Saimaa University of Applied Sciences"
                }
              ],
              "service_description": [
                {
                  "lang": "fi",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "TimeEdit, palvelun tarjoaa Evolvera AB"
                },
                {
                  "lang": "sv",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "TimeEdit, utvecklat av Evolvera AB"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "TimeEdit, developed by Evolvera AB"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.issuesonline.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sewell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kari@realnet.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kari"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sewell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kari@realnet.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kari"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.issuesonline.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-03-02T08:54:34Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Issues Online"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://issuesonline.co.uk/what-we-do/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Independence Educational Publishers Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.issuesonline.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.issuesonline.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.issuesonline.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.issuesonline.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.issuesonline.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Resources for schools, colleges and libraries"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.issuesonline.co.uk/resources/images/header/logo.png",
                    "height": "79",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "329"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Issues Online"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.issuesonline.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.issuesonline.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDITCCAgmgAwIBAgIJALqyRi7RcRm9MA0GCSqGSIb3DQEBBQUAMCkxJzAlBgNV\n\t\t\t\t\t\tBAMTHnNlcmVuaXR5LTAwMS5yZWFsbmV0MjAwMC5jby51azAeFw0xNTAyMjYxMjEy\n\t\t\t\t\t\tNTNaFw0yNTAyMjMxMjEyNTNaMCkxJzAlBgNVBAMTHnNlcmVuaXR5LTAwMS5yZWFs\n\t\t\t\t\t\tbmV0MjAwMC5jby51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL7f\n\t\t\t\t\t\tGguU7RUkjcExiPCDt6y7m8O95jgYTnBf0JR1NC6XUmq5ClSrvwopeoYHdFZgZNPg\n\t\t\t\t\t\thBdN9ZpLNf7zXprkNnycsMw4FNKw+9XptaiYLM4j1/yNTyZ8Rskrnvd1lPvlVjmx\n\t\t\t\t\t\tRvOtF+gNbXDKDgPTWYsvu1BkjtaHHcWN/tmRkPdjST7H4aGhQc7F5S0ka1HiqO1T\n\t\t\t\t\t\tp6IWYiJ25VCVq+eszCz+FO/bXkR8B32P3Zp0ccLwqOEAHn0K3UKu21/HJ6eNpT5s\n\t\t\t\t\t\t0b7uirPmveSS7L5+XSIDe6u1jmlxwtk9cDgSh0FvRBqEjLw5us7tXfMhUHTWAr/s\n\t\t\t\t\t\tGoUgXNHkYBRT6DFAxhsCAwEAAaNMMEowKQYDVR0RBCIwIIIec2VyZW5pdHktMDAx\n\t\t\t\t\t\tLnJlYWxuZXQyMDAwLmNvLnVrMB0GA1UdDgQWBBTCr+UQKfAtVYV9QIFpBp8sxXhJ\n\t\t\t\t\t\t8zANBgkqhkiG9w0BAQUFAAOCAQEAvRii27N52xgxwRsO9qQC67rbW4Wa7tNzKlGH\n\t\t\t\t\t\tiRzlhTWBFi5e3nmnDZ/svXQI0dfeJIsVV293CgO7RQqkcNH/ZqQ6wQW8nkBG0ruz\n\t\t\t\t\t\tBlPV8v27e017FzbrjncQMT8Fxsxxc5YPa710ihh+OTvDAjMhW7UmOYRL7oOTXI5Z\n\t\t\t\t\t\t95HM8MY0CercGLx6vUpLCoiAj/HXDu8lxP1meX4fUODoAiKXXyNI0F6X2WBCeW1O\n\t\t\t\t\t\tB/bTTlZ72l4idlNBvCEanRUR3vteHosW+NdoHZqfeb/2hoZDgVX6mxrNmVsngt+a\n\t\t\t\t\t\tHxkUVc9Uc6QfHSqM+dXfPFIex+3Xwa+jJ6RvjcoUIWJoMN8r0g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.issuesonline.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.issuesonline.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.issuesonline.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.issuesonline.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.issuesonline.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.issuesonline.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.lec.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McDonald"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lmcdonald@lec.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lisa"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "D'Souza"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sdsouza@lec.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sherwin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.lec.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-08-19T09:21:36Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAOhCOyKOXTcMdnvggD4B9+FnzBWtMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBgxFjAUBgNVBAMTDWlkcC5sZWMuYWMudWswHhcNMTQwNjE5MTUyODQxWhcN\n\t\t\t\t\t\tMzQwNjE5MTUyODQxWjAYMRYwFAYDVQQDEw1pZHAubGVjLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnnerdYQQxQIZU5eVNTKYtAKY3LaWLGFJ\n\t\t\t\t\t\th20xeYu8DYnc79EbitOROhHYrg/ORw9Ns63bvaLsXPwj6MC+zo31AF67SvmvKI7C\n\t\t\t\t\t\t5QqlXBaZVYPvgNEGIPYtqfMdEYBfnCea3Wfrc+R06IcLbC+NLJetv1M1BpzkfmSa\n\t\t\t\t\t\txwUA//pZ6iEYkta1StPwX7JwILQHXqNVDYH9QUldvOxyMsM+DpqY0pCnrBxoAvVO\n\t\t\t\t\t\t15e6aLkLIs3OHzhkREomiu3N3K8Wt4ePkBy8PruVpODWf2Yl1qAbXHczo2jeR9S+\n\t\t\t\t\t\tjgY8TRdblPn2WcKoZ6Xs0hQldlGzTcoPYREB3J671iI/0Qd4bBky9QIDAQABo2Ew\n\t\t\t\t\t\tXzA+BgNVHREENzA1gg1pZHAubGVjLmFjLnVrhiRodHRwczovL2lkcC5sZWMuYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFNq8a16FuYh4F4H642sLTgWlIr5o\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQAgoPBw1rcnYM2LrNO4GjATEBUt9mX/OGXCR6ar\n\t\t\t\t\t\tHrY/tEYn3kDIOukO3mjpVJXuxuRJEZZuG5+iCqb9/icgh7UPRZZ1pQS92JdtSvZk\n\t\t\t\t\t\tCLZfaEih3jP3khZEzxPSnscMkMYyMxdMxcFIzrq/vt36gzCU5X2F5gO89jn++z2t\n\t\t\t\t\t\tEi8LRmUPKJ/czStcMTf8uS6Xy1jrIPoEUcqv8z9TFir+SWynz2NqLlRq8f/q3qNb\n\t\t\t\t\t\t4c/B50roEAWi6UjG1BoWsAHpAU6vNpAwX5rpPF2jfW3diOaSlOeId7C679ccWmQJ\n\t\t\t\t\t\tGp39POQVUg52O0GAfPJgGgmUrlThA5+DQ5KdGTlmOsObK3LV"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lec.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.lec.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.lec.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.lec.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.lec.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.lec.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.lec.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.lec.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.lec.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.lec.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.lec.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.lec.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lec.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAOhCOyKOXTcMdnvggD4B9+FnzBWtMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBgxFjAUBgNVBAMTDWlkcC5sZWMuYWMudWswHhcNMTQwNjE5MTUyODQxWhcN\n\t\t\t\t\t\tMzQwNjE5MTUyODQxWjAYMRYwFAYDVQQDEw1pZHAubGVjLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnnerdYQQxQIZU5eVNTKYtAKY3LaWLGFJ\n\t\t\t\t\t\th20xeYu8DYnc79EbitOROhHYrg/ORw9Ns63bvaLsXPwj6MC+zo31AF67SvmvKI7C\n\t\t\t\t\t\t5QqlXBaZVYPvgNEGIPYtqfMdEYBfnCea3Wfrc+R06IcLbC+NLJetv1M1BpzkfmSa\n\t\t\t\t\t\txwUA//pZ6iEYkta1StPwX7JwILQHXqNVDYH9QUldvOxyMsM+DpqY0pCnrBxoAvVO\n\t\t\t\t\t\t15e6aLkLIs3OHzhkREomiu3N3K8Wt4ePkBy8PruVpODWf2Yl1qAbXHczo2jeR9S+\n\t\t\t\t\t\tjgY8TRdblPn2WcKoZ6Xs0hQldlGzTcoPYREB3J671iI/0Qd4bBky9QIDAQABo2Ew\n\t\t\t\t\t\tXzA+BgNVHREENzA1gg1pZHAubGVjLmFjLnVrhiRodHRwczovL2lkcC5sZWMuYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFNq8a16FuYh4F4H642sLTgWlIr5o\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQAgoPBw1rcnYM2LrNO4GjATEBUt9mX/OGXCR6ar\n\t\t\t\t\t\tHrY/tEYn3kDIOukO3mjpVJXuxuRJEZZuG5+iCqb9/icgh7UPRZZ1pQS92JdtSvZk\n\t\t\t\t\t\tCLZfaEih3jP3khZEzxPSnscMkMYyMxdMxcFIzrq/vt36gzCU5X2F5gO89jn++z2t\n\t\t\t\t\t\tEi8LRmUPKJ/czStcMTf8uS6Xy1jrIPoEUcqv8z9TFir+SWynz2NqLlRq8f/q3qNb\n\t\t\t\t\t\t4c/B50roEAWi6UjG1BoWsAHpAU6vNpAwX5rpPF2jfW3diOaSlOeId7C679ccWmQJ\n\t\t\t\t\t\tGp39POQVUg52O0GAfPJgGgmUrlThA5+DQ5KdGTlmOsObK3LV"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Leicester College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lec.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Leicester College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.ripfadev.co.uk/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Catling"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:robin.catling@ripfa.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Catling"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:robin.catling@ripfa.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.ripfadev.co.uk/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-03-03T15:04:35Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Research in Practice for Adults TEST SITE"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.ripfa.org.uk/about-us/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Dartington Hall Trust"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TEST - Learning resources for the Social Care sector \n\t\t\tsupporting evidence-informed practice with adults and families"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.ripfadev.co.uk/assets/_userfiles/images/general/Partner_logos/ripfa_logo.png",
                    "height": "76",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "132"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Research in Practice for Adults TEST SITE"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDdjCCAl6gAwIBAgIJAJQrX225OXYjMA0GCSqGSIb3DQEBBQUAMDAxETAPBgNV\n\t\t\t\t\tBAoTCFJJUEZBREVWMRswGQYDVQQDExJ3d3cucmlwZmFkZXYuY28udWswHhcNMTYw\n\t\t\t\t\tMjI5MTU0MjE4WhcNMjYwMjI2MTU0MjE4WjAwMREwDwYDVQQKEwhSSVBGQURFVjEb\n\t\t\t\t\tMBkGA1UEAxMSd3d3LnJpcGZhZGV2LmNvLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\tAQ8AMIIBCgKCAQEAnbARvd4NSCdrwRfxgrByix75yb25xuQJKRhADPIf6YLGM4nx\n\t\t\t\t\t7R11HPHi3H5RgKpBKr/frmFV5dTmPL+D/BzECkQXCIzDuYghImF9uevrTnqlC+4G\n\t\t\t\t\tnaQy/hwht54h4NNTwlDRxaf4ALZP5sb3DQ2deR9YP5D7NyM57qRZ1lXrvi3FLwG3\n\t\t\t\t\tq7BgwIlRxAwow9lHRlJNTiTxaVVZRZsTnzCdVsezln7YHCQ5hftk7IkLxLfh4Kne\n\t\t\t\t\tDnNWW1PWCBE/9CTKr1TCgXzRxme/KTDwOB/I0XStUUPiG5FqwB+BL+ACI4A59qAy\n\t\t\t\t\tk1ZaJ6hCmBncdLBeenU6cvvcor+/D8CN66qw7wIDAQABo4GSMIGPMB0GA1UdDgQW\n\t\t\t\t\tBBQqBfXTynAW9iZ0GaoUEJJxSmC0ajBgBgNVHSMEWTBXgBQqBfXTynAW9iZ0GaoU\n\t\t\t\t\tEJJxSmC0aqE0pDIwMDERMA8GA1UEChMIUklQRkFERVYxGzAZBgNVBAMTEnd3dy5y\n\t\t\t\t\taXBmYWRldi5jby51a4IJAJQrX225OXYjMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcN\n\t\t\t\t\tAQEFBQADggEBAGg5iv6uMhGD4pxvgoy9c/xC8nYuIPGF37PGsdcDrN5eIuwp8E89\n\t\t\t\t\tt+BEZ+odTKIxXPnIf7Ddk4JmpzNi82CsthARqO8NzmQrZbjgTl5ItSyhj8PRxLL5\n\t\t\t\t\tmT8F9L5dFtA7hzdlZucJVXEkAm1o0X9Ki8ucNsrIj7RnEWN+vEjfSNvlumIus9Li\n\t\t\t\t\tYQjNlDqkXhNbo72bkoeSBo90aEbZYtSPRBLcDMrbD0DsUxJqrjK3I3hgjyF1Zagw\n\t\t\t\t\tF2l7wflWxH2ODGqHFrm6QfnHelFIeb2svSh65fb7mzvpoC15t53P44CzeUNF3b7E\n\t\t\t\t\tfLQb7ewjZCVQ8T4edUSWQv2mF7ZBw7ntAOQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDdjCCAl6gAwIBAgIJAJQrX225OXYjMA0GCSqGSIb3DQEBBQUAMDAxETAPBgNV\n\t\t\t\t\tBAoTCFJJUEZBREVWMRswGQYDVQQDExJ3d3cucmlwZmFkZXYuY28udWswHhcNMTYw\n\t\t\t\t\tMjI5MTU0MjE4WhcNMjYwMjI2MTU0MjE4WjAwMREwDwYDVQQKEwhSSVBGQURFVjEb\n\t\t\t\t\tMBkGA1UEAxMSd3d3LnJpcGZhZGV2LmNvLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\tAQ8AMIIBCgKCAQEAnbARvd4NSCdrwRfxgrByix75yb25xuQJKRhADPIf6YLGM4nx\n\t\t\t\t\t7R11HPHi3H5RgKpBKr/frmFV5dTmPL+D/BzECkQXCIzDuYghImF9uevrTnqlC+4G\n\t\t\t\t\tnaQy/hwht54h4NNTwlDRxaf4ALZP5sb3DQ2deR9YP5D7NyM57qRZ1lXrvi3FLwG3\n\t\t\t\t\tq7BgwIlRxAwow9lHRlJNTiTxaVVZRZsTnzCdVsezln7YHCQ5hftk7IkLxLfh4Kne\n\t\t\t\t\tDnNWW1PWCBE/9CTKr1TCgXzRxme/KTDwOB/I0XStUUPiG5FqwB+BL+ACI4A59qAy\n\t\t\t\t\tk1ZaJ6hCmBncdLBeenU6cvvcor+/D8CN66qw7wIDAQABo4GSMIGPMB0GA1UdDgQW\n\t\t\t\t\tBBQqBfXTynAW9iZ0GaoUEJJxSmC0ajBgBgNVHSMEWTBXgBQqBfXTynAW9iZ0GaoU\n\t\t\t\t\tEJJxSmC0aqE0pDIwMDERMA8GA1UEChMIUklQRkFERVYxGzAZBgNVBAMTEnd3dy5y\n\t\t\t\t\taXBmYWRldi5jby51a4IJAJQrX225OXYjMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcN\n\t\t\t\t\tAQEFBQADggEBAGg5iv6uMhGD4pxvgoy9c/xC8nYuIPGF37PGsdcDrN5eIuwp8E89\n\t\t\t\t\tt+BEZ+odTKIxXPnIf7Ddk4JmpzNi82CsthARqO8NzmQrZbjgTl5ItSyhj8PRxLL5\n\t\t\t\t\tmT8F9L5dFtA7hzdlZucJVXEkAm1o0X9Ki8ucNsrIj7RnEWN+vEjfSNvlumIus9Li\n\t\t\t\t\tYQjNlDqkXhNbo72bkoeSBo90aEbZYtSPRBLcDMrbD0DsUxJqrjK3I3hgjyF1Zagw\n\t\t\t\t\tF2l7wflWxH2ODGqHFrm6QfnHelFIeb2svSh65fb7mzvpoC15t53P44CzeUNF3b7E\n\t\t\t\t\tfLQb7ewjZCVQ8T4edUSWQv2mF7ZBw7ntAOQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://www.ripfadev.co.uk/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ripfadev.co.uk/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sso.sbg.ac.at/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+43 662 8044 6761"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Renzl"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:clemens.renzl@sbg.ac.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Clemens"
          }
        }
      ],
      "entity_id": "https://sso.sbg.ac.at/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://eduid.at/policy/mdrps-20140606"
              }
            ],
            "registration_instant": "2010-04-26T14:16:34Z",
            "registration_authority": "http://eduid.at",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAM/a3obaebb4N7KALoWgPOwQKFPuMA0GCSqGSIb3DQEB\nBQUAMBgxFjAUBgNVBAMTDXNzby5zYmcuYWMuYXQwHhcNMTAwNDEwMTgxMzU0WhcN\nMzAwNDEwMTgxMzU0WjAYMRYwFAYDVQQDEw1zc28uc2JnLmFjLmF0MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAso8F1k1Z3subIMuyqXHpPCNJogiv3GQ1\nuNXHNUL31ToqkIxcL+yL7QBLgnB8pZKmOaDOnveSllrTI8lArzJUbIYTRq/q8vjC\n35I5elBDktrOAAIeoogwdyhtau/AyiNvbZmPZGlcgBmWAPIUPoFjVF+U5+CbiQ8q\niAzvdJn+yJvX+dkRQGg33Ebvh0pnlvD5qWeiwqWlJgFk4zUFNK40p3FFDMETNkTk\n7/U+bt/xMdwYdHI3wvb42ZBXTajsTsXnSlSA5B695dfpHfGbeIqTae32XsWHm77p\n+Nrl7flUJNGtTm8SNPx7K4CJIdRhdhKiuIX+5sOSxZg8iVDghZC4pwIDAQABo2Ew\nXzA+BgNVHREENzA1gg1zc28uc2JnLmFjLmF0hiRodHRwczovL3Nzby5zYmcuYWMu\nYXQvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFCr2Q6zhfulYa7kl0Pm752frFiF9\nMA0GCSqGSIb3DQEBBQUAA4IBAQB/AyjefKCO1cP806UO/L2olnsnD0VA50smzTto\np72RH8sBCosRwkeyHI3/aqjSPEqsB1p1IcEEeOR4b+07PgtWmOMbZ6l9zOGDB7zB\nRCK2tq1P1avux6RGlj1q3vHlllfcdUnVFe3U6TOfk3faTeVBTLTpssBQOv0Y/W2k\nmWnkiKSHMFPlwWqllohGFuTfhSRLLDmX4lshBmC2WWPa/GmpqNnvY97oEYe0F/pV\nm/boLPgSS4HU06/UyTL75mHgtC9iCj4iLpDPJPDp8XcfwO62QogFU3+U7qqezqmV\nVfvOxPSoIdhmoHDf8FyFGq6FOVs0pSd+7RFboe5lAvmp6PrI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sbg.ac.at"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.sbg.ac.at:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.sbg.ac.at:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso.sbg.ac.at/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.sbg.ac.at/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sso.sbg.ac.at/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.sbg.ac.at/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.sbg.ac.at:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.sbg.ac.at:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sbg.ac.at"
              },
              {
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e4t Salzburg"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Salzburg"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAM/a3obaebb4N7KALoWgPOwQKFPuMA0GCSqGSIb3DQEB\nBQUAMBgxFjAUBgNVBAMTDXNzby5zYmcuYWMuYXQwHhcNMTAwNDEwMTgxMzU0WhcN\nMzAwNDEwMTgxMzU0WjAYMRYwFAYDVQQDEw1zc28uc2JnLmFjLmF0MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAso8F1k1Z3subIMuyqXHpPCNJogiv3GQ1\nuNXHNUL31ToqkIxcL+yL7QBLgnB8pZKmOaDOnveSllrTI8lArzJUbIYTRq/q8vjC\n35I5elBDktrOAAIeoogwdyhtau/AyiNvbZmPZGlcgBmWAPIUPoFjVF+U5+CbiQ8q\niAzvdJn+yJvX+dkRQGg33Ebvh0pnlvD5qWeiwqWlJgFk4zUFNK40p3FFDMETNkTk\n7/U+bt/xMdwYdHI3wvb42ZBXTajsTsXnSlSA5B695dfpHfGbeIqTae32XsWHm77p\n+Nrl7flUJNGtTm8SNPx7K4CJIdRhdhKiuIX+5sOSxZg8iVDghZC4pwIDAQABo2Ew\nXzA+BgNVHREENzA1gg1zc28uc2JnLmFjLmF0hiRodHRwczovL3Nzby5zYmcuYWMu\nYXQvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFCr2Q6zhfulYa7kl0Pm752frFiF9\nMA0GCSqGSIb3DQEBBQUAA4IBAQB/AyjefKCO1cP806UO/L2olnsnD0VA50smzTto\np72RH8sBCosRwkeyHI3/aqjSPEqsB1p1IcEEeOR4b+07PgtWmOMbZ6l9zOGDB7zB\nRCK2tq1P1avux6RGlj1q3vHlllfcdUnVFe3U6TOfk3faTeVBTLTpssBQOv0Y/W2k\nmWnkiKSHMFPlwWqllohGFuTfhSRLLDmX4lshBmC2WWPa/GmpqNnvY97oEYe0F/pV\nm/boLPgSS4HU06/UyTL75mHgtC9iCj4iLpDPJPDp8XcfwO62QogFU3+U7qqezqmV\nVfvOxPSoIdhmoHDf8FyFGq6FOVs0pSd+7RFboe5lAvmp6PrI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e4t Salzburg"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Salzburg"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-salzburg.at/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-salzburg.at/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e4t Salzburg"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Salzburg"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth-idp.pucrs.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dilermando Bueno"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dbueno@pucrs.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth-idp.pucrs.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6jCCAdICAQAwDQYJKoZIhvcNAQEFBQAwOzEKMAgGA1UECxMBIDELMAkGA1UE\nBhMCQlIxIDAeBgNVBAMTF3NoaWJib2xldGgtaWRwLnB1Y3JzLmJyMB4XDTE0MDkw\nMzE2NTAyNloXDTE5MDkwMjE2NTAyNlowOzEKMAgGA1UECxMBIDELMAkGA1UEBhMC\nQlIxIDAeBgNVBAMTF3NoaWJib2xldGgtaWRwLnB1Y3JzLmJyMIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1iilPh8rOxBD8ceqrAb8KcN3WRX6V8CtSEs8\nGBAKjDt9nRYpFavkJcW6w6+w6ZJz1KlJndy6sgleGjsXR1za5nK3gKe3nvWJwkIm\nqNX/nAjBegCnvxq8VSJ4VspLYZQYoTIbAiGvSs7pP++/7OBimb424JHU+16+ceqG\nF75C9tXeA3vOJzHS/bLgxhRwyhhug25DHkTl8wVDuCU0q/P8Y0D6sLEXaYFb2jl0\npiXWK7dz/5LhX2AyyKtrYlQEzgndR/SkANY5iIFiXqJ7/q5tQTOQQN4aeb9YEQJa\nNWJfoa4co8LTmHki6KQvPCmtaBBAjSU7kk9s3+mXJL8lgtRI6QIDAQABMA0GCSqG\nSIb3DQEBBQUAA4IBAQDRcEBWeU30bZBS/mtcDGdhsbxjLmd1IhHAio/iuHrVvfv6\n0RJv9BtOokGbtsGLInxH/HEqUAm7+I3lm2UH/ah5oSEreumLPpNnGwtqsK+z/oN3\nwe03FEd0WUl8GkMsLapmbaQ/NlP8oQDVWTjfYsrUSak42uW8LZ88OUz30NHhYFwo\n2UCXamrmbHrnlCKZFKjWypn2GCwPMZ+liM1Yfxdlp6yVzgTDKpAI8fU/bEwgc3V4\nOIw0tlAwW9X8O7oWvd7h9dfyqCCmHee2LzqZaC+uAb0XPEDeEN+rhgwZPGsjlxpJ\nZc48iq/nJ5myburOM8iFHNedgaLhTDDuTXIM0EWL"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pucrs.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-idp.pucrs.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth-idp.pucrs.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth-idp.pucrs.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth-idp.pucrs.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth-idp.pucrs.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth-idp.pucrs.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-idp.pucrs.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth-idp.pucrs.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pucrs.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.pucrs.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.pucrs.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "PUCRS - Pontificia Universidade Catolica do Rio Grande do Sul"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "PUCRS - Pontificia Universidade Catolica do Rio Grande do Sul"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PUCRS - Pontificia Universidade Catolica do Rio Grande do Sul"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PUCRS - Pontificia Universidade Catolica do Rio Grande do Sul"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6jCCAdICAQAwDQYJKoZIhvcNAQEFBQAwOzEKMAgGA1UECxMBIDELMAkGA1UE\nBhMCQlIxIDAeBgNVBAMTF3NoaWJib2xldGgtaWRwLnB1Y3JzLmJyMB4XDTE0MDkw\nMzE2NTAyNloXDTE5MDkwMjE2NTAyNlowOzEKMAgGA1UECxMBIDELMAkGA1UEBhMC\nQlIxIDAeBgNVBAMTF3NoaWJib2xldGgtaWRwLnB1Y3JzLmJyMIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1iilPh8rOxBD8ceqrAb8KcN3WRX6V8CtSEs8\nGBAKjDt9nRYpFavkJcW6w6+w6ZJz1KlJndy6sgleGjsXR1za5nK3gKe3nvWJwkIm\nqNX/nAjBegCnvxq8VSJ4VspLYZQYoTIbAiGvSs7pP++/7OBimb424JHU+16+ceqG\nF75C9tXeA3vOJzHS/bLgxhRwyhhug25DHkTl8wVDuCU0q/P8Y0D6sLEXaYFb2jl0\npiXWK7dz/5LhX2AyyKtrYlQEzgndR/SkANY5iIFiXqJ7/q5tQTOQQN4aeb9YEQJa\nNWJfoa4co8LTmHki6KQvPCmtaBBAjSU7kk9s3+mXJL8lgtRI6QIDAQABMA0GCSqG\nSIb3DQEBBQUAA4IBAQDRcEBWeU30bZBS/mtcDGdhsbxjLmd1IhHAio/iuHrVvfv6\n0RJv9BtOokGbtsGLInxH/HEqUAm7+I3lm2UH/ah5oSEreumLPpNnGwtqsK+z/oN3\nwe03FEd0WUl8GkMsLapmbaQ/NlP8oQDVWTjfYsrUSak42uW8LZ88OUz30NHhYFwo\n2UCXamrmbHrnlCKZFKjWypn2GCwPMZ+liM1Yfxdlp6yVzgTDKpAI8fU/bEwgc3V4\nOIw0tlAwW9X8O7oWvd7h9dfyqCCmHee2LzqZaC+uAb0XPEDeEN+rhgwZPGsjlxpJ\nZc48iq/nJ5myburOM8iFHNedgaLhTDDuTXIM0EWL"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PUCRS - Pontificia Universidade Catolica do Rio Grande do Sul"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PUCRS - Pontificia Universidade Catolica do Rio Grande do Sul"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.pucrs.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.pucrs.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "PUCRS - Pontificia Universidade Catolica do Rio Grande do Sul"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "PUCRS - Pontificia Universidade Catolica do Rio Grande do Sul"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://federation.crous-lille.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "informatique@crous-lille.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federation.crous-lille.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-10-02T15:28:06Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.crous-lille.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federation.crous-lille.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://federation.crous-lille.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "crous-lille.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.crous-lille.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Staffs"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnels"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Lille"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Lille"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEgDCCA2igAwIBAgIRAOe2cWAZ40jrksSS84mgafQwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDA5MjUwMDAwMDBaFw0xNjEyMzEyMzU5NTlaMEcxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEiMCAGA1UEAxMZZmVkZXJhdGlv\nbi5jcm91cy1saWxsZS5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nANnI5vHZtv9EG1YcpR+Lu0i2zEHwg9REfT60TKOuRZ4uGEO5HkPz0EZk//g5ANrL\nE/wM6Dc+FzWERy1FIrDEve8rPcSfWjOnei32N0+xmWb470gkXHMHa768JZgYYKPT\nYQtw2w3mO2K6xPSVSgcGp0cToCgeN3Zmj7OjnP1d8FRXQNZfkNbGeTkcE14zTGvn\nil9gGSg6eLp4n+AhzzFqVrsh7nhjDQUVGYSS13gc3QqrbvzhgVA3ezUhuTSf6a2Q\nAyc/aZ+fsPc2lqBxAN5+CXE+F8hZ2EwT4lS9tPyC9LMmkG6Z/5p2LxjiWD9BAmPs\n8PpBgiv2PQDYpEiImOr7cg8CAwEAAaOCAXYwggFyMB8GA1UdIwQYMBaAFAy9k2gM\n896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBQA6VUfnc6ew1jN4PWrQ88BPAFhLzAO\nBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcD\nAQYIKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEw\nOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJF\nTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8v\nY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYa\naHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwJAYDVR0RBB0wG4IZZmVkZXJhdGlv\nbi5jcm91cy1saWxsZS5mcjANBgkqhkiG9w0BAQUFAAOCAQEAIgY+7c4wkrbZpY3o\niGyUJ13AjbqyUReqedYEhOC7a6/QfR+AvhSpsig+qPHGz6ouGx7AbSagW3cUvN9Y\nXKAEMvaZDTvgXldQma8/KHxls7sRAKa/xj52C7KJPNynjZCtry3Ibaf/XVG2436/\nqA1F99mmPzg1kwJTnKvUUpWxazcipfKPxw9diYudxPUSxVKS+k1TCynaP40T5r+F\nZu+ubcxq2fxvr9Hg44hUNPmDGZUE7UFMb97y2oVl/Wt9M6Uv85P593e9GHh9RO98\nrIzZ+UPSX0Y5lkCcEuqMR9FoY/Hs4jGsVBMrwmWGZJGMM2PlT9xIcY2cCqeKu2E/\nLfrh4A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS Lille"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.crous-lille.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS Lille"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://academic.mintel.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Malik"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:amalik@mintel.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Abdul"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Shah"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ashah@mintel.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ameet"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://academic.mintel.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-07-01T10:09:14Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mintel Oxygen Academic"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://academic.mintel.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Mintel International Group Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.mintel.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibboleth.mintel.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "World class Market Intelligence reports from Mintel.  Data and analysis on consumers, markets, companies and brands."
                  }
                ],
                "logo": [
                  {
                    "text": "https://academic.mintel.com/static/mintel_header/images/mintelLogo.png",
                    "height": "109",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "211"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mintel Reports Academic"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIECDCCAvCgAwIBAgIJAO7HNDxW/p6sMA0GCSqGSIb3DQEBBQUAMIGEMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEQMA4GA1UECBMHRW5nbGFuZDEPMA0GA1UEBxMGTG9uZG9uMScwJQYD\n\t\t\t\t\t\tVQQKEx5NaW50ZWwgSW50ZXJuYXRpb25hbCBHcm91cCBMdGQxCzAJBgNVBAsTAklU\n\t\t\t\t\t\tMRwwGgYDVQQDExNhY2FkZW1pYy5taW50ZWwuY29tMB4XDTExMDMyMTEyMDQyNVoX\n\t\t\t\t\t\tDTIxMDMxODEyMDQyNVowgYQxCzAJBgNVBAYTAkdCMRAwDgYDVQQIEwdFbmdsYW5k\n\t\t\t\t\t\tMQ8wDQYDVQQHEwZMb25kb24xJzAlBgNVBAoTHk1pbnRlbCBJbnRlcm5hdGlvbmFs\n\t\t\t\t\t\tIEdyb3VwIEx0ZDELMAkGA1UECxMCSVQxHDAaBgNVBAMTE2FjYWRlbWljLm1pbnRl\n\t\t\t\t\t\tbC5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDBnMZaWUjR2Dn7\n\t\t\t\t\t\tdACN6ecDbGRAm/Z2rHa9OhQMXQhkt5685OlvTBqy0NkHLo+IDK7CqELM3B41+EAb\n\t\t\t\t\t\t6Lr3BLce/LFTxcBQsnHnnD5tINW64gJpD2H6QhSHJ2aqVLeY8wPl6fXtlVytluBV\n\t\t\t\t\t\tk1T6yjiP/YfUBg7tUSOrsG9nLQCKbZa6+Swubuu0RD42y8v+eUBGZNYJe+MqidxJ\n\t\t\t\t\t\trx2/oBwLrbS/a6FgRckPXOU/PZIx/Xeb7I7TIiypTG+JclszphYYWyjowELVkdc/\n\t\t\t\t\t\t2RYIjR0sPeGVE9XOvPd65Vu5iA3q7QX0TXfr/sfvSH6cHe6eMwHAGutUrzO6FtDs\n\t\t\t\t\t\td9E61PsXAgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5T\n\t\t\t\t\t\tU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBSbbZMSZPF3EcrK/8Tf\n\t\t\t\t\t\tJqdvf+/RODAfBgNVHSMEGDAWgBSbbZMSZPF3EcrK/8TfJqdvf+/RODANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAmV3hGvndRDttCzoB+u6FoKevaifS9x4cwcOZAuCQuLWM09E5\n\t\t\t\t\t\tryFxZMSkTKxnfRM9b183qq+rGWQyGJx6mv5GOBOOjlVWgxYfV2acxSRU8D0ZXZR+\n\t\t\t\t\t\tR4wVx7CL3lg8INzzZ8xdGdToI8L8EH5Q2ogfiVhc6ubQ/rRvxDVlQga3AwN8zFhl\n\t\t\t\t\t\tQHH2W6QQAh9NPHRac3MtTeISpyO9q8vmIYhG2/4iy8Y46zM9KgIoeZkG9tY4Of7L\n\t\t\t\t\t\tRNNnH2p2d6Z13fL+4GtUD9vLGi+3LYpuexnMyK721t3z4gbMrNHq7PqmJayvMw4T\n\t\t\t\t\t\ty1i5AwcB1d7VsdGmUDdaaAr5beJzjSS21W7tuw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://academic.mintel.com/resolve_ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://testacademic.mintel.com/resolve_ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://academic.mintel.com/resolve_ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://testacademic.mintel.com/resolve_ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "4",
              "location": "https://shibboleth.mintel.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.mintel.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://test-shibboleth.mintel.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://test-shibboleth.mintel.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.mintel.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.mintel.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test-shibboleth.mintel.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test-shibboleth.mintel.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://coip-test.sunet.se/shibboleth",
    {
      "entity_id": "https://coip-test.sunet.se/shibboleth",
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish University Network (SUNET)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sunet.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SUNET"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://coip-test.sunet.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://coip-test.sunet.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://coip-test.sunet.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://coip-test.sunet.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://coip-test.sunet.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://coip-test.sunet.se/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "coip-test.sunet.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAMJwrBkmzHKJMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEmNvaXAtdGVzdC5zdW5ldC5zZTAeFw0xMDEyMDcwOTM0NTFaFw0yMDEyMDQw\nOTM0NTFaMB0xGzAZBgNVBAMTEmNvaXAtdGVzdC5zdW5ldC5zZTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAMR4JETtaGG+7n5+NksVT/7LnmveeNwbGuPS\nCyW1GY+7yYBwjMnnsFnnprl2curgER/HeOXf3bBxnoxbSVFdaZILPRVStLngzhYJ\n7qGOGWHWdukDDzgCDfdOVEOwLAiV4TXhCoKzaRKaUV63Ul9pEG2ogkQHlsW7zTmX\n4DJNdpBgmB/ohjuAceY3xUrKj9TBZf9KPKYE1D8xoig5qCUhWUqWrltxBBbNubsa\nUIXun9Hf1zemgViLuPI2s5/RD5uY3x6FpkXeNGRHvPT7+LnKrPNi4g41m1FZ+wvj\nxPkNVXBLJgEIsHtYTKvY8dXaA+k1xyFvqjWf1RjuG8TYIlvHoDkCAwEAAaNAMD4w\nHQYDVR0RBBYwFIISY29pcC10ZXN0LnN1bmV0LnNlMB0GA1UdDgQWBBR/jp1zUgjw\nrKZimB05qmprVJvYEDANBgkqhkiG9w0BAQUFAAOCAQEAeAYegf9tMG2Lg7AW2tIq\n5bTbaMwRzLtFkB1KZrh17RUSneiF1FrRD5Qo4O1/rh0PrxO9+R1M9VpYXrcEg48u\nTLOo7EEaJaF7+Eh9Z/UaJjY5zL6hhQSW+nxHHtluuIRCJwH26oF04v9Ty9TC+4Ax\ng6NuvysrzRWhdeWh4voY1lBi1po+/MqUWufXS/uxrHBT9XNSb6dvqWTvUEe09Sj9\nUTHOU967H8PfFKB6w8/lIqCd66P3PnZrNQVmfbjDkrASkmvhUKEMc//Nn/+MS02T\nuXfFMclNeY0vwkDmtQCDB2o8DGQS8H3hpXb2MmJtFgu/81yZRqX/0uRC3kGBQXyd\ncA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=coip-test.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "coip-test.sunet.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAMJwrBkmzHKJMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEmNvaXAtdGVzdC5zdW5ldC5zZTAeFw0xMDEyMDcwOTM0NTFaFw0yMDEyMDQw\nOTM0NTFaMB0xGzAZBgNVBAMTEmNvaXAtdGVzdC5zdW5ldC5zZTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAMR4JETtaGG+7n5+NksVT/7LnmveeNwbGuPS\nCyW1GY+7yYBwjMnnsFnnprl2curgER/HeOXf3bBxnoxbSVFdaZILPRVStLngzhYJ\n7qGOGWHWdukDDzgCDfdOVEOwLAiV4TXhCoKzaRKaUV63Ul9pEG2ogkQHlsW7zTmX\n4DJNdpBgmB/ohjuAceY3xUrKj9TBZf9KPKYE1D8xoig5qCUhWUqWrltxBBbNubsa\nUIXun9Hf1zemgViLuPI2s5/RD5uY3x6FpkXeNGRHvPT7+LnKrPNi4g41m1FZ+wvj\nxPkNVXBLJgEIsHtYTKvY8dXaA+k1xyFvqjWf1RjuG8TYIlvHoDkCAwEAAaNAMD4w\nHQYDVR0RBBYwFIISY29pcC10ZXN0LnN1bmV0LnNlMB0GA1UdDgQWBBR/jp1zUgjw\nrKZimB05qmprVJvYEDANBgkqhkiG9w0BAQUFAAOCAQEAeAYegf9tMG2Lg7AW2tIq\n5bTbaMwRzLtFkB1KZrh17RUSneiF1FrRD5Qo4O1/rh0PrxO9+R1M9VpYXrcEg48u\nTLOo7EEaJaF7+Eh9Z/UaJjY5zL6hhQSW+nxHHtluuIRCJwH26oF04v9Ty9TC+4Ax\ng6NuvysrzRWhdeWh4voY1lBi1po+/MqUWufXS/uxrHBT9XNSb6dvqWTvUEe09Sj9\nUTHOU967H8PfFKB6w8/lIqCd66P3PnZrNQVmfbjDkrASkmvhUKEMc//Nn/+MS02T\nuXfFMclNeY0vwkDmtQCDB2o8DGQS8H3hpXb2MmJtFgu/81yZRqX/0uRC3kGBQXyd\ncA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=coip-test.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://coip-test.sunet.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://coip-test.sunet.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://coip-test.sunet.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://coip-test.sunet.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://coip-test.sunet.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://coip-test.sunet.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://coip-test.sunet.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://coip-test.sunet.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://coip-test.sunet.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://coip-test.sunet.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://nordushare-dev.nordu.net/shibboleth",
    {
      "entity_id": "https://nordushare-dev.nordu.net/shibboleth",
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nordushare-dev.nordu.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nordushare-dev.nordu.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nordushare-dev.nordu.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nordushare-dev.nordu.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "nordushare-dev.nordu.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAJ5ml9hvwGGbMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\nBAMTGG5vcmR1c2hhcmUtZGV2Lm5vcmR1Lm5ldDAeFw0xMDAyMjYwODQyMTBaFw0y\nMDAyMjQwODQyMTBaMCMxITAfBgNVBAMTGG5vcmR1c2hhcmUtZGV2Lm5vcmR1Lm5l\ndDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANU+6XYCTSHlNgtFfmSN\nNFK7rDmwAo+OzunzZzQRHy9VmacRiREBVAa6qy/zR292HAiRg06oU0GCGlRO79pI\n6qTIVKOmDJ+seMzfGQ1E1dgAelort6BHebaifSM0iwacSuooopa0FOHE5usAfx/h\nMx4iw0zKTZ9zZhRjO4zcxhRuyKjvXYzpYma9QrHDZhqJfy095zFfTwX7gNwk4YNI\n2XLDWDYpwJHXENjzvZ/lU0zugpz0Pe1apC4zsKMdNa3hrkHBRIk03SYJy5553Zii\nvldAxEGZKu2WCRbrh9v8KfyxABPBkzenNN7KQCHPPC5GM3M0hFrOF3es+KTm2S9G\nxPsCAwEAAaNGMEQwIwYDVR0RBBwwGoIYbm9yZHVzaGFyZS1kZXYubm9yZHUubmV0\nMB0GA1UdDgQWBBQ6+ZPltnZEDFIC9fI8qAdsy6y4MjANBgkqhkiG9w0BAQUFAAOC\nAQEAP22l4WOyAUSmws18L3J2GJYkQ1bcpMBhS0XJCFTY+iCrFCPUeXy8EIpSCk0Y\nIWyEeZxt+wzpZnq92+zOOe7Y0WIPpvNW0Xnp/JXsnUwX3C+G8pfzZSjsDbWEUrZW\nywCKikjjrLEKd7WNeWoiabb8uiyTey3Fn/nAJKWQTzmfAuw3E6qGjWwEKkpKorVM\nS/V9sZaU6cn4DdwUcWYM+fLdoN+guhvq3tcoFaMXqV/h5unfWoLQKv1HU8+fciVu\nASIdGcirEZCB5YlXPAFo2DLC11SHkDvCXxZY7+lqJVwXJkPbeFHtlXMvluu9vFz8\nKaYlHoIdpaOJncFcM6QJQyZPJQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=nordushare-dev.nordu.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "nordushare-dev.nordu.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAJ5ml9hvwGGbMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\nBAMTGG5vcmR1c2hhcmUtZGV2Lm5vcmR1Lm5ldDAeFw0xMDAyMjYwODQyMTBaFw0y\nMDAyMjQwODQyMTBaMCMxITAfBgNVBAMTGG5vcmR1c2hhcmUtZGV2Lm5vcmR1Lm5l\ndDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANU+6XYCTSHlNgtFfmSN\nNFK7rDmwAo+OzunzZzQRHy9VmacRiREBVAa6qy/zR292HAiRg06oU0GCGlRO79pI\n6qTIVKOmDJ+seMzfGQ1E1dgAelort6BHebaifSM0iwacSuooopa0FOHE5usAfx/h\nMx4iw0zKTZ9zZhRjO4zcxhRuyKjvXYzpYma9QrHDZhqJfy095zFfTwX7gNwk4YNI\n2XLDWDYpwJHXENjzvZ/lU0zugpz0Pe1apC4zsKMdNa3hrkHBRIk03SYJy5553Zii\nvldAxEGZKu2WCRbrh9v8KfyxABPBkzenNN7KQCHPPC5GM3M0hFrOF3es+KTm2S9G\nxPsCAwEAAaNGMEQwIwYDVR0RBBwwGoIYbm9yZHVzaGFyZS1kZXYubm9yZHUubmV0\nMB0GA1UdDgQWBBQ6+ZPltnZEDFIC9fI8qAdsy6y4MjANBgkqhkiG9w0BAQUFAAOC\nAQEAP22l4WOyAUSmws18L3J2GJYkQ1bcpMBhS0XJCFTY+iCrFCPUeXy8EIpSCk0Y\nIWyEeZxt+wzpZnq92+zOOe7Y0WIPpvNW0Xnp/JXsnUwX3C+G8pfzZSjsDbWEUrZW\nywCKikjjrLEKd7WNeWoiabb8uiyTey3Fn/nAJKWQTzmfAuw3E6qGjWwEKkpKorVM\nS/V9sZaU6cn4DdwUcWYM+fLdoN+guhvq3tcoFaMXqV/h5unfWoLQKv1HU8+fciVu\nASIdGcirEZCB5YlXPAFo2DLC11SHkDvCXxZY7+lqJVwXJkPbeFHtlXMvluu9vFz8\nKaYlHoIdpaOJncFcM6QJQyZPJQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=nordushare-dev.nordu.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nordushare-dev.nordu.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nordushare-dev.nordu.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nordushare-dev.nordu.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nordushare-dev.nordu.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nordushare-dev.nordu.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://nordushare-dev.nordu.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nordushare-dev.nordu.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://nordushare-dev.nordu.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://nordushare-dev.nordu.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://nordushare-dev.nordu.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://reading.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Egleton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:s.egleton@reading.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sue"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chapman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:c.d.chapman@reading.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://reading.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-10-31T10:08:01Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://openathens.auth.reading.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://openathens.auth.reading.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "reading.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDajCCAlKgAwIBAgIISa3f8+58NocwDQYJKoZIhvcNAQEFBQAwTDEiMCAGA1UE\n\t\t\t\t\t\tCgwZVGhlIFVuaXZlcnNpdHkgb2YgUmVhZGluZzEmMCQGA1UEAwwdb3BlbmF0aGVu\n\t\t\t\t\t\tcy5hdXRoLnJlYWRpbmcuYWMudWswHhcNMTIwMTEyMTIxNDAwWhcNMjIwMTEyMTIx\n\t\t\t\t\t\tNDAwWjBMMSIwIAYDVQQKDBlUaGUgVW5pdmVyc2l0eSBvZiBSZWFkaW5nMSYwJAYD\n\t\t\t\t\t\tVQQDDB1vcGVuYXRoZW5zLmF1dGgucmVhZGluZy5hYy51azCCASIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEBBQADggEPADCCAQoCggEBAJNYQ5WyjzIufrzwdnz8gBri2uTETchGZlYYHPUF\n\t\t\t\t\t\tLA9W8uFfZwlFbJPnxcGxiXSCVmPGfLp0c8DywmQUbumdlVuTDPBoQnKMCst8fRcI\n\t\t\t\t\t\tCitVbYTotup97HEneR3zoWVgsAYZ92QJ/Jucxf+aXrhUygK3cIjUXq69Kgk3ywjc\n\t\t\t\t\t\tgFfRIjpQCVi7h2VuhNE2Zy7/7kSHpG7BVWC9ebUrDC7M+enF7c+wNZZEMZzjAzDE\n\t\t\t\t\t\ts8WuIqgnnog+KpEYqEvhNgjTKx5/aZ8JEWBmdKQc/Q/UnwUtjsYyC5aWr4q0rX5/\n\t\t\t\t\t\tIothWPf9dwzVbJutK8fyJ098HrViCGEwFbCCGw6dAhSOAqECAwEAAaNQME4wHQYD\n\t\t\t\t\t\tVR0OBBYEFL19dBzqhuxKdXZOjxR98MipVHf5MB8GA1UdIwQYMBaAFL19dBzqhuxK\n\t\t\t\t\t\tdXZOjxR98MipVHf5MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAChi\n\t\t\t\t\t\tOe5GqHzBymz+7I+UquzLz4v4aZrTbse1kiMHNVBGPnZsmAO5J0pR+8G4fI9/q8yi\n\t\t\t\t\t\tH1NZ7j2Rju/LAnbACJoWD/Y09csVqkeYCsostlBAg0iswiGrV4XsUjoIV/2G8K/6\n\t\t\t\t\t\tw7o2aNw0vao8gLryS7iAVTJnivnzmtjItUMX9bFCFR6DKA2z74FeyslBE8NqAw49\n\t\t\t\t\t\tsRTw7OH3rhuCeSVieXNUUnMD1nX1cdRkndht3wn1EpJoWEywup92YqBZORywFPcY\n\t\t\t\t\t\tS3bWx3YM0LY8BWYUjq8CBR5Sw4WdDcDiR3YeBrT9mUiVa7yqxPoA8I/+mmkjPpiA\n\t\t\t\t\t\tXJlpnBImjl8K0L6rTNE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDajCCAlKgAwIBAgIISa3f8+58NocwDQYJKoZIhvcNAQEFBQAwTDEiMCAGA1UE\n\t\t\t\t\t\tCgwZVGhlIFVuaXZlcnNpdHkgb2YgUmVhZGluZzEmMCQGA1UEAwwdb3BlbmF0aGVu\n\t\t\t\t\t\tcy5hdXRoLnJlYWRpbmcuYWMudWswHhcNMTIwMTEyMTIxNDAwWhcNMjIwMTEyMTIx\n\t\t\t\t\t\tNDAwWjBMMSIwIAYDVQQKDBlUaGUgVW5pdmVyc2l0eSBvZiBSZWFkaW5nMSYwJAYD\n\t\t\t\t\t\tVQQDDB1vcGVuYXRoZW5zLmF1dGgucmVhZGluZy5hYy51azCCASIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEBBQADggEPADCCAQoCggEBAJNYQ5WyjzIufrzwdnz8gBri2uTETchGZlYYHPUF\n\t\t\t\t\t\tLA9W8uFfZwlFbJPnxcGxiXSCVmPGfLp0c8DywmQUbumdlVuTDPBoQnKMCst8fRcI\n\t\t\t\t\t\tCitVbYTotup97HEneR3zoWVgsAYZ92QJ/Jucxf+aXrhUygK3cIjUXq69Kgk3ywjc\n\t\t\t\t\t\tgFfRIjpQCVi7h2VuhNE2Zy7/7kSHpG7BVWC9ebUrDC7M+enF7c+wNZZEMZzjAzDE\n\t\t\t\t\t\ts8WuIqgnnog+KpEYqEvhNgjTKx5/aZ8JEWBmdKQc/Q/UnwUtjsYyC5aWr4q0rX5/\n\t\t\t\t\t\tIothWPf9dwzVbJutK8fyJ098HrViCGEwFbCCGw6dAhSOAqECAwEAAaNQME4wHQYD\n\t\t\t\t\t\tVR0OBBYEFL19dBzqhuxKdXZOjxR98MipVHf5MB8GA1UdIwQYMBaAFL19dBzqhuxK\n\t\t\t\t\t\tdXZOjxR98MipVHf5MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAChi\n\t\t\t\t\t\tOe5GqHzBymz+7I+UquzLz4v4aZrTbse1kiMHNVBGPnZsmAO5J0pR+8G4fI9/q8yi\n\t\t\t\t\t\tH1NZ7j2Rju/LAnbACJoWD/Y09csVqkeYCsostlBAg0iswiGrV4XsUjoIV/2G8K/6\n\t\t\t\t\t\tw7o2aNw0vao8gLryS7iAVTJnivnzmtjItUMX9bFCFR6DKA2z74FeyslBE8NqAw49\n\t\t\t\t\t\tsRTw7OH3rhuCeSVieXNUUnMD1nX1cdRkndht3wn1EpJoWEywup92YqBZORywFPcY\n\t\t\t\t\t\tS3bWx3YM0LY8BWYUjq8CBR5Sw4WdDcDiR3YeBrT9mUiVa7yqxPoA8I/+mmkjPpiA\n\t\t\t\t\t\tXJlpnBImjl8K0L6rTNE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Reading"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.reading.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Reading"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/idp.umit.dk",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/idp.umit.dk",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2014-01-02T14:49:44Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/idp.umit.dk/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "umit.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Uddannelsesministeriets It"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IT Department of the Ministry of Higher Education"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "umit.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICsDCCAZgCAQcwDQYJKoZIhvcNAQELBQAwHjEcMBoGA1UEAwwTaHR0cHM6Ly9p\nZHAudW1pdC5kazAeFw0xNTAxMDEwMDAwMDBaFw0yNTEyMzEyMzU5NTlaMB4xHDAa\nBgNVBAMME2h0dHBzOi8vaWRwLnVtaXQuZGswggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQDHiAwKahBTuI4Z+IJ1rgOeEiCCy3bR9QIe3BpCsejFCU5rSzkW\nANqVuc1PDfp0JdIZhrPXsmDJQMmidPCGPIDQKo+bk+af3+EUFS/I/+35sSBX2vf+\nh1DHvZV9jsznmpSVjp7HZ/WoPWBykWBJO0AOVmzB5zlaqkS36J76+wxerwdpuExV\nnYSNd73S+AyT/EZ+tXAO+6lQ8FL/YMlJnUkSaSqLSHFy01D2qBNmYRwBpCS6/dUZ\nyxi0t5j8ghKUD4BHOZVavn65J62cJdXiOcMRyUAIp57GXQrL63KtrjIcXddq+CZy\nZ5t37EdUOIz42joFcy73MFOntynlKEvOw1BJAgMBAAEwDQYJKoZIhvcNAQELBQAD\nggEBAKkfFk8Zq0silkoNnU1PATnJH+ZBnzJRHcaT6F6hZD8AYgDJalYPYvdd+C+q\n/XKgOl4Zn3VRSUuZeCaPJiyR3KImAYX0LaRauSFebKcLUzmXlxapQdU0zpcUy5zc\nasB6hIhFlQp4E1/F7SzO8qnnyo0THxXn6fvDnJ6jGTWFCC+bUPD6587lp+cEX5qU\n/sEJQmLR6tyJ818FWyJu12HglFNELnKPzEzYpNtFNUd+Eu1cvjVxzOm0fblDVvf/\n/112CCqW22eyo2tDTAte06e/buaZf/dSK6TwEkwvjxVeqRFUKWOeA+dHMc/6Eazi\nWma0d+CKLHPagLmm29t8EF37hZE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Uddannelsesministeriets It"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IT Department of the Ministry of Higher Education"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://fivu.dk/minister-og-ministerium/organisation/uddannelsesministeriets-it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://fivu.dk/en/the-minister-and-the-ministry/organisation/it-department-of-the-ministry-of-science-innovation-and-higher-education"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Uddannelsesministeriets It"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IT Department of the Ministry of Higher Education"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibidp.varndean.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Skelhorn"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sas@varndean.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Skelhorn"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sas@varndean.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibidp.varndean.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-09-16T11:52:38Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUYnAHVOZFTgSHvflAx2tiuguv7kowDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwITEfMB0GA1UEAxMWc2hpYmlkcC52YXJuZGVhbi5hYy51azAeFw0xNDA1MDEx\n\t\t\t\t\t\tMDEwNTlaFw0zNDA1MDExMDEwNTlaMCExHzAdBgNVBAMTFnNoaWJpZHAudmFybmRl\n\t\t\t\t\t\tYW4uYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCAz+ei5lxa\n\t\t\t\t\t\tTA4LwlADyP4JJKaGIa1xpQoSAkluJaXogaTq0BsXIFEk0/FOoTCq3bjUVpq+bjfz\n\t\t\t\t\t\tZbLeFioKUyWBULNW//qLBmfcN8lVWdWyhju/PepezoM3sjup7JW4pZQp/7fdjmok\n\t\t\t\t\t\tfKFaaBFVsnILzIZ2/26KmDzek19cmlfI/Zn+9VTzKA7TL0qneQdFoyTkLUB2gIZG\n\t\t\t\t\t\t1TGqohPGxW59ZyYsU0Ic209zpqS1VSz4lMAXvfCMAU/ngmDIXUqxWSwV/zZcEZGq\n\t\t\t\t\t\tySMdE23U5YFT9jNG2aLaYXx8GB6sWg/kshMcgadfPyT9AZa68ObpSdrm6uc1mqgj\n\t\t\t\t\t\tPhqvevqDRLMtAgMBAAGjczBxMFAGA1UdEQRJMEeCFnNoaWJpZHAudmFybmRlYW4u\n\t\t\t\t\t\tYWMudWuGLWh0dHBzOi8vc2hpYmlkcC52YXJuZGVhbi5hYy51ay9pZHAvc2hpYmJv\n\t\t\t\t\t\tbGV0aDAdBgNVHQ4EFgQUmuqY360czCtkfOA9uYzZDygT2ogwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQADggEBAGjREkcSrh8oEx1TCylPjB+DrzlZuIcrsQKtRBr3CwQcP011h5Dwq/Lq\n\t\t\t\t\t\t1RXtMFm10qnU2+x7bhI8xCqjlz0k80G6yEcY/9+pwqL6LgoeUT3sGvXfMf0k6usJ\n\t\t\t\t\t\tnoW7QnGPavB+i2Al8yeH/setuVUWnsObISiLte3poWn1fY8028MQqDuwNJRojBRY\n\t\t\t\t\t\t3M//PcIdYzftbeqgtno5g9++ChY3ZwaPFHnLJra/FVvTeUa0aIfk4KhEsmqzp/18\n\t\t\t\t\t\tOjXjAm0VoplJriXkOkpXBRpP/XraSC+wha4JhjrZZTLOs2qwHf0WkT19H5i5Fe2x\n\t\t\t\t\t\thG2q5MTeya5x8Bg9CY3QvgzviQlwuho="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "varndean.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.varndean.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.varndean.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.varndean.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.varndean.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibidp.varndean.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.varndean.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.varndean.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.varndean.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "varndean.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://shibidp.varndean.ac.uk/idp/images/dummylogo.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Varndean College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUYnAHVOZFTgSHvflAx2tiuguv7kowDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwITEfMB0GA1UEAxMWc2hpYmlkcC52YXJuZGVhbi5hYy51azAeFw0xNDA1MDEx\n\t\t\t\t\t\tMDEwNTlaFw0zNDA1MDExMDEwNTlaMCExHzAdBgNVBAMTFnNoaWJpZHAudmFybmRl\n\t\t\t\t\t\tYW4uYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCAz+ei5lxa\n\t\t\t\t\t\tTA4LwlADyP4JJKaGIa1xpQoSAkluJaXogaTq0BsXIFEk0/FOoTCq3bjUVpq+bjfz\n\t\t\t\t\t\tZbLeFioKUyWBULNW//qLBmfcN8lVWdWyhju/PepezoM3sjup7JW4pZQp/7fdjmok\n\t\t\t\t\t\tfKFaaBFVsnILzIZ2/26KmDzek19cmlfI/Zn+9VTzKA7TL0qneQdFoyTkLUB2gIZG\n\t\t\t\t\t\t1TGqohPGxW59ZyYsU0Ic209zpqS1VSz4lMAXvfCMAU/ngmDIXUqxWSwV/zZcEZGq\n\t\t\t\t\t\tySMdE23U5YFT9jNG2aLaYXx8GB6sWg/kshMcgadfPyT9AZa68ObpSdrm6uc1mqgj\n\t\t\t\t\t\tPhqvevqDRLMtAgMBAAGjczBxMFAGA1UdEQRJMEeCFnNoaWJpZHAudmFybmRlYW4u\n\t\t\t\t\t\tYWMudWuGLWh0dHBzOi8vc2hpYmlkcC52YXJuZGVhbi5hYy51ay9pZHAvc2hpYmJv\n\t\t\t\t\t\tbGV0aDAdBgNVHQ4EFgQUmuqY360czCtkfOA9uYzZDygT2ogwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQADggEBAGjREkcSrh8oEx1TCylPjB+DrzlZuIcrsQKtRBr3CwQcP011h5Dwq/Lq\n\t\t\t\t\t\t1RXtMFm10qnU2+x7bhI8xCqjlz0k80G6yEcY/9+pwqL6LgoeUT3sGvXfMf0k6usJ\n\t\t\t\t\t\tnoW7QnGPavB+i2Al8yeH/setuVUWnsObISiLte3poWn1fY8028MQqDuwNJRojBRY\n\t\t\t\t\t\t3M//PcIdYzftbeqgtno5g9++ChY3ZwaPFHnLJra/FVvTeUa0aIfk4KhEsmqzp/18\n\t\t\t\t\t\tOjXjAm0VoplJriXkOkpXBRpP/XraSC+wha4JhjrZZTLOs2qwHf0WkT19H5i5Fe2x\n\t\t\t\t\t\thG2q5MTeya5x8Bg9CY3QvgzviQlwuho="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Varndean College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.varndean.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Varndean College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp2.bth.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "administrative",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 455 38 51 00"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ithelpdesk@bth.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Blekinge Institute of Technology"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 455 38 51 00"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ithelpdesk@bth.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Blekinge Institute of Technology"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 455 381500"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "IT Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ithelpdesk@bth.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "Blekinge Institute of Technology"
          }
        }
      ],
      "entity_id": "https://idp2.bth.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp2.bth.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.bth.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2.bth.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp2.bth.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp2.bth.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bth.se"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.bth.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.bth.se/eng"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r Blekinge Tekniska H\u00f6gskola"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Blekinge Institute of Technology"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp2.bth.se/idp/images/logo_bth.png",
                    "height": "139",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "114"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Blekinge Tekniska H\u00f6gskola"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Blekinge Institute of Technology"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "bth.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:56.181775,15.590592"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.11.184.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "194.47.128.0/19"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:6b0:2a::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUAjSTOLSd0Pch+pYciElnGplug8kwDQYJKoZIhvcNAQEL\nBQAwFjEUMBIGA1UEAwwLaWRwMi5idGguc2UwHhcNMTYwMjE4MTE1OTI0WhcNMzYw\nMjE4MTE1OTI0WjAWMRQwEgYDVQQDDAtpZHAyLmJ0aC5zZTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAMbKNJA6MEAtWxPCzMAc84dxsVBo0+Tmh0wbMJUI\nZIOAvU4ceRUKc/ZpOZ0KbnjX7W48J+dVyTD9ix4vyr4kyHXL7DK6XH3rtZafpUxo\nPX/MBA3JBd2uArrYSChmJS8bUMwZFZmN7tCEAMRsSozUxyYBZ0HCxJdhSTS2Rzrg\nZcd5Gd9wzmxOmXR2yx8xwfvJUSXotH1x9zLIu80XD+dzn7Ym9XyMnVxVmZJ5G9AG\npiwccsUXo/6g3/DzRL0i2nLQWZPxZ4EUkRLAU+bBkhJ2HpshC4pJzzmZmLG+H1VQ\n4Yl6FcfEcwkzl0Vj356PTKjA9iTTpHIPFj7au9knGR+HMh0CAwEAAaNdMFswHQYD\nVR0OBBYEFKvL63FlLvmyTOAcHPnFB/oufu6HMDoGA1UdEQQzMDGCC2lkcDIuYnRo\nLnNlhiJodHRwczovL2lkcDIuYnRoLnNlL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3\nDQEBCwUAA4IBAQBs+q+yxQFE2CmufA2uFvBXgQV72zVwCwNeWgFsIt40JIVyGuEi\nLhJGuygAKgDq0weMkS+v+Uq+6VFfSdDQtkMqLmQbzQPPTX5KDXZBl+0qHoe1N2pb\n0EM+J8z6mUYInN33EqO8p7rxxLtbWHrf52uLeVJ0GRCjM0VYJQVdkdZkHaJJ6zjX\nTfH2lJmH0df+CSgiQATV5DOdTQlFe7lYvzUIeACjf6vEHEeDcV36U+U9Y1/sd0y6\n1HLIAeSH9AfmfubhTXLHD8xaQG2J1BJaOKZA+HeYL7MgJV9i9x9nyiv95tkxjDgl\nGbWSba9T9esRqtkbCarn3pNZbtkvA/eL7AkD"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVALFoKFMrJuieCS8dfq1gtvn345/lMA0GCSqGSIb3DQEB\nCwUAMBYxFDASBgNVBAMMC2lkcDIuYnRoLnNlMB4XDTE2MDIxODExNTkyMloXDTM2\nMDIxODExNTkyMlowFjEUMBIGA1UEAwwLaWRwMi5idGguc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDTprjClVpgF6iDPrC6sbZMhQeGI95pa2fCIlcV\nuIsGglNn5rfUETtjcn1Njf3XXqLgKi0f+WykowBXuarw2cguvUjwiE3jQARyxg+M\n3uuqUWIAYrE8bInbR2uVs9qhylqKv/tK+ILXFXrNiylqTN1xyV1LdEcGmiyr8uWz\n9srrt/zV0LqHt5IpuDlS3vcgKFgmBipP1I7jiTTH98JnbgSxwSTWv40FaEAWPbgz\nMlaBrzbKsVU/h+IRpVaQCnWI2MyBb9rr2B/q+3OWv3CpBk/uL++xSZC9teXHgFWF\ntDqVakTXC7P6ySPx885mzOqzWIzXgRqm4GTcT7FubvN0ztnjAgMBAAGjXTBbMB0G\nA1UdDgQWBBRvZOA7bCpDBGhA7gMGZBJyapFMKzA6BgNVHREEMzAxggtpZHAyLmJ0\naC5zZYYiaHR0cHM6Ly9pZHAyLmJ0aC5zZS9pZHAvc2hpYmJvbGV0aDANBgkqhkiG\n9w0BAQsFAAOCAQEAtmCmwWJSyH4WGqoPusV0m5Oe8JiTOBC66ccZo7fOYPIQh0OU\nU9SKlSvuoC3i6oOAXEDd/8yr1YScgaCFxbDb+h1GFv5Ng1QXudCowSYXabQA3pEw\nmmDc3+0FkRtRkR2tks2K3563mjFEWoMyd8y+3Aycu53FI/NNCNcawrB8VmE+GLXN\n6Jq1pwISVamDiJanykiDubEjKEm8AuwjKz/3Vbu1TtDKNPcbDdpZGHNKgNMuSeDC\nC6IIfksrX1+HwFx5AyCAEg3wp9xeP3+BEQciX25HSwNEOCy382O6pWQC+mFvTXVA\nNtrCdbz6qKoDHbanW9dGf/6dGg95GwTJAA1ZSA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAOSVWhOajvTHRYTBeX4CXM/zZ1l+MA0GCSqGSIb3DQEB\nCwUAMBYxFDASBgNVBAMMC2lkcDIuYnRoLnNlMB4XDTE2MDIxODExNTkyNFoXDTM2\nMDIxODExNTkyNFowFjEUMBIGA1UEAwwLaWRwMi5idGguc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDmHrGdGbyhgX+HlfSBbQ5T8+hgF3YpdqwCfzrj\nzil+YdZ+GO6YT84zSbmH75SX9wbcOw2TTfaPUPF40CSF5VBp9zqvnBdFINFN2cEd\nsI96UbB/BQGUeTV8dze298ItCWtHV/y+BYWRyDgnFRijt8WIUJUHA9FvxcrU5zns\npXVStBlqIZt5iaGrvt5s5imTi50gq1SmtdOBE64vkYkQHdzIcWcd+00dpXgqiciU\nej/sA+NnE9IreGXUpKlLHhLmJuQXxqHBfXAX90CYiOutpotUPJULaxYt5UlAVQc0\n46Xeb7kQoNkKyOqKwgm4I6YevwkNmS70/As/TEH2LIjUpG2JAgMBAAGjXTBbMB0G\nA1UdDgQWBBRIaBMwAzytSCAmOuvKBR2NTRu3gDA6BgNVHREEMzAxggtpZHAyLmJ0\naC5zZYYiaHR0cHM6Ly9pZHAyLmJ0aC5zZS9pZHAvc2hpYmJvbGV0aDANBgkqhkiG\n9w0BAQsFAAOCAQEA0QJ25UYZc0vbqkEUbsAG3tqlC6woUq0sCfTbf522PtlVPpbS\nUXuOoNJvhFFa0qEny6QqJhGmFT51ZUC5FaRevzshVMkTxMDTOwRh7YF94KUTwtWn\ntpjGabharxvOUuaD1FPQyXtIq49YH1KuaqpZFN+f8mjLVVVYqjvDgB+lpb2FvzoQ\n//eLyFyrZR2ZTqHMMDSVC6Y3fm8PP7kGFgSMYNaaKTGaNVao1dGE09Lu3O2yjfgT\nB9VY8Qllh3EWiRkI3VA8tR5RuMjFd6A8AOtoxbW2BJQM4rn9Ma2Su2nOD23s7w/H\nKWto/xyUQbv82gswLTMa9y869J9X9IcMEYjVxg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Blekinge Tekniska H\u00f6gskola"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Blekinge Institute of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bth.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "BTH"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.hmc.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cabercrombie@hmc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Cindy Abercrombie"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mshacklett@hmc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mitch Shacklett"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dvu@hmc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Duke Vu"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "andy@hmc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andy Davenport"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.hmc.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.hmc.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.hmc.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hmc.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.hmc.edu"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.hmc.edu/communications/wp-content/uploads/sites/19/2013/11/HMC-BGW-RGB-150dpi-150x150.png",
                    "lang": "en",
                    "height": "150",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "150"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.hmc.edu/cis/about-cis/policies/claremont-appropriate-use-policy/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Harvey Mudd College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGjCCAgKgAwIBAgIUN47xMNeIGq+9fTb4aJR1KEWc7wswDQYJKoZIhvcNAQEF\nBQAwIzEhMB8GA1UEAxMYaWRwMi5maXNjaGVyaWRlbnRpdHkuY29tMB4XDTExMTIx\nMjE2NTc0NFoXDTMxMTIxMjE2NTc0NFowIzEhMB8GA1UEAxMYaWRwMi5maXNjaGVy\naWRlbnRpdHkuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAm/SU\n7QC7q5ijdiZ1aq7/wwOYGWUkI5TvIGAZgOtVwteHfiwNjsQL1YcVtmxPj37Gts1z\n/+DbRaPGWaXxvMj0SzwsYiJEw/P5EKOC3ujhc10cs6RutdpNLno3CjbQazZrpDqk\nOPwGsGtc0r6Jn9MRsZDpfzaVS8E1wbBUQ1uU5PfUUvW+Q1pxDqzOSv8ZtqIgFQgS\nk1JpjqL45h5t+C5WnxidLjkB1L0fgVLi+DDjYYK+6sTlCd600Ixufr1Vb9Qj+90v\n//U5XkUNYwCAVASuVlXpWXfdfKyCuUyVa+3VZIWRKxye8abN/jJoE1uHmgbnVWul\naPzrvNjbzVLo7nBo2QIDAQABo0YwRDAjBgNVHREEHDAaghhpZHAyLmZpc2NoZXJp\nZGVudGl0eS5jb20wHQYDVR0OBBYEFN3LsRRIf64KoZtwrtGt1bfwnSX6MA0GCSqG\nSIb3DQEBBQUAA4IBAQAVSzbN7EtwyvMka3hIX/5KGKbavF7FtIGN4p7jg2UMeH89\npAzjxIGOnibFIr5QF9RV0qtG/3SaQMyH18OV73SkcLYOifjJKEnceGi44TdBkfIG\n/6LY3n5lMd3UvC0qbR59qZ0qIkd2kmfo/b9mfPjwy3+6ypN6J9DeSQFxffu+o7UI\npi+52yms2KD8klrC+Ptq76kKetJifRalHNK0cEMzNae6s+sQYxGVhqOHijEgXvTB\nabocdzekYdo3N1BoA3TNcqWvBcVEt6m9iW/cDKMr8xlkpII8A8p9piPozcFmCDll\nip/lOg2kOdU7AB80pFPqQLvDSArQpzItz88dbws6"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "error_url": "https://login.hmc.edu/idp/shibboleth/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Harvey Mudd College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hmc.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Harvey Mudd College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.izs.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Quaranta"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@izs.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Fabrizio"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Zippo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@izs.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Daniele"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.izs.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2014-10-27T16:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEzCCAfugAwIBAgIUZ8t3b8eAjLbPx7nCcmtLRNfMP/wwDQYJKoZIhvcNAQEF\nBQAwFTETMBEGA1UEAxMKaWRwLml6cy5pdDAeFw0xNDAzMjQxMjI2NTBaFw0zNDAz\nMjQxMjI2NTBaMBUxEzARBgNVBAMTCmlkcC5penMuaXQwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQCEZQogi++nPZ4OO1lklIcyCvA0W9NCyKLvVybJh1XM\nRT7jCoYa/rcsTS0mXt8sQIhRgC/mYAjIUMAophRaxewLjXiUBzFEdgc2ssP/ooYm\nO90nK5u3huiOav0KjNyS2Noei06yO57Iqx3L7ZJfWj2ligNrdN2HvIv+zMLe6m+d\n5g0tNWeP1Fya2kC9rY4O2yOR826vkJ/B4CLg8nQcOIWFnYWxBfNGWalShUR0K5+o\nRS3FWEda1ngg5ZxuLRKHVbGPU3eF513ZLGBS77aw9/L2dkFuaa8P+s/OQgTGI2Lp\n1CDAysIcxAZldY61BTxUfChYA99zgeQltvLmQMVr4YoPAgMBAAGjWzBZMDgGA1Ud\nEQQxMC+CCmlkcC5penMuaXSGIWh0dHBzOi8vaWRwLml6cy5pdC9pZHAvc2hpYmJv\nbGV0aDAdBgNVHQ4EFgQUgQniglbaB0PJ8a6mBBEG7QB+Z80wDQYJKoZIhvcNAQEF\nBQADggEBACey/uQv50Tla66zVhm4C9Rj6zVJp/QMMNwO0j7BeihE3h4YRVqBrL79\nVhChAhnV8CTuP2g4iSx8ssk/ypw9/vIt54hnEgk16/gc+Fe/5IUk8Sd0ACtrX83u\nwHBi/QTBY+ja7HHUqG1OOItHTOdSkaEA3wMrRICIAem+tc6riyqt7Rdq+TyPVukg\n55oCYkYmDX6wPU/0yWOuR6ZbDthggmsKATteRrT//mM5qLhW0Ddiv5wWqCIlt3Oo\nF0PKMvSLcp+4wF7XpaoMsHY6biufInIY2o4pb+Qie/4VeXMbYG4OEahvxXZl1ugp\nz+ag8yGYGtSO0bWu0ysZBLnaYCV2HDA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "izs.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.izs.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.izs.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.izs.it/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.izs.it/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.izs.it:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.izs.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.izs.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.izs.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.izs.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.izs.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.izs.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "izs.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.izs.it/IZS/Engine/RAServePG.php/P/695510010701/W/0/L/0"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.izs.it/IZS/Engine/RAServePG.php/P/695510010701/W/0/L/1"
                  }
                ],
                "description": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti dell' Istituto Zooprofilattico Sperimentale dell'Abruzzo e del Molise \"G. Caporale\""
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for the user of Istituto Zooprofilattico Sperimentale dell'Abruzzo e del Molise \"G. Caporale\""
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.izs.it/IZS/Engine/RAServePG.php/P/695610010701/W/0/L/0"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.izs.it/IZS/Engine/RAServePG.php/P/695610010701/W/0/L/1"
                  }
                ],
                "display_name": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Istituto Zooprofilattico Sperimentale dell'Abruzzo e del Molise \"G. Caporale\""
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Istituto Zooprofilattico Sperimentale dell'Abruzzo e del Molise \"G. Caporale\""
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEzCCAfugAwIBAgIUZ8t3b8eAjLbPx7nCcmtLRNfMP/wwDQYJKoZIhvcNAQEF\nBQAwFTETMBEGA1UEAxMKaWRwLml6cy5pdDAeFw0xNDAzMjQxMjI2NTBaFw0zNDAz\nMjQxMjI2NTBaMBUxEzARBgNVBAMTCmlkcC5penMuaXQwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQCEZQogi++nPZ4OO1lklIcyCvA0W9NCyKLvVybJh1XM\nRT7jCoYa/rcsTS0mXt8sQIhRgC/mYAjIUMAophRaxewLjXiUBzFEdgc2ssP/ooYm\nO90nK5u3huiOav0KjNyS2Noei06yO57Iqx3L7ZJfWj2ligNrdN2HvIv+zMLe6m+d\n5g0tNWeP1Fya2kC9rY4O2yOR826vkJ/B4CLg8nQcOIWFnYWxBfNGWalShUR0K5+o\nRS3FWEda1ngg5ZxuLRKHVbGPU3eF513ZLGBS77aw9/L2dkFuaa8P+s/OQgTGI2Lp\n1CDAysIcxAZldY61BTxUfChYA99zgeQltvLmQMVr4YoPAgMBAAGjWzBZMDgGA1Ud\nEQQxMC+CCmlkcC5penMuaXSGIWh0dHBzOi8vaWRwLml6cy5pdC9pZHAvc2hpYmJv\nbGV0aDAdBgNVHQ4EFgQUgQniglbaB0PJ8a6mBBEG7QB+Z80wDQYJKoZIhvcNAQEF\nBQADggEBACey/uQv50Tla66zVhm4C9Rj6zVJp/QMMNwO0j7BeihE3h4YRVqBrL79\nVhChAhnV8CTuP2g4iSx8ssk/ypw9/vIt54hnEgk16/gc+Fe/5IUk8Sd0ACtrX83u\nwHBi/QTBY+ja7HHUqG1OOItHTOdSkaEA3wMrRICIAem+tc6riyqt7Rdq+TyPVukg\n55oCYkYmDX6wPU/0yWOuR6ZbDthggmsKATteRrT//mM5qLhW0Ddiv5wWqCIlt3Oo\nF0PKMvSLcp+4wF7XpaoMsHY6biufInIY2o4pb+Qie/4VeXMbYG4OEahvxXZl1ugp\nz+ag8yGYGtSO0bWu0ysZBLnaYCV2HDA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Istituto Zooprofilattico Sperimentale dell'Abruzzo e del Molise \"G. Caporale\""
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Istituto Zooprofilattico Sperimentale dell'Abruzzo e del Molise \"G. Caporale\""
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.izs.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.izs.it"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Istituto Zooprofilattico Sperimentale dell'Abruzzo e del Molise \"G. Caporale\""
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Istituto Zooprofilattico Sperimentale dell'Abruzzo e del Molise \"G. Caporale\""
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://engine.eduteams.org/authentication/sp/metadata",
    {
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-03-20T09:40:32Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Technical Contact"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tech@eduteams.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "eduTEAMs"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@eduteams.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "eduTEAMs"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrative Contact"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "admin@eduteams.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "eduTEAMs"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://engine.eduteams.org/authentication/sp/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.eduteams.org/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "eduTEAMs"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "eduTEAMs"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "eduTEAMs is een dienst voor het aanmaken en beheren van groepen. De dienst is vrij beschikbaar voor alle gebruikers van Identity Providers in de eduGAIN community"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "eduTEAMs is a service for creating and managing groups that can be used for Autherization. This service is open to all end users of eduGAIN Identity Providers"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.eduteams.org/media/eduteams_logo_250x250.jpg",
                    "height": "250",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "250"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.eduteams.org/privacypolicy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "want_assertions_signed": "true",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://engine.eduteams.org/authentication/sp/consume-assertion",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "nl",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "eduTEAMs"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "eduTEAMs"
                }
              ],
              "service_description": [
                {
                  "lang": "nl",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "eduTEAMs is een dienst voor het aanmaken en beheren van groepen. De dienst is vrij beschikbaar voor alle eind gebruikers in de eduGAIN community"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "eduTEAMs is a service for creating and managing groups that can be used for Autherization. This service is open to all end users of eduGAIN Identity Providers"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sso.saxion.nl/opensso",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.saxion.nl/opensso",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-04-29T12:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/2b2c18e5b3bde6129f0e388ab85541c4",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Saxion"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Saxion University of Applied Sciences"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/saxion.png",
                    "height": "46",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Saxion"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Saxion University of Applied Sciences"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Saxion"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Saxion University of Applied Sciences"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://saxion.nl"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://saxion.edu"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Saxion"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Saxion University of Applied Sciences"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://maps.slu.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "H\u00f6gstr\u00f6m"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mats.hogstrom@slu.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mats"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fransson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:johan.fransson@slu.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Johan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://maps.slu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://maps.slu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://maps.slu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://maps.slu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://maps.slu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://maps.slu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://maps.slu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://maps.slu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SLU:s tj\u00e4nst f\u00f6r distribution av geografiska data"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SLU service for distribution of geographical data"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "maps.slu.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "maps.slu.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "fme1-1.ad.slu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAID0pitDTgz2MA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGZtZTEtMS5hZC5zbHUuc2UwHhcNMTIwNjI3MDg0NDEzWhcNMjIwNjI1MDg0\nNDEzWjAbMRkwFwYDVQQDExBmbWUxLTEuYWQuc2x1LnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAw7oOCbv2+Z2jh0uM6YlV7Q9sF0uH03jBj67JPA4r\nCIXIFdJ/g7gLliZa+DjxaNlPxQAE4xc3vGGO7TUyKCftvRIUI49Phm8WKtapy6XE\nPb52xE0ie+B0RO2boUG9xiM50WlZT0VsmdYjwHey7fT5UZjaGa/PLOAAoKXLvfJG\nVQb1IAO8bQ+k4XWf/2oR2BLEKWmy3xW1T4ew34SmAPcpbwZOxj5t0GRDt6lblHvG\nL4KB5a6hEOuU+0U0KjFYKG2PYLJUB4RM6ctmGOnuwUyoWmFAN1h4OZzXoyckr8u2\ngdaWyFL+k/ojckmw5aaJBpce332Bh9wy53W6J77qa0ANawIDAQABoz4wPDAbBgNV\nHREEFDASghBmbWUxLTEuYWQuc2x1LnNlMB0GA1UdDgQWBBSrX7qpYidl+M3/uMRp\nBZk7JtDvtTANBgkqhkiG9w0BAQUFAAOCAQEAAh37ouHU+pXCxffOUOrDNkBSJSAb\nmmD67HCLmcdLwMxBLji/M/FTK5RYdxlwAwK5F1ntbHovDJKWMva7wuWzmjbcSJ6R\nJVrolJWJDR+Fc84L2Lh1Q3sVOXjDXU5Lw+yYApNcs+f2TdYZEa9HDqTyEjupjecd\na7N6bBlELYgoYFbTpg8AmQOsvVl2yQQiX07lBHHeGOn4i1bbB6ip6exRTxUqf0Ed\nQM0LY0RQjVj4+R+UdaRYQfizHG1rnKcEiRzi/mXYt2YXSjKuyvNUn6uc1GY9/3aJ\n9wX+6Hnwlg8X2wAoLJDLxAoOWSUSyPLCSzqp90tYAn1L6/pX68R46PWq4Q=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=fme1-1.ad.slu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://maps.slu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://maps.slu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://maps.slu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://maps.slu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://maps.slu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://maps.slu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ifs.org.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ifs.org.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/ifs.org.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/ifs.org.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ifs.org.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute for Fiscal Studies"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifs.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.juilliard.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jpinquist@juilliard.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeremy Pinquist"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "amilyavskiy@juilliard.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex Milyavskiy"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tgiwa@juilliard.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tunde Giwa"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.juilliard.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.juilliard.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.juilliard.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.juilliard.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.juilliard.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.juilliard.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "juilliard.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The identity provider for InCommon operations."
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.juilliard.edu/idp/images/jlogo2011.jpg",
                    "lang": "en",
                    "height": "109",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "300"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The Juilliard School"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUd4dtEwhlfYyB4HH7Ogd0EyU2elIwDQYJKoZIhvcNAQEF\nBQAwHDEaMBgGA1UEAxMRaWRwLmp1aWxsaWFyZC5lZHUwHhcNMTIwMzAxMjAxNDA5\nWhcNMzIwMzAxMjAxNDA5WjAcMRowGAYDVQQDExFpZHAuanVpbGxpYXJkLmVkdTCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKjC0qHg4m+AvA1GoEIJ/jX6\nKQxKJNEm4UrcRXbZ3oncAXIYVC/HUmWP6/jcrKhYyxvQoADMi7KLkZsFQ1IiZz7G\nq0KicuR6/DIduO/xhBTRc2gjTtF+f+XuPBx5PMRiZAhDgOwvGGZgKnlgRYihQ0in\nBuU2aEijI67C03n6ohTYM86DLLQUmkIB9YDOrz53glNOCvBxm4NTyYz3G9i6kNaz\nR7ADUTR3sUolhlnO+KKN70Zo2RVfOvKJfuv0w/4d8JUL18ly/+cQyrhf9nsjSHpa\nF//8J0e31VI4wzsRHCrKc2zny5o1D+FGTaoV3y6oF30u1ek6Sy2OsUVI9O/zoyEC\nAwEAAaNpMGcwRgYDVR0RBD8wPYIRaWRwLmp1aWxsaWFyZC5lZHWGKGh0dHBzOi8v\naWRwLmp1aWxsaWFyZC5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFN3rKo1I\nRY3WwTMF9W/xgty5B5wlMA0GCSqGSIb3DQEBBQUAA4IBAQCVwQkjs3pzOCFOCt4n\nqRuBLtc9UK8Ut9Ridd9DooFiN0NMAe2+e4yVdE7R04oNSlF0k9dQYkFisM5rEOGr\nCRioWvGAmCweetpmDjHwuoo9N93KfJOq9MmnjIfQax/AqdraW8crsKkTJnjD9TnD\n4Wkr7bLv0TuA3FzVRhGzTsnaBLUHQz6tOxJZlZPImhw6GUn+jmbXP9ZehN5RMWgR\n3u3lvuhNYYJ++Wz5qn2TEOjzPOaN78gqrdDQJGrzyupyoQozGPabm54G3TY3j7LN\nwbbE50o+AHJCe0UX6qPQgV/B79j6Z0uAL93NiL+v7e2tJYZj1ePR7gzqBX1YK5zs\nNIEi"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "http://www.juilliard.edu/juilliards-incommon-federated-id-system"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Juilliard School"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.juilliard.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Juilliard School"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-19.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-19.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-19.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-19.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-19.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-19.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-19.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-19.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-19.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;19"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;19"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-19.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-19.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJAPENUUAnnIM8MA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0xOS5sYWRvay51bXUuc2UwHhcNMTQwOTAxMTQ0NTM0WhcNMjQw\nODI5MTQ0NTM0WjAhMR8wHQYDVQQDExZsYWRvazMtMTkubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA3/G5VT0IVGe2ajSCQMZd41S8\nrUE7AwEKAoWtbYev5NHsawizIqmhfXMo5seJp3L78t2daFZMdZleGql+8/SRSCWu\nETRGe/MmpeKMwB+nGoiu/AOlCNqK79SmIH0dyIkgrQ/1ABtVFe2RVEismF6L3nZT\nTD7r6WaGVGdlR8X1GSRLKtn8VsNQh4LOxQHdGlYsNbAWKy5mAqon/8YF6yK6OqC9\nIyuq2l+K30rsHONEX+2h2PF78vGQo0a0afTzVZoDOnq/GILpS4n9tN+BasETFdPe\n0Unaq4Nmm3wnj1LwG0kinVONA0LEOlKjhg0vI8YvTcrY0C24tVnUPGZbJgtDDwID\nAQABo2swaTBIBgNVHREEQTA/ghZsYWRvazMtMTkubGFkb2sudW11LnNlhiVodHRw\nczovL2xhZG9rMy0xOS5sYWRvay51bXUuc2UvZ3VpLXNwMB0GA1UdDgQWBBR3/RKb\n/zuCATe9qISF5UpRe+lapTANBgkqhkiG9w0BAQUFAAOCAQEAnH4V3/aEPoNM3yT7\n0yFrIo6zu5YbIF6YuvLTPyBg7Bzyrvgm/dzhnRyMCCTyjkrCY2F35OxX9sowS/TX\nsbdIQlXeTWDnY7Eug6mj8DvoUwueVLfkNGdK2Duwid7lEfSWLwJH/t5bVMokogHm\n4l14IfYBdJ0BaYVsG/m/51sgkzquBAhfBzaBaNY2kFyl4kD4FVtzqfexOyaevs0g\njSqRYBv4x2PkPMzUeYUFOHhEw6OP1YVe8HEIfdbNMR77WMDyMizsnIiLuYzlC0w9\ngOTNw2ZoS5S1bBr8G0vLVzwk0QHiJp6l4k8c5k3latfdA1xIJ2OITMBLUhD1ShIc\nIJHO3g=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-19.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-19.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-19.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-19.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-19.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-19.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-19.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-19.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-19.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-19.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://nlw-shib.hosted.exlibrisgroup.com/shib",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://nlw-shib.hosted.exlibrisgroup.com/shib",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-07-02T11:38:42Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "This is a Shibboleth SP for National Library of Wales"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://exlibrisgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ex Libris (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nlw-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nlw-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nlw-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nlw-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nlw-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://nlw-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://nlw-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is an Ex Libris Primo Hosted SP on behalf of National Library of Wales"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "National Library of Wales - Primo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAJtjN/Sjy8NPMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB2FpbzAwMjYwHhcNMTUwNDAyMTkyMDQ1WhcNMjUwMzMwMTkyMDQ1WjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdhaW8wMDI2MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\t7Jt19IZw6ICRXtbeaAcFrr5D6aadKv+8DW6DCLU7COaPBgPhlQW3Y6yqh4T8XTpz\n\t\t\t\t\t\tAU4I5HISgZlm9/C8aLQWWzxa432p6FcGrkY4EYGyT7Ez4qcwamisIN6Hsb6mtPaJ\n\t\t\t\t\t\ta/ZpRWcEYhS3z0wiJiGHJa3z81DmZ8fBqZkGEj2PRYpdQdV80ILiJeAHUnAKL59E\n\t\t\t\t\t\tIFFfbzJwqz0OImdHMS8BI8ewojta8Cnun/Ue8JOvp703Yt4/YmXQlb69lN29Rhet\n\t\t\t\t\t\tbDEUL3rjQK+Omf/kCGUdQtXfuFl5zvL3JUz6ktwzj5rMtCAqNaZnEHsdh2YC6IWK\n\t\t\t\t\t\tHeE3OR5THvu5+NLDuAkDywIDAQABozUwMzASBgNVHREECzAJggdhaW8wMDI2MB0G\n\t\t\t\t\t\tA1UdDgQWBBR8qDCK47IUQfSx79u36cex86OrXzANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\t6nVdsxI/Z3eSLnIjQt2xvpLHbA0xfhcNi5VvKOHSRxZryE+PIe+Lzu9ycj3d3t4O\n\t\t\t\t\t\tOWIGLafxvNi52udtPa8uG4ZsUEe3UUm5SV0ezVWZK2H2LkX3E7rq6xWGuZxmZtGy\n\t\t\t\t\t\t8yaLXKOQsecj+O111rCOSmVGPwho7+AKtBMl7qD+2kN7j3ZGc8Ze9MG/M1RuOhpB\n\t\t\t\t\t\t4sefEKZCcWZJfjwmSQa8KKz7p3teflnKndl0yovrb1Yosy3C0GqGJz5OmyOxfO3I\n\t\t\t\t\t\tvOdVbh1NvO7LYzioXPk7URk1vst4P9pQbmcUFNRrd+WjfzOUjiAJYGm43DNqQEqC\n\t\t\t\t\t\tXfBl+0BWyo22ZUbTodVKFw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nlw-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://nlw-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nlw-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://nlw-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://nlw-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://nlw-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.alvin-portal.org/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.alvin-portal.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.alvin-portal.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.alvin-portal.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.alvin-portal.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.alvin-portal.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.alvin-portal.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.alvin-portal.org/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://wiki.epc.ub.uu.se/display/alvininfo/Alvin+info"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Alvin \u00e4r en plattform f\u00f6r digitalisering, beskrivning, lagring och tillg\u00e4ngligg\u00f6rande av biblioteks/andra institutioners samlingar."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Alvin is a platform for digitizing, description, storage, and dissemination of collections in libraries and other culture heritage institutions."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Alvin"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Alvin"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.alvin-portal.org"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAMDMuQZ7AA/7MA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFHd3dy5hbHZpbi1wb3J0YWwub3JnMB4XDTE0MDQyMzExMjIxNloXDTI0MDQy\nMDExMjIxNlowHzEdMBsGA1UEAxMUd3d3LmFsdmluLXBvcnRhbC5vcmcwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDH4u8f1DVQPd+4GGO15zItmRoOzMUx\nP2CmfwY54kGqEbDuF5l7xlHd8nHoyc7xyq7+2iN3wqLYsc/bMRt/7nvaQgQ+9Abt\nn+UDSJP4Ja67tbTeASbzVQBLHZsbJpS5fSeu/U5pMs9ypzHLnkRRA8bH8H1k1Cbu\nADcPjfs+ICzXSIEPMtdcPBitu1rVlomKHJGTc1dvroArHuKxKoF0o2B1v7wDq9nI\nb+WvUe7s2R4Ckm2Luu8vwHRNfIKQ2+JtAPuakWDDEYb6vkrt0DPMLrrqaoofGVZ+\nBWMnhQWLpQEcvBoOBVNQkHgFzGOzQiBatBqkTHwgHqYaRh66CUYn1D2vAgMBAAGj\nQjBAMB8GA1UdEQQYMBaCFHd3dy5hbHZpbi1wb3J0YWwub3JnMB0GA1UdDgQWBBRh\n8I/nWuX7DEoHKhQwzbJJ2OlZCjANBgkqhkiG9w0BAQUFAAOCAQEAuTHO3SFkz/Be\n2U13HyP7Dya3x/CDXInsUjI/5e4VfFYhaFvM7gKLI/2+/FKPhdH1gfZICl8NZoj6\nJABY7IdZ05XYjbuF1lP+BGOGma+b1ctaRJaL4tqEJS3T8SbvRbCudM78D2v+HTd2\nBGed+OkqQJDK+RtiD4YGJB0ivUWjKO9f6V7IAPn8kCAV6/wrxoVn9LV0VminU6pT\ncckp1mHdgJLan3LhOW6P/b3Rs0TXkRsBCCxizmbmO8oWbKPVjE8wbaPhl2dX3O9W\nbMNGcqL1wkQkAUiQjcma8zpBNxnQdb4xeEYAbJyDX+MulR8ZEbo67LCmPKtPQMfN\nnCC3ytLciA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.alvin-portal.org"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.alvin-portal.org"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAMDMuQZ7AA/7MA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFHd3dy5hbHZpbi1wb3J0YWwub3JnMB4XDTE0MDQyMzExMjIxNloXDTI0MDQy\nMDExMjIxNlowHzEdMBsGA1UEAxMUd3d3LmFsdmluLXBvcnRhbC5vcmcwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDH4u8f1DVQPd+4GGO15zItmRoOzMUx\nP2CmfwY54kGqEbDuF5l7xlHd8nHoyc7xyq7+2iN3wqLYsc/bMRt/7nvaQgQ+9Abt\nn+UDSJP4Ja67tbTeASbzVQBLHZsbJpS5fSeu/U5pMs9ypzHLnkRRA8bH8H1k1Cbu\nADcPjfs+ICzXSIEPMtdcPBitu1rVlomKHJGTc1dvroArHuKxKoF0o2B1v7wDq9nI\nb+WvUe7s2R4Ckm2Luu8vwHRNfIKQ2+JtAPuakWDDEYb6vkrt0DPMLrrqaoofGVZ+\nBWMnhQWLpQEcvBoOBVNQkHgFzGOzQiBatBqkTHwgHqYaRh66CUYn1D2vAgMBAAGj\nQjBAMB8GA1UdEQQYMBaCFHd3dy5hbHZpbi1wb3J0YWwub3JnMB0GA1UdDgQWBBRh\n8I/nWuX7DEoHKhQwzbJJ2OlZCjANBgkqhkiG9w0BAQUFAAOCAQEAuTHO3SFkz/Be\n2U13HyP7Dya3x/CDXInsUjI/5e4VfFYhaFvM7gKLI/2+/FKPhdH1gfZICl8NZoj6\nJABY7IdZ05XYjbuF1lP+BGOGma+b1ctaRJaL4tqEJS3T8SbvRbCudM78D2v+HTd2\nBGed+OkqQJDK+RtiD4YGJB0ivUWjKO9f6V7IAPn8kCAV6/wrxoVn9LV0VminU6pT\ncckp1mHdgJLan3LhOW6P/b3Rs0TXkRsBCCxizmbmO8oWbKPVjE8wbaPhl2dX3O9W\nbMNGcqL1wkQkAUiQjcma8zpBNxnQdb4xeEYAbJyDX+MulR8ZEbo67LCmPKtPQMfN\nnCC3ytLciA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.alvin-portal.org"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.alvin-portal.org/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.alvin-portal.org/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.alvin-portal.org/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.alvin-portal.org/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.alvin-portal.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.alvin-portal.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.alvin-portal.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.alvin-portal.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.alvin-portal.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.uppfoljning.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.uppfoljning.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.uppfoljning.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.uppfoljning.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.uppfoljning.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.uppfoljning.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.uppfoljning.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.uppfoljning.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.uppfoljning.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.uppfoljning.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.uppfoljning.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.uppfoljning.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.uppfoljning.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.uppfoljning.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFODCCAyCgAwIBAgIJAOk6eA6bBSUAMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\nBAMTGHd3dy51cHBmb2xqbmluZy5sYWRvay5zZTAeFw0xNTEyMDQwNzMxMDNaFw0y\nNTEyMDEwNzMxMDNaMCMxITAfBgNVBAMTGHd3dy51cHBmb2xqbmluZy5sYWRvay5z\nZTCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIBAMgvIKG0Iddz3FLny2fV\nYENWzgyr/dv0r+c0JDRp3P0bKoQnYiOC+XVAGi6e6u5XazWzkQJapQSO1W3z2eXG\nIWFaAYgZFsqINmIIKKcxN/n9Zevh88DgKa3Oz8S/5cTxhQflikDXvyaCeWy2hZKP\nuLt+mtCxmtBFZQqyWkSPIeb6naAAuMHba2xAfstM9mUJsobKJWjfg40jrhAHo2Kc\nLFES9ckL2IKbduC1RO9S98h8LoTGHI1KCegpmptyMveJL6r5bPJYRTuTCRyIDQ53\nWuzAuOMfTrvTX/2NO2zF7UWASRyZCSNjew/cfE7qL3YRJfeEMPDy/BTmtsdoBdHS\nJ3zK1sNLfv8yaYOo2Ows9hFZeNKaFBMunXvIUBnXcfAZQMRutOXJYtC7Cfc0+djl\n3J/l9SLQfQfqxww8cf/RBWNMvjapL2IU5g2D7buEsgkxM56b0Yw3YZ1XMQHOy9pG\nBOEt6NaIdtTyz2dA1JxRurOCkPq3kNfHnJlYAuB9rNc8t5b34M/oZKA7cdVPBa+N\nTy40YhjZw9Z05b4G+Y0nXMxORB7kJFqAjmBd59ZbhphqgCIkrRuzIMK+iouAlq2f\nlgsJ38oMW1f6DLVGH2GC2Sx81Ngq6BoJFUlJq/sE0fnUbdEpC/aQky5ph9rVCx7r\nyWewkliKVJemhyYYLXR3oas7AgMBAAGjbzBtMEwGA1UdEQRFMEOCGHd3dy51cHBm\nb2xqbmluZy5sYWRvay5zZYYnaHR0cHM6Ly93d3cudXBwZm9sam5pbmcubGFkb2su\nc2UvZ3VpLXNwMB0GA1UdDgQWBBQsive1Oq4SvjwbaHCpcUagbKLD7jANBgkqhkiG\n9w0BAQUFAAOCAgEAMxAsYYpc23IeKioe+YkUMp5w5LSAzFw84Hbnvn7kpWZnCjkJ\nlWQIg43rfoP245VV5iete0s9yvMl5PrnFlGs/5SgTCBdrTXXSjMc9AbXW3WAMnpy\nUj4mloSfwCURUtm6JlzlQE+cI2/2gqcjyX3NO5bm5ztNxJkMPH/eS8OmaG8PSUdd\nnHCgPGaXMRphFKa6PIOXjauWhSVZMXyQyFUo9NY6arc341qt3DmrrmrQhm6IvavH\nZ9h5c9sjOBqPT0BXMxDWgWkRih3R9nFsITd0rmZTJ1sOt4rDDq5UrTTUMCk6SdsJ\nVFbtw1UaIKfxxD/hI8kvt53dHPQFf07PJM5gHmi6rW0y9qGtgJlbo1gnavRDyIxQ\n7RY0JUZHZbwbErb76VVrq/IYfCRYn9ITSBNaRFmxCYmfk2glZE11MPNijg3/SdN2\nuUIuMpT3jxebMVF/jprgY3SXYVtylGd6jOWZmKqGxMQ0gII0StsMgAlk22MWr4HO\nvK6J9hwUI057LYBOpwF777iKoGTpAdDnk8wEpc/gD6OVAjdmPmoxq1F6aXQ/0Rb0\n9AHiq9QuIZvfZxuLZua08zjkw/PiD51rHgQ6xGabj5dag5rI+WzYvdqQf43Q+NRf\nIn/ikXXTMoplS8tRzCrjMQsTrhAg8qemRbZ6iGMqy8/lXraUDplt75yZFcY="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.uppfoljning.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.uppfoljning.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.uppfoljning.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.uppfoljning.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.uppfoljning.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.uppfoljning.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.uppfoljning.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.uppfoljning.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.uppfoljning.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.uppfoljning.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.aalto.fi/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Niemi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@aalto.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mika"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tunturi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idp-admin@aalto.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Timo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@aalto.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IdP"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.aalto.fi/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.csc.fi/english/institutions/haka/instructions/join/eduGAINRegistrationStatement/"
              }
            ],
            "registration_authority": "http://www.csc.fi/haka",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.aalto.fi/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aalto.fi"
              },
              {
                "description": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Aalto-yliopiston opiskelijoita, tutkijoita, opetushenkil\u00f6kuntaa ja ty\u00f6ntekij\u00f6it\u00e4."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Aalto University students, faculty and employees."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Aalto University"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Aalto-yliopisto"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Aalto-universitetet"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEZTCCA02gAwIBAgIQfPk0tfjUFfPvbNYjMlu/rDANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMTExMTAwMDAwMFoXDTE2MTExMDIzNTk1OVowOjEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRUwEwYDVQQDEwxpZHAuYWFsdG8u\nZmkwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCjQ14Y5ls9qgndtooF\nZ9tekHhuETMtovhozaCqvm6HwVE+jEo9ik4zwre42zTGz2QACBOldN5RlFw/A3kJ\noGK5jEqQZFIw2XG22C+A7NNoZLqgGH7K3BYlYpI1Vpqpx+tk2/QpVUi4JqdIfVxT\nKHQZIW66dV4Zz+JMlAiPR/qzjLBYwUBllE5GG/BMBo7fQvMKqfrdAi3QcPdsiAQG\nHl39WcchL53Y2tN8xOq2bkk6XOELBEe6byYdVgRzsGi6eyQHPvcWGb/Fl2JPahUj\nWM8Zz1w077omI4tzq/OLhnKAB/J25m9SAh23rq/lCFrnle528tE/nRBqX/yop8Hh\nn++dAgMBAAGjggFpMIIBZTAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3V0fqkOO5\n7TAdBgNVHQ4EFgQU7fL+WKGykn8q5Nden977Qx3neOEwDgYDVR0PAQH/BAQDAgWg\nMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMCIG\nA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1UdHwQzMDEwL6At\noCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3JsMG0G\nCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3MudGVyZW5h\nLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9vY3NwLnRj\ncy50ZXJlbmEub3JnMBcGA1UdEQQQMA6CDGlkcC5hYWx0by5maTANBgkqhkiG9w0B\nAQUFAAOCAQEAMqh4jbB8O648lGCpqemnz15SXeHGdQAyfvC3xDwEVa7eplPzeSg1\nXW1MqufDwc6j7nO5fYtULdMuj7/GM9gXkiU2Zv+qPbymrdADan8zqHQ65Ph+JarH\nU+WwQBqDu5B4ZLpp1188FPxqX+cq/5AdJ0/yxiQjG5yC0o5iPV94AEnUBCrB7Kp1\nY79B00ak/mPB48aieNaM+iyYfkmyrzg7qlaRcXhh0CsFlL9zDt7l8eUImkesv6UM\nCxdagkq9pUvFaktXeSRZbrRFcaP2j/TqkPnCtuoK/oQxvwcnllp4PqGQHypWfHOd\nZxL0Jnn1/d6adGsxw3M6+kdWZG8Iu+3Mzg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Aalto-yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Aalto University"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Aalto-universitetet"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aalto.fi"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aalto.fi"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aalto.fi"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Aalto-yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Aalto University"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Aalto-universitetet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://webauth.umaryland.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "bscoats@umaryland.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brian Coats"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "brent@umaryland.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brent Nickles"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "bscoats@umaryland.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brian Coats"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@umaryland.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://webauth.umaryland.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://webauth.umaryland.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://webauth.umaryland.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVAIJL3xlKBtxM29EgLG3uO45k3D/WMA0GCSqGSIb3DQEB\nBQUAMCAxHjAcBgNVBAMTFXdlYmF1dGgudW1hcnlsYW5kLmVkdTAeFw0xMjEwMjYx\nNjQ5MDRaFw0zMjEwMjYxNjQ5MDRaMCAxHjAcBgNVBAMTFXdlYmF1dGgudW1hcnls\nYW5kLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKA/GisjATA6\njTXmT0yDRFjtBBpWz50qYpPpLJ5+QJEt26jTlztQRg3aimomjLyeMaSMrk6NaVd5\nMqUSDwhAW6lmhkkc7SK0DXSVNNmvd8BT60ZlNxYSNF3jAEjsgQu+o3+KWLkVPlY8\nnjCUvGh3+Gg7eTULf66UfM5oRgHYaonWBzd2Ayx3sxFD6HTupfC0o/MmXyJsnuOV\nhAzKp1x52fDndYDvA7ki7+z/RCgYYTNsgwjp+1preNQeJfIXwTr9bOpkvLx4v4ij\n8lDTWDtsxvq3WyZNrAHTJoEaKym6AeoloDTtNXIHWl99Z8OIhJVJdBSjQaE8580m\nBuinQ/3GWJECAwEAAaNxMG8wTgYDVR0RBEcwRYIVd2ViYXV0aC51bWFyeWxhbmQu\nZWR1hixodHRwczovL3dlYmF1dGgudW1hcnlsYW5kLmVkdS9pZHAvc2hpYmJvbGV0\naDAdBgNVHQ4EFgQUcjvwyPv4suKIR1/ISJTsDvddPYcwDQYJKoZIhvcNAQEFBQAD\nggEBAEN+MsMdV4cUYWfF8WQTgD5U1wnkB/7Ya11wvsRA2ycFo3XIGXnfiN/nAdd9\n3QVzjeXy5Eck2hL6O4b7jBXhaC6V58HdskSKEQv1pV5g0Uc9umXfeI2qwGgiDG+/\nAYp5sQfEOR2iqm2fFOcg8jHY0rA6x+TaSG4HPxNGyPUMr++lB7/GVveOtApbiUy1\noy9sjvoB6Q2spGvKL9ztGS7DArQ5vmppu/cW6KLyKxvlex0l2eqSLc6ykbmmsZfS\nC3tP4wi5CZgqM/Ak34O9PntDHTUgXUUmK0TAXJqXwsRffYByDJFXlNgTQWLiYf5e\npnBcdqtVQcuIV+E+RUNLcxS0b5w="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "umaryland.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://webauth.umaryland.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webauth.umaryland.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://webauth.umaryland.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://webauth.umaryland.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://webauth.umaryland.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://webauth.umaryland.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "umaryland.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The University of Maryland, Baltimore (UMB) is the State's public health, law and human services university devoted to excellence in professional and graduate education, research, patient care, and public service. As a diverse community of outstanding faculty, staff and students, and using state-of-the-art technological support, we educate leaders in health care delivery, biomedical science, global health, social work and the law. We emphasize interdisciplinary education and research in an atmosphere that explicitly values civility, diversity, collaboration, teamwork and accountability. By conducting internationally recognized research to cure disease and to improve the health, social functioning and just treatment of the people we serve, we foster economic development in the City, State, and nation. We are committed to ensuring that the knowledge we generate provides maximum benefit to society and directly enhances our various communities."
                  }
                ],
                "logo": [
                  {
                    "text": "https://directory.umaryland.edu/shibboleth/umblogo.gif",
                    "lang": "en",
                    "height": "89",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "340"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.umaryland.edu/cits/policies/privacy_policy.doc"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Maryland Baltimore"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVAIJL3xlKBtxM29EgLG3uO45k3D/WMA0GCSqGSIb3DQEB\nBQUAMCAxHjAcBgNVBAMTFXdlYmF1dGgudW1hcnlsYW5kLmVkdTAeFw0xMjEwMjYx\nNjQ5MDRaFw0zMjEwMjYxNjQ5MDRaMCAxHjAcBgNVBAMTFXdlYmF1dGgudW1hcnls\nYW5kLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKA/GisjATA6\njTXmT0yDRFjtBBpWz50qYpPpLJ5+QJEt26jTlztQRg3aimomjLyeMaSMrk6NaVd5\nMqUSDwhAW6lmhkkc7SK0DXSVNNmvd8BT60ZlNxYSNF3jAEjsgQu+o3+KWLkVPlY8\nnjCUvGh3+Gg7eTULf66UfM5oRgHYaonWBzd2Ayx3sxFD6HTupfC0o/MmXyJsnuOV\nhAzKp1x52fDndYDvA7ki7+z/RCgYYTNsgwjp+1preNQeJfIXwTr9bOpkvLx4v4ij\n8lDTWDtsxvq3WyZNrAHTJoEaKym6AeoloDTtNXIHWl99Z8OIhJVJdBSjQaE8580m\nBuinQ/3GWJECAwEAAaNxMG8wTgYDVR0RBEcwRYIVd2ViYXV0aC51bWFyeWxhbmQu\nZWR1hixodHRwczovL3dlYmF1dGgudW1hcnlsYW5kLmVkdS9pZHAvc2hpYmJvbGV0\naDAdBgNVHQ4EFgQUcjvwyPv4suKIR1/ISJTsDvddPYcwDQYJKoZIhvcNAQEFBQAD\nggEBAEN+MsMdV4cUYWfF8WQTgD5U1wnkB/7Ya11wvsRA2ycFo3XIGXnfiN/nAdd9\n3QVzjeXy5Eck2hL6O4b7jBXhaC6V58HdskSKEQv1pV5g0Uc9umXfeI2qwGgiDG+/\nAYp5sQfEOR2iqm2fFOcg8jHY0rA6x+TaSG4HPxNGyPUMr++lB7/GVveOtApbiUy1\noy9sjvoB6Q2spGvKL9ztGS7DArQ5vmppu/cW6KLyKxvlex0l2eqSLc6ykbmmsZfS\nC3tP4wi5CZgqM/Ak34O9PntDHTUgXUUmK0TAXJqXwsRffYByDJFXlNgTQWLiYf5e\npnBcdqtVQcuIV+E+RUNLcxS0b5w="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Maryland Baltimore"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.umaryland.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Maryland Baltimore"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://salford.idm.oclc.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Support Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Support Desk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://salford.idm.oclc.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-08T07:44:57Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Salford Hosted EZProxy"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oclc.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "OCLC (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://login.salford.idm.oclc.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.salford.idm.oclc.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.salford.idm.oclc.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.salford.idm.oclc.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEDjCCAvagAwIBAgIBAjANBgkqhkiG9w0BAQUFADBnMR8wHQYDVQQDFBYqLnNh\n\t\t\t\t\t\tbGZvcmQuaWRtLm9jbGMub3JnMQswCQYDVQQGEwJVSzENMAsGA1UEChMET0NMQzEo\n\t\t\t\t\t\tMCYGCSqGSIb3DQEJARYZamFtZXMuaHV0Y2hpbnNvbkBvY2xjLm9yZzAeFw0xNTA1\n\t\t\t\t\t\tMDUxMzMwMDVaFw0yNTA1MDQxMzMwMDVaMGcxHzAdBgNVBAMUFiouc2FsZm9yZC5p\n\t\t\t\t\t\tZG0ub2NsYy5vcmcxCzAJBgNVBAYTAlVLMQ0wCwYDVQQKEwRPQ0xDMSgwJgYJKoZI\n\t\t\t\t\t\thvcNAQkBFhlqYW1lcy5odXRjaGluc29uQG9jbGMub3JnMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEA1kUySsrv1+6UNChn/pAjQLGxNmiSee2KzjHE+2v6\n\t\t\t\t\t\tEy7Mj/C5PFogUsbKR7UGNpvk/y3Jg5xk9pjeeRV2nC8E8vjq96/svo8b/SubuAfW\n\t\t\t\t\t\tU+8Fnie0BgKzmbrGgBR/UX2urqZV0Motf1TMpkKqxvvhLSCmjLxHEms+UXdE7DP+\n\t\t\t\t\t\tkR9WnN9qsJ31YgzT0zi3voGVUajwWfviNudqOCHfC2dO5piuV1LmjEkn+hTox9Xh\n\t\t\t\t\t\t7wr2P2lDaYGuX3V7t9vNvNLOss3fTxWsK0T3uCt+h/MSjNp0bT+vyUR23fRqgt9K\n\t\t\t\t\t\t94ZDNrjLpu7AS07WvxEZpWeyKP+PLwMRXuZ3mKnICLiBJQIDAQABo4HEMIHBMB0G\n\t\t\t\t\t\tA1UdDgQWBBQZ3Q0KOx50hbPkk02txlwfKEDRZzCBkQYDVR0jBIGJMIGGgBQZ3Q0K\n\t\t\t\t\t\tOx50hbPkk02txlwfKEDRZ6FrpGkwZzEfMB0GA1UEAxQWKi5zYWxmb3JkLmlkbS5v\n\t\t\t\t\t\tY2xjLm9yZzELMAkGA1UEBhMCVUsxDTALBgNVBAoTBE9DTEMxKDAmBgkqhkiG9w0B\n\t\t\t\t\t\tCQEWGWphbWVzLmh1dGNoaW5zb25Ab2NsYy5vcmeCAQIwDAYDVR0TBAUwAwEB/zAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAJ1ipjSG8TTxBrltXSd7JRGLcI+YpC0H4icIr1Ybo\n\t\t\t\t\t\t9ulwtNmc8nXRwd4s2Hf5hClZ2flb0+dar1x+0Ht48dQ0tRRUPsAlxChkkKJ8xMI3\n\t\t\t\t\t\tCFGVRIkpeLPWfpvY9bvmwQxJXbGtwZwH516PaSQ2BaoD/jBliKs3gGtYTFW5G3f8\n\t\t\t\t\t\tbFb1xmsJWRJ+T82M1Ayou4Pg4zt15DUh7mQG+vKanrCCxMOwp29OwPiIt5QPNPc1\n\t\t\t\t\t\t7/DnFzG87+qTQcdqhzs5sVf+UbQEZZWfO2h3SETBJEeurGamU4hb7snRASKCqcw4\n\t\t\t\t\t\thtEj3D0rPUXTvX36xmS+25M81EcZKM/3NPwnGJgmNUmhPw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://login.salford.idm.oclc.org/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://devsaas.topdeskdev.net/tas/secure/login/verify",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "van Berkel"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:l.van.berkel@topdesk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Laurent"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "van Berkel"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:l.van.berkel@topdesk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Laurent"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://devsaas.topdeskdev.net/tas/secure/login/verify",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-06-09T08:35:51Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "topdeskdev"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.topdesk.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "TOPdesk Nederland BV"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID/zCCAuegAwIBAgIJAJm7S+R3eAhJMA0GCSqGSIb3DQEBBQUAMIGVMQswCQYD\n\t\t\t\t\t\tVQQGEwJOTDEVMBMGA1UECAwMWnVpZC1Ib2xsYW5kMQ4wDAYDVQQHDAVEZWxmdDEQ\n\t\t\t\t\t\tMA4GA1UECgwHVE9QZGVzazEPMA0GA1UECwwGWnl0aG9zMRMwEQYDVQQDDAp0b3Bk\n\t\t\t\t\t\tZXNrZGV2MScwJQYJKoZIhvcNAQkBFhhsLnZhbi5iZXJrZWxAdG9wZGVzay5jb20w\n\t\t\t\t\t\tHhcNMTUwNjA4MTQ1OTAzWhcNMTgwNjA3MTQ1OTAzWjCBlTELMAkGA1UEBhMCTkwx\n\t\t\t\t\t\tFTATBgNVBAgMDFp1aWQtSG9sbGFuZDEOMAwGA1UEBwwFRGVsZnQxEDAOBgNVBAoM\n\t\t\t\t\t\tB1RPUGRlc2sxDzANBgNVBAsMBlp5dGhvczETMBEGA1UEAwwKdG9wZGVza2RldjEn\n\t\t\t\t\t\tMCUGCSqGSIb3DQEJARYYbC52YW4uYmVya2VsQHRvcGRlc2suY29tMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAw7vPXtzLc6MyiXiGxLEtqRfFD11Elugn\n\t\t\t\t\t\teg7Nr0zqm6QtJ6GBUzv6GSf5F/CX7Zo8saoA5IZzeSEtESH5i0xotzMGaovZKMMO\n\t\t\t\t\t\tc5gHsGYjv4o/G7BY3rzG+Hr+aoFQMTDZy/151zGAO4Y/fQyL5zUnEQYjDzKC4X6V\n\t\t\t\t\t\tAH9B/cRbWn+NfCaEA3wYmVqheYKklffdYSG1fORoujZ3LsntjkWvwCRgvyQutjVP\n\t\t\t\t\t\tiMxW2Iz2PU6lxPRVRAK0URz4EKQ/ULfwBiwjpX91Pqb+bm/KF6dkpN6Q5+UjGCmd\n\t\t\t\t\t\tEE93HhV/dhf08lLaQL4GBvzJRgvsWJ2q3q8F53PXO83LHOgv9sTHlQIDAQABo1Aw\n\t\t\t\t\t\tTjAdBgNVHQ4EFgQUWXOZkJVPkyAMxCJ48JV5RTxB6SYwHwYDVR0jBBgwFoAUWXOZ\n\t\t\t\t\t\tkJVPkyAMxCJ48JV5RTxB6SYwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAQ8RlfKbYqNFP/CpA2SnalEH+JiwhUCZtmwMjorlJro/a3PmgRDfl/FuS+dhF\n\t\t\t\t\t\twVgK1wJTr6bbW3Ac1ZLPjUVrCnpK0iDNSzdObGfaZCdk7lBEyxilo8D8WkrrBiVW\n\t\t\t\t\t\tTyxQx3OD2FCe9Rrlva50gUAOpmv/W9WBztmf4kVxjT00+TneswfxSvTz/ErfVoKV\n\t\t\t\t\t\t7IKNTrNasLYdsE74A8TZgjEOvKEssP1eU/cYAmgSJl9agw+L0eZBV4QPLkPdUYqL\n\t\t\t\t\t\tMowydgIbulCvZoR6GUe+pTUNSeg4xmKbojB0XzZAFuR3psx8+D6FFspCszdSc40q\n\t\t\t\t\t\tm9MCRRGj6m2ZrvVhZeFtqBRb1w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID/zCCAuegAwIBAgIJAJm7S+R3eAhJMA0GCSqGSIb3DQEBBQUAMIGVMQswCQYD\n\t\t\t\t\t\tVQQGEwJOTDEVMBMGA1UECAwMWnVpZC1Ib2xsYW5kMQ4wDAYDVQQHDAVEZWxmdDEQ\n\t\t\t\t\t\tMA4GA1UECgwHVE9QZGVzazEPMA0GA1UECwwGWnl0aG9zMRMwEQYDVQQDDAp0b3Bk\n\t\t\t\t\t\tZXNrZGV2MScwJQYJKoZIhvcNAQkBFhhsLnZhbi5iZXJrZWxAdG9wZGVzay5jb20w\n\t\t\t\t\t\tHhcNMTUwNjA4MTQ1OTAzWhcNMTgwNjA3MTQ1OTAzWjCBlTELMAkGA1UEBhMCTkwx\n\t\t\t\t\t\tFTATBgNVBAgMDFp1aWQtSG9sbGFuZDEOMAwGA1UEBwwFRGVsZnQxEDAOBgNVBAoM\n\t\t\t\t\t\tB1RPUGRlc2sxDzANBgNVBAsMBlp5dGhvczETMBEGA1UEAwwKdG9wZGVza2RldjEn\n\t\t\t\t\t\tMCUGCSqGSIb3DQEJARYYbC52YW4uYmVya2VsQHRvcGRlc2suY29tMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAw7vPXtzLc6MyiXiGxLEtqRfFD11Elugn\n\t\t\t\t\t\teg7Nr0zqm6QtJ6GBUzv6GSf5F/CX7Zo8saoA5IZzeSEtESH5i0xotzMGaovZKMMO\n\t\t\t\t\t\tc5gHsGYjv4o/G7BY3rzG+Hr+aoFQMTDZy/151zGAO4Y/fQyL5zUnEQYjDzKC4X6V\n\t\t\t\t\t\tAH9B/cRbWn+NfCaEA3wYmVqheYKklffdYSG1fORoujZ3LsntjkWvwCRgvyQutjVP\n\t\t\t\t\t\tiMxW2Iz2PU6lxPRVRAK0URz4EKQ/ULfwBiwjpX91Pqb+bm/KF6dkpN6Q5+UjGCmd\n\t\t\t\t\t\tEE93HhV/dhf08lLaQL4GBvzJRgvsWJ2q3q8F53PXO83LHOgv9sTHlQIDAQABo1Aw\n\t\t\t\t\t\tTjAdBgNVHQ4EFgQUWXOZkJVPkyAMxCJ48JV5RTxB6SYwHwYDVR0jBBgwFoAUWXOZ\n\t\t\t\t\t\tkJVPkyAMxCJ48JV5RTxB6SYwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAQ8RlfKbYqNFP/CpA2SnalEH+JiwhUCZtmwMjorlJro/a3PmgRDfl/FuS+dhF\n\t\t\t\t\t\twVgK1wJTr6bbW3Ac1ZLPjUVrCnpK0iDNSzdObGfaZCdk7lBEyxilo8D8WkrrBiVW\n\t\t\t\t\t\tTyxQx3OD2FCe9Rrlva50gUAOpmv/W9WBztmf4kVxjT00+TneswfxSvTz/ErfVoKV\n\t\t\t\t\t\t7IKNTrNasLYdsE74A8TZgjEOvKEssP1eU/cYAmgSJl9agw+L0eZBV4QPLkPdUYqL\n\t\t\t\t\t\tMowydgIbulCvZoR6GUe+pTUNSeg4xmKbojB0XzZAFuR3psx8+D6FFspCszdSc40q\n\t\t\t\t\t\tm9MCRRGj6m2ZrvVhZeFtqBRb1w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://devsaas.topdeskdev.net/tas/secure/login/verify",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://athensla-dev.uwe.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lib.it@uwe.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Library IT Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lib.it@uwe.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Library IT Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://athensla-dev.uwe.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_instant": "2012-02-27T10:49:58Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://athensla-dev.uwe.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://athensla-dev.uwe.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uwe.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDnDCCAoSgAwIBAgIIAj83J4NilnUwDQYJKoZIhvcNAQEFBQAwZTFCMEAGA1UE\n\t\t\t\t\t\tCgw5VW5pdmVyc2l0eSBvZiB0aGUgV2VzdCBvZiBFbmdsYW5kIChVV0UpIC0gT3Bl\n\t\t\t\t\t\tbkF0aGVucyB0ZXN0MR8wHQYDVQQDDBZhdGhlbnNsYS1kZXYudXdlLmFjLnVrMB4X\n\t\t\t\t\t\tDTEyMDEzMTE0NDQwOVoXDTIyMDEzMTE0NDQwOVowZTFCMEAGA1UECgw5VW5pdmVy\n\t\t\t\t\t\tc2l0eSBvZiB0aGUgV2VzdCBvZiBFbmdsYW5kIChVV0UpIC0gT3BlbkF0aGVucyB0\n\t\t\t\t\t\tZXN0MR8wHQYDVQQDDBZhdGhlbnNsYS1kZXYudXdlLmFjLnVrMIIBIjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqxbxAqe72n/rFUKC+8culLa4pBzN/nJtn9GF\n\t\t\t\t\t\t6n6zV89BXbmtzJ+BHMaRxnK38RCbnD0DteMsOidfFH5cfiWCE2sc9QYEOnH33QKA\n\t\t\t\t\t\twE4hWKaTWgQPyGqZeuMYG1fJIUSVuO6Uv6BU8rPcUUA+Y5KMqtNW+7gqqMTZIzN8\n\t\t\t\t\t\t9DAHQuFuAQ0eo45sQ9R/KlHGhCLxq7QfSc5Ubw0RDAu6LKNIcysE5Z2wHveSrOFl\n\t\t\t\t\t\tATfGvlIDqD3NgU5qTAgOmtdV7SMLV2GmUHchywsU5lAfe79F29eLR76I3VS7QvS/\n\t\t\t\t\t\tpNFWaNEeZ6KzekjuP1AA9DTE6e/G8tGbp9TuN3Voxd17X3df6wIDAQABo1AwTjAd\n\t\t\t\t\t\tBgNVHQ4EFgQUH09lZ8a/50v7n7KoHu5cPkXL4c0wHwYDVR0jBBgwFoAUH09lZ8a/\n\t\t\t\t\t\t50v7n7KoHu5cPkXL4c0wDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tOddVOziOhr4dyJAY4qlb1KOoYmluG79TdWJX8j35+ZiyMzm/xgA0uHzwuSIu3XbE\n\t\t\t\t\t\tdskHJou0p13BqDOMXXeTvCmOWylxPgrLv7bDfY3IiCJO/lLcCESJ+gDglkjDioGq\n\t\t\t\t\t\tpwrdhq9wOFVThuqmQSQlBFxPauGazIs+9x1g+pb0xtHXQY3VQabwtgOF9j1kRJ34\n\t\t\t\t\t\t6h/pyQvI3Xqs+z+v/LPb3Kgq9Xfx91U+KJcPgzrcqVYPRYcEXQnDIag3JO9KQvja\n\t\t\t\t\t\tCBC55WV0qbeYU7fb3oAdceGRkKzS5oP0h0rtRxTaAKq6HIrmu65mF4upHfAR3KB+\n\t\t\t\t\t\ti+gyuTDSHb2b8u6Rvfl54A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDnDCCAoSgAwIBAgIIAj83J4NilnUwDQYJKoZIhvcNAQEFBQAwZTFCMEAGA1UE\n\t\t\t\t\t\tCgw5VW5pdmVyc2l0eSBvZiB0aGUgV2VzdCBvZiBFbmdsYW5kIChVV0UpIC0gT3Bl\n\t\t\t\t\t\tbkF0aGVucyB0ZXN0MR8wHQYDVQQDDBZhdGhlbnNsYS1kZXYudXdlLmFjLnVrMB4X\n\t\t\t\t\t\tDTEyMDEzMTE0NDQwOVoXDTIyMDEzMTE0NDQwOVowZTFCMEAGA1UECgw5VW5pdmVy\n\t\t\t\t\t\tc2l0eSBvZiB0aGUgV2VzdCBvZiBFbmdsYW5kIChVV0UpIC0gT3BlbkF0aGVucyB0\n\t\t\t\t\t\tZXN0MR8wHQYDVQQDDBZhdGhlbnNsYS1kZXYudXdlLmFjLnVrMIIBIjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqxbxAqe72n/rFUKC+8culLa4pBzN/nJtn9GF\n\t\t\t\t\t\t6n6zV89BXbmtzJ+BHMaRxnK38RCbnD0DteMsOidfFH5cfiWCE2sc9QYEOnH33QKA\n\t\t\t\t\t\twE4hWKaTWgQPyGqZeuMYG1fJIUSVuO6Uv6BU8rPcUUA+Y5KMqtNW+7gqqMTZIzN8\n\t\t\t\t\t\t9DAHQuFuAQ0eo45sQ9R/KlHGhCLxq7QfSc5Ubw0RDAu6LKNIcysE5Z2wHveSrOFl\n\t\t\t\t\t\tATfGvlIDqD3NgU5qTAgOmtdV7SMLV2GmUHchywsU5lAfe79F29eLR76I3VS7QvS/\n\t\t\t\t\t\tpNFWaNEeZ6KzekjuP1AA9DTE6e/G8tGbp9TuN3Voxd17X3df6wIDAQABo1AwTjAd\n\t\t\t\t\t\tBgNVHQ4EFgQUH09lZ8a/50v7n7KoHu5cPkXL4c0wHwYDVR0jBBgwFoAUH09lZ8a/\n\t\t\t\t\t\t50v7n7KoHu5cPkXL4c0wDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tOddVOziOhr4dyJAY4qlb1KOoYmluG79TdWJX8j35+ZiyMzm/xgA0uHzwuSIu3XbE\n\t\t\t\t\t\tdskHJou0p13BqDOMXXeTvCmOWylxPgrLv7bDfY3IiCJO/lLcCESJ+gDglkjDioGq\n\t\t\t\t\t\tpwrdhq9wOFVThuqmQSQlBFxPauGazIs+9x1g+pb0xtHXQY3VQabwtgOF9j1kRJ34\n\t\t\t\t\t\t6h/pyQvI3Xqs+z+v/LPb3Kgq9Xfx91U+KJcPgzrcqVYPRYcEXQnDIag3JO9KQvja\n\t\t\t\t\t\tCBC55WV0qbeYU7fb3oAdceGRkKzS5oP0h0rtRxTaAKq6HIrmu65mF4upHfAR3KB+\n\t\t\t\t\t\ti+gyuTDSHb2b8u6Rvfl54A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of the West of England (UWE) - OpenAthens test"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uwe.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of the West of England, Bristol"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://birk.wayf.dk/birk.php/fg.ucsyd.dk/adfs/services/trust",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://birk.wayf.dk/birk.php/fg.ucsyd.dk/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2015-08-24T10:04:27Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/fg.ucsyd.dk/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://birk.wayf.dk/birk.php/fg.ucsyd.dk/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucsyd.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UC SYD"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University College South Denmark"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "ucsyd.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC1jCCAb4CAQcwDQYJKoZIhvcNAQELBQAwMTEvMC0GA1UEAwwmaHR0cDovL2Zn\nLnVjc3lkLmRrL2FkZnMvc2VydmljZXMvdHJ1c3QwHhcNMTUwMTAxMDAwMDAwWhcN\nMjUxMjMxMjM1OTU5WjAxMS8wLQYDVQQDDCZodHRwOi8vZmcudWNzeWQuZGsvYWRm\ncy9zZXJ2aWNlcy90cnVzdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAMeIDApqEFO4jhn4gnWuA54SIILLdtH1Ah7cGkKx6MUJTmtLORYA2pW5zU8N+nQl\n0hmGs9eyYMlAyaJ08IY8gNAqj5uT5p/f4RQVL8j/7fmxIFfa9/6HUMe9lX2OzOea\nlJWOnsdn9ag9YHKRYEk7QA5WbMHnOVqqRLfonvr7DF6vB2m4TFWdhI13vdL4DJP8\nRn61cA77qVDwUv9gyUmdSRJpKotIcXLTUPaoE2ZhHAGkJLr91RnLGLS3mPyCEpQP\ngEc5lVq+frknrZwl1eI5wxHJQAinnsZdCsvrcq2uMhxd12r4JnJnm3fsR1Q4jPja\nOgVzLvcwU6e3KeUoS87DUEkCAwEAATANBgkqhkiG9w0BAQsFAAOCAQEAkHqEqEjr\nN4B3C4ve/P2hcPYWuZmKbmMq1lCUZ4hQFojUGrv9xWmYJ7EOm2XTRvZbCli7a2Wd\ndAyO3hIYTSZ+jF7Yd1AHWYT6962JbsL+Nh1gKEc6JteOaboxRLVCA7rpIP7B6Gv2\nnISW/fieSzMAhTUe6tPN1Z7W9g51KBsTorAk4aF/y2y2zaqaTZTdtuftRIFi19zZ\ne3YxKZTXpYQNXgjPi9OB0R/mpA2vq6h5c1sVH547Rn22N/Aa/Dywdb/q4Q9360dZ\nUFdljlsuM44ZHRRTQB7UThOzNtQaqFViwo1G86pznm4OQ5WhZqzFO8eoPb8bBtrk\n+rIdBFfSZxkAiQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UC SYD"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University College South Denmark"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ucsyd.dk/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.ucsyd.dk/international/welcome-to-university-college-south-denmark/"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UC SYD"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University College South Denmark"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.uwf.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mhaveard@uwf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Melanie Haveard"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ggolding@uwf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Geissler Golding"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jandrews@uwf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Justin Andrews"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@uwf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UWF ITS Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uwf.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uwf.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uwf.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAPWEoMIc9MgjL3fLMSOKivnmI4soMA0GCSqGSIb3DQEB\nCwUAMBYxFDASBgNVBAMMC2lkcC51d2YuZWR1MB4XDTE1MTAwODEyMzc1OVoXDTM1\nMTAwODEyMzc1OVowFjEUMBIGA1UEAwwLaWRwLnV3Zi5lZHUwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCIBUPbpiv3h2s2JEUUxdfxMFYvu5lvoPdggHb9\nBhWT53BgJVV7cH1XcrtWn/7/NwMGOYGLzMzvpMJOCXUatVpJybhtM9sffy6hjjKS\n3+vAKFEAI38vfTdoZoM17UEM+22Y1Bim4AkdyCdSLMLDNH2edt7WocgB1gnandJI\naKWP/ZI3Fu+4KA5GTbGsd3DJsJIV3NeHuGIUhRCaDPbR08Hc7u7RopgmmohV0tOp\n4NvWhbqy5c2M50cg4h+PAhesyk3id3P/ZZ+5e2PLxBB2kGuHK2qrs1+OI6rzwNE6\n8R0Ij9BUiDSeY6L0ST5p1kA//t22UZOFlE4DwNFi9mz3E85/AgMBAAGjXTBbMB0G\nA1UdDgQWBBScj7YiheZwUBxNvWg6KUtfw37yGTA6BgNVHREEMzAxggtpZHAudXdm\nLmVkdYYiaHR0cHM6Ly9pZHAudXdmLmVkdS9pZHAvc2hpYmJvbGV0aDANBgkqhkiG\n9w0BAQsFAAOCAQEAQWq+qgyNF5aIMd72d4l2EFvVo0MS0y60OhqbFFMh1zAodjgG\nj2S1bDSkagWZnkReopf5vt+7/oUeaav0b1bR5/C/cn3y4j2VgMMVNolCVMDuGhJu\nKMDFH3A9LmFUxiI/EBehP2miYOGxo8cg3cfxR4LvveJPuwl0lEzpOHa7ITNcuY4i\nNkrSXk8BPkxKbOfkPY/03cxGCVAbDDtAFbrpc+Dl7oWzZyWEPGBOPO1+FwOnouhg\ngwO2WaSZ5oSRh89lFWWjxnXcLM0qysDrlr7ZypdE4sa0l49XmWSHIUqmlB4N6v1R\nQn1Arbqr1KlWplK7ZKwCVb3qIEuvCtarRGT3ow=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uwf.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://idp.uwf.edu/idp/images/logo_west_florida.jpg",
                    "lang": "en",
                    "height": "68",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "260"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://uwf.edu/offices/general-counsel/uwf-policies-procedures-notices-regulations/privacy-statement"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of West Florida"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of West Florida"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://uwf.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of West Florida"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://saml.salesforce.com/sunet-sandbox",
    {
      "entity_id": "https://saml.salesforce.com/sunet-sandbox",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFYDCCBEigAwIBAgIQQ4KxN7E3aAGP1rpwQm6gZzANBgkqhkiG9w0BAQUFADCBvDELMAk\nGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMR8wHQYDVQQLExZWZXJpU2lnbi\nBUcnVzdCBOZXR3b3JrMTswOQYDVQQLEzJUZXJtcyBvZiB1c2UgYXQgaHR0cHM6Ly93d3cud\nmVyaXNpZ24uY29tL3JwYSAoYykxMDE2MDQGA1UEAxMtVmVyaVNpZ24gQ2xhc3MgMyBJbnRl\ncm5hdGlvbmFsIFNlcnZlciBDQSAtIEczMB4XDTEzMTAxODAwMDAwMFoXDTE3MTAxNzIzNTk\n1OVowgY8xCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpDYWxpZm9ybmlhMRYwFAYDVQQHFA1TYW\n4gRnJhbmNpc2NvMR0wGwYDVQQKFBRTYWxlc2ZvcmNlLmNvbSwgSW5jLjEVMBMGA1UECxQMQ\nXBwbGljYXRpb25zMR0wGwYDVQQDFBRwcm94eS5zYWxlc2ZvcmNlLmNvbTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALJtS/8tJmPZ/CKOz/dJ7MXrgz0MPQKxEAdgrdOFdRj\nsavTY+RviREe+zwjrKd9ZsCS3GltV2GBFD+YxXzuptQr+ZUDC8Vwx+49WQ13D55nmoUJVcB\n1nHlTXBICJQDo87cZ4AIViuSVkUfQRG7BeMfKTMngyGdAOIsnSFwp1ONmRqaIarWTfr2w0S\nNFNPikW9rQjehAF/eh6Ib4H3bJEE/kAwRS4mFJoxEKsiJQhnymqeoVgLMSb3UTS8J9R1RmQ\ni+kisC39NAzVwQjM1X677cdQt0FaF6GlZ97vCH/rpNAJnAVwaWiRNQ32AR2X39rp8DVpSk9\neynNGp1JI/6mIv3ECAwEAAaOCAYcwggGDMB8GA1UdEQQYMBaCFHByb3h5LnNhbGVzZm9yY2\nUuY29tMAkGA1UdEwQCMAAwDgYDVR0PAQH/BAQDAgWgMCgGA1UdJQQhMB8GCCsGAQUFBwMBB\nggrBgEFBQcDAgYJYIZIAYb4QgQBMEMGA1UdIAQ8MDowOAYKYIZIAYb4RQEHNjAqMCgGCCsG\nAQUFBwIBFhxodHRwczovL3d3dy52ZXJpc2lnbi5jb20vY3BzMB8GA1UdIwQYMBaAFNebfNg\nioBX33a1fzimbWMO8RgC1MEEGA1UdHwQ6MDgwNqA0oDKGMGh0dHA6Ly9TVlJJbnRsLUczLW\nNybC52ZXJpc2lnbi5jb20vU1ZSSW50bEczLmNybDByBggrBgEFBQcBAQRmMGQwJAYIKwYBB\nQUHMAGGGGh0dHA6Ly9vY3NwLnZlcmlzaWduLmNvbTA8BggrBgEFBQcwAoYwaHR0cDovL1NW\nUkludGwtRzMtYWlhLnZlcmlzaWduLmNvbS9TVlJJbnRsRzMuY2VyMA0GCSqGSIb3DQEBBQU\nAA4IBAQAEMsL4HAd5uYW3j0SQFX4Opl7p0Vo4o7HKBHCtV4ZjzkSFwvRR9+5zijYqlhe4ou\n1SL4WAWAsTKMTpKz0CL1S9Npt0IcKmIWeRsjJKKznFa8sxHhgEvm3O11a9uVfgvmnwn0VEp\nuTmGvXvIUSAZ5q0CVDgzbGsrjWnZXllgO6krwPonEg6MdFarA87bAkLCrLZ0HqWeUVlf2nt\nfvR7kjr0trUM/EBxPdcPxeMK70EJqku7GMEPOxkexTr2O0yD/2lZM0il+AUuOboZDl0Syfj\nU0N7YIKNKZq5hcoUP/sCpcReMNj0dAWeVYmADrV7LlOVvndgHKcLrUydS/9obQHen"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://sunet--Test.cs80.my.salesforce.com?so=00D25000000Czjt",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SUNET Salesforce.com (sandbox)"
                }
              ],
              "requested_attribute": [
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.mta.hu/idp/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "AAT"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:szervezes@titkarsag.mta.hu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "AAT"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:szervezes@titkarsag.mta.hu"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "AAT"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:szervezes@titkarsag.mta.hu"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.mta.hu/idp/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "urn:schac:homeOrganizationType:hu:nren"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-test"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-edugain"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-idps"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "mtatitk"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:geant:niif.hu:eduid.hu:entity-attributes:processing-info",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "hu",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://metadata.eduid.hu/registration_policy_1_0.txt"
              }
            ],
            "registration_instant": "2013-08-01T07:17:19.807Z",
            "registration_authority": "http://eduid.hu",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.mta.hu/idp/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.mta.hu/idp/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://aat.mta.hu"
                  }
                ],
                "display_name": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "MTA Akad\u00e9miai Adatt\u00e1r (AAT)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hungarian Academy Database (AAT)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "MTA Titk\u00e1rs\u00e1g"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hungarian Academy of Sciences"
                  }
                ],
                "logo": [
                  {
                    "text": "https://aat.mta.hu/aat/Content/images/mta_logo_small.png",
                    "height": "73",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://aat.mta.hu/aat/Content/documents/35_2013_aat_adatvedelem.en.pdf"
                  }
                ]
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "titkarsag.mta.hu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.mta.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MTA Titk\u00e1rs\u00e1g"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hungarian Academy of Sciences"
          }
        ],
        "organization_url": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://aat.mta.hu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://aat.mta.hu/en"
          }
        ],
        "organization_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "MTA Titk\u00e1rs\u00e1g"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hungarian Academy of Sciences"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.dfn.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "K\u00e4hler"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kaehler@dfn.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ulrich"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Borenius"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hotline@aai.dfn.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Raoul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hotline"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hotline@aai.dfn.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "DFN-AAI"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.dfn.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2009-08-10T13:32:27Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.dfn.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGmDCCBYCgAwIBAgIHF2OL3fx3djANBgkqhkiG9w0BAQsFADBeMQswCQYDVQQG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\nOcCmF2VZ92umABiw"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.dfn.de,OU=Geschaeftsstelle,O=DFN-Verein,L=Berlin,ST=Berlin,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dfn.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.dfn.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.dfn.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.dfn.de:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.dfn.de/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.dfn.de/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.dfn.de/idp/profile/SAML2/POST-SimpleSign/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.dfn.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.dfn.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.dfn.de/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.dfn.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.dfn.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.dfn.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dfn.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.dfn.de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.dfn.de/en/"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "F\u00f6derations-Login f\u00fcr MitarbeiterInnen des DFN-Vereins"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Federation login for DFN staff members"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.aai.dfn.de/fileadmin/pics/dfn_small.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://www.aai.dfn.de/fileadmin/pics/dfn_big.png",
                    "height": "130",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "236"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DFN-Verein Gesch\u00e4ftsstelle"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DFN Office"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.dfn.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGmDCCBYCgAwIBAgIHF2OL3fx3djANBgkqhkiG9w0BAQsFADBeMQswCQYDVQQG\nEwJERTETMBEGA1UEChMKREZOLVZlcmVpbjEZMBcGA1UECxMQR2VzY2hhZWZ0c3N0\nZWxsZTEfMB0GA1UEAxMWREZOLVZlcmVpbi1HUy1DQSAtIEcwMjAeFw0xNDA0MDgx\nNDU3MTdaFw0xODExMzAyMjAwMDBaMHQxCzAJBgNVBAYTAkRFMQ8wDQYDVQQIEwZC\nZXJsaW4xDzANBgNVBAcTBkJlcmxpbjETMBEGA1UEChMKREZOLVZlcmVpbjEZMBcG\nA1UECxMQR2VzY2hhZWZ0c3N0ZWxsZTETMBEGA1UEAxMKaWRwLmRmbi5kZTCCAiIw\nDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIBANLulBKv3/WE3HhIhXkl+u974zhl\nsQF6VLuZ90e3EDX7jD7Hbb2x9ntefY3whu8rpGKqkP4r6Au9QydnulyRTBg7ss7O\npEy/hfoTug2QwEZEXRZZgTcxYptkoIUxyoKaZfWxe2/0IFWObSlmNx9jvY3oR1W0\neVHDCb4FB2NVYoLNaOHLxaOF+pQZKgJnm96emX+JeC/YP9ecdtRi7ZYiFRA2uUXR\nux0+r3zrYEVmBM7vWu1paHGvGMDpNHG7s+5a33ercMAB31G1MIcgDyXCHiWPuYlj\np3X3OyYMkL+jGbhJ9Db3ChE9aiG93Lb4Qo5NQuCCcSJs1tz78vkCfJ7tNOBVk5KK\nYJK9i48zwg22+MicX5pPdxllRrEh0Psp6MoVdTNIq8Minyr1BrmdZB9DZBmraMXp\nJ6unZoll3KWr2WTlrr43V9QMoFjKjToYEhG+2U1kWeXwK0WM8fTxuUEFvUtqNbEX\n6CAgEFoef/Jf59k2JdTvLvtZZs5DHgWKbH/VR9j8z+91nij8QmPUuBWeuWeyeirt\nUD+G07BSDS7Lebi3OnsumpGPWrxmKWEOHccgGflaRA2pQYCiW8Rv8x7adLcf0sAo\nBDCX7+737ywrDqshRDX5y75tAES6aCm/fARsZKQ4/HiOvx5vNefHElMY3w3YMUKd\nNthdnrYZeKe0WmW1AgMBAAGjggJDMIICPzA5BgNVHSAEMjAwMBEGDysGAQQBga0h\ngiwBAQQDATARBg8rBgEEAYGtIYIsAgEEAwEwCAYGZ4EMAQICMAkGA1UdEwQCMAAw\nCwYDVR0PBAQDAgXgMB0GA1UdJQQWMBQGCCsGAQUFBwMCBggrBgEFBQcDATAdBgNV\nHQ4EFgQUaWmQ/Clpu7Zdjqw/7viZtheoEiQwHwYDVR0jBBgwFoAUeaJiL87xBjlS\n53ZtYsfem2p1S0kwFQYDVR0RBA4wDIIKaWRwLmRmbi5kZTCBkQYDVR0fBIGJMIGG\nMEGgP6A9hjtodHRwOi8vY2RwMS5wY2EuZGZuLmRlL2Rmbi12ZXJlaW4tZ3MtY2Ev\ncHViL2NybC9nX2NhY3JsLmNybDBBoD+gPYY7aHR0cDovL2NkcDIucGNhLmRmbi5k\nZS9kZm4tdmVyZWluLWdzLWNhL3B1Yi9jcmwvZ19jYWNybC5jcmwwgd8GCCsGAQUF\nBwEBBIHSMIHPMDMGCCsGAQUFBzABhidodHRwOi8vb2NzcC5wY2EuZGZuLmRlL09D\nU1AtU2VydmVyL09DU1AwSwYIKwYBBQUHMAKGP2h0dHA6Ly9jZHAxLnBjYS5kZm4u\nZGUvZGZuLXZlcmVpbi1ncy1jYS9wdWIvY2FjZXJ0L2dfY2FjZXJ0LmNydDBLBggr\nBgEFBQcwAoY/aHR0cDovL2NkcDIucGNhLmRmbi5kZS9kZm4tdmVyZWluLWdzLWNh\nL3B1Yi9jYWNlcnQvZ19jYWNlcnQuY3J0MA0GCSqGSIb3DQEBCwUAA4IBAQBhogS0\nluPrkG27IJ+U533cyV407S0PPN2WbiS/i+BqVXJt0JkEz9WP3oFMg5jF3V/R0czH\n2pXqx6sVuRqXUczNCKQ7ayRkQLJJRRKvWBxTk4P3/BivbEmoszIL0m7POge3hZLe\ndH+9WswAHIDwczkPqip77o6kbrjiDeEj8epv8dNBGLnHMHoQuAntnehIb6fr+BF1\nXljtaDnOsSkkwlHPHmsIrjIyHCf5+bAOjvLs9/tOtoR5heDPM3elCSZ0U4+FfGIO\nt19h1FfeHHhQ9zC4DVuQJGVwWD5/ppoQXwA3acoFUdRnwH/ojbx8+plHuxu2Pfz8\nOcCmF2VZ92umABiw"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.dfn.de,OU=Geschaeftsstelle,O=DFN-Verein,L=Berlin,ST=Berlin,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Verein zur F\u00f6rderung eines Deutschen Forschungsnetzes"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "German National Research and Education Network, DFN"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dfn.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dfn.de/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e15"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e15"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "test.lararlyftet-validering.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "test.lararlyftet-validering.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.lararlyftet-validering.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://test.lararlyftet-validering.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.lararlyftet-validering.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.lararlyftet-validering.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://acc.lararlyftet-validering.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://acc.lararlyftet-validering.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://acc.lararlyftet-validering.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://acc.lararlyftet-validering.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.lararlyftet-validering.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://acc.lararlyftet-validering.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.lararlyftet-validering.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://test.lararlyftet-validering.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Valideringssystemet f\u00f6r L\u00e4rarlyftet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service is the validation system for L\u00e4rarlyftet"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "L\u00e4rarlyftet Validering"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "L\u00e4rarlyftet Validation"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "uhrval-test.i.uhr.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAKrvj/quXo0oMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFHVocnZhbC10ZXN0LmkudWhyLnNlMB4XDTE0MTIwODA5MTExMVoXDTI0MTIw\nNTA5MTExMVowHzEdMBsGA1UEAxMUdWhydmFsLXRlc3QuaS51aHIuc2UwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCtIWX5i6gPePK7nbap8snxwcLqlCID\nLWZkxbQGCVIgixRk1w87yUD882SSZjUATS8JV+8TeHNIsRSkBeXB1MQQopeDtm5C\nLDhh/RxHL3IRBlhesOE5zWcc4xeBzRIBKb1OC773XbSLx1lQhZmH+fiQvEk5FfWG\nri683HBCQq3gpc3hX2lY7C7oAxL7KST+37zLIBy7c83fzWr3eQ1myKZFfHBsmMOt\npNjBNMG8V924gaHWKAuqDa6lds53PszYZh27bN7dWXRrN0vXEZu6zfEioJVvg5RL\nc0lUqg/yu8Dk9JYYm9rQDj007livs9QllR54wsIxosVQWhAz36ZFafaNAgMBAAGj\nQjBAMB8GA1UdEQQYMBaCFHVocnZhbC10ZXN0LmkudWhyLnNlMB0GA1UdDgQWBBSG\nEGTlhQfKssjt+WgDPIKFHzzZEDANBgkqhkiG9w0BAQUFAAOCAQEAOHImN37aqOBU\nwicsP5vJ7X8yX6he/dAnRKhZbjWSlpFSZGwZrV/B6YeROAyRbzQH1fQRTup+angF\nB5m+vmxG0XjhUm8gXpMNqjgxaay72m2rPTVAkbqkMNTKNf44bRK5OGqPlJ0lwrnC\nWh1+2EdKahr4lzJaqiW2rXvX3moTYqrJlssglT+IRTzoNbL6eQLdqCVvZxXDjyUb\nD79D+ECq8yjkS4/8EQlvHdHozRMMplJTo+pXoZwV9KZgMMsxdT63VuJ/0HRCxCMC\nzcmOSN36LTlSIYY4q9pC8MCzt5YqZdnKJUIyjFy+Mmjeyw4t+ouUjjI6+AifCten\nBwquFopAQg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=uhrval-test.i.uhr.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.lararlyftet-validering.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://test.lararlyftet-validering.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.lararlyftet-validering.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.lararlyftet-validering.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://acc.lararlyftet-validering.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://acc.lararlyftet-validering.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://acc.lararlyftet-validering.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://acc.lararlyftet-validering.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.lararlyftet-validering.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.lararlyftet-validering.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://test.lararlyftet-validering.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://test.lararlyftet-validering.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://test.lararlyftet-validering.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://acc.lararlyftet-validering.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://acc.lararlyftet-validering.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://acc.lararlyftet-validering.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://acc.lararlyftet-validering.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://acc.lararlyftet-validering.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://luvit.ced.lu.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sidika.basic@ced.lu.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sidika Basic"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://luvit.ced.lu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "http://luvit.ced.lu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "http://luvit.ced.lu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://luvit.ced.lu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "http://luvit.ced.lu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "http://luvit.ced.lu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "http://luvit.ced.lu.se/Shibboleth.sso/Login-lu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "http://luvit.ced.lu.se/Shibboleth.sso/Login-swamid",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Milj\u00f6n \u00e4r utformad f\u00f6r s\u00e5v\u00e4l kursdeltagare som utbildare och administrat\u00f6rer f\u00f6r att kunna skapa, hantera, f\u00e5 tillg\u00e5ng till, administrera och deltaga i n\u00e4tbaserade kurser eller n\u00e4tbaserade aktiviteter i blandade kurser."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The environment is created for course participants as well as for educators and administrators in order to create, manage, overview, obtain, administrate and participate in online courses or in online course activities in mixed courses."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lunds universitet LUVIT"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lund University LUVIT"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "uwap122.uw.lu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJALDUiCW01jNBMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEHV3YXAxMjIudXcubHUuc2UwHhcNMTUwNjEyMDU1ODQ5WhcNMjUwNjA5MDU1\nODQ5WjAbMRkwFwYDVQQDExB1d2FwMTIyLnV3Lmx1LnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAyIAAztvo5p1DLnAblJ7n2PVyA+zPuriChIeyguRF\nzHXXqWET0CrWeAmIHVS22WYT7cbVlnS0Y+82NOf0tJOaFO5EmTseozQzGHL5Dc4F\ndHFO92oo2YOLimXuuuTS8gCaTcbsFrKoLBcQHXCu8lHyMWE/zoRZJkqxRJCg0Mmu\n55jUaxUG5FSdw0kS5Td1GRALUEBzzvsS+LlLJEM7gK3cHs23qwng7mqiK2d/oSAR\nxzwHeaQqGFEBCKl3S4PHGweV8BdJVOeJzKSC7L7ND3BGWUqXq1j2XA2otRU2MZIc\niHG0++I4ERw621OfYHduEqK7x9IcQVQWreCNEsTN3qkhFQIDAQABoz4wPDAbBgNV\nHREEFDASghB1d2FwMTIyLnV3Lmx1LnNlMB0GA1UdDgQWBBTuH02zf7l0oxRIzwqK\nRRDjwhC2ojANBgkqhkiG9w0BAQUFAAOCAQEAgiBlVk4LQDwbQ5skBi3tKk7FXK96\nyLiDgA4gR9XqD0Hq/l29Qzhya5mv3FBC9sgtV3ZJC9oH8H/jm4UuURg6iqKL7vmr\nwEGqG95E9xL2p6Jkcpi0CdjyUvkPcULlAKu/IRfRs/E1j/KtzacYEeQ3cDYD1d9F\nXvFIh3QzDURHqWL+ELZXMDSJYfjQe+7jP2w+Vu/TbF39otuREtJmYwcLOBxRvJYk\n6x3/BMwjSRXpDBttsVAClDS+Wm0A5jr5eCg7OoWNzdze74zGQpP4U7tWKZHT5bA4\nOTMXxdAawBca6aO1CpUMAwipgLVKJyNkmxV7+aPSdkp/U466LROEWhraZg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=uwap122.uw.lu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "http://luvit.ced.lu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "http://luvit.ced.lu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://luvit.ced.lu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "http://luvit.ced.lu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://luvit.ced.lu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "http://luvit.ced.lu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "http://luvit.ced.lu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "http://luvit.ced.lu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "http://luvit.ced.lu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://login.helsinki.fi/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Peltonen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idm-hosting@helsinki.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Janne"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Niemi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idm-hosting@helsinki.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Juha"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.helsinki.fi/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.csc.fi/english/institutions/haka/instructions/join/eduGAINRegistrationStatement/"
              }
            ],
            "registration_authority": "http://www.csc.fi/haka",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.helsinki.fi/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.helsinki.fi/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "helsinki.fi"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Helsinki"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Helsingin yliopisto"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Helsingfors universitet"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFnDCCBISgAwIBAgIQaa2rCkgYcvukeleEtUvyozANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMjAeFw0xNTA0MjcwMDAwMDBaFw0xODA2MTMyMzU5NTlaMD8xITAfBgNVBAsT\nGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEaMBgGA1UEAxMRbG9naW4uaGVsc2lu\na2kuZmkwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQC9+9NToC10zJ71\nAkre2PbHsI2Qzpdi0vFdlDh9W7BtFqz/4fpX/xe92EaGpDIxS06gSjl1XB4jGjbq\n6YUVXbu9Tg/FxGxfGt/lsEyvHrzyt3EdDQlm2Tn+WVwe5CDbLKsxAeC2nKUJPgdc\n8KT5iyKUAfyU/XK3TgBn0zuyM9XrI/C2bQfNgCF9KfrJALIUI6/Y+s8VCHTzQnwy\nNEZPdTtnb/8XNhKbf+UH42vGjRWH6loRN/6ZLg7t0FICvS73CtBxlh2IA6Qr0fNf\nThgeLr7R3IuY7Mff8Fpg1N/3uy85Pi79Lsfo6dbY0CAolgVvFKtZQVh4U1LzpvuF\nRttfOqMCruEgTA+3LUkBbQCY0bU43AqDByDHDnw+CU8+ivjw99OI2292cLVd1cFC\nY6Wx1fBgJps+d85fWFsz9kppYeAv7PLbMEesj4OPXGYAF84bBmrdNwcl0SoAVfzZ\nWTAAJZdxGAKsSpEdokQu7gsAXegLTFGCrSkxI/9337ZeMLd6LJyrWYxXFmxk6R5u\nowmZwKHxXOpq37ZlJksnCAghvoNjqdA0WBQeXNCrwrScWIdQIWBJCLYj/pYIBckZ\nAxvjm21cAgLl98lnCtWG3HG2t4GykxCsgtdY8hPw0Ze/oXBZpTY78DKD0pOW6ndj\nWGgtjZWiW6yrj8mlV8hWqCULfS/rfwIDAQABo4IBbTCCAWkwHwYDVR0jBBgwFoAU\nW9CKHJoyW+C13ZZUG+GGKLD9tr0wHQYDVR0OBBYEFMqg7/cYdb2o9CSfG4wtgFrc\ngwH9MA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsG\nAQUFBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeB\nDAECATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnVzZXJ0cnVzdC5jb20v\nVEVSRU5BU1NMQ0EyLmNybDBsBggrBgEFBQcBAQRgMF4wNQYIKwYBBQUHMAKGKWh0\ndHA6Ly9jcnQudXNlcnRydXN0LmNvbS9URVJFTkFTU0xDQTIuY3J0MCUGCCsGAQUF\nBzABhhlodHRwOi8vb2NzcC51c2VydHJ1c3QuY29tMBwGA1UdEQQVMBOCEWxvZ2lu\nLmhlbHNpbmtpLmZpMA0GCSqGSIb3DQEBCwUAA4IBAQCJ2I4mTHMYM2SZuAf9XI2x\nLk/VLU8LqZOGc5yvQCdLG3iLz6xkUU/ESG4Nrwyl8MN8IB/ul3bbZVriZ+htb4R4\nCmB44srsj10lKAHcCDYbxUNj+EbewMXkXqBybjkqlih5JjdlH1eA72M8aDvtHIi9\n7YOfX0qkuYX1MC17UL+IlD1Ed5oSdckyPUCDrTksNmZ3AegQVJlDmk8KL7xXm6qZ\n1JFj+dX1uM1cPa0sf0ZK6fI8aOhPhKz+usclFplwR7ohnEp60S3KgH9VbhHpjItj\nDjLzl9rFbErZuexB3N7XJhesfd5IwneNaJ2oVjJZB9gzknuG6bwrURgOA8sHcxV0"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Helsingin yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Helsinki"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Helsingfors universitet"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.helsinki.fi/yliopisto/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.helsinki.fi/yliopisto/"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.helsinki.fi/yliopisto/"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Helsingin yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Helsinki"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Helsingfors universitet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.okstate.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shawn.harpe@okstate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shawn Harpe"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tina.meier@okstate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tina Meier"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Raymond.Smith@okstate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Raymond Smith"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.okstate.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.okstate.edu:9443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.okstate.edu:9443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYjCCAkoCCQDzMip1XDG8GjANBgkqhkiG9w0BAQUFADBzMRgwFgYDVQQDDA9p\nZHAub2tzdGF0ZS5lZHUxIjAgBgNVBAoMGU9rbGFob21hIFN0YXRlIFVuaXZlcnNp\ndHkxCzAJBgNVBAYTAlVTMREwDwYDVQQIDAhPa2xhaG9tYTETMBEGA1UEBwwKU3Rp\nbGx3YXRlcjAeFw0xMjA2MTQxNTQ1MTBaFw0xMzA2MTQxNTQ1MTBaMHMxGDAWBgNV\nBAMMD2lkcC5va3N0YXRlLmVkdTEiMCAGA1UECgwZT2tsYWhvbWEgU3RhdGUgVW5p\ndmVyc2l0eTELMAkGA1UEBhMCVVMxETAPBgNVBAgMCE9rbGFob21hMRMwEQYDVQQH\nDApTdGlsbHdhdGVyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA6Qb5\npFa2CVE2rTeap0uYEBoJI0q5f3jpHwB/IysHTgDFtO337l4uQbkRBiQamZn/nUGb\nZwDwB5g/miUNnM+b8UctbiRQ5cbQ9UEGiFDipFklvXci9qTd4954VQabtq09FKx8\nAfKu/fjCL5xJfrkc8+1CY431sYBeVS+EfR1bZv3su0A30HTSK4IhEqrzo3BQbTxj\nes1JOiFNseF7SUqmdqsbSj4HsHjNwaLDEdF5zXuCgUL+USeMkGAmd4e1PXooTGgk\nMP2MiMuNDpHhG6aAbEncEgaFLLums48SY2qjIk3obihjRnU4oppSARom4h0paBkc\nP3TtfPT8vaPvZWUYyQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQAMEZIYHHXV/XoO\nA3f7isi1nUY6wTbmifIIAxVFRzKifbAKOjj9jVe3/Mi0dEDXuYTSrEbDgLtmLrxy\nIFmvZopmpGPQQ3BcNzsL+NsKju3DIohXnacuAax4K76a5rVqPu9KlmClSJmr12lB\n/MX45xmrb5jYIkwsG5aSgHJSbArDz9h0cwwOCcExthvp5Brb8F5J3/APluyg0hYj\npvucaNe/bhjtGVNcPmVkJ2bTzSOlE49icSRuDbc2bkZEqTPdBpSL6b+vKMTF+tDP\nA/br3xw5PtPDxp1uBcpZFuJ6GElZj2vUqXAt+l37NZHicQSRhMzGitXpTcO7OU/g\n7+8OWNW+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDpDCCAowCCQCjRgnERKTgvDANBgkqhkiG9w0BAQUFADCBkzELMAkGA1UEBhMC\nVVMxETAPBgNVBAgMCE9rbGFob21hMRMwEQYDVQQHDApTdGlsbHdhdGVyMRAwDgYD\nVQQKDAdPS1N0YXRlMQswCQYDVQQLDAJJVDEYMBYGA1UEAwwPaWRwLm9rc3RhdGUu\nZWR1MSMwIQYJKoZIhvcNAQkBFhRoZWxwZGVza0Bva3N0YXRlLmVkdTAeFw0xMzA1\nMjIxMjAwMTlaFw0yMzA1MjAxMjAwMTlaMIGTMQswCQYDVQQGEwJVUzERMA8GA1UE\nCAwIT2tsYWhvbWExEzARBgNVBAcMClN0aWxsd2F0ZXIxEDAOBgNVBAoMB09LU3Rh\ndGUxCzAJBgNVBAsMAklUMRgwFgYDVQQDDA9pZHAub2tzdGF0ZS5lZHUxIzAhBgkq\nhkiG9w0BCQEWFGhlbHBkZXNrQG9rc3RhdGUuZWR1MIIBIjANBgkqhkiG9w0BAQEF\nAAOCAQ8AMIIBCgKCAQEAwXKsNMBp5tdIbc1ZYbWy3AIKP3FbTjwLt8JU8Or5fnyg\nyOAxWZ9qSkaEoUNEJ+hF3pddckzdDoFXFu/iT5iNXSkb0fu1Z3TIq2L8ORzRuXmu\nXKaVjCzejeeitlyE9yDvXFQjT+Nvhi4j9PLzZ6cC6KW/fnOIdzrYUd1Gmrbu9bxe\nUXZKOn3u8foDeNmoG7WtmXwOhz8NemtMcEZ1L0VZugPqWQtyxCO7x3TeYwuS/4Te\nM+IqYeezWRhfsk7Vpamtgbfi9VMylC3cquE5f5/P24mp1AQuly81KZ9TZh4A9Mz6\nxUZfV7d+xQlQLimOmd5lXM1En4VhmPFfyfS7s1fWiwIDAQABMA0GCSqGSIb3DQEB\nBQUAA4IBAQC48jGan3mFH74r9/cDM44TbmS1LoNbe4ybvI50MgzvV055JRF/nVyf\n5oXYMTytnUCw8xh5IbQbbZnnxN1oJUD7CDcJ3j0alKx8/wsUQeCBnS5LN/WeBiRO\n0fEwOi5tmz7n0O6wQbu9psFPG2yl5Khj/jHYRVxQXwMoBMmrpxUG5Ha0UAoIPM8X\nQWUdAUmhN1oD6YxKK3Bf9pQ2Sinafdsc4k54wvfMZCQkH1f37Pll/cSQCSFxEDKX\nIUS69CJRUBfftvG82kYGdEO5y+FAWBuLyya32MVwWKzHOqh6Q0iTbgEsfWsQL7KU\naVziUIOjv/nrHap+xcHajNL7CKlXwKQ4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "okstate.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.okstate.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.okstate.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.okstate.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.okstate.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.okstate.edu:9443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.okstate.edu:9443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "okstate.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.it.okstate.edu/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Oklahoma State University Main Campus"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Oklahoma State University System"
                  }
                ],
                "logo": [
                  {
                    "text": "https://app.it.okstate.edu/osucalendar/images/logo.png",
                    "lang": "en",
                    "height": "130",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "200"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://stillwater.sharepoint.okstate.edu/Policies/Shared%20Documents/Family%20Educational%20Rights%20and%20Privacy%20Acts%20(B"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYjCCAkoCCQDzMip1XDG8GjANBgkqhkiG9w0BAQUFADBzMRgwFgYDVQQDDA9p\nZHAub2tzdGF0ZS5lZHUxIjAgBgNVBAoMGU9rbGFob21hIFN0YXRlIFVuaXZlcnNp\ndHkxCzAJBgNVBAYTAlVTMREwDwYDVQQIDAhPa2xhaG9tYTETMBEGA1UEBwwKU3Rp\nbGx3YXRlcjAeFw0xMjA2MTQxNTQ1MTBaFw0xMzA2MTQxNTQ1MTBaMHMxGDAWBgNV\nBAMMD2lkcC5va3N0YXRlLmVkdTEiMCAGA1UECgwZT2tsYWhvbWEgU3RhdGUgVW5p\ndmVyc2l0eTELMAkGA1UEBhMCVVMxETAPBgNVBAgMCE9rbGFob21hMRMwEQYDVQQH\nDApTdGlsbHdhdGVyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA6Qb5\npFa2CVE2rTeap0uYEBoJI0q5f3jpHwB/IysHTgDFtO337l4uQbkRBiQamZn/nUGb\nZwDwB5g/miUNnM+b8UctbiRQ5cbQ9UEGiFDipFklvXci9qTd4954VQabtq09FKx8\nAfKu/fjCL5xJfrkc8+1CY431sYBeVS+EfR1bZv3su0A30HTSK4IhEqrzo3BQbTxj\nes1JOiFNseF7SUqmdqsbSj4HsHjNwaLDEdF5zXuCgUL+USeMkGAmd4e1PXooTGgk\nMP2MiMuNDpHhG6aAbEncEgaFLLums48SY2qjIk3obihjRnU4oppSARom4h0paBkc\nP3TtfPT8vaPvZWUYyQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQAMEZIYHHXV/XoO\nA3f7isi1nUY6wTbmifIIAxVFRzKifbAKOjj9jVe3/Mi0dEDXuYTSrEbDgLtmLrxy\nIFmvZopmpGPQQ3BcNzsL+NsKju3DIohXnacuAax4K76a5rVqPu9KlmClSJmr12lB\n/MX45xmrb5jYIkwsG5aSgHJSbArDz9h0cwwOCcExthvp5Brb8F5J3/APluyg0hYj\npvucaNe/bhjtGVNcPmVkJ2bTzSOlE49icSRuDbc2bkZEqTPdBpSL6b+vKMTF+tDP\nA/br3xw5PtPDxp1uBcpZFuJ6GElZj2vUqXAt+l37NZHicQSRhMzGitXpTcO7OU/g\n7+8OWNW+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDpDCCAowCCQCjRgnERKTgvDANBgkqhkiG9w0BAQUFADCBkzELMAkGA1UEBhMC\nVVMxETAPBgNVBAgMCE9rbGFob21hMRMwEQYDVQQHDApTdGlsbHdhdGVyMRAwDgYD\nVQQKDAdPS1N0YXRlMQswCQYDVQQLDAJJVDEYMBYGA1UEAwwPaWRwLm9rc3RhdGUu\nZWR1MSMwIQYJKoZIhvcNAQkBFhRoZWxwZGVza0Bva3N0YXRlLmVkdTAeFw0xMzA1\nMjIxMjAwMTlaFw0yMzA1MjAxMjAwMTlaMIGTMQswCQYDVQQGEwJVUzERMA8GA1UE\nCAwIT2tsYWhvbWExEzARBgNVBAcMClN0aWxsd2F0ZXIxEDAOBgNVBAoMB09LU3Rh\ndGUxCzAJBgNVBAsMAklUMRgwFgYDVQQDDA9pZHAub2tzdGF0ZS5lZHUxIzAhBgkq\nhkiG9w0BCQEWFGhlbHBkZXNrQG9rc3RhdGUuZWR1MIIBIjANBgkqhkiG9w0BAQEF\nAAOCAQ8AMIIBCgKCAQEAwXKsNMBp5tdIbc1ZYbWy3AIKP3FbTjwLt8JU8Or5fnyg\nyOAxWZ9qSkaEoUNEJ+hF3pddckzdDoFXFu/iT5iNXSkb0fu1Z3TIq2L8ORzRuXmu\nXKaVjCzejeeitlyE9yDvXFQjT+Nvhi4j9PLzZ6cC6KW/fnOIdzrYUd1Gmrbu9bxe\nUXZKOn3u8foDeNmoG7WtmXwOhz8NemtMcEZ1L0VZugPqWQtyxCO7x3TeYwuS/4Te\nM+IqYeezWRhfsk7Vpamtgbfi9VMylC3cquE5f5/P24mp1AQuly81KZ9TZh4A9Mz6\nxUZfV7d+xQlQLimOmd5lXM1En4VhmPFfyfS7s1fWiwIDAQABMA0GCSqGSIb3DQEB\nBQUAA4IBAQC48jGan3mFH74r9/cDM44TbmS1LoNbe4ybvI50MgzvV055JRF/nVyf\n5oXYMTytnUCw8xh5IbQbbZnnxN1oJUD7CDcJ3j0alKx8/wsUQeCBnS5LN/WeBiRO\n0fEwOi5tmz7n0O6wQbu9psFPG2yl5Khj/jHYRVxQXwMoBMmrpxUG5Ha0UAoIPM8X\nQWUdAUmhN1oD6YxKK3Bf9pQ2Sinafdsc4k54wvfMZCQkH1f37Pll/cSQCSFxEDKX\nIUS69CJRUBfftvG82kYGdEO5y+FAWBuLyya32MVwWKzHOqh6Q0iTbgEsfWsQL7KU\naVziUIOjv/nrHap+xcHajNL7CKlXwKQ4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idp.okstate.edu/identity/feedback.htm"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Oklahoma State University System"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://osu.okstate.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Oklahoma State University Main Campus"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://bodportal.geant.net/autobahn-gui",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it@geant.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "G\u00c9ANT IT"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it@geant.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "G\u00c9ANT IT"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bodportal.geant.net/autobahn-gui",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-09-17T13:37:01Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "G\u00c9ANT Limited"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dante.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "G\u00c9ANT Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "response_location": "https://bodportal.geant.net/autobahn-gui/saml/LogoutServiceHTTPRedirectResponse",
              "location": "https://bodportal.geant.net/autobahn-gui/saml/LogoutServiceHTTPRedirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "A Portal that can be used to access the BoD service for requesting circuit reservations, tracking their status and for administrative operation"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "BoD Portal"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKjCCAhKgAwIBAgIJAJDmGErGOKVvMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\n\t\t\t\t\t\tBAMTE2JvZHBvcnRhbC5nZWFudC5uZXQwHhcNMTQwNDExMTUxMDE1WhcNMTcwNDEx\n\t\t\t\t\t\tMTUxMDE1WjAeMRwwGgYDVQQDExNib2Rwb3J0YWwuZ2VhbnQubmV0MIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAx+u+ncMfh9UiMVWMm38eNH38kSQxGs53\n\t\t\t\t\t\tYrgmXl2bJWx1cbDseJ28IIKa3xyR7kIDdGBSKgR9/+dcqmA0jitnQNkc0AxWO/SE\n\t\t\t\t\t\tFt9NXOWGPt8db1BuFD2DKtNnaqL5pxUFvv8ZvVtThf0cTWtbJXr9Fqscavh67Xs5\n\t\t\t\t\t\th8ZVV/PKJkWzI+MwNNZA4zY/XmlWgFj0JyOoNjKRj0CYdbAO9nxjDvglZBaBZhTL\n\t\t\t\t\t\tyUFPKFK9PYhvCDGidE6vntyN0IerZR5CVZ4UVB4RpnxhbZJKz2ahDGYDMd7ALOGl\n\t\t\t\t\t\tXVgbVZIEy1UaWSVw85hB3YolynSIDgQGMikPkm9Ob/p9MNqDSyzpyQIDAQABo2sw\n\t\t\t\t\t\taTBIBgNVHREEQTA/ghNib2Rwb3J0YWwuZ2VhbnQubmV0hihodHRwczovL2JvZHBv\n\t\t\t\t\t\tcnRhbC5nZWFudC5uZXQvYXV0b2JhaG4tZ3VpMB0GA1UdDgQWBBSYqysjUZVqc/9I\n\t\t\t\t\t\tLTMJw82mQm3zsTANBgkqhkiG9w0BAQUFAAOCAQEAh6tU+wzIMqNY47LypNVtdyZY\n\t\t\t\t\t\tlLCWA5zLnspGrAZoHkiQWgD9ci7J/WBswCdrs/lSJ170u+CiBulzCNgp3c+z2mlq\n\t\t\t\t\t\t6snJQNApKtE7JOOXXm7QiBmIeKycfmtkznSAfjQGjlfpIY/qmEPTljJQrj1cl0nH\n\t\t\t\t\t\t7mHxBTgN/YlZj2H7XQZRQZMw5Y63exLyOzD38kGxt+dUUi07cGHenGHs7y7aPKZi\n\t\t\t\t\t\tdTpN+ziSFq2kMwKJikMGPFrs84/iYCJxedloJqCXljGD5SMq4k5E4m36LpOyhduX\n\t\t\t\t\t\t5Xv78mo22p+fa22GBf1a6s/flNWU8+CrOWGHHGO3mvNuS0wMHid3D5dSEk8cLw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKjCCAhKgAwIBAgIJAJDmGErGOKVvMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\n\t\t\t\t\t\tBAMTE2JvZHBvcnRhbC5nZWFudC5uZXQwHhcNMTQwNDExMTUxMDE1WhcNMTcwNDEx\n\t\t\t\t\t\tMTUxMDE1WjAeMRwwGgYDVQQDExNib2Rwb3J0YWwuZ2VhbnQubmV0MIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAx+u+ncMfh9UiMVWMm38eNH38kSQxGs53\n\t\t\t\t\t\tYrgmXl2bJWx1cbDseJ28IIKa3xyR7kIDdGBSKgR9/+dcqmA0jitnQNkc0AxWO/SE\n\t\t\t\t\t\tFt9NXOWGPt8db1BuFD2DKtNnaqL5pxUFvv8ZvVtThf0cTWtbJXr9Fqscavh67Xs5\n\t\t\t\t\t\th8ZVV/PKJkWzI+MwNNZA4zY/XmlWgFj0JyOoNjKRj0CYdbAO9nxjDvglZBaBZhTL\n\t\t\t\t\t\tyUFPKFK9PYhvCDGidE6vntyN0IerZR5CVZ4UVB4RpnxhbZJKz2ahDGYDMd7ALOGl\n\t\t\t\t\t\tXVgbVZIEy1UaWSVw85hB3YolynSIDgQGMikPkm9Ob/p9MNqDSyzpyQIDAQABo2sw\n\t\t\t\t\t\taTBIBgNVHREEQTA/ghNib2Rwb3J0YWwuZ2VhbnQubmV0hihodHRwczovL2JvZHBv\n\t\t\t\t\t\tcnRhbC5nZWFudC5uZXQvYXV0b2JhaG4tZ3VpMB0GA1UdDgQWBBSYqysjUZVqc/9I\n\t\t\t\t\t\tLTMJw82mQm3zsTANBgkqhkiG9w0BAQUFAAOCAQEAh6tU+wzIMqNY47LypNVtdyZY\n\t\t\t\t\t\tlLCWA5zLnspGrAZoHkiQWgD9ci7J/WBswCdrs/lSJ170u+CiBulzCNgp3c+z2mlq\n\t\t\t\t\t\t6snJQNApKtE7JOOXXm7QiBmIeKycfmtkznSAfjQGjlfpIY/qmEPTljJQrj1cl0nH\n\t\t\t\t\t\t7mHxBTgN/YlZj2H7XQZRQZMw5Y63exLyOzD38kGxt+dUUi07cGHenGHs7y7aPKZi\n\t\t\t\t\t\tdTpN+ziSFq2kMwKJikMGPFrs84/iYCJxedloJqCXljGD5SMq4k5E4m36LpOyhduX\n\t\t\t\t\t\t5Xv78mo22p+fa22GBf1a6s/flNWU8+CrOWGHHGO3mvNuS0wMHid3D5dSEk8cLw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://bodportal.geant.net/autobahn-gui/saml/SAMLAssertionConsumer",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bodportal.geant.net/autobahn-gui/saml/SAMLAssertionConsumer",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "BoD Portal"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "A Portal that can be used to access the BoD service for requesting circuit reservations, tracking their status and for administrative operation"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.images.group.cam.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:falcon-support@ucs.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Falcon Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:falcon-support@ucs.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Falcon Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.images.group.cam.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-11-05T14:38:03Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The University of Cambridge IMAGES Network"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.images.group.cam.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Cambridge"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.images.group.cam.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.images.group.cam.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.images.group.cam.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.images.group.cam.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.images.group.cam.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.images.group.cam.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.images.group.cam.ac.uk/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.images.group.cam.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.images.group.cam.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAOB8D/FajzX8MA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHd3dy1mYWxjb24uY3N4LmNhbS5hYy51azAeFw0xMDAxMTgxMTAwMDdaFw0y\n\t\t\t\t\t\tMDAxMTYxMTAwMDdaMCMxITAfBgNVBAMTGHd3dy1mYWxjb24uY3N4LmNhbS5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKpU2AuemKJSIeDmgjkZ\n\t\t\t\t\t\ttPgKaPPkM5CKu3QUHm5JzmtnG3UFMxbOumt6sxWWF72ceXQNPgBNGqFI/sFdaCIo\n\t\t\t\t\t\tHxZj+Z2i+k7/IVXhc4wjs72YUfrjvTMDhHHzndm3KkJS8imsIYQ8/bBnJEF93zVJ\n\t\t\t\t\t\tgPYTrX1C8JxqF/wfY/XCGbEqHgJtqDrSEvK+vLF7LaYI4oTotZOg/vhN7uwaEa7n\n\t\t\t\t\t\tGU2+bKuhcAL+rolEM6sbdrQAj3KarTafacfh9IiAclzyOQTA6pfjFWrucNIuWXc4\n\t\t\t\t\t\tYhaEPyOMubMsp+0eXZAwEPTJ61x+nQZd3UAf7Rm5v7agrzRAdqdwpnqb4yyprJlI\n\t\t\t\t\t\t+lkCAwEAAaNGMEQwIwYDVR0RBBwwGoIYd3d3LWZhbGNvbi5jc3guY2FtLmFjLnVr\n\t\t\t\t\t\tMB0GA1UdDgQWBBTz/ES/EvNaSsqqXUxLuIFc9YHi/TANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAAvFTJS2L6StZuqKA935AD3bBOHe5pg+LCF6ydHdTuyWEJYIWBRJ1WXsKMyaG\n\t\t\t\t\t\tyvdlX60XziJARq2UiYxt4yRjuGLAjQl9kNdrlqeb2AJFnA5E1Mt56FtzPiwu2zrC\n\t\t\t\t\t\tTQlklC4Xfie1Yaw2kEVO2vAoRfg9bgSBfyvFC4oR3vCery3Z687oCeQqDp7LPRcn\n\t\t\t\t\t\t+k5qQD8pout57IYzwyo7GPeVkYEPb3GO2KYmoENlDR/xah2VcsTZF7aIsMBFxaPv\n\t\t\t\t\t\tO+oqrQcnQXTviY9yWLbAlSrPPqGNYDxayVHn+zDSO4scLlOoqZJ8iC5NboNKqFyB\n\t\t\t\t\t\tRsenNm/aXp0wIU+jHVmi/GAPCQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.images.group.cam.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.images.group.cam.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.images.group.cam.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.images.group.cam.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.images.group.cam.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.images.group.cam.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.images.group.cam.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.images.group.cam.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.images.group.cam.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.images.group.cam.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.bfi.org.uk/inview/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:online.support@bfi.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Online Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:online.technical@bfi.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Online Technical"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.bfi.org.uk/inview/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-03-09T17:30:12Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "British Film Institute: BFI InView"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bfi.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "British Film Institute"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.bfi.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.bfi.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.bfi.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.bfi.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3zCCAcegAwIBAgIJAJCZAVBpmy3YMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\n\t\t\t\t\t\tBAMTCHJvYmluc29uMB4XDTA5MTAwMTE0MTA0NFoXDTE5MDkyOTE0MTA0NFowEzER\n\t\t\t\t\t\tMA8GA1UEAxMIcm9iaW5zb24wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQC8gOXUZXEl3AdPbrI44ra8gDLytogk10Iu3DSwv56II/tF+yPcfUeT2sLRSOZG\n\t\t\t\t\t\tzqrAMBBsgJlCv1GEq94ybtdjjIJvPTzOp3IMPQkQU3SBZnq05rGLvsIgYyu4yg8z\n\t\t\t\t\t\t4MWit9JDCyQjRLZ/ayVUog1Xh4Q1Ml/Rv3BAeSHxtjjE7TaXQ9UjM9ebJ42wCjEp\n\t\t\t\t\t\t9swilxUA1OU+vJOpbcP6VVhBxe6ZstCNtEHeCnTDZtNJW2PIJaL2MopRPx7MqiV6\n\t\t\t\t\t\t+ySSkDc/u/UaepNTwgtfIHK7GFD62PilOrlS/PE73MVlUK7sLfJFaMYIUzaNxzUd\n\t\t\t\t\t\thcRJRaqPkKtgTkM2ph6vC+tPAgMBAAGjNjA0MBMGA1UdEQQMMAqCCHJvYmluc29u\n\t\t\t\t\t\tMB0GA1UdDgQWBBT5snOaM5DTvRHkjANs/TyJcZ7zLTANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAXuGwikXA4QCegNWBpXH0Rz/0scLjRLYKELH+oJPJkaw2PdTjRspiq1a6npJ/\n\t\t\t\t\t\tstBZnAA+P1Uv8z2P1V9ZJKnu1r3H/Ud16nTYohZE/xvLojjo8lI9xE16PMr2yYyO\n\t\t\t\t\t\tn+NJ3zBlTltEVI7e49iS0yxVDrbfOVyZJvtXvAxx+Lg+zQI2v5UT0qnxtzOKdavI\n\t\t\t\t\t\tPrf8Iq9rlOp3e21QQxTXdxAB3eGwne2r9xRphIicUq2l2beiCWP/7xrBs9HIxC1c\n\t\t\t\t\t\t3CIwNpT/P4STvqGoRTAoioiBoZycIY3GCaV57iTiT6eN0aEXWwwZX3uoqhd6H2tS\n\t\t\t\t\t\t8Q3adyi7hXpgTa3/E7CprovtpQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3zCCAcegAwIBAgIJAJCZAVBpmy3YMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\n\t\t\t\t\t\tBAMTCHJvYmluc29uMB4XDTA5MTAwMTE0MTA0NFoXDTE5MDkyOTE0MTA0NFowEzER\n\t\t\t\t\t\tMA8GA1UEAxMIcm9iaW5zb24wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQC8gOXUZXEl3AdPbrI44ra8gDLytogk10Iu3DSwv56II/tF+yPcfUeT2sLRSOZG\n\t\t\t\t\t\tzqrAMBBsgJlCv1GEq94ybtdjjIJvPTzOp3IMPQkQU3SBZnq05rGLvsIgYyu4yg8z\n\t\t\t\t\t\t4MWit9JDCyQjRLZ/ayVUog1Xh4Q1Ml/Rv3BAeSHxtjjE7TaXQ9UjM9ebJ42wCjEp\n\t\t\t\t\t\t9swilxUA1OU+vJOpbcP6VVhBxe6ZstCNtEHeCnTDZtNJW2PIJaL2MopRPx7MqiV6\n\t\t\t\t\t\t+ySSkDc/u/UaepNTwgtfIHK7GFD62PilOrlS/PE73MVlUK7sLfJFaMYIUzaNxzUd\n\t\t\t\t\t\thcRJRaqPkKtgTkM2ph6vC+tPAgMBAAGjNjA0MBMGA1UdEQQMMAqCCHJvYmluc29u\n\t\t\t\t\t\tMB0GA1UdDgQWBBT5snOaM5DTvRHkjANs/TyJcZ7zLTANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAXuGwikXA4QCegNWBpXH0Rz/0scLjRLYKELH+oJPJkaw2PdTjRspiq1a6npJ/\n\t\t\t\t\t\tstBZnAA+P1Uv8z2P1V9ZJKnu1r3H/Ud16nTYohZE/xvLojjo8lI9xE16PMr2yYyO\n\t\t\t\t\t\tn+NJ3zBlTltEVI7e49iS0yxVDrbfOVyZJvtXvAxx+Lg+zQI2v5UT0qnxtzOKdavI\n\t\t\t\t\t\tPrf8Iq9rlOp3e21QQxTXdxAB3eGwne2r9xRphIicUq2l2beiCWP/7xrBs9HIxC1c\n\t\t\t\t\t\t3CIwNpT/P4STvqGoRTAoioiBoZycIY3GCaV57iTiT6eN0aEXWwwZX3uoqhd6H2tS\n\t\t\t\t\t\t8Q3adyi7hXpgTa3/E7CprovtpQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.bfi.org.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.bfi.org.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.bfi.org.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.bfi.org.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.bfi.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.bfi.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.bfi.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.bfi.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.bfi.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.bfi.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://studentstore.phoenixs.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Leighton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Gary-Leighton@phoenixs.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gary"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Leighton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Gary-Leighton@phoenixs.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gary"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://studentstore.phoenixs.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2012-08-10T11:56:28Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Phoenix Student Store"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.phoenixs.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Phoenix Software Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://studentstore.phoenixs.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://studentstore.phoenixs.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://studentstore.phoenixs.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://studentstore.phoenixs.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://studentstore.phoenixs.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://studentstore.phoenixs.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://studentstore.phoenixs.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIJAMKtTUHoN0LYMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\n\t\t\t\t\t\tBAMTG3N0dWRlbnRzdG9yZS5waG9lbml4cy5jby51azAeFw0xMjA4MDkxNTMxMTBa\n\t\t\t\t\t\tFw0yMjA4MDcxNTMxMTBaMCYxJDAiBgNVBAMTG3N0dWRlbnRzdG9yZS5waG9lbml4\n\t\t\t\t\t\tcy5jby51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMiA8DdoMw8u\n\t\t\t\t\t\tn7QMtSDz2zi+fHPDrKb3/a2NtSCQh2TXIpN4uARHv3hpsHcbUmEDr2gIK0KTE1nW\n\t\t\t\t\t\tVD4ZrNqCiWBvWc9cf8sgUoYntcL9nXqwEfvoCtdw5jY6IzLj92hiH/TrkSFXL1Y7\n\t\t\t\t\t\tfW53pwaNjTo1Rck8c5Um1eKH+hNWwB1/jKVAlTsyr56c3t39FBNahlAxB3OoL4+6\n\t\t\t\t\t\tlPax1SXvugowfh7F7yWxCSIaKzAGXw75ml8jE0bo52jz+Zxk4Mmz8xDYjQ3+Itm1\n\t\t\t\t\t\tPZ94WymMTiRpKM0HLqH3s6ExKKHm08ahAwvDEz7hxSXna6iozFaQGxFNXD8J0lXM\n\t\t\t\t\t\tVJfYjJMmgscCAwEAAaN5MHcwVgYDVR0RBE8wTYIbc3R1ZGVudHN0b3JlLnBob2Vu\n\t\t\t\t\t\taXhzLmNvLnVrhi5odHRwczovL3N0dWRlbnRzdG9yZS5waG9lbml4cy5jby51ay9z\n\t\t\t\t\t\taGliYm9sZXRoMB0GA1UdDgQWBBSYHv7Z/DKteKW3DlKVYW5oR/QawzANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAvkuWNy9+6h2kW77zyBfAOiNAkfhUQJhLbKnT8pLf+WWUH8os\n\t\t\t\t\t\tK/U6TL8py/ReOLMIeIPMSLzDD4ZcXt029E1zoIo0XddRfpY/ts/zYvCSKvyV7Djm\n\t\t\t\t\t\t6+dTy9zWotpj6u8EG7/NwyqQ9T3p59HXaJCJnqFOgqfdyuxbQqpJKNkMTBnU9Lsn\n\t\t\t\t\t\t5/yTTiGVjO+kQJ4DqMBDIIXuxfOOLpnYEJpjRUkrGWqOiLvPUuOp6N+p7YOaof8+\n\t\t\t\t\t\tpMO1+iiqwJHHCnZnmAStXECu/j1i6BIvFX0bdK9imOuA+euujEfCf3E6evJvsCeu\n\t\t\t\t\t\tgYsJPfcJiOV+ZzJTGZE2VhUvF3MAeThxL44KmQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://studentstore.phoenixs.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://studentstore.phoenixs.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://studentstore.phoenixs.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://studentstore.phoenixs.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://studentstore.phoenixs.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://studentstore.phoenixs.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.kva.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:peter.jacobsson@kva.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "The Royal Swedish Academy of Sciences"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 70 6739792"
            }
          ]
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:peter.jacobsson@kva.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "The Royal Swedish Academy of Sciences"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 70 6739792"
            }
          ]
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:peter.jacobsson@kva.se"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "The Royal Swedish Academy of Sciences"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+46 70 6739792"
            }
          ]
        }
      ],
      "entity_id": "https://idp.kva.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAIEMcH8g/qilWjlQSS0EYqY8O3hnMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC5rdmEuc2UwHhcNMTMwNjExMTIwMzU2WhcNMzMw\nNjExMTIwMzU2WjAVMRMwEQYDVQQDEwppZHAua3ZhLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAhbLQb03KVvHFPZlmohpzwmr6tY7dZCKSRTdfoSpu\nfT6BykDryqo0vg8pSBWghkiFZQr1V36qdK0XUFNAtFEGTtlXyI+PDvtGLTzg2Swb\n9nxpwsXAxRUD1v/2SNUTxQW7O0t4jdZKxGcOEIDO8YHOpV0imw2v+tqzyr8MgwfE\nSSBV3ESUtHmDFvhanEp/TNsT6K8Y1IFqQzHCvNKV1WGW2vEKCjnwmMNd5N55cQrO\nfoWCeC7BJhm7dKrzk0WzSZLrX1PtitHB7Ms705x7XRWw1Inbp5jd56ONJ7sZXqpi\n4eb9wVovrZMqcBc/h4GPZN9WTACvfHUKvQ0N0lfzhUuKdQIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAua3ZhLnNlhiFodHRwczovL2lkcC5rdmEuc2UvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFKpM1lN1+VbR8w+sZ1O3g4Lc0SIxMA0GCSqGSIb3DQEB\nBQUAA4IBAQB+22vGRTKJyRGh5lHVyk0NXWjc8aRAdntepCR+Yy17HB1P4lBSlewS\nbHuDhu7hHp9ItJWJryhkO4F1c+RjELnGf++WvM3Fv05AIV3x0lh/Kxs9X2f4KYBI\nSa4XUUgl3lbrTI9H0Mse59OK4jz5LRF35OWihdoCNiRaKVjrRmMTZKrxBTJ5gSvf\nULOTA8+dCegP7Q4xnGmN2M8PfO6Lp6BQh2LaaBt4qDGUytMnclKUhDXpasr/oUfB\nbS0T9qUjP0Djkv1HcffkxHJd9mbHMv4MiQjScE4Gwy4+6PPOO5a/3Q7JoGSbdVfm\ny8hIAGqbY/OdUQkJXj68rm5qr6pGjBEq"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kva.se"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.kva.se:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.kva.se:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.kva.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.kva.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.kva.se/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.kva.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.kva.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.kva.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kva.se"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r Kungliga Vetenskapsakademien"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for the Royal Swedish Academy of Sciences"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.kva.se/idp/images/headerLogo.gif",
                    "height": "78",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "179"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kungliga Vetenskapsakademien"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The Royal Swedish Academy of Sciences"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "kva.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:59.36542,18.05204"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.242.20.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAIEMcH8g/qilWjlQSS0EYqY8O3hnMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC5rdmEuc2UwHhcNMTMwNjExMTIwMzU2WhcNMzMw\nNjExMTIwMzU2WjAVMRMwEQYDVQQDEwppZHAua3ZhLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAhbLQb03KVvHFPZlmohpzwmr6tY7dZCKSRTdfoSpu\nfT6BykDryqo0vg8pSBWghkiFZQr1V36qdK0XUFNAtFEGTtlXyI+PDvtGLTzg2Swb\n9nxpwsXAxRUD1v/2SNUTxQW7O0t4jdZKxGcOEIDO8YHOpV0imw2v+tqzyr8MgwfE\nSSBV3ESUtHmDFvhanEp/TNsT6K8Y1IFqQzHCvNKV1WGW2vEKCjnwmMNd5N55cQrO\nfoWCeC7BJhm7dKrzk0WzSZLrX1PtitHB7Ms705x7XRWw1Inbp5jd56ONJ7sZXqpi\n4eb9wVovrZMqcBc/h4GPZN9WTACvfHUKvQ0N0lfzhUuKdQIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAua3ZhLnNlhiFodHRwczovL2lkcC5rdmEuc2UvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFKpM1lN1+VbR8w+sZ1O3g4Lc0SIxMA0GCSqGSIb3DQEB\nBQUAA4IBAQB+22vGRTKJyRGh5lHVyk0NXWjc8aRAdntepCR+Yy17HB1P4lBSlewS\nbHuDhu7hHp9ItJWJryhkO4F1c+RjELnGf++WvM3Fv05AIV3x0lh/Kxs9X2f4KYBI\nSa4XUUgl3lbrTI9H0Mse59OK4jz5LRF35OWihdoCNiRaKVjrRmMTZKrxBTJ5gSvf\nULOTA8+dCegP7Q4xnGmN2M8PfO6Lp6BQh2LaaBt4qDGUytMnclKUhDXpasr/oUfB\nbS0T9qUjP0Djkv1HcffkxHJd9mbHMv4MiQjScE4Gwy4+6PPOO5a/3Q7JoGSbdVfm\ny8hIAGqbY/OdUQkJXj68rm5qr6pGjBEq"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Kungliga Vetenskapsakademien"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Royal Swedish Academy of Sciences"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kva.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "KVA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://adfs.stenden.com/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs.stenden.com/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-06-01T09:26:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/ef5e1f05a6c81593b3167fc71dfbb001",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Stenden Hogeschool"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Stenden Hogeschool"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/stenden.png",
                    "height": "300",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "427"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Stenden Hogeschool"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Stenden Hogeschool"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Stenden Hogeschool"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.stenden.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Stenden Hogeschool"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.solihull.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Stebbens"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ian.stebbens@solihull.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gartside"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dave.gartside@solihull.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.solihull.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-11-26T11:41:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID3jCCAsagAwIBAgIJAM+AyetIYqR6MA0GCSqGSIb3DQEBBQUAMHAxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRYwFAYDVQQIEw1XZXN0IE1pZGxhbmRzMREwDwYDVQQHEwhTb2xpaHVs\n\t\t\t\t\t\tbDEZMBcGA1UEChMQU29saWh1bGwgQ29sbGVnZTEbMBkGA1UEAxMSaWRwLnNvbGlo\n\t\t\t\t\t\tdWxsLmFjLnVrMB4XDTEzMTAxNjA5MTQwMVoXDTIzMTAxNDA5MTQwMVowcDELMAkG\n\t\t\t\t\t\tA1UEBhMCR0IxFjAUBgNVBAgTDVdlc3QgTWlkbGFuZHMxETAPBgNVBAcTCFNvbGlo\n\t\t\t\t\t\tdWxsMRkwFwYDVQQKExBTb2xpaHVsbCBDb2xsZWdlMRswGQYDVQQDExJpZHAuc29s\n\t\t\t\t\t\taWh1bGwuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC47smk\n\t\t\t\t\t\tB99t094xtfCf+qH4QtyW2PcThLbj+Kco0Fb/beVYidk/dunhQEO1I59uVfIlXOb6\n\t\t\t\t\t\tPcx6HmlV6kSN73xn0sruLBNOpQta1C5dpqaKkgJViezo7O6QbbJUgl1u2HJk9kiw\n\t\t\t\t\t\ttkOXh5pZKCgQqEI/Q3K9OKbv5RZHxatWouqGKAUeu8wPGnNeh9KkVbFqqc8DA1sl\n\t\t\t\t\t\taC4o4x4+3bgy9Jznbcbo7/jbnhLEvQgdZG0B1RdYL/R+B9cxPnz4ZcBPBkK81RG4\n\t\t\t\t\t\t9niQvrcaN5iUPk1DPxRj7qzaVl6OfWhyoh8coEH0JWgXiuEei0Pkm/Fm2oNp/Yea\n\t\t\t\t\t\tczrgbLyA3GaRtPsxAgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8W\n\t\t\t\t\t\tHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBQe665e7YLT\n\t\t\t\t\t\tF8ETkmhxSKGabAUIIzAfBgNVHSMEGDAWgBQe665e7YLTF8ETkmhxSKGabAUIIzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAFOHMzUyPPADOrALVV5CAnIOpb0W02YMl8ZwLaftH\n\t\t\t\t\t\t7aUtbL4aYSek3lO55aR6+QcEiBl9wSXHl0uPLaiC8Dmq1KJmlf5LUEj965bUE/Cu\n\t\t\t\t\t\ts5R6g3El1/SV3J8NUMsMJMq3H/6uDeZBAEXicFSKGwvt9MCv9PohWNB1JRzuGlIA\n\t\t\t\t\t\tY5878PvOuNY886Yz6McIIlAlYLtSh8nDPv0ULf/U/P5H3R3vYD8hn9sYFO8h5OrA\n\t\t\t\t\t\tmvdU+n4JipEfEVM2GgPtgov6Fj5D5+qVj6UzJa6FF8PEXcGrFoSmUO0TSGee0qXm\n\t\t\t\t\t\tKHpoixwcL60Mgq6hMlXKmT7Vs0IMQzx/FImSMNwaJDmy8Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "solihull.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.solihull.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.solihull.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.solihull.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.solihull.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.solihull.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.solihull.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.solihull.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.solihull.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "solihull.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID3jCCAsagAwIBAgIJAM+AyetIYqR6MA0GCSqGSIb3DQEBBQUAMHAxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRYwFAYDVQQIEw1XZXN0IE1pZGxhbmRzMREwDwYDVQQHEwhTb2xpaHVs\n\t\t\t\t\t\tbDEZMBcGA1UEChMQU29saWh1bGwgQ29sbGVnZTEbMBkGA1UEAxMSaWRwLnNvbGlo\n\t\t\t\t\t\tdWxsLmFjLnVrMB4XDTEzMTAxNjA5MTQwMVoXDTIzMTAxNDA5MTQwMVowcDELMAkG\n\t\t\t\t\t\tA1UEBhMCR0IxFjAUBgNVBAgTDVdlc3QgTWlkbGFuZHMxETAPBgNVBAcTCFNvbGlo\n\t\t\t\t\t\tdWxsMRkwFwYDVQQKExBTb2xpaHVsbCBDb2xsZWdlMRswGQYDVQQDExJpZHAuc29s\n\t\t\t\t\t\taWh1bGwuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC47smk\n\t\t\t\t\t\tB99t094xtfCf+qH4QtyW2PcThLbj+Kco0Fb/beVYidk/dunhQEO1I59uVfIlXOb6\n\t\t\t\t\t\tPcx6HmlV6kSN73xn0sruLBNOpQta1C5dpqaKkgJViezo7O6QbbJUgl1u2HJk9kiw\n\t\t\t\t\t\ttkOXh5pZKCgQqEI/Q3K9OKbv5RZHxatWouqGKAUeu8wPGnNeh9KkVbFqqc8DA1sl\n\t\t\t\t\t\taC4o4x4+3bgy9Jznbcbo7/jbnhLEvQgdZG0B1RdYL/R+B9cxPnz4ZcBPBkK81RG4\n\t\t\t\t\t\t9niQvrcaN5iUPk1DPxRj7qzaVl6OfWhyoh8coEH0JWgXiuEei0Pkm/Fm2oNp/Yea\n\t\t\t\t\t\tczrgbLyA3GaRtPsxAgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8W\n\t\t\t\t\t\tHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBQe665e7YLT\n\t\t\t\t\t\tF8ETkmhxSKGabAUIIzAfBgNVHSMEGDAWgBQe665e7YLTF8ETkmhxSKGabAUIIzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAFOHMzUyPPADOrALVV5CAnIOpb0W02YMl8ZwLaftH\n\t\t\t\t\t\t7aUtbL4aYSek3lO55aR6+QcEiBl9wSXHl0uPLaiC8Dmq1KJmlf5LUEj965bUE/Cu\n\t\t\t\t\t\ts5R6g3El1/SV3J8NUMsMJMq3H/6uDeZBAEXicFSKGwvt9MCv9PohWNB1JRzuGlIA\n\t\t\t\t\t\tY5878PvOuNY886Yz6McIIlAlYLtSh8nDPv0ULf/U/P5H3R3vYD8hn9sYFO8h5OrA\n\t\t\t\t\t\tmvdU+n4JipEfEVM2GgPtgov6Fj5D5+qVj6UzJa6FF8PEXcGrFoSmUO0TSGee0qXm\n\t\t\t\t\t\tKHpoixwcL60Mgq6hMlXKmT7Vs0IMQzx/FImSMNwaJDmy8Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Solihull College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.solihull.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Solihull College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://minosse.unime.it/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Admin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idp@unime.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IDP"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://minosse.unime.it/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2015-05-25T10:40:44Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://minosse.unime.it/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://minosse.unime.it/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unime.it"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "studenti.unime.it"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ospiti.unime.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unime.it/ciam_a_villari/_servizi/-27798.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unime.it/ciam_a_villari/_servizi/-27798.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IDP University of Messina"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IDP Universit\u00e0 degli Studi di Messina"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for University of Messina users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti dell'Universit\u00e0 degli Studi di Messina"
                  }
                ],
                "logo": [
                  {
                    "text": "https://minosse.unime.it/logo2.png",
                    "lang": "it",
                    "height": "61",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "61"
                  },
                  {
                    "text": "https://minosse.unime.it/logo2.png",
                    "lang": "en",
                    "height": "61",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "61"
                  },
                  {
                    "text": "https://minosse.unime.it/logo1.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://minosse.unime.it/logo1.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.unime.it/ciam_a_villari/_servizi/-27792.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.unime.it/ciam_a_villari/_servizi/-27792.html"
                  }
                ]
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:36.597889,16.875000"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEETCCAvmgAwIBAgIJAJv/7OTrVdPFMA0GCSqGSIb3DQEBBQUAMIGeMQswCQYD\nVQQGEwJJVDEOMAwGA1UECAwFSXRhbHkxEDAOBgNVBAcMB01lc3NpbmExHjAcBgNV\nBAoMFVVuaXZlcnNpdHkgb2YgTWVzc2luYTENMAsGA1UECwwEQ0lBTTEZMBcGA1UE\nAwwQbWlub3NzZS51bmltZS5pdDEjMCEGCSqGSIb3DQEJARYUaWRwQG1pbm9zc2Uu\ndW5pbWUuaXQwHhcNMTQxMDI4MTAzOTA2WhcNMjQxMDI3MTAzOTA2WjCBnjELMAkG\nA1UEBhMCSVQxDjAMBgNVBAgMBUl0YWx5MRAwDgYDVQQHDAdNZXNzaW5hMR4wHAYD\nVQQKDBVVbml2ZXJzaXR5IG9mIE1lc3NpbmExDTALBgNVBAsMBENJQU0xGTAXBgNV\nBAMMEG1pbm9zc2UudW5pbWUuaXQxIzAhBgkqhkiG9w0BCQEWFGlkcEBtaW5vc3Nl\nLnVuaW1lLml0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzE/VfNGT\nVppi3fdQvRBuv7dK89X2U0tjm97tY+YsM9+1Rucp1jMAtQLhufi4/YV5INUqoee5\nVKNmPlpXreDv1avkzPyJ9JNaYrfp2R82zU0QNzedDmem1OIwNSrRWrBn6q+dX0az\n6ZrU0FIOqotpGEcR2duERg7oj2PTF3artDUWPDCrAEk8xiSlKNmrvgqub9v5i2pm\nouh/In4tntRPLqctUoGFnX4A/7k3As7avQibRy5CLp0IosjKzKZXcGKPE+iJWL5M\nq5jY3C0cu4gSEXLunv3E+5/M/dx6M/D+89OMgP7YtIE/6KCMaAlv9fbWVE5A0fCK\nQ6NKLAiZKpRjhQIDAQABo1AwTjAdBgNVHQ4EFgQURgj0qpHyI0g/Z/uAs5TJhOOX\ncQgwHwYDVR0jBBgwFoAURgj0qpHyI0g/Z/uAs5TJhOOXcQgwDAYDVR0TBAUwAwEB\n/zANBgkqhkiG9w0BAQUFAAOCAQEAXTQPUKjVoqCXULCczpNyUFwq7k52toMIVsC5\n8bSb0SphuJpmBvI89L1BW8Qqd/etHn086ysTXT8cha9OV0qPatfEwUjxF7OFUmWA\nuJtL23h+6lFjJl+gg3W1LiBV722ssH/K86fBUijpGy9e6tDTb/gJKoVy3L3FGp1e\nwCu9/tEnLXz2Kf120i17a67NwuN19QH8+wFVJYNPAlzK7dMZcvzWXVK5jxNNdZ0U\n9Mr3Wb/FYQcDOucIrYdThh9//RbRTH0JMmbYhOiYXteJKOYreSwqGlZJLmfOExYx\nEXjRmsJ4xyedzAlUmmUj0WNkBA1fYmVhJ1JZqU+uRTgvL2QcPQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEETCCAvmgAwIBAgIJAJv/7OTrVdPFMA0GCSqGSIb3DQEBBQUAMIGeMQswCQYD\nVQQGEwJJVDEOMAwGA1UECAwFSXRhbHkxEDAOBgNVBAcMB01lc3NpbmExHjAcBgNV\nBAoMFVVuaXZlcnNpdHkgb2YgTWVzc2luYTENMAsGA1UECwwEQ0lBTTEZMBcGA1UE\nAwwQbWlub3NzZS51bmltZS5pdDEjMCEGCSqGSIb3DQEJARYUaWRwQG1pbm9zc2Uu\ndW5pbWUuaXQwHhcNMTQxMDI4MTAzOTA2WhcNMjQxMDI3MTAzOTA2WjCBnjELMAkG\nA1UEBhMCSVQxDjAMBgNVBAgMBUl0YWx5MRAwDgYDVQQHDAdNZXNzaW5hMR4wHAYD\nVQQKDBVVbml2ZXJzaXR5IG9mIE1lc3NpbmExDTALBgNVBAsMBENJQU0xGTAXBgNV\nBAMMEG1pbm9zc2UudW5pbWUuaXQxIzAhBgkqhkiG9w0BCQEWFGlkcEBtaW5vc3Nl\nLnVuaW1lLml0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzE/VfNGT\nVppi3fdQvRBuv7dK89X2U0tjm97tY+YsM9+1Rucp1jMAtQLhufi4/YV5INUqoee5\nVKNmPlpXreDv1avkzPyJ9JNaYrfp2R82zU0QNzedDmem1OIwNSrRWrBn6q+dX0az\n6ZrU0FIOqotpGEcR2duERg7oj2PTF3artDUWPDCrAEk8xiSlKNmrvgqub9v5i2pm\nouh/In4tntRPLqctUoGFnX4A/7k3As7avQibRy5CLp0IosjKzKZXcGKPE+iJWL5M\nq5jY3C0cu4gSEXLunv3E+5/M/dx6M/D+89OMgP7YtIE/6KCMaAlv9fbWVE5A0fCK\nQ6NKLAiZKpRjhQIDAQABo1AwTjAdBgNVHQ4EFgQURgj0qpHyI0g/Z/uAs5TJhOOX\ncQgwHwYDVR0jBBgwFoAURgj0qpHyI0g/Z/uAs5TJhOOXcQgwDAYDVR0TBAUwAwEB\n/zANBgkqhkiG9w0BAQUFAAOCAQEAXTQPUKjVoqCXULCczpNyUFwq7k52toMIVsC5\n8bSb0SphuJpmBvI89L1BW8Qqd/etHn086ysTXT8cha9OV0qPatfEwUjxF7OFUmWA\nuJtL23h+6lFjJl+gg3W1LiBV722ssH/K86fBUijpGy9e6tDTb/gJKoVy3L3FGp1e\nwCu9/tEnLXz2Kf120i17a67NwuN19QH8+wFVJYNPAlzK7dMZcvzWXVK5jxNNdZ0U\n9Mr3Wb/FYQcDOucIrYdThh9//RbRTH0JMmbYhOiYXteJKOYreSwqGlZJLmfOExYx\nEXjRmsJ4xyedzAlUmmUj0WNkBA1fYmVhJ1JZqU+uRTgvL2QcPQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 degli Studi di Messina"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Messina"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unime.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unime.it/en"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli Studi di Messina"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Messina"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp1.segfl.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hadfield"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:heather.hadfield@segfl.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Heather"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Johnson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:taras@gooii.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Taras"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp1.segfl.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-03-18T14:50:55Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SEGfL Website Services"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.segfl.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Bracknell Forest Borough Council"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp1.segfl.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp1.segfl.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp1.segfl.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp1.segfl.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp1.segfl.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sp1.segfl.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp1.segfl.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4jCCAcqgAwIBAgIJAKo2TwyB3hkyMA0GCSqGSIb3DQEBBQUAMBQxEjAQBgNV\n\t\t\t\t\t\tBAMTCXNlZ2ZsLXNwMTAeFw0xMTEyMTYxNTE0MDBaFw0yMTEyMTMxNTE0MDBaMBQx\n\t\t\t\t\t\tEjAQBgNVBAMTCXNlZ2ZsLXNwMTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAMQQA44wvMGBJWDyxubnF0Q5x3+ZZ2E9W6DhGIFlEUv09X+j9WIqNf7a66uQ\n\t\t\t\t\t\tFW2N1OOTCbn4gDHSKKjQ3kTz03f6XIoGOJVJYJ/6dU0mXmZ5/jqZqWY9fFCoGQBz\n\t\t\t\t\t\trylI1SFH7X1O6r/wpPvmp8dbA0/AMwvirXKKhzvvw8F/Jpu5W1g89VXBvDTJ/yjh\n\t\t\t\t\t\tRJasNM102Qhd8xlXH2N5ZReXXb1yEqzZ7Ss/oigFyXjhiHcxzBk/Zbt45+PyVDxw\n\t\t\t\t\t\tzfqLJKW763oHunaEXbCq2w5rbYGnlbTLEXc6CjDA4asOxEqY3+xlzqE8yJTngNae\n\t\t\t\t\t\t+SZQa5I6zSLjEwMz5s4EhJSdPGUCAwEAAaM3MDUwFAYDVR0RBA0wC4IJc2VnZmwt\n\t\t\t\t\t\tc3AxMB0GA1UdDgQWBBThQdOJbEqv+ifbPsJuWrJSoWjNEDANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAGNp6mtzGck7Dv7dxc6kZVC8jb9zVbXAFaVMBVyEjyd74E8T3/UTZVB00\n\t\t\t\t\t\tABKTImJYdFuSYSxSKLEtDQcMlIDvO/+YW7NuMaJCB1raxAJ5qRAxdqYheICa53uc\n\t\t\t\t\t\ttokIITAaNj5kVTfnUeLmZTerotNEQRduwzHDKE0X3IqrSLYx0s+maaa7hN7wgL88\n\t\t\t\t\t\t08KCC5+qL2JQQ6qNCwc/qY/ghhpEMhy3NLWnyrBnuv/4iErY0ogypOi/nXwOyNvn\n\t\t\t\t\t\tkVBc8iI75C1//VFt+8CiMkY9rnBRxn5IVAHXxVXnrssB/crrmyckb+YgwBBQ8iZa\n\t\t\t\t\t\tdCprZdnQx0YClGTn1VG3XHxua2BeCw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp1.segfl.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp1.segfl.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp1.segfl.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp1.segfl.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp1.segfl.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp1.segfl.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://hashog.umdc.umu.se:8087/HTH.xml",
    {
      "entity_id": "http://hashog.umdc.umu.se:8087/HTH.xml",
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hoerberg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "hans.horberg@umu.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hans"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ITS"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ITS"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.its.umu.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ITS"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "http://hashog.umdc.umu.se:8087/slo",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "attribute": [
                  {
                    "attribute_value": [
                      {
                        "extension_attributes": {
                          "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                        },
                        "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                        "text": "eyJhbGciOiAiUlNBLU9BRVAiLCAiZW5jIjogIkEyNTZHQ00ifQ.fmCzquqwio4B-mN5Dvm6vbcuZFp4pjK5a918YN4aJgmP4xFl_X5T71gIGCJH4VTDtGzJNj38nJTjhmx51Fqqg6wS1HOjsIeX1pUx0w1KL32Wnas13gekhM8oK-NZvmW7ulBOGUuXNMJEOyX8pbMHOeiCd4C8CDzI2M9zQ1Xve5s77f3tpTEmdR3AQ4vs5EIl3TYTVs-z9O8FWha2dx7N_qvf5FNUkZaQpZa_HxaD5cpQ2ahsAeqZxLq6gRf-fMcrmHEBlQaqbaVvtFnHEuzGzwltIFXRg_RJA7UPmg41MPhyJmG0BmWC27h1w4aCE5IXrOKji1kBTTQpfZqbHmo01g.l7h8x8_hqXZJO3t9. .7T81HKUbt6wrQPSeB0v9Lw"
                      }
                    ],
                    "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                    "name": "http://social2saml.nordu.net/customer",
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDbjCCAtegAwIBAgIJAMzVnpW6xnXJMA0GCSqGSIb3DQEBBQUAMIGBMQswCQYD\nVQQGEwJTRTELMAkGA1UECBMCQUMxDTALBgNVBAcTBFVtZWExDDAKBgNVBAoTA0lU\nUzEMMAoGA1UECxMDRElHMRYwFAYDVQQDEw1IYW5zIEhvZXJiZXJnMSIwIAYJKoZI\nhvcNAQkBFhNoYW5zLmhvcmJlcmdAdW11LnNlMCAXDTEzMDQyNDEzMTUyOVoYDzIy\nODcwMjA2MTMxNTI5WjCBgTELMAkGA1UEBhMCU0UxCzAJBgNVBAgTAkFDMQ0wCwYD\nVQQHEwRVbWVhMQwwCgYDVQQKEwNJVFMxDDAKBgNVBAsTA0RJRzEWMBQGA1UEAxMN\nSGFucyBIb2VyYmVyZzEiMCAGCSqGSIb3DQEJARYTaGFucy5ob3JiZXJnQHVtdS5z\nZTCBnzANBgkqhkiG9w0BAQEFAAOBjQAwgYkCgYEAvvz/QurwxhDWZYarwgsk+KKw\nWxD6b1cTLTSg3A+NHE3xy2yLr4rUDmYQXNVfMYbBxuOrFRrX6gLscv6D/CXm684m\nbBJb5fE1tIdhfxWzN7GFFjWheRqxKSOI7WaclW3QKAe6WwFd+W69Qg2HFOfLAMI5\nAPhsYnHtjtU696HNNBcCAwEAAaOB6TCB5jAdBgNVHQ4EFgQUeFoKo9hADNDTLyIk\nIB1jdfo6mNMwgbYGA1UdIwSBrjCBq4AUeFoKo9hADNDTLyIkIB1jdfo6mNOhgYek\ngYQwgYExCzAJBgNVBAYTAlNFMQswCQYDVQQIEwJBQzENMAsGA1UEBxMEVW1lYTEM\nMAoGA1UEChMDSVRTMQwwCgYDVQQLEwNESUcxFjAUBgNVBAMTDUhhbnMgSG9lcmJl\ncmcxIjAgBgkqhkiG9w0BCQEWE2hhbnMuaG9yYmVyZ0B1bXUuc2WCCQDM1Z6VusZ1\nyTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4GBAI3LPS9fQ7eQMFUE1PcP\ns46Xsh+qUQiKdsYyXdAqgXrrV/ut8nmFqXyhxlqvQ5d4OLgcLYHejiqDBN0monQh\nPYMxdrL78/lzuwI47SEgp/LU8IqQWQdodaZ1yQDVvZeJ+HKuIX0dLzOaVHDLZSqE\nXUx2MauoLiNDXkEYs9GBFdgE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDbjCCAtegAwIBAgIJAMzVnpW6xnXJMA0GCSqGSIb3DQEBBQUAMIGBMQswCQYD\nVQQGEwJTRTELMAkGA1UECBMCQUMxDTALBgNVBAcTBFVtZWExDDAKBgNVBAoTA0lU\nUzEMMAoGA1UECxMDRElHMRYwFAYDVQQDEw1IYW5zIEhvZXJiZXJnMSIwIAYJKoZI\nhvcNAQkBFhNoYW5zLmhvcmJlcmdAdW11LnNlMCAXDTEzMDQyNDEzMTUyOVoYDzIy\nODcwMjA2MTMxNTI5WjCBgTELMAkGA1UEBhMCU0UxCzAJBgNVBAgTAkFDMQ0wCwYD\nVQQHEwRVbWVhMQwwCgYDVQQKEwNJVFMxDDAKBgNVBAsTA0RJRzEWMBQGA1UEAxMN\nSGFucyBIb2VyYmVyZzEiMCAGCSqGSIb3DQEJARYTaGFucy5ob3JiZXJnQHVtdS5z\nZTCBnzANBgkqhkiG9w0BAQEFAAOBjQAwgYkCgYEAvvz/QurwxhDWZYarwgsk+KKw\nWxD6b1cTLTSg3A+NHE3xy2yLr4rUDmYQXNVfMYbBxuOrFRrX6gLscv6D/CXm684m\nbBJb5fE1tIdhfxWzN7GFFjWheRqxKSOI7WaclW3QKAe6WwFd+W69Qg2HFOfLAMI5\nAPhsYnHtjtU696HNNBcCAwEAAaOB6TCB5jAdBgNVHQ4EFgQUeFoKo9hADNDTLyIk\nIB1jdfo6mNMwgbYGA1UdIwSBrjCBq4AUeFoKo9hADNDTLyIkIB1jdfo6mNOhgYek\ngYQwgYExCzAJBgNVBAYTAlNFMQswCQYDVQQIEwJBQzENMAsGA1UEBxMEVW1lYTEM\nMAoGA1UEChMDSVRTMQwwCgYDVQQLEwNESUcxFjAUBgNVBAMTDUhhbnMgSG9lcmJl\ncmcxIjAgBgkqhkiG9w0BCQEWE2hhbnMuaG9yYmVyZ0B1bXUuc2WCCQDM1Z6VusZ1\nyTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4GBAI3LPS9fQ7eQMFUE1PcP\ns46Xsh+qUQiKdsYyXdAqgXrrV/ut8nmFqXyhxlqvQ5d4OLgcLYHejiqDBN0monQh\nPYMxdrL78/lzuwI47SEgp/LU8IqQWQdodaZ1yQDVvZeJ+HKuIX0dLzOaVHDLZSqE\nXUx2MauoLiNDXkEYs9GBFdgE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://hashog.umdc.umu.se:8087",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ukfederation.ecu.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gregory"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@comistechnology.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hanno"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gregory"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@comistechnology.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hanno"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ukfederation.ecu.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-10-21T15:45:37Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVANMvXrP3yd50wehorJHIv4sqdsdqMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCExHzAdBgNVBAMTFnVrZmVkZXJhdGlvbi5lY3UuYWMudWswHhcNMTMwOTI1\n\t\t\t\t\t\tMTA0NDIzWhcNMzMwOTI1MTA0NDIzWjAhMR8wHQYDVQQDExZ1a2ZlZGVyYXRpb24u\n\t\t\t\t\t\tZWN1LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuN/sVb/k\n\t\t\t\t\t\tdm7u9DJjDZ9sc7w6LeK24doCHc1Se1g/01ii5FSL8paysmNW1AexblCq3pO4z286\n\t\t\t\t\t\tzDjXAvJn2X41YJb1JYXtdbp++VPhJ0c/wNMZhZZgN3zdMYmEqyVZHQphuJPCFvs4\n\t\t\t\t\t\tj/sKm2wArc7XsG7G2wuvayQ4yhrA6AFPB+LtsVbml1MbpL9JgixQNWaOUELT7g/Z\n\t\t\t\t\t\t/fSzuVdJ7Gj0VwUDuEc9VQsfizGzoq5aPUtEJshI64PbJQEYchSqL97Jk4CqZ+pl\n\t\t\t\t\t\tCyHdW7uy306t5bS2LxuhOZoZWqVqEttmSjiygwydV1bigROBVizDPU1JZ7hmq6x6\n\t\t\t\t\t\tQ9VUR2jQ0usmeQIDAQABo3MwcTBQBgNVHREESTBHghZ1a2ZlZGVyYXRpb24uZWN1\n\t\t\t\t\t\tLmFjLnVrhi1odHRwczovL3VrZmVkZXJhdGlvbi5lY3UuYWMudWsvaWRwL3NoaWJi\n\t\t\t\t\t\tb2xldGgwHQYDVR0OBBYEFDJlcovxD/rhWuukxo82lQ4WNsIfMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQA2qsCup37tuAq6LrQR54tEToCV4aAoDgSahDrubmCI0IhFRhtNycRC\n\t\t\t\t\t\teVe/eWW0ZjJvZ5ycTWH8UmHcWTU0DFPz1iyLPFe/0Zn5KU/K91XhE7w5TUM9oX66\n\t\t\t\t\t\t3EU0IpBGa2UaMINDkSYI1Qd6mHc4ilVyqCgCPNbh8aF7CS2rNLIPLpUF/kgcR4/C\n\t\t\t\t\t\txueo9DB8f06YkzjvhRVYt+08OVkt0vrJy34huV6/eqP9fxcAy9eJ+2O/pNqX5Bsa\n\t\t\t\t\t\tjUKdc4Ab3/C4QO/9kzBuhuHHsuQCnCU6puPgy8n2IKlXwS+PhMsC+mnvqDil77xN\n\t\t\t\t\t\tO7939VxLIqifIAdVAOq2xkneYhX/3sy4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ecu.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://ukfederation.ecu.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ukfederation.ecu.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://ukfederation.ecu.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ukfederation.ecu.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ukfederation.ecu.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ukfederation.ecu.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://ukfederation.ecu.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ukfederation.ecu.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ecu.ac.uk"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Equality Challenge Unit"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVANMvXrP3yd50wehorJHIv4sqdsdqMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCExHzAdBgNVBAMTFnVrZmVkZXJhdGlvbi5lY3UuYWMudWswHhcNMTMwOTI1\n\t\t\t\t\t\tMTA0NDIzWhcNMzMwOTI1MTA0NDIzWjAhMR8wHQYDVQQDExZ1a2ZlZGVyYXRpb24u\n\t\t\t\t\t\tZWN1LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuN/sVb/k\n\t\t\t\t\t\tdm7u9DJjDZ9sc7w6LeK24doCHc1Se1g/01ii5FSL8paysmNW1AexblCq3pO4z286\n\t\t\t\t\t\tzDjXAvJn2X41YJb1JYXtdbp++VPhJ0c/wNMZhZZgN3zdMYmEqyVZHQphuJPCFvs4\n\t\t\t\t\t\tj/sKm2wArc7XsG7G2wuvayQ4yhrA6AFPB+LtsVbml1MbpL9JgixQNWaOUELT7g/Z\n\t\t\t\t\t\t/fSzuVdJ7Gj0VwUDuEc9VQsfizGzoq5aPUtEJshI64PbJQEYchSqL97Jk4CqZ+pl\n\t\t\t\t\t\tCyHdW7uy306t5bS2LxuhOZoZWqVqEttmSjiygwydV1bigROBVizDPU1JZ7hmq6x6\n\t\t\t\t\t\tQ9VUR2jQ0usmeQIDAQABo3MwcTBQBgNVHREESTBHghZ1a2ZlZGVyYXRpb24uZWN1\n\t\t\t\t\t\tLmFjLnVrhi1odHRwczovL3VrZmVkZXJhdGlvbi5lY3UuYWMudWsvaWRwL3NoaWJi\n\t\t\t\t\t\tb2xldGgwHQYDVR0OBBYEFDJlcovxD/rhWuukxo82lQ4WNsIfMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQA2qsCup37tuAq6LrQR54tEToCV4aAoDgSahDrubmCI0IhFRhtNycRC\n\t\t\t\t\t\teVe/eWW0ZjJvZ5ycTWH8UmHcWTU0DFPz1iyLPFe/0Zn5KU/K91XhE7w5TUM9oX66\n\t\t\t\t\t\t3EU0IpBGa2UaMINDkSYI1Qd6mHc4ilVyqCgCPNbh8aF7CS2rNLIPLpUF/kgcR4/C\n\t\t\t\t\t\txueo9DB8f06YkzjvhRVYt+08OVkt0vrJy34huV6/eqP9fxcAy9eJ+2O/pNqX5Bsa\n\t\t\t\t\t\tjUKdc4Ab3/C4QO/9kzBuhuHHsuQCnCU6puPgy8n2IKlXwS+PhMsC+mnvqDil77xN\n\t\t\t\t\t\tO7939VxLIqifIAdVAOq2xkneYhX/3sy4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Equality Challenge Unit"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ecu.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Equality Challenge Unit"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://caneid.miami.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "akadiyala@miami.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Anil Kadiyala"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "akadiyala@miami.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Anil Kadiyala"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://caneid.miami.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://caneid.miami.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://caneid.miami.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://caneid.miami.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://caneid.miami.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://caneid.miami.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "miami.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Miami"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAPQh6d6BZ9YFBFUWqakLfYnEdM4xMA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEGNhbmVpZC5taWFtaS5lZHUwHhcNMTEwNzA1MTc0NDM2\nWhcNMzEwNzA1MTc0NDM2WjAbMRkwFwYDVQQDExBjYW5laWQubWlhbWkuZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1rzg7ZatkXxqJ/zgNGeewolU\ndHPcTL/K5qF+pR3oFCPy9OFFLSdilEQlvM1Tlbk/mtChIhL2EtkA0EXyFqQdDAmf\njw94nYJEHn35T98K1fZxdbATFnZCXWmofTW7h45gV5rROFZApd9PyzC0saTYOco9\n1/yqftPdT2gbLStY4ygQmjJfbTcuSNxW764WSx10ZfuQYi3opJdHWt2erv6hX/jK\nAXQxVXFWxknMaAQsX4Ux9T2XenRYCzN89+hiOrHXf/HCNLYQRy4iDDQL+JlhYYeV\n8lJZy+8YIZycMtxzfDusivTDNtZVxzs4a5887JBgTZ9e04i6ShKF+6RaQ7YQnwID\nAQABo2cwZTBEBgNVHREEPTA7ghBjYW5laWQubWlhbWkuZWR1hidodHRwczovL2Nh\nbmVpZC5taWFtaS5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFJyoHhDM6V21\nxYU2zaZW8N1Z07u0MA0GCSqGSIb3DQEBBQUAA4IBAQC2YOObmOvCRPLeixpeGhoM\nNnw3Kn9U4F1jBtZlRWTOXJmbi1BmBibgMJKBdelh1zsPZnUWaolMhjimmEMHkNmX\nELyvC+9VpS5QX/27ct1thtHIwKn8lb2ZlBf8gfYOS9piL3Fq57JpUQIzvYSYfJNh\n/mnixpoGtqPtt3FYqBR40+HJxhF8xFg3cbsqOZZelXdeyh2vkUcQYSEaecI762qE\nik202ny3EMaI0Inw9Wc8Toppy2R91Bz/bh0SCYqsCrcJygRoZ4ROwvUZ/DBoyixB\n1JB2M6xRO0un23rAAyIUk2T0YZtXuDvbwqN6wUOWj5oHvbtXGF4eg8KmyIozGx5n"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Miami"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.miami.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Miami"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://bmthbs.sisoshibboleth.co.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Info"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Oates"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bmthbs.sisoshibboleth.co.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-12-01T17:24:32Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SiSo Bournemouth University ~ Business School, Online Resource Booking"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.siso.uk.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "TechEthika Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bmth.siso.co/bs/sso/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://bmth.siso.co/bs/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://bmth.siso.co/bs/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SiSo Bournemouth University ~ Business School, Online Resource Booking"
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth.siso.co/siso-logo60x60.jpg",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SiSo Bournemouth University ~ Business School, Online Resource Booking"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAOSUhyDXVj7AMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB3Npc28uY28wHhcNMTMwMTA3MTYzMTIxWhcNMjMwMTA1MTYzMTIxWjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdzaXNvLmNvMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\txDnj9YFJVXclawo/8rs1aWYAgk6rKi8A/Cyycq0mW5yOKLLh8MUIgDeOGL7bLl7p\n\t\t\t\t\t\tMBeZM4ILlNaeJhICWm1tuLB6SYzREnXwpO7+lvx13xsRHW2TjCPGV3yUgz55vRYj\n\t\t\t\t\t\tbseFrwFHJ8IrL24UTLcpX/R//9cMkZpSqM+77Hn22dxbYvGUOQCHOQzL78AO91qz\n\t\t\t\t\t\tdUaxKzYWyWM7w2U4APP41Zvd0flyUtRZXp8W+WwlUDffFoNndsjR4L/9wuXvOcrH\n\t\t\t\t\t\t+VZtMLy60+cB9bpvVlaQVlt+1stEABdMVvuGNkJ9wIjRjP2b9OLUI76QmgwIDtdE\n\t\t\t\t\t\t5BS0Bv0Puz66L96r2MunRQIDAQABozUwMzASBgNVHREECzAJggdzaXNvLmNvMB0G\n\t\t\t\t\t\tA1UdDgQWBBRRosxNbUQXXwtWDl/kYMScRImh5TANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tgrfjza9Btcz+9WvzcjDTZ+KSrWWvrthA3zc6Q+C/MIBG8CCuxMO+uwFBnXIopGlX\n\t\t\t\t\t\tbLa/QtVLjOugsnizFxjaEFTG4jGndtPJ8+9V8Eja5RlOazuM2LT738+Um8/1Frhr\n\t\t\t\t\t\tGXa0Hdv9ZWEbIhil65fFqZNOmOteja6xxAQ9NgGG/XUnTVTbr7msihEAYTTcS40/\n\t\t\t\t\t\tGSYpT9nQwiryfSWDNJ17Zyl44389kSw+FCUsu8Ns9VSDEDWr/R+97ZMcjN6hAfJL\n\t\t\t\t\t\tdji3X1aaAC/JbnJl/v+yR1TH/sdHyObVaM7FToUGKiyjX9VpfOe64d0hjogzEr0x\n\t\t\t\t\t\tfirJubLNu96jbGctasqcpQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bmth.siso.co/bs/sso/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://bmth.siso.co/bs/sso/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bmth.siso.co/bs/sso/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://bmth.siso.co/bs/sso/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://bmth.siso.co/bs/sso/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://bmth.siso.co/bs/sso/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://portaltest.mdh.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://portaltest.mdh.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://portaltest.mdh.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://portaltest.mdh.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://portaltest.mdh.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJAJxlrtEgwIdRMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE3YtcG9yanVzLml0YS5tZGguc2UwHhcNMTQwMTI4MTAzMzQ2WhcNMjQwMTI2\nMTAzMzQ2WjAeMRwwGgYDVQQDExN2LXBvcmp1cy5pdGEubWRoLnNlMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAyLaBGpaEsfZSKVfudzLCVLceAtwwrANy\n8DHWGHmSpcXoLxg3Stk0tMPkA1A8X6aLSdvsIggYZO9Ocy4NrM7Laiv1fKoYm+Z6\nLxJYmUXvBTi1bZjYkF/dv7ElsR/dci/dV6FX52j8v3zFCx2s00LQ0Gv0qIYDbbXo\nTEaId0UNTkpJYkIyo9idHDX8ZGo5We1smlJYcNwa2Pgd9qTfrudUVpxTA0vT0zLT\nIL5QDoPniSFpm75CQA+KvY4wH2Hk03bJdxyn8tIW/CDotC8hwUwYTceocYNAEtQI\nxTpvd3aIQJ3v6mC+hpADDnsQIN6ewBaWJ/16EOZ2VQqwonNYlFo8fQIDAQABo0Ew\nPzAeBgNVHREEFzAVghN2LXBvcmp1cy5pdGEubWRoLnNlMB0GA1UdDgQWBBTgmWfR\nx9pMqVvg3BMDnRDWmOf60DANBgkqhkiG9w0BAQUFAAOCAQEADBgUq1K9/VbZuSRe\nUUVuBeOCRuwZmCa9kO5KjED/qygUzC0Zz2A5+du+lwTFOB8KBzy5lIsBDDwHdhPz\nBKLGfEGN+eMpvpz1C/wm23LyiBISTv8VvokdErOXpqJZq7P7K9fQiy7F5rW52UG+\nOX/uxQ35zRnueetkYTfBptqmLJhncQueBCCRFwzoH4UhOmyR2xx1Ba1nFLHqZhXi\n7+G7S9RMj99B5pCY/inq/vdRIaTMkw/ikTbOe1Z78Oaa29NSMKwa2sxr81J8hiOC\nQoxXlVvgoGgO78eQBdUXDw9lmNy/Q/MD57AROnFz79BH9Yi0aacn7dEPHBML3NJ8\ngBz/xw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.mdh.se/student/service/studentportalen-1.260?l=sv_SE"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.mdh.se/student/service/studentportalen-1.260?l=en_UK"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Denna applikation anv\u00e4nds f\u00f6r att registrera sig p\u00e5 kurs p\u00e5 MDH."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service is used for registering at course at MDH."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.mdh.se/gemensamt/webbplatsen/juridisk-information-1.205?l=sv_SE"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.mdh.se/gemensamt/webbplatsen/juridisk-information-1.205?l=en_UK"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Studentportal MDH"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Student portal MDH"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://idp.natcen.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.natcen.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/natcen.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/natcen.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "natcen.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "National Centre for Social Research"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.natcen.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.envt.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ARNOUX Jean-Baptiste"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jb.arnoux@envt.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.envt.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-07-15T15:58:51Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.envt.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.envt.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.envt.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "envt.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.envt.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "7",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Nationale V\u00e9t\u00e9rinaire de Toulouse (ENVT)"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Nationale V\u00e9t\u00e9rinaire de Toulouse (ENVT)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVALbIAX96KL3MHHLOC3iIdPBazQtRMA0GCSqGSIb3DQEB\nBQUAMB0xGzAZBgNVBAMTEnNoaWJib2xldGguZW52dC5mcjAeFw0xMzA2MjYwNzQ1\nMjhaFw0zMzA2MjYwNzQ1MjhaMB0xGzAZBgNVBAMTEnNoaWJib2xldGguZW52dC5m\ncjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL14Y39Z+9nkRJRbtsZs\nGIFZcTO8R4DH9nhPuokCn/mByrzCtVAEdC91yQ7+jGgXB/DZ/HECMvolPFnV3aRP\nCrsFap1m1WbaL72fLhO3zxappC0BzZxyefuHtRkvf2yx6hS7qg2HHgzNVqUpJFW9\ncbaxLyIIZuy6cmGvfNGZ7SchdgIqcUclhxZWOo8HH2d4rFZWIIOScZ9gyhThlZUs\nZKXCe2cw0b69B3tU7DVT2ZL3G8HPDOsJ02EHckSJhExRRB6obM7FSnvi2qOkSoTS\n/tobBMNR6vGN6EYc3+6MwR572TEG0YKDWA4UkfVkrb5BGwclehPoYybuwLO9bIGz\ny+MCAwEAAaNrMGkwSAYDVR0RBEEwP4ISc2hpYmJvbGV0aC5lbnZ0LmZyhilodHRw\nczovL3NoaWJib2xldGguZW52dC5mci9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\nfCqGnApiVU0GuQF3nPx7nd06SPswDQYJKoZIhvcNAQEFBQADggEBADI4y7Im35ne\n5YqpHF4hfF6HCIVezRvIrm6WrdL5aB7U//Pfq+ZTDnByLzULEU2LIgOlEyFlz5Os\n5yYI9c5nGrStndK9dvWTTUhQdZjVBJAfiHx0wBIdgEgI/R7X4kUpgZgpPC/WCk0W\nCP+KGdCy+HnpZ40bq0AhDKIoX5iXoXIIvmioONovPXmUh0aHgHVFufW8Y4qHilW/\niowguqDTs4Es0C9ynTwu/wWLb1GWoIRtBHq7BR1yUCnefmDlZ1dP5sNCShVALvie\nba49eIXgBqBxpQGrsHsgBR0UlekV5SmAQxH42PmEzeOpLCRTvlmOn2SYTJd4gJ1a\nJZ1pqUirmzM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ecole Nationale V\u00e9t\u00e9rinaire de Toulouse (ENVT)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.envt.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ecole Nationale V\u00e9t\u00e9rinaire de Toulouse (ENVT)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://coip.app.nordu.net/saml2/sp/metadata",
    {
      "entity_id": "https://coip.app.nordu.net/saml2/sp/metadata",
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Johansson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "leifj@nordu.net"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "NORDUnet"
          },
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Leif"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Berggren"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jbn@nordu.net"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "NORDUnet"
          },
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Johan"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUNet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://coip.app.nordu.net/saml2/sp/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEujCCA6KgAwIBAgIQLINqZJFs8l1wYd2J2IBMTjANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEyMDIyOTAwMDAwMFoXDTE1MDIyODIzNTk1OVowgZUxCzAJBgNV\nBAYTAkRLMQowCAYDVQQREwEuMQowCAYDVQQIEwEuMQswCQYDVQQHEwIuLjEZMBcG\nA1UECRMQREsgMjk3MCBIb3JzaG9sbTEVMBMGA1UECRMMQWdlcm4gQWxsZSAzMRUw\nEwYDVQQKEwxOT1JEVW5ldCBBL1MxGDAWBgNVBAMUDyouYXBwLm5vcmR1Lm5ldDCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJkBbj0ZJsjuirO6tN9rbRhE\n5PfQKfjrwMf5lp1a05DHlJcxsv2JZGPszkOA260D8gouWfjk3DJQIIJJgELfn5yP\nL4zwKArBDpsttTXW+DFmhfECbkemWV571ErDHMVC9JUD39uLhE1bAoYFxAeJGr14\nmg/N5YdnsuSTGOfVfC+XuhA3CgylcGBIWoXHPbPlUJk3VWVeNnYjO+nLlKPjhSSq\nmRVhmVhEwREiRPgbKyMEEoFpdmSzuNWcBMtVKt4FTLa0cjx3/rIn77imztcXRDSN\nT6GwXaG5pjy+7E602epC4t5hbj6pxzrC7mpyIQXdYjKboPgaKQ+E7bv+OqJNG3sC\nAwEAAaOCAWIwggFeMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdXR+qQ47ntMB0G\nA1UdDgQWBBT0F6Szj83YxTlMGIIIf3I9jdTedjAOBgNVHQ8BAf8EBAMCBaAwDAYD\nVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwGAYDVR0g\nBBEwDzANBgsrBgEEAbIxAQICHTA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3Js\nLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8w\nNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NM\nQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAa\nBgNVHREEEzARgg8qLmFwcC5ub3JkdS5uZXQwDQYJKoZIhvcNAQEFBQADggEBADMQ\nbc0dPVC1SlyOxDf90hN9sDKw92YdVtsUNFfs9MYivZK7KI5+qEQStpAvXkrBUNfd\ngM9wqL9ea9BDDmBcn5lYyjPBgGJBeLLkcyBbZ56JbcBAxIncKKFw6r5M3j7tMcth\nf06K4cm7ngUg80ZEYK00ioAyFle56qPfZ5UM25QFzV38DGvusLl5H1bTtpz1ijh7\nkO/ehJVo4K64KVCbjOr1bavp665TtcIQX2qoPsnTZY30gQ/X/K2UJQSUE5Qc+o19\nBkvvVT5jNYdeLZHXbC6X4kXYNhFKZaz9nURgfaFQIeIEu/zmsIM8tcwLjZyF1veH\nwXXiBDXS3PNHXQnnpys="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://coip.app.nordu.net/saml2/sp/acs/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "COIP"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.cardiff.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athens@cardiff.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "The Athens Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smart"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:smartp@cardiff.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Philip"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cardiff.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2006-10-23T17:54:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIUe8wsOBcOivZ/X/QVj8+2Uw+jnbAwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwFzEVMBMGA1UEAxMMaWRwLmNmLmFjLnVrMB4XDTE0MDgxNDEzMTMxNVoXDTM0\n\t\t\t\t\t\tMDgxNDEzMTMxNVowFzEVMBMGA1UEAxMMaWRwLmNmLmFjLnVrMIIBIjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQEFAAOCAQ8AMIIBCgKCAQEApqXJD7Pmm0di7+qRkZYSDcc3JLPzVQkylFiV\n\t\t\t\t\t\tbvpNphN9Rt9cRVv/qvN1nZVMYCanwzDJSz6idD4jip33u1up1szRTn5vfQLT5ta5\n\t\t\t\t\t\t+PBzZad2lIao4CGH4PzSbUTUxivhldMQShlonsxmtpdFinHOKMjt8WYXB7iF0qDm\n\t\t\t\t\t\tPQnJJC7tjHku/yc+d1Zh2VgzTG/OQ0fGvvkp5dFywjAAUH/ot/kheCqw4g0F/LHj\n\t\t\t\t\t\tPlKUMvGFZc7PnmYgVa7Xz9YI0ZJjdc8uCHsvEZfCpoDnTpigUUvqwuuvwdSR7aew\n\t\t\t\t\t\tSLcJi74+DXEZh/aa23HLVWrxk4xfMojpKVC+SwweohEeg4Wr3QIDAQABo2AwXjA9\n\t\t\t\t\t\tBgNVHREENjA0ggxpZHAuY2YuYWMudWuGJGh0dHBzOi8vaWRwLmNhcmRpZmYuYWMu\n\t\t\t\t\t\tdWsvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUGzP0X/B4uf8Nz8c3KPWxG4gG8dQwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBAGfqyC6ItIgEs3LtHUApmqvKDpFT90Uw03q4G5mwYT/Z\n\t\t\t\t\t\t8V2ml+ppXGJJbz2tdQcyJOXr+Ik2UmFauYvtedsAuc+q2j1i4LMrveo03XP1NrHY\n\t\t\t\t\t\tBMwMbvsjPqRbHk8398M4XA92712iB448+8kwI8zwu5Nlbayu9JF84eSEsufQHaA3\n\t\t\t\t\t\t2tEqUYZYw+5SIhUPPL+rJbOTh/sPYy0niY2RVX22MsBGHIH+c93gpSYoCdQI5XBu\n\t\t\t\t\t\tfj8uW6fP20q8JEagC8olauNbiOgoRFaxjTOjudZKT449m6DrOdbcvPgV0s0vxTlR\n\t\t\t\t\t\ttSTvwfp+LJO2OrKN2zIzV+mrAeKIWaatx542gFAATg8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cardiff.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cf.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cf.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cf.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cf.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.cf.ac.uk/idp/profile/SAML2/POST-SimpleSign/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cf.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.cf.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cf.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.cf.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cf.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cf.ac.uk/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cf.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cf.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cardiff.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://static.cf.ac.uk/images/FAMLogos/cu-logo-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://static.cf.ac.uk/images/FAMLogos/cu-logo-128x126.png",
                    "height": "126",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "128"
                  },
                  {
                    "text": "https://static.cf.ac.uk/images/FAMLogos/cu-logo-64x62.png",
                    "height": "62",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  },
                  {
                    "text": "https://static.cf.ac.uk/images/FAMLogos/cu-logo-80x60t.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Cardiff University"
                  },
                  {
                    "lang": "cy",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Prifysgol Caerdydd"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "cardiff.ac.uk"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "cf.ac.uk"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:51.487626,-3.178638"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "131.251.0.0/16"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIUe8wsOBcOivZ/X/QVj8+2Uw+jnbAwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwFzEVMBMGA1UEAxMMaWRwLmNmLmFjLnVrMB4XDTE0MDgxNDEzMTMxNVoXDTM0\n\t\t\t\t\t\tMDgxNDEzMTMxNVowFzEVMBMGA1UEAxMMaWRwLmNmLmFjLnVrMIIBIjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQEFAAOCAQ8AMIIBCgKCAQEApqXJD7Pmm0di7+qRkZYSDcc3JLPzVQkylFiV\n\t\t\t\t\t\tbvpNphN9Rt9cRVv/qvN1nZVMYCanwzDJSz6idD4jip33u1up1szRTn5vfQLT5ta5\n\t\t\t\t\t\t+PBzZad2lIao4CGH4PzSbUTUxivhldMQShlonsxmtpdFinHOKMjt8WYXB7iF0qDm\n\t\t\t\t\t\tPQnJJC7tjHku/yc+d1Zh2VgzTG/OQ0fGvvkp5dFywjAAUH/ot/kheCqw4g0F/LHj\n\t\t\t\t\t\tPlKUMvGFZc7PnmYgVa7Xz9YI0ZJjdc8uCHsvEZfCpoDnTpigUUvqwuuvwdSR7aew\n\t\t\t\t\t\tSLcJi74+DXEZh/aa23HLVWrxk4xfMojpKVC+SwweohEeg4Wr3QIDAQABo2AwXjA9\n\t\t\t\t\t\tBgNVHREENjA0ggxpZHAuY2YuYWMudWuGJGh0dHBzOi8vaWRwLmNhcmRpZmYuYWMu\n\t\t\t\t\t\tdWsvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUGzP0X/B4uf8Nz8c3KPWxG4gG8dQwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBAGfqyC6ItIgEs3LtHUApmqvKDpFT90Uw03q4G5mwYT/Z\n\t\t\t\t\t\t8V2ml+ppXGJJbz2tdQcyJOXr+Ik2UmFauYvtedsAuc+q2j1i4LMrveo03XP1NrHY\n\t\t\t\t\t\tBMwMbvsjPqRbHk8398M4XA92712iB448+8kwI8zwu5Nlbayu9JF84eSEsufQHaA3\n\t\t\t\t\t\t2tEqUYZYw+5SIhUPPL+rJbOTh/sPYy0niY2RVX22MsBGHIH+c93gpSYoCdQI5XBu\n\t\t\t\t\t\tfj8uW6fP20q8JEagC8olauNbiOgoRFaxjTOjudZKT449m6DrOdbcvPgV0s0vxTlR\n\t\t\t\t\t\ttSTvwfp+LJO2OrKN2zIzV+mrAeKIWaatx542gFAATg8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cardiff University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cardiff.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cardiff University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ship.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp@ship.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shippensburg University Computing Technologies Center"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp@ship.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shippensburg University Computing Technologies Center"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@ship.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shippensburg University Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ship.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ship.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ship.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ship.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ship.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ship.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ship.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ship.edu/technology"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Shippensburg University of Pennsylvania"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Shippensburg, Pennsylvania"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.ship.edu/ShipLogo.jpg",
                    "lang": "en",
                    "height": "900",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "1200"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.ship.edu/Technology/Policies/Computing_and_Information_Network_Usage_Policy/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFgDCCBGigAwIBAgIQIIqv7avkn41Rrf4h3IiBujANBgkqhkiG9w0BAQsFADB2\nMQswCQYDVQQGEwJVUzELMAkGA1UECBMCTUkxEjAQBgNVBAcTCUFubiBBcmJvcjES\nMBAGA1UEChMJSW50ZXJuZXQyMREwDwYDVQQLEwhJbkNvbW1vbjEfMB0GA1UEAxMW\nSW5Db21tb24gUlNBIFNlcnZlciBDQTAeFw0xNDEyMDkwMDAwMDBaFw0xNzEyMDgy\nMzU5NTlaMIG9MQswCQYDVQQGEwJVUzEOMAwGA1UEERMFMTcyNTcxCzAJBgNVBAgT\nAlBBMRUwEwYDVQQHEwxTaGlwcGVuc2J1cmcxGTAXBgNVBAkTEDE4NzEgT2xkIE1h\naW4gRHIxIDAeBgNVBAoTF1NoaXBwZW5zYnVyZyBVbml2ZXJzaXR5MSYwJAYDVQQL\nEx1Db21wdXRpbmcgVGVjaG5vbG9naWVzIENlbnRlcjEVMBMGA1UEAxMMaWRwLnNo\naXAuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA7DSYzTNKxc/G\nTK8e+bCrtl/1BncZVNu4BOigHFeL3zWwgBjvVppVJtza/ipj33Yb3Svxw3E7y7Ql\n4ZBnnahQcAKaBZogfvfefDIhkllVz8vhtaa4BLcl1241BrDBi86kV0/T1J8WHuYc\npCOFiSmzHdpZA67eMX2nIgZfOiNayNty1w8LNJadOZsy670SaV878UM4PU2I7Rnj\nThKBEl0symd5n8gEUZA9BpcyhLTmIeDAvX7y+ho0LzrujYTbWF8l9e5l0f1ytd/D\nzO2i6JnAmRAmuwb9j26myFo1S/f2PhnITI+6N/leZt1Tzy0Zqbva1OY3IR6hrDHm\nbHj10cl30wIDAQABo4IBwDCCAbwwHwYDVR0jBBgwFoAUHgWjd49sluJbh0umtIas\ncQAM5zgwHQYDVR0OBBYEFMwl/1ZxqnDlJeQc5D40kklquGpZMA4GA1UdDwEB/wQE\nAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcD\nAjBnBgNVHSAEYDBeMFIGDCsGAQQBriMBBAMBATBCMEAGCCsGAQUFBwIBFjRodHRw\nczovL3d3dy5pbmNvbW1vbi5vcmcvY2VydC9yZXBvc2l0b3J5L2Nwc19zc2wucGRm\nMAgGBmeBDAECAjBEBgNVHR8EPTA7MDmgN6A1hjNodHRwOi8vY3JsLmluY29tbW9u\nLXJzYS5vcmcvSW5Db21tb25SU0FTZXJ2ZXJDQS5jcmwwdQYIKwYBBQUHAQEEaTBn\nMD4GCCsGAQUFBzAChjJodHRwOi8vY3J0LnVzZXJ0cnVzdC5jb20vSW5Db21tb25S\nU0FTZXJ2ZXJDQV8yLmNydDAlBggrBgEFBQcwAYYZaHR0cDovL29jc3AudXNlcnRy\ndXN0LmNvbTAXBgNVHREEEDAOggxpZHAuc2hpcC5lZHUwDQYJKoZIhvcNAQELBQAD\nggEBAAECWt1wp9jnH/7TlHwg9xJzaRO8UawTQiiTp8oHqLKiOxzFcCPzJEatUfwF\nQuTuAEdvv5jvlwLPtZqkaiVdTAxKjVgxCBKlSRqdRiHkXHeeKlN6/dE9SSKpS/3n\n/nnKpgwK0kfXkOTFbcFOaEEehY/oIHlEPONUn5dNDB5EMaNRKh9ATwLe6G2V1KT8\nwPwL6yo+Dk5PsGngpwy+ujQOhSJoCCbzoBFlDzpTHp8gl2hpScUQOLziW8M1BpRP\nLJQxOR1AvCp9E0gAFMTuOWaDR1Ybwllg3C7YizSUcK669Z4zjx/0+hcgDFbNpBov\nIvnQF4KSwZqAOukHhzVkzkfPjiI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idp.ship.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Shippensburg University of Pennsylvania"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://ship.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Shippensburg University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.wisum.umdac.umu.se/shibboleth",
    {
      "entity_id": "https://www.wisum.umdac.umu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.wisum.umdac.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.wisum.umdac.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.wisum.umdac.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.wisum.umdac.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.wisum.umdac.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.wisum.umdac.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEyjCCA7KgAwIBAgIJALCcJKZ84qQKMA0GCSqGSIb3DQEBBQUAMIGeMQswCQYD\nVQQGEwJTRTEVMBMGA1UECBMMVmFzdGVyYm90dGVuMQ0wCwYDVQQHEwRVbWVhMQ4w\nDAYDVQQKEwVVbWRhYzEOMAwGA1UECxMFVW1kYWMxHzAdBgNVBAMTFnd3dy53aXN1\nbS51bWRhYy51bXUuc2UxKDAmBgkqhkiG9w0BCQEWGW1hdHMubGFyc3NvbkB1bWRh\nYy51bXUuc2UwHhcNMTAxMjA5MjEzNTI2WhcNMTMxMDIyMjEzNTI2WjCBnjELMAkG\nA1UEBhMCU0UxFTATBgNVBAgTDFZhc3RlcmJvdHRlbjENMAsGA1UEBxMEVW1lYTEO\nMAwGA1UEChMFVW1kYWMxDjAMBgNVBAsTBVVtZGFjMR8wHQYDVQQDExZ3d3cud2lz\ndW0udW1kYWMudW11LnNlMSgwJgYJKoZIhvcNAQkBFhltYXRzLmxhcnNzb25AdW1k\nYWMudW11LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqgludy+/\ngDt8lUW67WutHZiJrYYro0og5ONioOkakzVgm74747J91EuYora+Y2jVMk7vXAPn\n3xvC52/2sN1kbtfhUoDCKfj4X/rkea891q4zd4hvGMMQiUU2vHX/qkcRbLuLrzXj\n7yfIq2bL4xlXSlBobMxCKHDo+AwtbPOhwEC57jwLVuQ42no57WRxoJ1gVraxpX5q\ng8maA4pUxplhfVVSl+zvH+KAyQROQ1dz02giQtpdbPpyIlK23ZlUHCNxSPKc6loo\nyUIsn7vkji2rbTxydce7R0AJDFapLF9yET2Lcszst25yCx3oPAk3YkvBtJYHjmv9\nVnNHWV8iBbeLpwIDAQABo4IBBzCCAQMwHQYDVR0OBBYEFB9YkDvP4A3oXEOz9AiS\n5wmU/Gg7MIHTBgNVHSMEgcswgciAFB9YkDvP4A3oXEOz9AiS5wmU/Gg7oYGkpIGh\nMIGeMQswCQYDVQQGEwJTRTEVMBMGA1UECBMMVmFzdGVyYm90dGVuMQ0wCwYDVQQH\nEwRVbWVhMQ4wDAYDVQQKEwVVbWRhYzEOMAwGA1UECxMFVW1kYWMxHzAdBgNVBAMT\nFnd3dy53aXN1bS51bWRhYy51bXUuc2UxKDAmBgkqhkiG9w0BCQEWGW1hdHMubGFy\nc3NvbkB1bWRhYy51bXUuc2WCCQCwnCSmfOKkCjAMBgNVHRMEBTADAQH/MA0GCSqG\nSIb3DQEBBQUAA4IBAQBMgsLrlDuF2E2G4+NjPLSDoqyXxcsziUzhOkYyDzwPq6v7\nHyYYPJYfc8YFwp+fbYp8JqqCyUqgbC3A0/hcBXQT3TxQZoi011/8mHg97Y7aSvus\n2oBgDaeI/n2aEJCN5Ty4iRo7tujF4toZ67Afceiw8r0im0yXOCEjOmsu5IZ/usEt\nCLr8JaUWpP9FrrKkFm6qlFkn6fb3MKiK5Q5+ywH//2A32s/DTT7gsIUoA2d7sQQZ\naeuGsLFXZYIsTtz9zAy13nUaPG+xk3JAFte9p+nYhB0+NOZY9sEKoJEK/1FW5wol\n5fMCo6rrhCpoEsDkXy1wxcYKE/WfOvySZaEiw70o"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=mats.larsson@umdac.umu.se,CN=www.wisum.umdac.umu.se,OU=Umdac,O=Umdac,L=Umea,ST=Vasterbotten,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.wisum.umdac.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEyjCCA7KgAwIBAgIJALCcJKZ84qQKMA0GCSqGSIb3DQEBBQUAMIGeMQswCQYD\nVQQGEwJTRTEVMBMGA1UECBMMVmFzdGVyYm90dGVuMQ0wCwYDVQQHEwRVbWVhMQ4w\nDAYDVQQKEwVVbWRhYzEOMAwGA1UECxMFVW1kYWMxHzAdBgNVBAMTFnd3dy53aXN1\nbS51bWRhYy51bXUuc2UxKDAmBgkqhkiG9w0BCQEWGW1hdHMubGFyc3NvbkB1bWRh\nYy51bXUuc2UwHhcNMTAxMjA5MjEzNTI2WhcNMTMxMDIyMjEzNTI2WjCBnjELMAkG\nA1UEBhMCU0UxFTATBgNVBAgTDFZhc3RlcmJvdHRlbjENMAsGA1UEBxMEVW1lYTEO\nMAwGA1UEChMFVW1kYWMxDjAMBgNVBAsTBVVtZGFjMR8wHQYDVQQDExZ3d3cud2lz\ndW0udW1kYWMudW11LnNlMSgwJgYJKoZIhvcNAQkBFhltYXRzLmxhcnNzb25AdW1k\nYWMudW11LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqgludy+/\ngDt8lUW67WutHZiJrYYro0og5ONioOkakzVgm74747J91EuYora+Y2jVMk7vXAPn\n3xvC52/2sN1kbtfhUoDCKfj4X/rkea891q4zd4hvGMMQiUU2vHX/qkcRbLuLrzXj\n7yfIq2bL4xlXSlBobMxCKHDo+AwtbPOhwEC57jwLVuQ42no57WRxoJ1gVraxpX5q\ng8maA4pUxplhfVVSl+zvH+KAyQROQ1dz02giQtpdbPpyIlK23ZlUHCNxSPKc6loo\nyUIsn7vkji2rbTxydce7R0AJDFapLF9yET2Lcszst25yCx3oPAk3YkvBtJYHjmv9\nVnNHWV8iBbeLpwIDAQABo4IBBzCCAQMwHQYDVR0OBBYEFB9YkDvP4A3oXEOz9AiS\n5wmU/Gg7MIHTBgNVHSMEgcswgciAFB9YkDvP4A3oXEOz9AiS5wmU/Gg7oYGkpIGh\nMIGeMQswCQYDVQQGEwJTRTEVMBMGA1UECBMMVmFzdGVyYm90dGVuMQ0wCwYDVQQH\nEwRVbWVhMQ4wDAYDVQQKEwVVbWRhYzEOMAwGA1UECxMFVW1kYWMxHzAdBgNVBAMT\nFnd3dy53aXN1bS51bWRhYy51bXUuc2UxKDAmBgkqhkiG9w0BCQEWGW1hdHMubGFy\nc3NvbkB1bWRhYy51bXUuc2WCCQCwnCSmfOKkCjAMBgNVHRMEBTADAQH/MA0GCSqG\nSIb3DQEBBQUAA4IBAQBMgsLrlDuF2E2G4+NjPLSDoqyXxcsziUzhOkYyDzwPq6v7\nHyYYPJYfc8YFwp+fbYp8JqqCyUqgbC3A0/hcBXQT3TxQZoi011/8mHg97Y7aSvus\n2oBgDaeI/n2aEJCN5Ty4iRo7tujF4toZ67Afceiw8r0im0yXOCEjOmsu5IZ/usEt\nCLr8JaUWpP9FrrKkFm6qlFkn6fb3MKiK5Q5+ywH//2A32s/DTT7gsIUoA2d7sQQZ\naeuGsLFXZYIsTtz9zAy13nUaPG+xk3JAFte9p+nYhB0+NOZY9sEKoJEK/1FW5wol\n5fMCo6rrhCpoEsDkXy1wxcYKE/WfOvySZaEiw70o"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=mats.larsson@umdac.umu.se,CN=www.wisum.umdac.umu.se,OU=Umdac,O=Umdac,L=Umea,ST=Vasterbotten,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.wisum.umdac.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.wisum.umdac.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.wisum.umdac.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.wisum.umdac.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.wisum.umdac.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.wisum.umdac.umu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.wisum.umdac.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.wisum.umdac.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.wisum.umdac.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.wisum.umdac.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://its-shib.its.csulb.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jsantana@csulb.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jesse Santana"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ryan.tapp@csulb.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ryan Tapp"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://its-shib.its.csulb.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://its-shib.its.csulb.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://its-shib.its.csulb.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVAJPL4jmebB2O17/3wHKhz8V1qEArMA0GCSqGSIb3DQEB\nBQUAMCExHzAdBgNVBAMTFml0cy1zaGliLml0cy5jc3VsYi5lZHUwHhcNMTAwMjAz\nMTg1NzQ1WhcNMzAwMjAzMTg1NzQ1WjAhMR8wHQYDVQQDExZpdHMtc2hpYi5pdHMu\nY3N1bGIuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArbViX4eh\nmsE7HYLfwAeBnBVkAwrw526zOn9dki/7AVLOb7E+EmmSur0WJDI83UqPzmPqaF3r\ndelLE4CMtRPt+qtZBfC6gSiOU85hwKdC6zCY9qMeeGA3mbcdpBUeRAQs5CBpVfIq\n9b6ONlMzDdcIgeLNFUhHTZk/TKgkXWYyWVgbsLQJjkjDJWgN+joWl2d2zNWkwHPL\nA2pn3eBxDN1ljxYI3Y7mD/KWMEkNDuhSZUckCRM1VBdyUKccmUXlGDbLJTZ9jJq9\n5Vrtcy+PgqTKzkt1V7PDyf3RbZBM+NgQKktrmWgjQYwWEonNpo1y6aSQCfDxQ8lQ\n25Oljv2lfTcfMQIDAQABo3MwcTBQBgNVHREESTBHghZpdHMtc2hpYi5pdHMuY3N1\nbGIuZWR1hi1odHRwczovL2l0cy1zaGliLml0cy5jc3VsYi5lZHUvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFGcFT/yuYca/kcgGyIaK+VZ9Mqx1MA0GCSqGSIb3DQEB\nBQUAA4IBAQBkdTI5YljHX1yxnvXzKxrFNM5e+d44vy845vuZz3phQkLJbx0qE5I9\nHiPwt54umx+neXTuTkKW9nozjb6O1G7XcCk10574Ou1zXI3ndV6rxgfxygkw1TRR\nwvsQvjaT2Ap5ogqo95BVGVNX+vGlhPneoMfVbHUHwFjv6IIlRPUfIT6V2g5y6CKV\nBIFqM69GfneuKbZkLsDsZDL6CLXWz2BYE4Z/RGRRWwN2+IE//9vcDra+7q0bqfqf\n7eMgq13DOjl3gbhvE1Hq1pkmzrwv1ewjHCxd4ILQC05MYFPAJiq3hzhske1DU8xO\nBqRi7xc2j/DiFKyFbqwPCyGLSIlDG9Tu"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csulb.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://its-shib.its.csulb.edu/idp/profile/Logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://its-shib.its.csulb.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://its-shib.its.csulb.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://its-shib.its.csulb.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csulb.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "California State University, Long Beach"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVAJPL4jmebB2O17/3wHKhz8V1qEArMA0GCSqGSIb3DQEB\nBQUAMCExHzAdBgNVBAMTFml0cy1zaGliLml0cy5jc3VsYi5lZHUwHhcNMTAwMjAz\nMTg1NzQ1WhcNMzAwMjAzMTg1NzQ1WjAhMR8wHQYDVQQDExZpdHMtc2hpYi5pdHMu\nY3N1bGIuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArbViX4eh\nmsE7HYLfwAeBnBVkAwrw526zOn9dki/7AVLOb7E+EmmSur0WJDI83UqPzmPqaF3r\ndelLE4CMtRPt+qtZBfC6gSiOU85hwKdC6zCY9qMeeGA3mbcdpBUeRAQs5CBpVfIq\n9b6ONlMzDdcIgeLNFUhHTZk/TKgkXWYyWVgbsLQJjkjDJWgN+joWl2d2zNWkwHPL\nA2pn3eBxDN1ljxYI3Y7mD/KWMEkNDuhSZUckCRM1VBdyUKccmUXlGDbLJTZ9jJq9\n5Vrtcy+PgqTKzkt1V7PDyf3RbZBM+NgQKktrmWgjQYwWEonNpo1y6aSQCfDxQ8lQ\n25Oljv2lfTcfMQIDAQABo3MwcTBQBgNVHREESTBHghZpdHMtc2hpYi5pdHMuY3N1\nbGIuZWR1hi1odHRwczovL2l0cy1zaGliLml0cy5jc3VsYi5lZHUvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFGcFT/yuYca/kcgGyIaK+VZ9Mqx1MA0GCSqGSIb3DQEB\nBQUAA4IBAQBkdTI5YljHX1yxnvXzKxrFNM5e+d44vy845vuZz3phQkLJbx0qE5I9\nHiPwt54umx+neXTuTkKW9nozjb6O1G7XcCk10574Ou1zXI3ndV6rxgfxygkw1TRR\nwvsQvjaT2Ap5ogqo95BVGVNX+vGlhPneoMfVbHUHwFjv6IIlRPUfIT6V2g5y6CKV\nBIFqM69GfneuKbZkLsDsZDL6CLXWz2BYE4Z/RGRRWwN2+IE//9vcDra+7q0bqfqf\n7eMgq13DOjl3gbhvE1Hq1pkmzrwv1ewjHCxd4ILQC05MYFPAJiq3hzhske1DU8xO\nBqRi7xc2j/DiFKyFbqwPCyGLSIlDG9Tu"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California State University, Long Beach"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csulb.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California State University, Long Beach"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.grantham.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.grantham.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/grantham.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/grantham.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "grantham.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Grantham College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.grantham.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.apus.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sodriscoll@apus.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sean O'Driscoll"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jcolon@apus.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Joe Colon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.apus.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.apus.edu/idp/profile/Logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.apus.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.apus.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.apus.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.apus.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.apus.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mycampus.apus.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "American Public University System"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUDhoamxOWGuk5FrIlSwlhAgBHcNowDQYJKoZIhvcNAQEL\nBQAwFzEVMBMGA1UEAwwMaWRwLmFwdXMuZWR1MB4XDTE1MDkyNDE1MjcxOFoXDTM1\nMDkyNDE1MjcxOFowFzEVMBMGA1UEAwwMaWRwLmFwdXMuZWR1MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkLKoU5xvhAuqHVRvn22P9232fbSeMWz8V8e1\nFDNSMfm1ksKKSdUI2NURdDPWEolNZWRoAYUMromdq3Dz76iogUMiH4PAr63Ehow9\nwAZUnxoD38g3Ss4w3Ri3GLz5ySh4h1tlIB2Eie2tjosvL8pCitd5wqDFioigT+li\nFN0PVF2eMnnAdl6RH4j+3JFVhbCZwyscYKZNWTPU0o2fHcgyVtLO6p0dp0ywM5km\nBjIhxBU1G9zzUwavE1gWh2fD0Aw9qduaDvv5uDr6EAQtGXCWo/Anr6pVX4KnSspa\n2Rz/Q4IR0A7MuRszZKnLKPJg7Tt1Y1dDXjvSnfD+yPXR5JdhfwIDAQABo18wXTAd\nBgNVHQ4EFgQUHIu2L8zKe5HgbHhXb/60LgJhPXgwPAYDVR0RBDUwM4IMaWRwLmFw\ndXMuZWR1hiNodHRwczovL2lkcC5hcHVzLmVkdS9pZHAvc2hpYmJvbGV0aDANBgkq\nhkiG9w0BAQsFAAOCAQEAhLa7Z0z6YK8smDjbNZcjDI/aGzJUy+A4sVE3LW+j4QGp\nSXYpcXWGuwHiUT5dehAK/+hXYyHTcsOxXKqfRR18D1oDd1ao9d1XMB+FvnzQjYkS\nDg4EeGcU51f0WOVDan5uskXicOPmDCrE21LW1UEbDGTqQDHQduKf1gqCX4t7uYAr\no24OC3bgXJbuG2OrqKHbKVbfkHEHydJwRvKzxU6+64Pn+0UvJpaBd+HksJAW0fx5\nuGx5aijPhN0BbMOsIwLQfzfGgq+yrBFBwbLIbdDWjJLWtz9F8DRGSBp0VwPU9jnA\nl892XxjtwvFhA5uiw4A/hMfzfwONtSoAe9wGpcCtVw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "American Public University System"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.apus.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "American Public University System"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://rdmc.nottingham.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itservicedesk@nottingham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "University of Nottingham IT Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Betts"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Craig.Betts@nottingham.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Craig"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://rdmc.nottingham.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-04T11:52:31Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "DSPACE"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://rdmc.nottingham.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Nottingham"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://rdmc.nottingham.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://rdmc.nottingham.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://rdmc.nottingham.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://rdmc.nottingham.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://rdmc.nottingham.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://rdmc.nottingham.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://rdmc.nottingham.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://rdmc.nottingham.ac.uk/Shibboleth.sso/UKfederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://rdmc.nottingham.ac.uk/Shibboleth.sso/UKfederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEpTCCA42gAwIBAgIRAJ2/okPnsHx5Wip6mqpvf1AwDQYJKoZIhvcNAQELBQAw\n\t\t\t\t\t\tZDELMAkGA1UEBhMCTkwxFjAUBgNVBAgTDU5vb3JkLUhvbGxhbmQxEjAQBgNVBAcT\n\t\t\t\t\t\tCUFtc3RlcmRhbTEPMA0GA1UEChMGVEVSRU5BMRgwFgYDVQQDEw9URVJFTkEgU1NM\n\t\t\t\t\t\tIENBIDIwHhcNMTUwNDAyMDAwMDAwWhcNMTgwNDAxMjM1OTU5WjBDMSEwHwYDVQQL\n\t\t\t\t\t\tExhEb21haW4gQ29udHJvbCBWYWxpZGF0ZWQxHjAcBgNVBAMTFXJkbWMubm90dGlu\n\t\t\t\t\t\tZ2hhbS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMkaEBv9\n\t\t\t\t\t\tb319Pbo1S5W9yga8aTnsLKw1rEg3wx0w4WgVZDVmjMhsnJ66I+IdxMqmBhPEyLPw\n\t\t\t\t\t\tLHZsdBe5cOW/pwnhxfTm0ie783QFiQn/9zmohCgWUI2rgFIDPc2r9bRPRkeuqJ7Z\n\t\t\t\t\t\t9ifY08oc1yBY1amk/ik9NYhYDM8DmiPz1+Vl8wntCKWz359Cnw3XqVigO+N3Jrga\n\t\t\t\t\t\tCtOa0E8YnhnxgCnQXDwgFxCQBMPoqiiiFCDo/G+IObIA8DOBGYdT0IDzERo+A0xC\n\t\t\t\t\t\tdakGAdHNQPDUkq/Z2Pdg2or0GmUeZOPvQOYDUjpZ6awpaJxHHxJBlqulTkbQU9Op\n\t\t\t\t\t\tM+pLJ0wglohcJusCAwEAAaOCAXEwggFtMB8GA1UdIwQYMBaAFFvQihyaMlvgtd2W\n\t\t\t\t\t\tVBvhhiiw/ba9MB0GA1UdDgQWBBTSjvnt304tu1RyfA0EvDFM+weCADAOBgNVHQ8B\n\t\t\t\t\t\tAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYB\n\t\t\t\t\t\tBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0f\n\t\t\t\t\t\tBDMwMTAvoC2gK4YpaHR0cDovL2NybC51c2VydHJ1c3QuY29tL1RFUkVOQVNTTENB\n\t\t\t\t\t\tMi5jcmwwbAYIKwYBBQUHAQEEYDBeMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnVz\n\t\t\t\t\t\tZXJ0cnVzdC5jb20vVEVSRU5BU1NMQ0EyLmNydDAlBggrBgEFBQcwAYYZaHR0cDov\n\t\t\t\t\t\tL29jc3AudXNlcnRydXN0LmNvbTAgBgNVHREEGTAXghVyZG1jLm5vdHRpbmdoYW0u\n\t\t\t\t\t\tYWMudWswDQYJKoZIhvcNAQELBQADggEBABC3WaY9MaO8xGuL44HR9+gsAY/ghCQy\n\t\t\t\t\t\tL85iGRhaxfyVw8N3e1leGsCpUdL23U2IxZfKmOitJPS29/VO0iw48cKpj8JHWM+f\n\t\t\t\t\t\tM9MHa64R5xdz2RX94tS055VwmBMUA5+trbxjBghDNve7lzA40Qem8gBiW4iE0mpe\n\t\t\t\t\t\tEldxgFRlWtDNql6kmdH9PbZGUV59ZosvzN6LFi1QHpPQMwpVkDGv+acbybA95ieF\n\t\t\t\t\t\t8F0iJHeANxWeyb/2GkDR+vuQ7UHpQ76rnYn4P8yCHU3uwegbX7GEkcz6oCCyiDUH\n\t\t\t\t\t\tCku4Jqus863LhvmD4gwnwkqqNrOLWpDJ2ED/KY/6bip25QsDgvQn4ZI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://rdmc.nottingham.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://rdmc.nottingham.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://rdmc.nottingham.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://rdmc.nottingham.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://rdmc.nottingham.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://rdmc.nottingham.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://bathspa.idm.oclc.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Support Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Support Desk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bathspa.idm.oclc.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-15T08:34:21Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bath Spa University Hosted EZproxy"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oclc.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "OCLC (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://login.bathspa.idm.oclc.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.bathspa.idm.oclc.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.bathspa.idm.oclc.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://login.bathspa.idm.oclc.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEDjCCAvagAwIBAgIBAjANBgkqhkiG9w0BAQUFADBnMR8wHQYDVQQDFBYqLmJh\n\t\t\t\t\t\tdGhzcGEuaWRtLm9jbGMub3JnMQswCQYDVQQGEwJVSzENMAsGA1UEChMET0NMQzEo\n\t\t\t\t\t\tMCYGCSqGSIb3DQEJARYZamFtZXMuaHV0Y2hpbnNvbkBvY2xjLm9yZzAeFw0xNTA1\n\t\t\t\t\t\tMTIxNTAwMTBaFw0yNTA1MTExNTAwMTBaMGcxHzAdBgNVBAMUFiouYmF0aHNwYS5p\n\t\t\t\t\t\tZG0ub2NsYy5vcmcxCzAJBgNVBAYTAlVLMQ0wCwYDVQQKEwRPQ0xDMSgwJgYJKoZI\n\t\t\t\t\t\thvcNAQkBFhlqYW1lcy5odXRjaGluc29uQG9jbGMub3JnMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAxMKFqwcpn26B1ScIzs6NFdszkiwlVIGDc3PAJogO\n\t\t\t\t\t\tvWVTCIiJPtuJmKHAT1648jb2/+wdku0FbSbwxuMWTXV/+dZse1pR1pRuUQW9ru7Y\n\t\t\t\t\t\thwscfhqBTyq45SN7zNTdZymJn6ToPSQSfP9WpodqJhgJGL2k3JFJGZWXl0Jp+zd+\n\t\t\t\t\t\tySfCxU2PVD6x8mh9Y1vkV7ZCtc/0+aSsCj72iln29wK2gtkXWjwRvuV/OjKmDtz1\n\t\t\t\t\t\tR0MUKJAdQFvpEvnM8riYl8ivNUOXLBHCUNsHf7ehuNry9Fze33hwE+b7MSzCwzn6\n\t\t\t\t\t\tLTSqrn9lj5UrOKMRAr3yPY3FKgnQxijexF2tIDjlstqpiQIDAQABo4HEMIHBMB0G\n\t\t\t\t\t\tA1UdDgQWBBSeXp6qeRYFjUiu/xEa3nrdd0d0XDCBkQYDVR0jBIGJMIGGgBSeXp6q\n\t\t\t\t\t\teRYFjUiu/xEa3nrdd0d0XKFrpGkwZzEfMB0GA1UEAxQWKi5iYXRoc3BhLmlkbS5v\n\t\t\t\t\t\tY2xjLm9yZzELMAkGA1UEBhMCVUsxDTALBgNVBAoTBE9DTEMxKDAmBgkqhkiG9w0B\n\t\t\t\t\t\tCQEWGWphbWVzLmh1dGNoaW5zb25Ab2NsYy5vcmeCAQIwDAYDVR0TBAUwAwEB/zAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAenYu+66MmJtk4Of778ctSVrt/AlXZ+D51DdbL8Xs\n\t\t\t\t\t\tPeizzPHZtzTWQzf80x69cCadksZu7RsAXVbopW7VN7HZ4yad7kvgNqkKUhKTB7Lz\n\t\t\t\t\t\ttcQxd/BOToJs7hCglOTYJQ92Jce9RmTfM7f7JXaV+kELdqd2GrF8+2zym7sJB5Af\n\t\t\t\t\t\tvfyv9B0XeuxE7IBoXmV8lVJGUYXYXKanFbNPv2FOGdkzdMKirlbrUr7aVUF8ZYcm\n\t\t\t\t\t\t4H3x2qGf3tdIrMH4E8ONOafEZt8A685ktADWXFXJ/SY/QQH+fJ15fFiOyGq2YaI9\n\t\t\t\t\t\t/L80KBx3p+HV0AJkENO5x2LPdJNaQ20ez6Mkkp/FAWLabQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://login.bathspa.idm.oclc.org/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://rigal.enpc.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dsi-exploitation@enpc.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://rigal.enpc.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-03-28T15:39:31Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://rigal.enpc.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://rigal.enpc.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://rigal.enpc.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "enpc.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.enpc.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "PhD and Service documentary \u00c9cole des Ponts ParisTech"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Doctorants et service documentaire de l'\u00c9cole des Ponts ParisTech"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u00c9cole des Ponts ParisTech"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u00c9cole des Ponts ParisTech"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUH3f/yFgC6fTl8d177PnqB8yGBfUwDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNcmlnYWwuZW5wYy5mcjAeFw0xNDAzMDMwOTIwMTFaFw0z\nNDAzMDMwOTIwMTFaMBgxFjAUBgNVBAMTDXJpZ2FsLmVucGMuZnIwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC1gDcOz8nWvGsuFucX+6kW5jtwJMMbDRR1\ngtOCqEiJGk1rgbQEDrUi30PQP67F4qnV/AsVuZqIY17YmTgDSIg/Fu+nkS4FoK5N\nRVWn24laimwKJuCKJHGe01aTsQl1rr+W0uFd2K7R7/dn2fDCHhdtfebNHEMYcE//\nef6yaBnkUewNpRApFj3WMJtOaQSg68DY0DYLEJZwU/d7UVKeYUiTk7J+K0wWdVX8\narjMUB4DvKo5s3hpatBpMj5SIdTRuWe4xAZqL/q+gSUZEHuaMRTg7frHlEFNK3vE\nsNGIKqvSmIvhsTW33NUStnl48WhsLI223phM7OCi2nQsI4Es7uqRAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDXJpZ2FsLmVucGMuZnKGJGh0dHBzOi8vcmlnYWwuZW5wYy5m\nci9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUvu92pbXivK9Fs+FYMN/ImZAwVMIw\nDQYJKoZIhvcNAQEFBQADggEBAJaDtoqa/0UAA0ubCVxJB587RFFavytKS7WJlk5X\nBRPIWKG/bSw0NGmzwPy32o4ZKfdp7nTNjJk6qk6w0ZDDRNA9dQkMZamNyVJDMF5/\nQG0wbOzJn8UPu/6A+tB9LwGwB3nX+FbML9DdxBVli9njUoFvNh0Ni4o6U/HXvPeq\nsEO4AsyB/pRaaLnY0f8l4JWQ7FamjxTnh8qHGJoqduObD7Xbb0qXVYkrbFlL3FPM\nPMKklaZEuFwUvhZv4b4/knBsTY44PY+O1RrRrCYPq9vp9Bom1ISiib5z4NEAdqmc\n9qZF1JjPaLWtNJBI1GyC1Pu5LMuR/e/8h0w1OliDby1w3fw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u00c9cole des Ponts ParisTech"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.enpc.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u00c9cole des Ponts ParisTech"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://identity.gettysburg.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "netmaint@gettysburg.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Eric Yurick"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ITHelpdesk@gettysburg.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "netmaint@gettysburg.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael Hayden"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://identity.gettysburg.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://identity.gettysburg.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://identity.gettysburg.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRzCCAi+gAwIBAgIUa3MGMc8uaB4aTTQas66uRLYPddMwDQYJKoZIhvcNAQEF\nBQAwIjEgMB4GA1UEAxMXaWRlbnRpdHkuZ2V0dHlzYnVyZy5lZHUwHhcNMTQwNTAy\nMjAxODIzWhcNMzQwNTAyMjAxODIzWjAiMSAwHgYDVQQDExdpZGVudGl0eS5nZXR0\neXNidXJnLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ8MSZuX\nQgeOYDw1Ym7kYYHBhuhm0Uvg+RKf3ASzvtsfI+ikRuYdjpiTDVxjBnSfCiJt12pl\n91YkchSk9cZZRdnlbgfxWEAb9oVmAxuSRF22sfdoZLu2fduTy9j/jb7zgT0VUatG\n54kleuiRStaIUdzxwEc3gmRuO6uFxv5Kg2caovFfxWgYdTmvjRSom7A6H4GNJ/5N\nIBVn1ygB8d3KZ65uocaZ6nXGY8Rursz1h324Zwd0DLYmLviKdq+R42poIOzLwMdz\nIWZX2BVzafibId6Cer8KzxW12heM+brfD/DmMDi+QPnZDglNPDZj0pxYjGPwwYqI\nNpKOV5ftGZ/vpdMCAwEAAaN1MHMwUgYDVR0RBEswSYIXaWRlbnRpdHkuZ2V0dHlz\nYnVyZy5lZHWGLmh0dHBzOi8vaWRlbnRpdHkuZ2V0dHlzYnVyZy5lZHUvaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFFYwuZiYNzL+zr9/ji52hEFMLZk8MA0GCSqGSIb3\nDQEBBQUAA4IBAQB6CMZYhPdkC6O6uGwg4bTWdlyZ1S4eAZBJbc9L05CmMpjqjHS+\nMz2QYy2Kss0CjDTEBDKplOF5AywgtROqff1vtzI4Ms3exfeeShfPTFry5pCSc4i3\nAref+AumaQYPc+IlHQuU5k3IhbU8wZLZpEOo/Z5hXdNMcy+A5k3TP/QTNgVY5efk\ngcSrWUynbwYsBwNVPprtFIDzt0ZUD6A1Gw6FYMW6gapHaNkZu0Nbw/5r/F8JrX8s\n2OfeRMA7g+yi6cFxonAIXYiwtkFqunjgM+GVtj3RkfA7AkYiOgKGAW+FSvqgGWdw\nqxNBz1YaAbi+ryPrCrHRrXZViELMLbf1WkK3"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gettysburg.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://identity.gettysburg.edu:8444/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://identity.gettysburg.edu:8444/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://identity.gettysburg.edu:8444/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://identity.gettysburg.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://identity.gettysburg.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gettysburg.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Single Sign On system for Gettysburg College students, faculty, staff, administrators and affiliates."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.gettysburg.edu/global2/images/template/logo2.gif",
                    "lang": "en",
                    "height": "33",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "125"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://www.gettysburg.edu/global/privacy_statement.dot"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Gettysburg College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRzCCAi+gAwIBAgIUa3MGMc8uaB4aTTQas66uRLYPddMwDQYJKoZIhvcNAQEF\nBQAwIjEgMB4GA1UEAxMXaWRlbnRpdHkuZ2V0dHlzYnVyZy5lZHUwHhcNMTQwNTAy\nMjAxODIzWhcNMzQwNTAyMjAxODIzWjAiMSAwHgYDVQQDExdpZGVudGl0eS5nZXR0\neXNidXJnLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ8MSZuX\nQgeOYDw1Ym7kYYHBhuhm0Uvg+RKf3ASzvtsfI+ikRuYdjpiTDVxjBnSfCiJt12pl\n91YkchSk9cZZRdnlbgfxWEAb9oVmAxuSRF22sfdoZLu2fduTy9j/jb7zgT0VUatG\n54kleuiRStaIUdzxwEc3gmRuO6uFxv5Kg2caovFfxWgYdTmvjRSom7A6H4GNJ/5N\nIBVn1ygB8d3KZ65uocaZ6nXGY8Rursz1h324Zwd0DLYmLviKdq+R42poIOzLwMdz\nIWZX2BVzafibId6Cer8KzxW12heM+brfD/DmMDi+QPnZDglNPDZj0pxYjGPwwYqI\nNpKOV5ftGZ/vpdMCAwEAAaN1MHMwUgYDVR0RBEswSYIXaWRlbnRpdHkuZ2V0dHlz\nYnVyZy5lZHWGLmh0dHBzOi8vaWRlbnRpdHkuZ2V0dHlzYnVyZy5lZHUvaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFFYwuZiYNzL+zr9/ji52hEFMLZk8MA0GCSqGSIb3\nDQEBBQUAA4IBAQB6CMZYhPdkC6O6uGwg4bTWdlyZ1S4eAZBJbc9L05CmMpjqjHS+\nMz2QYy2Kss0CjDTEBDKplOF5AywgtROqff1vtzI4Ms3exfeeShfPTFry5pCSc4i3\nAref+AumaQYPc+IlHQuU5k3IhbU8wZLZpEOo/Z5hXdNMcy+A5k3TP/QTNgVY5efk\ngcSrWUynbwYsBwNVPprtFIDzt0ZUD6A1Gw6FYMW6gapHaNkZu0Nbw/5r/F8JrX8s\n2OfeRMA7g+yi6cFxonAIXYiwtkFqunjgM+GVtj3RkfA7AkYiOgKGAW+FSvqgGWdw\nqxNBz1YaAbi+ryPrCrHRrXZViELMLbf1WkK3"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Gettysburg College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gettysburg.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Gettysburg College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:odu.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tdergens@odu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Todd Dergenski"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tdergens@odu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Todd Dergenski"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "itshelp@odu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support Center"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:odu.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.odu.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.odu.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE0zCCA7ugAwIBAgIJAM0WUqwWTWK5MA0GCSqGSIb3DQEBBQUAMIGhMQswCQYD\nVQQGEwJVUzERMA8GA1UECBMIVmlyZ2luaWExEDAOBgNVBAcTB05vcmZvbGsxIDAe\nBgNVBAoTF09sZCBEb21pbmlvbiBVbml2ZXJzaXR5MQ0wCwYDVQQLEwRPQ0NTMRsw\nGQYDVQQDExJzaGliYm9sZXRoLm9kdS5lZHUxHzAdBgkqhkiG9w0BCQEWEHRkZXJn\nZW5zQG9kdS5lZHUwHhcNMTIwNjI5MTQ0OTQwWhcNMTgwNjI4MTQ0OTQwWjCBoTEL\nMAkGA1UEBhMCVVMxETAPBgNVBAgTCFZpcmdpbmlhMRAwDgYDVQQHEwdOb3Jmb2xr\nMSAwHgYDVQQKExdPbGQgRG9taW5pb24gVW5pdmVyc2l0eTENMAsGA1UECxMET0ND\nUzEbMBkGA1UEAxMSc2hpYmJvbGV0aC5vZHUuZWR1MR8wHQYJKoZIhvcNAQkBFhB0\nZGVyZ2Vuc0BvZHUuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\ntmhF0eShpmRoaSU6VB2e0IFlmxGNOJxFmxdNcMT4vGOqV+3o+Hw6ja9uUSxfsLRt\ns9EgV4+XQAE2HMVRTcTDAuTpcZzhV+uY53Q5yQI0JyCEefBQkLZOhT2+Rgpw62lH\nELX0XK5DqlTc7oxTt3Sph2ZFsF+ae04jNKughZ7n8BZHLa5ArsBvFp4aOdK0BiDa\nGSbHqvRgZLPAB+W8fljQbwqUiuRQ4O2lVVqmRRON5NCK8QYk4f/1MPShX8g0z39g\nMLjGjZ5GAfRXFJgodTGiVXxD8Eh/ikDQJ86yMo19/92ZM1EGFOYrlLzFeV6lcv6p\nA4LibJoRrqdpeP+HIOtbdwIDAQABo4IBCjCCAQYwHQYDVR0OBBYEFCYuMzBiSlod\numXknepMcfO7oslaMIHWBgNVHSMEgc4wgcuAFCYuMzBiSlodumXknepMcfO7osla\noYGnpIGkMIGhMQswCQYDVQQGEwJVUzERMA8GA1UECBMIVmlyZ2luaWExEDAOBgNV\nBAcTB05vcmZvbGsxIDAeBgNVBAoTF09sZCBEb21pbmlvbiBVbml2ZXJzaXR5MQ0w\nCwYDVQQLEwRPQ0NTMRswGQYDVQQDExJzaGliYm9sZXRoLm9kdS5lZHUxHzAdBgkq\nhkiG9w0BCQEWEHRkZXJnZW5zQG9kdS5lZHWCCQDNFlKsFk1iuTAMBgNVHRMEBTAD\nAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQA6Oewdj4raYggafMVYUiIAn8dex1oBEX6S\nXN1Iw+XyHPXBJlSmf/L+qtDNyj8UMGaGebHbRPKiklxXd1J0pKvuzolwCphMrgXL\n8w0l4fr9368ZwM75/Gfs4MZeMObrlhsCRGfcX+xrefmcpjpTH/fwEOztvK+Gpq0o\nuhXaH0Ebso7KDEhBvZvDRmfR01SvUzpeftTsPRKnaWJTla1YUPgFszmjUkTJ1Qpa\ncnfTbgwJ96hKnHxmpK5uUsjV+V7EbuIPtI8tz5eL00nP8L/bXsgS3op6kHUk5+NS\noQUCVhY/uxrC4/QdhUjx1/LfsyW84/+U6K9xavH1VPQaRyzB7MlM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "odu.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.odu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.odu.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.odu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.odu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.odu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.odu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "odu.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://shibboleth.odu.edu"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Old Dominion University Shibboleth IDP"
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth.odu.edu/images/mkwl-logo-sm.png",
                    "lang": "en",
                    "height": "48",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "128"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Old Dominion University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE0zCCA7ugAwIBAgIJAM0WUqwWTWK5MA0GCSqGSIb3DQEBBQUAMIGhMQswCQYD\nVQQGEwJVUzERMA8GA1UECBMIVmlyZ2luaWExEDAOBgNVBAcTB05vcmZvbGsxIDAe\nBgNVBAoTF09sZCBEb21pbmlvbiBVbml2ZXJzaXR5MQ0wCwYDVQQLEwRPQ0NTMRsw\nGQYDVQQDExJzaGliYm9sZXRoLm9kdS5lZHUxHzAdBgkqhkiG9w0BCQEWEHRkZXJn\nZW5zQG9kdS5lZHUwHhcNMTIwNjI5MTQ0OTQwWhcNMTgwNjI4MTQ0OTQwWjCBoTEL\nMAkGA1UEBhMCVVMxETAPBgNVBAgTCFZpcmdpbmlhMRAwDgYDVQQHEwdOb3Jmb2xr\nMSAwHgYDVQQKExdPbGQgRG9taW5pb24gVW5pdmVyc2l0eTENMAsGA1UECxMET0ND\nUzEbMBkGA1UEAxMSc2hpYmJvbGV0aC5vZHUuZWR1MR8wHQYJKoZIhvcNAQkBFhB0\nZGVyZ2Vuc0BvZHUuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\ntmhF0eShpmRoaSU6VB2e0IFlmxGNOJxFmxdNcMT4vGOqV+3o+Hw6ja9uUSxfsLRt\ns9EgV4+XQAE2HMVRTcTDAuTpcZzhV+uY53Q5yQI0JyCEefBQkLZOhT2+Rgpw62lH\nELX0XK5DqlTc7oxTt3Sph2ZFsF+ae04jNKughZ7n8BZHLa5ArsBvFp4aOdK0BiDa\nGSbHqvRgZLPAB+W8fljQbwqUiuRQ4O2lVVqmRRON5NCK8QYk4f/1MPShX8g0z39g\nMLjGjZ5GAfRXFJgodTGiVXxD8Eh/ikDQJ86yMo19/92ZM1EGFOYrlLzFeV6lcv6p\nA4LibJoRrqdpeP+HIOtbdwIDAQABo4IBCjCCAQYwHQYDVR0OBBYEFCYuMzBiSlod\numXknepMcfO7oslaMIHWBgNVHSMEgc4wgcuAFCYuMzBiSlodumXknepMcfO7osla\noYGnpIGkMIGhMQswCQYDVQQGEwJVUzERMA8GA1UECBMIVmlyZ2luaWExEDAOBgNV\nBAcTB05vcmZvbGsxIDAeBgNVBAoTF09sZCBEb21pbmlvbiBVbml2ZXJzaXR5MQ0w\nCwYDVQQLEwRPQ0NTMRswGQYDVQQDExJzaGliYm9sZXRoLm9kdS5lZHUxHzAdBgkq\nhkiG9w0BCQEWEHRkZXJnZW5zQG9kdS5lZHWCCQDNFlKsFk1iuTAMBgNVHRMEBTAD\nAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQA6Oewdj4raYggafMVYUiIAn8dex1oBEX6S\nXN1Iw+XyHPXBJlSmf/L+qtDNyj8UMGaGebHbRPKiklxXd1J0pKvuzolwCphMrgXL\n8w0l4fr9368ZwM75/Gfs4MZeMObrlhsCRGfcX+xrefmcpjpTH/fwEOztvK+Gpq0o\nuhXaH0Ebso7KDEhBvZvDRmfR01SvUzpeftTsPRKnaWJTla1YUPgFszmjUkTJ1Qpa\ncnfTbgwJ96hKnHxmpK5uUsjV+V7EbuIPtI8tz5eL00nP8L/bXsgS3op6kHUk5+NS\noQUCVhY/uxrC4/QdhUjx1/LfsyW84/+U6K9xavH1VPQaRyzB7MlM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "http://shibboleth.odu.edu/error.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Old Dominion University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://web.odu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Old Dominion University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://www.pharmacopoeia.com/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pope"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nichol.pope@tso.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nichol"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Khurana"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Jaspaul.Khurana@tso.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jaspaul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://www.pharmacopoeia.com/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-09-14T13:31:36Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "British Pharmacopoeia"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.pharmacopoeia.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Stationery Office Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "British Pharmacopoeia"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.pharmacopoeia.com/assets/bp/images/british-pharmacopoeia.png",
                    "height": "106",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "480"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "British Pharmacopoeia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDcDCCAligAwIBAgIJAKNqg3+e59PHMA0GCSqGSIb3DQEBBQUAMC4xDDAKBgNV\n\t\t\t\t\t\tBAoTA1RTTzEeMBwGA1UEAxMVd3d3LnBoYXJtYWNvcG9laWEuY29tMB4XDTE1MDgw\n\t\t\t\t\t\tNzE1NDczNVoXDTI1MDgwNDE1NDczNVowLjEMMAoGA1UEChMDVFNPMR4wHAYDVQQD\n\t\t\t\t\t\tExV3d3cucGhhcm1hY29wb2VpYS5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQCtAr/AsZ79dO0pgPupqfStUaz5DmNqgkNhFBzyurii3T7A/gYhKK+d\n\t\t\t\t\t\tbuDgZCLTXLUHW64fOlM7vRDFWdmiZpwguVfm3PWaB8+i5drwPP2/3AEE3W0WzTeo\n\t\t\t\t\t\tdwxkGJCz9syQh2CStC/kW0bDVpn4O7QguwVtSX1oD6PunAcwIvri9wESkw6UeyZ1\n\t\t\t\t\t\t/rWgEXBhp6rXUyJi638dR6/nr8UTCEaxg2vUugw/yR4NqrB2tP2MAC1nsoG2QWwJ\n\t\t\t\t\t\tYoCnc7mAbELSloohgGMKAIf9bxq6avwOq+87YU/tgA0qMnwtgquTtKZWcowth3pG\n\t\t\t\t\t\tb8e4sbEZReDCskuDZYoCZbHY+xJva05tAgMBAAGjgZAwgY0wHQYDVR0OBBYEFB6r\n\t\t\t\t\t\tbmDDRDm0jgjnoldiBzw8xbmGMF4GA1UdIwRXMFWAFB6rbmDDRDm0jgjnoldiBzw8\n\t\t\t\t\t\txbmGoTKkMDAuMQwwCgYDVQQKEwNUU08xHjAcBgNVBAMTFXd3dy5waGFybWFjb3Bv\n\t\t\t\t\t\tZWlhLmNvbYIJAKNqg3+e59PHMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBACYjvdAjjvz4xRgC8HMpx+LFg3k0XCyEGxz8CZWOW3C+9fHLv906KHt/89Vb\n\t\t\t\t\t\tXq219cAfqjDKhtBrRDjslFbuFXtxlpT4GeGfkr8FskqH/4yUDEPzoE1tsZ++dEeJ\n\t\t\t\t\t\tJNRx6beS8x25YfHhT5oNIqLHu0S5sppl0175ipLzZLzvFOmCeRKJB4mI88vlN3PH\n\t\t\t\t\t\tgryT2uLDshfufiLzsJyGsJhwVxjJrTZpZkVVIsLN6euxeVi+b9dH+8aZlLULtYoU\n\t\t\t\t\t\t2kpGXv46PNFW01vl+J/EVxq3YitsdWzopSmjHYIZR0eKXDG4bAS6ulPAAElDsKlE\n\t\t\t\t\t\t0e00+Q6k8r5lfTGa50KV3OMQGR8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDcDCCAligAwIBAgIJAKNqg3+e59PHMA0GCSqGSIb3DQEBBQUAMC4xDDAKBgNV\n\t\t\t\t\t\tBAoTA1RTTzEeMBwGA1UEAxMVd3d3LnBoYXJtYWNvcG9laWEuY29tMB4XDTE1MDgw\n\t\t\t\t\t\tNzE1NDczNVoXDTI1MDgwNDE1NDczNVowLjEMMAoGA1UEChMDVFNPMR4wHAYDVQQD\n\t\t\t\t\t\tExV3d3cucGhhcm1hY29wb2VpYS5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQCtAr/AsZ79dO0pgPupqfStUaz5DmNqgkNhFBzyurii3T7A/gYhKK+d\n\t\t\t\t\t\tbuDgZCLTXLUHW64fOlM7vRDFWdmiZpwguVfm3PWaB8+i5drwPP2/3AEE3W0WzTeo\n\t\t\t\t\t\tdwxkGJCz9syQh2CStC/kW0bDVpn4O7QguwVtSX1oD6PunAcwIvri9wESkw6UeyZ1\n\t\t\t\t\t\t/rWgEXBhp6rXUyJi638dR6/nr8UTCEaxg2vUugw/yR4NqrB2tP2MAC1nsoG2QWwJ\n\t\t\t\t\t\tYoCnc7mAbELSloohgGMKAIf9bxq6avwOq+87YU/tgA0qMnwtgquTtKZWcowth3pG\n\t\t\t\t\t\tb8e4sbEZReDCskuDZYoCZbHY+xJva05tAgMBAAGjgZAwgY0wHQYDVR0OBBYEFB6r\n\t\t\t\t\t\tbmDDRDm0jgjnoldiBzw8xbmGMF4GA1UdIwRXMFWAFB6rbmDDRDm0jgjnoldiBzw8\n\t\t\t\t\t\txbmGoTKkMDAuMQwwCgYDVQQKEwNUU08xHjAcBgNVBAMTFXd3dy5waGFybWFjb3Bv\n\t\t\t\t\t\tZWlhLmNvbYIJAKNqg3+e59PHMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBACYjvdAjjvz4xRgC8HMpx+LFg3k0XCyEGxz8CZWOW3C+9fHLv906KHt/89Vb\n\t\t\t\t\t\tXq219cAfqjDKhtBrRDjslFbuFXtxlpT4GeGfkr8FskqH/4yUDEPzoE1tsZ++dEeJ\n\t\t\t\t\t\tJNRx6beS8x25YfHhT5oNIqLHu0S5sppl0175ipLzZLzvFOmCeRKJB4mI88vlN3PH\n\t\t\t\t\t\tgryT2uLDshfufiLzsJyGsJhwVxjJrTZpZkVVIsLN6euxeVi+b9dH+8aZlLULtYoU\n\t\t\t\t\t\t2kpGXv46PNFW01vl+J/EVxq3YitsdWzopSmjHYIZR0eKXDG4bAS6ulPAAElDsKlE\n\t\t\t\t\t\t0e00+Q6k8r5lfTGa50KV3OMQGR8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://www.pharmacopoeia.com/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.pharmacopoeia.com/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.astonsu.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.astonsu.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-09-08T09:46:13Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Aston Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.astonsu.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.astonsu.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.astonsu.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.astonsu.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.astonsu.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.astonsu.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.astonsu.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.astonsu.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.astonsu.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.astonsu.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.astonsu.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.astonsu.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.astonsu.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.astonsu.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.astonsu.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.astonsu.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.astonsu.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.onlinelibrary.wiley.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:wps-olhelp@wiley.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:wps-olhelp@wiley.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.onlinelibrary.wiley.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-07-27T11:15:10Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "John Wiley & Sons Limited: Wiley Online Library"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://wiley.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "John Wiley & Sons Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.onlinelibrary.wiley.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.onlinelibrary.wiley.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.onlinelibrary.wiley.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.onlinelibrary.wiley.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "John Wiley & Sons Limited: Wiley Online Library"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This service allows Wiley Online Library users to use login credentials at their home organisations."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.onlinelibrary.wiley.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service allows Wiley Online Library users to use login credentials at their home organisations"
                  }
                ],
                "logo": [
                  {
                    "text": "https://sp.onlinelibrary.wiley.com/images/WOL_Stacked_k.gif",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "74"
                  },
                  {
                    "text": "https://sp.onlinelibrary.wiley.com/images/WOL_favicon.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "John Wiley & Sons Limited: Wiley Online Library"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sp.onlinelibrary.wiley.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp.onlinelibrary.wiley.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFTDCCBDSgAwIBAgIQGN7fuC0Uze8yew92tsrArTANBgkqhkiG9w0BAQUFADCB\n\t\t\t\t\t\ttTELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMR8wHQYDVQQL\n\t\t\t\t\t\tExZWZXJpU2lnbiBUcnVzdCBOZXR3b3JrMTswOQYDVQQLEzJUZXJtcyBvZiB1c2Ug\n\t\t\t\t\t\tYXQgaHR0cHM6Ly93d3cudmVyaXNpZ24uY29tL3JwYSAoYykxMDEvMC0GA1UEAxMm\n\t\t\t\t\t\tVmVyaVNpZ24gQ2xhc3MgMyBTZWN1cmUgU2VydmVyIENBIC0gRzMwHhcNMTQwNjA0\n\t\t\t\t\t\tMDAwMDAwWhcNMTYwNzE3MjM1OTU5WjCBljELMAkGA1UEBhMCVVMxEzARBgNVBAgT\n\t\t\t\t\t\tCk5ldyBKZXJzZXkxETAPBgNVBAcUCFNvbWVyc2V0MR8wHQYDVQQKFBZKb2huIFdp\n\t\t\t\t\t\tbGV5ICYgU29ucywgSW5jMRkwFwYDVQQLFBBJbnRlcm5ldCBIb3N0aW5nMSMwIQYD\n\t\t\t\t\t\tVQQDFBpzcC5vbmxpbmVsaWJyYXJ5LndpbGV5LmNvbTCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBALxNMyyEQztZxX2CnHwTsI5AIKhOza2HNuJ7fsfbmnS7\n\t\t\t\t\t\txCaDNVaVoT9nWvpLNwJ8Dn54IYCVJoFtnwkWHFu/E6AKjGROJt1YDQUMmoeNse+/\n\t\t\t\t\t\tL1fj5NdGSiUpmFdnrJFSB5dFQ1qDG3R+23lfEZCKqByqEd6nnNZJIgMe32+1vA+k\n\t\t\t\t\t\tS46cU2tRw+Z5UUDjdZ5dyTjKpdQ4mC+zQW4X1h6vrouNxcs/1En+EFqadQuVmLsQ\n\t\t\t\t\t\tYzkj0eLBGrYatWNELyZOxIOFj8ERb9Z+08eiXHa19K7uYUHw7ZBlyYciJZNZYVbw\n\t\t\t\t\t\t59YiXaByT9BR7cFgGxNKoAJpfw+PsBnT7kFB103yxqkCAwEAAaOCAXMwggFvMCUG\n\t\t\t\t\t\tA1UdEQQeMByCGnNwLm9ubGluZWxpYnJhcnkud2lsZXkuY29tMAkGA1UdEwQCMAAw\n\t\t\t\t\t\tDgYDVR0PAQH/BAQDAgWgMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjBl\n\t\t\t\t\t\tBgNVHSAEXjBcMFoGCmCGSAGG+EUBBzYwTDAjBggrBgEFBQcCARYXaHR0cHM6Ly9k\n\t\t\t\t\t\tLnN5bWNiLmNvbS9jcHMwJQYIKwYBBQUHAgIwGRoXaHR0cHM6Ly9kLnN5bWNiLmNv\n\t\t\t\t\t\tbS9ycGEwHwYDVR0jBBgwFoAUDURcFlNEwYJ+HSCrJfQBY9i+eaUwKwYDVR0fBCQw\n\t\t\t\t\t\tIjAgoB6gHIYaaHR0cDovL3NkLnN5bWNiLmNvbS9zZC5jcmwwVwYIKwYBBQUHAQEE\n\t\t\t\t\t\tSzBJMB8GCCsGAQUFBzABhhNodHRwOi8vc2Quc3ltY2QuY29tMCYGCCsGAQUFBzAC\n\t\t\t\t\t\thhpodHRwOi8vc2Quc3ltY2IuY29tL3NkLmNydDANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tDc2lww9Dk/JaDPLQoHbqQjprtJZUTe9cEVvu02AKWMGvNlaUWDeHAqd1D+dbmMn7\n\t\t\t\t\t\tmIXhqERDQUiEr7kS9yehKNSazQXvNy5S9xnPuO64m77zoDTslWIREyRgRPClxmvE\n\t\t\t\t\t\t6LXZzucaLy1KMuuiWK2Jle/yb8e9s5M51jU0UQVVQjFQaWe1NKUzrt31QgWAgTWX\n\t\t\t\t\t\tvSMwOdHJKGYpHXjpalopAX8fNV4lNg6kt9Ob3kJsQtUQkVLlPkwaVwlVLgWjbTIO\n\t\t\t\t\t\tavofP9ub8R9GYHjPSoX6IlOlJTFigxBnP4AonNGmQZjVgqp81MZSMhwEo7MZvhnT\n\t\t\t\t\t\tQQTmkDY7OVzHpicSEkVGKw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.onlinelibrary.wiley.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.onlinelibrary.wiley.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.onlinelibrary.wiley.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.onlinelibrary.wiley.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.onlinelibrary.wiley.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp.onlinelibrary.wiley.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.onlinelibrary.wiley.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp.onlinelibrary.wiley.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp.onlinelibrary.wiley.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp.onlinelibrary.wiley.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://dev.niif.hu/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NIIFI AAI"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@niif.hu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NIIFI AAI"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@niif.hu"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NIIFI AAI"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@niif.hu"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dev.niif.hu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-edugain"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:geant:niif.hu:eduid.hu:entity-attributes:processing-info",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "hu",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://metadata.eduid.hu/registration_policy_1_0.txt"
              }
            ],
            "registration_instant": "2013-08-01T07:17:19.807Z",
            "registration_authority": "http://eduid.hu",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NIIF - Nemzeti Inform\u00e1ci\u00f3s Infrastrukt\u00fara Fejleszt\u00e9si Int\u00e9zet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NIIF Institute - National Information Infrastructure Development"
          }
        ],
        "organization_url": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.niif.hu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.niif.hu/en"
          }
        ],
        "organization_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NIIF - Nemzeti Inform\u00e1ci\u00f3s Infrastrukt\u00fara Fejleszt\u00e9si Int\u00e9zet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NIIF Institute - National Information Infrastructure Development"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dev.niif.hu/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://dev.niif.hu/"
                  }
                ],
                "description": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "K\u00f6z\u00f6s fejleszt\u00e9st t\u00e1mogat\u00f3 k\u00f6rnyezet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Development support platform"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.eduid.hu/dev-niif-hu-adatkezelesi-szabalyzat/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "dev.niif.hu - NIIF Gitlab"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "dev.niif.hu - NIIF Gitlab"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "dev.niif.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.niif.hu/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.niif.hu/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "hu",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "dev.niif.hu - NIIF Gitlab"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "dev.niif.hu - NIIF Gitlab"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.sthelenslife.net/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@uniservity.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UniServity Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Zefaj"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rezar.zafaj@uniservity.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rezar"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.sthelenslife.net/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-09-01T16:34:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UniServity Limited: St Helens Council"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uniservity.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UniServity Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.sthelenslife.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.sthelenslife.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.sthelenslife.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.sthelenslife.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "1",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.sthelenslife.net/Shibboleth.sso/Secure",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAMzAs1ASwVMDMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\n\t\t\t\t\t\tBAMTFHd3dy5zdGhlbGVuc2xpZmUubmV0MB4XDTExMDgzMTEzMTk0M1oXDTIxMDgy\n\t\t\t\t\t\tODEzMTk0M1owHzEdMBsGA1UEAxMUd3d3LnN0aGVsZW5zbGlmZS5uZXQwggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDsKV5eWwWRG6z8eVRrTLoDtZcSftHI\n\t\t\t\t\t\tBYUX13hrU8cE1IofG58fDeoJhwJY0joxnnpwNQZGNolX0EIIjNNbW9CSckPwJxSl\n\t\t\t\t\t\tRTHXK2J6R4PjMePxLNAetK9V0oxC0PMz28n30N6iyP/LyYr9+rdYyLElQawtM2ZN\n\t\t\t\t\t\t2U7erDr215gP7GDd6sqWmp+s6hKhHdjLFbCLBgTOlCFVMiz17x4Z0DbemQZsbmja\n\t\t\t\t\t\tj7YdIcVeqTNLludEKIcg5Hl7XXyXbiAyBnlK1S0ljW89+2b6g9Kr2aVNBg3hRi6O\n\t\t\t\t\t\tTdru8W+kbkvU5JxGK7hOSZZtRiZi9YO9wcbsuQh43mVfyyTS6+4TQsd3AgMBAAGj\n\t\t\t\t\t\tazBpMEgGA1UdEQRBMD+CFHd3dy5zdGhlbGVuc2xpZmUubmV0hidodHRwczovL3d3\n\t\t\t\t\t\tdy5zdGhlbGVuc2xpZmUubmV0L3NoaWJib2xldGgwHQYDVR0OBBYEFHcQZY+V9asV\n\t\t\t\t\t\t5kkMf9gJVci4/nK4MA0GCSqGSIb3DQEBBQUAA4IBAQDjzLkEqEVDhilutvybAtkZ\n\t\t\t\t\t\tQaO++l/AlDpB8Bb4E2EdeKxIFXRxWoRmPT4SFtbKlGRMG6Pw9hpC6ujw9s+oNq2E\n\t\t\t\t\t\tGRnGRT44qUcd3YpUdjS2puF13vtqY7q+dWgMk2WzI+5v+I8DckPo0j603F9rlGgR\n\t\t\t\t\t\tWUT2yIvdX+m/AEMeWowT5qYfv0Qdmf7dWrn/H4ITlUb8Rw10DtFL5aWSEu+lVK0E\n\t\t\t\t\t\tafPqDUGNuJgpItPpvxVX7yKHooGSQkdigJqwN+lyrusV6OZt2fnrKZkr3nSTjYfg\n\t\t\t\t\t\tyQBZZJMd4TmXDz4KAxPrktUlomUIorfnKHBMSVwvF6hYYNOe4rXpTCqHxeNetBcW"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.sthelenslife.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.sthelenslife.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib-idp.cms.hu-berlin.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Berg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibadmin@hu-berlin.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petra"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Berg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibadmin@hu-berlin.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petra"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Berg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibadmin@hu-berlin.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petra"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib-idp.cms.hu-berlin.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2011-10-21T09:44:34Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shibboleth.uvf.hu-berlin.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGUzCCBTugAwIBAgIHGYZDvIB0rjANBgkqhkiG9w0BAQsFADBoMQswCQYDVQQG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\nmFsxhGZXe6H3Sr7aLhCsdB+7yKCROUaNU9C28W9fp3N+oFK8AGpt"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=shibboleth.uvf.hu-berlin.de,OU=ZE Computer- und Medienservice,O=Humboldt-Universitaet zu Berlin,L=Berlin,ST=Berlin,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hu-berlin.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-idp.cms.hu-berlin.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.cms.hu-berlin.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "response_location": "https://shib-idp.cms.hu-berlin.de/idp/profile/SAML2/Redirect/SLO",
              "location": "https://shib-idp.cms.hu-berlin.de/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "response_location": "https://shib-idp.cms.hu-berlin.de/idp/profile/SAML2/POST/SLO",
              "location": "https://shib-idp.cms.hu-berlin.de/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.cms.hu-berlin.de:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib-idp.cms.hu-berlin.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-idp.cms.hu-berlin.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib-idp.cms.hu-berlin.de/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-idp.cms.hu-berlin.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-idp.cms.hu-berlin.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.cms.hu-berlin.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hu-berlin.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.hu-berlin.de/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.hu-berlin.de/"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IdP der Humboldt-Universit\u00e4t zu Berlin"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IdP der Humboldt-Universit\u00e4t zu Berlin"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Humboldt-Universit\u00e4t zu Berlin"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Humboldt-Universit\u00e4t zu Berlin"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shibboleth.uvf.hu-berlin.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGUzCCBTugAwIBAgIHGYZDvIB0rjANBgkqhkiG9w0BAQsFADBoMQswCQYDVQQG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\nmFsxhGZXe6H3Sr7aLhCsdB+7yKCROUaNU9C28W9fp3N+oFK8AGpt"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=shibboleth.uvf.hu-berlin.de,OU=ZE Computer- und Medienservice,O=Humboldt-Universitaet zu Berlin,L=Berlin,ST=Berlin,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Humboldt-Universit\u00e4t zu Berlin"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Humboldt-University Berlin"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hu-berlin.de/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hu-berlin.de/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e233"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e233"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://cambro-tst1.umdc.umu.se/shibboleth",
    {
      "entity_id": "https://cambro-tst1.umdc.umu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cambro-tst1.umdc.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cambro-tst1.umdc.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cambro-tst1.umdc.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cambro-tst1.umdc.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://cambro-tst1.umdc.umu.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "cambro-tst1.umdc.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEhzCCA2+gAwIBAgIQNCZ6Wao5rCiMh8bMn8dl9DANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEwMDEwNDAwMDAwMFoXDTEzMDEwMzIzNTk1OVowWzELMAkGA1UE\nBhMCU0UxGjAYBgNVBAoMEVVtZcOlIHVuaXZlcnNpdGV0MQ4wDAYDVQQLEwVVTURB\nQzEgMB4GA1UEAxMXY2FtYnJvLXRzdDEudW1kYy51bXUuc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQD35dREFJcNZx8SrndY6t23IFA+HZPzlqSlYqgb\nsh5Es7k7pg2T0XllCoc8NfJB/g2OtJSVZr3ANKFaIei4q4u/blN3BFwEKQsyXbly\nlqJXKvPlOvyPzmC67vPB+2gWlLAOa2bRpGa/VkUFGis+yk+WITMwfNiHnap/Bq4Q\ngmgH9EgNDssTEHU1CCh7IrUKIpKfQVsoVLUGxoWxYLFMfGhgJfq3OtMQvvydN6hN\necvoeVydOvdXegI/OZGxKGGYeiWH3kqMjTmfHzCLnw5YexBr3WHxgoxar2XfQPwB\nI/5wTtVLjQZkF4QoMkP/82Q1MshaPwHpoOV40sQ3nYwgZiFVAgMBAAGjggFqMIIB\nZjAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3V0fqkOO57TAdBgNVHQ4EFgQU+HiE\nq3c7HVUR0vHnWLyyDOdQCyUwDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAw\nHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMBgGA1UdIAQRMA8wDQYLKwYB\nBAGyMQECAh0wOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5h\nLm9yZy9URVJFTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAC\nhilodHRwOi8vY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggr\nBgEFBQcwAYYaaHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwIgYDVR0RBBswGYIX\nY2FtYnJvLXRzdDEudW1kYy51bXUuc2UwDQYJKoZIhvcNAQEFBQADggEBALzxzMtR\no8BxLXRi9FB72jRQeNu7KfRgpSrqLmAMlKQRamNl3VjinUOAuNXR7Ri4tKJ+9oAN\nvneP9Hion4ppXksU6OSUE/6zByAdF21zVe62DaczHS77urZMqgXIThDVwl0XOtai\nLlDHkbIs6OVYwrp//pPTNQ/j4GnPZOA1Ghnw+FXRHRLD1sOqZWGkCXzWJETZIH7y\nuBq90+cT5Jw5XHICeLGVy5QipR08cJS7JJTcdVPxDMqgzv0gsgVG7n4GUMkedSmI\nNRAsAsB2WLZT+aJN5LHLkPGEq64W8hV8QPUUZfsIMbnSdwpQNFG5FrA9MwCjQqe5\nn5/yB4LGJWrAQjc="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=cambro-tst1.umdc.umu.se,OU=UMDAC,O=Ume\\C3\\A5 universitet,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "cambro-tst1.umdc.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEhzCCA2+gAwIBAgIQNCZ6Wao5rCiMh8bMn8dl9DANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEwMDEwNDAwMDAwMFoXDTEzMDEwMzIzNTk1OVowWzELMAkGA1UE\nBhMCU0UxGjAYBgNVBAoMEVVtZcOlIHVuaXZlcnNpdGV0MQ4wDAYDVQQLEwVVTURB\nQzEgMB4GA1UEAxMXY2FtYnJvLXRzdDEudW1kYy51bXUuc2UwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQD35dREFJcNZx8SrndY6t23IFA+HZPzlqSlYqgb\nsh5Es7k7pg2T0XllCoc8NfJB/g2OtJSVZr3ANKFaIei4q4u/blN3BFwEKQsyXbly\nlqJXKvPlOvyPzmC67vPB+2gWlLAOa2bRpGa/VkUFGis+yk+WITMwfNiHnap/Bq4Q\ngmgH9EgNDssTEHU1CCh7IrUKIpKfQVsoVLUGxoWxYLFMfGhgJfq3OtMQvvydN6hN\necvoeVydOvdXegI/OZGxKGGYeiWH3kqMjTmfHzCLnw5YexBr3WHxgoxar2XfQPwB\nI/5wTtVLjQZkF4QoMkP/82Q1MshaPwHpoOV40sQ3nYwgZiFVAgMBAAGjggFqMIIB\nZjAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3V0fqkOO57TAdBgNVHQ4EFgQU+HiE\nq3c7HVUR0vHnWLyyDOdQCyUwDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAw\nHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMBgGA1UdIAQRMA8wDQYLKwYB\nBAGyMQECAh0wOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5h\nLm9yZy9URVJFTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAC\nhilodHRwOi8vY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggr\nBgEFBQcwAYYaaHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwIgYDVR0RBBswGYIX\nY2FtYnJvLXRzdDEudW1kYy51bXUuc2UwDQYJKoZIhvcNAQEFBQADggEBALzxzMtR\no8BxLXRi9FB72jRQeNu7KfRgpSrqLmAMlKQRamNl3VjinUOAuNXR7Ri4tKJ+9oAN\nvneP9Hion4ppXksU6OSUE/6zByAdF21zVe62DaczHS77urZMqgXIThDVwl0XOtai\nLlDHkbIs6OVYwrp//pPTNQ/j4GnPZOA1Ghnw+FXRHRLD1sOqZWGkCXzWJETZIH7y\nuBq90+cT5Jw5XHICeLGVy5QipR08cJS7JJTcdVPxDMqgzv0gsgVG7n4GUMkedSmI\nNRAsAsB2WLZT+aJN5LHLkPGEq64W8hV8QPUUZfsIMbnSdwpQNFG5FrA9MwCjQqe5\nn5/yB4LGJWrAQjc="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=cambro-tst1.umdc.umu.se,OU=UMDAC,O=Ume\\C3\\A5 universitet,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cambro-tst1.umdc.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cambro-tst1.umdc.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cambro-tst1.umdc.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cambro-tst1.umdc.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cambro-tst1.umdc.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cambro-tst1.umdc.umu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cambro-tst1.umdc.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://cambro-tst1.umdc.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://cambro-tst1.umdc.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://cambro-tst1.umdc.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.mines-ales.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "cisana"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pascal.cisana@mines-ales.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "pellissier"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "laurent.pellissier@mines-ales.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.mines-ales.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2011-06-16T12:03:53Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.mines-ales.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.mines-ales.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.mines-ales.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mines-ales.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mines-ales.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Permanents et Etudiants"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "7",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole des Mines d'Al\u00e8s"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole des Mines d'Al\u00e8s"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIVAIqjvHm0aoiaxBOCA0hQPBF/i3NHMA0GCSqGSIb3DQEB\nBQUAMCMxITAfBgNVBAMTGHNoaWJib2xldGgubWluZXMtYWxlcy5mcjAeFw0xMDAy\nMDUxNTM3MzNaFw0zMDAyMDUxNTM3MzNaMCMxITAfBgNVBAMTGHNoaWJib2xldGgu\nbWluZXMtYWxlcy5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAItD\naS5KDMxNFvZLeYTCJMufD5l6n30RVg7kPxP6QDJsXvCyKW8kaAojwgr0BUNhIuWW\n9KYTab705HN9IUTNHQGngYmcLtOvMvX5eGO9tYKXqBA+vjSyCet5HRSd8bimtjwJ\nmHfOheQXeHtHtF4gcM5rKlToUdny4UKc3V5EaglZPOsgA9bIdLX/XGuXORoU7C8d\njQpyo3Y6knBQsxHfZEZFiIUQTBfenc/Hqt5+ialLA4OqjR/yZATpVXZubVf1f2Vj\nXEo4685sWxRC2IsZ0IIjCtEWvf+9P4jEgiBW/M9FFwhXLkofqbossasVs+INU04m\nUGfb7SH1222oPbeawBECAwEAAaN3MHUwVAYDVR0RBE0wS4IYc2hpYmJvbGV0aC5t\naW5lcy1hbGVzLmZyhi9odHRwczovL3NoaWJib2xldGgubWluZXMtYWxlcy5mci9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUTlAtOzPum6kvlDfiRmAWJAeNWVswDQYJ\nKoZIhvcNAQEFBQADggEBAD4IpGmClwDAJUSTNQeYZoRCk5dliPTxshVu/X1QLfLg\noonrMZBGnnbJPqATRQDQyGnDjL7v437cDtzOtpCMYIOLiGIFtBdS/dupqNNvKMJg\nwX5vqXzxlSZNkwHveUeipfZvvRDYNEwwGsGaMWFiYYxQlncMl9ebxvvF+dNyYzue\nHTU084KFhXJ+hhq+HTvPIxAm6xS0SJI9lM5E2OaSh+Twy0+ItMFcF5dHl9BpfiZI\nE3TaYCTUy81TNeHR1G8FxfdCea+Dz1w5jT+mX9l3ZsIZ36HXX6avx+go0MlzEa8d\nBArDDouye8IrssgKRMfPT0sQ0b+Nw56O2B4u/+48w4A="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ecole des Mines d'Al\u00e8s"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mines-ales.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ecole des Mines d'Al\u00e8s"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.edina.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:edina@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EDINA Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:edina.infrastructure@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EDINA Infrastructure"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ukfed.infrastructure@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UK federation infrastructure"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.edina.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-06-24T17:03:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUZ8boiTD4RixSt29es15v8YO8F34wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAwwUZGxpYi1pZHAuZWRpbmEuYWMudWswHhcNMTUwNDE1MTQz\n\t\t\t\t\t\tMjQ0WhcNMzUwNDE1MTQzMjQ0WjAfMR0wGwYDVQQDDBRkbGliLWlkcC5lZGluYS5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAItcB9RJ4egqyCLB\n\t\t\t\t\t\tmuirezae3x3BYwITlDc9JTCGHJkqZigd8lwL6POMgjFip1uIqjd4SRmh3ToXD7+I\n\t\t\t\t\t\tJi1kLFbRD7ndpoC4Y/x2Szsgq2Vfly22znIR4825KroMPd4VlpLFs9U0oK2Mh12J\n\t\t\t\t\t\tl7srcFAnUWHVLKFDL+jpKPCuX0Iioy+Wxkku9Hpo/J+I+ftDCk7f2dMw+1ZPOsBj\n\t\t\t\t\t\tFYRfQhb2ttfs+tiiE5QWanFArQrEMfKB+9OaheBOd8GnxgQaL4tomf3P33vcz3T5\n\t\t\t\t\t\t+fpu38bjBFe7BlUGCLF0YGXrNV7DfT1HIf/tJtcbrZhcWmEUCxZSWpUnQ6RVTeBQ\n\t\t\t\t\t\tUjZAFdMCAwEAAaNvMG0wHQYDVR0OBBYEFD2dMjYASBgbSAgYQecY5Rk+9zCeMEwG\n\t\t\t\t\t\tA1UdEQRFMEOCFGRsaWItaWRwLmVkaW5hLmFjLnVrhitodHRwczovL2RsaWItaWRw\n\t\t\t\t\t\tLmVkaW5hLmFjLnVrL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBBQUAA4IBAQA8\n\t\t\t\t\t\t/cfWH9Dw05/JDdZxpW5lDqbIC9sMBZoJUmxLGCRSAiOI+yftyO8tcX7kCmRGPkdp\n\t\t\t\t\t\trXY1Mhta/ZfZTp82wiqfS7xAXAPKn5ExuuNnIVCYLjzsgsyYVeJeB8nCSkXe9bdp\n\t\t\t\t\t\tvzRDO+Sa2gZLM16CdsEIfuKUzqO68gIcFeZentQHYjCYFfwGUVrf7XF8yosRXIvx\n\t\t\t\t\t\t1roqZA3Ej7bVZ2d1sQVM0G77BT7Yngefz66rQUcgHMQHdXiF1/9XeVDeyzDI85AU\n\t\t\t\t\t\tbFwFjyGIOmTeUTfN4ekLZ596U7/IHoJRqIzWRtgKhIq9UgQpRNijkIjyEXxnIU4b\n\t\t\t\t\t\tTJoGlwD1bfDo3vnukwHI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edina.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "trial.edina.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://dlib-idp.edina.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-idp.edina.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://dlib-idp.edina.ac.uk/shibboleth-idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dlib-idp.edina.ac.uk/shibboleth-idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dlib-idp.edina.ac.uk/shibboleth-idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dlib-idp.edina.ac.uk/shibboleth-idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://dlib-idp.edina.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-idp.edina.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edina.ac.uk"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "trial.edina.ac.uk"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "EDINA-internal IdP"
                  }
                ],
                "logo": [
                  {
                    "text": "https://dlib-idp.edina.ac.uk/img/edina.gif",
                    "height": "57",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "113"
                  },
                  {
                    "text": "https://dlib-idp.edina.ac.uk/img/edina-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EDINA (staff and trials)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUZ8boiTD4RixSt29es15v8YO8F34wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAwwUZGxpYi1pZHAuZWRpbmEuYWMudWswHhcNMTUwNDE1MTQz\n\t\t\t\t\t\tMjQ0WhcNMzUwNDE1MTQzMjQ0WjAfMR0wGwYDVQQDDBRkbGliLWlkcC5lZGluYS5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAItcB9RJ4egqyCLB\n\t\t\t\t\t\tmuirezae3x3BYwITlDc9JTCGHJkqZigd8lwL6POMgjFip1uIqjd4SRmh3ToXD7+I\n\t\t\t\t\t\tJi1kLFbRD7ndpoC4Y/x2Szsgq2Vfly22znIR4825KroMPd4VlpLFs9U0oK2Mh12J\n\t\t\t\t\t\tl7srcFAnUWHVLKFDL+jpKPCuX0Iioy+Wxkku9Hpo/J+I+ftDCk7f2dMw+1ZPOsBj\n\t\t\t\t\t\tFYRfQhb2ttfs+tiiE5QWanFArQrEMfKB+9OaheBOd8GnxgQaL4tomf3P33vcz3T5\n\t\t\t\t\t\t+fpu38bjBFe7BlUGCLF0YGXrNV7DfT1HIf/tJtcbrZhcWmEUCxZSWpUnQ6RVTeBQ\n\t\t\t\t\t\tUjZAFdMCAwEAAaNvMG0wHQYDVR0OBBYEFD2dMjYASBgbSAgYQecY5Rk+9zCeMEwG\n\t\t\t\t\t\tA1UdEQRFMEOCFGRsaWItaWRwLmVkaW5hLmFjLnVrhitodHRwczovL2RsaWItaWRw\n\t\t\t\t\t\tLmVkaW5hLmFjLnVrL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBBQUAA4IBAQA8\n\t\t\t\t\t\t/cfWH9Dw05/JDdZxpW5lDqbIC9sMBZoJUmxLGCRSAiOI+yftyO8tcX7kCmRGPkdp\n\t\t\t\t\t\trXY1Mhta/ZfZTp82wiqfS7xAXAPKn5ExuuNnIVCYLjzsgsyYVeJeB8nCSkXe9bdp\n\t\t\t\t\t\tvzRDO+Sa2gZLM16CdsEIfuKUzqO68gIcFeZentQHYjCYFfwGUVrf7XF8yosRXIvx\n\t\t\t\t\t\t1roqZA3Ej7bVZ2d1sQVM0G77BT7Yngefz66rQUcgHMQHdXiF1/9XeVDeyzDI85AU\n\t\t\t\t\t\tbFwFjyGIOmTeUTfN4ekLZ596U7/IHoJRqIzWRtgKhIq9UgQpRNijkIjyEXxnIU4b\n\t\t\t\t\t\tTJoGlwD1bfDo3vnukwHI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EDINA (staff and trials)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://edina.ac.uk/about/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.elte.hu/auth/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ELTE IIG Informatikai Szolg\u00e1ltat\u00e1si Oszt\u00e1ly"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:system@caesar.elte.hu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ELTE IIG Informatikai Szolg\u00e1ltat\u00e1si Oszt\u00e1ly"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:system@caesar.elte.hu"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ELTE IIG \u00dcgyf\u00e9lt\u00e1mogat\u00e1si Oszt\u00e1ly"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:operator@caesar.elte.hu"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.elte.hu/auth/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "urn:schac:homeOrganizationType:hu:university"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "elte"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-edugain"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-idps"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:geant:niif.hu:eduid.hu:entity-attributes:processing-info",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "hu",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://metadata.eduid.hu/registration_policy_1_0.txt"
              }
            ],
            "registration_instant": "2013-08-01T07:17:19.807Z",
            "registration_authority": "http://eduid.hu",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.elte.hu/auth/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.elte.hu/auth/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.elte.hu/auth/saml2/idp/ArtifactResolutionService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.49005,19.05955"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "description": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "E\u00f6tv\u00f6s Lor\u00e1nd Tudom\u00e1nyegyetem"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "E\u00f6tv\u00f6s Lor\u00e1nd University Budapest"
                  }
                ],
                "display_name": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "E\u00f6tv\u00f6s Lor\u00e1nd Tudom\u00e1nyegyetem"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "E\u00f6tv\u00f6s Lor\u00e1nd University Budapest"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "elte.hu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.elte.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ELTE"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ELTE"
          }
        ],
        "organization_url": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.elte.hu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.elte.hu"
          }
        ],
        "organization_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ELTE"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ELTE"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://applications.eumedgrid.eu/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fargetta"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:marco.fargetta@ct.infn.it"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:credentials-admin@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marco"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rotondo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:riccardo.rotondo@ct.infn.it"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:credentials-admin@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Riccardo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Platania"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:giuseppe.platania@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Giuseppe"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rocca"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:carlo.rocca@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Carlo"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Barbera"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:roberto.barbera@ct.infn.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roberto"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://applications.eumedgrid.eu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2011-09-05T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "COMETA"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "COMETA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.consorzio-cometa.it/"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.consorzio-cometa.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "COMETA Consortium"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consorzio COMETA (COnsorzio Multi Ente per la promozione e l'adozione di Tecnologie di calcolo Avanzato)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://applications.eumedgrid.eu/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://applications.eumedgrid.eu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://applications.eumedgrid.eu/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://applications.eumedgrid.eu/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://applications.eumedgrid.eu/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This service provides information for Grid users, Application developers and\n                        Grid site administrators. It is mainly devoted to the people involved in the\n                        EUMEDGRID-Support project but many pages are of general interest"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Questo servizio fornisce informazioni per utenti Grid, sviluppatori ed amministratori\n                        di siti Grid. Esso \u00e8 principalmente indirizzato alle persone coinvolte nel progetto europeo\n                        EUMEDGRID-Support ma molte informazioni sono di interesse generale"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EUMEDGRID Science Gateway"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EUMEDGRID Science Gateway"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://applications.eumedgrid.eu/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://applications.eumedgrid.eu/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFhDCCBGygAwIBAgIRAOyXU1f6GS689kEaSDAhQPYwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDA1MTkwMDAwMDBaFw0xNzA1MTgyMzU5NTlaMEAxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEbMBkGA1UEAxMSbGlmZXJheS5j\ndC5pbmZuLml0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApizyvtMI\nuoSnnz/fvk7lcXwoDUk11NVAlg5w4zh01YKNvy5SzBu0eRIzRos/ALs4CwmxrmCv\n3JQPA4xxItxVd8x9Q+YElQteEcX+mWXXW5LI5XE3xhPzkdFeQrhkinAK2JreSn6E\nTQk8YO1rOxW3qCpKeYZ2VQF3grAU/JRWbvLF+r2j4zE27n+RzBxnYeZ9rtJ/67gU\n7t1S39DRDTyKit7dJIYl50n9g3atWGALb56QoVnlR+RPRxVI9EFd2hEXfrxWXGdt\nF2v6YIMSAAM5l2/SlEmhQSSkmQ4zXcmPrzC6pte9NWoPOTsQnCnocwMJ16aXsnQy\nBxaoywMtq8NsdwIDAQABo4ICgTCCAn0wHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsr\nN1dH6pDjue0wHQYDVR0OBBYEFCy5dq76F94vaAuznAys6UmGxySTMA4GA1UdDwEB\n/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEF\nBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8E\nMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENB\nLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNz\nLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8v\nb2NzcC50Y3MudGVyZW5hLm9yZzCCAS0GA1UdEQSCASQwggEgghJsaWZlcmF5LmN0\nLmluZm4uaXSCGWFwcGxpY2F0aW9ucy5ldS1kZWNpZGUuZXWCGWFwcGxpY2F0aW9u\ncy5ldW1lZGdyaWQuZXWCEGdpbGRhLmN0LmluZm4uaXSCFGdpc2VsYS1ndy5jdC5p\nbmZuLml0gg1ndy5jdC5pbmZuLml0ghNnd2VhdGhlci5jdC5pbmZuLml0ghBnd2xp\nYi5jdC5pbmZuLml0gh9pbmRpY2F0ZS1ndy5jb25zb3J6aW8tY29tZXRhLml0ghFy\naWNldmkuY3QuaW5mbi5pdIIUdmlyYWxncmlkLmN0LmluZm4uaXSCFHd3dy5jaGFp\nbi1wcm9qZWN0LmV1ghZ3d3cuc3BlY2lhbC1wcm9qZWN0Lml0MA0GCSqGSIb3DQEB\nBQUAA4IBAQCEZIHNNQPD5WkGSlUhCN/BRSharmQ6dT0NiwjQNmRODCpVqBgwVZY0\nVUlAobHaF186QXeiNYge8ZYSpYY2VhBa4znL7IjFODE3FsaJNseKgsyNFqKR8xNO\nnsOCM//SN9N79hwH8yAxLhGyxbnInpOhE6rEkbhtowTjqhDq26cGGlH8JTTPuYvY\nJhgPGGkxo1286x1nuN4ELKvwZ7RF+YTH/WPOIBMNi+ee+vxrIhWbU6iy97f7k4PA\n2e35ZQ6gutnmX2v/ybFWh0ruO4zszYKiMo+zGyLvYmIpV/+Mjs26KbqqrBOS1jjN\nW3MiH8HMxzzYHExNCvzrAgN1TfB+SCiB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://applications.eumedgrid.eu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://applications.eumedgrid.eu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://applications.eumedgrid.eu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://applications.eumedgrid.eu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://applications.eumedgrid.eu/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://applications.eumedgrid.eu/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "EUMEDGRID Science Gateway"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This service provides information for Grid users, Application developers and\n                    Grid site administrators. It is mainly devoted to the people involved in the\n                    EUMEDGRID-Support project but many pages are of general interes"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://janus.bordeaux.archi.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "D\u00e9pinay"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "guillaume.depinay@bordeaux.archi.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dumas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jean-louis.dumas@bordeaux.archi.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://janus.bordeaux.archi.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-03-03T11:39:30Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://janus.bordeaux.archi.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://janus.bordeaux.archi.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://janus.bordeaux.archi.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bordeaux.archi.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.bordeaux.archi.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Etudiants en architecture et paysage"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Etudiants en architecture et paysage"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/gif;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENSAPBX - Ecole Nationale Sup\u00e9rieure d'Architecture et de Paysage de Bordeaux"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENSAPBX - Ecole Nationale Sup\u00e9rieure d'Architecture et de Paysage de Bordeaux"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVANQRFAgpYoToGKMWg8l5CtEP+fE3MA0GCSqGSIb3DQEB\nBQUAMCIxIDAeBgNVBAMTF2phbnVzLmJvcmRlYXV4LmFyY2hpLmZyMB4XDTE0MDEw\nNjE0MzYyN1oXDTM0MDEwNjE0MzYyN1owIjEgMB4GA1UEAxMXamFudXMuYm9yZGVh\ndXguYXJjaGkuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC8pUD1\nrfIX1k/y24cQnDYj/j06C8eRpjJ7h809cAuMA++rFeeM8CPjzDBxOgcM/sxLk4Hm\nkxetKPSwWaz2Q0eXRpjy1+gX53dz5mYyb7D3kSz3/kLTfrY5IrPjXUgOGZWwYlcG\nMt05Mh7AMNPns+xuNrrVhKMy9hA/1HO5cgDfamc+ovDqnvRBQIjqRhvxM4CEnJGH\ncyxaGrF++0Hh/DYWrlH0dCeLxLNGUyv6SfDKCm5GBkK3pmPoKu9HYeJb0AZcIA37\nugRWnx+kHmgLaHWGkKEqTf52sp1mJYplVc+ykdztLYXoghlRRVKJxotZa6aFmcDV\nukmhCWQLQ8l4xewZAgMBAAGjdTBzMFIGA1UdEQRLMEmCF2phbnVzLmJvcmRlYXV4\nLmFyY2hpLmZyhi5odHRwczovL2phbnVzLmJvcmRlYXV4LmFyY2hpLmZyL2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBT/gbDUy3XKG6rYVG7mfleHRs97XTANBgkqhkiG\n9w0BAQUFAAOCAQEAar3F3OsrV1trAQ/ObeP8/KPTgUrGa3HV0yNwbNCP/F8CNzZI\npKY0hE8eGHjdFpfxrC9MPe3YR7CmZtlAT0rkkDZFVRFtjaLK15oOnmrbvuCMkPI7\nyATc1qnTMbH0EgMl55zJvyXy6+HpCn8xASpeGqqf/ZGu0Y4p4oytrD/UZKjHGj59\nfiHuBltSrUbuScoYIDjv/VIiG5XrPe791/OUKEONUzwulye26Lz5qOZcwIUgmCV1\nYt1QoZ6/V4O7uCiPDiad1bluCsGR6Y0o5BJTcPNSSluKuzc/DwJOY9obsR7rYY0m\nQrKLREVlmoE0vK7znYaAPUaXVpJwmNe9GPqvsw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ENSAPBX - Ecole Nationale Sup\u00e9rieure d'Architecture et de Paysage de Bordeaux"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bordeaux.archi.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ENSAPBX - Ecole Nationale Sup\u00e9rieure d'Architecture et de Paysage de Bordeaux"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.qmc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.qmc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/qmc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/qmc.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "qmc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Queen Mary's College, Basingstoke"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qmc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.xaverian.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.xaverian.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/xaverian.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/xaverian.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "xaverian.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Xaverian College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.xaverian.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://aai-login.fh-htwchur.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "HTW"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@htwchur.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAI"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41 44 268 15 05"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@switch.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SWITCHaai"
          }
        }
      ],
      "entity_id": "https://aai-login.fh-htwchur.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2015-06-29T09:17:05Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIJAKtX8BuSldreMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2FhaS1sb2dpbi5maC1odHdjaHVyLmNoMB4XDTE1MDYwMjA2MjQzOFoXDTE4\nMDYwMTA2MjQzOFowIjEgMB4GA1UEAxMXYWFpLWxvZ2luLmZoLWh0d2NodXIuY2gw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDojAIPHZ3tQ1FE+stoW3n6\ngmdsUM/MBwi2jw9M9savDQk9rq36fSPjZW8qUz8bGPO5bw2QAkcUsZchFjZLrObX\nec38/zFSb0n4gS0S2EC2HwcPyZzswJqSw8OcZ497yGiBjZa5Z0oPI9TKoBcPoxUN\nSySON/qFUFicYvDv6fRiMCQllXjIT76HFsvIgnshgmTeO+66if9bh6596L3anHYM\ntUssLfwKZiv7HiIRoufXomTk80jnSqG015zgrkfgxn78zSQdscqgMaYupzW9k+L5\n2mq3FrmkIOWaXPva9NPvwrigYLn9ekNqSiFH7A57ZPnWqjuYIHOfouQM+Kl4vYtN\nAgMBAAGjdTBzMFIGA1UdEQRLMEmCF2FhaS1sb2dpbi5maC1odHdjaHVyLmNohi5o\ndHRwczovL2FhaS1sb2dpbi5maC1odHdjaHVyLmNoL2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBRpoSJX2tqdoLobBhzcCwEBlU3YcjANBgkqhkiG9w0BAQUFAAOCAQEA\nvFGeP2aiStlFZUpU9IJnpN7KPl96hN8XEYVCNMBYRbMjgjEj6shy6B/oyabx9Yn0\ng8RP//1vqWSxSPSkHAeTwX42tO/GRLlL03eRMKUVKBJhLJkvp98ORGah2x6HE+v4\n19wmQZO1i/Ki2PWlHqGEdGB/bxHc/2Fdq7gL4VuFCLmhZ5aZDZGpNYaH+1G/of4S\nZtp+npQbDCJYU/DjwrlmhYVHeRltzcxR0WIb5woxQFBVB4gIZFpC/LFWFDNZFZO5\nsAylL3KJpGpKKRqi316YK1J0rHhpPkhDrGl2CkM/gIr3NzEGWxxHeq2FZ8ChfDwC\nczVRKZjqSip4oiVxXHKCGA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fh-htwchur.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-login.fh-htwchur.ch/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-login.fh-htwchur.ch/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aai-login.fh-htwchur.ch/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai-login.fh-htwchur.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai-login.fh-htwchur.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aai-login.fh-htwchur.ch/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-login.fh-htwchur.ch/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-login.fh-htwchur.ch/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fh-htwchur.ch"
              },
              {
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hochschule f\u00fcr Technik und Wirtschaft Chur"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Applied Sciences HTW Chur"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "HTW Chur - Hochschule f\u00fcr Technik und Wirtschaft"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "HTW Chur - University of Applied Sciences HTW Chur"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "fh-htwchur.ch"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "htwchur.ch"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:46.852909,9.512614"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.5.58.254/32"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.5.58.11/32"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.5.58.23/32"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.242.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIJAKtX8BuSldreMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2FhaS1sb2dpbi5maC1odHdjaHVyLmNoMB4XDTE1MDYwMjA2MjQzOFoXDTE4\nMDYwMTA2MjQzOFowIjEgMB4GA1UEAxMXYWFpLWxvZ2luLmZoLWh0d2NodXIuY2gw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDojAIPHZ3tQ1FE+stoW3n6\ngmdsUM/MBwi2jw9M9savDQk9rq36fSPjZW8qUz8bGPO5bw2QAkcUsZchFjZLrObX\nec38/zFSb0n4gS0S2EC2HwcPyZzswJqSw8OcZ497yGiBjZa5Z0oPI9TKoBcPoxUN\nSySON/qFUFicYvDv6fRiMCQllXjIT76HFsvIgnshgmTeO+66if9bh6596L3anHYM\ntUssLfwKZiv7HiIRoufXomTk80jnSqG015zgrkfgxn78zSQdscqgMaYupzW9k+L5\n2mq3FrmkIOWaXPva9NPvwrigYLn9ekNqSiFH7A57ZPnWqjuYIHOfouQM+Kl4vYtN\nAgMBAAGjdTBzMFIGA1UdEQRLMEmCF2FhaS1sb2dpbi5maC1odHdjaHVyLmNohi5o\ndHRwczovL2FhaS1sb2dpbi5maC1odHdjaHVyLmNoL2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBRpoSJX2tqdoLobBhzcCwEBlU3YcjANBgkqhkiG9w0BAQUFAAOCAQEA\nvFGeP2aiStlFZUpU9IJnpN7KPl96hN8XEYVCNMBYRbMjgjEj6shy6B/oyabx9Yn0\ng8RP//1vqWSxSPSkHAeTwX42tO/GRLlL03eRMKUVKBJhLJkvp98ORGah2x6HE+v4\n19wmQZO1i/Ki2PWlHqGEdGB/bxHc/2Fdq7gL4VuFCLmhZ5aZDZGpNYaH+1G/of4S\nZtp+npQbDCJYU/DjwrlmhYVHeRltzcxR0WIb5woxQFBVB4gIZFpC/LFWFDNZFZO5\nsAylL3KJpGpKKRqi316YK1J0rHhpPkhDrGl2CkM/gIr3NzEGWxxHeq2FZ8ChfDwC\nczVRKZjqSip4oiVxXHKCGA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "HTW Chur - Hochschule f\u00fcr Technik und Wirtschaft"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "HTW Chur - University of Applied Sciences HTW Chur"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fh-htwchur.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fh-htwchur.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "fh-htwchur.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.csp.it/sp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info-idem@csp.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "System"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.csp.it/sp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2015-01-02T14:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "WiFi Tower erogata da CSP"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "WiFi Tower provided by CSP"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csp.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csp.it/?lang=en"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CSP - innovazione nelle ICT"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CSP - innovation in ICT"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.csp.it/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.csp.it/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.csp.it/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://idp.csp.it/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.csp.it/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://idp.csp.it/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.csp.it/federation/?lang=en"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.csp.it/federation/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WiFi Tower CSP"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WiFi Tower CSP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Access to WiFi Tower provided by CSP"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Accesso alla rete WiFi Tower erogata da CSP"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.csp.it/images/csp_logo_16x16.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.csp.it/images/csp_logo_16x16.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.csp.it/images/csp_logo_80x80.png",
                    "lang": "en",
                    "height": "80",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idp.csp.it/images/csp_logo_80x80.png",
                    "lang": "it",
                    "height": "80",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.csp.it/federation/?lang=en"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.csp.it/federation/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC0DCCAbigAwIBAgIJAMxj7o7FT11OMA0GCSqGSIb3DQEBBQUAMA4xDDAKBgNV\nBAMTA2lkcDAeFw0xMzAyMjUxMDEwNTBaFw0yMzAyMjMxMDEwNTBaMA4xDDAKBgNV\nBAMTA2lkcDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALBf7mmx56i5\nD21+iW0FYxVaZtRjZiWsP7+1OgDXYoFFCw6I3d3IyBw/w2l248/SHFA8Tb3R8rn7\nyjY/3X1KHfR/tjiJql9WuW1S++2jfhTWMc1BZaf2oKseBaFHWSMJ9wnnCU64P6GX\nssxauRpLXT6Yv1kAINnHqmaP1MsN5Y4TL5hGK2g764gLjXNqv1+rUMhqIs5o3Owx\nutg/xEiqZY1pOrP385b+JTzg4Cv5fuGC/b3+nq490paML9R5URQVHErpL8tSFcwr\nmnq8ymoghRXgsQ70O+1EAt1HTJc/oKwKVxtuR+5uXvBPPU1s777WH1iB0U6pZdAf\n+/qitsavsCUCAwEAAaMxMC8wDgYDVR0RBAcwBYIDaWRwMB0GA1UdDgQWBBT9zbqw\nTHojBpjCsQhOhg2kIPzj5DANBgkqhkiG9w0BAQUFAAOCAQEAYUg98pUGUlGri0H0\nZO8UEtMpd+6QRXZp0JYYz5JFBtFEVIW8pcr7VIB2THSJGFnttpQKBDy6/TedQcsf\n5Bz1hVAOL8R5UG5GcRhxZ+trh9XcdBls7dCXRgLaZIi0FJgxGjZXObvrjVxggGv9\nrHrgSt0DmAux/xTmzgorGgor6Fue9O0/q+PyMuoUBOzZ3sSldkh09CA1f96mBu3f\nbQLibp8moXN3SjxRvqufUJIgFeh/JoonndDaC3k6tQRbGXxQnDXa/RoDSDwSyRsE\nEkfeWh8XDP1T2B4AiP38KYZRsfnOi+jtS2Q44doZpNfQk+LFbBhh5V74LeKTaDE3\nLcBp9w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.csp.it/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.csp.it/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://idp.csp.it/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://idp.csp.it/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://idp.csp.it/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://idp.csp.it/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "WiFi Tower CSP"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "WiFi Tower CSP"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Access to WiFi Tower provided by CSP"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Accesso alla rete WiFi Tower erogata da CSP"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ipa.ie/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sisk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:psisk@ipa.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Peter"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sisk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:psisk@ipa.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Peter"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ipa.ie/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2011-11-28T00:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ipa.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ipa.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ipa.ie/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ipa.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ipa.ie"
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/ipa.png",
                    "height": "120",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "130"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Public Administration"
                  },
                  {
                    "lang": "ga",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "An Foras Riaracha\u00edn"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.3337363,-6.2300127"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAI3sMWxFvjpe4FwTUUSZvm2vGfvVMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC5pcGEuaWUwHhcNMTExMTI1MTczNTQxWhcNMzEx\nMTI1MTczNTQxWjAVMRMwEQYDVQQDEwppZHAuaXBhLmllMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAtRddMdHqEdiL5NPjnqqt4VZZtuNNq1xslTEzOoKW\n4fJ7uKbxw0TOnUVgeqoBJEIVhxDvilQXkonb+jDCFZCbyrNsh/ENr0bbqtOwvMYP\nQ4ODxnxK4D+Qjbf/Ld0ki0jjUvZ8v9J6aO2AKk6IPVlvwXi1GoEGy2Ds46DVq3Gl\nV54v/cu6A8vatOpRgF3keOkL1nLW37mjiy9Xu7+8/C5uK+UBzjb/bX5qzjbHbVOG\nhnamqwgRN0QyzQPU1OyNK4b88DIw+gqUi0qo2tlcc+Hn6He3O56uSsTprNwoNKrr\nMvlkEL1pY0lfgAcadJGGrQ9FEi0Ty+GeeyoT0agvHlq0jwIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAuaXBhLmllhiFodHRwczovL2lkcC5pcGEuaWUvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFJhKeTQ7ebYvmIRcYtOY8b9L1zhaMA0GCSqGSIb3DQEB\nBQUAA4IBAQANi1lNeUhqvdVK7q7dotF3EPg6C2PJLYUXjInHfHKLHbDDfYGEVf19\nnz2pasKmdfo0bv9kssbuwVfn7tUro8Igdt661gq/0/eriKaMg83qeo5MOoJa0I5t\n94y8/mZAhz3SUReGR3zEhbZIXEx+zdbbz992k6FjMCi4MQpfoN1LD6uqIHqjAu0P\nA2dPT+rM2JRZ/li0YmTLUcvE0IP1q7VuihtEXBKbndKPe4sEIy4LVfpPDs2oYjg6\n0VDwE1ENoiu+3TYEkP/ZZpu2Z68FG7Ygpedl96CjXFm5qufuU8UUpz7SRMf2gEv/\nNkaVXN/aXmq6gSQ+gfVeKU+eqHo2TR51"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Public Administration"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ipa.ie"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Public Administration"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ifpb.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Alexandre Almeida de Lucena"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "alexandre.almeida@ifpb.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ifpb.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID7jCCAtYCAQAwDQYJKoZIhvcNAQEFBQAwgbwxLTArBgNVBAoUJElGUEIgLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkYSBQYXJhw61iYTEMMAoGA1UECxMDRFRJMSwwKgYJ\nKoZIhvcNAQkBFh1hbGV4YW5kcmUuYWxtZWlkYUBpZnBiLmVkdS5icjEVMBMGA1UE\nBxQMSm/Do28gUGVzc29hMREwDwYDVQQIFAhQYXJhw61iYTELMAkGA1UEBhMCQlIx\nGDAWBgNVBAMTD2lkcC5pZnBiLmVkdS5icjAeFw0xNTExMjcxOTQ3NDNaFw0xODEx\nMjYxOTQ3NDNaMIG8MS0wKwYDVQQKFCRJRlBCIC0gSW5zdGl0dXRvIEZlZGVyYWwg\nZGEgUGFyYcOtYmExDDAKBgNVBAsTA0RUSTEsMCoGCSqGSIb3DQEJARYdYWxleGFu\nZHJlLmFsbWVpZGFAaWZwYi5lZHUuYnIxFTATBgNVBAcUDEpvw6NvIFBlc3NvYTER\nMA8GA1UECBQIUGFyYcOtYmExCzAJBgNVBAYTAkJSMRgwFgYDVQQDEw9pZHAuaWZw\nYi5lZHUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC86dKAJidm\nTFuVKDguITfO7pAFVrPQ5xTMuuTPfkaajstKL6G28CkK2ovAl8VYkIeH50nqc78i\n2F1kjrxvXYdUU2IiZzILUiuZ6aZDPbxVGWfY1LTenoijNcWFTSsqT8ExvCUqFhCz\n2VPy7bkR3d6jvMDTn+wRuudDzBMIS6XmTXNoqDMp1tTCTrPiKwEJAQDhMQHkXAVB\nIC0U4DuIcARLLqw8nQ73K83BfFlkdbdcwV4A8Y3fNCSTBTslKp9PzA694GdbsfQh\nSbXWQXdO7kI0P3JnyXuxsNvlX3EGdv5tvwPx/W9NXXDH7H99uMpdhUTS6W7rRqWm\ndKf78jPlAeZHAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAKXXg2ofZPRNfNF9COfu\nNlHawtVoCdWi92smA6LeMt7N9MvCkkpC8ZdwCc1ebS4XDW4wKf8vd30GrQ1qI2PQ\nBB6Iz9r4w3pNwBhSB0iBKRAkkTYLCI80R1ghjdoOO4PHYWxMhzM7Q683PhU0Zhmm\nWO4aOIsUZ6Nse4205I4r/mkxJNrfLtmBxJQGWwUxckFeP4OYipYt8v2lnSPkJOc6\nmiCjubGUFtcp0AyIauaCBrDa5yXQC7G4aGsdUmLM9rkVOohfyo6+KXbBXBdH4ohp\nT8Co/9psHWaWH/nbbWkLPelRY7xBqyLbUwdAFj8W6v8BExWLWMJqSZq8A4eD02Ky\nsHw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ifpb.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ifpb.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ifpb.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ifpb.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ifpb.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ifpb.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ifpb.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ifpb.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifpb.edu.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifpb.edu.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFPB - Instituto Federal da Paraiba"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFPB - Instituto Federal da Paraiba"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFPB - Instituto Federal da Paraiba"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFPB - Instituto Federal da Paraiba"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID7jCCAtYCAQAwDQYJKoZIhvcNAQEFBQAwgbwxLTArBgNVBAoUJElGUEIgLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkYSBQYXJhw61iYTEMMAoGA1UECxMDRFRJMSwwKgYJ\nKoZIhvcNAQkBFh1hbGV4YW5kcmUuYWxtZWlkYUBpZnBiLmVkdS5icjEVMBMGA1UE\nBxQMSm/Do28gUGVzc29hMREwDwYDVQQIFAhQYXJhw61iYTELMAkGA1UEBhMCQlIx\nGDAWBgNVBAMTD2lkcC5pZnBiLmVkdS5icjAeFw0xNTExMjcxOTQ3NDNaFw0xODEx\nMjYxOTQ3NDNaMIG8MS0wKwYDVQQKFCRJRlBCIC0gSW5zdGl0dXRvIEZlZGVyYWwg\nZGEgUGFyYcOtYmExDDAKBgNVBAsTA0RUSTEsMCoGCSqGSIb3DQEJARYdYWxleGFu\nZHJlLmFsbWVpZGFAaWZwYi5lZHUuYnIxFTATBgNVBAcUDEpvw6NvIFBlc3NvYTER\nMA8GA1UECBQIUGFyYcOtYmExCzAJBgNVBAYTAkJSMRgwFgYDVQQDEw9pZHAuaWZw\nYi5lZHUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC86dKAJidm\nTFuVKDguITfO7pAFVrPQ5xTMuuTPfkaajstKL6G28CkK2ovAl8VYkIeH50nqc78i\n2F1kjrxvXYdUU2IiZzILUiuZ6aZDPbxVGWfY1LTenoijNcWFTSsqT8ExvCUqFhCz\n2VPy7bkR3d6jvMDTn+wRuudDzBMIS6XmTXNoqDMp1tTCTrPiKwEJAQDhMQHkXAVB\nIC0U4DuIcARLLqw8nQ73K83BfFlkdbdcwV4A8Y3fNCSTBTslKp9PzA694GdbsfQh\nSbXWQXdO7kI0P3JnyXuxsNvlX3EGdv5tvwPx/W9NXXDH7H99uMpdhUTS6W7rRqWm\ndKf78jPlAeZHAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAKXXg2ofZPRNfNF9COfu\nNlHawtVoCdWi92smA6LeMt7N9MvCkkpC8ZdwCc1ebS4XDW4wKf8vd30GrQ1qI2PQ\nBB6Iz9r4w3pNwBhSB0iBKRAkkTYLCI80R1ghjdoOO4PHYWxMhzM7Q683PhU0Zhmm\nWO4aOIsUZ6Nse4205I4r/mkxJNrfLtmBxJQGWwUxckFeP4OYipYt8v2lnSPkJOc6\nmiCjubGUFtcp0AyIauaCBrDa5yXQC7G4aGsdUmLM9rkVOohfyo6+KXbBXBdH4ohp\nT8Co/9psHWaWH/nbbWkLPelRY7xBqyLbUwdAFj8W6v8BExWLWMJqSZq8A4eD02Ky\nsHw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFPB - Instituto Federal da Paraiba"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFPB - Instituto Federal da Paraiba"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifpb.edu.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifpb.edu.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFPB - Instituto Federal da Paraiba"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFPB - Instituto Federal da Paraiba"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.tentaadmindev.uhr.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.tentaadmindev.uhr.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.tentaadmindev.uhr.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.tentaadmindev.uhr.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.tentaadmindev.uhr.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.tentaadmindev.uhr.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.tentaadmindev.uhr.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.tentaadmindev.uhr.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration av tentamen och tentamensvakter."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration av tentamen och tentamensvakter."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TentaAdmin"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TentaAdmin"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "uhrextwebtest01.i.uhr.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAN6k6XIcpXI3MA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\nBAMTGHVocmV4dHdlYnRlc3QwMS5pLnVoci5zZTAeFw0xNDA5MTUxMTM1NTFaFw0y\nNDA5MTIxMTM1NTFaMCMxITAfBgNVBAMTGHVocmV4dHdlYnRlc3QwMS5pLnVoci5z\nZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMs4QlMhfYX8rSvesdpb\n12C82iJMsUIi4d5omOwxmt7HNA6Xxz3HEW/ge3WmsjpHL1tN1gWQkILLOKyAUAPw\nR1xEEREQiNeFnrdcqpfMmSJudgumoocHLwNiU6Tcooi0aQGDkobvnX2r9oUbd2T5\nA/qXmwk1czLeHD0HAC+gD4Nsmjto0AvuxGHKlceSZStXAhdsdHpCKUEzReHPHkyO\nn4uE3fmDg2jnVeZQNbkRoWTZN216YBGaBYux0FDD9fnJA/X/8qPOPAwDptcNQj5u\nSS4zppajv2BaAHe3/IxXoCb3WEDE2i20N7FJ6pqiqfZbE8C8QwCrE+Ylj2m7UVLx\nvmUCAwEAAaNGMEQwIwYDVR0RBBwwGoIYdWhyZXh0d2VidGVzdDAxLmkudWhyLnNl\nMB0GA1UdDgQWBBQGJCUBefBDuYDpYQgWYVA1RaJo+TANBgkqhkiG9w0BAQUFAAOC\nAQEAfqYGfsx2YapLPbtavNH9c5BMK+uvx2Z52nJbje9/RdTigmDtPbW+ZSOibMpD\nEC7BlH7OMRM5j0/vVlRoRadjkJmRaEf/VfaNxwktgNQPVkXQatycSZ7oderQngbG\nCVlWHY4+3c6XmbuQZDjPYFQcbamkQf61/0xyPAXr6z7vF1RiSzt4ej9q3gI+7/if\nnQjC6dzNCzYmZcO1m5jx5BgECpee+1YzPgWSnZmXexQiPsv7AeTosT0CxdFkwKz9\nOCAgWY6O9B3McR43joEl1kbkE4ckdvrpmDrGdjZn78smL6SGV2Frl5d0ALjQSVkB\n9qq7wBTjnxf2rBXhnRNuEzB+Jw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=uhrextwebtest01.i.uhr.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.tentaadmindev.uhr.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.tentaadmindev.uhr.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.tentaadmindev.uhr.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.tentaadmindev.uhr.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.tentaadmindev.uhr.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.tentaadmindev.uhr.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.tentaadmindev.uhr.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.tentaadmindev.uhr.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.tentaadmindev.uhr.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.sanger.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@sanger.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sanger Institute Systems Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fraser"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:srf@sanger.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.sanger.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-05-13T11:49:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAKQYJxHECH4G5xoOCxtCz43WOfkYMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBsxGTAXBgNVBAMTEGlkcC5zYW5nZXIuYWMudWswHhcNMTQwMzI3MTMyMDM0\n\t\t\t\t\t\tWhcNMzQwMzI3MTIyMDM0WjAbMRkwFwYDVQQDExBpZHAuc2FuZ2VyLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsoZnFVTzScX4KleGsZ0R2/5d\n\t\t\t\t\t\tE/ab+OrE9bttogijThDmtzzV/2hgkrOspcBHB/g1FzZfaCV5yMBG52W7mGurS6kR\n\t\t\t\t\t\tF+q7uPhB3UJSoXwUz8tN7w1ZK6MHC8Cwy/nJfsbOhA4kTtk9r+6KFORBh8ek3KPq\n\t\t\t\t\t\tRkNyDhhEYcIgK5HokuweVGjPWjmGFa7JKRhpnU9V1RnJY7coprT/3IxcJUfvpRam\n\t\t\t\t\t\tbvYwZfP1VTMj4ia0kFrE6drOArfhq2MZupwN+YxmxXmv75vL2Xblxfrmk0BwHYs5\n\t\t\t\t\t\tq5hcG75VSCZVeKlDEooPbb5IKjRM9J+ymKlfFyqZbUlkUJyBzHRz+hctqifrZwID\n\t\t\t\t\t\tAQABo2cwZTBEBgNVHREEPTA7ghBpZHAuc2FuZ2VyLmFjLnVrhidodHRwczovL2lk\n\t\t\t\t\t\tcC5zYW5nZXIuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFAl/k8y3QBmG\n\t\t\t\t\t\tQV6XLFD9CSGFEOC7MA0GCSqGSIb3DQEBBQUAA4IBAQAEn6x7S/SeKxMLZUDkFXuV\n\t\t\t\t\t\tf9Wv7z5UJ/2Xi4FyQDG+l0QCb+tVeMid1IU1EIuPQWsoWcpl/w9rXpHY2yHxBafA\n\t\t\t\t\t\tVcHurzix2tquXbfQdrg/gBkwaDVAh/xmr6qhpz9vVyxH4JzUuMg5KFOOKI2UewE8\n\t\t\t\t\t\t7aPjhhuWkozRDbcDd76EtyJIaknSjRlw6uncnY2JJLITzWnndFxCgZgiyWew6HGp\n\t\t\t\t\t\tdnZI4GN5IWgtKyLa4PrxWjtPPt+JTbx2iaclyk7AUlB1bN02JZF0BlW35oygFZLd\n\t\t\t\t\t\te1ezwFWxhm6gCPNfBWDWNeRZBidDsz193MDbIS/mWBzyAYXot1TxBRXiBeXbaWmB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sanger.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sanger.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sanger.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.sanger.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sanger.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.sanger.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sanger.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sanger.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sanger.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sanger.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAKQYJxHECH4G5xoOCxtCz43WOfkYMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBsxGTAXBgNVBAMTEGlkcC5zYW5nZXIuYWMudWswHhcNMTQwMzI3MTMyMDM0\n\t\t\t\t\t\tWhcNMzQwMzI3MTIyMDM0WjAbMRkwFwYDVQQDExBpZHAuc2FuZ2VyLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsoZnFVTzScX4KleGsZ0R2/5d\n\t\t\t\t\t\tE/ab+OrE9bttogijThDmtzzV/2hgkrOspcBHB/g1FzZfaCV5yMBG52W7mGurS6kR\n\t\t\t\t\t\tF+q7uPhB3UJSoXwUz8tN7w1ZK6MHC8Cwy/nJfsbOhA4kTtk9r+6KFORBh8ek3KPq\n\t\t\t\t\t\tRkNyDhhEYcIgK5HokuweVGjPWjmGFa7JKRhpnU9V1RnJY7coprT/3IxcJUfvpRam\n\t\t\t\t\t\tbvYwZfP1VTMj4ia0kFrE6drOArfhq2MZupwN+YxmxXmv75vL2Xblxfrmk0BwHYs5\n\t\t\t\t\t\tq5hcG75VSCZVeKlDEooPbb5IKjRM9J+ymKlfFyqZbUlkUJyBzHRz+hctqifrZwID\n\t\t\t\t\t\tAQABo2cwZTBEBgNVHREEPTA7ghBpZHAuc2FuZ2VyLmFjLnVrhidodHRwczovL2lk\n\t\t\t\t\t\tcC5zYW5nZXIuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFAl/k8y3QBmG\n\t\t\t\t\t\tQV6XLFD9CSGFEOC7MA0GCSqGSIb3DQEBBQUAA4IBAQAEn6x7S/SeKxMLZUDkFXuV\n\t\t\t\t\t\tf9Wv7z5UJ/2Xi4FyQDG+l0QCb+tVeMid1IU1EIuPQWsoWcpl/w9rXpHY2yHxBafA\n\t\t\t\t\t\tVcHurzix2tquXbfQdrg/gBkwaDVAh/xmr6qhpz9vVyxH4JzUuMg5KFOOKI2UewE8\n\t\t\t\t\t\t7aPjhhuWkozRDbcDd76EtyJIaknSjRlw6uncnY2JJLITzWnndFxCgZgiyWew6HGp\n\t\t\t\t\t\tdnZI4GN5IWgtKyLa4PrxWjtPPt+JTbx2iaclyk7AUlB1bN02JZF0BlW35oygFZLd\n\t\t\t\t\t\te1ezwFWxhm6gCPNfBWDWNeRZBidDsz193MDbIS/mWBzyAYXot1TxBRXiBeXbaWmB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Wellcome Trust Sanger Institute"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sanger.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Genome Research Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://se.timeedit.net/umu-employee-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@evolvera.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TimeEdit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://se.timeedit.net/umu-employee-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://se.timeedit.net/web/umu/db1/timeedit/p/empres2/ssoLogout/umu_pers_saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TimeEdit, utvecklat av Evolvera AB"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TimeEdit, developed by Evolvera AB"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TimeEdit f\u00f6r anst\u00e4llda vid Ume\u00e5 universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TimeEdit for employees at Ume\u00e5 University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAggCCQDSfJxeKVOg3jANBgkqhkiG9w0BAQUFADBSMQswCQYDVQQGEwJTRTESMBAGA1UE\nBxQJR8O2dGVib3JnMRQwEgYDVQQKEwtUaW1lRWRpdCBBQjEZMBcGA1UEAxMQYXV0aC50aW1lZWRp\ndC5zZTAeFw0xMzA2MTQwNzE0MTlaFw0xNTA2MTQwNzE0MTlaMFIxCzAJBgNVBAYTAlNFMRIwEAYD\nVQQHFAlHw7Z0ZWJvcmcxFDASBgNVBAoTC1RpbWVFZGl0IEFCMRkwFwYDVQQDExBhdXRoLnRpbWVl\nZGl0LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoL+lyBleTM0UGwGPLXPcfBMr\nomnPqP8+qlE+rOs0mEbvNyXdEWT0Z5P/XoMVfERJQQ6v5DAJF4c3o1BiPshZL8cj6QdLuJXLfVNG\nu5mzq/lKpB/n38Y4cWYxIyNtBcV9vcKDIRUbQP/27nEPMsbs2IaCXf6V3l3yQqbymZTyd8nBfZZF\nG95zDKBTSD5UQ3XW+LbvjKSZY4qDjyFkeOfj8kVyltWTHRMvKTKGLeNrGyCFiaMY/vfyA22gOyz4\nO2cY/oqFs8+82AOs3Si4+eGkFAq3CdEWSE4c69oDrzEWk+bKgxw5qyhWQ/13eh8AiZMDeqhT7q32\nRthqEp8GfwPM1QIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCRsLvMI4OJ076STPIyxnwk6bXRG5RL\nMR1pJ3umMNCa1LR1RnH1feuvm9dxerUTow7bPIsarJarh0iEIj2kLtu/prPm+ZcAKeEjh27pSM7m\n1F0XBkDqeP1msR+7g0aHlt0MzrKm/Esb1JX9YCO3MHl1XFc8xSnv2bxKWvER+tmDWkFrC0y1u2+H\nB/CfyES8ntBP6F7aZ6UQ4GTrqF0MZNGBoWFyXecGe5XEwWJwP4otSrJ2q7cbQU33xEcri0dHiMMl\nTiN/6f25dSm5UFCxqWGGAQndGfn/tE5FSqJlrHnbF2M6x4eH3MEIbHebI+nJlk6ASPdgIssvsDcd\nGImnaeS4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://se.timeedit.net/web/umu/db1/timeedit/p/empres2/ssoResponse/umu_pers_saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "false"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://doit.swisdom.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Djamei"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:vahid.djamei@uzh.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Vahid"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:vahid.djamei@uzh.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "DOIT"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://doit.swisdom.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2014-08-25T12:32:55Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "friendly_name": "swissEduPersonHomeOrganization",
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "uzh.ch"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:2.16.756.1.2.5.1.1.4",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "friendly_name": "swissEduPersonHomeOrganizationType",
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "university"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:2.16.756.1.2.5.1.1.5",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e4t Z\u00fcrich"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Zurich"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uzh.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uzh.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "uzh.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Dermatology Online with Interactive Technology"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "25",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "68"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "DOIT - Dermatology eLearning"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIJAJHcXT05fMs7MA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGRvaXQuc3dpc2RvbS5vcmcwHhcNMTQwODI1MTE1ODExWhcNMTcwODI0MTE1\nODExWjAbMRkwFwYDVQQDExBkb2l0LnN3aXNkb20ub3JnMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA7yfqRa1uZXzzBaC10gq40/I7xws9oK3wsbwFTlho\n4LQ1W3Ph48PlJGH0VIUEhCZE+ZEKY4QBB3a+ZZU7TWdiu0L2RZDm+pM60pfLaMZv\nsWEC5QwQQyJ27GuECU+mmXYfo7yXTdNu7JA797H7xpWdzLz37cBX6BlF5OvlkHQ2\nViFO/xNLrw4JiBlRJkX0A+DETgutcyK6RwzQ0jstj1e/U8w9HMxYkuhJ79jcUJQx\n9F5rzfhXg9qHD0VtA9iiwlgbAdqChfyUXxQrOptaE0G3t/fuI2rwYJ3QoX7xQnwF\narngEtm1LyfpeXWuI5IlzYrjVDs3Ba4TTYLUMuNDDFG/jQIDAQABo2MwYTBABgNV\nHREEOTA3ghBkb2l0LnN3aXNkb20ub3JnhiNodHRwczovL2RvaXQuc3dpc2RvbS5v\ncmcvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUwAvg3JPnWCqyc595uuwFXNv2QScwDQYJ\nKoZIhvcNAQEFBQADggEBANPmBQZ+uWR42Q7Q32iCHn40YYGK0iLyyVsGYqVFjklF\nJQcQ5QiATQiLBMiXzGB8NO1LEVIEPuMQ/c0kQhBICPc+CUJkHpvIQziHwcM/GVNb\n3A60JjpG4L1hNJs+Upc6xUSYi3bteUsXE67c1pGdF5DB7IAWJjGyeM5q4BG6AmSv\naAGKF8PQrkdLm2KLzgZIBCf+O/yVz6Yn1Jqb1JW6+TRLkWFF7eaYYAGH5YMQ8mwk\nPu/Y3XLZI21tZN3bVaj/FW0nvSakrF6Ic+90NF+5i891xXjypJOthoe20x1ulX78\nnAvioAXLKLyPxl70a9Yj0TSJVsCSAk2bTcgY6WOnsBQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai.cyberderm.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cyberderm.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://doit.mironet.ch/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://doit.swisdom.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://aai.cyberderm.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cyberderm.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://doit.mironet.ch/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://doit.swisdom.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://aai.cyberderm.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://cyberderm.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://doit.mironet.ch/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://doit.swisdom.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://aai.cyberderm.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://cyberderm.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://doit.mironet.ch/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://doit.swisdom.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://aai.cyberderm.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://cyberderm.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "18"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://doit.mironet.ch/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "19"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://doit.swisdom.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "20"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "DOIT - Dermatology eLearning"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Dermatology Online with Interactive Technology"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganizationType",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "postalAddress",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.16",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "homePostalAddress",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.39",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "preferredLanguage",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.39",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/auth.dsl.dk/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/auth.dsl.dk/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2010-09-21T14:47:42Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/auth.dsl.dk/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dsl.dk"
              },
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "DSL"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "DSL"
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Det Danske Sprog- og Litteraturselskab"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Danish Society for Language and Literature"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "dsl.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdwCAQcwDQYJKoZIhvcNAQELBQAwQDE+MDwGA1UEAww1aHR0cHM6Ly9h\ndXRoLmRzbC5kay9zaW1wbGVzYW1sL3NhbWwyL2lkcC9tZXRhZGF0YS5waHAwHhcN\nMTUwMTAxMDAwMDAwWhcNMjUxMjMxMjM1OTU5WjBAMT4wPAYDVQQDDDVodHRwczov\nL2F1dGguZHNsLmRrL3NpbXBsZXNhbWwvc2FtbDIvaWRwL21ldGFkYXRhLnBocDCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMeIDApqEFO4jhn4gnWuA54S\nIILLdtH1Ah7cGkKx6MUJTmtLORYA2pW5zU8N+nQl0hmGs9eyYMlAyaJ08IY8gNAq\nj5uT5p/f4RQVL8j/7fmxIFfa9/6HUMe9lX2OzOealJWOnsdn9ag9YHKRYEk7QA5W\nbMHnOVqqRLfonvr7DF6vB2m4TFWdhI13vdL4DJP8Rn61cA77qVDwUv9gyUmdSRJp\nKotIcXLTUPaoE2ZhHAGkJLr91RnLGLS3mPyCEpQPgEc5lVq+frknrZwl1eI5wxHJ\nQAinnsZdCsvrcq2uMhxd12r4JnJnm3fsR1Q4jPjaOgVzLvcwU6e3KeUoS87DUEkC\nAwEAATANBgkqhkiG9w0BAQsFAAOCAQEAYxKtUGv8KP9ekGMKVhx3A6xMs1iQ6PtP\nWNdSn/CJVcqLxt+cO0LTPQg862C8Kk66COiJZ1zqQVtH1qOUn01uNwURWnIAtlx3\nyjmnu6bAkr8N1zZchBPns3jvRLen9FgUASZxZyCMq12CbOExiByyn0uX/Xalb3E2\n/sp1y7ePhUaQwLl7qTehi8Qns/PFJ/HuPe01umYZL2eaRIepIceDbZrjaBGYV5rM\nYddwdo55oZyYRtYPfvbI7ThZ1slkiND3U2W3u3G/XgbN0Jd8Mp6UBnLttIqus3iK\n7IxZv6lGXMla6y4BCHRYWu2yw4Ba2o004aA46xXhMwDBFs1ySLZA0Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Det Danske Sprog- og Litteraturselskab"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Danish Society for Language and Literature"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dsl.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dsl.dk"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Det Danske Sprog- og Litteraturselskab"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Danish Society for Language and Literature"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.u-cergy.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "disi-infra-systeme@ml.u-cergy.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.u-cergy.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-11-27T10:43:24Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.u-cergy.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.u-cergy.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.u-cergy.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "u-cergy.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.u-cergy.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Cergy Pontoise"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Cergy Pontoise"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAL5VX/FyJxE+QaVPYflgTRs+IqDyMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC51LWNlcmd5LmZyMB4XDTA5MTEyMDE1MTIyNVoX\nDTI5MTEyMDE1MTIyNVowGTEXMBUGA1UEAxMOaWRwLnUtY2VyZ3kuZnIwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC7KhqnXYp0okpZLWhOZfE0/a6hGLOB\n08hVe7wynrKu5rBBXl290/67ral6I2o2Vb2moNpJ+/4Jfoq/dS6pJqGsAQAIIiuJ\nB7Cg1OI0xFSBCNlOw7Pl8790IeX+hDxwlmFCiedz8yU4QaqDypmr8minfUIrcLjE\nQ18eRsHCkRI9yHm6CzZ9qyX9I3pHvkYYwjrOcZ3MR4aWzG+c5IT73Th8SL0Wy6xF\n8BKsR5QFb2Lu4lbcIr3PQCmUTetj/4BbOucZG3s1T9T16I5jqLhfraAxkl6rlV5o\ndRN32vJqMIHWTHBt01SK1h0ox1vfClR86QGFsJDerIy3TRd9AvNwBLkFAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC51LWNlcmd5LmZyhiVodHRwczovL2lkcC51LWNl\ncmd5LmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSRFHgF1B3bXQf6voF95osf\nxbAbhDANBgkqhkiG9w0BAQUFAAOCAQEAtiS/TRfjM8+Ush2VSL/y73Qk6FSExEjQ\nZEFb5YmXCwpnAmrzKTlTVDhaDyYPB5vMQf0PWN8MB1fOy9J7fnN1ENr0oUVwpgkZ\n88THCKybJbsY2NHhxSGVRIkxuIAKh1ofvR3A/9vwteGkzCZYTVloqUR85CBD2qWq\nzE7fqzssOVC0HYf0fuvZyEV1ix45zxhCVtuSjL/39ttUDNcAe0hbc4J+XdtseBXE\n+aj1Ghr+XBI3dG4FUhea8Ic6pTg3BPgSdEZVq2xumojU8lKa+1LzF4IY6YKATkz8\no7TC7JeLaEP9IIl444TjCDusYcOd5ESjG4zw6KiQaO9Jpp2jOL/jMg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Cergy Pontoise"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.u-cergy.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Cergy Pontoise"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://aai.insel.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Inselspital"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:switch-aai@insel.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAI-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Inselspital"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:switch-aai@insel.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAI-Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://aai.insel.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2016-02-05T06:44:46Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAK7E4k9piEwza7yzmzmZydw5nGskMA0GCSqGSIb3DQEB\nCwUAMBcxFTATBgNVBAMMDGFhaS5pbnNlbC5jaDAeFw0xNjAxMDYyMTQ2NDlaFw0x\nOTAxMDYyMTQ2NDlaMBcxFTATBgNVBAMMDGFhaS5pbnNlbC5jaDCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAIHxxvN+AakNF0Hev2R79IkurOJGw6ibdA+2\npx9enpip7Ik5TIvuzakf7hkKL9ib3fqrWsEQzrBZMEs7KvC9oak1rDJIr1CdUp9i\nmJGnF6ZmvJWgxMxN7gogOTJCSnnEF3A8/prp7rQ5K92ItXV4Xcarjh7ijMlrKvKE\n3oxUnP7VRc2PRedwVrePnf1YSKjJ9GoPwgAqYQKpu+UGaRERf0ZLrF76t4//R1vz\nXnw2FG4+u+Px3zCOWr110xGB+tjC0UrOm7u4LfFVN0yQGewTWjKPAClncPD8go+g\nJQJ1qRBcmhrRZ0VA271oVZTBCG7j0k9dKc8PSztfJYRuMyTOPZ0CAwEAAaNfMF0w\nHQYDVR0OBBYEFEq6P/+eGBcgRgWcbv8c3j5Sd8QfMDwGA1UdEQQ1MDOCDGFhaS5p\nbnNlbC5jaIYjaHR0cHM6Ly9hYWkuaW5zZWwuY2gvaWRwL3NoaWJib2xldGgwDQYJ\nKoZIhvcNAQELBQADggEBADtJgWdGm0LqeXw13NDXYmXefpx7IGHcpoWPmwTlkBtB\nuYeDluPBp+foPmAdshSbHW+cSxgE6T1LbxM6ji8ew5tyRLK/3yu83e9b8gW4/PYf\nN07zyUtx6tbWjmWHhdRwG3JrWGjeZFIxhbLQkQ2gjVexCMUqUkmmWERt6ylv/8Kx\nkdrSMarwqii3vU/R2YFtxLRUM2uoxEC1dATJg7QpBv6SMJ2o2goBd5ssnPFRlFco\n5PcMJzQ7SfRD0fdmvRPONfFMnbHmYtCriZduK8f2dWeQl9W0xU/AodamGIbgJVL7\nBbG3+ZKq/D7ulwKieVayksBhM+cMnwpJypdN/cuMSBg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "insel.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai.insel.ch/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai.insel.ch/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aai.insel.ch/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai.insel.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai.insel.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aai.insel.ch/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai.insel.ch/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai.insel.ch/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "insel.ch"
              },
              {
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Insel Gruppe"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Insel Gruppe"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Insel Gruppe"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Insel Gruppe"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "insel.ch"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "inselspital.ch"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:46.947734,7.424789"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "161.62.0.0/16"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAK7E4k9piEwza7yzmzmZydw5nGskMA0GCSqGSIb3DQEB\nCwUAMBcxFTATBgNVBAMMDGFhaS5pbnNlbC5jaDAeFw0xNjAxMDYyMTQ2NDlaFw0x\nOTAxMDYyMTQ2NDlaMBcxFTATBgNVBAMMDGFhaS5pbnNlbC5jaDCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAIHxxvN+AakNF0Hev2R79IkurOJGw6ibdA+2\npx9enpip7Ik5TIvuzakf7hkKL9ib3fqrWsEQzrBZMEs7KvC9oak1rDJIr1CdUp9i\nmJGnF6ZmvJWgxMxN7gogOTJCSnnEF3A8/prp7rQ5K92ItXV4Xcarjh7ijMlrKvKE\n3oxUnP7VRc2PRedwVrePnf1YSKjJ9GoPwgAqYQKpu+UGaRERf0ZLrF76t4//R1vz\nXnw2FG4+u+Px3zCOWr110xGB+tjC0UrOm7u4LfFVN0yQGewTWjKPAClncPD8go+g\nJQJ1qRBcmhrRZ0VA271oVZTBCG7j0k9dKc8PSztfJYRuMyTOPZ0CAwEAAaNfMF0w\nHQYDVR0OBBYEFEq6P/+eGBcgRgWcbv8c3j5Sd8QfMDwGA1UdEQQ1MDOCDGFhaS5p\nbnNlbC5jaIYjaHR0cHM6Ly9hYWkuaW5zZWwuY2gvaWRwL3NoaWJib2xldGgwDQYJ\nKoZIhvcNAQELBQADggEBADtJgWdGm0LqeXw13NDXYmXefpx7IGHcpoWPmwTlkBtB\nuYeDluPBp+foPmAdshSbHW+cSxgE6T1LbxM6ji8ew5tyRLK/3yu83e9b8gW4/PYf\nN07zyUtx6tbWjmWHhdRwG3JrWGjeZFIxhbLQkQ2gjVexCMUqUkmmWERt6ylv/8Kx\nkdrSMarwqii3vU/R2YFtxLRUM2uoxEC1dATJg7QpBv6SMJ2o2goBd5ssnPFRlFco\n5PcMJzQ7SfRD0fdmvRPONfFMnbHmYtCriZduK8f2dWeQl9W0xU/AodamGIbgJVL7\nBbG3+ZKq/D7ulwKieVayksBhM+cMnwpJypdN/cuMSBg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Insel Gruppe"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Insel Gruppe"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.insel.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.insel.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "insel.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.cloud.rsmart.com/saml",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@rsmart.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cloud.rsmart.com/saml",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cloud.rsmart.com/saml/saml2/slo",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.cloud.rsmart.com/saml/saml1/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cloud.rsmart.com/saml/saml2/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cloud.rsmart.com/saml/saml2/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cloud.rsmart.com/saml/saml2/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rsmart.com"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://rsmart.com"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "rSmart Corporate IdP"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://rsmart.com/privacy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "RSmart"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDETCCAfmgAwIBAgIJAMOVQ66HI1iJMA0GCSqGSIb3DQEBCwUAMB8xHTAbBgNV\nBAMMFGlkcC5jbG91ZC5yc21hcnQuY29tMB4XDTE0MDgyMjAzMTA1NloXDTI0MDgy\nMTAzMTA1NlowHzEdMBsGA1UEAwwUaWRwLmNsb3VkLnJzbWFydC5jb20wggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQD1nKxBxHabmRa+ldtR4nduYhun8jph\nOgFcvnewXk/cgG+b+DbvFRB7cFAuEKYRsRd7BFZHHOLuwOYoKI+Ih64lgoMeZ5+V\nQUBIyujk5d5NlQLFWrEJ+qVj33bxnlkD/k8SwOZ7601m33gM+2GFJcTCHGGPeUZO\nXr6B5YBkQi4T1ygCOtP3ND+VgFWZy5aVpn18kd04kw9A2R36zGqE7o550j8ASwLv\nsCNKEubAuw3GpYu666SA/aCpwRukBIX8HO//K69TIx/V87jxL3U/ktdqZvEcYeWQ\nzNE2/DzIRjntMINQXYmPk1xFzgrQAFB93rJumiHcYZCm8ETBiHKHrufnAgMBAAGj\nUDBOMB0GA1UdDgQWBBQ0nS+aXjzlydfphC8jT07rhRTFdjAfBgNVHSMEGDAWgBQ0\nnS+aXjzlydfphC8jT07rhRTFdjAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUA\nA4IBAQCrVxMmJLgZvpDee+2upfdyZma9Xvqt96diO6Kebte0Z1lNi0LIvoaUAqq1\nrAUEqIn55+DJsvdRNWvLVHvTOSrONwH7F8GjNS/EqO1j/6OP0UR1eJwdnSA+5EfB\n7c8cP8PmKvdul0uhOLAj4YjNjCHW04SxKWMeEBvvNaA/gXFIGnSFfgZeXcFrhc+h\n+zSm7YYGwLgTDkHOQZRIaHDVbuMuVCdkMLLFkbJOT8diJWZbSXt1oTOsr9mGvlJm\nhyZQAvr/QOSMv/csIOcNnq5bJ5rkMPUHC5+/BWO88iO5wMm+vxIYRnTB1flw/o0i\ncpX6/qZs7VVwnx5qd3n4+ZUKOzN4"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idp.cloud.rsmart.com/error"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RSmart"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rsmart.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RSmart"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ltu.hr.evry.se/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "primulasupport@evry.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Primula"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ltu.hr.evry.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Evry HR Solutions AB"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.evry.se/it-tjanster/applikationstjanster-och-losningar/personal-och-lonesystem/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Evry HR Solutions AB"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Webgr\u00e4nssnittet till HR-systemet Primula fr\u00e5n EVRY HR Solutions AB f\u00f6r anst\u00e4llda vid Lule\u00e5 tekniska universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The web interface to the HR software system Primula from EVRY HR Solutions AB for employees at Lule\u00e5 University of Technology"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Primula"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Primula"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDuDCCAqACBQCo2ygOMA0GCSqGSIb3DQEBBAUAMIGfMQswCQYDVQQGEwJTRTEQ\nMA4GA1UECBMHVXBwc2FsYTEdMBsGA1UEChMURXZyeSBIUiBTb2x1dGlvbnMgQUIx\nEDAOBgNVBAcTB1VwcHNhbGExEzARBgNVBAMTCmhyLmV2cnkuc2UxEDAOBgNVBAsT\nB1ByaW11bGExJjAkBgkqhkiG9w0BCQEWF3ByaW11bGFzdXBwb3J0QGV2cnkuY29t\nMB4XDTE1MDEyNzEzMTQ0M1oXDTI1MDEyNDEzMTQ0M1owgZ8xCzAJBgNVBAYTAlNF\nMRAwDgYDVQQIEwdVcHBzYWxhMR0wGwYDVQQKExRFdnJ5IEhSIFNvbHV0aW9ucyBB\nQjEQMA4GA1UEBxMHVXBwc2FsYTETMBEGA1UEAxMKaHIuZXZyeS5zZTEQMA4GA1UE\nCxMHUHJpbXVsYTEmMCQGCSqGSIb3DQEJARYXcHJpbXVsYXN1cHBvcnRAZXZyeS5j\nb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCvJstEPNIMU6Q+1Fie\nekZiInII7woqYNQ9cg30gvwYluNA9aKs9Rx1OXufcvxZEhcQ1R5zCe2gWa7I9bCi\ngyluonu51qmk++c7aMLIXU1pXhM/6sIXIHy36WZbabg7HYp4Ju+diUmV+LxWAe3c\nzjvoFWC3pr4mwJBeUkQtKk+UBLd4L6rOAM2htN6lyXduMcSJMSckS4aZqYMj02Dd\nhz3lMiSVErkA351af+oVC+6HghlnfNyiJbjGh+hslPcvnrBaOCX84/QI36X0NZjo\n7/o5vfmbfEM3K4YZklqhjkXOm+0KuRWj3DLyxqDyMURu4WNpMlap+kPhm1J64agx\nuo6rAgMBAAEwDQYJKoZIhvcNAQEEBQADggEBAEl9NSzAegcuz+J2ktf63LNRge/e\nGxWW8KIM2t5HyWYudHBTsVqlSNQEe1V/vmW/lwntct7gGHXwnPp8Ulb3JrGjJq6I\nNukeIMKSMJVHsCYTwbAqeCT6POaX6C8Uzs4CFV8VUv3x61Rbr7BKrYgxf2Q+CyG7\n2fWaucSmjZ56flYFTUmJ1sFzYuFKn9Ty5xPMV/eGmlT8kJ8HBH5E3cVQ+vVSoRYf\nfP/0el9T10aI13RD/03wXWCku1Ewx8Qqw+ANcN9HhZwdH23kpP+jYiBfOmhtCDh1\nDTGN04FIC5s+8yFP1O/+RrQ8DQRmS/dfyc8iOXxm5vsWIVAnwD5nX5WrSp4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ltu.hr.evry.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ltu.hr.evry.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ltu.hr.evry.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:artifact-01",
              "location": "https://ltu.hr.evry.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:browser-post",
              "location": "https://ltu.hr.evry.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Primula Web"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eppn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "norEduPersonNIN",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.2428.90.1.5",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp1.proofidcloud.co.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@proofid.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Heaney"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ukfed@proofid.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp1.proofidcloud.co.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-07-29T13:42:12Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAO42NKVQT3aOFGBFVBQbZ5n2yNhCMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCIxIDAeBgNVBAMTF2lkcDEucHJvb2ZpZGNsb3VkLmNvLnVrMB4XDTE0MDcy\n\t\t\t\t\t\tOTA5MjU0MVoXDTM0MDcyOTA5MjU0MVowIjEgMB4GA1UEAxMXaWRwMS5wcm9vZmlk\n\t\t\t\t\t\tY2xvdWQuY28udWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCygPFc\n\t\t\t\t\t\t+Y88TUGNchadaZmOW1iHZdenETJvkgYAbAa3jKaKkUXzN36EAmwTw2xMZEhjRofI\n\t\t\t\t\t\tvfxdK8L1Pq12ohcDErK26/tTXPLeECsKXv1L4DOClQYCmi3pSHSoXuznWwKQdifq\n\t\t\t\t\t\thbU0Qu2+Sf/fGaEt3h2+/hwgwKuS+IRv39/XwHab6i+VfU76BpkKfL8z1YBftha7\n\t\t\t\t\t\tgguvXYYMq+OcNR5Js4V4vZNsNTLdrWg2SrWG9aoyChHeQBE0D0piBbKH7qftAkN9\n\t\t\t\t\t\t98ABxnZMYbRQK7jXBybRlRl/fKjdXXZOl2pP3J6yco8+LAzAokWB/vCCh5W2FKW4\n\t\t\t\t\t\t1h0aej05wepq/5KRAgMBAAGjdTBzMFIGA1UdEQRLMEmCF2lkcDEucHJvb2ZpZGNs\n\t\t\t\t\t\tb3VkLmNvLnVrhi5odHRwczovL2lkcDEucHJvb2ZpZGNsb3VkLmNvLnVrL2lkcC9z\n\t\t\t\t\t\taGliYm9sZXRoMB0GA1UdDgQWBBTpX6QnFh6Olp5+tHJlBUytNeIhezANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAJ8sa6jPg5IZ/00j/G1IJl15hCgMumyef27HNBA1yMpQhYwxE\n\t\t\t\t\t\tvNiHPXenv98nPYe9y7YcC52E2ZmmTF91sAPKomfg029/iO6oJiSVVmVb9z8qu2Df\n\t\t\t\t\t\tAtJxixzs++rAvosd/0lV3EXUgrwdmq3Gp3HnbRuwodu59oPtOlOb3yqa8x1BHYD3\n\t\t\t\t\t\tkHvJhFKX+LrKTZiw6kNl9wQyNSaQ/MpFNcweLU+Se40qchjKpUDZtYKg/UxZToux\n\t\t\t\t\t\tLrh0v65OPRCnaVWpnkouhVW341rvY1cSGGOrGeG8QoQWAI/UbdZtjYicrIV7Wt3G\n\t\t\t\t\t\t9C6qgxQNg/yFFt3Z1jhEgxkVlpktnahzL/cKSA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "proofidcloud.co.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.proofidcloud.co.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.proofidcloud.co.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp1.proofidcloud.co.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp1.proofidcloud.co.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.proofidcloud.co.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp1.proofidcloud.co.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp1.proofidcloud.co.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp1.proofidcloud.co.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp1.proofidcloud.co.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.proofidcloud.co.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.proofidcloud.co.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "proofidcloud.co.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://idp1.proofidcloud.co.uk/images/proofid-60.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ProofID test Shibboleth identity provider"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAO42NKVQT3aOFGBFVBQbZ5n2yNhCMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCIxIDAeBgNVBAMTF2lkcDEucHJvb2ZpZGNsb3VkLmNvLnVrMB4XDTE0MDcy\n\t\t\t\t\t\tOTA5MjU0MVoXDTM0MDcyOTA5MjU0MVowIjEgMB4GA1UEAxMXaWRwMS5wcm9vZmlk\n\t\t\t\t\t\tY2xvdWQuY28udWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCygPFc\n\t\t\t\t\t\t+Y88TUGNchadaZmOW1iHZdenETJvkgYAbAa3jKaKkUXzN36EAmwTw2xMZEhjRofI\n\t\t\t\t\t\tvfxdK8L1Pq12ohcDErK26/tTXPLeECsKXv1L4DOClQYCmi3pSHSoXuznWwKQdifq\n\t\t\t\t\t\thbU0Qu2+Sf/fGaEt3h2+/hwgwKuS+IRv39/XwHab6i+VfU76BpkKfL8z1YBftha7\n\t\t\t\t\t\tgguvXYYMq+OcNR5Js4V4vZNsNTLdrWg2SrWG9aoyChHeQBE0D0piBbKH7qftAkN9\n\t\t\t\t\t\t98ABxnZMYbRQK7jXBybRlRl/fKjdXXZOl2pP3J6yco8+LAzAokWB/vCCh5W2FKW4\n\t\t\t\t\t\t1h0aej05wepq/5KRAgMBAAGjdTBzMFIGA1UdEQRLMEmCF2lkcDEucHJvb2ZpZGNs\n\t\t\t\t\t\tb3VkLmNvLnVrhi5odHRwczovL2lkcDEucHJvb2ZpZGNsb3VkLmNvLnVrL2lkcC9z\n\t\t\t\t\t\taGliYm9sZXRoMB0GA1UdDgQWBBTpX6QnFh6Olp5+tHJlBUytNeIhezANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAJ8sa6jPg5IZ/00j/G1IJl15hCgMumyef27HNBA1yMpQhYwxE\n\t\t\t\t\t\tvNiHPXenv98nPYe9y7YcC52E2ZmmTF91sAPKomfg029/iO6oJiSVVmVb9z8qu2Df\n\t\t\t\t\t\tAtJxixzs++rAvosd/0lV3EXUgrwdmq3Gp3HnbRuwodu59oPtOlOb3yqa8x1BHYD3\n\t\t\t\t\t\tkHvJhFKX+LrKTZiw6kNl9wQyNSaQ/MpFNcweLU+Se40qchjKpUDZtYKg/UxZToux\n\t\t\t\t\t\tLrh0v65OPRCnaVWpnkouhVW341rvY1cSGGOrGeG8QoQWAI/UbdZtjYicrIV7Wt3G\n\t\t\t\t\t\t9C6qgxQNg/yFFt3Z1jhEgxkVlpktnahzL/cKSA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ProofID test Shibboleth identity provider"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.proofid.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ProofID Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.unipi.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Technical Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@unipi.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tognini"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:samuele.tognini@unipi.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Samuele"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Vaghetti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:davide.vaghetti@unipi.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Davide"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.unipi.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2011-11-01T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVANpHH4cWOn6yEYz2lRJ3vuZn9emLMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDGlkcC51bmlwaS5pdDAeFw0xMTAzMTAxMzM4MjRaFw0z\nMTAzMTAxMzM4MjRaMBcxFTATBgNVBAMTDGlkcC51bmlwaS5pdDCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAIxD1yQuyQ1P7wVjslFUKXVAtWQ2Oe9h7vVO\nzGVo+08dZ1RFoS9e4wtMj3UOme7VwxKdvlkzp3B0sSJS5FqZ7oMf3Wi0SZKbldew\nzvO/ToeJLjCq4oQBXmi7RePwHZ2GEmyzk7JTujtnBrY6vjfIB+AwviT3y13OHCqB\nT1XCi8bNsAoviDjyN/TKG/AU1pJFc5NWFLRy1YKC+5FlJCh/Kr+uC/KVdUhn40Wm\ncAjLfTATK+Y1RbVb4eHF6vJOOBsTQqvat4heBmpBnuyY06ngU/dZp6Te3BCPMSm2\n6PQnYF8uf9Ftf5U++J32DJIRKimN8N3y0sVK8xsaIUbmAfkT6gMCAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMaWRwLnVuaXBpLml0hiNodHRwczovL2lkcC51bmlwaS5pdC9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUuVwagCJNNlDEGjXsYBV07TH67W4wDQYJ\nKoZIhvcNAQEFBQADggEBACVqW+MNuwIyvc4ut3mhAt/TBD5HOFO7kPaylsaTwIe6\nhBgb6H9cEMHQAmgNFITHjzLjDiM5dag9dWqdDvHLoINgKEKgBSN8/tEJoh7qI60m\nPv7PNEN3Jolwm8YeB0dite8aPioPvw4kReGAQnmkvDX4q809p3SRBOI9SCM4Rgwu\nxZq2gW4a+MiO6qdJ/MQi/3526//S2wreCvVijqYj68zo+NEN/3vevH/r9aWLZYsI\nVPU5U8UPwrVbbpGR6yUiilBrLvdHfaXWNOTnY7XBdMBms0JZEYGRiyUmQ6j4Pi/H\n23jC2wFN8qTFa4MKNluOJFOvXzgSY5iS1t6g0hrslao="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unipi.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unipi.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unipi.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.unipi.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unipi.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.unipi.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unipi.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unipi.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unipi.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unipi.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idp.unipi.it/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idp.unipi.it/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 degli Studi di Pisa"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Pisa"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for University of Pisa users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti dell'Universita' degli Studi di Pisa"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.unipi.it/logos/cherubino_80x80.png",
                    "height": "82",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idp.unipi.it/logos/cherubino_16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://idp.unipi.it/privacy_it.html"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://idp.unipi.it/privacy_en.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVANpHH4cWOn6yEYz2lRJ3vuZn9emLMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDGlkcC51bmlwaS5pdDAeFw0xMTAzMTAxMzM4MjRaFw0z\nMTAzMTAxMzM4MjRaMBcxFTATBgNVBAMTDGlkcC51bmlwaS5pdDCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAIxD1yQuyQ1P7wVjslFUKXVAtWQ2Oe9h7vVO\nzGVo+08dZ1RFoS9e4wtMj3UOme7VwxKdvlkzp3B0sSJS5FqZ7oMf3Wi0SZKbldew\nzvO/ToeJLjCq4oQBXmi7RePwHZ2GEmyzk7JTujtnBrY6vjfIB+AwviT3y13OHCqB\nT1XCi8bNsAoviDjyN/TKG/AU1pJFc5NWFLRy1YKC+5FlJCh/Kr+uC/KVdUhn40Wm\ncAjLfTATK+Y1RbVb4eHF6vJOOBsTQqvat4heBmpBnuyY06ngU/dZp6Te3BCPMSm2\n6PQnYF8uf9Ftf5U++J32DJIRKimN8N3y0sVK8xsaIUbmAfkT6gMCAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMaWRwLnVuaXBpLml0hiNodHRwczovL2lkcC51bmlwaS5pdC9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUuVwagCJNNlDEGjXsYBV07TH67W4wDQYJ\nKoZIhvcNAQEFBQADggEBACVqW+MNuwIyvc4ut3mhAt/TBD5HOFO7kPaylsaTwIe6\nhBgb6H9cEMHQAmgNFITHjzLjDiM5dag9dWqdDvHLoINgKEKgBSN8/tEJoh7qI60m\nPv7PNEN3Jolwm8YeB0dite8aPioPvw4kReGAQnmkvDX4q809p3SRBOI9SCM4Rgwu\nxZq2gW4a+MiO6qdJ/MQi/3526//S2wreCvVijqYj68zo+NEN/3vevH/r9aWLZYsI\nVPU5U8UPwrVbbpGR6yUiilBrLvdHfaXWNOTnY7XBdMBms0JZEYGRiyUmQ6j4Pi/H\n23jC2wFN8qTFa4MKNluOJFOvXzgSY5iS1t6g0hrslao="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 di Pisa"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Pisa"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unipi.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unipi.it/english"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli Studi di Pisa"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Pisa"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://prdidp.uncg.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sshensle@uncg.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Susan Hensley"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rwgorrel@uncg.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert Gorrell"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "6-tech@uncg.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Service Desk (6-TECH)"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://prdidp.uncg.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.uncg.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uncg.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uncg.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.uncg.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uncg.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uncg.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uncg.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uncg.edu"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of North Carolina at Greensboro"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNCG is a public liberal arts and research university in Greensboro, North Carolina and constituent institution of the UNC system."
                  }
                ],
                "logo": [
                  {
                    "text": "https://uncgcdn.blob.core.windows.net/inc/formatted-uncg-incommon.gif",
                    "lang": "en",
                    "height": "96",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "101"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://policy.uncg.edu/acceptable_use/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMjCCAhqgAwIBAgIJAMqxN/v9QtC8MA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD3ByZGlkcC51bmNnLmVkdTAeFw0xMTA2MTMxNTI3MzdaFw0yMTA2MTMxNTI3\nMzdaMBoxGDAWBgNVBAMTD3ByZGlkcC51bmNnLmVkdTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAMcQLm/5wUB0aOWQgN+yBxS1+VsN1VLUbeaE9k6S4ADD\nBgZ6uHYrprWyp7JqYYS96I3y3B6/FFwC44CWc9Drajgx3vgwl6tmdbjMZxiVhILC\nTCT0bVBvfelq/9p/6Jy9CCEr+mtaH5YgTlfbByKjrAqzrl2/e3aIKKI8AH/MKU7p\np9U7NBCw50GNUa+NZ+nzIXLx/iYGzyhBjmzfD1RI6sHYVV+rx2IZjYZ8+Lw9tJ/H\nkWIAbEslY7CHS6nhVsRXKN1CZUdjNUOX1Ce74ygS1/DarGb7lIB8byWfeW/8PTkR\nrE1tgSNktCtn4L8OKV/Ma4i4oFsl1s4tTAq3gy68kYsCAwEAAaN7MHkwHQYDVR0O\nBBYEFO5c0T5RBCqKHUzjFUXn9avY7HHJMEoGA1UdIwRDMEGAFO5c0T5RBCqKHUzj\nFUXn9avY7HHJoR6kHDAaMRgwFgYDVQQDEw9wcmRpZHAudW5jZy5lZHWCCQDKsTf7\n/ULQvDAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCtqJqAWwbQI/l1\ni+a3Eom2upU7r9NQ8bw/IvBNr6VLkJyGmm4Y41hh6yp6zKUerECVwVGfcdOumLQQ\nrQvfG9XK9Ax5CxC34/qA8cn6TuHldPntBqGiCcPfqjN64wCITl0MhJ+FrRTXVhw1\nFutslB2FC/t+EyPkk1FB8RBa417/Rf24AcAnGb0CuM6Y/M22dvYNrLE+mePL4JTM\nBu22LQTtR6UgA6NvQR7Znv/XrtHKCzkcEwKWTuZjiZQqjpItTjYl3Fz/BOITT+57\n+lxD/J8U1TYtgs0D5Im9Ttt09xRzeXB0+gHWUIV7oM/KURL8RO6fPxj1gE5wcQrt\n9C/plVjK"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idp.uncg.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of North Carolina at Greensboro"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uncg.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of North Carolina at Greensboro"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.sgsu.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.sgsu.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-04-13T14:37:41Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "St George's Students Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sgsu.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.sgsu.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.sgsu.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.sgsu.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.sgsu.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.sgsu.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.sgsu.org.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.sgsu.org.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.sgsu.org.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.sgsu.org.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.sgsu.org.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.sgsu.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.sgsu.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.sgsu.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.sgsu.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.sgsu.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.sgsu.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.longroad.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@longroad.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CSD Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@longroad.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CSD Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.longroad.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUCy8kggY2RBllD2ewV21UpOU1mlkwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHTEbMBkGA1UEAxMSaWRwLmxvbmdyb2FkLmFjLnVrMB4XDTExMDUxMzA4MTI0\n\t\t\t\t\t\tM1oXDTMxMDUxMzA4MTI0M1owHTEbMBkGA1UEAxMSaWRwLmxvbmdyb2FkLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAgcmsqS7ONbUBSlCFn4+5\n\t\t\t\t\t\tndvJvVgknMjZVZZulScLs3K1R7cJifMh/njFVDxdZ2fFBFwstUmUljjiM/GgBPGj\n\t\t\t\t\t\tGMVEysJRzOiuTVaON3t/hE918o6DDZpkIcAC7JRuo9OL21K70WsJV9J1dqmx9t5n\n\t\t\t\t\t\te+rj/s/w0HB3GOR/3J2B9xbkX16B7wXBBZILhRcFy4nd1wFOCmurSC20o6iUwBsH\n\t\t\t\t\t\t9lEVQlx/Es4o9sa8+U+5qtnQGDEiy2l9R7Em1lrpAnFpqM6n7C9kh4sMsIdGRFy5\n\t\t\t\t\t\t0Q/4hSMRGNWyExP29Ipa0A6r8bfSlnN4lMo1QZMjBXS1NNHnVEpnafmO+CwyWL20\n\t\t\t\t\t\tbwIDAQABo2swaTBIBgNVHREEQTA/ghJpZHAubG9uZ3JvYWQuYWMudWuGKWh0dHBz\n\t\t\t\t\t\tOi8vaWRwLmxvbmdyb2FkLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQe\n\t\t\t\t\t\tdOgyl13wsMnik57R8aImPj76cjANBgkqhkiG9w0BAQUFAAOCAQEAEz5uJOOUmPsn\n\t\t\t\t\t\t7Mq0h2FY8mDrwmVFTNismazFxmCEykDZON1baS6wnKjQC22w/MWJ8gq0NEwY/If2\n\t\t\t\t\t\tfg3ZL7L6eEKWPHf10HNi1HdlgdQ6JWf5I/CLnccrQdwAfeeJ4O/1qtscXpylqp5y\n\t\t\t\t\t\tAesJcymZxwcqQ+rWxFvxXKhk4RNabImkitFqxngqOfEaML+hL0OMlsO9GJbUgUPn\n\t\t\t\t\t\tKrvGzcxIUT2L7hWBAIkM3rhBUkcEXLJzVcLPXW122Wcjr5gk6/il9cyveqANRbiB\n\t\t\t\t\t\tX/xSXhUkBYgRzeNd4EaiR4zZLepncxkcIZF+To/nrXNoghw9aQny7LYKL9dOeOIT\n\t\t\t\t\t\tgyi6viaAxA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "longroad.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.longroad.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.longroad.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.longroad.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.longroad.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.longroad.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.longroad.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.longroad.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.longroad.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "longroad.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://idp.longroad.ac.uk/idp/images/idp-logo-80x60.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idp.longroad.ac.uk/idp/images/idp-icon-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Long Road Sixth Form College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUCy8kggY2RBllD2ewV21UpOU1mlkwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHTEbMBkGA1UEAxMSaWRwLmxvbmdyb2FkLmFjLnVrMB4XDTExMDUxMzA4MTI0\n\t\t\t\t\t\tM1oXDTMxMDUxMzA4MTI0M1owHTEbMBkGA1UEAxMSaWRwLmxvbmdyb2FkLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAgcmsqS7ONbUBSlCFn4+5\n\t\t\t\t\t\tndvJvVgknMjZVZZulScLs3K1R7cJifMh/njFVDxdZ2fFBFwstUmUljjiM/GgBPGj\n\t\t\t\t\t\tGMVEysJRzOiuTVaON3t/hE918o6DDZpkIcAC7JRuo9OL21K70WsJV9J1dqmx9t5n\n\t\t\t\t\t\te+rj/s/w0HB3GOR/3J2B9xbkX16B7wXBBZILhRcFy4nd1wFOCmurSC20o6iUwBsH\n\t\t\t\t\t\t9lEVQlx/Es4o9sa8+U+5qtnQGDEiy2l9R7Em1lrpAnFpqM6n7C9kh4sMsIdGRFy5\n\t\t\t\t\t\t0Q/4hSMRGNWyExP29Ipa0A6r8bfSlnN4lMo1QZMjBXS1NNHnVEpnafmO+CwyWL20\n\t\t\t\t\t\tbwIDAQABo2swaTBIBgNVHREEQTA/ghJpZHAubG9uZ3JvYWQuYWMudWuGKWh0dHBz\n\t\t\t\t\t\tOi8vaWRwLmxvbmdyb2FkLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQe\n\t\t\t\t\t\tdOgyl13wsMnik57R8aImPj76cjANBgkqhkiG9w0BAQUFAAOCAQEAEz5uJOOUmPsn\n\t\t\t\t\t\t7Mq0h2FY8mDrwmVFTNismazFxmCEykDZON1baS6wnKjQC22w/MWJ8gq0NEwY/If2\n\t\t\t\t\t\tfg3ZL7L6eEKWPHf10HNi1HdlgdQ6JWf5I/CLnccrQdwAfeeJ4O/1qtscXpylqp5y\n\t\t\t\t\t\tAesJcymZxwcqQ+rWxFvxXKhk4RNabImkitFqxngqOfEaML+hL0OMlsO9GJbUgUPn\n\t\t\t\t\t\tKrvGzcxIUT2L7hWBAIkM3rhBUkcEXLJzVcLPXW122Wcjr5gk6/il9cyveqANRbiB\n\t\t\t\t\t\tX/xSXhUkBYgRzeNd4EaiR4zZLepncxkcIZF+To/nrXNoghw9aQny7LYKL9dOeOIT\n\t\t\t\t\t\tgyi6viaAxA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Long Road Sixth Form College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.longroad.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Long Road Sixth Form College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp-nya.bth.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://sp-nya.bth.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp-nya.bth.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp-nya.bth.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp-nya.bth.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp-nya.bth.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://localhost.localdom/shibboleth"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "localhost.localdom"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIJAPCfAvPVoGjGMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEmxvY2FsaG9zdC5sb2NhbGRvbTAeFw0wOTA2MjQxNDA3MDhaFw0xOTA2MjIx\nNDA3MDhaMB0xGzAZBgNVBAMTEmxvY2FsaG9zdC5sb2NhbGRvbTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALeBQ5D5sonC9Tai/+Dm0fi6bxkGWi95Pbtt\ngcZwNxUJjJ0HyEiJJel7zVbUalemllaf4J7LTX+T6XUl5452qgd8Fv1HBGkhezq8\nP8qkJd2Mih7Us43k4xi2b1atsvdfeWdHQrNbtAqDCTwsH1GVmAgZc66c6Wkk53Mt\nVGH7GtDdNkK9hSqXMuk5B9Ov5Iq4g7MJQNVCWj4cizscQC5mAZB/Yw+CulEvi5Kg\nvNCQVFg0bBpC+0aL9IpT6vtS1cuBZKmN/z64iyD3glIeQ9fuumUrSuLHmKOCy7Kq\n3WXMHqTZcHGbDcpIeCBST4QgCySP6ajwFVMzxCW+5MataQeo9mkCAwEAAaNnMGUw\nRAYDVR0RBD0wO4ISbG9jYWxob3N0LmxvY2FsZG9thiVodHRwczovL2xvY2FsaG9z\ndC5sb2NhbGRvbS9zaGliYm9sZXRoMB0GA1UdDgQWBBRL+ENhdpInVAgkI5q2dRYh\nl5nM3DANBgkqhkiG9w0BAQUFAAOCAQEAeR7YWtjttMPr3aQCMxxtzSfj+tpb+s0h\nxXwH9DhIf6gsvwNF9I/99OJ6PLDqovKGD9VDaADRCKJi4K6qTtn/pcIj+WAfYlBU\nToH+Zu7h8XbHsfRKq6MxH8xjxee/VIcPlm15bCJ16qSEA3HFxKVv7+dGMzz1uI/0\n7g5eXCE/7zp7CCyoAWkqU/QlGFZuaE4G1Ee0bepfOalePvEHb28hSC728+9hM2pF\nGguL7+C52scvuAbqa9wPXn43BJzjrJX2Z1ItKbUHdKnDtFUew9DXRWFzxjRfToEN\nekmka1/wMV9rv31RCKyKaYvWrGBAIO8IQWWGU4X0+y/rKn71cxoskg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=localhost.localdom"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://localhost.localdom/shibboleth"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "localhost.localdom"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIJAPCfAvPVoGjGMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEmxvY2FsaG9zdC5sb2NhbGRvbTAeFw0wOTA2MjQxNDA3MDhaFw0xOTA2MjIx\nNDA3MDhaMB0xGzAZBgNVBAMTEmxvY2FsaG9zdC5sb2NhbGRvbTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALeBQ5D5sonC9Tai/+Dm0fi6bxkGWi95Pbtt\ngcZwNxUJjJ0HyEiJJel7zVbUalemllaf4J7LTX+T6XUl5452qgd8Fv1HBGkhezq8\nP8qkJd2Mih7Us43k4xi2b1atsvdfeWdHQrNbtAqDCTwsH1GVmAgZc66c6Wkk53Mt\nVGH7GtDdNkK9hSqXMuk5B9Ov5Iq4g7MJQNVCWj4cizscQC5mAZB/Yw+CulEvi5Kg\nvNCQVFg0bBpC+0aL9IpT6vtS1cuBZKmN/z64iyD3glIeQ9fuumUrSuLHmKOCy7Kq\n3WXMHqTZcHGbDcpIeCBST4QgCySP6ajwFVMzxCW+5MataQeo9mkCAwEAAaNnMGUw\nRAYDVR0RBD0wO4ISbG9jYWxob3N0LmxvY2FsZG9thiVodHRwczovL2xvY2FsaG9z\ndC5sb2NhbGRvbS9zaGliYm9sZXRoMB0GA1UdDgQWBBRL+ENhdpInVAgkI5q2dRYh\nl5nM3DANBgkqhkiG9w0BAQUFAAOCAQEAeR7YWtjttMPr3aQCMxxtzSfj+tpb+s0h\nxXwH9DhIf6gsvwNF9I/99OJ6PLDqovKGD9VDaADRCKJi4K6qTtn/pcIj+WAfYlBU\nToH+Zu7h8XbHsfRKq6MxH8xjxee/VIcPlm15bCJ16qSEA3HFxKVv7+dGMzz1uI/0\n7g5eXCE/7zp7CCyoAWkqU/QlGFZuaE4G1Ee0bepfOalePvEHb28hSC728+9hM2pF\nGguL7+C52scvuAbqa9wPXn43BJzjrJX2Z1ItKbUHdKnDtFUew9DXRWFzxjRfToEN\nekmka1/wMV9rv31RCKyKaYvWrGBAIO8IQWWGU4X0+y/rKn71cxoskg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=localhost.localdom"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp-nya.bth.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp-nya.bth.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp-nya.bth.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp-nya.bth.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp-nya.bth.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp-nya.bth.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp-nya.bth.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp-nya.bth.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp-nya.bth.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp-nya.bth.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.independence.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:issues@independence.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Issues"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sewell"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kari@realnet.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kari"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.independence.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-08-12T15:52:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Independence Educational Publishers: Independence Issues Online"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://independence.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Independence Educational Publishers Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.independence.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.independence.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.independence.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.independence.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.independence.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.independence.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.independence.co.uk/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Issues Online explores today's most important social issues through \n\t\t\t\t\tarticles, videos, ebooks & more."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.issuesonline.co.uk/resources/images/header/logo.png",
                    "height": "79",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "329"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Issues Online"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJALdHDkKittLZMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\n\t\t\t\t\t\tBAMTF3JlYWwxLnJlYWxuZXQyMDAwLmNvLnVrMB4XDTExMDgwMjEyMTYxNVoXDTIx\n\t\t\t\t\t\tMDczMDEyMTYxNVowIjEgMB4GA1UEAxMXcmVhbDEucmVhbG5ldDIwMDAuY28udWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC/Ogks/sRjSvAzujMkoEn7\n\t\t\t\t\t\t89fJQ4EHrCbnvAF/7dAKRhsr2Yalkvuf6oNI+SI7NL1lUiNWOBYyIVBEl2Q9gyi3\n\t\t\t\t\t\t5/AWMPDe0c1Kw7Y0lBBvKDEzyixlSfTh/Nszh4qgaVBvV1qaFc65SK4m+EWXoB+3\n\t\t\t\t\t\tT1lUX/5upB188Xj4xtl+QDv1iPGNBRlfstG9RUMVgNHeHTCYLdWYQv+ZubbBJUkX\n\t\t\t\t\t\tSZ+xedFVulYAMPn5qjh2F0z0fTw6yzY9arrWRohbVoZyUXODO+ekGTGMj4OHJk2a\n\t\t\t\t\t\tBVvRzeCburjo8NRV58kq97zqEgPYqFeTj9eFxN7nkej5VRD3FWBPtH63DTLVIdAB\n\t\t\t\t\t\tAgMBAAGjRTBDMCIGA1UdEQQbMBmCF3JlYWwxLnJlYWxuZXQyMDAwLmNvLnVrMB0G\n\t\t\t\t\t\tA1UdDgQWBBQW+gIr9QKPFZn7blTtjZ4W/zt3JzANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tB52AFbao2FOGfM1rS/XAy8j3qrLVJOPoEGevcN6lA+J0xfzLIQnqGgLNagIYMR/t\n\t\t\t\t\t\tMMTLNK/Z7fTPQsDEXXr3aH+yKBjctyWz3vAkVM7r/JzopxSCuwzVNkawDqfeyXVW\n\t\t\t\t\t\tZkQfI16kQXh/Rdom2K6MMHG8YEKvc1w2UlnjX8qo7N8n2NqZiDZvvB1rP12ER0cq\n\t\t\t\t\t\tQrQo1cgAM2crAb7eVXHxYVlfMqnD4y4xVkcwf1hoYEfxjFWExRKp+pom4tffxXs2\n\t\t\t\t\t\tOt71rokgeIjZSPUMPCSfu/PGiw2S8yxiEi8/5sXx0mbFNJ+SlamPNl8AYSONeiTu\n\t\t\t\t\t\tCsJ2jfI9xrr+q7DFANi+HQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.independence.co.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.independence.co.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.independence.co.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.independence.co.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.independence.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.independence.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.independence.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.independence.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.independence.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.independence.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.uni-market.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@uni-market.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Uni Market"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@uni-market.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Uni Market"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.uni-market.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-08-22T10:09:29Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Uni Market"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-market.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Uni-Market Enterprises Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.uni-market.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.uni-market.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.uni-market.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.uni-market.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.uni-market.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.uni-market.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.uni-market.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Your student marketplace has arrived. Buy and sell university essentials on a safe online platform!"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.uni-market.co.uk/Content/images/common/logo.png",
                    "height": "130",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "130"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Uni Market"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAIMM91GfaXNYMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHVuaS1tYXJrZXQuY28udWswHhcNMTUwOTAyMTQzODQ4WhcNMjUwODMwMTQz\n\t\t\t\t\t\tODQ4WjAbMRkwFwYDVQQDExB1bmktbWFya2V0LmNvLnVrMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAoIWuFsiiajSGtYqmpxT0bxcJu6A6E3tV+M6rMqtT\n\t\t\t\t\t\tXdW+vKwclFjBqZOaVzGt/QBIlgmjsVq/4jy6Y9soQHBU6/elfPpUSa0hP8S3gaL3\n\t\t\t\t\t\t6udsAZdLjxNF0moOE7zpuqJy4uVWgC7f+G1isCanczA9X5maia19OKh83gAeYuLW\n\t\t\t\t\t\tzvsctKb+AywyQ1nZOfO+4VAljvj+1MM0Mh08u1MlNlO1jhqAB2aMLF/otiGZvvu6\n\t\t\t\t\t\tARhsaIJNF4nuaGdZRMZP66CavTyISHKqfloklnyNvBte+KoC5ysjN38uAr9UZ26p\n\t\t\t\t\t\tK++YWhE4wKsUSxlwtueHrNuV7f95D/JPUNKFrp8CDOcdnQIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB1bmktbWFya2V0LmNvLnVrMB0GA1UdDgQWBBS4qCoHKhUElrDEDToF\n\t\t\t\t\t\tkd0vlbwUHDANBgkqhkiG9w0BAQUFAAOCAQEAW34+CTBilEo239rXa998aQRg6w0t\n\t\t\t\t\t\tbiNoIjxYlgkmvaGRddIQNBNLHq+dxIUH1KiXqlCT+yIPuCSKU8Fwc4JkEx7w5I2m\n\t\t\t\t\t\tr/SGPeQNkZangDlkd+uKjDUOZ78MbgmdOotWUUFe0UdyB2j/BGLkVR9Ia1q5oVwo\n\t\t\t\t\t\tzenDzOGq1iu9uhmQDq0VM7CxL4uAmNlV85lOdT3o1OIRV4QBhChnvt8HGVqiuOZo\n\t\t\t\t\t\toDXqb5aLalOGbSRALV1UyVZJQUr0Z+7zZh2HWwk2VqhOgBdXlrG48/E+orSYHodG\n\t\t\t\t\t\tzZIKEZpWB/Mio9aTqkqLW5eEI3zHyBK+ywCylVl8PVWIY7fSo1OCVL//zA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.uni-market.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.uni-market.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.uni-market.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.uni-market.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.uni-market.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.uni-market.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.newcollege.ac.uk/athensla",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Turpin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:richard.turpin@newcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hole"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Ian.hole@newcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.newcollege.ac.uk/athensla",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-10-17T09:21:34Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://athensruntime.newcollege.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://athensruntime.newcollege.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "newcollege.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://www.newcollege.ac.uk/athens/logo.jpg",
                    "height": "523",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "258"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "New College Swindon LA"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYDCCAkigAwIBAgIIDMoTE+e8SLkwDQYJKoZIhvcNAQEFBQAwRzEcMBoGA1UE\n\t\t\t\t\t\tCgwTTmV3IENvbGxlZ2UgU3dpbmRvbjEnMCUGA1UEAwweYXRoZW5zcnVudGltZS5u\n\t\t\t\t\t\tZXdjb2xsZWdlLmFjLnVrMB4XDTE0MDkwOTEzMjk0N1oXDTI0MDkwOTEzMjk0N1ow\n\t\t\t\t\t\tRzEcMBoGA1UECgwTTmV3IENvbGxlZ2UgU3dpbmRvbjEnMCUGA1UEAwweYXRoZW5z\n\t\t\t\t\t\tcnVudGltZS5uZXdjb2xsZWdlLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\n\t\t\t\t\t\tMIIBCgKCAQEA0Ez45eYCSrflOrisYZeEFa67TskdS51M4kAIuscDLu7Kff9H6dBO\n\t\t\t\t\t\tyYKPBDsYitiyI1z5fY7+cYt4kb+77ke/2AU+JnT3RUePm/9G3xzGFY5Fu4KTXnXj\n\t\t\t\t\t\t6Bui5zXSna35ry4eLagL0buNRpx/saSyg6+8MFdRBqVb668XYq19xxngRI6DlN2n\n\t\t\t\t\t\tnM9NiA5AV+NGIsC7/RC0tYXQ2G3VJePi65Iejan+77leUeTp1hufJD5OwfudoXFc\n\t\t\t\t\t\t58/hdz4PFHC3NUd8UMhL1WyibbvYwhfBta5V6H/Im0BL0e1qQJjdb/vg3P7w0SOI\n\t\t\t\t\t\tH2qsAPzqa3DZPCTPf4uLorZ87t73q9J+XQIDAQABo1AwTjAdBgNVHQ4EFgQU0HGl\n\t\t\t\t\t\t6yLJboYAwDMCD8QfzF5odXcwHwYDVR0jBBgwFoAU0HGl6yLJboYAwDMCD8QfzF5o\n\t\t\t\t\t\tdXcwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAoXzQtdDC4MIhfHWZ\n\t\t\t\t\t\tdydDbdxXdTus14w6betasZ1XdOEAXK+L+yAJ0FWjNsvXAZCKqkOZoQDpfCpTaIkV\n\t\t\t\t\t\tEQtzHeHO8/xHkobTHrNeuJnPTBbIl5ZWMedaoY5bu2n4+MWW5G08sSfxpZzcTeNw\n\t\t\t\t\t\tdQJl1Q+eHlcn1zFsZglZvyYF7crg1n0OVH6Ws+yJs772BrNopFqmaMpdPeLpd8Pk\n\t\t\t\t\t\teOFLI4LOL8mVNH2lDvt2LYxkOhW2U9XpGc3j2u8kbHEVPXVVrSaaNtwzeSa3W4sY\n\t\t\t\t\t\t73sUhZUXRR7JmqIZsXmX80WflC+LakBe+LKGsAqzCHcYBP1dFImF5M0fDOFSOqYN\n\t\t\t\t\t\t/0f/XA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYDCCAkigAwIBAgIIDMoTE+e8SLkwDQYJKoZIhvcNAQEFBQAwRzEcMBoGA1UE\n\t\t\t\t\t\tCgwTTmV3IENvbGxlZ2UgU3dpbmRvbjEnMCUGA1UEAwweYXRoZW5zcnVudGltZS5u\n\t\t\t\t\t\tZXdjb2xsZWdlLmFjLnVrMB4XDTE0MDkwOTEzMjk0N1oXDTI0MDkwOTEzMjk0N1ow\n\t\t\t\t\t\tRzEcMBoGA1UECgwTTmV3IENvbGxlZ2UgU3dpbmRvbjEnMCUGA1UEAwweYXRoZW5z\n\t\t\t\t\t\tcnVudGltZS5uZXdjb2xsZWdlLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\n\t\t\t\t\t\tMIIBCgKCAQEA0Ez45eYCSrflOrisYZeEFa67TskdS51M4kAIuscDLu7Kff9H6dBO\n\t\t\t\t\t\tyYKPBDsYitiyI1z5fY7+cYt4kb+77ke/2AU+JnT3RUePm/9G3xzGFY5Fu4KTXnXj\n\t\t\t\t\t\t6Bui5zXSna35ry4eLagL0buNRpx/saSyg6+8MFdRBqVb668XYq19xxngRI6DlN2n\n\t\t\t\t\t\tnM9NiA5AV+NGIsC7/RC0tYXQ2G3VJePi65Iejan+77leUeTp1hufJD5OwfudoXFc\n\t\t\t\t\t\t58/hdz4PFHC3NUd8UMhL1WyibbvYwhfBta5V6H/Im0BL0e1qQJjdb/vg3P7w0SOI\n\t\t\t\t\t\tH2qsAPzqa3DZPCTPf4uLorZ87t73q9J+XQIDAQABo1AwTjAdBgNVHQ4EFgQU0HGl\n\t\t\t\t\t\t6yLJboYAwDMCD8QfzF5odXcwHwYDVR0jBBgwFoAU0HGl6yLJboYAwDMCD8QfzF5o\n\t\t\t\t\t\tdXcwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAoXzQtdDC4MIhfHWZ\n\t\t\t\t\t\tdydDbdxXdTus14w6betasZ1XdOEAXK+L+yAJ0FWjNsvXAZCKqkOZoQDpfCpTaIkV\n\t\t\t\t\t\tEQtzHeHO8/xHkobTHrNeuJnPTBbIl5ZWMedaoY5bu2n4+MWW5G08sSfxpZzcTeNw\n\t\t\t\t\t\tdQJl1Q+eHlcn1zFsZglZvyYF7crg1n0OVH6Ws+yJs772BrNopFqmaMpdPeLpd8Pk\n\t\t\t\t\t\teOFLI4LOL8mVNH2lDvt2LYxkOhW2U9XpGc3j2u8kbHEVPXVVrSaaNtwzeSa3W4sY\n\t\t\t\t\t\t73sUhZUXRR7JmqIZsXmX80WflC+LakBe+LKGsAqzCHcYBP1dFImF5M0fDOFSOqYN\n\t\t\t\t\t\t/0f/XA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "New College Swindon LA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.newcollege.ac.uk/athens/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "New College Swindon"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://calpoly.infoready4.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jtesta@inforeadycorp.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Testa"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://calpoly.infoready4.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "InfoReady Corp"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.infoready4.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "InfoReady Corp"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://calpoly.infoready4.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://calpoly.infoready4.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://calpoly.infoready4.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://calpoly.infoready4.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "InfoReady Review - Cal Poly, San Luis Obispo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6zCCAdOgAwIBAgIJAOO9wmxE2PCSMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDGluZm9yZHl3aW4wMjAeFw0xMzEwMjkwNjE0NDlaFw0yMzEwMjcwNjE0NDla\nMBcxFTATBgNVBAMTDGluZm9yZHl3aW4wMjCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAMpdE35LzF2eEaAhLfxtotv6XhMXfkOMbugHq8xk5rhyx7RKS+Ku\nt9wW8Mv2rG7NAJw+8167dP6N2RQKpRBn17FIOhm/cuSNtiTBJtA9QiTEkyN5D1ma\nykJjlD95ymo0XdRDWwz/6IP5v+d95BlfbnlkswWOGOMLxCtaWCSZQ00RJFDKudL5\nIrK+2A1KwF4O+DxqivhdLsd/yA+IjX1efYnT7MPsd7Yyh5wKXKkGbKEg9yAW65Dt\nx2xbBCjDT2PCBhJ4ZuRfUv8whBCT2qgH6+pQ5JBN9ZDz1iGDFp8XfQ27UtzlFdBc\ncjvWmtOh/V35fBXl5LIbJdU/ypJMBwehxbcCAwEAAaM6MDgwFwYDVR0RBBAwDoIM\naW5mb3JkeXdpbjAyMB0GA1UdDgQWBBQTyklRhSLuL0VcI0Nv4tQhZYqHITANBgkq\nhkiG9w0BAQUFAAOCAQEAJyNYKdKAFdp7xvqnjszw+AF3dYl3HQKe5bC0M+gu7G+2\nhJL2D70cFCXXi2bNcdyLsFVPiecMo69QinOP3kqCPNL7S5pSjm48T9bTiRr4WNy1\nhkxJ7nCV++z696YqbE7WYec9LEpcNDnDnmDfQOxvxzdtpIyM3Egw+koKEZu13ebw\nzAs2xgBj3V5YWmzS7nk1wPPJBKpr+9W5xixEGfaKfrrQXayP/LVyN+u/3BjZCZfE\nbfqmalH+rjpJ7ZCck4CQFxCvnLhwl+L5DEuEFXmgTzk7EDb65no+rXaZQd3/IEre\nsazovBHNw8FPYGiOCi2757flvBsb6gW+FbN0SPmtSQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://calpoly.infoready4.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://calpoly.infoready4.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://calpoly.infoready4.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://calpoly.infoready4.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "InfoReady Review - Cal Poly, San Luis Obispo"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://naming.ja.net/dns/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:naming@ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "JANET NAMING"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:naming@ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "JANET NAMING"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://naming.ja.net/dns/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-12-16T16:13:54Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Janet Naming Service"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ja.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "JISC Collections and Janet Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://naming.ja.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://naming.ja.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://naming.ja.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://naming.ja.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://naming.ja.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://naming.ja.net/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://naming.ja.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://domainregistry.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://naming.ja.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://domainregistry.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Jisc Domain Registration Service"
                  }
                ],
                "logo": [
                  {
                    "text": "https://domainregistry.jisc.ac.uk/dns/Images/federation-sp-logo.png",
                    "height": "72",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Jisc Domain Registration Service"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4jCCAcqgAwIBAgIJAKyF+vahRReuMA0GCSqGSIb3DQEBBQUAMBQxEjAQBgNV\n\t\t\t\t\t\tBAMTCWhhcjAwMzkxODAeFw0wOTExMjAwODM4MTVaFw0xOTExMTgwODM4MTVaMBQx\n\t\t\t\t\t\tEjAQBgNVBAMTCWhhcjAwMzkxODCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAKyGnAXQpTnriKaVLhBxB2V01KEV7JFljb6JyCUgmPzhjozQV78Lt6wnrlVE\n\t\t\t\t\t\tPMJUFzx6MhVOOFdmoud9f4uEt3eLeNNBkXy6F1hLsK93MmEq7NycC9f+RTGkXuI9\n\t\t\t\t\t\tZZ6bHpCQg4cgLlo+e+oSmyFrqdwHkKXRxhx7sLDpmrBRt4WS1Yom/sf1roaj/HYJ\n\t\t\t\t\t\tI09jwKfl5mlFhWqHoprT6zHYZ/q4HIgo8CYFzRPTBYP2WoakD87P3UPpVZj6uLAz\n\t\t\t\t\t\td8LCuv1ZX2HJTHYrUyEM4tbqA2cv/CN8W6cgTkm5puZAMvPmFeNnoQlkBnUpH/oc\n\t\t\t\t\t\toGDmT026FyBGQ6yXva1uZVOX0xMCAwEAAaM3MDUwFAYDVR0RBA0wC4IJaGFyMDAz\n\t\t\t\t\t\tOTE4MB0GA1UdDgQWBBQST9Pog/haMAhYi8W9rY0cKz3XfjANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAERDcKAB+oNKMF14ys3MjR7NgPZzAnxNjyDizDMsPug9ZqfXKTfU1NFZx\n\t\t\t\t\t\tnx1ihIXHOBZgLU4RKLJSopHZ57V+HlOebXCckx/je1y4a30B0sIg3yk9ZZlMNcVI\n\t\t\t\t\t\tJWEIEGc6kkIhgQBMAtTaae+Yd1gqk4MQBQG08iDy9M3E4jp3BmgZbJL2lBYwCoRc\n\t\t\t\t\t\tU2soIdQNoQS5WDuqwDVXqOljUfijVZU9YRpjPDsXqDQDVO+7v/EbPxVtRThQChxY\n\t\t\t\t\t\tLwXeoQe6wBNtmeBEdm16Ik+PCxkgQlTCLythjkwmB+AjmqoW6Kp9bNfh7/Tlv/lM\n\t\t\t\t\t\tbYW9q2/JzwJW2LhAXTV1ev8D9e3peg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://naming.ja.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://naming.ja.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://naming.ja.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://naming.ja.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://domainregistry.jisc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://domainregistry.jisc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://domainregistry.jisc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://domainregistry.jisc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://domainregistry.jisc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://domainregistry.jisc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://naming.ja.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://naming.ja.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://naming.ja.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://naming.ja.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://naming.ja.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://naming.ja.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://lms.hig.se/shibboleth-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://lms.hig.se/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lms.hig.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lms.hig.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lms.hig.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lms.hig.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lms.hig.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lms.hig.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lms.hig.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lms.hig.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lms.hig.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Blackboard is a web based learning management system, for courses at the University of G\u00e4vle. The system is used for both campus courses and distance learning."
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Blackboard \u00e4r ett webbaserat system f\u00f6r hantering av kurser vid H\u00f6gskolan i G\u00e4vle, en s\u00e5 kallad l\u00e4rplattform. Systemet kan anv\u00e4ndas f\u00f6r b\u00e5de campus- och distanskurser."
                  }
                ],
                "logo": [
                  {
                    "text": "https://webkonto.student.hig.se/img/cencolor-50.gif",
                    "height": "45",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "https://webkonto.student.hig.se/img/cenfarg-50.gif",
                    "lang": "sv",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.blackboard.com/Footer/Privacy-Center.aspx"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Blackboard (Learning Management System)"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Blackboard l\u00e4rplattform"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://lms.hig.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://lms.hig.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "fgprd-137892-sf108273-app001"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIJAJjJj09+G/e9MA0GCSqGSIb3DQEBBQUAMCcxJTAjBgNV\nBAMTHGZncHJkLTEzNzg5Mi1zZjEwODI3My1hcHAwMDEwHhcNMTUwNDIwMTYwMzE3\nWhcNMjUwNDE3MTYwMzE3WjAnMSUwIwYDVQQDExxmZ3ByZC0xMzc4OTItc2YxMDgy\nNzMtYXBwMDAxMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuCKelXjL\n3oStYmCPuLadSQ9VoUVsoUDVvG/KZMyqGffZFnecykjIR98UrmfP0HyTVSJKrTyZ\noRMKgs+lLFFO6VXlBz8psHBjLbF/ZUk3Vz361iU1eWK9TZ2I0zQT+DEYqGY2iYGf\nQDM3tpzuuqm9cez/XlGINZK5Yxzt31+JirDTx5BwGgkTqNl34WO4LWcGSybMrIcM\n1kHqQ1j2vWe5/1QBVskIABEtZK3m798XcLAaGPvyFxl9iO9aBbpXGIyR9F0t2row\nlPAsEXkJ1pli/aLSq2EaGdXd+jHm9avhzvqqd1EgB8W4rbk99znNhOAOR8tBV8G5\npC4gPZFmXTNi4wIDAQABo0owSDAnBgNVHREEIDAeghxmZ3ByZC0xMzc4OTItc2Yx\nMDgyNzMtYXBwMDAxMB0GA1UdDgQWBBT97eKp2I/NaaU7VpgTGmVhNQTsmDANBgkq\nhkiG9w0BAQUFAAOCAQEAPzOmg2K4XVoCrfGgaLk911O0Ok0aIs99HdBZ00Z1/7Qo\nqSZhZwas6HZdxkx2KA/RLztfbE71V33RVYlOhtH47lGLCvaEd5bsrrDeVnXsxPVS\nNzdp17br+kLxyTqwSG2rvMVwHjFuDBS1Ar/Admm+k5Szj6UfuPBBIXDw8F33GwOT\nhzAuvpNmZKE5MpDOE97gtvAKAfPzL/St1off5DiCc1fC/AIYusUtcxh9hGdIZ5X8\nLk4WW3xh7ISn0oT7Dd4ySiBaxYc1XWalRa082HDRHKW0xHZC+yywn+yiloN+t3sj\nXiuyn7D35GBAgkGy+kU+hqB2fHQUrvnx3tn6wfL7BA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=fgprd-137892-sf108273-app001"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lms.hig.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lms.hig.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lms.hig.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lms.hig.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lms.hig.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lms.hig.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://lms.hig.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://lms.hig.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://lms.hig.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lms.hig.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lms.hig.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://lms.hig.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://lms.hig.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://lms.hig.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ucopia-shib.ensta-bretagne.fr",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jean-Paul KIRKBRIDE"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jean-paul.kirkbride@ensta-bretagne.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pierrick VEILLON"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pierrick.veillon@ensta-bretagne.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ucopia-shib.ensta-bretagne.fr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-03-18T14:19:04Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/wifi"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/national"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ENSTA Bretagne"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ensta-bretagne.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ENSTA Bretagne"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://ucopia-shib.ensta-bretagne.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ENSTA Bretagne - WiFi EduSpot"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ENSTA Bretagne - Portail WiFi EduSpot"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENSTA Bretagne - WiFi EduSpot"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENSTA Bretagne - Portail WiFi EduSpot"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDljCCAn4CCQCfU0WUIcNFIDANBgkqhkiG9w0BAQUFADCBjDELMAkGA1UEBhMC\nRlIxETAPBgNVBAgMCEJyZXRhZ25lMQ4wDAYDVQQHDAVCcmVzdDEXMBUGA1UECgwO\nRU5TVEEgQnJldGFnbmUxHTAbBgNVBAsMFFNlcnZpY2UgSW5mb3JtYXRpcXVlMSIw\nIAYDVQQDDBljb250cm9sbGVyLmFjY2Vzcy5uZXR3b3JrMB4XDTE1MDkxNzExNTUy\nNloXDTI1MDkxNDExNTUyNlowgYwxCzAJBgNVBAYTAkZSMREwDwYDVQQIDAhCcmV0\nYWduZTEOMAwGA1UEBwwFQnJlc3QxFzAVBgNVBAoMDkVOU1RBIEJyZXRhZ25lMR0w\nGwYDVQQLDBRTZXJ2aWNlIEluZm9ybWF0aXF1ZTEiMCAGA1UEAwwZY29udHJvbGxl\nci5hY2Nlc3MubmV0d29yazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAOlH6arzFtnQLs11KKlLn9qwzsIClXFckQjk48kfFnu8+8nHFIXa6VwsQDlFvQ5O\nnyETzMqym7cT3kZuZkvldVH1ds0W7a0yqbOoy83t0GhaPjIaq1xxHsJD8l28Il8H\nAkRKFV4KIUlFFdpFYi4IWx2a8yB3JxS9sbPfslJMzbUkqXzIKuspX96qBDZuZux+\n8YnEUmrtr7ZPJXvQMlGpFkuhv0zg8V/D1EUODBrAFYeqpWFOH0PZhj4DQ+mfmjMO\n53R0zmYbeNC1zPyYg+ZZlgfeVKY5BXyja4ZNvSsUtyic/P9780ZK72NromFx4n/c\nYMi3TFRSQk5Vnn2n68LgZRMCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAC9TuIpO1\nijHePC8x0QTqJkX/PA3uWu/dXTL19zHWrXhHJaYzw9FRrNU1TRWPpmhDsbMNig7k\nldA5Asdqy0kogRRt7NR7Eqylvb5WQyX2z8gMFrNE/czAuDUPOh2b6yPa1lwi3YZo\nghD8fPA/vM5JF0nb/2LL/mXhVygslhpqaaH+Ybq9iQeQWtWg17hMYoyc+gz5FfGd\naCK5iwx95AZ6qN5d0BzzC8PAcULgZjbgyOk/AF6PVZklHKs5u/vsyOFhlevj+YfM\nca90uwRHWn/k67mBa29JYu6i+m0C9ivPTCHn9c4HaVGV023h2UvWXj2gFpUgesO/\n/1CfOyqCdiur4Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDljCCAn4CCQCfU0WUIcNFIDANBgkqhkiG9w0BAQUFADCBjDELMAkGA1UEBhMC\nRlIxETAPBgNVBAgMCEJyZXRhZ25lMQ4wDAYDVQQHDAVCcmVzdDEXMBUGA1UECgwO\nRU5TVEEgQnJldGFnbmUxHTAbBgNVBAsMFFNlcnZpY2UgSW5mb3JtYXRpcXVlMSIw\nIAYDVQQDDBljb250cm9sbGVyLmFjY2Vzcy5uZXR3b3JrMB4XDTE1MDkxNzExNTUy\nNloXDTI1MDkxNDExNTUyNlowgYwxCzAJBgNVBAYTAkZSMREwDwYDVQQIDAhCcmV0\nYWduZTEOMAwGA1UEBwwFQnJlc3QxFzAVBgNVBAoMDkVOU1RBIEJyZXRhZ25lMR0w\nGwYDVQQLDBRTZXJ2aWNlIEluZm9ybWF0aXF1ZTEiMCAGA1UEAwwZY29udHJvbGxl\nci5hY2Nlc3MubmV0d29yazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAOlH6arzFtnQLs11KKlLn9qwzsIClXFckQjk48kfFnu8+8nHFIXa6VwsQDlFvQ5O\nnyETzMqym7cT3kZuZkvldVH1ds0W7a0yqbOoy83t0GhaPjIaq1xxHsJD8l28Il8H\nAkRKFV4KIUlFFdpFYi4IWx2a8yB3JxS9sbPfslJMzbUkqXzIKuspX96qBDZuZux+\n8YnEUmrtr7ZPJXvQMlGpFkuhv0zg8V/D1EUODBrAFYeqpWFOH0PZhj4DQ+mfmjMO\n53R0zmYbeNC1zPyYg+ZZlgfeVKY5BXyja4ZNvSsUtyic/P9780ZK72NromFx4n/c\nYMi3TFRSQk5Vnn2n68LgZRMCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAC9TuIpO1\nijHePC8x0QTqJkX/PA3uWu/dXTL19zHWrXhHJaYzw9FRrNU1TRWPpmhDsbMNig7k\nldA5Asdqy0kogRRt7NR7Eqylvb5WQyX2z8gMFrNE/czAuDUPOh2b6yPa1lwi3YZo\nghD8fPA/vM5JF0nb/2LL/mXhVygslhpqaaH+Ybq9iQeQWtWg17hMYoyc+gz5FfGd\naCK5iwx95AZ6qN5d0BzzC8PAcULgZjbgyOk/AF6PVZklHKs5u/vsyOFhlevj+YfM\nca90uwRHWn/k67mBa29JYu6i+m0C9ivPTCHn9c4HaVGV023h2UvWXj2gFpUgesO/\n/1CfOyqCdiur4Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEYTCCA0mgAwIBAgIBATANBgkqhkiG9w0BAQUFADCByjELMAkGA1UEBhMCRlIx\nETAPBgNVBAgMCEJSRVRBR05FMRcwFQYDVQQKDA5FTlNUQSBCUkVUQUdORTExMC8G\nA1UECwwoRUNPTEUgTkFUIFNVUCBJTkdFTiBFVFVERSBURUNITiBBUk1FTUVOVDEm\nMCQGA1UEAwwddWNvcGlhLXNoaWIuZW5zdGEtYnJldGFnbmUuZnIxNDAyBgkqhkiG\n9w0BCQEWJWplYW4tcGF1bC5raXJrYnJpZGVAZW5zdGEtYnJldGFnbmUuZnIwHhcN\nMTUwOTA0MDcyODEzWhcNMjUwOTAxMDcyODEzWjCByjELMAkGA1UEBhMCRlIxETAP\nBgNVBAgMCEJSRVRBR05FMRcwFQYDVQQKDA5FTlNUQSBCUkVUQUdORTExMC8GA1UE\nCwwoRUNPTEUgTkFUIFNVUCBJTkdFTiBFVFVERSBURUNITiBBUk1FTUVOVDEmMCQG\nA1UEAwwddWNvcGlhLXNoaWIuZW5zdGEtYnJldGFnbmUuZnIxNDAyBgkqhkiG9w0B\nCQEWJWplYW4tcGF1bC5raXJrYnJpZGVAZW5zdGEtYnJldGFnbmUuZnIwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCjTFwcA3jwkswwrf6wiB7HnGqQ7hzc\netx4DCKWp7q4c5VpSiYaWjXCMWowCS9L9HBvY9acOR2uRPubvIWMAoZPELvFC5uN\ntX3fTLl/tzFxK6AfhS1fgnZI4rLfdwLEVaNcl/EVSlhzYK/vvU8ogiJR0Wnug2kc\npKngb2lY1lq6Gk1LmxTNMlqBXxDMBpaVrNIoH0c4xb+NkGWW+7LDswGLPz612BIB\nJQnq1Zz3BiE837NRoeoZWLPrgHzb7fKL25NgpaElt60MqM+Pm/T1bC4ki2T8XAmM\nR2R/Bni0f0v2Xl81a2FPAE1BU8w6jTMFSkBfrnrqCAfWtHahxM0Xj2e9AgMBAAGj\nUDBOMB0GA1UdDgQWBBSoLmW/7Ri+xwt2g0D7F+Tl2Cap2jAfBgNVHSMEGDAWgBSo\nLmW/7Ri+xwt2g0D7F+Tl2Cap2jAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUA\nA4IBAQAcyAM1+lP7dKnbgqgWv8pe4+K/JP6PX5gCTDjs/OGg/9OpHmFEDAMmN6SM\n5yAbWFAylwu4P3txtViT52SzRT2bOYSlkkh4sbpBz0E0wn41GJXpIEnBHJF26n7X\nFAMpsE9UQKwWwx9+FtVM38AORfkwg+kS/N3OO0FipySqAjiGb7SKo1lY9ZHof/jW\ngBgI0bwtyCTjP0RVzJ4vWPpglXJPddfUvYh3rzDVM2wSzcVw36rl7s2oPgJy0CT9\nmrnJXRMvro3o5/2uT+4qCpJXj0mtWcAiOQDHISXFb7TpKZu8ra/XDpx1dVejo3e8\nfievTXxCFzLqApOjCWA8o5hbmgx1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://controller.access.network/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://controller.access.network/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ENSTA Bretagne - Portail WiFi EduSpot"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ENSTA Bretagne - WiFi EduSpot"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "ENSTA Bretagne - Portail WiFi EduSpot"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "ENSTA Bretagne - WiFi EduSpot"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://bristol-shib.hosted.exlibrisgroup.com/shib",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bristol-shib.hosted.exlibrisgroup.com/shib",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-06-11T14:16:51Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Bristol - Primo"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://exlibrisgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ex Libris (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bristol-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://bristol-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bristol-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bristol-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bristol-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://bristol-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "his is an Ex Libris Primo Hosted SP on behalf of the University of Bristol"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Bristol - Primo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNjCCAh6gAwIBAgIJAIkWelwTQdkGMA0GCSqGSIb3DQEBBQUAMDAxLjAsBgNV\n\t\t\t\t\t\tBAMTJWRjMDNrZzAzNzlldS5ob3N0ZWQuZXhsaWJyaXNncm91cC5jb20wHhcNMTQw\n\t\t\t\t\t\tNTI2MDUyNjI4WhcNMjQwNTIzMDUyNjI4WjAwMS4wLAYDVQQDEyVkYzAza2cwMzc5\n\t\t\t\t\t\tZXUuaG9zdGVkLmV4bGlicmlzZ3JvdXAuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAmLLqAX90cJhcxejFx99BYTZazaK9Zy892I1i5cOIPdyRtEZm\n\t\t\t\t\t\tW4/Lj7aUT+U7m2W7+Go9Q4EavP9OUBFxhPI0ffNDQHzkNecVpeJugMpExkOpziet\n\t\t\t\t\t\tUQ7Hu9wpI0fS3k0CElMCcNkpWi/q6whlDyOMJ1W8a1uXuAkYLe6f9ySRdN8OV/6W\n\t\t\t\t\t\tqFUtFmS6yziyYFKifhwqeJMIB88Xwm+ibH/p2NsWmCQ+sH15EJ6tNS9oxAXMbywn\n\t\t\t\t\t\tTQw5Mlg560bGkeBRBD0yS+aEZs5hTg7SMXhJoV0GLPi2jb5IgsjL5/7nWtMMdSnG\n\t\t\t\t\t\tm6/ZbPVmt/e4jwh8H4TJWCknLQRurM+XYMGizwIDAQABo1MwUTAwBgNVHREEKTAn\n\t\t\t\t\t\tgiVkYzAza2cwMzc5ZXUuaG9zdGVkLmV4bGlicmlzZ3JvdXAuY29tMB0GA1UdDgQW\n\t\t\t\t\t\tBBQWr7RBWVGCpD0Xcucrg00yG2FZqjANBgkqhkiG9w0BAQUFAAOCAQEACbsq0lFP\n\t\t\t\t\t\t3EdK7+SkT3LmUiRUCLZPopsAcIEmLeB7f35vKltAROGpxteWO1konftz5p8fSpec\n\t\t\t\t\t\tbXaYtUGvwOcHmxik5SRBEJpuCWFSlUkBIhBJM8HKtSlx9OMqmBL449TVyShDZGqX\n\t\t\t\t\t\txr/8TbzueVRtB6IY4SfLsdmXKp9MTswSC94yyLkqMvAGIeAIDlIMYV6rP5w95Y9h\n\t\t\t\t\t\t1T41keC9ILBwLYIqz7uKmynr91siE6F2ITwZ6Sp1hpa0o1sbcFq0j+KCD64eFaOh\n\t\t\t\t\t\tAbzbMLCKIHRvB24eIqpA5vLt1u/7cbtuHOUrMxVqlDO9UqOlqhnxRdeN1lncqUnx\n\t\t\t\t\t\tmAb78NKYEfHMBQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bristol-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://bristol-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bristol-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://bristol-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://bristol-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://bristol-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://oa-idp22.wlv.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Henderson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:d.henderson@wlv.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Henderson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:d.henderson@wlv.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://oa-idp22.wlv.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-05-23T16:25:35Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://oa-idp22.wlv.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://oa-idp22.wlv.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wlv.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkCgAwIBAgIICo+mehMlNtowDQYJKoZIhvcNAQEFBQAwQzEkMCIGA1UE\n\t\t\t\t\t\tCgwbVW5pdmVyc2l0eSBvZiBXb2x2ZXJoYW1wdG9uMRswGQYDVQQDDBJvYS1pZHAy\n\t\t\t\t\t\tMi53bHYuYWMudWswHhcNMTUwMTIwMTI1ODE5WhcNMjUwMTIwMTI1ODE5WjBDMSQw\n\t\t\t\t\t\tIgYDVQQKDBtVbml2ZXJzaXR5IG9mIFdvbHZlcmhhbXB0b24xGzAZBgNVBAMMEm9h\n\t\t\t\t\t\tLWlkcDIyLndsdi5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAIm+DWXZjRBVNcSwWm76ONZ4PP97SOtfI9xLxSul1B6VGbaBj9psMTA83h9Thwyi\n\t\t\t\t\t\thnu4qql1o58dtH7u2Du2W9bIR0K3BT3Whn5N+oTB6dakZ5TIp27cHnZfedbQ3xfX\n\t\t\t\t\t\tOvg+eXl0hQieICaF5NW2zSJGKacp+cckbR6USlUMjVAmu8T+Q7afw2k3do5IyNF4\n\t\t\t\t\t\t8FnuSL/S6PtwpbLMl5+DkQKS2pNXx76jqfGwoJBiXzxR43vyzIz6Lz6foh7B+sCH\n\t\t\t\t\t\tPFB9w9nKQOSW0RTlUTSlNIRrFKYS8jBmGg0SYCTCqAOZQd/S2wDoNdxotnUh045c\n\t\t\t\t\t\tPlS66duNqlV/BcMhGZriVocCAwEAAaNQME4wHQYDVR0OBBYEFCCaekjMQckGDHAs\n\t\t\t\t\t\tuGTK2YWenmVqMB8GA1UdIwQYMBaAFCCaekjMQckGDHAsuGTK2YWenmVqMAwGA1Ud\n\t\t\t\t\t\tEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAGT5NNSjh5DLoY11NupSxaqm2kXx\n\t\t\t\t\t\tOr1pIN4QgEPl5KKBxfnBGQSzzACg+pFzzhq7PS/1D1/ctmTAowDH7RNQLRNKMcq1\n\t\t\t\t\t\thD9bUfVfcItmYyR6RLFFX1TTvf94W2UbfVvblMbBY1+BLkPgRO7YFxGuhcdXTh9t\n\t\t\t\t\t\tyBnW7SQuYB8OadqOhgnBxGohFnwIAxMzsQTBi0rd4ujeKiZxoMj27dzH0lIgKC7D\n\t\t\t\t\t\tYfu47aQJpYnVshufazOye5broAdudUUnilRdcrQpIRWOCBRVD4FhKP2c6RfQY3dl\n\t\t\t\t\t\txxc2jE/LIUkl6G9Kezhlig7zn3EuOjuClGhY1kfMQY48P2Cula64ZZ5Y9Vo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Wolverhampton (Test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wlv.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Wolverhampton"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.ate.resultat.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.ate.resultat.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ate.resultat.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.ate.resultat.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ate.resultat.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ate.resultat.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ate.resultat.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.ate.resultat.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.ate.resultat.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.ate.resultat.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.ate.resultat.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.ate.resultat.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.ate.resultat.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.ate.resultat.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIJAL33q6wYZ/iYMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\nBAMTGXd3dy5hdGUucmVzdWx0YXQubGFkb2suc2UwHhcNMTUwNDMwMTEwOTQ4WhcN\nMjUwNDI3MTEwOTQ4WjAkMSIwIAYDVQQDExl3d3cuYXRlLnJlc3VsdGF0LmxhZG9r\nLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsiUgpXCWfEWIOYkU\n/6ihCl4kdjtnJ9UnPXxajFN2EI3TcgbUxOMLeKwdfGQCPhmupQPsz+6tJ6z/46IW\nJitUOsY1wzLSw68E0Voh5Z/NQdNLa4HHSAbompqKcdLO2djNKeOvMgdfj94omrRp\n9LKvUmLY0+dbltb3XyYqhR9yWKqUXBskh0V5grLQO1KGQOpNHQRJmZK+eHhnAFg5\nhqXLIR45pu76+2RHpV7Q1dUEaSZjWvtXLeGGudYXtAHa6Tar9XjHvnUPoZRM5wCT\nmsOtSNdYrmhMVQJ0TntmdqQTVidbhEA77XmbAH4r4PD6DPFUZf7hmCtPzT9Snveg\nVghGdwIDAQABo3EwbzBOBgNVHREERzBFghl3d3cuYXRlLnJlc3VsdGF0LmxhZG9r\nLnNlhihodHRwczovL3d3dy5hdGUucmVzdWx0YXQubGFkb2suc2UvZ3VpLXNwMB0G\nA1UdDgQWBBR9M31f7CdCJA48pwgxYPVCW76Y1zANBgkqhkiG9w0BAQUFAAOCAQEA\ncbdbe0pic7pucb2zNQJfTs7AMWjE4iECU8+ZD/w1ms9CICTesky+Ls+X5upU8IHA\nxIF7Gus5zQhzxAT8voBPpE8kzMt95NaITBIYCEZJK8GKRm5qEB5f+0s2ySMT5oa0\n7MPEjKYK/jXj8TBCGIaxu65yguNqEoqWGt+JU+gwActjEYuudAnpKNHbzANDL1CX\nch1BQNQ/1KLb56MA5XtD6+TFKukuo0Ue6uf6SSr9Uc4EtTycicPg+e+RRwi1HhiU\nNcCCKYTIBQSYBIpHdjg1CQ0gWOnwfyJjFVC8QAuC79ODRdjItStcO3c06LoKqVwS\n3hhdmaLGW7LBj9QAMWGvCQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.ate.resultat.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ate.resultat.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.ate.resultat.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ate.resultat.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ate.resultat.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ate.resultat.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ate.resultat.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.ate.resultat.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.ate.resultat.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.ate.resultat.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.crous-limoges.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "informatique@crous-limoges.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.crous-limoges.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-04-15T15:53:51Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.crous-limoges.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.crous-limoges.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.crous-limoges.fr/cas/login",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "crous-limoges.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.crous-limoges.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Employees"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnels"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS de Limoges"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS de Limoges"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEdjCCA16gAwIBAgIRALZcQBV2KHd5bIl5Qpk5ONAwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDAzMjcwMDAwMDBaFw0xNzAzMjYyMzU5NTlaMEIxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEdMBsGA1UEAxMUaWRwLmNyb3Vz\nLWxpbW9nZXMuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDYnE9D\nNfGEpBj3Iy72odoL+yZSdhS+FsM/IU2BJANw6dbXRpNMFfNnLRkWWPTwdeJh8r4A\neNmRKLQCMZP+E/NY3zQlnAOakL2c/fgBTv5Oawe3speWTS3N0whStUMtbgzWafBE\ncToI3gFcC4x0JPklum99m+ZZ17D3oLrIttOYZ4fXjsQj2yJwFBp3nJ7qh1rfwfKf\nrAYKF0gxekGUR5YgjFKpU4zbcZSHeIAHaD8WLJRkdEBvEC/tF8gjrBSP2aTAgLUS\nbk81rZWRXXA0CCZynsTpDvtycQhL3/4zMIkUPpV9So68DZz63QXXZTwUIyyjWtOv\nC8ZDw3WvVWTsxdf9AgMBAAGjggFxMIIBbTAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJ\nays3V0fqkOO57TAdBgNVHQ4EFgQUfiR82eCVOYTgD0HPV8QeEe5jLSIwDgYDVR0P\nAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsG\nAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1Ud\nHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NM\nQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50\nY3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6\nLy9vY3NwLnRjcy50ZXJlbmEub3JnMB8GA1UdEQQYMBaCFGlkcC5jcm91cy1saW1v\nZ2VzLmZyMA0GCSqGSIb3DQEBBQUAA4IBAQCQRcYk/yvCdP/VT7R890J3pvAXlEm8\n7/DWetj4M6P3pV41o8wiuZT49jsSvGKvFEiq8QrE3MQjpWO+ASd90WCfKGJGgWta\n9oftaIHINRmEd2mDQ1WMuZMbaXEwOf7lxiSvzlxRXHgAJ3C0oexBx6z16GRPLDMY\nXm2MIteZK1lI8FEoWX8qXg8EjL/NZdxu1v7dU/jSHL2HlNj8sNVWwh+aUQxL8qBe\nMyun/oIQkNnp0Pdk8+EGzL0g39mOz/aifvbBnk4nBg9YZhbX1PHPcsaTXReB9z48\nZDIXns+y/xQLIh4KMx/XzIpQHZC0zvB3nMoYPiHZ3L/UUxNGQacmInYV"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS de Limoges"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.crous-limoges.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS de Limoges"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://rhc-fed.reaseheath.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itservices@reaseheath.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Services"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dickins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Oliverd@reaseheath.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Oliver"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://rhc-fed.reaseheath.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-10-07T15:39:22Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.reaseheath.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.reaseheath.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.reaseheath.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.reaseheath.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.reaseheath.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.reaseheath.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "reaseheath.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUJtSeU6l5y3tr7fhTbEMMdn2U+BYwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwIDEeMBwGA1UEAwwVc2hpYi5yZWFzZWhlYXRoLmFjLnVrMB4XDTE1MTAxNDE1\n\t\t\t\t\t\tNDUxMFoXDTM1MTAxNDE1NDUxMFowIDEeMBwGA1UEAwwVc2hpYi5yZWFzZWhlYXRo\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAr2h1r5VBnL9+\n\t\t\t\t\t\tBiLgULv0RqHvItjgw6Dxr7fW3PWPHxR465Igl6bQGMeBncN7BplQw2qCtf/Pdw65\n\t\t\t\t\t\tTGKPijbrDBXobI9hKhvIUTia6w5D3qFetCSCkRnoA9dq9xFpNOcT/0bCCkshl+dt\n\t\t\t\t\t\tlEu5dvA5q0mp9AXHo+f/h3NjVAkpQ0c9saA99nxtpZOqOR6CIB6zFLg6cSftEqX4\n\t\t\t\t\t\t39qbAZKBIRPiJn6PQSUd8n3zPgPy5qTts1ToksRYR6LOgi4z87CfhxMMrNfjkUM9\n\t\t\t\t\t\tLM0ma7LWhJo32Sbci0nja8HalLRfK0gUH1GlHMh2OZkgQJ9LmLUm6E0gtYdTnDYB\n\t\t\t\t\t\tpSky2sFa+wIDAQABo3EwbzAdBgNVHQ4EFgQU9C6qwGwlN1SKjJagZYW3GKaalVUw\n\t\t\t\t\t\tTgYDVR0RBEcwRYIVc2hpYi5yZWFzZWhlYXRoLmFjLnVrhixodHRwczovL3NoaWIu\n\t\t\t\t\t\tcmVhc2VoZWF0aC5hYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOC\n\t\t\t\t\t\tAQEAHJp4ZwMk7E8ECWWtwBL2Fq/Sg34b+WdXhgqLt2YFPxYn1Z3MzN1QVD+3JiSd\n\t\t\t\t\t\tB6/krjU5jjhqXe69HXzTIMy7wFhEhk78IhFcHxugyj9zC1+TXoMOLo72CvnDrPcb\n\t\t\t\t\t\tITBm3ypNt/UV4wKUxAfltDQy/IAbs/CXFLIAhYG7xFZ06dHuGOQ1I0JYFyDf9eqn\n\t\t\t\t\t\t8nGFHFsCW0cs16s4d6jFvGwTYHQ7/x5aKAgztkD2VgiDZXof/Hg3HiOtVPEFX1NV\n\t\t\t\t\t\tqRa8xFl+F1m4flEPHbHDWdjbmnwe2kPl4y6PwqWJrSMNgKlOSVhPAbztz/t3H6gp\n\t\t\t\t\t\tLesywhYMlSPtH22K+a3CiahDMw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUGjPH8LhaoQmEkZaMA9mvvFacc/swDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwIDEeMBwGA1UEAwwVc2hpYi5yZWFzZWhlYXRoLmFjLnVrMB4XDTE1MTAxNDE1\n\t\t\t\t\t\tNDUwN1oXDTM1MTAxNDE1NDUwN1owIDEeMBwGA1UEAwwVc2hpYi5yZWFzZWhlYXRo\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAphZayAXU4TZd\n\t\t\t\t\t\tGHTg8O533mIIgetrNg622ypHh8Cp4yISkwBeRqXsysm7eLisT98f6TwF/909yvVi\n\t\t\t\t\t\tvc6nbW93ZI/NZNdgtI/TJf2PCZL7s610Ep3ovqYR39iR4bw5PHmLXGRdLiVuKWzH\n\t\t\t\t\t\tclNq/5/J5IAVIc/ZxkrLprDKFXwzw/c323JtdBMfNhk5ybluMhMwN5nA5CykDGfz\n\t\t\t\t\t\ttklFQ79col3TD/pZs1DdU+iyZp9G8eO4fC66DP9awfQeg3nGtGQUB5v2ZI6GcPNd\n\t\t\t\t\t\tVauZseVGUzCpPMY3cTr9xfsR643SOSnNkTkafiEM+mkt5pYpWAPQAZ4waPpYGYES\n\t\t\t\t\t\tJdsLXzdBLQIDAQABo3EwbzAdBgNVHQ4EFgQUVDIF0fJ8QtDTH2hViCgfNUfqit4w\n\t\t\t\t\t\tTgYDVR0RBEcwRYIVc2hpYi5yZWFzZWhlYXRoLmFjLnVrhixodHRwczovL3NoaWIu\n\t\t\t\t\t\tcmVhc2VoZWF0aC5hYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOC\n\t\t\t\t\t\tAQEAkw7D/FwTi7k+qqVbQmLNpzKgDAioMyAFSeiuCw280IBwvxa2PfBcSTGDzR3t\n\t\t\t\t\t\tTNbKSI1GrSfRDcsoYIVt9UQX2Hy/cNUGMUS7UgNRpQ4CG+p/f9U9GHIFO6nKDsbg\n\t\t\t\t\t\ttT24pA5Uhn1hFRHTiGgaovx9sK6QwFFOvztOpVbF97zl5AtisKZ/tS/gD1q0IC+1\n\t\t\t\t\t\tDq07d0W/Ki6taSUClNk9PebFIOIuwOQHG9Gx+hqTOAqWFDNlMPwaLdvtZEVRpN+6\n\t\t\t\t\t\tdU+M+4WHeWDHiNxPX3k/jNUTlmHskrxTtXi4RbVYyXw+tAxhHq8S4vN2kNElhr8l\n\t\t\t\t\t\tgvZT6e+fbGfucnFJvdlyK66CbQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVALhMQiufWiWfLbo35hETLp+s2plNMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMCAxHjAcBgNVBAMMFXNoaWIucmVhc2VoZWF0aC5hYy51azAeFw0xNTEwMTQx\n\t\t\t\t\t\tNTQ1MDlaFw0zNTEwMTQxNTQ1MDlaMCAxHjAcBgNVBAMMFXNoaWIucmVhc2VoZWF0\n\t\t\t\t\t\taC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANSlu8ODQ8vQ\n\t\t\t\t\t\t5gIusx6gX27mN3vNYBwtUoH98MunT8KoKme1O2D52/Q4l9VRrRuxO5rv2X2ezSbo\n\t\t\t\t\t\tUoacSBGmqR15LpJJE9qIysAe4nIwlOTfuSN/8P4CcrzbZAFf1gu0BHsLkVkBb2cm\n\t\t\t\t\t\t/wSmfISG6mh/+7VKwkEcxHA+gej1QdJbjmU+TQKjK0A6Px02PHYvuHBdFBFv+00/\n\t\t\t\t\t\tK24pUCBANpPBK9RWxN3LxYrQervyzRAWy5JHitZuIkO9q4XWW+YuJSADzTY/y1+M\n\t\t\t\t\t\tAr6ZBLUcxUg0NqZJLtvhQwoJZnUqIwEY8kbN9A5FmLHFpPl9BFgx32nMGKna8YvI\n\t\t\t\t\t\tWWp7dftoAgECAwEAAaNxMG8wHQYDVR0OBBYEFLRRrSoN4c99qjThozsyvcCPqR8v\n\t\t\t\t\t\tME4GA1UdEQRHMEWCFXNoaWIucmVhc2VoZWF0aC5hYy51a4YsaHR0cHM6Ly9zaGli\n\t\t\t\t\t\tLnJlYXNlaGVhdGguYWMudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQAD\n\t\t\t\t\t\tggEBAAxgcPcNG1wMo8hIca5uxoaluAJ4FGPiq90h7MWS1XSMDX3ERc2wXzZWSmhp\n\t\t\t\t\t\tvKl/6B99HoqPycfkCVqg3c3CGW9y41bdXltxhvLID3JN7cxf3Ne7vQUNMDXlR5D9\n\t\t\t\t\t\tqVqo0lAySIWY4Yz+FB1CzcUBsxb3dnJ4cwH+xHAx3YkVDDwyIq6gsvIvuu+oN4G7\n\t\t\t\t\t\t5eR54/RUm65jzVW2hUJLk3MLC4/1syOrvJAfmEJrIfdPg5DrlpN4HsucpWLO88wo\n\t\t\t\t\t\tdwmJ2RZsUVyC97olmPKAQOLV0YdeoDn8jowXXo+xDGxKQzO1S8M9STBJPr3c5+yV\n\t\t\t\t\t\t5QUuKHTcpSRcXCPL+qGac9d/T6E="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Reaseheath College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.reaseheath.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Reaseheath College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://playgen.a-n.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Schinella"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Eleonora.Schinella@a-n.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Eleonora"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Schinella"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Eleonora.Schinella@a-n.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Eleonora"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://playgen.a-n.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-10-17T15:04:22Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "a-n Resource"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.a-n.co.uk/about_an/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "An:Artists Information Company"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://playgen.a-n.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://playgen.a-n.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://playgen.a-n.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://playgen.a-n.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://playgen.a-n.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://playgen.a-n.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://playgen.a-n.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Resource for visual artists: news, reviews, debate, research, publications, guides, toolkits...."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.a-n.co.uk/wp-content/themes/a-n/img/a-nlogoforfederation.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "197"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "a-n Resource"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIJALZ0HnVpTZsXMA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\n\t\t\t\t\t\tBAMTEXBsYXlnZW4uYS1uLmNvLnVrMB4XDTEzMTAxODExMTYwMloXDTE2MTAxNzEx\n\t\t\t\t\t\tMTYwMlowHDEaMBgGA1UEAxMRcGxheWdlbi5hLW4uY28udWswggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDGy7TgC2JyLa2SqOL0bKb3UZrkBMHI3+FKgZtl\n\t\t\t\t\t\tAeQvpKyZ8I9wG139BAdYIZlKH+RUIj/Wd2Wa69IZDnU/P20iKKQmBrheWna8ce3x\n\t\t\t\t\t\tvGRi4q7Qp4xk+Oks/3KF3N48PYLy6JWQvOKlzkDo+vZndMwrZITINkJ+WwtWabBr\n\t\t\t\t\t\t85yQ+g2OCnqjznYVIyzVyWaWwD7EW/x5kyDi70nYVUQ8fR21T3m64hoNfD9cPhF1\n\t\t\t\t\t\tUq/qvtls5ubHJWiZDoUG5OX1jhMPPtd0zwt+vNzlkm1RfnYC7WrW5WeL1WrhRU/V\n\t\t\t\t\t\tSozkoxl36qJwtZQAYhOXSs9lKrnX+yE2lXQRR5hlQId52oMlAgMBAAGjZTBjMEIG\n\t\t\t\t\t\tA1UdEQQ7MDmCEXBsYXlnZW4uYS1uLmNvLnVrhiRodHRwczovL3BsYXlnZW4uYS1u\n\t\t\t\t\t\tLmNvLnVrL3NoaWJib2xldGgwHQYDVR0OBBYEFIeK96KEhd/EQmjx2xd3pj8Zeu+l\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQA+Po3EcuVGKS41nGDet0fD7fyEQ4sOPeCe65/T\n\t\t\t\t\t\tPMYWByMs53FXHlB32xObJruW/cFyoDMFhwWq4D5FwmYpGnyC1TQBrR7K25yP6ZuT\n\t\t\t\t\t\t9ogMtqKb/VIx/UlIcfiaDHZJWW4N6qF6MAwX8Qpv7ek9PQ3/ZiFdzbtEZqDd/grz\n\t\t\t\t\t\tNtSKUusX30kNI9tAc2qvsccGEuzWWLI6h82aipoHtvb2CF+yYkS060MItJZreMSp\n\t\t\t\t\t\tYfJHyQM480FeByWQGkzZyPOhIWIfrC0ynOBhkzKrPvjaLp+M4BHnixlVSBvjsRjH\n\t\t\t\t\t\t8CVDPzFaPDFn3WDvQFi2bmBYvnIG3ULMJIcdjIVIoIOhe3Sz"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://playgen.a-n.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://playgen.a-n.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://playgen.a-n.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://playgen.a-n.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://playgen.a-n.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://playgen.a-n.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.borderscollege.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kyle"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:AKyle@borderscollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andy"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Saunders"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:GSaun@borderscollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Gary"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.borderscollege.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-03-20T15:57:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID/DCCAuQCCQDmNVK58fWDtTANBgkqhkiG9w0BAQUFADCBvzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxGjAYBgNVBAgMEVNjb3R0aXNoIEJvcmRlcnMgMRMwEQYDVQQHDApHYWxhc2hp\n\t\t\t\t\t\tZWxzMRgwFgYDVQQKDA9Cb3JkZXJzIENvbGxlZ2UxFzAVBgNVBAsMDklDVCBEZXBh\n\t\t\t\t\t\tcnRtZW50MSEwHwYDVQQDDBhpZHAuYm9yZGVyc2NvbGxlZ2UuYWMudWsxKTAnBgkq\n\t\t\t\t\t\thkiG9w0BCQEWGkdTYXVuQGJvcmRlcnNjb2xsZWdlLmFjLnVrMB4XDTE1MDIxODE1\n\t\t\t\t\t\tMzQ1M1oXDTI1MDIxNTE1MzQ1M1owgb8xCzAJBgNVBAYTAkdCMRowGAYDVQQIDBFT\n\t\t\t\t\t\tY290dGlzaCBCb3JkZXJzIDETMBEGA1UEBwwKR2FsYXNoaWVsczEYMBYGA1UECgwP\n\t\t\t\t\t\tQm9yZGVycyBDb2xsZWdlMRcwFQYDVQQLDA5JQ1QgRGVwYXJ0bWVudDEhMB8GA1UE\n\t\t\t\t\t\tAwwYaWRwLmJvcmRlcnNjb2xsZWdlLmFjLnVrMSkwJwYJKoZIhvcNAQkBFhpHU2F1\n\t\t\t\t\t\tbkBib3JkZXJzY29sbGVnZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\n\t\t\t\t\t\tAQoCggEBAO/lris+8qS70Yb/6096UTgmMZcJEsPHweU8GmZDgIeb3b+/5vSlixlh\n\t\t\t\t\t\tutP8tiF7oeLx/rapMSSLbbP0muG+aePPk2TNCR8mklYYzaAumBKIfJL4NJLz5qYN\n\t\t\t\t\t\tXXeu31yHoK865kN7d27l7EaH0hlbGz9KR1PbCtD5/Db35MU1uPWAaNAUB9KZrqeF\n\t\t\t\t\t\tx+C+bCvRbAfbQXAIOg0E0mdJpYQnx2b1wIucY7zoemkivBdlHkr00OUn8hCSD+bb\n\t\t\t\t\t\tzL/OQO77/CKxPYn2cAeE8cPQPNJOISiupEVSY7rqNuktw6knrl4zQdXNoCXO86Nd\n\t\t\t\t\t\tuQK4fRC9lCq9/HNmwiWjzHbtRZ/UpnMCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tLtT/rEHRmejcFxajw0S+QrvnQOo51UbCrn5Uj+sB/vNWNNO/H2q7Z4vqcttd5Md3\n\t\t\t\t\t\tB5pcDenz3EnlsNb/MPQNxA2ilf56llPM7WBQlbM74gKRIo5i5Nn98henvD8+m3tj\n\t\t\t\t\t\tNdapAU3pl5pqocCwQL3gE5NC4L6YhY7UBKdqbRE6vPBOtbHIJAF0BKM5Crxp3ee+\n\t\t\t\t\t\tYWig50w3rNKFyBWQ0xHLVEs+FeiZBbSBNBBK1Gqjg8bWylPyvK0kCgLyVIjZX9D9\n\t\t\t\t\t\t9pPT26OiCFI3SypXYPOYjSWiNz5tlY3CYna/x7LAZSg3h+RJmp0VByjNe0s3CkZg\n\t\t\t\t\t\tez/Z03T/OFgp5FhaUpqzxQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "borderscollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.borderscollege.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.borderscollege.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.borderscollege.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.borderscollege.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.borderscollege.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.borderscollege.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.borderscollege.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.borderscollege.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "borderscollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID/DCCAuQCCQDmNVK58fWDtTANBgkqhkiG9w0BAQUFADCBvzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxGjAYBgNVBAgMEVNjb3R0aXNoIEJvcmRlcnMgMRMwEQYDVQQHDApHYWxhc2hp\n\t\t\t\t\t\tZWxzMRgwFgYDVQQKDA9Cb3JkZXJzIENvbGxlZ2UxFzAVBgNVBAsMDklDVCBEZXBh\n\t\t\t\t\t\tcnRtZW50MSEwHwYDVQQDDBhpZHAuYm9yZGVyc2NvbGxlZ2UuYWMudWsxKTAnBgkq\n\t\t\t\t\t\thkiG9w0BCQEWGkdTYXVuQGJvcmRlcnNjb2xsZWdlLmFjLnVrMB4XDTE1MDIxODE1\n\t\t\t\t\t\tMzQ1M1oXDTI1MDIxNTE1MzQ1M1owgb8xCzAJBgNVBAYTAkdCMRowGAYDVQQIDBFT\n\t\t\t\t\t\tY290dGlzaCBCb3JkZXJzIDETMBEGA1UEBwwKR2FsYXNoaWVsczEYMBYGA1UECgwP\n\t\t\t\t\t\tQm9yZGVycyBDb2xsZWdlMRcwFQYDVQQLDA5JQ1QgRGVwYXJ0bWVudDEhMB8GA1UE\n\t\t\t\t\t\tAwwYaWRwLmJvcmRlcnNjb2xsZWdlLmFjLnVrMSkwJwYJKoZIhvcNAQkBFhpHU2F1\n\t\t\t\t\t\tbkBib3JkZXJzY29sbGVnZS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\n\t\t\t\t\t\tAQoCggEBAO/lris+8qS70Yb/6096UTgmMZcJEsPHweU8GmZDgIeb3b+/5vSlixlh\n\t\t\t\t\t\tutP8tiF7oeLx/rapMSSLbbP0muG+aePPk2TNCR8mklYYzaAumBKIfJL4NJLz5qYN\n\t\t\t\t\t\tXXeu31yHoK865kN7d27l7EaH0hlbGz9KR1PbCtD5/Db35MU1uPWAaNAUB9KZrqeF\n\t\t\t\t\t\tx+C+bCvRbAfbQXAIOg0E0mdJpYQnx2b1wIucY7zoemkivBdlHkr00OUn8hCSD+bb\n\t\t\t\t\t\tzL/OQO77/CKxPYn2cAeE8cPQPNJOISiupEVSY7rqNuktw6knrl4zQdXNoCXO86Nd\n\t\t\t\t\t\tuQK4fRC9lCq9/HNmwiWjzHbtRZ/UpnMCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tLtT/rEHRmejcFxajw0S+QrvnQOo51UbCrn5Uj+sB/vNWNNO/H2q7Z4vqcttd5Md3\n\t\t\t\t\t\tB5pcDenz3EnlsNb/MPQNxA2ilf56llPM7WBQlbM74gKRIo5i5Nn98henvD8+m3tj\n\t\t\t\t\t\tNdapAU3pl5pqocCwQL3gE5NC4L6YhY7UBKdqbRE6vPBOtbHIJAF0BKM5Crxp3ee+\n\t\t\t\t\t\tYWig50w3rNKFyBWQ0xHLVEs+FeiZBbSBNBBK1Gqjg8bWylPyvK0kCgLyVIjZX9D9\n\t\t\t\t\t\t9pPT26OiCFI3SypXYPOYjSWiNz5tlY3CYna/x7LAZSg3h+RJmp0VByjNe0s3CkZg\n\t\t\t\t\t\tez/Z03T/OFgp5FhaUpqzxQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Borders College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.borderscollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Borders College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://Shibboleth.uem.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helcio do Prado"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helcio@uem.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://Shibboleth.uem.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4jCCAcoCAQAwDQYJKoZIhvcNAQEFBQAwNzEMMAoGA1UECxMDTlBEMQswCQYD\nVQQGEwJCUjEaMBgGA1UEAxMRU2hpYmJvbGV0aC51ZW0uYnIwHhcNMTQwNDE1MTQx\nNTIwWhcNMTkwNDE0MTQxNTIwWjA3MQwwCgYDVQQLEwNOUEQxCzAJBgNVBAYTAkJS\nMRowGAYDVQQDExFTaGliYm9sZXRoLnVlbS5icjCCASIwDQYJKoZIhvcNAQEBBQAD\nggEPADCCAQoCggEBALs/KHnZekrQFrHtk9e+vVMklEe0+7HfSu34nJHP7vOpQTZR\nKwpRnisPoSwBkeY4JcbgUa2/gSskUTSf4EBWvrfaUs5NATXc0l5VOT7T2vXrUye0\nUa1LsAroWH2/yEB2gvs8THrtp+UZ1uAYJkoIxcc9ydZ7LKUpSuv/LrCAjHaiwD6q\njNMSFYm+UUpt6tzAWBuHfoJng92JId0qelSGIT7WjjOPlyE/iA+gXZd1/k4FFS8V\ndxAcNYLlP8uqVjVR9RsHRjOphdxvvNg8r9210k2z8XH698EOKmunuVMkcFaBIevO\npc6rhoGj/ldt9J8F5skvx2l9qwezMOXwgJyf/UsCAwEAATANBgkqhkiG9w0BAQUF\nAAOCAQEApYQmpGfiWbaWLXUYvh30t5YUPqvnPcNfz70mdUhm4zIDBzHIRZeBHg2L\n95GqLFmCdQnHXcVVVADx/w1FXOQk14l3tmukOCRGHga0Ut6DPvAcJSVcTAfUh03U\nmFETv9XACNN6qWfV0f6kUWU3O64runCgTATOHFNkT+wOusx8pIIwdXudj47+KbZS\ng1si2gBE4K06TiA8DygDCIaqS7roCrsGc1iY1FWop03y91TABSH9EzU25dgAW9Q2\nrFO4M7HOkAEzzTLR7/3eE3fLOv6xTGnASwz3rYbhA/SfJZE/v/Ld6PUhBY1a+WO1\nTZVYQfUodulLy5CH0QkSH1Focl6MuA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uem.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://Shibboleth.uem.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://Shibboleth.uem.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://Shibboleth.uem.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://Shibboleth.uem.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://Shibboleth.uem.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://Shibboleth.uem.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://Shibboleth.uem.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://Shibboleth.uem.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uem.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uem.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uem.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UEM - Universidade Estadual de Maringa"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UEM - Universidade Estadual de Maringa"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UEM - Universidade Estadual de Maringa"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UEM - Universidade Estadual de Maringa"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4jCCAcoCAQAwDQYJKoZIhvcNAQEFBQAwNzEMMAoGA1UECxMDTlBEMQswCQYD\nVQQGEwJCUjEaMBgGA1UEAxMRU2hpYmJvbGV0aC51ZW0uYnIwHhcNMTQwNDE1MTQx\nNTIwWhcNMTkwNDE0MTQxNTIwWjA3MQwwCgYDVQQLEwNOUEQxCzAJBgNVBAYTAkJS\nMRowGAYDVQQDExFTaGliYm9sZXRoLnVlbS5icjCCASIwDQYJKoZIhvcNAQEBBQAD\nggEPADCCAQoCggEBALs/KHnZekrQFrHtk9e+vVMklEe0+7HfSu34nJHP7vOpQTZR\nKwpRnisPoSwBkeY4JcbgUa2/gSskUTSf4EBWvrfaUs5NATXc0l5VOT7T2vXrUye0\nUa1LsAroWH2/yEB2gvs8THrtp+UZ1uAYJkoIxcc9ydZ7LKUpSuv/LrCAjHaiwD6q\njNMSFYm+UUpt6tzAWBuHfoJng92JId0qelSGIT7WjjOPlyE/iA+gXZd1/k4FFS8V\ndxAcNYLlP8uqVjVR9RsHRjOphdxvvNg8r9210k2z8XH698EOKmunuVMkcFaBIevO\npc6rhoGj/ldt9J8F5skvx2l9qwezMOXwgJyf/UsCAwEAATANBgkqhkiG9w0BAQUF\nAAOCAQEApYQmpGfiWbaWLXUYvh30t5YUPqvnPcNfz70mdUhm4zIDBzHIRZeBHg2L\n95GqLFmCdQnHXcVVVADx/w1FXOQk14l3tmukOCRGHga0Ut6DPvAcJSVcTAfUh03U\nmFETv9XACNN6qWfV0f6kUWU3O64runCgTATOHFNkT+wOusx8pIIwdXudj47+KbZS\ng1si2gBE4K06TiA8DygDCIaqS7roCrsGc1iY1FWop03y91TABSH9EzU25dgAW9Q2\nrFO4M7HOkAEzzTLR7/3eE3fLOv6xTGnASwz3rYbhA/SfJZE/v/Ld6PUhBY1a+WO1\nTZVYQfUodulLy5CH0QkSH1Focl6MuA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UEM - Universidade Estadual de Maringa"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UEM - Universidade Estadual de Maringa"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uem.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uem.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UEM - Universidade Estadual de Maringa"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UEM - Universidade Estadual de Maringa"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.iit.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ict_servicedesk@iit.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IIT-Service Desk ICT"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.iit.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2014-07-24T14:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEzCCAfugAwIBAgIUHIWbRP4lLaQqLeAOPCDTBpfKvFAwDQYJKoZIhvcNAQEF\nBQAwFTETMBEGA1UEAxMKaWRwLmlpdC5pdDAeFw0xMzA1MzExNjAxMTRaFw0zMzA1\nMzExNjAxMTRaMBUxEzARBgNVBAMTCmlkcC5paXQuaXQwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQCXtz7N8Q8s8RgmfsMD0oKFSU3Tka0uiSLLb32v1GGU\nBUa/0PJ2JHtGflLSUqat5eY57tgapbmuZ4wcL69dNEysmulLcaXBEJW6N+gZgOEp\njefydM9yur6LyQFGPJEo8xtjhLgje835g69lRejx5I6uR/xB/ZpsFFezZB0bEiLT\no++j3feGk41B/9sHtHF1hsXZB1XxACtoF7PSSCXHVzlWaL3Dqqy/7/LHSYRbRM7V\nM7nEbT3rnGIYy7w4127q8EYyO70ehC2x06kNAt7cpEPyT6I86Q9g39KCztAmpAXt\nar3oBkWq3OTR2til0WqsnAI28PlULIcthqVAn53bp/pLAgMBAAGjWzBZMDgGA1Ud\nEQQxMC+CCmlkcC5paXQuaXSGIWh0dHBzOi8vaWRwLmlpdC5pdC9pZHAvc2hpYmJv\nbGV0aDAdBgNVHQ4EFgQUlm9TS1DW0CQjQP3dOgSB1L9zICkwDQYJKoZIhvcNAQEF\nBQADggEBAAhirHsW76gKfQPyNc1tAUQOu+wt9wlb+lkkthT7sRcBfInpB7JAEABY\nEEL+vARREM0JGlIVjDolnQcfX08+XVkIgmIzte5/8hDKtN8FalpD5FhvdKfOxh+6\nLIzpG+nsuhX+Zg7xlfy1acqfqjT3LutHTDc1+GKnQo/pUoZbTvjzZLtEd1pXibZy\nw1LSYU47K4epzK2OpxXyX85KoNdnjfK4qPH2DOt9RAtcryqL1o0C9vAYspib/Efr\npMQa1UDXAYBHZUmb72ol+6UtRnrFLWJJOIa/XXL21p1NQ3A17rssS751OfcFmkLP\nroltF87PG3SU/pYmKkSZM7KUtqQHk3U="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iit.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.iit.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.iit.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.iit.it/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.iit.it/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.iit.it:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.iit.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.iit.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.iit.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.iit.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.iit.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.iit.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iit.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idp.iit.it/"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idp.iit.it/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IIT - Istituto Italiano di Tecnologia"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IIT - Istituto Italiano di Tecnologia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for staff and students of IIT - Istituto Italiano di Tecnologia"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per personale e studenti del IIT - Istituto Italiano di Tecnologia"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.iit.it/public/logo16.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.iit.it/public/logo16.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.iit.it/public/logo80.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idp.iit.it/public/logo80.png",
                    "lang": "it",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://idp.iit.it/"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://idp.iit.it/"
                  }
                ]
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "iit.it"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "90.147.14.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "90.147.15.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "90.147.38.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEzCCAfugAwIBAgIUHIWbRP4lLaQqLeAOPCDTBpfKvFAwDQYJKoZIhvcNAQEF\nBQAwFTETMBEGA1UEAxMKaWRwLmlpdC5pdDAeFw0xMzA1MzExNjAxMTRaFw0zMzA1\nMzExNjAxMTRaMBUxEzARBgNVBAMTCmlkcC5paXQuaXQwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQCXtz7N8Q8s8RgmfsMD0oKFSU3Tka0uiSLLb32v1GGU\nBUa/0PJ2JHtGflLSUqat5eY57tgapbmuZ4wcL69dNEysmulLcaXBEJW6N+gZgOEp\njefydM9yur6LyQFGPJEo8xtjhLgje835g69lRejx5I6uR/xB/ZpsFFezZB0bEiLT\no++j3feGk41B/9sHtHF1hsXZB1XxACtoF7PSSCXHVzlWaL3Dqqy/7/LHSYRbRM7V\nM7nEbT3rnGIYy7w4127q8EYyO70ehC2x06kNAt7cpEPyT6I86Q9g39KCztAmpAXt\nar3oBkWq3OTR2til0WqsnAI28PlULIcthqVAn53bp/pLAgMBAAGjWzBZMDgGA1Ud\nEQQxMC+CCmlkcC5paXQuaXSGIWh0dHBzOi8vaWRwLmlpdC5pdC9pZHAvc2hpYmJv\nbGV0aDAdBgNVHQ4EFgQUlm9TS1DW0CQjQP3dOgSB1L9zICkwDQYJKoZIhvcNAQEF\nBQADggEBAAhirHsW76gKfQPyNc1tAUQOu+wt9wlb+lkkthT7sRcBfInpB7JAEABY\nEEL+vARREM0JGlIVjDolnQcfX08+XVkIgmIzte5/8hDKtN8FalpD5FhvdKfOxh+6\nLIzpG+nsuhX+Zg7xlfy1acqfqjT3LutHTDc1+GKnQo/pUoZbTvjzZLtEd1pXibZy\nw1LSYU47K4epzK2OpxXyX85KoNdnjfK4qPH2DOt9RAtcryqL1o0C9vAYspib/Efr\npMQa1UDXAYBHZUmb72ol+6UtRnrFLWJJOIa/XXL21p1NQ3A17rssS751OfcFmkLP\nroltF87PG3SU/pYmKkSZM7KUtqQHk3U="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IIT - Istituto Italiano di Tecnologia"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IIT - Istituto Italiano di Tecnologia"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iit.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iit.it/en/home.html"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IIT - Istituto Italiano di Tecnologia"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IIT - Istituto Italiano di Tecnologia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://academic.reportlinker.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cadi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kca@reportlinker.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Karim"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cadi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kca@reportlinker.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Karim"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://academic.reportlinker.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-06-28T14:55:01Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Reportlinker for Libraries"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.reportlinker.com/index/about/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UBIQUICK SAS"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://academic.reportlinker.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://academic.reportlinker.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://academic.reportlinker.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "logo": [
                  {
                    "text": "https://www.reportlinker.com/public/images/commun/academic/logo_w350.jpg",
                    "height": "96",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Reportlinker for Libraries"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEADCCAuigAwIBAgIJAI2zAKYVKKSxMA0GCSqGSIb3DQEBBQUAMIGAMQswCQYD\n\t\t\t\t\t\tVQQGEwJGUjEPMA0GA1UECBMGRnJhbmNlMQ0wCwYDVQQHEwRMeW9uMREwDwYDVQQK\n\t\t\t\t\t\tEwhVYmlxdWljazEZMBcGA1UEAxMQcmVwb3J0bGlua2VyLmNvbTEjMCEGCSqGSIb3\n\t\t\t\t\t\tDQEJARYUa2NhQHJlcG9ydGxpbmtlci5jb20wHhcNMTIwNjIwMTYxMTQ5WhcNMzIw\n\t\t\t\t\t\tNjE1MTYxMTQ5WjCBgDELMAkGA1UEBhMCRlIxDzANBgNVBAgTBkZyYW5jZTENMAsG\n\t\t\t\t\t\tA1UEBxMETHlvbjERMA8GA1UEChMIVWJpcXVpY2sxGTAXBgNVBAMTEHJlcG9ydGxp\n\t\t\t\t\t\tbmtlci5jb20xIzAhBgkqhkiG9w0BCQEWFGtjYUByZXBvcnRsaW5rZXIuY29tMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoQ/PEL4omNHjglyYy0m9TtYy\n\t\t\t\t\t\tPs2EdFQy7nbt/EOav1ogaqNJwcF4d3KneSJuaJWsxFoPw0f0uqCuK1hHBQbTowjA\n\t\t\t\t\t\tBW/RSPzzyv1MgtUqpKIWk07WgQcYAPEm8pkMoCrpgqb36p/2tFgwpp/9H2zqtLS9\n\t\t\t\t\t\tqYKKPLG1CTAGT3CfbO22hFAeulyudcdo9u/hg/mIAhBlM84KVXY5SLp+yvTeUfSq\n\t\t\t\t\t\tOvk3H+EpdUESagO5sujHvPo6YM4g8ndnMqIbJtdslyXYtZLt71eViTSnEP/sfT+2\n\t\t\t\t\t\tNs7DPXSHcwcGV7sB961MeATYC1dGX3h45PYejtttA3JxEnGMzeN8+4Hg9Lu8cQID\n\t\t\t\t\t\tAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVy\n\t\t\t\t\t\tYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQU8AkQ/A+PIm42swrGvEzXv4kxziMw\n\t\t\t\t\t\tHwYDVR0jBBgwFoAU8AkQ/A+PIm42swrGvEzXv4kxziMwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAJ4bBp0Jkt+VyBt/MvAq86H79p0r4BoznVAgQgjrS7g5vy1b6TvcDze0F0qt\n\t\t\t\t\t\tb381xndZhF2d4OVgDOBUjY1fRf+fom+uaBd5xT+oyPGICRBS26SUWm0xg7RPy02E\n\t\t\t\t\t\t/Okd/Unoycb8mwOKFjI1J5FcWDF/RvQNEdgLPjYY0uD00sp13riYDz1MAwy7lTsz\n\t\t\t\t\t\tLk9Oa6pe822E2IFi2oGJ4oUB+dMSUmRuRps4xGxiy+XG9bXGIs1kgNJTc31EYYle\n\t\t\t\t\t\t+PT1s+jOYaWdH5KVVcbTO2RGZVo6PMMVgIne6wwKzOY9L4P+LCtAO7NXiNKs170e\n\t\t\t\t\t\tm7vEy4QyxlwygQmmFRKsLgO8M9I="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://academic.reportlinker.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://academic.reportlinker.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://academic.reportlinker.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://academic.reportlinker.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://academic.reportlinker.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://academic.reportlinker.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.uams.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kapowell@uams.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Keith A. Powell"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "CochranStephenW@uams.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve W. Cochran"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.uams.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.uams.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF6DCCA9ACAQEwDQYJKoZIhvcNAQEFBQAwgbkxCzAJBgNVBAYTAlVTMREwDwYD\nVQQIEwhBcmthbnNhczEUMBIGA1UEBxMLTGl0dGxlIFJvY2sxNDAyBgNVBAoTK1Vu\naXZlcnNpdHkgb2YgQXJrYW5zYXMgZm9yIE1lZGljYWwgU2NpZW5jZXMxCzAJBgNV\nBAsTAklUMRwwGgYDVQQDExNzaGliYm9sZXRoLnVhbXMuZWR1MSAwHgYJKoZIhvcN\nAQkBFhFrYXBvd2VsbEB1YW1zLmVkdTAeFw0xMDAxMjEyMDIwMTlaFw0yMDAxMTky\nMDIwMTlaMIG5MQswCQYDVQQGEwJVUzERMA8GA1UECBMIQXJrYW5zYXMxFDASBgNV\nBAcTC0xpdHRsZSBSb2NrMTQwMgYDVQQKEytVbml2ZXJzaXR5IG9mIEFya2Fuc2Fz\nIGZvciBNZWRpY2FsIFNjaWVuY2VzMQswCQYDVQQLEwJJVDEcMBoGA1UEAxMTc2hp\nYmJvbGV0aC51YW1zLmVkdTEgMB4GCSqGSIb3DQEJARYRa2Fwb3dlbGxAdWFtcy5l\nZHUwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQD5Hc8JIuSngcQzhmkZ\nhjJy5R1d/7zlBNEHuBrHw21UE1y7lpVAJUAk1wDj4twxLjrkzTuWcClvr+8DU+ov\nKvd8as3UmxcLtUdzpgDPGNggLyyNn5kdJP0Ds0eQ7RzIVMOq4tU87eL0TjIFY6Kg\n4898Now4GKkcb+D13d+a3mXWSUAi1HfnUtKoAwZIj1awc/P7C5lO+sq+rgB4+EAl\nTcjB+vS1puUbk+eKBLWfp4iQfwpmRVtTRhQT/fDxvvebbW/in2GoRUDLHsgkxLLk\ncIVPw965w3bek93EOj/nJeZ8FtGgByQhIONOyXWgLgIzSb6q+r0aO7cGYOeTD2fd\nckJxFIu6lrk25pdWE7heUCwmFiOpG5i4Dn/Zyfbk5Mf2rrEOimzNLQGMXoXrSo2x\nw8Md5hQTa2hgkEhOAqYCYVeZEkpPJkj9yeYvnYF1pOvzRvUVbje93SV9Mp1Umt4A\nkmGR7PWBYnRO+ibspy5KTt2wZvwm8Nnz9FMa4KY93/HdS55OYPzUZ0U6J1Qb66Co\njjD0/7DAKNWyP2rDxor1HAP94tYwkkM5N/nmGh7rp5/ky0UYN46dVruLozO6CvC0\nHL4Jv3oAByDM3mA9zEWUFnPLGSel87N6Bghp7y+NSbop6QxDThgKJom3BZdoFrRd\nIVpTEW1a4Bkx0n4/HN+wVSuaiQIDAQABMA0GCSqGSIb3DQEBBQUAA4ICAQAVSKZp\nWRiiI/GMwP8J1qLpPYps9GAg8K3SSamNTZjFb4Bx1U9BX2oVfhFzWUHlkEZ4I9Kn\npHy1DoajsUMXGihIAW7nE4QB7Scg0/j72qWD8RTYJf45LOMmYjwaFzh6nx8ZW8nr\njQFlZ3FZqrdxRlc09QGj+/1EAB8zsl1TwY5LLHKXmxrrzxgcjlEJQj5W1QsxY+cp\nqR7U2FTIUHWPYIuk32j+4D0cADEgSPRoWQvhQ4yv6ObXnnysmQyL80vMy4qWRkQW\nEZzValhP7+c1HlX/3ZFE5oyfa4MIArxQ2cD6wCxhGLauMOCAGkWw2OBSTsNrAQ9k\nZ5w7ZkB+dkZjTLbMpXEBEjInQraA6daFGpHn0XZWt0yUrPv8yuwrPZPEhCulnCwz\njPT8ic+thGwdiyXVouxToFoDS+IHHhQXkH4tNTZSVK8g8do5V5mxSJLq2QiySAKj\n8HCKUSg+5YT9hghvD/DZg7AIG7x15WB7tguybmEZ0ZQTMbXfxW8++ennnMv0YB08\n0TcaZVLkzfGqpa7LViMTg+DMOxrbxDPyWwmJYIp1wctIwD/0Mt1GLO24SCpsL0Xi\n/oQmUfmngWJ89KOYIv/FBO1yVwq3LUuwc1bDS+6zYsmOTIdNTjl+HGmq07Nu5IEV\n5CGF3Xf3OCIcIPuFxeF6aJA+h9o82twJq3mwpw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uams.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.uams.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.uams.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.uams.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.uams.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uams.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Arkansas for Medical Sciences"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF6DCCA9ACAQEwDQYJKoZIhvcNAQEFBQAwgbkxCzAJBgNVBAYTAlVTMREwDwYD\nVQQIEwhBcmthbnNhczEUMBIGA1UEBxMLTGl0dGxlIFJvY2sxNDAyBgNVBAoTK1Vu\naXZlcnNpdHkgb2YgQXJrYW5zYXMgZm9yIE1lZGljYWwgU2NpZW5jZXMxCzAJBgNV\nBAsTAklUMRwwGgYDVQQDExNzaGliYm9sZXRoLnVhbXMuZWR1MSAwHgYJKoZIhvcN\nAQkBFhFrYXBvd2VsbEB1YW1zLmVkdTAeFw0xMDAxMjEyMDIwMTlaFw0yMDAxMTky\nMDIwMTlaMIG5MQswCQYDVQQGEwJVUzERMA8GA1UECBMIQXJrYW5zYXMxFDASBgNV\nBAcTC0xpdHRsZSBSb2NrMTQwMgYDVQQKEytVbml2ZXJzaXR5IG9mIEFya2Fuc2Fz\nIGZvciBNZWRpY2FsIFNjaWVuY2VzMQswCQYDVQQLEwJJVDEcMBoGA1UEAxMTc2hp\nYmJvbGV0aC51YW1zLmVkdTEgMB4GCSqGSIb3DQEJARYRa2Fwb3dlbGxAdWFtcy5l\nZHUwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQD5Hc8JIuSngcQzhmkZ\nhjJy5R1d/7zlBNEHuBrHw21UE1y7lpVAJUAk1wDj4twxLjrkzTuWcClvr+8DU+ov\nKvd8as3UmxcLtUdzpgDPGNggLyyNn5kdJP0Ds0eQ7RzIVMOq4tU87eL0TjIFY6Kg\n4898Now4GKkcb+D13d+a3mXWSUAi1HfnUtKoAwZIj1awc/P7C5lO+sq+rgB4+EAl\nTcjB+vS1puUbk+eKBLWfp4iQfwpmRVtTRhQT/fDxvvebbW/in2GoRUDLHsgkxLLk\ncIVPw965w3bek93EOj/nJeZ8FtGgByQhIONOyXWgLgIzSb6q+r0aO7cGYOeTD2fd\nckJxFIu6lrk25pdWE7heUCwmFiOpG5i4Dn/Zyfbk5Mf2rrEOimzNLQGMXoXrSo2x\nw8Md5hQTa2hgkEhOAqYCYVeZEkpPJkj9yeYvnYF1pOvzRvUVbje93SV9Mp1Umt4A\nkmGR7PWBYnRO+ibspy5KTt2wZvwm8Nnz9FMa4KY93/HdS55OYPzUZ0U6J1Qb66Co\njjD0/7DAKNWyP2rDxor1HAP94tYwkkM5N/nmGh7rp5/ky0UYN46dVruLozO6CvC0\nHL4Jv3oAByDM3mA9zEWUFnPLGSel87N6Bghp7y+NSbop6QxDThgKJom3BZdoFrRd\nIVpTEW1a4Bkx0n4/HN+wVSuaiQIDAQABMA0GCSqGSIb3DQEBBQUAA4ICAQAVSKZp\nWRiiI/GMwP8J1qLpPYps9GAg8K3SSamNTZjFb4Bx1U9BX2oVfhFzWUHlkEZ4I9Kn\npHy1DoajsUMXGihIAW7nE4QB7Scg0/j72qWD8RTYJf45LOMmYjwaFzh6nx8ZW8nr\njQFlZ3FZqrdxRlc09QGj+/1EAB8zsl1TwY5LLHKXmxrrzxgcjlEJQj5W1QsxY+cp\nqR7U2FTIUHWPYIuk32j+4D0cADEgSPRoWQvhQ4yv6ObXnnysmQyL80vMy4qWRkQW\nEZzValhP7+c1HlX/3ZFE5oyfa4MIArxQ2cD6wCxhGLauMOCAGkWw2OBSTsNrAQ9k\nZ5w7ZkB+dkZjTLbMpXEBEjInQraA6daFGpHn0XZWt0yUrPv8yuwrPZPEhCulnCwz\njPT8ic+thGwdiyXVouxToFoDS+IHHhQXkH4tNTZSVK8g8do5V5mxSJLq2QiySAKj\n8HCKUSg+5YT9hghvD/DZg7AIG7x15WB7tguybmEZ0ZQTMbXfxW8++ennnMv0YB08\n0TcaZVLkzfGqpa7LViMTg+DMOxrbxDPyWwmJYIp1wctIwD/0Mt1GLO24SCpsL0Xi\n/oQmUfmngWJ89KOYIv/FBO1yVwq3LUuwc1bDS+6zYsmOTIdNTjl+HGmq07Nu5IEV\n5CGF3Xf3OCIcIPuFxeF6aJA+h9o82twJq3mwpw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Arkansas for Medical Sciences"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uams.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Arkansas for Medical Sciences"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://udash-dev.data.alpha.jisc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Baylis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lee.baylis@jisc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lee"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Baylis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lee.baylis@jisc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lee"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://udash-dev.data.alpha.jisc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-02-15T14:36:19Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Jisc Unicon Dashboard (Development)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.jisc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Jisc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://udash-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://udash-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://udash-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://udash-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://udash-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://udash-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Access to the Development version of the Jisc Unicon Dashboard"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.jisc.ac.uk/sites/all/themes/jisc_clean/logo.png",
                    "height": "34",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "61"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Jisc Unicon Dashboard (Development)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIJAMoOqszthd+3MA0GCSqGSIb3DQEBBQUAMCoxKDAmBgNV\n\t\t\t\t\t\tBAMTH3VkYXNoLWRldi5kYXRhLmFscGhhLmppc2MuYWMudWswHhcNMTYwMjExMTMw\n\t\t\t\t\t\tOTUwWhcNMjYwMjA4MTMwOTUwWjAqMSgwJgYDVQQDEx91ZGFzaC1kZXYuZGF0YS5h\n\t\t\t\t\t\tbHBoYS5qaXNjLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tmmX3dhTPAgcCPyDXXljuirFTktjI/+Df1e/TdsgbiIi9OVDb0dxRnUOnuFEgVNsK\n\t\t\t\t\t\tpNb5xSXCNMGXnXQc7tviOuYFho+yxGtLYJd5S7Re2PuQlTp8HuVivES+MGkmKvz8\n\t\t\t\t\t\tcrrwA/rpY7FMMDTBg1tEOhnTwQnkLNtyA2ahqBtzCNzAvWhCjpX6KnEjg+QoRqoi\n\t\t\t\t\t\tdWCqXLh6GlNsBlJYs4vV2vG+W6giR8saVeLt+oGOB4sShOp+1yHrvO/C8W3uyjes\n\t\t\t\t\t\ti8YvXFnLr/7n/USGSjyZWwgKYBe8fB42Zu1XItSnag/yzWiqXkOzTrnnsmooto7E\n\t\t\t\t\t\tNqeFQ60bcVTXkuwVYhljPQIDAQABo00wSzAqBgNVHREEIzAhgh91ZGFzaC1kZXYu\n\t\t\t\t\t\tZGF0YS5hbHBoYS5qaXNjLmFjLnVrMB0GA1UdDgQWBBSOmUPK+6BZogF6Szdpuvjt\n\t\t\t\t\t\t5AftjDANBgkqhkiG9w0BAQUFAAOCAQEAezNCq6M0MT6s49J1b69XEiUunolCB+ZM\n\t\t\t\t\t\tn8Dwa6prnwErPbNCrwdIqFjm3OtvXovxPUkyp7zelxX6o01sclIwwKGLXnI4PSMk\n\t\t\t\t\t\tPycSMFaHVIQfB1IzXZYVto/GPHqUNPodFXgzTfECzkGt/lpG7uGt4l+lnC0IjYoc\n\t\t\t\t\t\tj4ck+x3KWINkKT2rRZQMOb3XVhO3uMdKUnPbbP+tH0u2XocjMJkCLcAhiDEgGCGJ\n\t\t\t\t\t\t+NwsIoGehsa2hcJ7NeMhQKgTZKJMw3Aq/LltoqBe3qLe1RLgdR9Yr37KdCFknBlK\n\t\t\t\t\t\te1kOr58uk4NSlXwpnXzJm1qbO8wyNpg5BSS3J+AJmlYNDgPDah/zdg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://udash-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://udash-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://udash-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://udash-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://udash-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://udash-dev.data.alpha.jisc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Jisc Unicon Dashboard (Development)"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonEntitlement",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://portalservicesutv.miun.se/shibboleth",
    {
      "entity_id": "https://portalservicesutv.miun.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://portalservicesutv.miun.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://portalservicesutv.miun.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://portalservicesutv.miun.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://portalservicesutv.miun.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://portalservicesutv.miun.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://portalservicesutv.miun.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "rosalindutv.personal.miun.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIJAKCTfNMVxYcfMA0GCSqGSIb3DQEBBQUAMCcxJTAjBgNV\nBAMTHHJvc2FsaW5kdXR2LnBlcnNvbmFsLm1pdW4uc2UwHhcNMTIxMTE1MjIyMTM5\nWhcNMjIxMTEzMjIyMTM5WjAnMSUwIwYDVQQDExxyb3NhbGluZHV0di5wZXJzb25h\nbC5taXVuLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqKPvBXqy\nnRvi3sDksMSy9G5VZ9JhXA4/Kz3xY00PiE0Qg6FonPD01VqAJe8uh/yZc4Ckb9on\n6eWHX9wRiE+bdk0HsqaqXvXjmbQdQs2w3VQqNVDIAWoIljdVFf80G5KzJYLf8IRd\n5HI/hQ72rctAQCo5XWB8VfU18QDcPVMdiJJ4mVjOEuj5nWBqOi5xX94SHJZzlsA3\nUamgvzbO4hypXeoXxz2t8rAsMSSajlvURBN7/7yKp0Phwp5UqGXQz/O+FrjNxVxa\nT5ARsjgi3h1L1izfkHlOnCB6CL4Hgs4azOfAlokchmV4I92Wz4zyQq9HwCylJDOv\nckP3oS/ZKIe2DwIDAQABo0owSDAnBgNVHREEIDAeghxyb3NhbGluZHV0di5wZXJz\nb25hbC5taXVuLnNlMB0GA1UdDgQWBBQKoz3fn0XgpuozE4czYMpBM19mZjANBgkq\nhkiG9w0BAQUFAAOCAQEAU6lmNUTJOleVGd5RjCnHBx5qBHU158VVUfrKEWbCohPi\nE0gUTOT7wf7FEK7A7XEdV1oC530cIUsRiEAi/hZMQxhkHwjcxRTEtqbIsknDcP6P\nYCROa5TjdPIF/ABsFXlVG5ypmezx/6i+iT+9INr6ipvnQP0bNnfnZGejI9OUrAw4\n42gbDmSviYSYdHr6VDi2V3+JdIQ7AEgw5VRdPsBwAg1b8jyrvTywbYooSHvh/9sp\nOdn0f+Ng1oWBX+8fMDWfhppFm2bDrgM3xCF9GA15oA24yzp4n1VZN5K4mr1+79Tj\nvWPiY7ukG3rEmXz1vlicbY542ygl7W7mMwL6JqPEXw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=rosalindutv.personal.miun.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "rosalindutv.personal.miun.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIJAKCTfNMVxYcfMA0GCSqGSIb3DQEBBQUAMCcxJTAjBgNV\nBAMTHHJvc2FsaW5kdXR2LnBlcnNvbmFsLm1pdW4uc2UwHhcNMTIxMTE1MjIyMTM5\nWhcNMjIxMTEzMjIyMTM5WjAnMSUwIwYDVQQDExxyb3NhbGluZHV0di5wZXJzb25h\nbC5taXVuLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqKPvBXqy\nnRvi3sDksMSy9G5VZ9JhXA4/Kz3xY00PiE0Qg6FonPD01VqAJe8uh/yZc4Ckb9on\n6eWHX9wRiE+bdk0HsqaqXvXjmbQdQs2w3VQqNVDIAWoIljdVFf80G5KzJYLf8IRd\n5HI/hQ72rctAQCo5XWB8VfU18QDcPVMdiJJ4mVjOEuj5nWBqOi5xX94SHJZzlsA3\nUamgvzbO4hypXeoXxz2t8rAsMSSajlvURBN7/7yKp0Phwp5UqGXQz/O+FrjNxVxa\nT5ARsjgi3h1L1izfkHlOnCB6CL4Hgs4azOfAlokchmV4I92Wz4zyQq9HwCylJDOv\nckP3oS/ZKIe2DwIDAQABo0owSDAnBgNVHREEIDAeghxyb3NhbGluZHV0di5wZXJz\nb25hbC5taXVuLnNlMB0GA1UdDgQWBBQKoz3fn0XgpuozE4czYMpBM19mZjANBgkq\nhkiG9w0BAQUFAAOCAQEAU6lmNUTJOleVGd5RjCnHBx5qBHU158VVUfrKEWbCohPi\nE0gUTOT7wf7FEK7A7XEdV1oC530cIUsRiEAi/hZMQxhkHwjcxRTEtqbIsknDcP6P\nYCROa5TjdPIF/ABsFXlVG5ypmezx/6i+iT+9INr6ipvnQP0bNnfnZGejI9OUrAw4\n42gbDmSviYSYdHr6VDi2V3+JdIQ7AEgw5VRdPsBwAg1b8jyrvTywbYooSHvh/9sp\nOdn0f+Ng1oWBX+8fMDWfhppFm2bDrgM3xCF9GA15oA24yzp4n1VZN5K4mr1+79Tj\nvWPiY7ukG3rEmXz1vlicbY542ygl7W7mMwL6JqPEXw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=rosalindutv.personal.miun.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://portalservicesutv.miun.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://portalservicesutv.miun.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://portalservicesutv.miun.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://portalservicesutv.miun.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://portalservicesutv.miun.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://portalservicesutv.miun.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://portalservicesutv.miun.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://portalservicesutv.miun.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://portalservicesutv.miun.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://portalservicesutv.miun.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ocvc.ac.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athens@ocvc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ithelpdesk@ocvc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Services"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ocvc.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-11-19T17:55:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://openathens.ocvc.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://openathens.ocvc.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ocvc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDaDCCAlCgAwIBAgIIJK53AJuGOYowDQYJKoZIhvcNAQEFBQAwSzEpMCcGA1UE\n\t\t\t\t\t\tCgwgT3hmb3JkICYgQ2hlcndlbGwgVmFsbGV5IENvbGxlZ2UxHjAcBgNVBAMMFW9w\n\t\t\t\t\t\tZW5hdGhlbnMub2N2Yy5hYy51azAeFw0xMzEwMjgxNDM5NTVaFw0yMzEwMjgxMzM5\n\t\t\t\t\t\tNTVaMEsxKTAnBgNVBAoMIE94Zm9yZCAmIENoZXJ3ZWxsIFZhbGxleSBDb2xsZWdl\n\t\t\t\t\t\tMR4wHAYDVQQDDBVvcGVuYXRoZW5zLm9jdmMuYWMudWswggEiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tAQUAA4IBDwAwggEKAoIBAQCNnm5Z9gl6f4YR2HJAHY8ne53sVj4L+PL4orRT/cG/\n\t\t\t\t\t\tCcnldjJRFOEdeJhK53/Gxdgoxt0gtZulIfTofGOPskBu+rr1OWJWW2VeAP2elp2r\n\t\t\t\t\t\t+Tl/aNjFiMhBriKhAZJJpm1kcZkjO7sYrVvMbreVS0/9y1GuoKKfO7MjIZ5Yxtnq\n\t\t\t\t\t\tXyimprbRsgNFxxE/B+BWFEsLwsJjhxM6puGOBl3x+3oyfBLDP4qPThG+isa1j/fj\n\t\t\t\t\t\t8Z3vG2XFfcYj+KvlSYm6IEI/M7V8Eq7tOCPk+4y1fuEMFB1f/M9FgmX4McwhSFMa\n\t\t\t\t\t\tsjcRrGeXZdPawGqcGv4rgvPcj0frRbMVqWl1JZtqc1Z3AgMBAAGjUDBOMB0GA1Ud\n\t\t\t\t\t\tDgQWBBSMitszDAvNeoGk0O7s/xrD8Eys9DAfBgNVHSMEGDAWgBSMitszDAvNeoGk\n\t\t\t\t\t\t0O7s/xrD8Eys9DAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQA0WOY/\n\t\t\t\t\t\tphQvI6UKEiIkjS2B9lDB29bR8LFB1AiotU9y3a1ynTzXWDwxHtEpR+kuSC1qgpOI\n\t\t\t\t\t\tHMqNSsUTvAKs36pPk4/esCCUzdbG2i+6oIEyIykpULBX0zR+XzXPhng8HQCStcGQ\n\t\t\t\t\t\tU5IsgVzitMO4UlmdF4GiVGb+OCd/pydtBpb2oRK53/x+dW5p49XPN8HjoqpF1tMV\n\t\t\t\t\t\tuQBLmqpPooVlHC3LZnFRJ9bo1seEpZwBzVdTWaGLRXQu3Hsa8vGZTtefRRPWlPdA\n\t\t\t\t\t\t8xu4ferryExDoB95D0cLivnE73eO8QlsbdDVjfYRwHDvx3VFWFOwuiDakNE5ZLj8\n\t\t\t\t\t\tfxjatX0mFmoxpNUu"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Activate Learning"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ocvc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Activate Learning"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://nya-gerrit.its.umu.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://nya-gerrit.its.umu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nya-gerrit.its.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nya-gerrit.its.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nya-gerrit.its.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nya-gerrit.its.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nya-gerrit.its.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://nya-gerrit.its.umu.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://nya-gerrit.its.umu.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://nya-gerrit.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Gerrit f\u00f6r NyA p\u00e5 ITS, Ume\u00e5 universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Gerrit for NyA at ITS, Ume\u00e5 university"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Gerrit f\u00f6r NyA p\u00e5 ITS, Ume\u00e5 universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Gerrit for NyA at ITS, Ume\u00e5 university"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "nya-gerrit.its.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJAPYUOmUEXEx7MA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\nBAMTFW55YS1nZXJyaXQuaXRzLnVtdS5zZTAeFw0xNTEyMTYwODU2NDRaFw0yNTEy\nMTMwODU2NDRaMCAxHjAcBgNVBAMTFW55YS1nZXJyaXQuaXRzLnVtdS5zZTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMt6Yzi3g3Zi2xU/5x0ko16wX6W9\n0MUT/qfPGXpRxbZ7XFtie7Nta7fkycWKbbPVbwqKN8UfFwHX8nKQXDH1qr+DcUsg\naZkpuZWQCmBak0suJMe9KoWHtuV4rRLy/bGdP1nr/iCQXgzzMaK5Vl3zjwveMGLm\n8o8IEKseiXhOIi6SylOIr7uXSISJDXMsp8ci3+/x5BxspObSabMYP4N/BmHyLS9B\nqRUaPnZXLkAtACJKoO3tFp8WRD8km0MIHxVwyWlt5VZ/O07SwR/aE5S00N90uTUi\nDZvLTdGf5oqFEpvbwwvtxlh+YGa21NTG5gr3jvhBUTPg9htaHXCjoVDOYk8CAwEA\nAaNDMEEwIAYDVR0RBBkwF4IVbnlhLWdlcnJpdC5pdHMudW11LnNlMB0GA1UdDgQW\nBBQFyI1JDTEsUquK39VeFpxYxsURZTANBgkqhkiG9w0BAQUFAAOCAQEAtPNFyjz3\nkCnoRXulU7Q0jCRLUwpprWXnf2dljDDdQWtsT+tGsVPsvkIOw2l8pCHtyk6H2xqs\n0NW5mg3DwveZfs6D2CSMCfjeR/snrFRkecWow+zAJ49Qhb/dzCgwT2HhcWNr/PlY\nBtpf6GrNXRBK32odHiayHphOlMzIjo8Rg3w5o5S4xFH/4njP3dE5yeS6npXBD61P\n+Cd3DAHgCMRdOg9XdZFhV1FP/G1h4iBkwXYDGyMyQeVsx3TEmvgwWs/J1mCWXBCR\nt4sAFjL3EzEpVBBtvV7lMHO8Z+6Xqc7La0Auy6ZfZgovFyz919WkueKCdjGZXsJ3\n0PUBKN9pvQ4JWQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=nya-gerrit.its.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://nya-gerrit.its.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://nya-gerrit.its.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nya-gerrit.its.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nya-gerrit.its.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://nya-gerrit.its.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://nya-gerrit.its.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://nya-gerrit.its.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://nya-gerrit.its.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://nya-gerrit.its.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.niu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dgersic@niu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David Gersic"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dgersic@niu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David Gersic"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dgersic@niu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David Gersic"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.niu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.niu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.niu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.niu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.niu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.niu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "niu.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Northern Illinois University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUKnaPgEQSbfYJd3gH9ZzjBNXVpDwwDQYJKoZIhvcNAQEF\nBQAwFjEUMBIGA1UEAxMLaWRwLm5pdS5lZHUwHhcNMTIwNjI1MjEyMzQyWhcNMzIw\nNjI1MjEyMzQyWjAWMRQwEgYDVQQDEwtpZHAubml1LmVkdTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBANuafXsLdk3SmPpCyiffiR7vZANMZR2z8CLJ/gFX\n3K5Xg9NRxulRbODOc3BPPQ0lsOjDbdJHnS61ynhCkX+TDNjdslINg+GtD25VG3hT\nSAmsu3BLIcYayR6TqB9kOJ5aZD3xi5OX9zgTrJonkpF5O18A/Nf4ze4U0fi284Ff\nMhChMChLTSHdGUX7CMgGtvTLeINUAPTA1y28QdqGa1gXRMrVYh0dHpLOLA0+2rjU\nsTvjyLzr8Mhy+1dLOetZznDodBnNzEHJtOBsgoNYHIzDk9VSvtHf09y5HPDloLY1\nriGYBquHi3j8a0JBujreT9GmNDL+gcq4MX/ciijMkhtO318CAwEAAaNdMFswOgYD\nVR0RBDMwMYILaWRwLm5pdS5lZHWGImh0dHBzOi8vaWRwLm5pdS5lZHUvaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFKXEzk/Mh/VQaH38rRYuaeMYBvhwMA0GCSqGSIb3\nDQEBBQUAA4IBAQCLljQgIjIbmd2Fpg5M6q6pUNtmmUjXEs9FlcIjJb7A1rh3ViME\nkmEqQsko2Pho4fYs4nV1K3JHwl/cTG9pfv07OaZP/nqnXlUYoz6ExDw8FjVmC1cR\nWrDr1KpMAmr0j3+EqVvWfBIBOCbIgjQAt/N1SOaEDirBYVUcAslZHYZ2bxlYnP20\nUOqBrWO6GFnhn3OYsTxtSiT8RO7XI4tq3aBxKUfjd1p9eM5OtHvOFSZEjGEyFomL\nXQZKskmaxo4qmHMwKxfx3+KgBRWg2Ulsdo2LXvFPNDcpPKqxzMttT63xvyeSDICa\nH83FixTxhPWSdCCW+q92fF/ESMtrlCQHBvAy"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Northern Illinois University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.niu.edu/index.html"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Northern Illinois University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.globaldata.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Imran"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:assad.imran@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Assad"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sfikas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:panagiotis.sfikas@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Panagiotis"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hogg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ghogg@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Geoffrey"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Imran"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:assad.imran@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Assad"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sfikas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:panagiotis.sfikas@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Panagiotis"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hogg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ghogg@progressivemediagroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Geoffrey"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.globaldata.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-02-25T15:12:36Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Marketline Advantage"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.progressivemediagroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GlobalData PLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.globaldata.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.globaldata.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.globaldata.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.globaldata.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.globaldata.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib.globaldata.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib.globaldata.com/Shibboleth.sso/UKfederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shib.globaldata.com/Shibboleth.sso/UKfederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFTCCAf2gAwIBAgIJAIPtXUnJnE1GMA0GCSqGSIb3DQEBBQUAMCUxIzAhBgNV\n\t\t\t\t\t\tBAMTGnBkbTc2d2ViMjEucGRtMTZkYXRhLmxvY2FsMB4XDTE2MDIyNDEyMjQyOFoX\n\t\t\t\t\t\tDTI2MDIyMTEyMjQyOFowJTEjMCEGA1UEAxMacGRtNzZ3ZWIyMS5wZG0xNmRhdGEu\n\t\t\t\t\t\tbG9jYWwwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC2jbrYeBhyAcDH\n\t\t\t\t\t\t70dSrmdX9A72VBpo6el40VQ2hhCiBr9/z0h3xOTIiEJJkSn/eqG7VCu4h0f7q3lu\n\t\t\t\t\t\tzaVmMXcJKMmrP7zRHTo9LzGUKNEFMwn8ixHhmZQjoxaiNpEoSNLek49e6CqRqPof\n\t\t\t\t\t\thD6cUH3CZ1hPnZP7MNhinwIGWWtB4tbcc8JOxWzJu7RYUbCroFrUtwRrHP5Ke7dA\n\t\t\t\t\t\tuoeq1MdZXDgjl+0Q3GF7lFNHe6dpynDbszvn83kV/McE0an5KLmywfVNVbNZudIB\n\t\t\t\t\t\tMCCy39xfGKkVa+mmBwttejC53rZpn1PkRzFQi3BrQlY+cZezkSOXSrBhb7fWhLqX\n\t\t\t\t\t\t+jTqYCvbAgMBAAGjSDBGMCUGA1UdEQQeMByCGnBkbTc2d2ViMjEucGRtMTZkYXRh\n\t\t\t\t\t\tLmxvY2FsMB0GA1UdDgQWBBQN/+Lmtg98KmwdwIduwxNjhFfOpzANBgkqhkiG9w0B\n\t\t\t\t\t\tAQUFAAOCAQEAhvjRfA5RAfjl3RC4Kp4aaqZX86uWliqqdh1y9CQlSWYafoTM7yGK\n\t\t\t\t\t\tVt0OMYnELmJfYVcZKqHhI0KNi9abfAJ3T0kpx5ZB43pV3pWg7Y6yPLBT7lmdYFH8\n\t\t\t\t\t\ttkj+caBt6YZI6SZiASUDzyNoHkyk+ys3Xc7/SCHQM1R5nkyvugqumeg0gB5K/WDw\n\t\t\t\t\t\tN0g1jP3j2q6NG3hhKgj+Nrxi4nJLP7l/S8T47Mhe7loDu7nXm3bHnfKU3fEcXWSV\n\t\t\t\t\t\tYurWPT+UtAXIsDyZ+/PTwDFBA6VF/WsKMPuvwzt/20b/dJeR3lmA2OHJ9XSnqSly\n\t\t\t\t\t\tAZjDyGL+M78bgGAJHAB3ULGowwH4yckkYg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.globaldata.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.globaldata.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.globaldata.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shib.globaldata.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shib.globaldata.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shib.globaldata.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.nuca.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.nuca.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/nuca.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/nuca.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nuca.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Norwich University of the Arts"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nua.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://scsh.scran.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webadmins@rcahms.gov.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Scran/RCAHMS Web Admins"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webadmins@rcahms.gov.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Scran/RCAHMS Web Admins"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://scsh.scran.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-03-14T14:42:36Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Screening Shorts"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.screeningshorts.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Scran Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.scran.ac.uk/scsh/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.scran.ac.uk/scsh/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.scran.ac.uk/scsh/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.scran.ac.uk/scsh/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.scran.ac.uk/scsh/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.scran.ac.uk/scsh/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.scran.ac.uk/scsh/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.scran.ac.uk/scsh/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.scran.ac.uk/scsh/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.scran.ac.uk/scsh/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "A resource developed by Creative Scotland and Education Scotland to help teachers deliver moving image education (MIE)."
                  }
                ],
                "logo": [
                  {
                    "text": "https://shib.scran.ac.uk/images/logo-scsh.png",
                    "height": "69",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "250"
                  },
                  {
                    "text": "https://shib.scran.ac.uk/images/icon-scsh.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Screening Shorts"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.scran.ac.uk/scsh/Shibboleth.sso/DS/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.scran.ac.uk/scsh/Shibboleth.sso/DS/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.scran.ac.uk/scsh/Shibboleth.sso/WAYF/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.scran.ac.uk/scsh/Shibboleth.sso/glow",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib.scran.ac.uk/scsh/Shibboleth.sso/DS/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shib.scran.ac.uk/scsh/Shibboleth.sso/DS/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib.scran.ac.uk/scsh/Shibboleth.sso/WAYF/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shib.scran.ac.uk/scsh/Shibboleth.sso/glow",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEpzCCA4+gAwIBAgIJAJr9uyuwy/Y2MA0GCSqGSIb3DQEBBQUAMIGTMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjERMA8GA1UECBMIU2NvdGxhbmQxEjAQBgNVBAcTCUVkaW5idXJnaDEP\n\t\t\t\t\t\tMA0GA1UEChMGUkNBSE1TMQ4wDAYDVQQLEwVTY3JhbjEWMBQGA1UEAwwNKi5zY3Jh\n\t\t\t\t\t\tbi5hYy51azEkMCIGCSqGSIb3DQEJARYVd2ViYWRtaW5zQHNjcmFuLmFjLnVrMB4X\n\t\t\t\t\t\tDTEwMDIyMjExNDU1OVoXDTIwMDIyMDExNDU1OVowgZMxCzAJBgNVBAYTAkdCMREw\n\t\t\t\t\t\tDwYDVQQIEwhTY290bGFuZDESMBAGA1UEBxMJRWRpbmJ1cmdoMQ8wDQYDVQQKEwZS\n\t\t\t\t\t\tQ0FITVMxDjAMBgNVBAsTBVNjcmFuMRYwFAYDVQQDDA0qLnNjcmFuLmFjLnVrMSQw\n\t\t\t\t\t\tIgYJKoZIhvcNAQkBFhV3ZWJhZG1pbnNAc2NyYW4uYWMudWswggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDEywuow7F7KjwlfTa4vj/2QWvtexIy+OO0hWvn\n\t\t\t\t\t\tSJ8B3goDjqaC7Mv1fNJdxtZMl/kR6ZfMT86Xa2VfK47NOe14jJDgZxN/0lbwsLwb\n\t\t\t\t\t\tGyyxcZeDg0NCcv/jFKUiH6m2jSLkpSrSTHuUqRUhGpR0wcr3+HZjLZrpHI0FQ5EH\n\t\t\t\t\t\tcnkhg1fYwZ5Z6vth+0NhZt9HjWLrUtia4Bj0orj0MkUAKlGEBudrPsC/OITO9oUp\n\t\t\t\t\t\tpXV0PBi0hILJdbgeJXDFhxfcEpCczQlQgdx/KWD6q/6nSOmT9hNGMjkiprn/w/q1\n\t\t\t\t\t\tSsAMRqSfrWrR6q8hWTkWmNsm/c39bJFuMvkfkiOgvvBVqE3nAgMBAAGjgfswgfgw\n\t\t\t\t\t\tHQYDVR0OBBYEFG8UIQ7Hc9WHtlS6PKYYP/7RWNcrMIHIBgNVHSMEgcAwgb2AFG8U\n\t\t\t\t\t\tIQ7Hc9WHtlS6PKYYP/7RWNcroYGZpIGWMIGTMQswCQYDVQQGEwJHQjERMA8GA1UE\n\t\t\t\t\t\tCBMIU2NvdGxhbmQxEjAQBgNVBAcTCUVkaW5idXJnaDEPMA0GA1UEChMGUkNBSE1T\n\t\t\t\t\t\tMQ4wDAYDVQQLEwVTY3JhbjEWMBQGA1UEAwwNKi5zY3Jhbi5hYy51azEkMCIGCSqG\n\t\t\t\t\t\tSIb3DQEJARYVd2ViYWRtaW5zQHNjcmFuLmFjLnVrggkAmv27K7DL9jYwDAYDVR0T\n\t\t\t\t\t\tBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAWSSnSaVz28lDBISUNRmNJFwKvjo5\n\t\t\t\t\t\tnC4+WM7h6Tg9QbC/EYNCwkH7bOoEcCJs28jn0EwRfn4GUgc1LFkf9UYc3rJ+mihD\n\t\t\t\t\t\t+RZDHjaJSZDbQgZI55y8dpuYT8r70rCg+xtq1Iwv0NzcM+Q/3cEeiMlIXY6YFAAA\n\t\t\t\t\t\tDsp1/4NlItMUs6ZwAyMLjyIlSjIHjTVLI2bRTDlY4nUgZhqz4spvqDtnmq7PERUN\n\t\t\t\t\t\tLTUxK70J8DSNHEuzC8s+rTfXhsn01ZUKGDQqeFDO3TccF/x8iespeHPJO7uD/klz\n\t\t\t\t\t\tbjQPf6gJKSkRW/uiwoDLkt/CChMGLGbYpQcx/7RpyzUpN4u4PHLduf03kQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.scran.ac.uk/scsh/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.scran.ac.uk/scsh/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.scran.ac.uk/scsh/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.scran.ac.uk/scsh/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.scran.ac.uk/scsh/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.scran.ac.uk/scsh/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.scran.ac.uk/scsh/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.scran.ac.uk/scsh/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.scran.ac.uk/scsh/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.scran.ac.uk/scsh/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.scran.ac.uk/scsh/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.scran.ac.uk/scsh/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.scran.ac.uk/scsh/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.scran.ac.uk/scsh/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shib.scran.ac.uk/scsh/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shib.scran.ac.uk/scsh/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.scran.ac.uk/scsh/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shib.scran.ac.uk/scsh/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.scran.ac.uk/scsh/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.scran.ac.uk/scsh/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://adfs.morgan.edu/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "TRaisbeck@sycomtech.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tom Raisbeck"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Alexandre.Adao@morgan.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alexandre Adao"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs.morgan.edu/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://adfs.morgan.edu/adfs/ls",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC2jCCAcKgAwIBAgIQZ4Ca0HR644NMZw4H92x4fDANBgkqhkiG9w0BAQsFADAp\nMScwJQYDVQQDEx5BREZTIFNpZ25pbmcgLSBBREZTLk1vcmdhbi5lZHUwHhcNMTMx\nMjA5MTgxMjU0WhcNMTQxMjA5MTgxMjU0WjApMScwJQYDVQQDEx5BREZTIFNpZ25p\nbmcgLSBBREZTLk1vcmdhbi5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQCT6FWhre5VGszboXF2s0i6QNCf5R8ptj0TfXpg104FLV47wIjh6eENGUsE\nZvSJ5sP8xlxkvVlsyrNZrRJQ+85MtlNpH9K+zdhYUnbdi+2NRcAR4ZzYgpHpued0\nWDKmhu26dLlCkPs4zITfTWpx7nc/5aTCa04mdgrYU4vhIzXWiTYvu0UN9FdxQ2N1\nSsweArHilPoiVUOVofWx9urrrndzgJ6MWuCIjWk4NVy2dKw9KWHNPZI9YYGFXRVP\nVMo68tsH1TYQwBw93WHINXkBCVzsPrJujXXPZ1QzftBnW7Nk3h/eKG6Oax46dzxA\nz16gxndQg5y0EJShUYb804hTMAaPAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAE3h\nQ40sr5Vtny9ya3dm5vhnVn5Dy5Vcfs2Jibd6UYO2yU4wIE0+REh+ms88384s90VA\n3nkCuT3z1EzoBbG128/opJA7p77s493TgQb0GhhjGIIh9hPzdSbkcwnbrolK+arA\nXJTqhQEZ5JkkDORySN+gt4mjB0DvaZTQXGm/H420ecX6GT/t9zNJycnz4cId1K1S\nc2SnJZkGv1OMp3SLipQ+ouGzoyF3O3OzcvQkcc8l2D6MKfQveCAnL8qIBXo6lrYz\nNB2YMc40VslJhFrugMvw+4J04NHbjDFPjCzu6WdLjHtjk16Z5NQOs8a5f1kBW+Lx\n2QvIFX+YUmvc+TvooRY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "morgan.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Morgan State University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Morgan State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.morgan.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Morgan State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://bmtheventskit.sisoshibboleth.co.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Info"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Oates"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bmtheventskit.sisoshibboleth.co.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-12-09T14:52:37Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SiSo Bournemouth University ~ Events, Online Resource Booking"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.siso.uk.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "TechEthika Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bmth.siso.co/eventskit/sso/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://bmth.siso.co/eventskit/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://bmth.siso.co/eventskit/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SiSo Bournemouth University ~ Events, Online Resource Booking"
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth.siso.co/siso-logo60x60.jpg",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SiSo Bournemouth University ~ Events, Online Resource Booking"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAOSUhyDXVj7AMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB3Npc28uY28wHhcNMTMwMTA3MTYzMTIxWhcNMjMwMTA1MTYzMTIxWjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdzaXNvLmNvMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\txDnj9YFJVXclawo/8rs1aWYAgk6rKi8A/Cyycq0mW5yOKLLh8MUIgDeOGL7bLl7p\n\t\t\t\t\t\tMBeZM4ILlNaeJhICWm1tuLB6SYzREnXwpO7+lvx13xsRHW2TjCPGV3yUgz55vRYj\n\t\t\t\t\t\tbseFrwFHJ8IrL24UTLcpX/R//9cMkZpSqM+77Hn22dxbYvGUOQCHOQzL78AO91qz\n\t\t\t\t\t\tdUaxKzYWyWM7w2U4APP41Zvd0flyUtRZXp8W+WwlUDffFoNndsjR4L/9wuXvOcrH\n\t\t\t\t\t\t+VZtMLy60+cB9bpvVlaQVlt+1stEABdMVvuGNkJ9wIjRjP2b9OLUI76QmgwIDtdE\n\t\t\t\t\t\t5BS0Bv0Puz66L96r2MunRQIDAQABozUwMzASBgNVHREECzAJggdzaXNvLmNvMB0G\n\t\t\t\t\t\tA1UdDgQWBBRRosxNbUQXXwtWDl/kYMScRImh5TANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tgrfjza9Btcz+9WvzcjDTZ+KSrWWvrthA3zc6Q+C/MIBG8CCuxMO+uwFBnXIopGlX\n\t\t\t\t\t\tbLa/QtVLjOugsnizFxjaEFTG4jGndtPJ8+9V8Eja5RlOazuM2LT738+Um8/1Frhr\n\t\t\t\t\t\tGXa0Hdv9ZWEbIhil65fFqZNOmOteja6xxAQ9NgGG/XUnTVTbr7msihEAYTTcS40/\n\t\t\t\t\t\tGSYpT9nQwiryfSWDNJ17Zyl44389kSw+FCUsu8Ns9VSDEDWr/R+97ZMcjN6hAfJL\n\t\t\t\t\t\tdji3X1aaAC/JbnJl/v+yR1TH/sdHyObVaM7FToUGKiyjX9VpfOe64d0hjogzEr0x\n\t\t\t\t\t\tfirJubLNu96jbGctasqcpQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bmth.siso.co/eventskit/sso/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://bmth.siso.co/eventskit/sso/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bmth.siso.co/eventskit/sso/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://bmth.siso.co/eventskit/sso/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://bmth.siso.co/eventskit/sso/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://bmth.siso.co/eventskit/sso/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.hslu.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41 41 228 21 21"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "(Hotline)"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:informatikhotline@hslu.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hochschule Luzern - IT Services"
          }
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "(AAI Technician)"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@hslu.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hochschule Luzern - IT Services"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.hslu.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2016-03-03T15:19:10Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAOIyvPYAinGuMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC2lkcC5oc2x1LmNoMB4XDTE0MDQxMTA4MTM1MVoXDTE3MDQxMDA4MTM1MVow\nFjEUMBIGA1UEAxMLaWRwLmhzbHUuY2gwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQCwhrP8yk/+IifeO8mUL2SPCX2Jwze6fiyBxaLFsq9PRUKwu/m6CMk9\n87SAvBV541a0pWRpizrAa/jSRNPXQYQLK9h93/5bTc4VBbf1PfqnluOIAq7y23bG\nRQEkcd7NqOkTMOl404LIys0lsk6yQz/GILg6howVh77wGG07AL8DlBFhyjMaOHTt\naNHh5Chkk8mEB7EP92uJpB6vISJV/Adj2Y95ZefwWo09vGWlUP1usJr0Rhn2HpYy\n68Q0tKY5vXQYIf2IDyoCmPVXW+Q5GWL/WWc/ZUfmi5Srrueh/DRNzoT4/6tqt39r\nRfiVjjhml9p2w4NPwchEYKkec5/ThxIzAgMBAAGjXTBbMDoGA1UdEQQzMDGCC2lk\ncC5oc2x1LmNohiJodHRwczovL2lkcC5oc2x1LmNoL2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBRclnGUQ4woRbzyaXdRPmu0afzYDDANBgkqhkiG9w0BAQUFAAOCAQEA\nlxSpDW+8n4O9+VGRxrqir42UFerXSYKlr5TiCzU2vpgUOuecK05hrskCeCrn1Zr+\ns4zkISefcaXayNOVhCOfUEfc/eA3VlefzSTfXk84pGkhIDJ4DTDMlkP1MCQNDYcx\neMTbruMyKU4AYHbQgvhAqXUuMD6dXqtmkKatWTyWw9jNYjsNi18CCPN0UIq2lqoM\ndKuYJ6IAhWZYLq/vqC4kllYX2rhXxu/F/1A92qfG4FhE9urOu+LVd6LdO2WSwj/N\nIwOpfglNU30kw1y3t08Pwq1wZEmNW+5PUjDbUrGLvnPaLRjjXoXVebzPXoqaGJm0\n7uYGZFS62PnJbFAk9NvN1g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hslu.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.hslu.ch/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.hslu.ch/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.hslu.ch/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.hslu.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.hslu.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.hslu.ch/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.hslu.ch/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.hslu.ch/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hslu.ch"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://english.hslu.ch/"
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.hslu.ch/"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hochschule Luzern"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Lucerne University of Applied Sciences and Arts"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAAXNSR0IArs4c6QAAACF0RVh0U29mdHdhcmUAR3JhcGhpY0NvbnZlcnRlciAoSW50ZWwpd4f6GQAAADVJREFUeJxi+P//PwMlmCLN1DHAxcXlPyV4OBgw8LGQNnPmf2LxcDVg4GOBUgMAAAAA//8DAA5inxcVtjGTAAAAAElFTkSuQmCC",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "HSLU - Hochschule Luzern"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "HSLU - Lucerne University of Applied Sciences and Arts"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "hslu.ch"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "hochschuleluzern.ch"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.046681,8.314912"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.013434,8.305034"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.174274,8.512537"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.060845,8.322106"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.048388,8.309762"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.048096,8.314655"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.054246,8.295853"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.219.232/29"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.220.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.221.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.217.218/31"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.222.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.224.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.225.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.226.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.228.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.230.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.231.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.232.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.236.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.237.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.217.220/30"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.217.224/27"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.238.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.218.0/25"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.240.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.254.64/29"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.254.72/29"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.254.80/29"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.254.96/29"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.254.112/29"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:620:110::/48"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.218.128/25"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.219.200/29"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.219.208/29"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.219.216/29"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.219.224/29"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.216.0/26"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.88.217.0/25"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "error_url": "http://hotline.hslu.ch/",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAOIyvPYAinGuMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC2lkcC5oc2x1LmNoMB4XDTE0MDQxMTA4MTM1MVoXDTE3MDQxMDA4MTM1MVow\nFjEUMBIGA1UEAxMLaWRwLmhzbHUuY2gwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQCwhrP8yk/+IifeO8mUL2SPCX2Jwze6fiyBxaLFsq9PRUKwu/m6CMk9\n87SAvBV541a0pWRpizrAa/jSRNPXQYQLK9h93/5bTc4VBbf1PfqnluOIAq7y23bG\nRQEkcd7NqOkTMOl404LIys0lsk6yQz/GILg6howVh77wGG07AL8DlBFhyjMaOHTt\naNHh5Chkk8mEB7EP92uJpB6vISJV/Adj2Y95ZefwWo09vGWlUP1usJr0Rhn2HpYy\n68Q0tKY5vXQYIf2IDyoCmPVXW+Q5GWL/WWc/ZUfmi5Srrueh/DRNzoT4/6tqt39r\nRfiVjjhml9p2w4NPwchEYKkec5/ThxIzAgMBAAGjXTBbMDoGA1UdEQQzMDGCC2lk\ncC5oc2x1LmNohiJodHRwczovL2lkcC5oc2x1LmNoL2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBRclnGUQ4woRbzyaXdRPmu0afzYDDANBgkqhkiG9w0BAQUFAAOCAQEA\nlxSpDW+8n4O9+VGRxrqir42UFerXSYKlr5TiCzU2vpgUOuecK05hrskCeCrn1Zr+\ns4zkISefcaXayNOVhCOfUEfc/eA3VlefzSTfXk84pGkhIDJ4DTDMlkP1MCQNDYcx\neMTbruMyKU4AYHbQgvhAqXUuMD6dXqtmkKatWTyWw9jNYjsNi18CCPN0UIq2lqoM\ndKuYJ6IAhWZYLq/vqC4kllYX2rhXxu/F/1A92qfG4FhE9urOu+LVd6LdO2WSwj/N\nIwOpfglNU30kw1y3t08Pwq1wZEmNW+5PUjDbUrGLvnPaLRjjXoXVebzPXoqaGJm0\n7uYGZFS62PnJbFAk9NvN1g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "HSLU - Hochschule Luzern"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "HSLU - Lucerne University of Applied Sciences and Arts"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hslu.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hslu.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "hslu.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://mailfilter-test.nordu.net/shibboleth",
    {
      "entity_id": "https://mailfilter-test.nordu.net/shibboleth",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mailfilter-test.nordu.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mailfilter-test.nordu.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mailfilter-test.nordu.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mailfilter-test.nordu.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mailfilter-test.nordu.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://mailfilter-test.nordu.net/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://mailfilter-test.nordu.net/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://mailfilter-test.nordu.net/Shibboleth.sso/DS/kalmar3",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "canit.nordu.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAO/nNPqDBCrnMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2Nhbml0Lm5vcmR1Lm5ldDAeFw0xMDA1MjAyMTUxMzRaFw0yMDA1MTcyMTUx\nMzRaMBoxGDAWBgNVBAMTD2Nhbml0Lm5vcmR1Lm5ldDCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBALfQeLKTUhs0gBj90i/FarDm1qm6HYUelLlxK5JJamU+\nBQGaODimGYrh2IzqGUMRxafshp1Z82v2W9ApQKHXO1m7Jg37F/jXmmOLPoF/P4vJ\ngh+c+H8WnPaNOJpWEJlQ/HQaMe6MZ/dZCUNbBnd6MN9vj+MvWH/4mKxIB+HAuOyi\nBAZr2hZyeafWU3+1bHVxUJZQuidYUVY09Jahvp1+kDargSuu0CLClyxqiJtiQN3P\nmAwjveC+Eo83s3/WvEYYkwMYmXYWQf5Rsy7ezKyg6QNfdIfQL1T0hOVmRXwYnzVY\n3zypH/tIaOeAa++fehFQiXB8v7wtTJSpFS9oFsaEFeMCAwEAAaM9MDswGgYDVR0R\nBBMwEYIPY2FuaXQubm9yZHUubmV0MB0GA1UdDgQWBBS0ezKIFjEF0O8UJQKM/2D1\ntp9scDANBgkqhkiG9w0BAQUFAAOCAQEAYWr+FCcA+9Q10RVl7b76EbZaKVjmNsey\nendNf62gKsdu7zbwyAxHVOQ+XA5qZS6kLQThVnF5IJASWO9OJWF3x3Q62TLEXtw0\ncde5YFPhrfdZqRof1dptwD7Bt7kTl6vUV1V5wt1nXMax+rZv6tj08mRaUqBfWZ8w\nobZ3raXz4kaDjT1EGFjwbIc4rS7mZjYwuTGT79zB19BIR5qnL4YvXu44koq02p4S\n9TW8EETE3axOzPF3Vvtmag2vgX9pFJ7G/gFt3Adt6ZKzo1a6GZ9kZKIaE5Dr2Tnn\nVXfcZO7EtnsxYb035Zcei+quLWwJFAIKXwMSWZQEVo4WXa83B8oKnw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=canit.nordu.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "canit.nordu.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAO/nNPqDBCrnMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2Nhbml0Lm5vcmR1Lm5ldDAeFw0xMDA1MjAyMTUxMzRaFw0yMDA1MTcyMTUx\nMzRaMBoxGDAWBgNVBAMTD2Nhbml0Lm5vcmR1Lm5ldDCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBALfQeLKTUhs0gBj90i/FarDm1qm6HYUelLlxK5JJamU+\nBQGaODimGYrh2IzqGUMRxafshp1Z82v2W9ApQKHXO1m7Jg37F/jXmmOLPoF/P4vJ\ngh+c+H8WnPaNOJpWEJlQ/HQaMe6MZ/dZCUNbBnd6MN9vj+MvWH/4mKxIB+HAuOyi\nBAZr2hZyeafWU3+1bHVxUJZQuidYUVY09Jahvp1+kDargSuu0CLClyxqiJtiQN3P\nmAwjveC+Eo83s3/WvEYYkwMYmXYWQf5Rsy7ezKyg6QNfdIfQL1T0hOVmRXwYnzVY\n3zypH/tIaOeAa++fehFQiXB8v7wtTJSpFS9oFsaEFeMCAwEAAaM9MDswGgYDVR0R\nBBMwEYIPY2FuaXQubm9yZHUubmV0MB0GA1UdDgQWBBS0ezKIFjEF0O8UJQKM/2D1\ntp9scDANBgkqhkiG9w0BAQUFAAOCAQEAYWr+FCcA+9Q10RVl7b76EbZaKVjmNsey\nendNf62gKsdu7zbwyAxHVOQ+XA5qZS6kLQThVnF5IJASWO9OJWF3x3Q62TLEXtw0\ncde5YFPhrfdZqRof1dptwD7Bt7kTl6vUV1V5wt1nXMax+rZv6tj08mRaUqBfWZ8w\nobZ3raXz4kaDjT1EGFjwbIc4rS7mZjYwuTGT79zB19BIR5qnL4YvXu44koq02p4S\n9TW8EETE3axOzPF3Vvtmag2vgX9pFJ7G/gFt3Adt6ZKzo1a6GZ9kZKIaE5Dr2Tnn\nVXfcZO7EtnsxYb035Zcei+quLWwJFAIKXwMSWZQEVo4WXa83B8oKnw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=canit.nordu.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mailfilter-test.nordu.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mailfilter-test.nordu.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mailfilter-test.nordu.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mailfilter-test.nordu.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mailfilter-test.nordu.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://mailfilter-test.nordu.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mailfilter-test.nordu.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://mailfilter-test.nordu.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://mailfilter-test.nordu.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://mailfilter-test.nordu.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.silverchair.com/acp/production/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ShibbolethAdmin@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Laseter"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jlaseter@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Josh"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.silverchair.com/acp/production/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2012-04-12T09:33:34Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Silverchair Production: Annals of Internal Medicine"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://annals.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Silverchair Science + Communications, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://annals.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://annals.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://annals.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://annals.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://annals.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://annals.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJANicnaiWujsWMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHNjbTYtZDVwdm0td2ViMS5zY3NsLmludDAeFw0xMjAzMjMxNjEzNDlaFw0y\n\t\t\t\t\t\tMjAzMjExNjEzNDlaMCMxITAfBgNVBAMTGHNjbTYtZDVwdm0td2ViMS5zY3NsLmlu\n\t\t\t\t\t\tdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMBwkz9AV9PbPUK7SXa7\n\t\t\t\t\t\trWvUj+xCylNNDrE4beQIKFSon64hKwfgXFyH7y9UMAq8eajn4J86htU7sLxQxaxe\n\t\t\t\t\t\tXMkU35WHo7GoFbtSFb+L6NHHv+UnIpl2FpeVwGGFUAEG/L4q69Bpy4VMDs0/7m6r\n\t\t\t\t\t\tUBEn/vz74A9nIvglxtyY3aOC9z5RWf0WYQ6MKFXDcVpWzXXRBxiQAGjwNLIDwMn/\n\t\t\t\t\t\tCCSsDjnt8vKWyBr8d/ehkPalUYWj5pBWdhrdSrQ1cWCrBtYJpBxJFgXbFs4i28w8\n\t\t\t\t\t\tb/Zf7ZkXkRLEL6d9C3Bs4yOQmBLWB33VURvAwTGt2SSgVCSt1PYrjkX8qdxe0bE6\n\t\t\t\t\t\tPJ0CAwEAAaNGMEQwIwYDVR0RBBwwGoIYc2NtNi1kNXB2bS13ZWIxLnNjc2wuaW50\n\t\t\t\t\t\tMB0GA1UdDgQWBBSDkYKQ64pYrPAkh2OIuEEcmy3reTANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAuMzCg0YVNDuS7dA9lQSKoqrXh5UjrTVS66McThWCSVz5anQLzk+yYzjDRfY5\n\t\t\t\t\t\t6UGp6vzrnXkd06hLXiYkhp+iKaWi0XtcSzMJ2hKK7JZCEjlDv2aa5G1RZOlVbrgb\n\t\t\t\t\t\tb5iLQRhPD8vkD41JfwqVWFPSUbhCHLpVyxcGsiSvns0lUyShDr+ud/ew1+uD38T+\n\t\t\t\t\t\tIYw3q6gIHAZTydVD5h3Zk0H2VtT1QjoMs9YQFl1iJJCLayeOSRulsUdyB8DxhkGJ\n\t\t\t\t\t\tmEdO6bcXXu7zFrr7ckCioS4N12ZSQuIDPFyfb9/fbpxmcbMmqY3KvZlPvR9OkV6L\n\t\t\t\t\t\tTd7a8cntDuAvJ/skPcyYKaXcbA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://annals.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://annals.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://annals.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://annals.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://annals.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://annals.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibidp.kgv.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Coleman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mpc@kgv.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martyn"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Coleman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mpc@kgv.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martyn"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibidp.kgv.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-05-22T10:26:54Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVANzd8W7p4MbyVI3/OVktKiz5Ch7uMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBwxGjAYBgNVBAMTEXNoaWJpZHAua2d2LmFjLnVrMB4XDTE0MDUwODE1MDE1\n\t\t\t\t\t\tNloXDTM0MDUwODE1MDE1NlowHDEaMBgGA1UEAxMRc2hpYmlkcC5rZ3YuYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDNzquN3Npl2h/H2EYoayIP\n\t\t\t\t\t\tpfTpjPN10gvpYWT1OeMeGrGcTzwetB0UZaE4YYFmpfo+4LJH+wJMUY1FaLLw+GbE\n\t\t\t\t\t\tXUsgaz3ungFsqyaMagEkBhHukrpDTbbU9daprg512h4HKckfdhnc0km7yXmB9dG9\n\t\t\t\t\t\t7ahJvvxlirB0yM9VWK7c+b2AoGKDFLT1SDM/x2oSqP7VWouGg+ncxZvRvkyvx5oI\n\t\t\t\t\t\tWfqoM6o3B7FF0N+XdZdiDiAtv7GqttiusFQvfHHLovREyrWgeIzUIeP7JcQ57gEa\n\t\t\t\t\t\tRZRAqfI0M0FUKnIQrnks3u4pwhx6QyIpb6sk2GZ4rSAKs0FZElgVd+X8LxzC9YIf\n\t\t\t\t\t\tAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEXNoaWJpZHAua2d2LmFjLnVrhihodHRwczov\n\t\t\t\t\t\tL3NoaWJpZHAua2d2LmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQXGuRc\n\t\t\t\t\t\td8maaWEM20jGXTwh0ag9bDANBgkqhkiG9w0BAQUFAAOCAQEAl85FH7yO5IZtaYZ3\n\t\t\t\t\t\tYx04UDAeMMS1LWAgLvz/tEyBK4/Fru7wDuPPhvT4UPtMfg37tKqPXzDisAXAulWP\n\t\t\t\t\t\t0FGUHbDgIMVQ5etmv2hk6Ck/2QdTQ45FTS22xTiveTP0pUYwg3owS4on/hp4KAAb\n\t\t\t\t\t\tVbRxFyQM5onKMCk2XREtfCWThnz+ftuhxJV7pfQMzHaR6Ws2saYHI6bk2TldpQXC\n\t\t\t\t\t\tBzvBJQvwHShZeIlmDzHVNPfpyqDYE0lO2XiqqnHEAImYHuNKoAvgj5jJcViFhWXI\n\t\t\t\t\t\tZhQMaxwU9/UVwOWO1REhWcd7KE+W2ELIgeySGijZmKquKTrOSqyFx3DKSxGdhFsk\n\t\t\t\t\t\tnSUetQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kgv.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.kgv.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.kgv.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.kgv.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.kgv.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibidp.kgv.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.kgv.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.kgv.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.kgv.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kgv.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVANzd8W7p4MbyVI3/OVktKiz5Ch7uMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBwxGjAYBgNVBAMTEXNoaWJpZHAua2d2LmFjLnVrMB4XDTE0MDUwODE1MDE1\n\t\t\t\t\t\tNloXDTM0MDUwODE1MDE1NlowHDEaMBgGA1UEAxMRc2hpYmlkcC5rZ3YuYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDNzquN3Npl2h/H2EYoayIP\n\t\t\t\t\t\tpfTpjPN10gvpYWT1OeMeGrGcTzwetB0UZaE4YYFmpfo+4LJH+wJMUY1FaLLw+GbE\n\t\t\t\t\t\tXUsgaz3ungFsqyaMagEkBhHukrpDTbbU9daprg512h4HKckfdhnc0km7yXmB9dG9\n\t\t\t\t\t\t7ahJvvxlirB0yM9VWK7c+b2AoGKDFLT1SDM/x2oSqP7VWouGg+ncxZvRvkyvx5oI\n\t\t\t\t\t\tWfqoM6o3B7FF0N+XdZdiDiAtv7GqttiusFQvfHHLovREyrWgeIzUIeP7JcQ57gEa\n\t\t\t\t\t\tRZRAqfI0M0FUKnIQrnks3u4pwhx6QyIpb6sk2GZ4rSAKs0FZElgVd+X8LxzC9YIf\n\t\t\t\t\t\tAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEXNoaWJpZHAua2d2LmFjLnVrhihodHRwczov\n\t\t\t\t\t\tL3NoaWJpZHAua2d2LmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQXGuRc\n\t\t\t\t\t\td8maaWEM20jGXTwh0ag9bDANBgkqhkiG9w0BAQUFAAOCAQEAl85FH7yO5IZtaYZ3\n\t\t\t\t\t\tYx04UDAeMMS1LWAgLvz/tEyBK4/Fru7wDuPPhvT4UPtMfg37tKqPXzDisAXAulWP\n\t\t\t\t\t\t0FGUHbDgIMVQ5etmv2hk6Ck/2QdTQ45FTS22xTiveTP0pUYwg3owS4on/hp4KAAb\n\t\t\t\t\t\tVbRxFyQM5onKMCk2XREtfCWThnz+ftuhxJV7pfQMzHaR6Ws2saYHI6bk2TldpQXC\n\t\t\t\t\t\tBzvBJQvwHShZeIlmDzHVNPfpyqDYE0lO2XiqqnHEAImYHuNKoAvgj5jJcViFhWXI\n\t\t\t\t\t\tZhQMaxwU9/UVwOWO1REhWcd7KE+W2ELIgeySGijZmKquKTrOSqyFx3DKSxGdhFsk\n\t\t\t\t\t\tnSUetQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "KGV College - Latest"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kgv.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "King George V College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.comune.trieste.it/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:triestefreespots@comune.trieste.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.comune.trieste.it/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2013-12-17T09:30:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "TriesteFreeSpoTS provided by Municipality of Trieste"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Servizio TriesteFreeSpoTS erogato da Comune di Trieste"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.retecivica.trieste.it/"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.retecivica.trieste.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Municipality of Trieste"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Comune di Trieste"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.comune.trieste.it/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.comune.trieste.it/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.comune.trieste.it/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.comune.trieste.it/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Wi-Fi Free - Trieste Municipality - TriesteFreeSpoTS"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Wi-Fi Libero - Trieste Municipality - TriesteFreeSpoTS"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Wi-Fi Free - Trieste Municipality - TriesteFreeSpoTS"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Wi-Fi Libero - Trieste Municipality - TriesteFreeSpoTS"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.comune.trieste.it/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.retecivica.trieste.it/triestefreespots"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.retecivica.trieste.it/triestefreespots"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Free Wi-Fi connection for people with smartphone, tablet, notebook and other mobile devices that supports Wi-Fi"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Connessione Wi-Fi libera per chi possiede Smartphone, tablet, pc portatili e qualsiasi altro dispositivo mobile dotato di Wi-Fi."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.retecivica.trieste.it/TriesteFreeSpoTS/privacyen.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.retecivica.trieste.it/TriesteFreeSpoTS/privacy.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Wi-Fi Free - Trieste Municipality - TriesteFreeSpoTS"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Wi-Fi Libero - Comune di Trieste - TriesteFreeSpoTS"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIJAJPOWX6jxm8nMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFnNoaWIuY29tdW5lLnRyaWVzdGUuaXQwHhcNMTMxMTE5MTMyNzM1WhcNNDMx\nMTEyMTMyNzM1WjAhMR8wHQYDVQQDExZzaGliLmNvbXVuZS50cmllc3RlLml0MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0Y+CScWVXs3Hl2gxmGp5D1Co\nGdHbRD9LShZ7fCeEpcjxJjZ2apGnXXuQc7DpTthfkiYw+10SvgspjpOsT0T2fPGg\noL6FIS4AUGKkspcGqmlHJjdj2d0bzVcyEpthd4LQmPajX5vNfiTFL01ZlJC4kBbE\ndFVobxxZPaeeMhxBFAwkf0vfmXBgJrUU4+zQoXE2VD/BOsK/tQStqrQH0uIGMR54\nlCkdFmiAaedYkdjsteZvKtxgb8TslE+ULxK0HAl9MmuHPSs/duaHmiM0Huybztj7\nOCgoa2hXKT9G867xB8kdFKwJgfyTZ2f9bIuPwcJEsVd6p5NBZFvd9qG1ILFWpQID\nAQABo28wbTBMBgNVHREERTBDghZzaGliLmNvbXVuZS50cmllc3RlLml0hilodHRw\nczovL3NoaWIuY29tdW5lLnRyaWVzdGUuaXQvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\ngYEe61royxEPHxue0/dBHfj4x0swDQYJKoZIhvcNAQEFBQADggEBAMvNk6mztqu3\n5fKoBZNYhJTdVcC9C4MqjcgrgNtiCCltJt9KrFyok7M+/DUKbBOLAVuGyr+W+Lmk\nGk4CXXAv222AlsZxuOW73uF21H1mUBcCbEWfXphKHkzjGlTlbrqXjop8IHeTD9XO\nNEirAqDB1j/4PAgFsTFBl0We5vJ/96mEYHjk4Ouk5/mn+Tpc2FgVgoe5tizQJ9Lv\nfpXa1oNeZP/WXEwNEVMJjfyqL2Nu9P8t4+5+cTZG/UrVT8JqZ7R/CjxWUwiw+hdI\nP0+J1ansVzeWtND1V+yxrY0kokEbQC/1aoHMnQSRxPLNORe9SRKBkOp+Ci0ROW45\nxEb0XXxzdH8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIJAJPOWX6jxm8nMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFnNoaWIuY29tdW5lLnRyaWVzdGUuaXQwHhcNMTMxMTE5MTMyNzM1WhcNNDMx\nMTEyMTMyNzM1WjAhMR8wHQYDVQQDExZzaGliLmNvbXVuZS50cmllc3RlLml0MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0Y+CScWVXs3Hl2gxmGp5D1Co\nGdHbRD9LShZ7fCeEpcjxJjZ2apGnXXuQc7DpTthfkiYw+10SvgspjpOsT0T2fPGg\noL6FIS4AUGKkspcGqmlHJjdj2d0bzVcyEpthd4LQmPajX5vNfiTFL01ZlJC4kBbE\ndFVobxxZPaeeMhxBFAwkf0vfmXBgJrUU4+zQoXE2VD/BOsK/tQStqrQH0uIGMR54\nlCkdFmiAaedYkdjsteZvKtxgb8TslE+ULxK0HAl9MmuHPSs/duaHmiM0Huybztj7\nOCgoa2hXKT9G867xB8kdFKwJgfyTZ2f9bIuPwcJEsVd6p5NBZFvd9qG1ILFWpQID\nAQABo28wbTBMBgNVHREERTBDghZzaGliLmNvbXVuZS50cmllc3RlLml0hilodHRw\nczovL3NoaWIuY29tdW5lLnRyaWVzdGUuaXQvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\ngYEe61royxEPHxue0/dBHfj4x0swDQYJKoZIhvcNAQEFBQADggEBAMvNk6mztqu3\n5fKoBZNYhJTdVcC9C4MqjcgrgNtiCCltJt9KrFyok7M+/DUKbBOLAVuGyr+W+Lmk\nGk4CXXAv222AlsZxuOW73uF21H1mUBcCbEWfXphKHkzjGlTlbrqXjop8IHeTD9XO\nNEirAqDB1j/4PAgFsTFBl0We5vJ/96mEYHjk4Ouk5/mn+Tpc2FgVgoe5tizQJ9Lv\nfpXa1oNeZP/WXEwNEVMJjfyqL2Nu9P8t4+5+cTZG/UrVT8JqZ7R/CjxWUwiw+hdI\nP0+J1ansVzeWtND1V+yxrY0kokEbQC/1aoHMnQSRxPLNORe9SRKBkOp+Ci0ROW45\nxEb0XXxzdH8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.comune.trieste.it/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.comune.trieste.it/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.comune.trieste.it/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.comune.trieste.it/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.comune.trieste.it/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.comune.trieste.it/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shib.comune.trieste.it/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shib.comune.trieste.it/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shib.comune.trieste.it/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shib.comune.trieste.it/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shu.unidesk.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:is.helpline@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-certs@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Application Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shu.unidesk.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-04-18T13:51:31Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Unidesk - Sheffield Hallam University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shu.unidesk.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shu.unidesk.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shu.unidesk.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shu.unidesk.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shu.unidesk.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shu.unidesk.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAPHsl6kKrFrnMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\n\t\t\t\t\t\tBAMTEmxpdmUudW5pZGVzay5hYy51azAeFw0xMjA0MTExNDU4MjhaFw0yMjA0MDkx\n\t\t\t\t\t\tNDU4MjhaMB0xGzAZBgNVBAMTEmxpdmUudW5pZGVzay5hYy51azCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBAL9qh/Dehm5jJdWdeFPNKqcjMdiqii8Iz9Rc\n\t\t\t\t\t\ttCAsEwRsYww4EQDG7MxG5hg4NSS+iIPFCp9gR+G7hTnZAMGgNpxs2vk4vs9lmhRY\n\t\t\t\t\t\tGmB7Y1NFloP9Pcsu+MaufaLzxi6bzIXV4dBVHqVnIcgxchDIsXmPE6xlq4poEq+q\n\t\t\t\t\t\tXJ3aFE/eWwxfwN9z0s5yeICzsil73xk9T9NLeNAeYq+jfVTcdqDbBHY6eHtMOYh/\n\t\t\t\t\t\tuPVYYxkKXjkgSH5cwG0b+7qN4z+uzKDNBXxnI1Nz+bLOazXW6ljQIDtAPQZMJSlr\n\t\t\t\t\t\t3OepVaQS+fMBi0Sku5yvADgINdXxkz6H4Zx4pZg/rTQBQ/8u2esCAwEAAaNAMD4w\n\t\t\t\t\t\tHQYDVR0RBBYwFIISbGl2ZS51bmlkZXNrLmFjLnVrMB0GA1UdDgQWBBQ2tPlzxC8e\n\t\t\t\t\t\takC2nh9qrG4TWfI3tzANBgkqhkiG9w0BAQUFAAOCAQEAWPY3Nv9ChZ+4XVNANhLq\n\t\t\t\t\t\tfGF7SbiPmUNj9vWGNjCp8Ma0tdDOZPvqBRzxKkkR+LS+fHpSQQ54RuNeZrulWBiN\n\t\t\t\t\t\takZe3LZiSH9AHG2uD0lDuxr0UQt1AHGDiLjFXuRg9+CdqqrdT3Anmy6exDDfRsjH\n\t\t\t\t\t\tk+ZJflkEtqTNd0dbEVlkYlg8Baqx/ZMOxkccx8PtQt1yptAMsH4Rn92vXLd9d3JM\n\t\t\t\t\t\tH1mrFuiriqrgsAfVLmzc4WeGmB+dK01cSB+CY7hKnoe7ds1y7kNhOmZ9HP3Iy7ev\n\t\t\t\t\t\tgF2RCdnqkP9zScihW4b20PlVa/sWMUyCj2uZE1lSO51PJcGVU0H/JFrBEpaM7u6t\n\t\t\t\t\t\tjg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shu.unidesk.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shu.unidesk.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shu.unidesk.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shu.unidesk.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shu.unidesk.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shu.unidesk.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.mf.uni-lj.si/idp/20111101",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:damijan.sencar@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "\u0160uput"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dusan.suput@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Du\u0161an"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hudomalj"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:emil.hudomalj@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Emil"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sen\u010dar"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:damijan.sencar@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Damijan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pesko"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jure.pesko@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jure"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lesko\u0161ek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:brane.leskosek@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Branimir"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sen\u010dar"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:damijan.sencar@mf.uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Damijan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.mf.uni-lj.si/idp/20111101",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_general.pdf"
              },
              {
                "lang": "sl",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_splosni_pogoji.pdf"
              }
            ],
            "registration_instant": "2015-01-13T10:01:30Z",
            "registration_authority": "http://aai.arnes.si",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.mf.uni-lj.si/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.mf.uni-lj.si/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mf.uni-lj.si"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mf.uni-lj.si/eng/"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mf.uni-lj.si"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Ljubljana, Faculty of Medicine"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Univerza v Ljubljani, Medicinska fakulteta"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for organization University of Ljubljana, Faculty of Medicine"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ponudnik identitet organizacije Univerza v Ljubljani, Medicinska fakulteta"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "287",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "189"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.mf.uni-lj.si/eng/"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.mf.uni-lj.si"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Univerza v Ljubljani Medicinska fakulteta"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Univerza v Ljubljani Medicinska fakulteta"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mf.uni-lj.si/eng/"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mf.uni-lj.si"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Univerza v Ljubljani Medicinska fakulteta"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Univerza v Ljubljani Medicinska fakulteta"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.usask.ca/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hadley"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:edupass_support@usask.ca"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jennifer"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.usask.ca/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2015-08-21T16:46:00Z",
            "registration_authority": "http://www.canarie.ca",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAMXVGogsmqnkwPUYCdxTPbev9l3ZMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDGlkcC51c2Fzay5jYTAeFw0xMDEwMjUyMDU2NTBaFw0z\nMDEwMjUyMDU2NTBaMBcxFTATBgNVBAMTDGlkcC51c2Fzay5jYTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALMSOFuhTJKiB3amc9licNeAGA3vbw/qksAZ\nI90sBiS5F6fmRcqeO4yZRvNqmCPp/By1iTJOf0ryd50P7szRXSBPiwgnCTox4m5k\nTyBciLbqIj4rtLu9ThuADreCV225cilhwwFIPW93ksJYn2gIuPlBV3zNqT27pQIo\nNhVhFNy/RHRKctAWIaH66RForxVkofJ2f3sY3RfEpl7PjZSj35RJaiICNDBcL/9P\nmiYmecit+pl8F64qmMZSr36Lond54RthIey3ai4Q5WMPKgkB/A0kk9hJN366GX/X\nJclXGMKimP4ymqmsyVIGUcu+8vBFHTsNu8Y8Sf/PSExfFzufus8CAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMaWRwLnVzYXNrLmNhhiNodHRwczovL2lkcC51c2Fzay5jYS9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUES778RCyfLDRWvsQSEz4R0JUHUwwDQYJ\nKoZIhvcNAQEFBQADggEBAHs1pJu8e1vHei30xNOnsO+RMx9Ye4AMR9dBmh2QkV5Q\n7UzS1YlA2wr4x3YSnm4IPfOjrQW0brXZjytZWdU9EBfinn4OUUG5RMD/1d/Nu5Zu\nkDm+qt2mCaYoxhdinuUcb6aiJBucpxulZLzByGxTAHXqXqOlh6Y5cJUwlweFHLka\nD0NZ6TrcXo/7QHXhypSrNOAyXrN+ngQ8j6KJXmtjXj601I71upEVWOGaor172aNo\n4OJ1yrQ6k4U6yjjuwrQEAjDCL3WYhrhGCwuu/l/AVw28RWHK5qKgMovdwIeukJfL\nB9WRkjxzB4gF0SyVYl64MQB5UICwuA6q6WLxlmMyWIY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "usask.ca"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.usask.ca:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.usask.ca:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.usask.ca/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.usask.ca/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.usask.ca/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.usask.ca/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.usask.ca:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.usask.ca:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "usask.ca"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.usask.ca/"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAMXVGogsmqnkwPUYCdxTPbev9l3ZMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDGlkcC51c2Fzay5jYTAeFw0xMDEwMjUyMDU2NTBaFw0z\nMDEwMjUyMDU2NTBaMBcxFTATBgNVBAMTDGlkcC51c2Fzay5jYTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALMSOFuhTJKiB3amc9licNeAGA3vbw/qksAZ\nI90sBiS5F6fmRcqeO4yZRvNqmCPp/By1iTJOf0ryd50P7szRXSBPiwgnCTox4m5k\nTyBciLbqIj4rtLu9ThuADreCV225cilhwwFIPW93ksJYn2gIuPlBV3zNqT27pQIo\nNhVhFNy/RHRKctAWIaH66RForxVkofJ2f3sY3RfEpl7PjZSj35RJaiICNDBcL/9P\nmiYmecit+pl8F64qmMZSr36Lond54RthIey3ai4Q5WMPKgkB/A0kk9hJN366GX/X\nJclXGMKimP4ymqmsyVIGUcu+8vBFHTsNu8Y8Sf/PSExfFzufus8CAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMaWRwLnVzYXNrLmNhhiNodHRwczovL2lkcC51c2Fzay5jYS9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUES778RCyfLDRWvsQSEz4R0JUHUwwDQYJ\nKoZIhvcNAQEFBQADggEBAHs1pJu8e1vHei30xNOnsO+RMx9Ye4AMR9dBmh2QkV5Q\n7UzS1YlA2wr4x3YSnm4IPfOjrQW0brXZjytZWdU9EBfinn4OUUG5RMD/1d/Nu5Zu\nkDm+qt2mCaYoxhdinuUcb6aiJBucpxulZLzByGxTAHXqXqOlh6Y5cJUwlweFHLka\nD0NZ6TrcXo/7QHXhypSrNOAyXrN+ngQ8j6KJXmtjXj601I71upEVWOGaor172aNo\n4OJ1yrQ6k4U6yjjuwrQEAjDCL3WYhrhGCwuu/l/AVw28RWHK5qKgMovdwIeukJfL\nB9WRkjxzB4gF0SyVYl64MQB5UICwuA6q6WLxlmMyWIY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Saskatchewan"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.usask.ca/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Saskatchewan"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp02.stfc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:obuservicedesk@rl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OBU Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Akkas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ali.akkas@stfc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ali"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp02.stfc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-06-16T17:51:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFFDCCA/ygAwIBAgIUOysRoBktqggd9zGS+JJEfPcJmKwwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwTTELMAkGA1UEBhMCQk0xGTAXBgNVBAoTEFF1b1ZhZGlzIExpbWl0ZWQxIzAh\n\t\t\t\t\t\tBgNVBAMTGlF1b1ZhZGlzIEdsb2JhbCBTU0wgSUNBIEcyMB4XDTE2MDQwNTEyNDUz\n\t\t\t\t\t\tNVoXDTE5MDQwNTEyNDUzM1owgZsxCzAJBgNVBAYTAkdCMRIwEAYDVQQIEwlXaWx0\n\t\t\t\t\t\tc2hpcmUxEDAOBgNVBAcTB1NXSU5ET04xMjAwBgNVBAoTKVNjaWVuY2UgYW5kIFRl\n\t\t\t\t\t\tY2hub2xvZ3kgRmFjaWxpdGllcyBDb3VuY2lsMRAwDgYDVQQLEwdSQUwtQ1NEMSAw\n\t\t\t\t\t\tHgYDVQQDExdzaGliYm9sZXRoMDIuc3RmYy5hYy51azCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBAMvR27pSvNdN412CLQs9mwht4/x7X7GFyo95R7M2ebA8\n\t\t\t\t\t\tNiWWpeO1a39mQAy0aA3jgI3dLM7FkvTAAe3PwjGG1ONoNzXkdF2ys+C4jf9Tgsl7\n\t\t\t\t\t\tgrv50GeFEckUUrvzgaMyZHZZmOwX9oc6AQCPw57f2UHv58LWYivz1Mmvp2JmnUiu\n\t\t\t\t\t\tUX574cgLN/KnRMTWl4sWvU3nwY+ZurTI8pj2B6Zj28hlPFbl6lNqd8jlT1j3+O1o\n\t\t\t\t\t\t+7ubSVvRV5rYy2CWxjGYDxEnm+dAoR7si3XxubiWXe4KIBwvbE9ZQMMjQ3d3cw5T\n\t\t\t\t\t\tlQwv9S9UQGEfNmDLZnRhzOit8KPqDk/p3Lc29mp/9nMCAwEAAaOCAZswggGXMHMG\n\t\t\t\t\t\tCCsGAQUFBwEBBGcwZTAqBggrBgEFBQcwAYYeaHR0cDovL29jc3AucXVvdmFkaXNn\n\t\t\t\t\t\tbG9iYWwuY29tMDcGCCsGAQUFBzAChitodHRwOi8vdHJ1c3QucXVvdmFkaXNnbG9i\n\t\t\t\t\t\tYWwuY29tL3F2c3NsZzIuY3J0MCIGA1UdEQQbMBmCF3NoaWJib2xldGgwMi5zdGZj\n\t\t\t\t\t\tLmFjLnVrMFEGA1UdIARKMEgwRgYMKwYBBAG+WAACZAEBMDYwNAYIKwYBBQUHAgEW\n\t\t\t\t\t\tKGh0dHA6Ly93d3cucXVvdmFkaXNnbG9iYWwuY29tL3JlcG9zaXRvcnkwDgYDVR0P\n\t\t\t\t\t\tAQH/BAQDAgWgMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAfBgNVHSME\n\t\t\t\t\t\tGDAWgBSRGWKtWxenMPvw3jklsb2MubhRJzA6BgNVHR8EMzAxMC+gLaArhilodHRw\n\t\t\t\t\t\tOi8vY3JsLnF1b3ZhZGlzZ2xvYmFsLmNvbS9xdnNzbGcyLmNybDAdBgNVHQ4EFgQU\n\t\t\t\t\t\tbJMoUGiBSfBEYv7zyHqX1fXLSkcwDQYJKoZIhvcNAQELBQADggEBAL1K6/RF+FdG\n\t\t\t\t\t\t0xpK1XVOvFsihV5P4OLXk9qhHh+CnKfDfqbJZTvppj1or7bi0D4GyIZQRqF19z4n\n\t\t\t\t\t\tdPB9ckfJF9YvyfR7uobHUJBm644hsxa5DTAMug0nHnDnHN/ueE0fBc8Vr2N0adZV\n\t\t\t\t\t\trlVcGRjXiBVPxfTk637ZIXShW+8923IIU/eECYc7Vvpe7giXfRF9SbFtAZ9/Rdjm\n\t\t\t\t\t\tYWMVdt0nBLwXSCdh4IIKHHnu4qq6Z0/RpWmA6iL/Y/hJzQAohoU/K7jGqPOMm9wF\n\t\t\t\t\t\tggRFV+FROzADdEtB2psKL+LrWhSGhRewqazW7eYB8Y9JGN1UnsE6NWyVru1LMYte\n\t\t\t\t\t\tIklcmjJ+40A="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stfc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth02.stfc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth02.stfc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth02.stfc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth02.stfc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth02.stfc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth02.stfc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth02.stfc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth02.stfc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stfc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFFDCCA/ygAwIBAgIUOysRoBktqggd9zGS+JJEfPcJmKwwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwTTELMAkGA1UEBhMCQk0xGTAXBgNVBAoTEFF1b1ZhZGlzIExpbWl0ZWQxIzAh\n\t\t\t\t\t\tBgNVBAMTGlF1b1ZhZGlzIEdsb2JhbCBTU0wgSUNBIEcyMB4XDTE2MDQwNTEyNDUz\n\t\t\t\t\t\tNVoXDTE5MDQwNTEyNDUzM1owgZsxCzAJBgNVBAYTAkdCMRIwEAYDVQQIEwlXaWx0\n\t\t\t\t\t\tc2hpcmUxEDAOBgNVBAcTB1NXSU5ET04xMjAwBgNVBAoTKVNjaWVuY2UgYW5kIFRl\n\t\t\t\t\t\tY2hub2xvZ3kgRmFjaWxpdGllcyBDb3VuY2lsMRAwDgYDVQQLEwdSQUwtQ1NEMSAw\n\t\t\t\t\t\tHgYDVQQDExdzaGliYm9sZXRoMDIuc3RmYy5hYy51azCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBAMvR27pSvNdN412CLQs9mwht4/x7X7GFyo95R7M2ebA8\n\t\t\t\t\t\tNiWWpeO1a39mQAy0aA3jgI3dLM7FkvTAAe3PwjGG1ONoNzXkdF2ys+C4jf9Tgsl7\n\t\t\t\t\t\tgrv50GeFEckUUrvzgaMyZHZZmOwX9oc6AQCPw57f2UHv58LWYivz1Mmvp2JmnUiu\n\t\t\t\t\t\tUX574cgLN/KnRMTWl4sWvU3nwY+ZurTI8pj2B6Zj28hlPFbl6lNqd8jlT1j3+O1o\n\t\t\t\t\t\t+7ubSVvRV5rYy2CWxjGYDxEnm+dAoR7si3XxubiWXe4KIBwvbE9ZQMMjQ3d3cw5T\n\t\t\t\t\t\tlQwv9S9UQGEfNmDLZnRhzOit8KPqDk/p3Lc29mp/9nMCAwEAAaOCAZswggGXMHMG\n\t\t\t\t\t\tCCsGAQUFBwEBBGcwZTAqBggrBgEFBQcwAYYeaHR0cDovL29jc3AucXVvdmFkaXNn\n\t\t\t\t\t\tbG9iYWwuY29tMDcGCCsGAQUFBzAChitodHRwOi8vdHJ1c3QucXVvdmFkaXNnbG9i\n\t\t\t\t\t\tYWwuY29tL3F2c3NsZzIuY3J0MCIGA1UdEQQbMBmCF3NoaWJib2xldGgwMi5zdGZj\n\t\t\t\t\t\tLmFjLnVrMFEGA1UdIARKMEgwRgYMKwYBBAG+WAACZAEBMDYwNAYIKwYBBQUHAgEW\n\t\t\t\t\t\tKGh0dHA6Ly93d3cucXVvdmFkaXNnbG9iYWwuY29tL3JlcG9zaXRvcnkwDgYDVR0P\n\t\t\t\t\t\tAQH/BAQDAgWgMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAfBgNVHSME\n\t\t\t\t\t\tGDAWgBSRGWKtWxenMPvw3jklsb2MubhRJzA6BgNVHR8EMzAxMC+gLaArhilodHRw\n\t\t\t\t\t\tOi8vY3JsLnF1b3ZhZGlzZ2xvYmFsLmNvbS9xdnNzbGcyLmNybDAdBgNVHQ4EFgQU\n\t\t\t\t\t\tbJMoUGiBSfBEYv7zyHqX1fXLSkcwDQYJKoZIhvcNAQELBQADggEBAL1K6/RF+FdG\n\t\t\t\t\t\t0xpK1XVOvFsihV5P4OLXk9qhHh+CnKfDfqbJZTvppj1or7bi0D4GyIZQRqF19z4n\n\t\t\t\t\t\tdPB9ckfJF9YvyfR7uobHUJBm644hsxa5DTAMug0nHnDnHN/ueE0fBc8Vr2N0adZV\n\t\t\t\t\t\trlVcGRjXiBVPxfTk637ZIXShW+8923IIU/eECYc7Vvpe7giXfRF9SbFtAZ9/Rdjm\n\t\t\t\t\t\tYWMVdt0nBLwXSCdh4IIKHHnu4qq6Z0/RpWmA6iL/Y/hJzQAohoU/K7jGqPOMm9wF\n\t\t\t\t\t\tggRFV+FROzADdEtB2psKL+LrWhSGhRewqazW7eYB8Y9JGN1UnsE6NWyVru1LMYte\n\t\t\t\t\t\tIklcmjJ+40A="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Science and Technology Facilities Council (2nd IdP)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.scitech.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Science and Technology Facilities Council"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.highwire.org/entity/oupacademic",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.highwire.org/entity/oupacademic",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-01-16T18:36:18Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Stanford University: Oxford Medicine"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oxfordmedicine.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HighWire Press, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.highwire.org/applications/oupacademic/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.highwire.org/applications/oupacademic/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIJAMTRVlqTJ11lMA0GCSqGSIb3DQEBBQUAMIG+MQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBD\n\t\t\t\t\t\taXR5MRcwFQYDVQQKEw5IaWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUx\n\t\t\t\t\t\tIDAeBgNVBAMTF3NoaWJib2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkB\n\t\t\t\t\t\tFiZzaGliYm9sZXRoLWFkbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTAeFw0xNDA0\n\t\t\t\t\t\tMTUxOTQzMDNaFw0yNDA0MTIxOTQzMDNaMIG+MQswCQYDVQQGEwJVUzETMBEGA1UE\n\t\t\t\t\t\tCBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBDaXR5MRcwFQYDVQQKEw5I\n\t\t\t\t\t\taWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUxIDAeBgNVBAMTF3NoaWJi\n\t\t\t\t\t\tb2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkBFiZzaGliYm9sZXRoLWFk\n\t\t\t\t\t\tbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALPB99M9iWjentrddY/rLgzKn1X0j4Ao191iyiowBBt/r/pmn2oz\n\t\t\t\t\t\tfrbONkkTVBB++mNtiufK6jyKnBM5mffPOkXHRo+K1DQec7TvpQ1PmLv/BpBgPrr9\n\t\t\t\t\t\tldViOSUnYJuB0IgJVV8oylgeH2Ay0XRkNPlBUjBA2fUPWVpXcvFe+aD2tLdVR9uO\n\t\t\t\t\t\tXvfTMxAEGqzxTU+OxO6pW2sBXNBmGvZQ0TRyovQh5+pTURY/lm0V/iWvRmRe51WE\n\t\t\t\t\t\tO/nhYyvRuMmNj8EL38o10S9TXuCkVzY00hK5cclaFge7gz/tfjmadVVcbe8xCVxc\n\t\t\t\t\t\tnb1lhmt1kH2XtKvU5hyZMTO+VUfXQvqcQyECAwEAAaN7MHkwCQYDVR0TBAIwADAs\n\t\t\t\t\t\tBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYD\n\t\t\t\t\t\tVR0OBBYEFJpUZq/XaW9/bPvjffkxX0IDvuPiMB8GA1UdIwQYMBaAFJpUZq/XaW9/\n\t\t\t\t\t\tbPvjffkxX0IDvuPiMA0GCSqGSIb3DQEBBQUAA4IBAQCq/FF56ZB1cL3KbniEJP99\n\t\t\t\t\t\tU9wTD6KpOrWxvqNbUSV1cefLf5cYHonOjy6oAJSSBSNuP7U5Q//0tXtkvlJoqGUY\n\t\t\t\t\t\tvqngmeg9wLZ/Fla3tXcDdTj0n1F+NZOx9vBDacIk0Ua4aHXDA4bdytzkV1QyZDRq\n\t\t\t\t\t\tQ8vq7RoQ8E5IF7Cll+kt2dZXQk8o6Qp3w2ppoMRtYdKOQassqn+V1MYcMPgdxZkS\n\t\t\t\t\t\tDrcgzktR/JMb5OmPrp4mSy1OWDGrFvUIigsLBPZV9tw1f7y42lnbmQas3RCS30yr\n\t\t\t\t\t\tCtUPT/PQDkCdBRViGmmMkYwjdaOTiHOJveWtrVXu8vLvO36pqFF4Kft0pgqlfvAE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.highwire.org/applications/oupacademic/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.highwire.org/applications/oupacademic/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.highwire.org/applications/oupacademic/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.highwire.org/applications/oupacademic/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp-cafe.unir.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fabio Leite Dias"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "fabioleite@unir.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-cafe.unir.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKDCCAxACAQAwDQYJKoZIhvcNAQEFBQAwgdkxMTAvBgNVBAoUKFVOSVIgLSBV\nbml2ZXJzaWRhZGUgRmVkZXJhbCBkZSBSb25kw7RuaWExNjA0BgNVBAsULURUSSAt\nIERpcmV0b3JpYSBkZSBUZWNub2xvZ2lhIGRhIEluZm9ybWHDp8OjbzEaMBgGCSqG\nSIb3DQEJARYLZHRpQHVuaXIuYnIxFDASBgNVBAcTC1BvcnRvIFZlbGhvMRIwEAYD\nVQQIFAlSb25kw7RuaWExCzAJBgNVBAYTAkJSMRkwFwYDVQQDExBpZHAtY2FmZS51\nbmlyLmJyMB4XDTE0MDgyMDEyMDgxOFoXDTE3MDgxOTEyMDgxOFowgdkxMTAvBgNV\nBAoUKFVOSVIgLSBVbml2ZXJzaWRhZGUgRmVkZXJhbCBkZSBSb25kw7RuaWExNjA0\nBgNVBAsULURUSSAtIERpcmV0b3JpYSBkZSBUZWNub2xvZ2lhIGRhIEluZm9ybWHD\np8OjbzEaMBgGCSqGSIb3DQEJARYLZHRpQHVuaXIuYnIxFDASBgNVBAcTC1BvcnRv\nIFZlbGhvMRIwEAYDVQQIFAlSb25kw7RuaWExCzAJBgNVBAYTAkJSMRkwFwYDVQQD\nExBpZHAtY2FmZS51bmlyLmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAsm9YPz01gnftklbFm5tNLpQHVXbLIlku3xGMIxL+8HNJaFV30ZNme68r/Pq9\nJa10EPKSogvdIY5TPI52OC5rEH7hGMpUKkogcv2Yhq2rIrjZaOf8fML5hyW0/DYm\njaLiWrpXgmesepXu4TfwxiZ/aJTjXYQhO2LFkP+/ybj5ANuuFj6kk6z98x+zUn/X\n/xHPrS+sXz+NRusK/EMi2y7PJ1d0l2V4t4Zr/T1EQqQJOR1DvKmcKgZ84I6WPk9M\no1o/m/OOyCuz1q1+TESJ9nuyAOK19Vch7Qh1lIt/kTrM2Ac/Gi9XAuhCLeDbUTxG\nsWdppd2oOgnVcbKNSzvuEuCD0QIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQB3QvGv\n7r93VG+qdmZFkw+6mtkJ6m9dEDmzVf4rzR1Pyra/CmLYQ1S31aVqNXf1IVr+egFV\nDWoxNX1BIHK9lZpcZugnl3i4FQ/fwl7RFwVrYri7cJx4XUL3pT+PVQk8XkarnJ6q\nWhISOtn2v/OKrrVgiwcNcUqdX9kn6YJK+PQWDE7y3lul+0L1SbJQGL8VkQ3zJnnD\n3zPFjycxg3Gu4KLvWlq7ZCkxsw7+DBjGXlXCs2JR188YRl6Oz+LKMkKIucnTQGB9\n/GOiJLIQ0IwVq5i5OTyUaEvXEiDopznRsqPTwbdgFFl9qS8Ilf+nCgmy/E+CBv93\nS/VP03ihbZgT9/Pt"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unir.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-cafe.unir.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-cafe.unir.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-cafe.unir.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-cafe.unir.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-cafe.unir.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-cafe.unir.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-cafe.unir.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-cafe.unir.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unir.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unir.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unir.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNIR - Universidade Federal de Rondonia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNIR - Universidade Federal de Rondonia"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNIR - Universidade Federal de Rondonia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNIR - Universidade Federal de Rondonia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKDCCAxACAQAwDQYJKoZIhvcNAQEFBQAwgdkxMTAvBgNVBAoUKFVOSVIgLSBV\nbml2ZXJzaWRhZGUgRmVkZXJhbCBkZSBSb25kw7RuaWExNjA0BgNVBAsULURUSSAt\nIERpcmV0b3JpYSBkZSBUZWNub2xvZ2lhIGRhIEluZm9ybWHDp8OjbzEaMBgGCSqG\nSIb3DQEJARYLZHRpQHVuaXIuYnIxFDASBgNVBAcTC1BvcnRvIFZlbGhvMRIwEAYD\nVQQIFAlSb25kw7RuaWExCzAJBgNVBAYTAkJSMRkwFwYDVQQDExBpZHAtY2FmZS51\nbmlyLmJyMB4XDTE0MDgyMDEyMDgxOFoXDTE3MDgxOTEyMDgxOFowgdkxMTAvBgNV\nBAoUKFVOSVIgLSBVbml2ZXJzaWRhZGUgRmVkZXJhbCBkZSBSb25kw7RuaWExNjA0\nBgNVBAsULURUSSAtIERpcmV0b3JpYSBkZSBUZWNub2xvZ2lhIGRhIEluZm9ybWHD\np8OjbzEaMBgGCSqGSIb3DQEJARYLZHRpQHVuaXIuYnIxFDASBgNVBAcTC1BvcnRv\nIFZlbGhvMRIwEAYDVQQIFAlSb25kw7RuaWExCzAJBgNVBAYTAkJSMRkwFwYDVQQD\nExBpZHAtY2FmZS51bmlyLmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAsm9YPz01gnftklbFm5tNLpQHVXbLIlku3xGMIxL+8HNJaFV30ZNme68r/Pq9\nJa10EPKSogvdIY5TPI52OC5rEH7hGMpUKkogcv2Yhq2rIrjZaOf8fML5hyW0/DYm\njaLiWrpXgmesepXu4TfwxiZ/aJTjXYQhO2LFkP+/ybj5ANuuFj6kk6z98x+zUn/X\n/xHPrS+sXz+NRusK/EMi2y7PJ1d0l2V4t4Zr/T1EQqQJOR1DvKmcKgZ84I6WPk9M\no1o/m/OOyCuz1q1+TESJ9nuyAOK19Vch7Qh1lIt/kTrM2Ac/Gi9XAuhCLeDbUTxG\nsWdppd2oOgnVcbKNSzvuEuCD0QIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQB3QvGv\n7r93VG+qdmZFkw+6mtkJ6m9dEDmzVf4rzR1Pyra/CmLYQ1S31aVqNXf1IVr+egFV\nDWoxNX1BIHK9lZpcZugnl3i4FQ/fwl7RFwVrYri7cJx4XUL3pT+PVQk8XkarnJ6q\nWhISOtn2v/OKrrVgiwcNcUqdX9kn6YJK+PQWDE7y3lul+0L1SbJQGL8VkQ3zJnnD\n3zPFjycxg3Gu4KLvWlq7ZCkxsw7+DBjGXlXCs2JR188YRl6Oz+LKMkKIucnTQGB9\n/GOiJLIQ0IwVq5i5OTyUaEvXEiDopznRsqPTwbdgFFl9qS8Ilf+nCgmy/E+CBv93\nS/VP03ihbZgT9/Pt"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNIR - Universidade Federal de Rondonia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNIR - Universidade Federal de Rondonia"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unir.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unir.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNIR - Universidade Federal de Rondonia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNIR - Universidade Federal de Rondonia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.hebis.de/uni-frankfurt",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Doerrer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:a.doerrer@ub.uni-frankfurt.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Axel"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Doerrer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:a.doerrer@ub.uni-frankfurt.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Axel"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.hebis.de/uni-frankfurt",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2014-08-11T07:07:20Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.ub.uni-frankfurt.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGNzCCBR+gAwIBAgIHGFx3pTtgCDANBgkqhkiG9w0BAQsFADCBoTELMAkGA1UE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\nbRTKhSFui7ClOO0="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.ub.uni-frankfurt.de,OU=Hochschulrechenzentrum,O=Johann Wolfgang Goethe-Universitaet Frankfurt am Main,L=Frankfurt am Main,ST=Hessen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uni-frankfurt.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ub.uni-frankfurt.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ub.uni-frankfurt.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ub.uni-frankfurt.de/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ub.uni-frankfurt.de/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ub.uni-frankfurt.de:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ub.uni-frankfurt.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ub.uni-frankfurt.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ub.uni-frankfurt.de/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ub.uni-frankfurt.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ub.uni-frankfurt.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ub.uni-frankfurt.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uni-frankfurt.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uni-frankfurt.de/de?locale=de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uni-frankfurt.de/en?locale=en"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider der Johann Wolfgang Goethe Universit\u00e4t Frankfurt am Main"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider of the Johann Wolfgang Goethe Universit\u00e4t Frankfurt am Main"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e4t Frankfurt"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e4t Frankfurt"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.ub.uni-frankfurt.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGNzCCBR+gAwIBAgIHGFx3pTtgCDANBgkqhkiG9w0BAQsFADCBoTELMAkGA1UE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\nbRTKhSFui7ClOO0="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.ub.uni-frankfurt.de,OU=Hochschulrechenzentrum,O=Johann Wolfgang Goethe-Universitaet Frankfurt am Main,L=Frankfurt am Main,ST=Hessen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Johann Wolfgang Goethe-Universit\u00e4t Frankfurt am Main"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Johann Wolfgang Goethe-Universit\u00e4t Frankfurt am Main"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-frankfurt.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-frankfurt.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e35"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e35"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp-test.lancs.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:iss-service-desk@lancaster.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ISS Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bennett"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:S.Bennett@lancaster.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-test.lancs.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-12-06T09:32:03Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUYU6NkvsQbpPZ0YcuNXj04ufIkuUwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAxMUaWRwLXRlc3QubGFuY3MuYWMudWswHhcNMTMwMjIyMTA0\n\t\t\t\t\t\tMDQ5WhcNMzMwMjIyMTA0MDQ5WjAfMR0wGwYDVQQDExRpZHAtdGVzdC5sYW5jcy5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIYOZJi8AQIEug05\n\t\t\t\t\t\tw+DVk2VhVCZJU2o4JVj70tGyXnj1CEMAwZGjFKmPTX8YtDv3e4eHwjk2AgX3rcKy\n\t\t\t\t\t\tOhr5sD0vaAdHdY51aq2P8QQ+8zTZSP4CNML2fMtrbCNzDj+L/KPA9Tnm3iXStDqd\n\t\t\t\t\t\tbKiEn7Sc+DgPKPe4o3oz00pymHGMuL2MHMnCUqyOE+vtF6YQzAFei81IUCVeiF/p\n\t\t\t\t\t\tjtKqtDvTHST4LNcSslqDaVA90zRv/QynXaUnsr6WYwEoBefGBzSBWpn6rYG6jFgu\n\t\t\t\t\t\tT6stqf0q3CpziDw6cxKrnl6HR9bRDFnYFElg0/g8Al7jcPB/lAkLmGU3GILG8mcq\n\t\t\t\t\t\tdax/4YsCAwEAAaNvMG0wTAYDVR0RBEUwQ4IUaWRwLXRlc3QubGFuY3MuYWMudWuG\n\t\t\t\t\t\tK2h0dHBzOi8vaWRwLXRlc3QubGFuY3MuYWMudWsvaWRwL3NoaWJib2xldGgwHQYD\n\t\t\t\t\t\tVR0OBBYEFOcwlLDv1eWSzgWtwDtw8slIuiKQMA0GCSqGSIb3DQEBBQUAA4IBAQAB\n\t\t\t\t\t\tC0NMk4y8FnYX9JrWYhp8XQcPc/q0ezkF3w3gUtHNEVllAmUSiNaGapkJcufMMNtk\n\t\t\t\t\t\teM1za6BnrhPrNeXJlOzc8P6ZyT8HSOPx/oIoKY+UuLyAfLk0FZM3KkHobSiLO+K6\n\t\t\t\t\t\t4B7u30Q93XTgelXKnViqTC1XW/QptiH2n3uyBh1ojrrkUTqZZDLit+54JZpG6qVo\n\t\t\t\t\t\tcxQedBTTZehgVYUnS3FidiJwSg+aUQUf0ubVzooYOkhCtr+C9C8W8dxj1O4Tj+68\n\t\t\t\t\t\t6DVOmoLSq0nR7CUO5lFWaSTpD0w/xOBwVYMAZGlUJH5fnF5qyisYIKNYAgBtPMYO\n\t\t\t\t\t\tpaN4cH6RgjoaIKmzc9qC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lancaster.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-test.lancs.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-test.lancs.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-test.lancs.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-test.lancs.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-test.lancs.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-test.lancs.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-test.lancs.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-test.lancs.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lancaster.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUYU6NkvsQbpPZ0YcuNXj04ufIkuUwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAxMUaWRwLXRlc3QubGFuY3MuYWMudWswHhcNMTMwMjIyMTA0\n\t\t\t\t\t\tMDQ5WhcNMzMwMjIyMTA0MDQ5WjAfMR0wGwYDVQQDExRpZHAtdGVzdC5sYW5jcy5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIYOZJi8AQIEug05\n\t\t\t\t\t\tw+DVk2VhVCZJU2o4JVj70tGyXnj1CEMAwZGjFKmPTX8YtDv3e4eHwjk2AgX3rcKy\n\t\t\t\t\t\tOhr5sD0vaAdHdY51aq2P8QQ+8zTZSP4CNML2fMtrbCNzDj+L/KPA9Tnm3iXStDqd\n\t\t\t\t\t\tbKiEn7Sc+DgPKPe4o3oz00pymHGMuL2MHMnCUqyOE+vtF6YQzAFei81IUCVeiF/p\n\t\t\t\t\t\tjtKqtDvTHST4LNcSslqDaVA90zRv/QynXaUnsr6WYwEoBefGBzSBWpn6rYG6jFgu\n\t\t\t\t\t\tT6stqf0q3CpziDw6cxKrnl6HR9bRDFnYFElg0/g8Al7jcPB/lAkLmGU3GILG8mcq\n\t\t\t\t\t\tdax/4YsCAwEAAaNvMG0wTAYDVR0RBEUwQ4IUaWRwLXRlc3QubGFuY3MuYWMudWuG\n\t\t\t\t\t\tK2h0dHBzOi8vaWRwLXRlc3QubGFuY3MuYWMudWsvaWRwL3NoaWJib2xldGgwHQYD\n\t\t\t\t\t\tVR0OBBYEFOcwlLDv1eWSzgWtwDtw8slIuiKQMA0GCSqGSIb3DQEBBQUAA4IBAQAB\n\t\t\t\t\t\tC0NMk4y8FnYX9JrWYhp8XQcPc/q0ezkF3w3gUtHNEVllAmUSiNaGapkJcufMMNtk\n\t\t\t\t\t\teM1za6BnrhPrNeXJlOzc8P6ZyT8HSOPx/oIoKY+UuLyAfLk0FZM3KkHobSiLO+K6\n\t\t\t\t\t\t4B7u30Q93XTgelXKnViqTC1XW/QptiH2n3uyBh1ojrrkUTqZZDLit+54JZpG6qVo\n\t\t\t\t\t\tcxQedBTTZehgVYUnS3FidiJwSg+aUQUf0ubVzooYOkhCtr+C9C8W8dxj1O4Tj+68\n\t\t\t\t\t\t6DVOmoLSq0nR7CUO5lFWaSTpD0w/xOBwVYMAZGlUJH5fnF5qyisYIKNYAgBtPMYO\n\t\t\t\t\t\tpaN4cH6RgjoaIKmzc9qC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lancaster University (Test IdP)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lancaster.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Lancaster"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://federation.u-pem.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "adm-federation@u-pem.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federation.u-pem.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-05-19T12:09:19Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.u-pem.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federation.u-pem.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://federation.u-pem.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "etud.u-pem.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "u-pem.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "umlv.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-mlv.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-mlv.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Every university member"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Tous les membres de l'universit\u00e9"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Paris-Est Marne-la-Vall\u00e9e University"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 Paris-Est Marne-la-Vall\u00e9e"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAM2PTKt1TV1kFUzpXmOV0ZzH5/RrMA0GCSqGSIb3DQEB\nBQUAMB4xHDAaBgNVBAMTE2ZlZGVyYXRpb24udS1wZW0uZnIwHhcNMTQwNTE5MTAw\nNzU0WhcNMzQwNTE5MTAwNzU0WjAeMRwwGgYDVQQDExNmZWRlcmF0aW9uLnUtcGVt\nLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0t2Ou0usGY1JzkfP\n1fqEphJbvG9dCqmyAy3aWE1udBLfjDtjLLjfHfIafRLkm2OVLwjI/5nbY6krNTXk\nnZNO0L8LJuOLImqfMluR75jWUWAJQsXrbJ+hOmsmt2nDfVGIRvkO8E59+vnsOZW4\nmYn+S1qbOxfy+FCff4zrqP6vij73UffoFYwrxg07q8jQP9Dhie/6nRKQtoXfDRwu\nhN7KJVuwBAT8OB1to1td7ETcFHrV3TBdCiykYQONpIQcbc3BJDHjSndn5TZtwmBr\nKoWVe7+FAdoASTriJPUgPSapdnsJS31nQaKwOPxcfqzobysb3FHRZ3c9e+k9s2lj\npl1qwQIDAQABo20wazBKBgNVHREEQzBBghNmZWRlcmF0aW9uLnUtcGVtLmZyhipo\ndHRwczovL2ZlZGVyYXRpb24udS1wZW0uZnIvaWRwL3NoaWJib2xldGgwHQYDVR0O\nBBYEFKsWCrm5woMmq5whBpJxFE7z3oSdMA0GCSqGSIb3DQEBBQUAA4IBAQA0yHMD\neBNRPmppFMlR71VZ+30TVxMBE6asRnn/69Ni/cYRxr+7EEVUgMzzxJfT2gwtkocg\nYkZR6nCR+KJmfk3KwR6CFfKV/eLuVA883x8j7tqY4YHmHn7RInFdibHwF6Ka58P7\nzwdoCWFvLZjFjaAWERxqGGjIZex/3FhxtgKEN4rWtUqlRNwhCMJP2ee4BIY84dTK\nrw154uC2Ng7lchO5gbMyUTxxVWX0K/oqpKW4nvpbsj2kkZI5rFSt5FRC/kVwkWJK\n9UTDRWo5w/HbzA8JVAnU0vwax0/E2nDrYSu1pbGOb0F97H+UBSWBMaBqZHoJLkEi\nwDJ2bH/IB8MKNLHT"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 Paris-Est Marne-la-Vall\u00e9e"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-mlv.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 Paris-Est Marne-la-Vall\u00e9e"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ekt.gr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "National Documentation Centre NOC"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@ekt.gr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ekt.gr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.ekt.gr"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEizCCA3OgAwIBAgIQb1SWwkDV328A41lusr2JKzANBgkqhkiG9w0BAQUFADA2\n                            MQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n                            U1NMIENBMB4XDTA5MTEwOTAwMDAwMFoXDTEyMTEwODIzNTk1OVowbDELMAkGA1UE\n                            BhMCR1IxJjAkBgNVBAoTHU5hdGlvbmFsIERvY3VtZW50YXRpb24gQ2VudHJlMSAw\n                            HgYDVQQLExdJbmZvcm1hdGlvbiBTeXN0ZW1zIERwdDETMBEGA1UEAxMKaWRwLmVr\n                            dC5ncjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK6Wn8EfealHFYNP\n                            YsHwvpH8mdSGI9MEXS+NLBsWpI6tS3DiqA/Z1QCxYaA7jB18Sb8gC00VOeuwdO9p\n                            xLblVLi9kciz0XuVyHLA1n6XgxXARGE15m+o21Vj50US8LmW3X44E0WXnh6QqiAN\n                            w1EJCCGk6nuqCe/Uy/Jc2je2GNrbnVIAUcLxKDIp0Sca62uIc5rXGSKkrNbFJw1+\n                            jIYOZTKlfwSiY5iDeN8gTKijpPVt/5iwyiAejZiNjBURVHa/hl4/h04RFZn3LowG\n                            Tp2ije0yz0Qh7ZfFRauIi326oI9JdQDtR3x0S+w2X1IbaUODWnOS2whapglxhic0\n                            gaC0rcUCAwEAAaOCAV0wggFZMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdXR+qQ\n                            47ntMB0GA1UdDgQWBBQG37V9qM5AYApDpVPtb+z6G0Z8RzAOBgNVHQ8BAf8EBAMC\n                            BaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIw\n                            GAYDVR0gBBEwDzANBgsrBgEEAbIxAQICHTA6BgNVHR8EMzAxMC+gLaArhilodHRw\n                            Oi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcB\n                            AQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVS\n                            RU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5h\n                            Lm9yZzAVBgNVHREEDjAMggppZHAuZWt0LmdyMA0GCSqGSIb3DQEBBQUAA4IBAQBX\n                            onl6/uH2I669/xvf0mS/SSAWV7HemtNb5MEm6ObMakarTs7Zz/Lr/Y815kKCbY3/\n                            yckJmCqm5hVrczJREw9/y9IF421qaWq9fA1mUfWgNNh1t9Lc7yw6TzgiHJsaUQyM\n                            1qz6BQsNNctdBtiDXx2It1Z6kG3ImLZdPsTIs+CuwVtIrbpR8yTuvRF/PVFg0WSS\n                            fB7jhjdgJoQvPbSxSuA2N9fbZewG9m0x8WBN+up4AIhR9pBPG//4qD7a6qlpasS5\n                            ivmIXUACm7ISQ8obzJ6mm2QPGWHgl4/XHpMouNjrI9piCuoU7PxPf4wESiiH/qbT\n                            KdYmP9TqxG7mvPfMZHTx"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ekt.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ekt.gr:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ekt.gr:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ekt.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ekt.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ekt.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ekt.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ekt.gr:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ekt.gr:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ekt.gr"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ekt.gr/"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ekt.gr/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "National Documentation Centre"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u0395\u03b8\u03bd\u03b9\u03ba\u03cc \u039a\u03ad\u03bd\u03c4\u03c1\u03bf \u03a4\u03b5\u03ba\u03bc\u03b7\u03c1\u03af\u03c9\u03c3\u03b7\u03c2"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "194.177.214.0/24"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:37.973263,23.745396"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.ekt.gr"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEizCCA3OgAwIBAgIQb1SWwkDV328A41lusr2JKzANBgkqhkiG9w0BAQUFADA2\n                            MQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n                            U1NMIENBMB4XDTA5MTEwOTAwMDAwMFoXDTEyMTEwODIzNTk1OVowbDELMAkGA1UE\n                            BhMCR1IxJjAkBgNVBAoTHU5hdGlvbmFsIERvY3VtZW50YXRpb24gQ2VudHJlMSAw\n                            HgYDVQQLExdJbmZvcm1hdGlvbiBTeXN0ZW1zIERwdDETMBEGA1UEAxMKaWRwLmVr\n                            dC5ncjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK6Wn8EfealHFYNP\n                            YsHwvpH8mdSGI9MEXS+NLBsWpI6tS3DiqA/Z1QCxYaA7jB18Sb8gC00VOeuwdO9p\n                            xLblVLi9kciz0XuVyHLA1n6XgxXARGE15m+o21Vj50US8LmW3X44E0WXnh6QqiAN\n                            w1EJCCGk6nuqCe/Uy/Jc2je2GNrbnVIAUcLxKDIp0Sca62uIc5rXGSKkrNbFJw1+\n                            jIYOZTKlfwSiY5iDeN8gTKijpPVt/5iwyiAejZiNjBURVHa/hl4/h04RFZn3LowG\n                            Tp2ije0yz0Qh7ZfFRauIi326oI9JdQDtR3x0S+w2X1IbaUODWnOS2whapglxhic0\n                            gaC0rcUCAwEAAaOCAV0wggFZMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdXR+qQ\n                            47ntMB0GA1UdDgQWBBQG37V9qM5AYApDpVPtb+z6G0Z8RzAOBgNVHQ8BAf8EBAMC\n                            BaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIw\n                            GAYDVR0gBBEwDzANBgsrBgEEAbIxAQICHTA6BgNVHR8EMzAxMC+gLaArhilodHRw\n                            Oi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcB\n                            AQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVS\n                            RU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5h\n                            Lm9yZzAVBgNVHREEDjAMggppZHAuZWt0LmdyMA0GCSqGSIb3DQEBBQUAA4IBAQBX\n                            onl6/uH2I669/xvf0mS/SSAWV7HemtNb5MEm6ObMakarTs7Zz/Lr/Y815kKCbY3/\n                            yckJmCqm5hVrczJREw9/y9IF421qaWq9fA1mUfWgNNh1t9Lc7yw6TzgiHJsaUQyM\n                            1qz6BQsNNctdBtiDXx2It1Z6kG3ImLZdPsTIs+CuwVtIrbpR8yTuvRF/PVFg0WSS\n                            fB7jhjdgJoQvPbSxSuA2N9fbZewG9m0x8WBN+up4AIhR9pBPG//4qD7a6qlpasS5\n                            ivmIXUACm7ISQ8obzJ6mm2QPGWHgl4/XHpMouNjrI9piCuoU7PxPf4wESiiH/qbT\n                            KdYmP9TqxG7mvPfMZHTx"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "National Documentation Centre"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u0395\u03b8\u03bd\u03b9\u03ba\u03cc \u039a\u03ad\u03bd\u03c4\u03c1\u03bf \u03a4\u03b5\u03ba\u03bc\u03b7\u03c1\u03af\u03c9\u03c3\u03b7\u03c2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ekt.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ekt.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National Documentation Centre"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u0395\u03b8\u03bd\u03b9\u03ba\u03cc \u039a\u03ad\u03bd\u03c4\u03c1\u03bf \u03a4\u03b5\u03ba\u03bc\u03b7\u03c1\u03af\u03c9\u03c3\u03b7\u03c2"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:ucsd.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "acthelp@ucsd.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ACT Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibsupport@ucsd.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth/IDM Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:ucsd.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://a4.ucsd.edu:8443/tritON/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://a4.ucsd.edu:8443/tritON/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFjzCCBHegAwIBAgICAQwwDQYJKoZIhvcNAQEFBQAwVjELMAkGA1UEBhMCVVMx\nHDAaBgNVBAoTE0luQ29tbW9uIEZlZGVyYXRpb24xKTAnBgNVBAMTIEluQ29tbW9u\nIENlcnRpZmljYXRpb24gQXV0aG9yaXR5MB4XDTA4MDIyODIxMTg0NFoXDTEwMDIy\nODIxMTg0NFowFjEUMBIGA1UEAxMLYTQudWNzZC5lZHUwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQDcEzH+KYmuGSDjlZeaOJc8VJS0/bRBjfE6HHDV9nN8\nghEm5AMS5OPx/ruM+5gchwuryogOMY7abSe3BpvVT/3A+fjKSNnklMPmQUuO6AqW\n7a6/w9w30tl/2OzG3u1sGAr1FkEXf/DmJOtXpAOhPAmyYb6o41k+ZwpvnRuyaoup\nIC1R5LLU2jCnnZCxBF6gvDlvmpaEO2c2aHrKJIaqxDuVhTDJRWp+IkcT8Jy4JAwv\n0R1w8FJXLyZ0RVeNL8v3ZcCzInfxsS1/+FuOOHitZ18WO4Ds5PJ5tEzree95EGe+\nU9dpjMrJQDdKiqPE18K7cQGuHfVkIMkU4phuyUXWKk09AgMBAAGjggKlMIICoTAO\nBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcD\nAQYIKwYBBQUHAwIwHQYDVR0OBBYEFPe85gpJxg5DPieEeNZF9FHWbW0rMH4GA1Ud\nIwR3MHWAFJMtyGEYrWPjm2Wznd2Nk7rnymNFoVqkWDBWMQswCQYDVQQGEwJVUzEc\nMBoGA1UEChMTSW5Db21tb24gRmVkZXJhdGlvbjEpMCcGA1UEAxMgSW5Db21tb24g\nQ2VydGlmaWNhdGlvbiBBdXRob3JpdHmCAQAwgboGCCsGAQUFBwEBBIGtMIGqMIGn\nBggrBgEFBQcwAoaBmmh0dHA6Ly9pbmNvbW1vbmNhMS5pbmNvbW1vbmZlZGVyYXRp\nb24ub3JnL2JyaWRnZS9jZXJ0cy9jYS1jZXJ0cy5wN2IKCQlDQSBJc3N1ZXJzIC0g\nVVJJOmh0dHA6Ly9pbmNvbW1vbmNhMi5pbmNvbW1vbmZlZGVyYXRpb24ub3JnL2Jy\naWRnZS9jZXJ0cy9jYS1jZXJ0cy5wN2IwgY0GA1UdHwSBhTCBgjA/oD2gO4Y5aHR0\ncDovL2luY29tbW9uY3JsMS5pbmNvbW1vbmZlZGVyYXRpb24ub3JnL2NybC9lZWNy\nbHMuY3JsMD+gPaA7hjlodHRwOi8vaW5jb21tb25jcmwyLmluY29tbW9uZmVkZXJh\ndGlvbi5vcmcvY3JsL2VlY3Jscy5jcmwwXgYDVR0gBFcwVTBTBgsrBgEEAa4jAQQB\nATBEMEIGCCsGAQUFBwIBFjZodHRwOi8vaW5jb21tb25jYS5pbmNvbW1vbmZlZGVy\nYXRpb24ub3JnL3ByYWN0aWNlcy5wZGYwFgYDVR0RBA8wDYILYTQudWNzZC5lZHUw\nDQYJKoZIhvcNAQEFBQADggEBAJeIDxI87H9yjtD8BLdiwEBsyKiADqL4jo2EeF9Z\nkz6GA89zEUXaL6M+UeWaHwrpbKbpR7JYb87qJhFYzCBBdLjUpHnvHI1M1/wl44XF\n/W8PpcuDF5vZmVDxYmKEJQJHnvRqOU08vIvk5bpgcI8ctNXUDWh9uEdtKMrg3+Tk\ngKCmAXAl9I6SOrnEy98RJ7yWL51qXHaWE5xXl9dTCh43JONZWlsah0smeDYkYhZq\n7g+zU6RW3i/LigqVYW84V0+WH30htKco5uwr0SGoL9u8PGbYPgrRtCJIo5r8eE7N\nR1kv+lykb9hrz1KUyDvLTDhWQ7l4bXDaP7/dIpaTrtd0zC4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJjCCAg6gAwIBAgIJAPn3wXbFGjOZMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC2E0LnVjc2QuZWR1MB4XDTEwMDQwODIyNDcwOVoXDTIwMDQwNTIyNDcwOVow\nFjEUMBIGA1UEAxMLYTQudWNzZC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQDUEpd4l0/TgMjGp8nyEA3eyMDB001MZIq/u9wjSNsPFoXGudwyRryf\nB+yKk4MTX/VqQ6cMZ1oFjP1h1phl5xWG1PZu2vXpjJuHb5X1J4GCK2u7j5mwN6zK\n/ekTVI4X/0ALe7uPE6ltcKd1XQctZfCe27e+cUdbqz3y16s+RWyUrC2pRK2aJuxm\nhR7rxMwAcpUYBrINqvoGAz7MIBZ2MNwNlMNK2scGBLsdahBG/JZk0PUYiwRxA1aq\nYAEeOsuR6jVhudDOAfTK/XtWneUrO0G0C3fCVmX5MGrUCPIY/cVAbuNBLGYDjg1+\n7iazyImK4nbgXQzBd7QfLayuITY5pludAgMBAAGjdzB1MB0GA1UdDgQWBBTIPcIR\n7y/+BZAKv3XBLkJsAw0l9DBGBgNVHSMEPzA9gBTIPcIR7y/+BZAKv3XBLkJsAw0l\n9KEapBgwFjEUMBIGA1UEAxMLYTQudWNzZC5lZHWCCQD598F2xRozmTAMBgNVHRME\nBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAwB9Fwts/0sEse6XtafnaYxoAukZwS\nCpbUv+LOLgwmFgLCm+eo9kCvbTTS4JZ3Ctz9/yGfRIcNygWsALSeBvpXmNA0gI/V\nCcsFrrllX1SrpIz5yuwHRZcj1WDDvAzqanvjXGT+2BxmjYS7E25XG+eMC0JlzxLV\n4PKbKEVZlfBEoRSZ/8wS2MqtZm2COZ21PRBHyfkxopkKpdqImQksx36nvEj4Ow6H\nua34fsQvpcou9ufs1WPqLRTD6AVU1ZrGFdFFAOFY8mG6BEDEplp0Jpn8knxtc2Cg\nY8R3vksytTmgdqrqYKEpA/CP8EUxyRB3IGOdZ3cJgxabq5X2FBWEFU8y"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucsd.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://a4.ucsd.edu/tritON/HS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://a4.ucsd.edu/tritON/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://a4.ucsd.edu/tritON/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFjzCCBHegAwIBAgICAQwwDQYJKoZIhvcNAQEFBQAwVjELMAkGA1UEBhMCVVMx\nHDAaBgNVBAoTE0luQ29tbW9uIEZlZGVyYXRpb24xKTAnBgNVBAMTIEluQ29tbW9u\nIENlcnRpZmljYXRpb24gQXV0aG9yaXR5MB4XDTA4MDIyODIxMTg0NFoXDTEwMDIy\nODIxMTg0NFowFjEUMBIGA1UEAxMLYTQudWNzZC5lZHUwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQDcEzH+KYmuGSDjlZeaOJc8VJS0/bRBjfE6HHDV9nN8\nghEm5AMS5OPx/ruM+5gchwuryogOMY7abSe3BpvVT/3A+fjKSNnklMPmQUuO6AqW\n7a6/w9w30tl/2OzG3u1sGAr1FkEXf/DmJOtXpAOhPAmyYb6o41k+ZwpvnRuyaoup\nIC1R5LLU2jCnnZCxBF6gvDlvmpaEO2c2aHrKJIaqxDuVhTDJRWp+IkcT8Jy4JAwv\n0R1w8FJXLyZ0RVeNL8v3ZcCzInfxsS1/+FuOOHitZ18WO4Ds5PJ5tEzree95EGe+\nU9dpjMrJQDdKiqPE18K7cQGuHfVkIMkU4phuyUXWKk09AgMBAAGjggKlMIICoTAO\nBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcD\nAQYIKwYBBQUHAwIwHQYDVR0OBBYEFPe85gpJxg5DPieEeNZF9FHWbW0rMH4GA1Ud\nIwR3MHWAFJMtyGEYrWPjm2Wznd2Nk7rnymNFoVqkWDBWMQswCQYDVQQGEwJVUzEc\nMBoGA1UEChMTSW5Db21tb24gRmVkZXJhdGlvbjEpMCcGA1UEAxMgSW5Db21tb24g\nQ2VydGlmaWNhdGlvbiBBdXRob3JpdHmCAQAwgboGCCsGAQUFBwEBBIGtMIGqMIGn\nBggrBgEFBQcwAoaBmmh0dHA6Ly9pbmNvbW1vbmNhMS5pbmNvbW1vbmZlZGVyYXRp\nb24ub3JnL2JyaWRnZS9jZXJ0cy9jYS1jZXJ0cy5wN2IKCQlDQSBJc3N1ZXJzIC0g\nVVJJOmh0dHA6Ly9pbmNvbW1vbmNhMi5pbmNvbW1vbmZlZGVyYXRpb24ub3JnL2Jy\naWRnZS9jZXJ0cy9jYS1jZXJ0cy5wN2IwgY0GA1UdHwSBhTCBgjA/oD2gO4Y5aHR0\ncDovL2luY29tbW9uY3JsMS5pbmNvbW1vbmZlZGVyYXRpb24ub3JnL2NybC9lZWNy\nbHMuY3JsMD+gPaA7hjlodHRwOi8vaW5jb21tb25jcmwyLmluY29tbW9uZmVkZXJh\ndGlvbi5vcmcvY3JsL2VlY3Jscy5jcmwwXgYDVR0gBFcwVTBTBgsrBgEEAa4jAQQB\nATBEMEIGCCsGAQUFBwIBFjZodHRwOi8vaW5jb21tb25jYS5pbmNvbW1vbmZlZGVy\nYXRpb24ub3JnL3ByYWN0aWNlcy5wZGYwFgYDVR0RBA8wDYILYTQudWNzZC5lZHUw\nDQYJKoZIhvcNAQEFBQADggEBAJeIDxI87H9yjtD8BLdiwEBsyKiADqL4jo2EeF9Z\nkz6GA89zEUXaL6M+UeWaHwrpbKbpR7JYb87qJhFYzCBBdLjUpHnvHI1M1/wl44XF\n/W8PpcuDF5vZmVDxYmKEJQJHnvRqOU08vIvk5bpgcI8ctNXUDWh9uEdtKMrg3+Tk\ngKCmAXAl9I6SOrnEy98RJ7yWL51qXHaWE5xXl9dTCh43JONZWlsah0smeDYkYhZq\n7g+zU6RW3i/LigqVYW84V0+WH30htKco5uwr0SGoL9u8PGbYPgrRtCJIo5r8eE7N\nR1kv+lykb9hrz1KUyDvLTDhWQ7l4bXDaP7/dIpaTrtd0zC4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJjCCAg6gAwIBAgIJAPn3wXbFGjOZMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC2E0LnVjc2QuZWR1MB4XDTEwMDQwODIyNDcwOVoXDTIwMDQwNTIyNDcwOVow\nFjEUMBIGA1UEAxMLYTQudWNzZC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQDUEpd4l0/TgMjGp8nyEA3eyMDB001MZIq/u9wjSNsPFoXGudwyRryf\nB+yKk4MTX/VqQ6cMZ1oFjP1h1phl5xWG1PZu2vXpjJuHb5X1J4GCK2u7j5mwN6zK\n/ekTVI4X/0ALe7uPE6ltcKd1XQctZfCe27e+cUdbqz3y16s+RWyUrC2pRK2aJuxm\nhR7rxMwAcpUYBrINqvoGAz7MIBZ2MNwNlMNK2scGBLsdahBG/JZk0PUYiwRxA1aq\nYAEeOsuR6jVhudDOAfTK/XtWneUrO0G0C3fCVmX5MGrUCPIY/cVAbuNBLGYDjg1+\n7iazyImK4nbgXQzBd7QfLayuITY5pludAgMBAAGjdzB1MB0GA1UdDgQWBBTIPcIR\n7y/+BZAKv3XBLkJsAw0l9DBGBgNVHSMEPzA9gBTIPcIR7y/+BZAKv3XBLkJsAw0l\n9KEapBgwFjEUMBIGA1UEAxMLYTQudWNzZC5lZHWCCQD598F2xRozmTAMBgNVHRME\nBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAwB9Fwts/0sEse6XtafnaYxoAukZwS\nCpbUv+LOLgwmFgLCm+eo9kCvbTTS4JZ3Ctz9/yGfRIcNygWsALSeBvpXmNA0gI/V\nCcsFrrllX1SrpIz5yuwHRZcj1WDDvAzqanvjXGT+2BxmjYS7E25XG+eMC0JlzxLV\n4PKbKEVZlfBEoRSZ/8wS2MqtZm2COZ21PRBHyfkxopkKpdqImQksx36nvEj4Ow6H\nua34fsQvpcou9ufs1WPqLRTD6AVU1ZrGFdFFAOFY8mG6BEDEplp0Jpn8knxtc2Cg\nY8R3vksytTmgdqrqYKEpA/CP8EUxyRB3IGOdZ3cJgxabq5X2FBWEFU8y"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucsd.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of California-San Diego"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of California-San Diego"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ucsd.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of California-San Diego"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ccn.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ccn.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/ccn.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/ccn.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ccn.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "City College Norwich"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ccn.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://app.goodpractice.net",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ferguson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:oferguson@goodpractice.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Owen"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Anderson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:janderson@goodpractice.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jonny"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://app.goodpractice.net",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-11-11T10:58:54Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GoodPractice Ltd"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.goodpractice.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Good Practice Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIJAPkZY/RifCMCMA0GCSqGSIb3DQEBCwUAMA8xDTALBgNV\n\t\t\t\t\t\tBAMTBHRlc3QwHhcNMTQxMTEyMTEwMTM1WhcNMjQxMTA5MTEwMTM1WjAPMQ0wCwYD\n\t\t\t\t\t\tVQQDEwR0ZXN0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAwbnYcv3B\n\t\t\t\t\t\tIHH5O1Nu9aOw7IgjsYrzTFGmx/R/Lgbyh03t34FkAQ9SZ4ToKHRI7wJuHN2SveV2\n\t\t\t\t\t\tLBjZ8PgoM7Nzkryl2fpF6sytuqMhKFzdSEbHEXMn1GqKCQoQGno5jzZAtcyqxXrF\n\t\t\t\t\t\tiK5WrwSuPbopgGzu9UyPfaxaqmYVN0BW50z3NlKEZoQsc8w5WR9r1GDLNTSG0Jqx\n\t\t\t\t\t\tsCpzRktkdKAsjskRiqp0X/gFquBEwajyWqF08PGsfwW0iqISc+bCmD1IWGZCQLcy\n\t\t\t\t\t\t7eanVD3w13oFNPmqmxZSIiNNSXP5Gb7jcBZ+xWORwnIGOTBeThIPEWOlO4Kr7dDC\n\t\t\t\t\t\t2fm1YW1OiJwRPQIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1P\n\t\t\t\t\t\tcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUwN4Ob3oWtiCr\n\t\t\t\t\t\tFwqrickuFNGD/e8wHwYDVR0jBBgwFoAUwN4Ob3oWtiCrFwqrickuFNGD/e8wDQYJ\n\t\t\t\t\t\tKoZIhvcNAQELBQADggEBAEOVm9crJjxi8CPsqJZEfV4ZnO4IlDyEFt3zNpKyamsC\n\t\t\t\t\t\t01KFXkldoUhg1YNjLkpueysSyCpYrVe3BgkWdEccPO1GrGWYCYOgT3lf9LQ9hH5z\n\t\t\t\t\t\tKTrkC+vftsNFv8YwWQgrncNscMPldbC6ig0khE2IC3mGJMKR8MgHLJWlNV3txgR5\n\t\t\t\t\t\tRi4pgGB+Ax6on6oQHks4I4EvDti7vtarY62Vuu8K6lJHltPkM6BjmQo2n0qJE9Hd\n\t\t\t\t\t\t4Cp1NN51cLFIhjRA/gurU7ZUJMg84oaEpG+CVQn0ckKLb9JiKajXSh8HvjX5+COk\n\t\t\t\t\t\tGvUxcf3q5ZXwJL6K+o0lrNadM/TN+8gZW441MEjl8Fc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://app.goodpractice.net/security/saml2/response",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "GoodPractice provides relevant leadership and management programmes that improve performance and deliver measurable business change."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "GoodPractice Ltd"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "Email",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "DisplayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "FirstName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "LastName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://esds80.mcc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:international@esds.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ESDS International Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mimas-shib-tech@listserv.manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mimas Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://esds80.mcc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MIMAS New ESDS Server"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.esds.ac.uk/international/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Manchester"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://esds80.mcc.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://esds80.mcc.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://esds80.mcc.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://esds80.mcc.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJAPsrc/dHrh27MA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\n\t\t\t\t\t\tBAMTFWVzZHN3cDAyLmRzLm1hbi5hYy51azAeFw0xMTA0MTQwODMwNTRaFw0yMTA0\n\t\t\t\t\t\tMTEwODMwNTRaMCAxHjAcBgNVBAMTFWVzZHN3cDAyLmRzLm1hbi5hYy51azCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOIW9zW3cx5qTffqwVyTfkIZq9rB\n\t\t\t\t\t\t2hwtpbPPD3pMOVzayJTjjjhFIbqOZ5cClg9KG4Z+fqrE8stkZnkvyyqYskQ1D17A\n\t\t\t\t\t\tVPqzz7pZHXgw3siViaK5+h4Pt6M0KTybcmEYpE25UB6liRoVaS74tUsLnQrbt3Kr\n\t\t\t\t\t\tyJuNjux6u0AJ6iLji2uEzI1VKp6vWNKLLN2kLYcm3b4oHIIetSOkSOnDTFtiWyGT\n\t\t\t\t\t\tMwEg5ocJZVOIW3BDAtylsYVHDKzO+uiTWgQ4pL5oljifBsM8tQloL8jGbFZ1vq/5\n\t\t\t\t\t\t3ZeXKG1NJ/X7/DjZKri7VDdVv7tRzuJdcookpTR61gjWXBkjQOB/znYKesUCAwEA\n\t\t\t\t\t\tAaNDMEEwIAYDVR0RBBkwF4IVZXNkc3dwMDIuZHMubWFuLmFjLnVrMB0GA1UdDgQW\n\t\t\t\t\t\tBBSZAvZof+nlO9BXlVnwD3uiwxovDTANBgkqhkiG9w0BAQUFAAOCAQEAUr7hL/Z9\n\t\t\t\t\t\txBMNAbVWZ1116SclReYyutdoqjMvS9mQjhbAzvERGDC2lnq7773bJvsqQKNB2WDY\n\t\t\t\t\t\tm3bsGaMXLY2XsQcV5SRzYADvvsxarruzzf41u2EIWrORuHZ44r4qSib7fU1rUIKt\n\t\t\t\t\t\tCQQkpXFl5bF861syiHahW874Ps24A2yOTqGLdFpLXXOHYeNd1DppxJ24NQT8Zbv4\n\t\t\t\t\t\tQRsxHJeqy5eD5bAq5w7k2OTTcK+wk9hOh/ZI9M3/Addini0dUUVGZIL4mX0szJ+C\n\t\t\t\t\t\trfxNIEq53mqQ2E3bBjXuEJxt54BJ7aaa2dPvhOq1RTZtKk8fzlkB7kYvLBJne4UB\n\t\t\t\t\t\tgjkwmpPei6RNFQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJAPsrc/dHrh27MA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\n\t\t\t\t\t\tBAMTFWVzZHN3cDAyLmRzLm1hbi5hYy51azAeFw0xMTA0MTQwODMwNTRaFw0yMTA0\n\t\t\t\t\t\tMTEwODMwNTRaMCAxHjAcBgNVBAMTFWVzZHN3cDAyLmRzLm1hbi5hYy51azCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOIW9zW3cx5qTffqwVyTfkIZq9rB\n\t\t\t\t\t\t2hwtpbPPD3pMOVzayJTjjjhFIbqOZ5cClg9KG4Z+fqrE8stkZnkvyyqYskQ1D17A\n\t\t\t\t\t\tVPqzz7pZHXgw3siViaK5+h4Pt6M0KTybcmEYpE25UB6liRoVaS74tUsLnQrbt3Kr\n\t\t\t\t\t\tyJuNjux6u0AJ6iLji2uEzI1VKp6vWNKLLN2kLYcm3b4oHIIetSOkSOnDTFtiWyGT\n\t\t\t\t\t\tMwEg5ocJZVOIW3BDAtylsYVHDKzO+uiTWgQ4pL5oljifBsM8tQloL8jGbFZ1vq/5\n\t\t\t\t\t\t3ZeXKG1NJ/X7/DjZKri7VDdVv7tRzuJdcookpTR61gjWXBkjQOB/znYKesUCAwEA\n\t\t\t\t\t\tAaNDMEEwIAYDVR0RBBkwF4IVZXNkc3dwMDIuZHMubWFuLmFjLnVrMB0GA1UdDgQW\n\t\t\t\t\t\tBBSZAvZof+nlO9BXlVnwD3uiwxovDTANBgkqhkiG9w0BAQUFAAOCAQEAUr7hL/Z9\n\t\t\t\t\t\txBMNAbVWZ1116SclReYyutdoqjMvS9mQjhbAzvERGDC2lnq7773bJvsqQKNB2WDY\n\t\t\t\t\t\tm3bsGaMXLY2XsQcV5SRzYADvvsxarruzzf41u2EIWrORuHZ44r4qSib7fU1rUIKt\n\t\t\t\t\t\tCQQkpXFl5bF861syiHahW874Ps24A2yOTqGLdFpLXXOHYeNd1DppxJ24NQT8Zbv4\n\t\t\t\t\t\tQRsxHJeqy5eD5bAq5w7k2OTTcK+wk9hOh/ZI9M3/Addini0dUUVGZIL4mX0szJ+C\n\t\t\t\t\t\trfxNIEq53mqQ2E3bBjXuEJxt54BJ7aaa2dPvhOq1RTZtKk8fzlkB7kYvLBJne4UB\n\t\t\t\t\t\tgjkwmpPei6RNFQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://esds80.mcc.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://esds80.mcc.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://esds80.mcc.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://esds80.mcc.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://esds80.mcc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://esds80.mcc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://esds80.mcc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://esds80.mcc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://esds80.mcc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://esds80.mcc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://test.abertay.unidesk.ac.uk/tas/public/login/verify",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:is.helpline@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-certs@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Apps Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test.abertay.unidesk.ac.uk/tas/public/login/verify",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-05T13:27:51Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Test Unidesk - Abertay"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID7TCCAtWgAwIBAgIJAPUeIQj7lZ7QMA0GCSqGSIb3DQEBCwUAMFcxIzAhBgNV\n\t\t\t\t\t\tBAMTGnRlc3QuYWJlcnRheS51bmlkZXNrLmFjLnVrMSMwIQYDVQQKExp0ZXN0LmFi\n\t\t\t\t\t\tZXJ0YXkudW5pZGVzay5hYy51azELMAkGA1UEBhMCVUswHhcNMTYwNDAxMTIzNTI0\n\t\t\t\t\t\tWhcNMjYwMzMwMTIzNTI0WjBXMSMwIQYDVQQDExp0ZXN0LmFiZXJ0YXkudW5pZGVz\n\t\t\t\t\t\tay5hYy51azEjMCEGA1UEChMadGVzdC5hYmVydGF5LnVuaWRlc2suYWMudWsxCzAJ\n\t\t\t\t\t\tBgNVBAYTAlVLMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0jHonD5R\n\t\t\t\t\t\tppuiFhtJsgXq/4z/rPdkJItKFdE9PlTjTHHBtpPolHTgVRRspCneX6CTdFVtGG8z\n\t\t\t\t\t\t25gdnmfs2ykUxyk1nzSzFJLV4tBKM1mOgYeZXYrcAXrppfkZARFybooj3zZn6XNi\n\t\t\t\t\t\t77vPuWiKWQBUAMAeTNxt1+CGWQXYA0c/quHwIyiWnAyzKM8FiN5JOQrJ4cFszE3U\n\t\t\t\t\t\tuhGannOO0RDv5bI2YWxEAx7IYFSGVm68Kwl/C6lQ1fcUoTqsGS/3YQEQGDdCG9cU\n\t\t\t\t\t\t4yALCA5f7Mj/PmFtnK3e0Y6MCVnNtWH/7958eMAVv4RgrqmQuPRbiCox+HeaK1aK\n\t\t\t\t\t\tiiWq9DuF3QS4BQIDAQABo4G7MIG4MB0GA1UdDgQWBBT7z4eRV9C/3pmldtooNQTp\n\t\t\t\t\t\tyu2oVzCBiAYDVR0jBIGAMH6AFPvPh5FX0L/emaV22ig1BOnK7ahXoVukWTBXMSMw\n\t\t\t\t\t\tIQYDVQQDExp0ZXN0LmFiZXJ0YXkudW5pZGVzay5hYy51azEjMCEGA1UEChMadGVz\n\t\t\t\t\t\tdC5hYmVydGF5LnVuaWRlc2suYWMudWsxCzAJBgNVBAYTAlVLggkA9R4hCPuVntAw\n\t\t\t\t\t\tDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAQEAVqr3p35sr70RxxlCdqKl\n\t\t\t\t\t\t1/qZJHd5G+I4TUJBXLZVXS9z8yXZoGQeHiRkrIm2++sVen2iBXG87CKfHvuFfqH2\n\t\t\t\t\t\tDtxuSSxw0EOPAzY9uYBMkzbtuos4LxflATngm5B943+++DYQoLTbs98sWLhFjgOC\n\t\t\t\t\t\tcNXXa//18LXVQ/Y21QuRQctu4UbdGrP5qWtKsjCmmv/XVH8/J52tf0xf/uygp0Ip\n\t\t\t\t\t\tkPOD+P7yHonb3slyoqg2k45mvpCFVkKreWvd20Hi4kqPhEKFYs4X6QCsMRlH7KMN\n\t\t\t\t\t\t1mSmbpr5sfg/lzDP6EYvvDdUPL4Nu5rkd3wYN+3s82k8xYFDgG+fKO2x9EUwmtQ7\n\t\t\t\t\t\tJA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID7TCCAtWgAwIBAgIJAPUeIQj7lZ7QMA0GCSqGSIb3DQEBCwUAMFcxIzAhBgNV\n\t\t\t\t\t\tBAMTGnRlc3QuYWJlcnRheS51bmlkZXNrLmFjLnVrMSMwIQYDVQQKExp0ZXN0LmFi\n\t\t\t\t\t\tZXJ0YXkudW5pZGVzay5hYy51azELMAkGA1UEBhMCVUswHhcNMTYwNDAxMTIzNTI0\n\t\t\t\t\t\tWhcNMjYwMzMwMTIzNTI0WjBXMSMwIQYDVQQDExp0ZXN0LmFiZXJ0YXkudW5pZGVz\n\t\t\t\t\t\tay5hYy51azEjMCEGA1UEChMadGVzdC5hYmVydGF5LnVuaWRlc2suYWMudWsxCzAJ\n\t\t\t\t\t\tBgNVBAYTAlVLMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0jHonD5R\n\t\t\t\t\t\tppuiFhtJsgXq/4z/rPdkJItKFdE9PlTjTHHBtpPolHTgVRRspCneX6CTdFVtGG8z\n\t\t\t\t\t\t25gdnmfs2ykUxyk1nzSzFJLV4tBKM1mOgYeZXYrcAXrppfkZARFybooj3zZn6XNi\n\t\t\t\t\t\t77vPuWiKWQBUAMAeTNxt1+CGWQXYA0c/quHwIyiWnAyzKM8FiN5JOQrJ4cFszE3U\n\t\t\t\t\t\tuhGannOO0RDv5bI2YWxEAx7IYFSGVm68Kwl/C6lQ1fcUoTqsGS/3YQEQGDdCG9cU\n\t\t\t\t\t\t4yALCA5f7Mj/PmFtnK3e0Y6MCVnNtWH/7958eMAVv4RgrqmQuPRbiCox+HeaK1aK\n\t\t\t\t\t\tiiWq9DuF3QS4BQIDAQABo4G7MIG4MB0GA1UdDgQWBBT7z4eRV9C/3pmldtooNQTp\n\t\t\t\t\t\tyu2oVzCBiAYDVR0jBIGAMH6AFPvPh5FX0L/emaV22ig1BOnK7ahXoVukWTBXMSMw\n\t\t\t\t\t\tIQYDVQQDExp0ZXN0LmFiZXJ0YXkudW5pZGVzay5hYy51azEjMCEGA1UEChMadGVz\n\t\t\t\t\t\tdC5hYmVydGF5LnVuaWRlc2suYWMudWsxCzAJBgNVBAYTAlVLggkA9R4hCPuVntAw\n\t\t\t\t\t\tDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAQEAVqr3p35sr70RxxlCdqKl\n\t\t\t\t\t\t1/qZJHd5G+I4TUJBXLZVXS9z8yXZoGQeHiRkrIm2++sVen2iBXG87CKfHvuFfqH2\n\t\t\t\t\t\tDtxuSSxw0EOPAzY9uYBMkzbtuos4LxflATngm5B943+++DYQoLTbs98sWLhFjgOC\n\t\t\t\t\t\tcNXXa//18LXVQ/Y21QuRQctu4UbdGrP5qWtKsjCmmv/XVH8/J52tf0xf/uygp0Ip\n\t\t\t\t\t\tkPOD+P7yHonb3slyoqg2k45mvpCFVkKreWvd20Hi4kqPhEKFYs4X6QCsMRlH7KMN\n\t\t\t\t\t\t1mSmbpr5sfg/lzDP6EYvvDdUPL4Nu5rkd3wYN+3s82k8xYFDgG+fKO2x9EUwmtQ7\n\t\t\t\t\t\tJA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.abertay.unidesk.ac.uk/tas/public/login/verify",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://aktivering.db.umu.se/shibboleth",
    {
      "entity_id": "https://aktivering.db.umu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aktivering.db.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aktivering.db.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aktivering.db.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://aktivering.db.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aktivering.db.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://aktivering.db.umu.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFgTCCBGmgAwIBAgIRANpx25pROOar5rDRfsK004UwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0wOTEyMTcwMDAwMDBaFw0xMjEyMTYyMzU5NTlaMFcxCzAJBgNV\nBAYTAlNFMRkwFwYDVQQKExBVbWVhIHVuaXZlcnNpdGV0MQ4wDAYDVQQLEwVVTURB\nQzEdMBsGA1UEAxMUYWt0aXZlcmluZy5kYi51bXUuc2UwggIiMA0GCSqGSIb3DQEB\nAQUAA4ICDwAwggIKAoICAQCi3/sGq/G/+3Q0NF5XHCyXt2A1Pf1bFc6/GTJpqZoZ\n4w6Z4qZukm/m2sg9lZt4eXGzff4J3LYfISl9YNY21qyNNx89vyGmZwreFhTKBgKM\n8HndtqQkhk/469mpVbP6nkYlqB1Yo1z4dknQY0W15/EwwdqoGSi/1RhaN5HeaGHi\nzOaEmOY8USvDg2a9C8eDFEJwr46E9R0aW3Qtanb610FYly7yZw1zq9GZGSfIcuhD\nXjBzUhgx0S+wnzp0t4g1xZa+hNbSuAb+orcy6N/Qf8G/v3TN9Deyy5QszTDh0DfM\npKgqKlxvFToRLDUxYgMwJhCQqMyQ6su2RL/lqyt4sktczCt4n6k0/PR75TygrC3A\nXNQyGbSOKyTWii5ZTnJpsDhfgzmmS1wvfceMAQhCaEHIOmytrfEKnBhN++RDzzow\nBes5LX9V+c34UnmbWLYuoRZSgXuDf+uo1M5D4wY/iLMfV8hrR3fxohugeICI5zHr\ndshPHf+1sGkR0GW5FZojA3MCqnvx2JXD/uzRZlklCpdvm7piaWpSUOTuozaiUvQf\nyLGFFhnoEpbABoJSCFSCQO2k2AZkAReA0tYhbYVe+mnxWZsOZRcLaQTMl6l/0uQ5\nSIVjC5S4JcDrHnHSbMLk2OIiiEFa515Maa/hNkS6MwyXKNpwpmJxB9W4rQ3MpQCI\n7wIDAQABo4IBZzCCAWMwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH6pDjue0w\nHQYDVR0OBBYEFPA2Tckr7sjvWayvY68aF7n0jY4+MA4GA1UdDwEB/wQEAwIFoDAM\nBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAYBgNV\nHSAEETAPMA0GCysGAQQBsjEBAgIdMDoGA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9j\ncmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEw\nXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3MudGVyZW5hLm9yZy9URVJFTkFT\nU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9vY3NwLnRjcy50ZXJlbmEub3Jn\nMB8GA1UdEQQYMBaCFGFrdGl2ZXJpbmcuZGIudW11LnNlMA0GCSqGSIb3DQEBBQUA\nA4IBAQAS33vefF1HZRklXjJfPwwvpFjYN/jp1+HS9yyMxV6xy7KDl9999sdAXv7y\nNzksZxOLrI220LX6vkDno7nHrRDCoJyaD4M8kBfrQFylrlm2Z2+JPFI9HxyQiwNO\n+jfje4/ZjJ5FCGQFS1fJfKS/z/h00HPxRrarCo9JbDx8n628swrUiWeu09ooRan4\n7e0pFS37NOHjDiX4xar/5ZftQdsnz/5M322LhhlMLUU7TPdB9neJnn8QxeSaLDsr\nLBQ+1+ysE+ryWjMO23qmJzxA8uVHHuiD30S2XHSsfL1clX20G2Zb5YAM6h/lZnGS\n9NeFIiSev3CzfBT/GlsNx0aGwTd/"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFgTCCBGmgAwIBAgIRANpx25pROOar5rDRfsK004UwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0wOTEyMTcwMDAwMDBaFw0xMjEyMTYyMzU5NTlaMFcxCzAJBgNV\nBAYTAlNFMRkwFwYDVQQKExBVbWVhIHVuaXZlcnNpdGV0MQ4wDAYDVQQLEwVVTURB\nQzEdMBsGA1UEAxMUYWt0aXZlcmluZy5kYi51bXUuc2UwggIiMA0GCSqGSIb3DQEB\nAQUAA4ICDwAwggIKAoICAQCi3/sGq/G/+3Q0NF5XHCyXt2A1Pf1bFc6/GTJpqZoZ\n4w6Z4qZukm/m2sg9lZt4eXGzff4J3LYfISl9YNY21qyNNx89vyGmZwreFhTKBgKM\n8HndtqQkhk/469mpVbP6nkYlqB1Yo1z4dknQY0W15/EwwdqoGSi/1RhaN5HeaGHi\nzOaEmOY8USvDg2a9C8eDFEJwr46E9R0aW3Qtanb610FYly7yZw1zq9GZGSfIcuhD\nXjBzUhgx0S+wnzp0t4g1xZa+hNbSuAb+orcy6N/Qf8G/v3TN9Deyy5QszTDh0DfM\npKgqKlxvFToRLDUxYgMwJhCQqMyQ6su2RL/lqyt4sktczCt4n6k0/PR75TygrC3A\nXNQyGbSOKyTWii5ZTnJpsDhfgzmmS1wvfceMAQhCaEHIOmytrfEKnBhN++RDzzow\nBes5LX9V+c34UnmbWLYuoRZSgXuDf+uo1M5D4wY/iLMfV8hrR3fxohugeICI5zHr\ndshPHf+1sGkR0GW5FZojA3MCqnvx2JXD/uzRZlklCpdvm7piaWpSUOTuozaiUvQf\nyLGFFhnoEpbABoJSCFSCQO2k2AZkAReA0tYhbYVe+mnxWZsOZRcLaQTMl6l/0uQ5\nSIVjC5S4JcDrHnHSbMLk2OIiiEFa515Maa/hNkS6MwyXKNpwpmJxB9W4rQ3MpQCI\n7wIDAQABo4IBZzCCAWMwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH6pDjue0w\nHQYDVR0OBBYEFPA2Tckr7sjvWayvY68aF7n0jY4+MA4GA1UdDwEB/wQEAwIFoDAM\nBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAYBgNV\nHSAEETAPMA0GCysGAQQBsjEBAgIdMDoGA1UdHwQzMDEwL6AtoCuGKWh0dHA6Ly9j\ncmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3JsMG0GCCsGAQUFBwEBBGEw\nXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50Y3MudGVyZW5hLm9yZy9URVJFTkFT\nU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6Ly9vY3NwLnRjcy50ZXJlbmEub3Jn\nMB8GA1UdEQQYMBaCFGFrdGl2ZXJpbmcuZGIudW11LnNlMA0GCSqGSIb3DQEBBQUA\nA4IBAQAS33vefF1HZRklXjJfPwwvpFjYN/jp1+HS9yyMxV6xy7KDl9999sdAXv7y\nNzksZxOLrI220LX6vkDno7nHrRDCoJyaD4M8kBfrQFylrlm2Z2+JPFI9HxyQiwNO\n+jfje4/ZjJ5FCGQFS1fJfKS/z/h00HPxRrarCo9JbDx8n628swrUiWeu09ooRan4\n7e0pFS37NOHjDiX4xar/5ZftQdsnz/5M322LhhlMLUU7TPdB9neJnn8QxeSaLDsr\nLBQ+1+ysE+ryWjMO23qmJzxA8uVHHuiD30S2XHSsfL1clX20G2Zb5YAM6h/lZnGS\n9NeFIiSev3CzfBT/GlsNx0aGwTd/"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aktivering.db.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aktivering.db.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aktivering.db.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://aktivering.db.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aktivering.db.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aktivering.db.umu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://aktivering.db.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://aktivering.db.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://aktivering.db.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://aktivering.db.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.sssup.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@sssup.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.sssup.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2014-10-08T10:30:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUZ0H4Pz2dfwqiTQgEDudEffWgc8gwDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMaWRwLnNzc3VwLml0MB4XDTEwMDUxMTExMzAyMFoXDTMw\nMDUxMTExMzAyMFowFzEVMBMGA1UEAxMMaWRwLnNzc3VwLml0MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAjmtnry6/PMlG+TnohAUy1szeBK2LtInYyhAV\n62GVLtgRj91lu+Ylv1DoVM/W+/F5qqDivYFepFH/ROaBxYnGIQPN9hbIQWW6y+2u\na4SN8MsC2NF5TGt4hOa558TDXy8AvrN1XWYavVxyZnCFbUG7xnvaksHgn8r+EqXa\n33t3g27DCqr8gZ2mKL4DdqMEqYaWYFvQcsSGFI7R7k2FlpwrkN0XV0J6sJziw7NX\nxMMyPEzSA+hWf9MNPqfSPq+IXyRwJLChGGbKAnVHmNFP0uAi30rNoTWaniHoeHrj\n/QxNpIE+bFarIxmSm03CTCtPUhOUHScz3WHWNp5RF6Af3GnWcwIDAQABo18wXTA8\nBgNVHREENTAzggxpZHAuc3NzdXAuaXSGI2h0dHBzOi8vaWRwLnNzc3VwLml0L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBQBxI1S8NHoUaJu90/HWsDurxXT6zANBgkq\nhkiG9w0BAQUFAAOCAQEAUaTYopotKd4yJbt9MzZJwBS0NBQRrNkADwWSZ6ztfRTf\nPbf5ZaDncxgw5GKdJZVY2VXkdSubhgBd0OPH37ah8iqeMftj7W6R+MVrd8v+Snv6\nRfw6VfKlWgbHOchBj9qVJeXYMlxME7fKrhLcgzEV3xcsv/o5Li3GGBd4H+ybQMI7\neKmkLMLVatoixFReLXPIiqVo79MkEVyVGlrK4dYrOJcJ594hstk9F3vcdY/U42LP\nAewSvVJLiwSwBXI+SE51+MTKSLnFgaysxCtFXAaO/yD62zA24gn7zju09SpRaRug\nO2Tf736AClLCgVeKQWYHIWrtjstpgmVbC1kZC/7hrA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sssup.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sssup.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sssup.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.sssup.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sssup.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.sssup.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sssup.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sssup.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sssup.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sssup.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.sssup.it/idem/idem.en.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.sssup.it/idem/idem.html"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for Scuola Superiore Sant'Anna users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider per gli utenti della Scuola Superiore Sant'Anna"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.sssup.it/idem/privacy.en.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.sssup.it/idem/privacy.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Scuola Superiore Sant'Anna"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Scuola Superiore Sant'Anna"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUZ0H4Pz2dfwqiTQgEDudEffWgc8gwDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMaWRwLnNzc3VwLml0MB4XDTEwMDUxMTExMzAyMFoXDTMw\nMDUxMTExMzAyMFowFzEVMBMGA1UEAxMMaWRwLnNzc3VwLml0MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAjmtnry6/PMlG+TnohAUy1szeBK2LtInYyhAV\n62GVLtgRj91lu+Ylv1DoVM/W+/F5qqDivYFepFH/ROaBxYnGIQPN9hbIQWW6y+2u\na4SN8MsC2NF5TGt4hOa558TDXy8AvrN1XWYavVxyZnCFbUG7xnvaksHgn8r+EqXa\n33t3g27DCqr8gZ2mKL4DdqMEqYaWYFvQcsSGFI7R7k2FlpwrkN0XV0J6sJziw7NX\nxMMyPEzSA+hWf9MNPqfSPq+IXyRwJLChGGbKAnVHmNFP0uAi30rNoTWaniHoeHrj\n/QxNpIE+bFarIxmSm03CTCtPUhOUHScz3WHWNp5RF6Af3GnWcwIDAQABo18wXTA8\nBgNVHREENTAzggxpZHAuc3NzdXAuaXSGI2h0dHBzOi8vaWRwLnNzc3VwLml0L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBQBxI1S8NHoUaJu90/HWsDurxXT6zANBgkq\nhkiG9w0BAQUFAAOCAQEAUaTYopotKd4yJbt9MzZJwBS0NBQRrNkADwWSZ6ztfRTf\nPbf5ZaDncxgw5GKdJZVY2VXkdSubhgBd0OPH37ah8iqeMftj7W6R+MVrd8v+Snv6\nRfw6VfKlWgbHOchBj9qVJeXYMlxME7fKrhLcgzEV3xcsv/o5Li3GGBd4H+ybQMI7\neKmkLMLVatoixFReLXPIiqVo79MkEVyVGlrK4dYrOJcJ594hstk9F3vcdY/U42LP\nAewSvVJLiwSwBXI+SE51+MTKSLnFgaysxCtFXAaO/yD62zA24gn7zju09SpRaRug\nO2Tf736AClLCgVeKQWYHIWrtjstpgmVbC1kZC/7hrA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Scuola Superiore Sant'Anna"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Scuola Superiore Sant'Anna"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.santannaschool.eu"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sssup.it"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Scuola Superiore Sant'Anna di Studi Universitari e di Perfezionamento"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Scuola Superiore Sant'Anna di Studi Universitari e di Perfezionamento"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:cru.fr:federation:univ-valenciennes.fr",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "fed-admin@univ-valenciennes.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:cru.fr:federation:univ-valenciennes.fr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-04-17T13:52:02Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univ-valenciennes.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univ-valenciennes.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.univ-valenciennes.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-valenciennes.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-valenciennes.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Valenciennes"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Valenciennes"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIVAJ08QHO7V9BoMbcBRHL2N0BzYGEIMA0GCSqGSIb3DQEB\nBQUAMCMxITAfBgNVBAMMGGlkcC51bml2LXZhbGVuY2llbm5lcy5mcjAeFw0xNTA4\nMjcxMzU4MDFaFw0zNTA4MjcxMzU4MDFaMCMxITAfBgNVBAMMGGlkcC51bml2LXZh\nbGVuY2llbm5lcy5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMlp\nfwIQN9r7CrX8PbORqQ2zzrzxcFbUlvh4nvXA8qZRScnNiInLff4TG8e+NQoisTbV\ntCHQJWi5YCyvjPN6pdNqYKM03153vOCGXObcmAfhuiz5/9mD+EoWZudaddxYFzYv\nCht2naCb6VH6kR18bgMcuaFdy3fI1xOJhKWkdLmkAcxyYoi9ZDpFV9GsV4MByzZb\nUthMKeCFqSnfuWIV2dN0thn/Uu7aGl+vLKYh5IqcqidMBbLPTIOFk26YF1UNo4CI\nJ7+Rtn8zCN7Tb6yhHGsPSgz22jZkYtk0M3qOOXd+94wyr+RzoTcsIR+aka9HfZI0\nhTKrIONR332e3zyUneECAwEAAaN3MHUwHQYDVR0OBBYEFEpUM/y3cq8LWhJ63YY8\nXcQiZes3MFQGA1UdEQRNMEuCGGlkcC51bml2LXZhbGVuY2llbm5lcy5mcoYvaHR0\ncHM6Ly9pZHAudW5pdi12YWxlbmNpZW5uZXMuZnIvaWRwL3NoaWJib2xldGgwDQYJ\nKoZIhvcNAQEFBQADggEBAC8QdCix58U4JyZVEX30cqHCWvbnQAW23eLFC9Wzzbae\nvU80GchqtO3xUQEwRXOoSms6ZC3eHmFLuMl2NtnTKTDMGbOSBYXDdJa8ks0Xctba\nUHvcFYBCZoeO/ZoeNfA5Q6rs59yf6CGddF1CT0LdSCa3W2tQ1ksz5+/rWoCYXfp2\n/FogjxPkL0v5vK6z7QsEeYhLsKe9uUpHrYdm9UN6iCBLc71g9Zyxh8zNoVleQ9Q2\nKHJkTmG701axl/BxOJwyOYz7dscQr3dvK6BnFxAEAFx3xDvB9xEJnXnsnh0g9xK6\nxSnpvawSYkjwVqPeJcD49c5+suFyql7UIF18xWjCk+c="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSzCCAjOgAwIBAgIUf/+c8ye6SzH67ieu864mtMPYXlswDQYJKoZIhvcNAQEF\nBQAwIzEhMB8GA1UEAxMYaWRwLnVuaXYtdmFsZW5jaWVubmVzLmZyMB4XDTA5MTAx\nMzEzMTA0M1oXDTI5MTAxMzEzMTA0M1owIzEhMB8GA1UEAxMYaWRwLnVuaXYtdmFs\nZW5jaWVubmVzLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAhhYP\nJ3k8hdOdhcye6mC5zPykjAy9JesMuIR/AYr+tWUpeYNbQeVPyMiqQduhBO08Z1Tz\nsRV/hsuIYv3eD5O+DXFn6U+sY63CzxQrIQ1SC+hIMlzdw7yvdnlkBodgZg6J7LjF\nbpJvpwhtFp84cxy0g/s6oUy/CUg4gMWwnsoah+dacay1GSvqOHo1lu9pdptHmK7h\nVGL5DAsw3Mt3Lb5KK9DlLffd6umayoI9f7Gt8Kouxa1HURuiebxRHmDDJXdzNZ94\n6IzRoFE3SUi1z3iGVDv8TDp1XLSUhNdYR8Plm84GHs03F3hIU1MKxEscFTd/U4zs\nhqKfK/mRqE7OvydIRQIDAQABo3cwdTBUBgNVHREETTBLghhpZHAudW5pdi12YWxl\nbmNpZW5uZXMuZnKGL2h0dHBzOi8vaWRwLnVuaXYtdmFsZW5jaWVubmVzLmZyL2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBTNbFHRtwU+XlpYz+rxvTgavdfoJTANBgkq\nhkiG9w0BAQUFAAOCAQEAb+WTNz5aJNRd/eYTsbgcd/zQLxPssQUgIfW35D2l37r5\nuUI/lTvzCS/XGjleZirVlg1I2BcuLyKNXbyc29OYjWXABBZ3pGX4BD3K+/xEMGwN\nXMQWw4ZdDDfU9Q7jqRog9WIuOcTb/7fRthOOdRPxOnUdl+XfpAqcqpYGPnqX+mXk\nVRZHYIjjVYLKY1Ye3jUPg3n4/hldWYSy2TxMlMbudAV01tb5jzz3k4c/AwzA5Q9i\nsch9WHg5TO5d2L1B6b44aMkefP9u+GBNaLZx1B+hb2b6ZCkxHojPHVeUSi1Hpz17\nlHNKGM/S8lXO2ADLPujRZnzHaBVAwxxAlSgX+PHvqw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Valenciennes"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-valenciennes.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Valenciennes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp-demo.proofidcloud.co.uk/portal",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@proofid.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@proofid.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp-demo.proofidcloud.co.uk/portal",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-03-16T15:12:48Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ProofID test portal SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.proofid.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ProofID Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIGAUwSegszMA0GCSqGSIb3DQEBCwUAMEQxCzAJBgNVBAYT\n\t\t\t\t\t\tAkdCMRAwDgYDVQQKEwdQcm9vZklEMSMwIQYDVQQDExpzcC1kZW1vLnByb29maWRj\n\t\t\t\t\t\tbG91ZC5jby51azAeFw0xNTAzMTMwOTMyMTBaFw0yNTAzMTAwOTMyMTBaMEQxCzAJ\n\t\t\t\t\t\tBgNVBAYTAkdCMRAwDgYDVQQKEwdQcm9vZklEMSMwIQYDVQQDExpzcC1kZW1vLnBy\n\t\t\t\t\t\tb29maWRjbG91ZC5jby51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAJbTlE98EWG7xF6dGiiAxoFPLVgwOwN455DGjlRA7T5zir8wTfA798hOpd0lLQHW\n\t\t\t\t\t\to2JgAWcYCQxkvW0tbUz62x/w4WwRuphqX56vENlNO1ujfVLwB8uV1PTz9E2dd2Zk\n\t\t\t\t\t\tldhd34wS7nTm4TDStxo6hjDy7SNJIpjSin5ZUzj6qhchE7yEj8WdNIHfI5n873aQ\n\t\t\t\t\t\tr34lhTeX0bO1SkjUVWZ35h/BZlQxMRxfAIWtRYjtDpCF5FQIuBjLYLGsQdbAuKUy\n\t\t\t\t\t\t22wfInSfKKeCtcvoGU2tiRNP2VlLndh8V9PTn90mb//7QQKTFybmu3Zg9+FMVvV5\n\t\t\t\t\t\tABffqolzoN+Ko6h14bdVk88CAwEAATANBgkqhkiG9w0BAQsFAAOCAQEASJ7zGI7R\n\t\t\t\t\t\tP+hAWaI6pPDQgBwcH0ofsd22b20n7Iy8dMNlmthFHy21B9LHiMijhaKUeRN0A7By\n\t\t\t\t\t\tsEDKCx2S8hDkbc+PtQocpummmjFdi7O7FzuAad12gq+v16xWcfrXePDb25koi3fs\n\t\t\t\t\t\tGvqNNGK5P5ix9ZoxYWuFNwbBfaKCZiUBfF3fKBg0nlx30Y2B5DhhI64FW9XNeVDn\n\t\t\t\t\t\t44cbVreq3j/qmRLvxwZ5NUXFmzR2Zo6Q3aj7Ytr39xVuOXUMmfPH0HbFQ66PKVWv\n\t\t\t\t\t\t52cBGjDQSv4b9b63zX/MGxHASJ2m1jV+CQ+ZAUb1+Ek0lXtfULBHrE9q6XDt5UWQ\n\t\t\t\t\t\tLJfFHRUh/AHvJA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://sso-demo.proofidcloud.co.uk/sp/ACS.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.bangor.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jones"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:c.m.jones@bangor.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Williams"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:matthew.williams@bangor.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matthew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.bangor.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-01-25T14:44:01Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUF2tfR3F/95LsBO8Z7dI/3Od1JrEwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGzEZMBcGA1UEAxMQaWRwLmJhbmdvci5hYy51azAeFw0xMzAxMTYxNjM3NTNa\n\t\t\t\t\t\tFw0zMzAxMTYxNjM3NTNaMBsxGTAXBgNVBAMTEGlkcC5iYW5nb3IuYWMudWswggEi\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDJBQhi8lIehZpcfLy6pzq9+YrE\n\t\t\t\t\t\ts8ECs4yWxQ9zaw8YFq19G1ErjQiP9lr7MVho9zUfl2d0Amo/zXvfU6Uhbc9ZFk3R\n\t\t\t\t\t\tnE8taqdwTya5x8m8vpbzxCw0h2+v8+FneDuPrxRgTajeHGhqm6hSb8XuJyoXQL5h\n\t\t\t\t\t\tlkPaP0aXcGnpehaGJORhFTy7eBxWGOAqEs0FswNVYDo2RjUhlkO2t3YkjVuvdaOU\n\t\t\t\t\t\t4gXKkoC+mpZJNHyz1soHz6gfbPgoDe7tzY+x4riJJPJ83LoEvYLzBR8FeSIbHhLQ\n\t\t\t\t\t\tLmNOk/Y0fKjIqtGFscZ+zm8iRvL/i0fo9p7SnSOH6IOkQAQlV4hGZtjrGi0fAgMB\n\t\t\t\t\t\tAAGjZzBlMEQGA1UdEQQ9MDuCEGlkcC5iYW5nb3IuYWMudWuGJ2h0dHBzOi8vaWRw\n\t\t\t\t\t\tLmJhbmdvci5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU42JN8CxdI3UM\n\t\t\t\t\t\tPnzBlxj2J0DY1AEwDQYJKoZIhvcNAQEFBQADggEBAFq+GsW2kGNchObmYHO6sBFs\n\t\t\t\t\t\tYVXlPEhrw2c/IsnentSOUV+1HJpfBajvdIHvGeCjG2Hwn+iCTW6P7LMDoqaJDxH7\n\t\t\t\t\t\tPhvzJzMk8haPjzOMIZhbRghkg45abX6SDP7AHsCoAkROHz4aVC4EuN+UyNCsxSTC\n\t\t\t\t\t\tKHuE39z3Nw3ENn7zSt0oTeHUy5anfrYDsECbp6NKFcPCeEHHgcRltqssPOcNj84X\n\t\t\t\t\t\tbOwIjKElyD6/LYB0zUAsVYvMHuwP/hpMpwyOk6baedxu7Ij0Rfea+m3yJOWzQkap\n\t\t\t\t\t\tBXv9usAPuXT0WpAXr236FlYZCkMosBJavcYBZVuKlS2JhipYXJyJfcRvFRw7dnI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bangor.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.bangor.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.bangor.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.bangor.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.bangor.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.bangor.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.bangor.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.bangor.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.bangor.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bangor.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://www.bangor.ac.uk/shibboleth-logos/bangor-73x59.png",
                    "height": "73",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "59"
                  },
                  {
                    "text": "https://www.bangor.ac.uk/shibboleth-logos/bangor-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Bangor University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUF2tfR3F/95LsBO8Z7dI/3Od1JrEwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGzEZMBcGA1UEAxMQaWRwLmJhbmdvci5hYy51azAeFw0xMzAxMTYxNjM3NTNa\n\t\t\t\t\t\tFw0zMzAxMTYxNjM3NTNaMBsxGTAXBgNVBAMTEGlkcC5iYW5nb3IuYWMudWswggEi\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDJBQhi8lIehZpcfLy6pzq9+YrE\n\t\t\t\t\t\ts8ECs4yWxQ9zaw8YFq19G1ErjQiP9lr7MVho9zUfl2d0Amo/zXvfU6Uhbc9ZFk3R\n\t\t\t\t\t\tnE8taqdwTya5x8m8vpbzxCw0h2+v8+FneDuPrxRgTajeHGhqm6hSb8XuJyoXQL5h\n\t\t\t\t\t\tlkPaP0aXcGnpehaGJORhFTy7eBxWGOAqEs0FswNVYDo2RjUhlkO2t3YkjVuvdaOU\n\t\t\t\t\t\t4gXKkoC+mpZJNHyz1soHz6gfbPgoDe7tzY+x4riJJPJ83LoEvYLzBR8FeSIbHhLQ\n\t\t\t\t\t\tLmNOk/Y0fKjIqtGFscZ+zm8iRvL/i0fo9p7SnSOH6IOkQAQlV4hGZtjrGi0fAgMB\n\t\t\t\t\t\tAAGjZzBlMEQGA1UdEQQ9MDuCEGlkcC5iYW5nb3IuYWMudWuGJ2h0dHBzOi8vaWRw\n\t\t\t\t\t\tLmJhbmdvci5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU42JN8CxdI3UM\n\t\t\t\t\t\tPnzBlxj2J0DY1AEwDQYJKoZIhvcNAQEFBQADggEBAFq+GsW2kGNchObmYHO6sBFs\n\t\t\t\t\t\tYVXlPEhrw2c/IsnentSOUV+1HJpfBajvdIHvGeCjG2Hwn+iCTW6P7LMDoqaJDxH7\n\t\t\t\t\t\tPhvzJzMk8haPjzOMIZhbRghkg45abX6SDP7AHsCoAkROHz4aVC4EuN+UyNCsxSTC\n\t\t\t\t\t\tKHuE39z3Nw3ENn7zSt0oTeHUy5anfrYDsECbp6NKFcPCeEHHgcRltqssPOcNj84X\n\t\t\t\t\t\tbOwIjKElyD6/LYB0zUAsVYvMHuwP/hpMpwyOk6baedxu7Ij0Rfea+m3yJOWzQkap\n\t\t\t\t\t\tBXv9usAPuXT0WpAXr236FlYZCkMosBJavcYBZVuKlS2JhipYXJyJfcRvFRw7dnI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bangor University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bangor.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Bangor University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.tavistockandportman.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:library@tavi-port.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Andre"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:candre@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.tavistockandportman.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDljCCAn4CCQC25DQCsFybpjANBgkqhkiG9w0BAQUFADCBjDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxDzANBgNVBAgMBkxvbmRvbjEPMA0GA1UEBwwGTG9uZG9uMTMwMQYDVQQKDCpU\n\t\t\t\t\t\tYXZpc3RvY2sgYW5kIFBvcnRtYW4gTkhTIEZvdW5kYXRpb24gVHJ1c3QxJjAkBgNV\n\t\t\t\t\t\tBAMMHWlkcC50YXZpc3RvY2thbmRwb3J0bWFuLmFjLnVrMB4XDTEyMDYyMjA4NDcw\n\t\t\t\t\t\tMFoXDTMyMDYxNzA4NDcwMFowgYwxCzAJBgNVBAYTAkdCMQ8wDQYDVQQIDAZMb25k\n\t\t\t\t\t\tb24xDzANBgNVBAcMBkxvbmRvbjEzMDEGA1UECgwqVGF2aXN0b2NrIGFuZCBQb3J0\n\t\t\t\t\t\tbWFuIE5IUyBGb3VuZGF0aW9uIFRydXN0MSYwJAYDVQQDDB1pZHAudGF2aXN0b2Nr\n\t\t\t\t\t\tYW5kcG9ydG1hbi5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tALaORMj2PIj4Nccnr5Qtz0aeSgHMOff3ExVO/4gX+hDpGampkME22nOfYB6uFT7V\n\t\t\t\t\t\tkoU5pQn1kEenWPdFx6pyDimK9iK7i7Vl5di7L8DYZbPtnRfO7J1ZQI/NpR7ivZdW\n\t\t\t\t\t\t78EkIvx+mweAg0DTSNKbP6FVrTI7b95qwmfaabPECorDwUq8urP5keITNIo+Amcm\n\t\t\t\t\t\txwVECLUYUYtivommlQsY8zfUpuKWRnBnINKL29IWWbRdNLOsR0MMTneOtGlRBOgl\n\t\t\t\t\t\tHeVsd6NRnMNayUrYrVGcxCZCA+G4KLEY7RUy23Xw0zfgGgBg5q9lWuB4eOboHd9b\n\t\t\t\t\t\tLoVSYHQP9syEzbhyV/CXZgsCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAi8ISBQ1z\n\t\t\t\t\t\tHpD7czu+OrPV3379rSOWTAeASEcgY2ugJW1oEOq6sQlH1wD2vpWRp5TY8XvLhmwD\n\t\t\t\t\t\tmd7iBNR+X2wY5VPQsyWbp8DJsG9mKwAkM6XBY2/E56wvo6eobIXmCFtPPEgERyRf\n\t\t\t\t\t\tjILYvxnwb5yNkzabPrBM287pWMt40EZV+HZBNqf95M863bgRl7SDoMzO+SFkkIwJ\n\t\t\t\t\t\tRcJykK333j5BFRLgRgwAUuISKxxKbgvMg8T4nh4jIM+YlYahegLF/GHCw3ZWG2Dk\n\t\t\t\t\t\tU3WmqCxuVXB1U2JfCO/egPOZr1R7tq1+3VMlPmpZMb8pMiLwXqJxU+niwzX8L6Gw\n\t\t\t\t\t\tZmOU0wEwiWOMxw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tavistockandportman.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.tavistockandportman.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.tavistockandportman.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.tavistockandportman.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.tavistockandportman.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.tavistockandportman.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.tavistockandportman.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.tavistockandportman.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.tavistockandportman.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tavistockandportman.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDljCCAn4CCQC25DQCsFybpjANBgkqhkiG9w0BAQUFADCBjDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxDzANBgNVBAgMBkxvbmRvbjEPMA0GA1UEBwwGTG9uZG9uMTMwMQYDVQQKDCpU\n\t\t\t\t\t\tYXZpc3RvY2sgYW5kIFBvcnRtYW4gTkhTIEZvdW5kYXRpb24gVHJ1c3QxJjAkBgNV\n\t\t\t\t\t\tBAMMHWlkcC50YXZpc3RvY2thbmRwb3J0bWFuLmFjLnVrMB4XDTEyMDYyMjA4NDcw\n\t\t\t\t\t\tMFoXDTMyMDYxNzA4NDcwMFowgYwxCzAJBgNVBAYTAkdCMQ8wDQYDVQQIDAZMb25k\n\t\t\t\t\t\tb24xDzANBgNVBAcMBkxvbmRvbjEzMDEGA1UECgwqVGF2aXN0b2NrIGFuZCBQb3J0\n\t\t\t\t\t\tbWFuIE5IUyBGb3VuZGF0aW9uIFRydXN0MSYwJAYDVQQDDB1pZHAudGF2aXN0b2Nr\n\t\t\t\t\t\tYW5kcG9ydG1hbi5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tALaORMj2PIj4Nccnr5Qtz0aeSgHMOff3ExVO/4gX+hDpGampkME22nOfYB6uFT7V\n\t\t\t\t\t\tkoU5pQn1kEenWPdFx6pyDimK9iK7i7Vl5di7L8DYZbPtnRfO7J1ZQI/NpR7ivZdW\n\t\t\t\t\t\t78EkIvx+mweAg0DTSNKbP6FVrTI7b95qwmfaabPECorDwUq8urP5keITNIo+Amcm\n\t\t\t\t\t\txwVECLUYUYtivommlQsY8zfUpuKWRnBnINKL29IWWbRdNLOsR0MMTneOtGlRBOgl\n\t\t\t\t\t\tHeVsd6NRnMNayUrYrVGcxCZCA+G4KLEY7RUy23Xw0zfgGgBg5q9lWuB4eOboHd9b\n\t\t\t\t\t\tLoVSYHQP9syEzbhyV/CXZgsCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAi8ISBQ1z\n\t\t\t\t\t\tHpD7czu+OrPV3379rSOWTAeASEcgY2ugJW1oEOq6sQlH1wD2vpWRp5TY8XvLhmwD\n\t\t\t\t\t\tmd7iBNR+X2wY5VPQsyWbp8DJsG9mKwAkM6XBY2/E56wvo6eobIXmCFtPPEgERyRf\n\t\t\t\t\t\tjILYvxnwb5yNkzabPrBM287pWMt40EZV+HZBNqf95M863bgRl7SDoMzO+SFkkIwJ\n\t\t\t\t\t\tRcJykK333j5BFRLgRgwAUuISKxxKbgvMg8T4nh4jIM+YlYahegLF/GHCw3ZWG2Dk\n\t\t\t\t\t\tU3WmqCxuVXB1U2JfCO/egPOZr1R7tq1+3VMlPmpZMb8pMiLwXqJxU+niwzX8L6Gw\n\t\t\t\t\t\tZmOU0wEwiWOMxw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Tavistock and Portman NHS Foundation Trust"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tavistockandportman.nhs.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Tavistock and Portman NHS Foundation Trust"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://moria.sai.kau.se/simplesaml/module.php/saml/sp/metadata.php/default-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webbteknik@kau.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT-Avdelningen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://moria.sai.kau.se/simplesaml/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://moria.sai.kau.se/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Staging server f\u00f6r www.kau.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Staging server for www.kau.se"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Logga in i Kau Drupal 8 staging server"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Login to Kau Drupal 8 staging server"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://moria.sai.kau.se/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://moria.sai.kau.se/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://moria.sai.kau.se/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://moria.sai.kau.se/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.crous-rennes.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jean-Louis Allier"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jean-louis.allier@crous-rennes.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Michel Gaigeard"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "michel.gaigeard@crous-rennes.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.crous-rennes.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-01-28T15:00:42Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.crous-rennes.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.crous-rennes.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.crous-rennes.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "crous-rennes.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.crous-rennes.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Rennes - Personnels"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Rennes - Personnels"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEdDCCA1ygAwIBAgIRAL5fVabkZawTDxzKI0ESjOYwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xMzEyMDUwMDAwMDBaFw0xNjEyMDQyMzU5NTlaMEExITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEcMBoGA1UEAxMTaWRwLmNyb3Vz\nLXJlbm5lcy5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMToPjIY\nEKGrNIwJhXle5sZXA9vse+uVBEU2CpCHfx7X+sD2RQCPtIrcw0g2CMQqCJV8ZYLM\n3ZQU22KCDsmmaabvs1xvumWRtXMEEB8CTyveGX+qYMYi2M/a4I+Q+LIpBIBaSdcs\nuNj0ICIbdLM0i6g1qEpG6F+uUFziVqIbzgs0lS+P54AeIS6mKe5JddPQXlwPpgd4\nDYkKYeL9++ItnOpoaCg6Jc3j48G9y4+2R1RcTXwxtvCW+2Tpz9cNGH6UC04NdoUk\nVd72lwRqA25wubIU7ZVzRnlpkegMX01u/FoeQack5jmlI8pBHZMaLqB0pNLBeFEK\n6eJxAe5fb1DSV78CAwEAAaOCAXAwggFsMB8GA1UdIwQYMBaAFAy9k2gM896ro0lr\nKzdXR+qQ47ntMB0GA1UdDgQWBBQdYX2QH6UnjgYOd4KnbTh8YmDJrTAOBgNVHQ8B\nAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYB\nBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEwOgYDVR0f\nBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xD\nQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRj\ncy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDov\nL29jc3AudGNzLnRlcmVuYS5vcmcwHgYDVR0RBBcwFYITaWRwLmNyb3VzLXJlbm5l\ncy5mcjANBgkqhkiG9w0BAQUFAAOCAQEAbgsDlas2dzrysn9qqmxmpqXHBGDIoXuq\nGQifopkpEVi51JmrvMl6ztKqyYVXLEdhbv2ZRJmitDyfxtvTvFfFlAU9iJiErVsq\nzbZAATD/8aC8kUoFmuRK6uvzec+chMS5kGlf7AKJSxgPIhTGdBGwllBUof5aE50Q\nBJ1R3SvSeovh8KBplnsI1v9nozPP3Yjc28BdMLs9p5Yeo+6htHVRTsec8SG4GjKQ\nVJWsJn9dlBNT8g9POrU7cyE7qnHs7ErkMFri0sPKSZbwD6vwBjViJ1KU3C9U9B9C\n1uRv0KqVOs4YO9ig3CbOEAszIIxNZvN6p++GOnm771PGXTWTF1DAfw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS Rennes - Personnels"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.crous-rennes.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS Rennes - Personnels"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.rediris.es/sir/ehuidp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sir@rediris.es"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SIR helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.rediris.es/sir/ehuidp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.rediris.es/sir/edugain/SIR_MRPS.pdf"
              }
            ],
            "registration_instant": "2012-10-09T13:08:24Z",
            "registration_authority": "http://www.rediris.es/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "response_location": "http://sir.rediris.es/ehu/saml2/idp/SingleLogoutService.php",
              "location": "http://sir.rediris.es/ehu/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "http://sir.rediris.es/ehu/shib13/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "http://sir.rediris.es/ehu/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Identity Provider of University of the Basque Country"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "El proveedor de identidad de la Universidad del Pa\u00eds Vasco"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EHU - University of the Basque Country"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EHU - Universidad del Pa\u00eds Vasco"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ehu.es"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEeTCCA2GgAwIBAgIQCP9faAGj247/+QVzgpX08zANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDcwMTAwMDAwMFoXDTE2MDYzMDIzNTk1OVowRDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMR8wHQYDVQQDExZzYW1saWRwLnNp\nci5yZWRpcmlzLmVzMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA5tO6\ntYAdozpFMDwS7QH1qm7eECkY05lG1sp14vcVOdyN0mAf8oai+M8dCQ5iyMxD/RaG\noSmhXfHUvJ+0x8Cp/NHYbKr0cXskANcYTI0JFMFypn9Uac62CGxUYZRhHQ/2LxiE\nvzNgKrm2JiXCvOQbWrbg0sZDEsONv2G1Ln3fvOLiSiO1AjWLvOeYFPNgkNy5dxxt\n7ms7mZ0bFth6Cj38BBL0I1RebVnMgAKZWSgICUXDx35nkB+iLtidIykBgz92ZQ5h\nUrVNndP5+lraoMRuIewESSFt+LBYVeUZFTBGlupiUZ/bi7rhtIuhMM8ahaKIstbu\nIgfQBHPqRkkiiKOJawIDAQABo4IBczCCAW8wHwYDVR0jBBgwFoAUDL2TaAzz3quj\nSWsrN1dH6pDjue0wHQYDVR0OBBYEFARoBLDWcsveEZQhaMVIR9mmJkUkMA4GA1Ud\nDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggr\nBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNV\nHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNT\nTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQu\ndGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRw\nOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAhBgNVHREEGjAYghZzYW1saWRwLnNpci5y\nZWRpcmlzLmVzMA0GCSqGSIb3DQEBBQUAA4IBAQB0gmr232YgpUC4HkwAHXaH91Zx\n8ZrwiEc8c4jGLh5VsaO0OqMfUEIXMuqZ+P9JNWVwlc6VLtmsypqTuqb9a06DS88q\n2o5sAUpbXZwhArhQs1bQnu5HJ6S84Ajn+NfMOyaO7NF8Colq/9lf3DihkT0jlD7i\nPHPMw2zauvtR/WPwdPszgfIOV/vkJ0rq9AjOXxSX7V2jpkxISGW/m93iahwXEoVF\nc8VXQhNjEfcm6uawmISjsyp6ta/U3e/8GJka2csDrF/bfipMBDSdWcLMscpYO8cb\nDC0L6vehZJ+lPz3wPH6YJmlstICZUdJIgDV3TUhmji6NNKa4p6by34QdYcDH"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EHU - Universidad del Pa\u00eds Vasco"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EHU - University of the Basque Country"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rediris.es/index.php.en"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rediris.es/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "EHU"
          },
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "EHU"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibtest.informit.com.au/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@rmitpublishing.com.au"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Informit Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Crowther"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dominic.crowther@rmit.edu.au"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dominic"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pham"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dominic.crowther@rmit.edu.au"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Loan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibtest.informit.com.au/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-11-18T09:01:07Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Informit"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.informit.com.au/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RMIT Training Pty Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibtest.informit.com.au/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibtest.informit.com.au/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibtest.informit.com.au/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibtest.informit.com.au/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibtest.informit.com.au/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibtest.informit.com.au/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibtest.informit.com.au/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibtest.informit.com.au/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibtest.informit.com.au/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibtest.informit.com.au/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibtest.informit.com.au/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibtest.informit.com.au/Shibboleth.sso/TESTtestDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://shibtest.informit.com.au/Shibboleth.sso/TESTtestDS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Informit is the premier source of core research and resources from the Australasian region."
                  }
                ],
                "logo": [
                  {
                    "text": "https://search.informit.com.au/images-v4/logo-informit.gif",
                    "height": "43",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "136"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Informit"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIJANAW6lqADfvcMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHNoaWJ0ZXN0LmluZm9ybWl0LmNvbS5hdTAeFw0xMjEwMDgwMzIxMjBaFw0y\n\t\t\t\t\t\tMjEwMDYwMzIxMjBaMCMxITAfBgNVBAMTGHNoaWJ0ZXN0LmluZm9ybWl0LmNvbS5h\n\t\t\t\t\t\tdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL/16egiJMNo0s7luNCB\n\t\t\t\t\t\t57tJ0Lvpe/CuA5MeEJJGnwumGP4tmmYjaLsO+7m1L5HVnH99JlPoY5XXLDIXpB46\n\t\t\t\t\t\tR3VMs0yS5FkvSF3GKdKtzNdGNUKZwJHVyevayJbIoSFgsTzjdrKfn0f7wFl1gT/o\n\t\t\t\t\t\tj8I8FWy+dzj6oFqQTd1hGQoIh/sqd6QoDJ3GYDR2LJUkmkYZbx+Y3XhEWXpklWzz\n\t\t\t\t\t\tPTx47StStcciRwcpLQ5/PTiQPUjuzl4L3TuhpNt9jy7+min9zYrCVBjOKvjRIBKL\n\t\t\t\t\t\t53G5WyAeHPn5Woe2c52Ryy5bZn07WG0xQbkpRfBXZm8JidyGZlZ3UQbFqk0vRmOA\n\t\t\t\t\t\tk/kCAwEAAaNzMHEwUAYDVR0RBEkwR4IYc2hpYnRlc3QuaW5mb3JtaXQuY29tLmF1\n\t\t\t\t\t\thitodHRwczovL3NoaWJ0ZXN0LmluZm9ybWl0LmNvbS5hdS9zaGliYm9sZXRoMB0G\n\t\t\t\t\t\tA1UdDgQWBBS29MuUEdmm7liCK8DyPCyiBUnfNDANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tKY+aK2b6zeMx50dKwVqjtsNMaUPI+Cwp2+ghJyG/j2NUmpeTRPwVBRPnifRFKSi6\n\t\t\t\t\t\tUXCI+eRzP4vJqbdksIebPr0feqwEHD5XDrbYeDmOLM4IN2u/ykVuSDIqFVV4rwTr\n\t\t\t\t\t\tYf6JyJCYJoebja/DtiqRE2nqDIrOYgdzreGyTHRm+PaVlEv9DSapC324F+WZDwoo\n\t\t\t\t\t\taqtGszguF/5Km8U1LJxLaQTyYV0skSJEhKWK8c41Erip2Iuv4c3gT/J0ML5sY1xB\n\t\t\t\t\t\th6LqQQCPoFMVqQPIacUcCcKA5scEpnxtalUccX8h6zOdpDjijSPRABuFJVRD4kWl\n\t\t\t\t\t\t2jG8gQO/jLpnk4IGfgwN1w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibtest.informit.com.au/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibtest.informit.com.au/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibtest.informit.com.au/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibtest.informit.com.au/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibtest.informit.com.au/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibtest.informit.com.au/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-demo-00.its.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-demo-00.its.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-00.its.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-00.its.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-00.its.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-00.its.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-00.its.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-demo-00.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-demo-00.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;demo-00"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;demo-00"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-demo-00.its.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-demo-00.its.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIJAJ+VUV8Zduz4MA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\nBAMTGWxhZG9rMy1kZW1vLTAwLml0cy51bXUuc2UwHhcNMTIxMjA3MDcyODA4WhcN\nMjIxMjA1MDcyODA4WjAkMSIwIAYDVQQDExlsYWRvazMtZGVtby0wMC5pdHMudW11\nLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAq6ABs5OFGxvp+JVn\nh0y5cKcqJd/pBy6wrBZHkveIOjOrD7cg1o4TorIFcjdQ+wNG1vS5sEZk8b4Um9dO\nmtHb2N1WiEpg4W/dve1q+YoZllQjSEV/ouNIzmTVvY84O8zIArbM484smVjo9a4p\n2Wc8goAIpuQF2ZtWix4UZHkJrhJrdFTU67e3Cl9QJFWGc0fCi+Cz5r++AtgtOAPN\noagiwdnJI319moULBrhisCrL1OWnKTiP2+D2CT8iMgoVAptpeEYJuFlL913LyomQ\ndWnaCvWp0FmERuVBPrShl0EZ5+i+jjsp5UdKg1cwYkS0b35GVuDMmS6pzK6HlAL2\nPC/1NQIDAQABo3EwbzBOBgNVHREERzBFghlsYWRvazMtZGVtby0wMC5pdHMudW11\nLnNlhihodHRwczovL2xhZG9rMy1kZW1vLTAwLml0cy51bXUuc2UvZ3VpLXNwMB0G\nA1UdDgQWBBTwikg2zQJCzo6yrFjx2EIhLB6UqzANBgkqhkiG9w0BAQUFAAOCAQEA\neNZzk8uZ4PJJks11q9WW1PTlyQmmRO6zfDVuJ38TQF5G8owkn5n1pefgCZXY1Pex\n0jz9rbs+cR0aWkdCQA6prFYAK8NT8k9190srrmOAk1p+uL4SbJJW6gxSUuwCJYVs\nR9ohpgwvJCvFqYo+fWMMFoW5eQzMsOZ79oExlx9fMAeJuVuuLkWkf4YABhIgxPTi\nBFoCX3hSHGjRDBVjJ+snuOagE3RpDs7bcHCbSVHvw6KDZbdLsY8qz6birOY9qQbk\nEeE68EA0OgCl1QP8GuR3llSLtvNsQS1JI2+LMPuma6sSEr1nQqwuZgZkQm78bygF\n5b8F1Nc7l9VE8yY3BhUT1Q=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-demo-00.its.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-00.its.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-00.its.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-00.its.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-00.its.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-00.its.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-00.its.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-demo-00.its.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-demo-00.its.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-demo-00.its.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://mintentateknat.kvk.uu.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://mintentateknat.kvk.uu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mintentateknat.kvk.uu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mintentateknat.kvk.uu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mintentateknat.kvk.uu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mintentateknat.kvk.uu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mintentateknat.kvk.uu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://mintentateknat.kvk.uu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://mintentateknat.kvk.uu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Inloggning f\u00f6r studenter till Min Tenta TekNat vid Uppsala universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Logon to My Exam TekNat at Uppsala University"
                  }
                ],
                "logo": [
                  {
                    "text": "https://weblogin.uu.se/idp/UUlogin/img/logga-50.png",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "https://weblogin.uu.se/idp/UUlogin/img/logga-50.png",
                    "lang": "sv",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "https://weblogin.uu.se/idp/UUlogin/img/logga-50.png",
                    "lang": "en",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Min Tenta TekNat vid Uppsala universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "My Exam TekNat at Uppsala University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "epi-tscan006.user.uu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAMNFJ+3oPnmNMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2VwaS10c2NhbjAwNi51c2VyLnV1LnNlMB4XDTE1MDgyNjE1MDIyN1oXDTI1\nMDgyMzE1MDIyN1owIjEgMB4GA1UEAxMXZXBpLXRzY2FuMDA2LnVzZXIudXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQChsjPeDl3A+bIaL/5iMFP2\n0015raSD2sTZpx/D+VC8h4DZLP5j4CaVz4P4psU9c8vMmz7blwi54Vkq6KN84mdM\nesF3Qw+NL5aZS6oUKPG8INuNPmYEJNB7dB3IlrWJp9YwC09FAC9eSGJ8qItTIyga\ncLyVz80XKV2N0JIbvL2HSa3Wp0Sashw6gDjH8EgSYKvT0Cd/YnqCHg+6pKOvdQwb\n/um30VKO92TyqLMdm/U4YUqZhuk2anfTWNyoGvtJOgg6wrVOESWr+yF/M5OBD3g6\ngaQP460SeursmMP+Fo6/MCQ0Mv8wNPS6jAsc4wDe6n+0c0xTsq5MyJx6XTzJMXTP\nAgMBAAGjRTBDMCIGA1UdEQQbMBmCF2VwaS10c2NhbjAwNi51c2VyLnV1LnNlMB0G\nA1UdDgQWBBTjsosb82gOhhKIHN8cVjxvzFr9ADANBgkqhkiG9w0BAQUFAAOCAQEA\nAA964l+VgUG6aO/E44Isc3G8e6mPPoYAfTqxIN3mjwdXyvFZLNBgffxYNeemlGnq\nf1EFTBHkzoXyyQzjRF/MM42ZzuiGqArkCCMlYc1zcIRxz6cOawRLx2he6BeWRvih\n1kNEQo+vPAzKYISXl2NTvOdPe9M/VQ4bfpQvlO6NzkDp7uhffKNmYu0OSO1rAtzv\n6FnVbYEd4VMKzZFM7qzSQu3+JXq2ssN6+V5mCyArOYRAQFFFQ/diBbOUfZmuxqAg\nHbvp7iTyKDIlEcyIYvshYARRFV/G8/by/ymeRCd7IBuvjfdqax/RDyFNlQM4kw3O\nJXGqqhG/E2dBIwnt5fEXVA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=epi-tscan006.user.uu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mintentateknat.kvk.uu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mintentateknat.kvk.uu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mintentateknat.kvk.uu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mintentateknat.kvk.uu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mintentateknat.kvk.uu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://mintentateknat.kvk.uu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://mintentateknat.kvk.uu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://mintentateknat.kvk.uu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://mintentateknat.kvk.uu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://webtut.fccn.pt",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:stv@fccn.pt"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Administrator"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://webtut.fccn.pt",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://www.fccn.pt",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "pt",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "FCT|FCCN"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "FCT|FCCN"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.fccn.pt"
          }
        ],
        "organization_name": [
          {
            "lang": "pt",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "FCT|FCCN"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "FCT|FCCN"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://webtut.fccn.pt/simplesaml/module.php/saml/sp/saml2-logout.php/webtut.fccn.pt",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "WebRTC in context example application"
                  },
                  {
                    "lang": "pt",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Aplica\u00e7\u00e3o exemplo de uso da tecnologia WebRTC"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "WebTUT Service"
                  },
                  {
                    "lang": "pt",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Servi\u00e7o WebTUT"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdYCCQD02c5n0jI2ODANBgkqhkiG9w0BAQUFADA5MQswCQYDVQQGEwJQ\nVDERMA8GA1UECgwIRkNUfEZDQ04xFzAVBgNVBAMMDndlYnR1dC5mY2NuLnB0MB4X\nDTE2MDEyODE2MzMzN1oXDTE5MDEyNzE2MzMzN1owOTELMAkGA1UEBhMCUFQxETAP\nBgNVBAoMCEZDVHxGQ0NOMRcwFQYDVQQDDA53ZWJ0dXQuZmNjbi5wdDCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL6KyuPJZKpaG1JSUZBh+sTBNB8BzwGZ\n9nXggSgYMc1bSijzbcDeUThF/76Qxdd8UnA2Fed806F+eajyVHDAIb28YIyAGncX\nVnjmryBzVPlIxe1FusR4pFvVaaGWr+DhgasoQYeQmFkmLhNPYOyU8GSA38zrOWrO\nLirZ26HqiSsFX3R2HWbILPwqJX/8nD1qcsV0ZEnOLUhxvQ2O8n9slkwinXZgAtyB\neoDM6KRMoayUzOvJggvASEzs32/g/0TxZcFF6nJGZPjMRDZfqqEsigtVYIWpvJ/W\nPo7OnvYhtSlS88uV4cVdOAoorXJoTs8yafDNLovyeUvS7y54w5AHLUsCAwEAATAN\nBgkqhkiG9w0BAQUFAAOCAQEAL88GMPpWdv0CTT/YIKdUAMaZBYskm66xVnXOMfG9\nLI6Kkc7cnxeqJ7jJyF6uJ4VvU8aJb4CRTivrqJFa9QuFslqK+xTujLY21XFKwO2S\nd5f3Is5is0vQ5oG6qaYPnU0F/rx170A20ZeYVMBnf8WOUpPD5Z8rBi6Dyom+YE+l\nJ0uE73E8LuN77O+enbjj/TeW3Zt2hurd/hpuFhBcAspFOoVQvMuMjjTaFkcdlQYg\nw3ks4BHE7Nswn/fPRvccX08mW/u8qM1o3NIaoCOBJRf4dyQuv22+K0y5a+3wH9o8\nQZfzDc9Vmm18OJtspKB74+x7JkNv6iszqOH6gvzq4qvkRw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdYCCQD02c5n0jI2ODANBgkqhkiG9w0BAQUFADA5MQswCQYDVQQGEwJQ\nVDERMA8GA1UECgwIRkNUfEZDQ04xFzAVBgNVBAMMDndlYnR1dC5mY2NuLnB0MB4X\nDTE2MDEyODE2MzMzN1oXDTE5MDEyNzE2MzMzN1owOTELMAkGA1UEBhMCUFQxETAP\nBgNVBAoMCEZDVHxGQ0NOMRcwFQYDVQQDDA53ZWJ0dXQuZmNjbi5wdDCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL6KyuPJZKpaG1JSUZBh+sTBNB8BzwGZ\n9nXggSgYMc1bSijzbcDeUThF/76Qxdd8UnA2Fed806F+eajyVHDAIb28YIyAGncX\nVnjmryBzVPlIxe1FusR4pFvVaaGWr+DhgasoQYeQmFkmLhNPYOyU8GSA38zrOWrO\nLirZ26HqiSsFX3R2HWbILPwqJX/8nD1qcsV0ZEnOLUhxvQ2O8n9slkwinXZgAtyB\neoDM6KRMoayUzOvJggvASEzs32/g/0TxZcFF6nJGZPjMRDZfqqEsigtVYIWpvJ/W\nPo7OnvYhtSlS88uV4cVdOAoorXJoTs8yafDNLovyeUvS7y54w5AHLUsCAwEAATAN\nBgkqhkiG9w0BAQUFAAOCAQEAL88GMPpWdv0CTT/YIKdUAMaZBYskm66xVnXOMfG9\nLI6Kkc7cnxeqJ7jJyF6uJ4VvU8aJb4CRTivrqJFa9QuFslqK+xTujLY21XFKwO2S\nd5f3Is5is0vQ5oG6qaYPnU0F/rx170A20ZeYVMBnf8WOUpPD5Z8rBi6Dyom+YE+l\nJ0uE73E8LuN77O+enbjj/TeW3Zt2hurd/hpuFhBcAspFOoVQvMuMjjTaFkcdlQYg\nw3ks4BHE7Nswn/fPRvccX08mW/u8qM1o3NIaoCOBJRf4dyQuv22+K0y5a+3wH9o8\nQZfzDc9Vmm18OJtspKB74+x7JkNv6iszqOH6gvzq4qvkRw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webtut.fccn.pt/simplesaml/module.php/saml/sp/saml2-acs.php/webtut.fccn.pt",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://webtut.fccn.pt/simplesaml/module.php/saml/sp/saml1-acs.php/webtut.fccn.pt",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://webtut.fccn.pt/simplesaml/module.php/saml/sp/saml2-acs.php/webtut.fccn.pt",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://webtut.fccn.pt/simplesaml/module.php/saml/sp/saml1-acs.php/webtut.fccn.pt/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "WebTUT Service"
                },
                {
                  "lang": "pt",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Servi\u00e7o WebTUT"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "WebRTC in context example application"
                },
                {
                  "lang": "pt",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Aplica\u00e7\u00e3o exemplo de uso da tecnologia WebRTC"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibidp.wcupa.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rkabir@wcupa.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rashed Kabir"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "fpiscitello@wcupa.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Frank Piscitello"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "abuse@wcupa.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Information Security"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@wcupa.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT HelpDesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibidp.wcupa.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.wcupa.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.wcupa.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUdeH51iARpA9IRaqlBc5rN1Yb6gUwDQYJKoZIhvcNAQEL\nBQAwHDEaMBgGA1UEAwwRc2hpYmlkcC53Y3VwYS5lZHUwHhcNMTUxMDMwMjAzNTM0\nWhcNMzUxMDMwMjAzNTM0WjAcMRowGAYDVQQDDBFzaGliaWRwLndjdXBhLmVkdTCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ9s+rurhmsVv2Nrdwx2ZngE\nogf41zeSQyxwS3kOmylJ3GyUrbSKdUL/E5+OUds/k/V9M63s8LpQ56lqa24pjp+Y\nvisg7PK1+LjeemSmEzltG3alDzrqBdk2cZ+f4KsOjlFTAPG92/JlJg8Wf1CJRTpJ\n/3Eth64kfz83/Q1xzJnO2tVdSwGbbFybc+b6hApUrE7QwCoOVk9rl5HCwfXE5SKu\n9dpvTL4X8QmfBNDAapRHjqFq4A48EnywJcceRElKX+eXa8iArkS1RVnipuDww+1O\ndfdVktBRC518AWH0eHHG9Cn8MbVoRHo4q6P3IBysfRh+6Rf5yY94L/m59CUFy7UC\nAwEAAaNpMGcwHQYDVR0OBBYEFCoZ8a9VWOYqg67BwvrhMKGop6fGMEYGA1UdEQQ/\nMD2CEXNoaWJpZHAud2N1cGEuZWR1hihodHRwczovL3NoaWJpZHAud2N1cGEuZWR1\nL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQBQcQLRMvL7ozLENHkE\n9/CJ+oC4eDd4NyHPcbTt8o0rRBHK260AohKP8rllZDTcNYiqH868r05cbhpCed38\nhWPvwhoAvs8sdQ9BWxNfizS0N9i+3jOB8djB8xwG84FzDy0S25WEOg2Ho7OU56Jf\nmA9j9eXob0zBb/y50dAD42P4Yt60QMVPizsON27R503gRJPd39kv6xoc1k+/Wv2z\nwsB2fZoZ/BEWyXyKG3k7rOfY5O1BvVQefIJZBlD2CYQr8Oc8PLZK1eHGB7pjD8qg\n8p22ptxVX4rEhY8uEkXGjxUNzvCy+R7HIJMnssjYyyu394532pvLwrFEJbi3IIpk\nlG2H"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wcupa.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://wcupa.edu/infoservices/security/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://wcupa.edu/images/WCULogo100x201.png",
                    "lang": "en",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "201"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://wcupa.edu/infoservices/security/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "West Chester University of Pennsylvania"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "West Chester University of Pennsylvania"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://wcupa.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "West Chester University of Pennsylvania"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://hr.su.se/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Primulasupport"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:primulasupport@evry.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://hr.su.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EVRY HR"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.evry.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "EVRY HR Solutions AB"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hr.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://hr.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hr.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hr.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hr.su.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://hr.su.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://hr.su.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Webgr\u00e4nssnittet till HR-systemet Primula fr\u00e5n EVRY HR Solutions AB f\u00f6r anst\u00e4llda p\u00e5 Stockholms Universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The web interface to the HR software system Primula from EVRY HR Solutions AB for employees at Stockholm University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Primula"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Primula"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "hr.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3zCCAcegAwIBAgIJANTo9EQ1a/exMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\nBAMTCGhyLnN1LnNlMB4XDTEzMDQyMzEzNDgwOVoXDTIzMDQyMTEzNDgwOVowEzER\nMA8GA1UEAxMIaHIuc3Uuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQC3CRsGCf/rcIKzBHKNz7faRCr0YGRmGayeX1E8wn5Dvc0S98kpl1AWwDSeTva0\n/bL0RTykVPoeRCUzb3Y2gpWvjA7vZp6Z+T3ovEdWYoiSyjytXejcEFjGhPRFMSm/\noTwZ0GV603iXO80Xk6t6LSAA4WiWZzLJs5TsHP+BvhTIYzSgsnZjHRY4UDrA3tCj\ntbFGtMepuvrtahhQrPWJA2MPbkKoQy6fVH5sNVvUKFSMbcLfJ37P5k8k4FH7veub\n83AoWVCz5zGyOciHz63IkTYBZunnK11kzLK2wNtabMqz5CDF++HzohzyzlrDxPmL\najAR63tKbLK5rEm0pum3NaHjAgMBAAGjNjA0MBMGA1UdEQQMMAqCCGhyLnN1LnNl\nMB0GA1UdDgQWBBQn07JAhkAPp7OpVUGizezK8POxCzANBgkqhkiG9w0BAQUFAAOC\nAQEAYHKQjVhqWjeS8uFQGbqrvDef6AH0lXVnCOJf8WrDpmDTI/zmy9qayf2bbIXg\nM+8W79NkWdxirKImqAVFeYST4PXBONuXOgz5YMc8adiDv/6jeFZ8T1X3py8v15VR\nqL01A8lR0w7BLIVr+dh5bVznc0k2Bqb6OpXkhvs8Q3LuO0EJYScbLAPUPcF0m24B\nYj4ybSzJjKJ38MxNnYWL2kjjzkgNdWVOd5Dnak3PqK9/2o9RJzqoWA9ZgEVFLdy/\ngwi5chzD+EG7sLZMZ+izxSBoFuMKIFfmz37zEafLh0z1YOBqLt20uxjw+ulMKLz4\n+Wt+7p+EmxcIvl5G19k9wtgesw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=hr.su.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hr.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://hr.su.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://hr.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://hr.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://hr.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://hr.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.sci-ware-customer.com/preprod/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:customersupport@sci-ware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Customer Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Scecina"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ondrej.scecina@sci-ware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ondrej"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.sci-ware-customer.com/preprod/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-09-12T16:02:51Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Science Warehouse PreProd1"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sci-ware.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Science Warehouse Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://secondary.sci-ware-customer.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://secondary.sci-ware-customer.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://secondary.sci-ware-customer.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://secondary.sci-ware-customer.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://secondary.sci-ware-customer.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://secondary.sci-ware-customer.com/Shibboleth.sso/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://secondary.sci-ware-customer.com/Shibboleth.sso/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://secondary.sci-ware-customer.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://secondary.sci-ware-customer.com/Shibboleth.sso/LoginYSJ",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAPOcCZG4kjBhMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\n\t\t\t\t\t\tBAMTF3NlY3ByZXdlYjEuc2NpLXdhcmUuY29tMB4XDTEzMDkwMzE0MjMyN1oXDTIz\n\t\t\t\t\t\tMDkwMTE0MjMyN1owIjEgMB4GA1UEAxMXc2VjcHJld2ViMS5zY2ktd2FyZS5jb20w\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC3p6apDMPvuzis5U7s2CMe\n\t\t\t\t\t\tox+i1ffSlt2ONB0pKnwdOyeAtqZgeiviuTww18icZy7olWYSSSumi0bANS7VJi8n\n\t\t\t\t\t\tEOI+yGl6kjNf6X33BNyO/B0afgX++d3sx02TlDtuqWqh2Oi67qdQPD/LVKWEB4bM\n\t\t\t\t\t\tlgK2Yf6Km8cfHl8dkR9Cfblt/AAOV5iE6HZDNiXdKj4suxoxjiOhI9JcDf1gicQB\n\t\t\t\t\t\tObXDu+dkfXIlyOI3r8JqOWsqWwW4E5UuJ4+XEIsCjrQAqAj2/NJ+fy6Pr/uAbsVb\n\t\t\t\t\t\tC4VWPJm4bdThGybNUDr2LGjbmnTLHwVp6yhcSnu7TAACljeltamWLoXD8TBz8doh\n\t\t\t\t\t\tAgMBAAGjRTBDMCIGA1UdEQQbMBmCF3NlY3ByZXdlYjEuc2NpLXdhcmUuY29tMB0G\n\t\t\t\t\t\tA1UdDgQWBBT94xDOhvG4i9HPxirLA3BO5Dg57DANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tBVkY4FYZ/6gbtuk/UQnbJnWWELy9vLV29OvrjTCe6QM+F8yFYkWme9LtFulfr9NM\n\t\t\t\t\t\tXIIavSmKI2RKnn/NLpYP2wDHNs+p+3c4JNJohJc2Dv3w2+MC4LMV/hezXXinGon1\n\t\t\t\t\t\tVpEJ3oP4n301o56/rGb+8eEFrCaaQlmtuwLfaKcKuW5ZNLNjtNwcPzNJ3GNH43MS\n\t\t\t\t\t\tSfSvzCcjoVWMmCNm2W8HpheZCgWawg0X02h22WJ6nLYzvdTxaIXHYrMdNl6XV5u5\n\t\t\t\t\t\tcOVsF94ZY4wriD0goxTHy7xKE9ICkUrT7kUF1kXBeImpM5Y8ak5mdYWPbZDTdN2M\n\t\t\t\t\t\t6NM1c5BqI+6jWLfWoTJNMw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://secondary.sci-ware-customer.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://secondary.sci-ware-customer.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://secondary.sci-ware-customer.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://secondary.sci-ware-customer.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://secondary.sci-ware-customer.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://secondary.sci-ware-customer.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://secondary.sci-ware-customer.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://secondary.sci-ware-customer.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://secondary.sci-ware-customer.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://secondary.sci-ware-customer.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.woking.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itsupport@woking.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Akram"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mak@woking.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mohammed"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.woking.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-06-26T13:59:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQjCCAioCCQDzQLFc3l5fVDANBgkqhkiG9w0BAQUFADBjMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEPMA0GA1UECBMGU3VycmV5MQ8wDQYDVQQHEwZXb2tpbmcxFzAVBgNVBAoTDldv\n\t\t\t\t\t\ta2luZyBDb2xsZWdlMRkwFwYDVQQDExBpZHAud29raW5nLmFjLnVrMB4XDTEzMTEw\n\t\t\t\t\t\tNTE0MTQxMVoXDTMzMTAzMTE0MTQxMVowYzELMAkGA1UEBhMCR0IxDzANBgNVBAgT\n\t\t\t\t\t\tBlN1cnJleTEPMA0GA1UEBxMGV29raW5nMRcwFQYDVQQKEw5Xb2tpbmcgQ29sbGVn\n\t\t\t\t\t\tZTEZMBcGA1UEAxMQaWRwLndva2luZy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQAD\n\t\t\t\t\t\tggEPADCCAQoCggEBAL4LR5bglyzayUHgWbAeGXwr7o2bav61X7rLiopGKRe23KwK\n\t\t\t\t\t\tIPnXkFx5XQ7AL9+2ZuINUXx6qMYAJg0bLMINokYH0Qlm6LsK1M8rT58+f4s8U5Mk\n\t\t\t\t\t\t6CHidaGhHHelH6dmRBkdqbIJ3/f201fMfprNxVJfovkFSwsByBTo7BEpKQmSajSG\n\t\t\t\t\t\tWdq+KSRgZhzzNp9s5dEaBZQFRqejGqj1jSZdz34bRtRZ8Vy17GALIoFtZE2P+zaa\n\t\t\t\t\t\trogI7MlPmDyoDUouQ9RsSVgj1+8zGDWmnjJcnQQIR8jvAaZeavcQfmnRXAtkPKiJ\n\t\t\t\t\t\tppwVjtxAlEuuSnWL+ROlXRqIun3uUEsKSr6PQ3kCAwEAATANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAvH9FxNrQp5F+GBC1D4PyiubJmA4e1CalqE7ra9m7pgBUhd8mvDJl2vfo\n\t\t\t\t\t\txAe5IVVfeSYpbJQ4cg9zd3Vnh3tRVW4lsjDzvHjBAnRHAO1yzjFfUwulBl+YCCjX\n\t\t\t\t\t\tN6cY7UMBPEWZ3mvwHc6B4pDDWPXx0Cq/p4da6KAT6ztlrjSUkcFVjtDexXbNmS04\n\t\t\t\t\t\tB/Q3pZUzdQs3EzTOrQiFQMNw56Kpy/sMEPEwXJ+xeaSNttiM5TgqIjENwFZbLSmt\n\t\t\t\t\t\tibTP5VM86O2mOIf1QfhPQMUqud7HZfa7b7oRPSwt73xFVvbnjvSvsE5uHw2hiNAz\n\t\t\t\t\t\tZ0EMXT53Z2x+2Euy0Y8Um48NtjrU3w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "woking.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.woking.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.woking.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.woking.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.woking.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.woking.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.woking.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.woking.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.woking.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "woking.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQjCCAioCCQDzQLFc3l5fVDANBgkqhkiG9w0BAQUFADBjMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEPMA0GA1UECBMGU3VycmV5MQ8wDQYDVQQHEwZXb2tpbmcxFzAVBgNVBAoTDldv\n\t\t\t\t\t\ta2luZyBDb2xsZWdlMRkwFwYDVQQDExBpZHAud29raW5nLmFjLnVrMB4XDTEzMTEw\n\t\t\t\t\t\tNTE0MTQxMVoXDTMzMTAzMTE0MTQxMVowYzELMAkGA1UEBhMCR0IxDzANBgNVBAgT\n\t\t\t\t\t\tBlN1cnJleTEPMA0GA1UEBxMGV29raW5nMRcwFQYDVQQKEw5Xb2tpbmcgQ29sbGVn\n\t\t\t\t\t\tZTEZMBcGA1UEAxMQaWRwLndva2luZy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQAD\n\t\t\t\t\t\tggEPADCCAQoCggEBAL4LR5bglyzayUHgWbAeGXwr7o2bav61X7rLiopGKRe23KwK\n\t\t\t\t\t\tIPnXkFx5XQ7AL9+2ZuINUXx6qMYAJg0bLMINokYH0Qlm6LsK1M8rT58+f4s8U5Mk\n\t\t\t\t\t\t6CHidaGhHHelH6dmRBkdqbIJ3/f201fMfprNxVJfovkFSwsByBTo7BEpKQmSajSG\n\t\t\t\t\t\tWdq+KSRgZhzzNp9s5dEaBZQFRqejGqj1jSZdz34bRtRZ8Vy17GALIoFtZE2P+zaa\n\t\t\t\t\t\trogI7MlPmDyoDUouQ9RsSVgj1+8zGDWmnjJcnQQIR8jvAaZeavcQfmnRXAtkPKiJ\n\t\t\t\t\t\tppwVjtxAlEuuSnWL+ROlXRqIun3uUEsKSr6PQ3kCAwEAATANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAvH9FxNrQp5F+GBC1D4PyiubJmA4e1CalqE7ra9m7pgBUhd8mvDJl2vfo\n\t\t\t\t\t\txAe5IVVfeSYpbJQ4cg9zd3Vnh3tRVW4lsjDzvHjBAnRHAO1yzjFfUwulBl+YCCjX\n\t\t\t\t\t\tN6cY7UMBPEWZ3mvwHc6B4pDDWPXx0Cq/p4da6KAT6ztlrjSUkcFVjtDexXbNmS04\n\t\t\t\t\t\tB/Q3pZUzdQs3EzTOrQiFQMNw56Kpy/sMEPEwXJ+xeaSNttiM5TgqIjENwFZbLSmt\n\t\t\t\t\t\tibTP5VM86O2mOIf1QfhPQMUqud7HZfa7b7oRPSwt73xFVvbnjvSvsE5uHw2hiNAz\n\t\t\t\t\t\tZ0EMXT53Z2x+2Euy0Y8Um48NtjrU3w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Woking College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.woking.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Woking College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://filesender.redclara.net/simplesaml/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "RedCLARA"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "seg@redclara.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SEG"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://filesender.redclara.net/simplesaml/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "es",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://cofre.reuna.cl/index.php/es/reglas-federacion"
              }
            ],
            "registration_instant": "2014-02-21T00:00:00Z",
            "registration_authority": "http://cofre.reuna.cl",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RedCLARA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.redclara.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RedCLARA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://filesender.redclara.net/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.redclara.net/index.php?lang=en"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.redclara.net/index.php?lang=es"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "RedCLARA's Filesender Service"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Servicio Filesender de RedCLARA"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Filesender - RedCLARA"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Filesender - RedCLARA"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://filesender.redclara.net/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://filesender.redclara.net/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://filesender.redclara.net/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://filesender.redclara.net/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Filesender - RedCLARA"
                },
                {
                  "lang": "es",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Filesender - RedCLARA"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "RedCLARA Nrenadmin Service"
                },
                {
                  "lang": "es",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "RedCLARA Nrenadmin Service"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.37",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://bathspa.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:e-resources@bathspa.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "E-Resources"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fry"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:p.fry@bathspa.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pete"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bathspa.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-06-11T18:26:50Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://auth.bathspa.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.bathspa.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bathspa.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjACCQDcLoBcXhuQpDANBgkqhkiG9w0BAQUFADBmMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjENMAsGA1UECAwEQmF0aDENMAsGA1UEBwwEQmF0aDEcMBoGA1UECgwTQmF0aCBT\n\t\t\t\t\t\tcGEgVW5pdmVyc2l0eTEbMBkGA1UEAwwSYXV0aC5iYXRoc3BhLmFjLnVrMB4XDTE0\n\t\t\t\t\t\tMDkxMTEyNDY0MFoXDTI0MDkwODEyNDY0MFowZjELMAkGA1UEBhMCR0IxDTALBgNV\n\t\t\t\t\t\tBAgMBEJhdGgxDTALBgNVBAcMBEJhdGgxHDAaBgNVBAoME0JhdGggU3BhIFVuaXZl\n\t\t\t\t\t\tcnNpdHkxGzAZBgNVBAMMEmF1dGguYmF0aHNwYS5hYy51azCCASIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEBBQADggEPADCCAQoCggEBANDnvw+jI/NjbEuPbKzjfQa5FqOZGYy2cGaX8opS\n\t\t\t\t\t\tWODxFwY/Ua8a9JJQlX2a8b2Wu7niQyJo1z75+cTVTljXXi4z5sghIhheFu0nv6zs\n\t\t\t\t\t\tjA73qefWlNkpUK7ytjPVrS1LE0OttEt5uvRVb4M0j3oIF3ueAMNeASJMGw7hHqM8\n\t\t\t\t\t\t7s9diYWljFnIiAnN0SXtMNskRBOvXQCxY1tY/qB8g1t4vx9TXyC3s54JBhT+o3wU\n\t\t\t\t\t\tdy0dCWpiY9iQNQLx3+l/74XqlwIIaFYHylheQMxkp1pEP1kO8LHor1n/0mtCzvK0\n\t\t\t\t\t\twGOUge2oW6AaDhqEZSOkcEIhDw4M6dKyNvOM7UiXFO853fUCAwEAATANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEARqEYYD8T5djkWXdTunxb9OCUNTVX6MOmBgFoE9wREI3zOWHR\n\t\t\t\t\t\tsR0nLbQylmfpqQBvgncqlhc0Ozd+Va8MXYcAFxoCBLOVc28I+Buengp+lhbddHBX\n\t\t\t\t\t\t1WaXAovAO8gzXCTO2KlUagzLDMGdUetz9UE+raA5D+RNPtchdNsXM+ma/rFzuZNI\n\t\t\t\t\t\tWC36eJwChM8Lz+Pge/lQAb9tsllTwvy8fh/xGwBxR5N+f5tupZjbj3uuWevR8oa3\n\t\t\t\t\t\t/egG7ermySwN33hXy3aWdP22CDWc8kxV44J5p8Cq3UTU08aXtlDMtaiTwBZ633Hx\n\t\t\t\t\t\t/6/Zs/TcjIKAfbi6nBCf9z6u2SrAtIiRcU51nw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bath Spa University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bathspa.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Bath Spa University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-demo-02.its.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-demo-02.its.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-02.its.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-02.its.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-02.its.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-02.its.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-02.its.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-demo-02.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-demo-02.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;demo-02"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;demo-02"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-demo-02.its.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-demo-02.its.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIJAInGoLqyk3C+MA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\nBAMTGWxhZG9rMy1kZW1vLTAyLml0cy51bXUuc2UwHhcNMTIxMjA3MDcyODEyWhcN\nMjIxMjA1MDcyODEyWjAkMSIwIAYDVQQDExlsYWRvazMtZGVtby0wMi5pdHMudW11\nLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA+xisO1AornoaWz46\nIAUSjOCPXp4NV3cGU01VsvXe7FhZGByScd01L53WkhvWWLCGKTxZNAS2dyAbDhEO\n5X9TMPtpHE9XCcyqd8yii3g7nScj5/S/YudZOnZvuCDlH2hg2YhCGZRujUA0e7JM\notEm/Lz18AecsECQsbNd/95oYl6/k4TMPg8dT32rbHQl6hGPfH+IK1Z7OMnXYsP+\nsMBgaSMfQna8zaijQo0aM9/zyp3wxeTsncS5l74eYm3whaKHxRsTjvUh/YaI9LTU\nwrPxuwZINtQ7HiZ/3KwoREl22zsntUemTmdWez85ctYMdtEc5h+3UVNfd1P7UNcW\nc+oZzQIDAQABo3EwbzBOBgNVHREERzBFghlsYWRvazMtZGVtby0wMi5pdHMudW11\nLnNlhihodHRwczovL2xhZG9rMy1kZW1vLTAyLml0cy51bXUuc2UvZ3VpLXNwMB0G\nA1UdDgQWBBRahNxHA0sPHkTEvPxjZ+V6K2tTQTANBgkqhkiG9w0BAQUFAAOCAQEA\ntUgKur8E4TfES+5QbUJpKABDRJUiPmxrlUAaU+B2BZA74+tO717esA44Jahlre/v\nCV5grAoeplD6llBeMUe7hVsMum63kUpUh+zLwiP/KSegjxrYMv9vueqpCB2bYzy4\n4Kv9GchQaA+XvdX7pBhQdQchEmexlkoyLk52pIG5kPos5FoKUnE1avcydLDn5IXF\nFtfOLxpCpBkLZT1JtloPydKvbueD28Kpq/BynPMijzH/Y5mTpy81h5MY+HoOWmus\nzhFBTc7cydJB7Uvj9A5mgA9DtxsnmBxwRv/VwpXGmXGTm/Lrh4o61MI/yI84/UEa\na/lggwDHd7eCy/34Rs5nJw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-demo-02.its.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-02.its.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-02.its.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-02.its.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-02.its.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-02.its.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-02.its.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-demo-02.its.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-demo-02.its.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-demo-02.its.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://bsp-idp.shibboleth.ox.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sysdev@it.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sysdev"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:help@it.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Help"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bsp-idp.shibboleth.ox.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEkDCCA3igAwIBAgIJAK74tuCrn4gMMA0GCSqGSIb3DQEBBQUAMIHIMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEUMBIGA1UECBMLT3hmb3Jkc2hpcmUxDzANBgNVBAcTBk94Zm9yZDEd\n\t\t\t\t\t\tMBsGA1UEChMUVW5pdmVyc2l0eSBvZiBPeGZvcmQxGzAZBgNVBAsTEkNvbXB1dGlu\n\t\t\t\t\t\tZyBTZXJ2aWNlczEkMCIGA1UEAxMbYnNwLWlkcC5zaGliYm9sZXRoLm94LmFjLnVr\n\t\t\t\t\t\tMTAwLgYJKoZIhvcNAQkBFiFlbWFpbEFkZHJlc3M9c3lzZGV2QG91Y3Mub3guYWMu\n\t\t\t\t\t\tdWswHhcNMTIwNTE4MDg1MjMwWhcNMjIwNTE2MDg1MjMwWjCByDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFDASBgNVBAgTC094Zm9yZHNoaXJlMQ8wDQYDVQQHEwZPeGZvcmQxHTAbBgNV\n\t\t\t\t\t\tBAoTFFVuaXZlcnNpdHkgb2YgT3hmb3JkMRswGQYDVQQLExJDb21wdXRpbmcgU2Vy\n\t\t\t\t\t\tdmljZXMxJDAiBgNVBAMTG2JzcC1pZHAuc2hpYmJvbGV0aC5veC5hYy51azEwMC4G\n\t\t\t\t\t\tCSqGSIb3DQEJARYhZW1haWxBZGRyZXNzPXN5c2RldkBvdWNzLm94LmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvnBxr4sjCqHqNQuqRKlscoqV\n\t\t\t\t\t\tn+KjKIL4oDVQY8lZpp9jbce7cLopWhAMhWXA5YwWBJTluYPkiEnzLQsWPdf4EKAG\n\t\t\t\t\t\tPtXz9OVAjZzKq3KB/Rdi29LUjuI5Ugd39OJn1NIH2FsVG7z/te3IrHf/n7/mTmYl\n\t\t\t\t\t\tOpPJ7XaAJgrRiNil5M2n/tmSg1rhbghR3TQAh0qtsO0h5N/b6cnRyFxVWk5Wn4U6\n\t\t\t\t\t\tKPfYd+jVCUkOawC22bW+6Poxh6fDDm9RgCstP14MpdST7VWBidv7kc1HiuSS/DH0\n\t\t\t\t\t\tdj3l9eqtpObDhUVHdDHTffpS32IuEdqPq5xJ80QRCmQxeRIQW3qzlAG3c4+WpwID\n\t\t\t\t\t\tAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVy\n\t\t\t\t\t\tYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUhm2QdhrbYvY9WzUEmTv/iAkRq5Uw\n\t\t\t\t\t\tHwYDVR0jBBgwFoAUhm2QdhrbYvY9WzUEmTv/iAkRq5UwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAIO+pz3LCPf88PSx7Mm3KbJ+EPxPbwY+nlk2IuIkxIDR4IVpdCV6uY70uR8+\n\t\t\t\t\t\tbN7mb9mpjGsJGcyDpSncQmM3qwC45Lv6F0giJQXCH84iTPoFoLSjToxE9kYaN9tg\n\t\t\t\t\t\tUOQiZODEuQWLGp80qHHWKYpG1/wxok3chwUW0dy8zGSm9esWwbEsInkm0cKq4MiG\n\t\t\t\t\t\twZ0maBagoaennxoKP9DKJp7bSePoAh/nZTCzQaQGK1JcQZsgzkHnomf7UaUFuslH\n\t\t\t\t\t\tpDq4lDx2f/mAtxY40toa3H7Bgm5Dd/lkqpgeYI5kkOJmlFCYroKrmhG0jtOX3RMT\n\t\t\t\t\t\t8aC6ef6hAwmREKbmNT8faiMPsss="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ox.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://bsp-idp.shibboleth.ox.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bsp-idp.shibboleth.ox.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://bsp-idp.shibboleth.ox.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bsp-idp.shibboleth.ox.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://bsp-idp.shibboleth.ox.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://bsp-idp.shibboleth.ox.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://bsp-idp.shibboleth.ox.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bsp-idp.shibboleth.ox.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ox.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEkDCCA3igAwIBAgIJAK74tuCrn4gMMA0GCSqGSIb3DQEBBQUAMIHIMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEUMBIGA1UECBMLT3hmb3Jkc2hpcmUxDzANBgNVBAcTBk94Zm9yZDEd\n\t\t\t\t\t\tMBsGA1UEChMUVW5pdmVyc2l0eSBvZiBPeGZvcmQxGzAZBgNVBAsTEkNvbXB1dGlu\n\t\t\t\t\t\tZyBTZXJ2aWNlczEkMCIGA1UEAxMbYnNwLWlkcC5zaGliYm9sZXRoLm94LmFjLnVr\n\t\t\t\t\t\tMTAwLgYJKoZIhvcNAQkBFiFlbWFpbEFkZHJlc3M9c3lzZGV2QG91Y3Mub3guYWMu\n\t\t\t\t\t\tdWswHhcNMTIwNTE4MDg1MjMwWhcNMjIwNTE2MDg1MjMwWjCByDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFDASBgNVBAgTC094Zm9yZHNoaXJlMQ8wDQYDVQQHEwZPeGZvcmQxHTAbBgNV\n\t\t\t\t\t\tBAoTFFVuaXZlcnNpdHkgb2YgT3hmb3JkMRswGQYDVQQLExJDb21wdXRpbmcgU2Vy\n\t\t\t\t\t\tdmljZXMxJDAiBgNVBAMTG2JzcC1pZHAuc2hpYmJvbGV0aC5veC5hYy51azEwMC4G\n\t\t\t\t\t\tCSqGSIb3DQEJARYhZW1haWxBZGRyZXNzPXN5c2RldkBvdWNzLm94LmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvnBxr4sjCqHqNQuqRKlscoqV\n\t\t\t\t\t\tn+KjKIL4oDVQY8lZpp9jbce7cLopWhAMhWXA5YwWBJTluYPkiEnzLQsWPdf4EKAG\n\t\t\t\t\t\tPtXz9OVAjZzKq3KB/Rdi29LUjuI5Ugd39OJn1NIH2FsVG7z/te3IrHf/n7/mTmYl\n\t\t\t\t\t\tOpPJ7XaAJgrRiNil5M2n/tmSg1rhbghR3TQAh0qtsO0h5N/b6cnRyFxVWk5Wn4U6\n\t\t\t\t\t\tKPfYd+jVCUkOawC22bW+6Poxh6fDDm9RgCstP14MpdST7VWBidv7kc1HiuSS/DH0\n\t\t\t\t\t\tdj3l9eqtpObDhUVHdDHTffpS32IuEdqPq5xJ80QRCmQxeRIQW3qzlAG3c4+WpwID\n\t\t\t\t\t\tAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVy\n\t\t\t\t\t\tYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUhm2QdhrbYvY9WzUEmTv/iAkRq5Uw\n\t\t\t\t\t\tHwYDVR0jBBgwFoAUhm2QdhrbYvY9WzUEmTv/iAkRq5UwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAIO+pz3LCPf88PSx7Mm3KbJ+EPxPbwY+nlk2IuIkxIDR4IVpdCV6uY70uR8+\n\t\t\t\t\t\tbN7mb9mpjGsJGcyDpSncQmM3qwC45Lv6F0giJQXCH84iTPoFoLSjToxE9kYaN9tg\n\t\t\t\t\t\tUOQiZODEuQWLGp80qHHWKYpG1/wxok3chwUW0dy8zGSm9esWwbEsInkm0cKq4MiG\n\t\t\t\t\t\twZ0maBagoaennxoKP9DKJp7bSePoAh/nZTCzQaQGK1JcQZsgzkHnomf7UaUFuslH\n\t\t\t\t\t\tpDq4lDx2f/mAtxY40toa3H7Bgm5Dd/lkqpgeYI5kkOJmlFCYroKrmhG0jtOX3RMT\n\t\t\t\t\t\t8aC6ef6hAwmREKbmNT8faiMPsss="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Oxford (BSP)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ox.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Oxford"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://pp.webauth.soton.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Serviceline@soton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Serviceline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Peters"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:C.L.Peters@soton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Clayton"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://pp.webauth.soton.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-03-02T14:13:42Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVAKwAy5Y30bYosT2rmKq0Nj3qJE+DMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCExHzAdBgNVBAMTFnBwLndlYmF1dGguc290b24uYWMudWswHhcNMTEwNDA1\n\t\t\t\t\t\tMTYxNTA5WhcNMzEwNDA1MTYxNTA5WjAhMR8wHQYDVQQDExZwcC53ZWJhdXRoLnNv\n\t\t\t\t\t\tdG9uLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAhsR/mkH2\n\t\t\t\t\t\tpEjNzEduiMVW7wu/no0JAcOD/EcR9ahH61oTkQMgfgMen7daVq7inRLptsV/bI1m\n\t\t\t\t\t\tWTF+Tzh49zxomLsHpf88yt8AbGMVy2oTWU69H4AN2b3L81h2psONA8AgHU/8ifUY\n\t\t\t\t\t\tRKtAmXGPd4Po5fVqG8zrTys/QKYAZJF4uUaCNSsSE5s5YnbTQieq69N/Z9TjhgUx\n\t\t\t\t\t\tW2hKmjKze2wPmyR2FVT/mqY8J8aLRL/VYXees210zs1F5V+PDVrfblrlrvy8vYG0\n\t\t\t\t\t\tV7vktx+P8P12hwj+dDy2i6Re7R02W5WNrPq6Yu66Q7IkUCeFkclCIom6JEXz8XUP\n\t\t\t\t\t\t7lSL3h2EhUOgXQIDAQABo3MwcTBQBgNVHREESTBHghZwcC53ZWJhdXRoLnNvdG9u\n\t\t\t\t\t\tLmFjLnVrhi1odHRwczovL3BwLndlYmF1dGguc290b24uYWMudWsvaWRwL3NoaWJi\n\t\t\t\t\t\tb2xldGgwHQYDVR0OBBYEFBTJEexZ7VRA9DX/eiB9OwNfBS5jMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQAw2wkGyB4qxKKCRDKddaje78ND2bkMl0mKWBMDujL7KIYIOZvbkCL1\n\t\t\t\t\t\t9InkQvU+PIu6lIFUvfmx2AbccHWf/o2IKi83UOrvb/e3QocIqnOIA0fX6Ivsnr88\n\t\t\t\t\t\tJfkdJfXNBh8ucc1N6joFNX2a8mR4ywv/QRAwHujF+AwsHz9AiBYJHV9YgbSKo326\n\t\t\t\t\t\t6cCK0I5oyB3iimdExWcc+a074sggo5kujGJhxhnHbB6BNFGjkc5kG+KR9udWk06t\n\t\t\t\t\t\tEddY9+fUrCdg5phPGLs5NLiYi7mTepVcUKkO07jjxON2mLDiRsVQpzMRoo7hscag\n\t\t\t\t\t\tzdj3Io3snavfZFcTxv/baypmvAmZ0ymK"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "soton.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://pp.webauth.soton.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://pp.webauth.soton.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://pp.webauth.soton.ac.uk/shibboleth-idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pp.webauth.soton.ac.uk/shibboleth-idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://pp.webauth.soton.ac.uk/shibboleth-idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://pp.webauth.soton.ac.uk/shibboleth-idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://pp.webauth.soton.ac.uk:8443/shibboleth-idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://pp.webauth.soton.ac.uk:8443/shibboleth-idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "soton.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVAKwAy5Y30bYosT2rmKq0Nj3qJE+DMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCExHzAdBgNVBAMTFnBwLndlYmF1dGguc290b24uYWMudWswHhcNMTEwNDA1\n\t\t\t\t\t\tMTYxNTA5WhcNMzEwNDA1MTYxNTA5WjAhMR8wHQYDVQQDExZwcC53ZWJhdXRoLnNv\n\t\t\t\t\t\tdG9uLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAhsR/mkH2\n\t\t\t\t\t\tpEjNzEduiMVW7wu/no0JAcOD/EcR9ahH61oTkQMgfgMen7daVq7inRLptsV/bI1m\n\t\t\t\t\t\tWTF+Tzh49zxomLsHpf88yt8AbGMVy2oTWU69H4AN2b3L81h2psONA8AgHU/8ifUY\n\t\t\t\t\t\tRKtAmXGPd4Po5fVqG8zrTys/QKYAZJF4uUaCNSsSE5s5YnbTQieq69N/Z9TjhgUx\n\t\t\t\t\t\tW2hKmjKze2wPmyR2FVT/mqY8J8aLRL/VYXees210zs1F5V+PDVrfblrlrvy8vYG0\n\t\t\t\t\t\tV7vktx+P8P12hwj+dDy2i6Re7R02W5WNrPq6Yu66Q7IkUCeFkclCIom6JEXz8XUP\n\t\t\t\t\t\t7lSL3h2EhUOgXQIDAQABo3MwcTBQBgNVHREESTBHghZwcC53ZWJhdXRoLnNvdG9u\n\t\t\t\t\t\tLmFjLnVrhi1odHRwczovL3BwLndlYmF1dGguc290b24uYWMudWsvaWRwL3NoaWJi\n\t\t\t\t\t\tb2xldGgwHQYDVR0OBBYEFBTJEexZ7VRA9DX/eiB9OwNfBS5jMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQAw2wkGyB4qxKKCRDKddaje78ND2bkMl0mKWBMDujL7KIYIOZvbkCL1\n\t\t\t\t\t\t9InkQvU+PIu6lIFUvfmx2AbccHWf/o2IKi83UOrvb/e3QocIqnOIA0fX6Ivsnr88\n\t\t\t\t\t\tJfkdJfXNBh8ucc1N6joFNX2a8mR4ywv/QRAwHujF+AwsHz9AiBYJHV9YgbSKo326\n\t\t\t\t\t\t6cCK0I5oyB3iimdExWcc+a074sggo5kujGJhxhnHbB6BNFGjkc5kG+KR9udWk06t\n\t\t\t\t\t\tEddY9+fUrCdg5phPGLs5NLiYi7mTepVcUKkO07jjxON2mLDiRsVQpzMRoo7hscag\n\t\t\t\t\t\tzdj3Io3snavfZFcTxv/baypmvAmZ0ymK"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Southampton (Testing)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.soton.ac.uk/iss/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Southampton"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://certify.skidmore.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "amjones@skidmore.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam Michael Jones"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cwilliam@skidmore.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Cliff Williams"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jclark@skidmore.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jeffrey A. Clark"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://certify.skidmore.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://certify.skidmore.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://certify.skidmore.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://certify.skidmore.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://certify.skidmore.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://certify.skidmore.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "skidmore.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Creative Thought Matters"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Skidmore College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAPIx9cT4q8AyR4ueZ8uIqpunypyjMA0GCSqGSIb3DQEB\nBQUAMB8xHTAbBgNVBAMTFGNlcnRpZnkuc2tpZG1vcmUuZWR1MB4XDTEyMDQyNTE4\nMDc1M1oXDTMyMDQyNTE4MDc1M1owHzEdMBsGA1UEAxMUY2VydGlmeS5za2lkbW9y\nZS5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCgQIzapjdutN/r\n2SVjlA0XDyQQ4Py3VUdFTxCm0s+aieDUnyY5H55z7q6a6SbGeC6r0voThzAp8fGv\n64XVxQaWFN/gv+7GnSHfORcSlpenXfVsPPW/BA/x2IKg2c/BfeRjmU8W7AZMgUcI\nnVj8sFzyF8OtglcQe/+V9TjvSdmOEIWG5mt0Up9oeOmHbe9eYvq+LPORGamQUHj0\niJIlJfiAMEm+bCuET4SbO1IUuv65oR77YuZcSWlVaP4NRbrqopO8ULiYkOMIEaZ2\nPbx+dhKgQJijFfbDFFzlFizV9AY7wt0nGMcGheFVUch7D/l12h4fHBTAGAcPYj3H\nT+AsiQq1AgMBAAGjbzBtMEwGA1UdEQRFMEOCFGNlcnRpZnkuc2tpZG1vcmUuZWR1\nhitodHRwczovL2NlcnRpZnkuc2tpZG1vcmUuZWR1L2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBQNIBXsa4ErtKvaykTt91WpA/q8xzANBgkqhkiG9w0BAQUFAAOCAQEA\nkwApou7fsK8oUx7AJC2t1JzqkbJaOpaUG/UdUPvOzBplnqqugy17Ug7HSy2/trKE\nmL7bPPuRi6p42sBGJwPCm3hC2gFfXmFWmMYTtO53zJNktXmfaTBtVZKHlpUVsXtG\n0uzPK5BoH9lpGwscn7JDMtC2qsF6HIZtRIPrPOnux/JznM8WyBaaE9HoSqzluRkk\nHOEet5gtgNt//cgfVwFISX0I3Uh/Wk9nHadr/pu9L2rz2Gkb+2LxBC5iKOtL5oW/\nq7QweOtDE18IwI4JCw4nsvU2YFZw9ooyK9f3w+tj6rV56cN22EpefXNOM4pZRP7D\nbGUHwACZ7MErl4ABbfZpVQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Skidmore College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.skidmore.edu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Skidmore College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth-idp.gwdg.de/gwdg/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Adler"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:daniel.adler@gwdg.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Daniel"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pohl"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:christof.pohl@gwdg.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Christof"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth-idp.gwdg.de/gwdg/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2014-01-16T13:09:19Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shibboleth-idp.gwdg.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGETCCBPmgAwIBAgIHGcwgX+yB9TANBgkqhkiG9w0BAQsFADCBuzELMAkGA1UE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\nJpA2gfQhkeFqqwJRdF6UeVYRdtar"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=shibboleth-idp.gwdg.de,O=Gesellschaft fuer wissenschaftliche Datenverarbeitung,L=GOETTINGEN,ST=NIEDERSACHSEN,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gwdg.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth-idp.gwdg.de:8443/gwdg/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-idp.gwdg.de:8443/gwdg/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth-idp.gwdg.de/gwdg/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth-idp.gwdg.de/gwdg/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-idp.gwdg.de:8443/gwdg/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth-idp.gwdg.de/gwdg/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth-idp.gwdg.de/gwdg/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth-idp.gwdg.de/gwdg/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth-idp.gwdg.de/gwdg/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth-idp.gwdg.de:8443/gwdg/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth-idp.gwdg.de:8443/gwdg/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gwdg.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://gwdg.de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://gwdg.de"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Gesellschaft f\u00fcr wissenschaftliche Datenverarbeitung mbH G\u00f6ttingen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Gesellschaft f\u00fcr wissenschaftliche Datenverarbeitung mbH G\u00f6ttingen"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Wir bieten als Hochschulrechenzentrum f\u00fcr die Georg-August-Universit\u00e4t G\u00f6ttingen und als Rechen- und IT-Kompetenzzentrum f\u00fcr die Max-Planck-Gesellschaft ein breites Spektrum an Informations- und Kommunikationsleistungen f\u00fcr die Wissenschaft."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "We offer as a university computer center of the Georg-August-University of G\u00f6ttingen and as computing and IT competence center for the Max Planck Society, a wide range of information and communication services to science."
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth-idp.gwdg.de/favicon.ico",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://shibboleth-idp.gwdg.de/logo.png",
                    "height": "72",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "240"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.gwdg.de/index.php?id=impressum"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.gwdg.de/index.php?id=impressum"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shibboleth-idp.gwdg.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGETCCBPmgAwIBAgIHGcwgX+yB9TANBgkqhkiG9w0BAQsFADCBuzELMAkGA1UE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\nJpA2gfQhkeFqqwJRdF6UeVYRdtar"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=shibboleth-idp.gwdg.de,O=Gesellschaft fuer wissenschaftliche Datenverarbeitung,L=GOETTINGEN,ST=NIEDERSACHSEN,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Gesellschaft f\u00fcr wissenschaftliche Datenverarbeitung mbH"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Gesellschaft f\u00fcr wissenschaftliche Datenverarbeitung mbH"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gwdg.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gwdg.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e112"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e112"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-p10.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-p10.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p10.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p10.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p10.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p10.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p10.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-p10.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-p10.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;p10"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;p10"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-p10.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-p10.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIJAINTr7hfhL9iMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2xhZG9rMy1wMTAubGFkb2sudW11LnNlMB4XDTE1MDIwOTEwNDEzNloXDTI1\nMDIwNjEwNDEzNlowIjEgMB4GA1UEAxMXbGFkb2szLXAxMC5sYWRvay51bXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDU/yuAJV0BuTbPMcYbwLxi\noneZh91NJJbL94zB7ffpgpF8BY4pKnXsbVfnxAR6jFVLPzduqAZ9DOdDPStRZ3k9\nYb8VtLZDRXTAkTF4Mw6Je8DwCH6OJFTmxpXtMKCWnMgHe/GIwRlyKI6U30YlmPUr\nwj9pm3n7UurAGwuB/oTnyW6+SMUJT2p1FqyZaV2uYZwoMPsPzVo7IFJV96Ck7B2h\nAgTp4LidFtp8ZJL3y61xmqdWZo0lNbJ1IGu0yYxJA6qg0vFv/6bHB8/3CSgEcoDM\nC79dORZuRWU5jVQCjqmZcgRS3sMu+lNo9u/FeO8v4rgVmLFhopWtYK806z31gZ2P\nAgMBAAGjbTBrMEoGA1UdEQRDMEGCF2xhZG9rMy1wMTAubGFkb2sudW11LnNlhiZo\ndHRwczovL2xhZG9rMy1wMTAubGFkb2sudW11LnNlL2d1aS1zcDAdBgNVHQ4EFgQU\nf35VL0UcsvOvRVK710Mtd7ZzFPkwDQYJKoZIhvcNAQEFBQADggEBAEdFZ5Q8S9lZ\nLBGroILwIIJ9y7Mtlkt74ulYseO0Z9/rPGUHYHv17XtYyD8p5xR+GsS6oFNHoz9D\nS+LjnfwTm1/u6C1mQqOuCKgTtf0YTH8D7IQG/YNY2kGvat02E67vakU6Fx3CqZyS\n0o18DgKsK93LPVz/3SvRgxusCnRi8LIRCY60/0XJkciK9OFpx2h9HJz5xUSJ8qUz\nizzNx59X+rZa01bxN9OX+18JKCyeD8XcV2aowwgZ9p1gGE11ET/jOLTAOLQYbbBZ\npDrLD8jQLkvfTRcOFmn560KGiJwYHa1E0iCEmv7m6ZBQuOxEpRXCJ3ASbuicTCtA\nijxYszxjc/c="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-p10.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p10.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p10.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p10.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p10.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p10.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p10.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-p10.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-p10.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-p10.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://access.hro.nl/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://access.hro.nl/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2014-12-05T00:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/080d16c1fde039152735783fffd2c0c2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hogeschool Rotterdam"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hogeschool Rotterdam"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/sp/hro-logo.png",
                    "height": "75",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "75"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hogeschool Rotterdam"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rotterdam University of Applied Sciences"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hogeschool Rotterdam"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Rotterdam University of Applied Sciences"
          }
        ],
        "organization_url": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hro.nl"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hro.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "nl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hogeschool Rotterdam"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Rotterdam University of Applied Sciences"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://tcs-personal.sunet.se/simplesamlphp/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "LIS Unix"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lis-unix@uvt.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UvT"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://tcs-personal.sunet.se/simplesamlphp/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish University Network (SUNET)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sunet.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SUNET"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://tcs-personal.sunet.se/simplesamlphp/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://tcs-personal.sunet.se/simplesamlphp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://tcs-personal.sunet.se/simplesamlphp/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://tcs-personal.sunet.se/simplesamlphp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://tcs-personal.sunet.se/simplesamlphp/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://wiki.larpp.internet2.edu/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tmitrano@internet2.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tracy Beth Mitrano"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@lists.larpp.internet2.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LARPP Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@lists.larpp.internet2.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LARPP Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@lists.larpp.internet2.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LARPP Incident Response"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://wiki.larpp.internet2.edu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Internet2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.internet2.edu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Internet2"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://wiki.larpp.internet2.edu/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://wiki.larpp.internet2.edu/confluence/display/SPIN/SP+Information"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Lifestyles of the Attribute Rich and Privacy Preserved (LARPP) Wiki"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Lifestyles of the Attribute Rich and Privacy Preserved (LARPP) is an activity funded by the National Strategies for Trusted Identities in Cyberspace (NSTIC) as part of the Scalable Privacy grant awarded to Internet2.   This activity supports pilot schools to investigate privacy management software, named PrivacyLens, to provide users with information and choices that allow them to exercise active, informed consent about the release of personal information, or \u201cattributes,\u201d in course of authentication to web sites and on-line services. This SP supports the LARPP wiki."
                  }
                ],
                "logo": [
                  {
                    "text": "https://wiki.larpp.internet2.edu/img/larpp_logo_transparent_275wX150h.png",
                    "lang": "en",
                    "height": "150",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "275"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.internet2.edu/privacy.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIJAL9sC3mP5/uMMA0GCSqGSIb3DQEBBQUAMCcxJTAjBgNV\nBAMTHHJlZ2lzdHJ5LmxhcnBwLmludGVybmV0Mi5lZHUwHhcNMTQwNDI5MTYwOTQz\nWhcNMjQwNDI2MTYwOTQzWjAnMSUwIwYDVQQDExxyZWdpc3RyeS5sYXJwcC5pbnRl\ncm5ldDIuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0kSJBA6Z\neqoV7iBaEWg879SeOw29W2G5lBWDaqFaBYTH00WJCF5C+okSmc7bFNfbbk3zhams\nP6ZW9x52lc5AZopKidHmEJLFw54ZnEOgsxdjs5jb+iyoOOblxIbyoa10YsHsTzWV\nM3HGhXStTZJj805dTXxxkAaw2r5l4rT6h3DdkpDoSn2Ofdz9/V/HrpFIq2QHEaoU\n/pTscCaiX6ScTcpwjvYnkWubsP1QUTpukqL8GqESAulhSb9EZxAVdNwkDHSqYXjA\nk4ViF69MApkII7z5Kge4Ga27JQqxIJ6ymZMu2nkx49fezWMi3yOutxGm9lSO3SMP\nfndgfgvFRGMJcwIDAQABo0owSDAnBgNVHREEIDAeghxyZWdpc3RyeS5sYXJwcC5p\nbnRlcm5ldDIuZWR1MB0GA1UdDgQWBBQKBLaZOFBkfMFBvncyNI+q/+FuPjANBgkq\nhkiG9w0BAQUFAAOCAQEAgc2npKbviJmtknUn1aSMFCfUPjUWtO4QWP8IhYO3gC9r\n/J1EUsgxJDYuLVdsye/2mSz9y37O0TJ+bcwh9RRoo21vxj7UsKn7Crrux171dkCa\nJ3J2czLUAOcZzoIxDM1mOUyI0D9QANpPxOH6707c8PSrNLk+5la7rpHXATPDyJlc\nwz1/tj+w3FgJhPG0qY+TOMGPSe+UagL2O4LMAyFk7I8vEWi60BlO52npDhaYGXeo\nmA/jv7XqqSBfGCvHS973BG/tP1XfuwmpJqgx00x0wQlbPweIH3RmmCg3S11ZCZi8\nQpkmgq5ZqYDMrzfYjwLpl5kpRrMdP/1Nw6g2BGe6qA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wiki.larpp.internet2.edu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://wiki.larpp.internet2.edu/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wiki.larpp.internet2.edu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://wiki.larpp.internet2.edu/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Lifestyles of the Attribute Rich and Privacy Preserved (LARPP) Wiki"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Lifestyles of the Attribute Rich and Privacy Preserved (LARPP) is an activity funded by the National Strategies for Trusted Identities in Cyberspace (NSTIC) as part of the Scalable Privacy grant awarded to Internet2.   This activity supports pilot schools to investigate privacy management software, named PrivacyLens, to provide users with information and choices that allow them to exercise active, informed consent about the release of personal information, or \u201cattributes,\u201d in course of authentication to web sites and on-line services. This SP supports the LARPP wiki."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.it.gu.se/shibboleth",
    {
      "entity_id": "https://sp.it.gu.se/shibboleth",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "G\u00f6teborgs universitet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gu.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GU"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.it.gu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.it.gu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.it.gu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.it.gu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.it.gu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp.it.gu.se/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "sp.it.gu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9TCCAd2gAwIBAgIJAPYrC72akwsZMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC3NwLml0Lmd1LnNlMB4XDTEwMTIwMjE1MzkwOFoXDTE1MTIwMTE1MzkwOFow\nFjEUMBIGA1UEAxMLc3AuaXQuZ3Uuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQDZx2MH0AOUIZouNQyGwtj/+M8BFtvusld5mn7PoLiCaEmTU2p4LVmr\nhRwsWuGLkJtqqONNfLh8aAJI47Wj+pLHKsTCrQjnPQdttE8blSpfjjuaOEHsPIio\nLnsxL0fuoGrDx4kb3UyICGvLntNXUuq6mvFqPwgw/650ZVIsnS8aS3hiUrxJG8tt\ntBFDXf53aDJx+VQuuKvAZ79ZXUoOUEX4XkL2xq7Bz5ljjfJd7IUAEjuSWCHyz1yZ\n2KqjJ9uCyi2DeiSCoibLM6GcuQP0AY2vE3h1aidK9sr64jPa5hnhMnimtmsa29K+\nP0etzBGrjrzStwaVKjqIinSZU+PLf7sPAgMBAAGjRjBEMCMGA1UdEQQcMBqCC3Nw\nLml0Lmd1LnNlhgtzcC5pdC5ndS5zZTAdBgNVHQ4EFgQU6/iWGhM8RnEGVjRFECtZ\nMsTWx/swDQYJKoZIhvcNAQEFBQADggEBAFvQ2wiEugd9cy2LG9sI88uINEMnLT+H\nbRroFbK0mOppXbDxVHmc+EWWVqQ9xc/JHdnd19cXSFuc6SmY7Lx5su0rIFv7/h8m\nHduwiIXFs3axucyl26ZKMltDOLpym9KK5u2NQXJYN7BpXq4sjtZlPLH2p9ShmoQ7\ns4wKEXrYSsBU/pTRFg60FNwo2OvJAuVRmPmESVn5YJ8AguUjeNWfiPAmUKhEofhK\npMGOQDUYW5u9fPy/O+qRzF3xhMLSOejkdwCC2kKEDVKxo27wy6CLeedBAWTj3ERu\nQ9GZYzxeMEXXQg7nerDoFisoBc8c6+jlak7yEX8v5GIZSKV1XHui/yc="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=sp.it.gu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "sp.it.gu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9TCCAd2gAwIBAgIJAPYrC72akwsZMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC3NwLml0Lmd1LnNlMB4XDTEwMTIwMjE1MzkwOFoXDTE1MTIwMTE1MzkwOFow\nFjEUMBIGA1UEAxMLc3AuaXQuZ3Uuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQDZx2MH0AOUIZouNQyGwtj/+M8BFtvusld5mn7PoLiCaEmTU2p4LVmr\nhRwsWuGLkJtqqONNfLh8aAJI47Wj+pLHKsTCrQjnPQdttE8blSpfjjuaOEHsPIio\nLnsxL0fuoGrDx4kb3UyICGvLntNXUuq6mvFqPwgw/650ZVIsnS8aS3hiUrxJG8tt\ntBFDXf53aDJx+VQuuKvAZ79ZXUoOUEX4XkL2xq7Bz5ljjfJd7IUAEjuSWCHyz1yZ\n2KqjJ9uCyi2DeiSCoibLM6GcuQP0AY2vE3h1aidK9sr64jPa5hnhMnimtmsa29K+\nP0etzBGrjrzStwaVKjqIinSZU+PLf7sPAgMBAAGjRjBEMCMGA1UdEQQcMBqCC3Nw\nLml0Lmd1LnNlhgtzcC5pdC5ndS5zZTAdBgNVHQ4EFgQU6/iWGhM8RnEGVjRFECtZ\nMsTWx/swDQYJKoZIhvcNAQEFBQADggEBAFvQ2wiEugd9cy2LG9sI88uINEMnLT+H\nbRroFbK0mOppXbDxVHmc+EWWVqQ9xc/JHdnd19cXSFuc6SmY7Lx5su0rIFv7/h8m\nHduwiIXFs3axucyl26ZKMltDOLpym9KK5u2NQXJYN7BpXq4sjtZlPLH2p9ShmoQ7\ns4wKEXrYSsBU/pTRFg60FNwo2OvJAuVRmPmESVn5YJ8AguUjeNWfiPAmUKhEofhK\npMGOQDUYW5u9fPy/O+qRzF3xhMLSOejkdwCC2kKEDVKxo27wy6CLeedBAWTj3ERu\nQ9GZYzxeMEXXQg7nerDoFisoBc8c6+jlak7yEX8v5GIZSKV1XHui/yc="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=sp.it.gu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.it.gu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.it.gu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.it.gu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.it.gu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.it.gu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp.it.gu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.it.gu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp.it.gu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp.it.gu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp.it.gu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sso.brockport.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@brockport.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IDM Team"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@brockport.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IDM Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@brockport.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IDM Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "infosec@brockport.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Security Team"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://sso.brockport.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso.brockport.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.brockport.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.brockport.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.brockport.edu/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.brockport.edu/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brockport.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SUNY College at Brockport Shibboleth Identity Provider"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.brockport.edu/privacy/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SUNY College at Brockport"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUSXda9Cn6rn9RL58UpIkGcNAMDzkwDQYJKoZIhvcNAQEF\nBQAwHDEaMBgGA1UEAxMRc3NvLmJyb2NrcG9ydC5lZHUwHhcNMTQwNTAyMTQxMzI1\nWhcNMzQwNTAyMTQxMzI1WjAcMRowGAYDVQQDExFzc28uYnJvY2twb3J0LmVkdTCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJxJiHgL4ar8q+COPbMY3T/4\nDdq8XnOxJSnn3Qldu8Ndgt9quM5ZatFU2u7hrt+tDXWrP2ZLRDibgXg/VkKv0f95\nABwU5RJ7Nagyzi4Ekjf1Ji4WsP0d28bAQFspL2IXwpAbKCpPqlGnwu0Op5JRisaC\ncnhdV4Uk91+WWsq2uPw+22qrjJ3DFCip+BGuEf99nFHFmle6fgEdVTqaMeOWNTxp\nu37D1zdSYDLrw6J7/tMujq/rEge1YNgXSA2FKVuGvF6Q+u1zCSDp/hYXPECkyjV9\n3Y/VWHUlWS03h24oRY51snDFKQeDStG7tO6nGwSdFg6jycD4ATgJkEABtQGBGvEC\nAwEAAaNpMGcwRgYDVR0RBD8wPYIRc3NvLmJyb2NrcG9ydC5lZHWGKGh0dHBzOi8v\nc3NvLmJyb2NrcG9ydC5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFF3v7hrS\nCk8K9TwhQESH4LnGiaJHMA0GCSqGSIb3DQEBBQUAA4IBAQBlAXKQ0F4mgTrxsYrZ\nuaUXvu9m+rVgabmb+ArdyF5lMOq4vEL0iaLVk8fTkEYHsbxzHWrx5x3kOV00+WSu\nJnw9gjunc3RzWQspVL88zgz7+p6JRevLCYR/G80GRCWHyEHuHfyjFpWP0FwjVmYS\nQIJrbZrOobpo3ij3AA9pN40xHI/wi4yw7YWOszxvZwZhem5qDy1/FjcH0I6gcWSj\ncqCDBhqRUJe828mS3ErtmfnxOXH6n91qvNX1/wGrrlvCSCZYT4UdgCHU97I7hN/z\ndFjJO/qm55k8j8PB8w9d2Ge93K0lH5OkiWJ54lHwvJTRBBF+w0duZ9Cp+U90+EF8\ntAha"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://sso.brockport.edu/idp/"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SUNY College at Brockport"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.brockport.edu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SUNY College at Brockport"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://lpwdev.it.ki.se/shibboleth",
    {
      "entity_id": "https://lpwdev.it.ki.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lpwdev.it.ki.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lpwdev.it.ki.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lpwdev.it.ki.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lpwdev.it.ki.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lpwdev.it.ki.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://lpwdev.it.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://lpwdev.it.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://lpwdev.it.ki.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "kiladokdev.it.ki.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJAMp62nwgYW3jMA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE2tpbGFkb2tkZXYuaXQua2kuc2UwHhcNMTEwNTA2MDk0MzI0WhcNMjEwNTAz\nMDk0MzI0WjAeMRwwGgYDVQQDExNraWxhZG9rZGV2Lml0LmtpLnNlMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxM8SLReq15M/D/J0ETBYZvMTVMpeno0B\n5d/ax2AOsJPn/4rzzVTTtIMroxr8yXKZ0RIxg+WsBqsNzhTEvzHa850rs0fZ9vkn\nmYWzBR13XFI0e6bS3jmqw5qFLQP6AsQ4Nfnw+BJILpRZSAVa9dTdfuAMGWT5t3VO\n6BgSvoxFgnvewR1yHuwZwnyHd3wqQIXlL7AibGSf+yoeCmatDueEn563ScU/62E6\nEBFcQFPC0vLC8w6XVwD4wVKyZXeTGG5fR4TUPeg6DaNc+jod59A9x6L0SZSMRqpe\noaAy2xTIY1aVYi6KAnDI2Zo+Aqazi9S8v+V7Euzhkq81M4s8fZDvgwIDAQABo0Ew\nPzAeBgNVHREEFzAVghNraWxhZG9rZGV2Lml0LmtpLnNlMB0GA1UdDgQWBBTNYLed\nxgm2UWlp89Kv854gx1F84TANBgkqhkiG9w0BAQUFAAOCAQEAqnJVmyJnj6/6C5uC\n2K7FhlIyNm4sgzh+OzirRbGg+5P/hCUzv9AbjVyichts8L1BGdRrDTd6alWAe8jo\nmolQUIizH5+reZIql9bjGCOkbrhTVLmzx8Tv4jCa202nXdrAazzBpbYf8JYGGSep\nD68STfoiiCfJrq2tiHPLhyaRthmHIP+kpG3QLNnWfg5T6f+gfDy6/EKnFDAD+oSq\nT3KdvO0Zx0+2keQLPgImrfPgNtMK9mcLeYwjopvXGfABSJ77OKER8alPcW1NVQM9\n1ykeP8ZFUW1tLe1vSfWMX7xVAPRLKPHDVHcANNvpncnz+Qb/RyXRAyEXnpNNurRQ\n9c/C1Q=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=kiladokdev.it.ki.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lpwdev.it.ki.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://lpwdev.it.ki.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lpwdev.it.ki.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://lpwdev.it.ki.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://lpwdev.it.ki.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://lpwdev.it.ki.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://connect-test.sunet.se/shibboleth",
    {
      "entity_id": "https://connect-test.sunet.se/shibboleth",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish University Network (SUNET)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sunet.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SUNET"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://connect-test.sunet.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://connect-test.sunet.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect-test.sunet.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect-test.sunet.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://connect-test.sunet.se/Shibboleth.sso/DS/nordu.net",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "acp-web.sunet.se"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://acp-web.sunet.se/shibboleth"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIJAKkN4aqE4O7tMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGFjcC13ZWIuc3VuZXQuc2UwHhcNMDkwNjE3MTAwNTA1WhcNMTkwNjE1MTAw\nNTA1WjAbMRkwFwYDVQQDExBhY3Atd2ViLnN1bmV0LnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA3iWXh1+ub5i8ZOypk7syIpndivWpp4jbcMYpmiEX\nq9Jym97j7x9WXc0vNrmKkccoUcWU1FgoiiXso6vhdgzKkqrcBIzc/YJpphN5K3tt\npVabdgV9TG6PJ0Q6k07bvZew9yEhpXDE3gfKLOFAKeSUILHGc2FBU32EuBqVt/sn\nzBleOEBb3tiIB9/YCZS2A6wtnvzGY1mUX27Vyv2SH6Bx/GlmWuTJRrv01avrldfv\n3CiFrCeeAfLfnljfy4WbpszzlqBQvaZFBaBRtg1AgmFNkryTCm5yO2BrM3NyurN/\nK/Uc/YBZ8thxQPSEeUVWHCStXTQGLREYwJKZMfp4yFhzeQIDAQABo2MwYTBABgNV\nHREEOTA3ghBhY3Atd2ViLnN1bmV0LnNlhiNodHRwczovL2FjcC13ZWIuc3VuZXQu\nc2Uvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUmtnePgSQNSvDZIox3d5mG/+AJb8wDQYJ\nKoZIhvcNAQEFBQADggEBAIaEDBm1eN9o7j0cQBQQNMh1FJFX2h1EklGj4YgXbqjj\nBy3duIzXVAut+z4VtCTGx2CjQ1YcmSqWvx7+XFY0xEnmuAMUw8rdp0OR2Sk0iU4/\nBZt5125JOtJRRVJIDz4n9jbf6NNUsP4+HA0ukqyHDrTD0+30IV48MaWxR7HdPpyE\nbCMK0FZIQYm6d3zSgZW6ofsx24AonFZBtJBCQZxdInvqg2eYemOUh37vEBxbjWqE\n51pFWLbVUit84wy8eG3E28OPa64gc/VNk1XEj1ILLzXFV59XuZG2jzjB9xCyPmHW\niMkYL+yQK1JqNXDJwr+eW3+iWptUXnyRCnGBrYMAvqw="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=acp-web.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "acp-web.sunet.se"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://acp-web.sunet.se/shibboleth"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIJAKkN4aqE4O7tMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGFjcC13ZWIuc3VuZXQuc2UwHhcNMDkwNjE3MTAwNTA1WhcNMTkwNjE1MTAw\nNTA1WjAbMRkwFwYDVQQDExBhY3Atd2ViLnN1bmV0LnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA3iWXh1+ub5i8ZOypk7syIpndivWpp4jbcMYpmiEX\nq9Jym97j7x9WXc0vNrmKkccoUcWU1FgoiiXso6vhdgzKkqrcBIzc/YJpphN5K3tt\npVabdgV9TG6PJ0Q6k07bvZew9yEhpXDE3gfKLOFAKeSUILHGc2FBU32EuBqVt/sn\nzBleOEBb3tiIB9/YCZS2A6wtnvzGY1mUX27Vyv2SH6Bx/GlmWuTJRrv01avrldfv\n3CiFrCeeAfLfnljfy4WbpszzlqBQvaZFBaBRtg1AgmFNkryTCm5yO2BrM3NyurN/\nK/Uc/YBZ8thxQPSEeUVWHCStXTQGLREYwJKZMfp4yFhzeQIDAQABo2MwYTBABgNV\nHREEOTA3ghBhY3Atd2ViLnN1bmV0LnNlhiNodHRwczovL2FjcC13ZWIuc3VuZXQu\nc2Uvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUmtnePgSQNSvDZIox3d5mG/+AJb8wDQYJ\nKoZIhvcNAQEFBQADggEBAIaEDBm1eN9o7j0cQBQQNMh1FJFX2h1EklGj4YgXbqjj\nBy3duIzXVAut+z4VtCTGx2CjQ1YcmSqWvx7+XFY0xEnmuAMUw8rdp0OR2Sk0iU4/\nBZt5125JOtJRRVJIDz4n9jbf6NNUsP4+HA0ukqyHDrTD0+30IV48MaWxR7HdPpyE\nbCMK0FZIQYm6d3zSgZW6ofsx24AonFZBtJBCQZxdInvqg2eYemOUh37vEBxbjWqE\n51pFWLbVUit84wy8eG3E28OPa64gc/VNk1XEj1ILLzXFV59XuZG2jzjB9xCyPmHW\niMkYL+yQK1JqNXDJwr+eW3+iWptUXnyRCnGBrYMAvqw="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=acp-web.sunet.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://connect-test.sunet.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://connect-test.sunet.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect-test.sunet.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect-test.sunet.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect-test.sunet.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://connect-test.sunet.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect-test.sunet.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://connect-test.sunet.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://connect-test.sunet.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://connect-test.sunet.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://inloggen.hogeschoolutrecht.nl/openaselect/profiles/saml2/",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://inloggen.hogeschoolutrecht.nl/openaselect/profiles/saml2/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-04-24T12:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/265c1f948fe360d0755dfd7310985bc0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hogeschool Utrecht"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hogeschool Utrecht"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/hu.png",
                    "height": "39",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hogeschool Utrecht"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "HU University of Applied Sciences Utrecht"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hogeschool Utrecht"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hu.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Applied Sciences Utrecht"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.sworcs.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ithelpdesk@sworcs.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Neath"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tneath@sworcs.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tony"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.sworcs.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-02-10T14:56:25Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sworcs.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sworcs.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.sworcs.ac.uk/idp/profile/SAML2/POST-SimpleSign/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sworcs.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.sworcs.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sworcs.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.sworcs.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sworcs.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sworcs.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sworcs.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "evesham.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://internal.evesham.ac.uk/intranet/img/icons/swc80x60pix.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "South Worcestershire College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAMBmzKWXYajA+5lcrW5Mg1lfTNGuMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMBsxGTAXBgNVBAMMEGlkcC5zd29yY3MuYWMudWswHhcNMTUwMjA1MDkzNDEz\n\t\t\t\t\t\tWhcNMzUwMjA1MDkzNDEzWjAbMRkwFwYDVQQDDBBpZHAuc3dvcmNzLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArEvWNYJ7gVZpZmulfiZv/Jnr\n\t\t\t\t\t\tm/4Oqh2+JEWW0mw4wvw9GbgVVgOL2ppzt22QdCiF9Ry6BRoYTVGeuW2Poncp5jHT\n\t\t\t\t\t\tqvmHXl6d0m6c+w/oTX8C5zwOs2c8kYHPDLwnqMoleuZTR7kK7GMs+DQoAn6+FXoH\n\t\t\t\t\t\t9qanFHx1pL3BYvFGUDmwNh91XLvDuBLFsdN0LPDNA6fcE8TKkV8KGf049pyqDi55\n\t\t\t\t\t\tpOo7IC1AcwZtm+HCH4s2lgFlQfRAmAK8u7+sBFzzHKb9Ey+DWlQSUKRbMhgeNXpZ\n\t\t\t\t\t\tQfhX8+kn0ytuUojYjGtlkFCWOan/Sr1s8n0tVzWGwJIYN+mNnjZt/NHdcnGVvwID\n\t\t\t\t\t\tAQABo2cwZTAdBgNVHQ4EFgQUHLtdodDvur7nmtVtQmi4QX51nQYwRAYDVR0RBD0w\n\t\t\t\t\t\tO4IQaWRwLnN3b3Jjcy5hYy51a4YnaHR0cHM6Ly9pZHAuc3dvcmNzLmFjLnVrL2lk\n\t\t\t\t\t\tcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQCbQ+3/saWmn1SDsIuL+Lj+\n\t\t\t\t\t\tQaZd0iJDzC9h2Itgcfj3IU9rqQTU9mOiSJb9dJokLWJBRc9zCQgMXtlK7Qx9PVJM\n\t\t\t\t\t\tCkR0VXU7+0JbNhcROY0dXVam6MZbI/zkmDjtALLayWk7XbTwCrli75BnqANPdMB4\n\t\t\t\t\t\tNNP+l0tyYjoJB5BZ1jpUVOJjDliQ2iDJIBHo+TeklaLDTyTqep5zXD8gYtmbGxeF\n\t\t\t\t\t\tTAgbjues+fafbNzKe6g96t8NRA5c+BegBm0cApLTI/zzDjba2uPSRCLbyED4QI2T\n\t\t\t\t\t\tps+pb/QgzksAN5Wj7M+takiz36hRSUYMH5AJTm/MeTKZ3DDpmHs9TZRf+4rIRbif"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVALRHbvHVOp59HaRxJ3BO3VYBu6htMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMBsxGTAXBgNVBAMMEGlkcC5zd29yY3MuYWMudWswHhcNMTUwMjA1MDkzMzU0\n\t\t\t\t\t\tWhcNMzUwMjA1MDkzMzU0WjAbMRkwFwYDVQQDDBBpZHAuc3dvcmNzLmFjLnVrMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmKOzw9xaYI3e4NtFEc8L+xls\n\t\t\t\t\t\tzHjKwKLMEIDi84hDgIbChj80niWrgiYde2qJB+YlvsOKMMahmhTty88FaQQd8jAL\n\t\t\t\t\t\ttBC/kp1Ki/uyD0bEdAZ2H6bC0ybfslf5JjwYZM3v6/Ycp2juSvi4FEbqSsjO3s6y\n\t\t\t\t\t\t9X6mE8uINSHnVIcmrOMfHXmQZVega2KO/COQrn6WjYSoPrkRYqGieX0Se+LEHfrA\n\t\t\t\t\t\t6TgG/k8l2tz6ldb64LOJX62ydGhPL4k+SjlrNX6CdEvKz6CPYKDm/HGL8g7hrjO3\n\t\t\t\t\t\tbafMnOZCRYOaV/OaOtH0+Ia0ZgtZVhlu+DreODcrKIUBy1Z5PWX2YcHVDrIj4QID\n\t\t\t\t\t\tAQABo2cwZTAdBgNVHQ4EFgQUDHIUiGmDeB+koqGpa3wsSGlmRi8wRAYDVR0RBD0w\n\t\t\t\t\t\tO4IQaWRwLnN3b3Jjcy5hYy51a4YnaHR0cHM6Ly9pZHAuc3dvcmNzLmFjLnVrL2lk\n\t\t\t\t\t\tcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQB3bZTeetJmBbRWFXk7zfyI\n\t\t\t\t\t\tt2zvL4k9V6aaH0SgUj4m1YbToGAedIsGXhCkbYAsgFFpylnQbG6u02RJTDHJ7lyN\n\t\t\t\t\t\tVhAhv/1FCLW/MVINSL93ciejFPOjBbZiU1iYNaI/5Cmk7yNytIJAVYn+HLWKc2GJ\n\t\t\t\t\t\tFvS3dsCkf7Td+Gnri398qnSObI3WOQhWwj1o/SIUJ5NqoJk9XHJj/6pkvkbQzzdU\n\t\t\t\t\t\tNpCaqWu34Y3xLq3zkalUWImULao/4fZtz4OVuvm+mZVGFjJWC3FwKOj46uDTv+1X\n\t\t\t\t\t\tmm72OxqpBVn6xiBTGOPANTruUzKvuFa7Ohbznc2gQXvGGUeUw6T3CaBCAei3pfKC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUR2mkXU3i/AK0KOIvY/W7Q557Ig8wDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwGzEZMBcGA1UEAwwQaWRwLnN3b3Jjcy5hYy51azAeFw0xNTAyMDUwOTM0MTJa\n\t\t\t\t\t\tFw0zNTAyMDUwOTM0MTJaMBsxGTAXBgNVBAMMEGlkcC5zd29yY3MuYWMudWswggEi\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCqKUhOBtt5q7ETDkUjbD/KENaE\n\t\t\t\t\t\trKtUaexbH5DzSolqsIOC4Ca1t6NVA92jDrl7iSy3CxoOS6KtOAfvjrlQ9oMOjQgS\n\t\t\t\t\t\tvwsvIeeFzyRnVwaQgR410Zoe/xDI6kS13dLKnKjgaz6j8bCtLvT1VKb27X8wtocF\n\t\t\t\t\t\tZqIasmQLh5kpEP9h5NpXrPIPeE/VfG5h5b6KcaNXjxI0x9lhkQY+t+R9+CM+Pxho\n\t\t\t\t\t\tRIOZ5yzGVYxpd8iwSTg+VEI/nQ09pdvGRNC/EcFocLMT/VT8+CPVwWuoUhXopl6s\n\t\t\t\t\t\tIpTuiVJk3+oi0DGKqoK7NxSFcxmeBSWFa4oUbP/j/Cqa6rG5rz9jOetJsWklAgMB\n\t\t\t\t\t\tAAGjZzBlMB0GA1UdDgQWBBQMt9lBmt9Tpm4HNoBLsmj7oYIoXDBEBgNVHREEPTA7\n\t\t\t\t\t\tghBpZHAuc3dvcmNzLmFjLnVrhidodHRwczovL2lkcC5zd29yY3MuYWMudWsvaWRw\n\t\t\t\t\t\tL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAGTTeBRCg+PawgdgFHEe46VQ\n\t\t\t\t\t\trBXhVm+h5LfaNXTlhKf3MD7AKTddVDOyNfhWX67aAQKO6C4r5sEKrCbzIi8w7y8H\n\t\t\t\t\t\ti3bSt17awmx58GPcSPICWGdlty8gkvaB+85QCLl3rURn9BwHyBs83mus3qiF1XfR\n\t\t\t\t\t\t0I1Sf1iOiBIn6YxOq6CpNLkPBVoo6kCZEgSs6pCAHRY51uZkiGrO9oGcGdS8W8Ql\n\t\t\t\t\t\ttMukNkGXjxDlGU7yN4Bb7bZI0bWLfQYIKMlDSnHP0utWX9CF6P31kBhDg4KdQ9sA\n\t\t\t\t\t\t4fMj1TQAMC8N11H7WA2qUpQtO09IQwfdyawo1LZS1+/lfV1QXz3hFOh5J/sSB64="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "South Worcestershire College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sworcs.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "South Worcestershire College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://cafe.unifran.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gustavo Carrijo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "gustavo@unifran.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.unifran.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIECDCCAvACAQAwDQYJKoZIhvcNAQEFBQAwgckxKTAnBgNVBAoTIFVOSUZSQU4g\nLSBVbml2ZXJzaWRhZGUgZGUgRnJhbmNhMSEwHwYDVQQLExhUZWNub2xvZ2lhIGRh\nIEluZm9ybWFjYW8xLTArBgkqhkiG9w0BCQEWHmd1c3Rhdm8uY2Fycmlqb0B1bmlm\ncmFuLmVkdS5icjEPMA0GA1UEBxMGRnJhbmNhMRIwEAYDVQQIEwlTYW8gUGF1bG8x\nCzAJBgNVBAYTAkJSMRgwFgYDVQQDEw9jYWZlLnVuaWZyYW4uYnIwHhcNMTUwODA1\nMjEyMzM5WhcNMTgwODA0MjEyMzM5WjCByTEpMCcGA1UEChMgVU5JRlJBTiAtIFVu\naXZlcnNpZGFkZSBkZSBGcmFuY2ExITAfBgNVBAsTGFRlY25vbG9naWEgZGEgSW5m\nb3JtYWNhbzEtMCsGCSqGSIb3DQEJARYeZ3VzdGF2by5jYXJyaWpvQHVuaWZyYW4u\nZWR1LmJyMQ8wDQYDVQQHEwZGcmFuY2ExEjAQBgNVBAgTCVNhbyBQYXVsbzELMAkG\nA1UEBhMCQlIxGDAWBgNVBAMTD2NhZmUudW5pZnJhbi5icjCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAKv46oStnlmR1Fa6hbCcOlgYZVOUCmF9pjXQDR3S\nyNBRtukPkfw/BxrhwnG0jwEVmoHfV0qgTk7gMjNtrJRoFctRQWLzglbxf1yBMTgw\nPqwv5pJRslIOXJLytk5oOlNgDAzyW9olb4ZH3ykq96ssGxiBN/OqgeLB7jLcQfE6\nt5fPWA8s7fC3OmLvrf9DR/5JV489FjqrJUA2OqOa3ZYGPsOb7Iu+/ZgS3KzbjK/R\npKOrV2GJBoRBylSW4QyNSjFHjnKWk5nG8AbArPzxc4Rf196xjgrcG6EUn9MgkN+H\nqK33rLEjPYinVgJhVutl4RPf3crIQnH40RlrfLseDxCnN8kCAwEAATANBgkqhkiG\n9w0BAQUFAAOCAQEAMb1OtL57m0uv+XnYIKq7PCPy+mgyfaEzMSLI6rVLiIcHkA6I\nwc46b67j9mG0xkipDaOci/fnSqA+VaVw8dM2NLOVRUgKLwyZ51jm0OojoIxxoXW3\nyQyvEPC3TxFT3C2aVA6u6HaxutoTc3X1iFN0Chp3RhQO1wUIuEpGoDYA4AzBHgsL\nJ0KJhJ8we4MfG8Ykhosw2NGe+3KELjm87cy/BWjcfXBGGQ8O14DyEp+xAApMpBlj\nTq9Q9YkdEX4XhRNU+qD6RUFPA+9a9H8dpeGECQEr6WWP2rhUecqnKFxIkodEJ90z\nmZfMvotH7YIPwtaPNUU2cOEWqWtBS/9iv/WBjQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unifran.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.unifran.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.unifran.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.unifran.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.unifran.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.unifran.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.unifran.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.unifran.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.unifran.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unifran.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unifran.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unifran.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNIFRAN - Universidade de Franca"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNIFRAN - Universidade de Franca"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNIFRAN - Universidade de Franca"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNIFRAN - Universidade de Franca"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIECDCCAvACAQAwDQYJKoZIhvcNAQEFBQAwgckxKTAnBgNVBAoTIFVOSUZSQU4g\nLSBVbml2ZXJzaWRhZGUgZGUgRnJhbmNhMSEwHwYDVQQLExhUZWNub2xvZ2lhIGRh\nIEluZm9ybWFjYW8xLTArBgkqhkiG9w0BCQEWHmd1c3Rhdm8uY2Fycmlqb0B1bmlm\ncmFuLmVkdS5icjEPMA0GA1UEBxMGRnJhbmNhMRIwEAYDVQQIEwlTYW8gUGF1bG8x\nCzAJBgNVBAYTAkJSMRgwFgYDVQQDEw9jYWZlLnVuaWZyYW4uYnIwHhcNMTUwODA1\nMjEyMzM5WhcNMTgwODA0MjEyMzM5WjCByTEpMCcGA1UEChMgVU5JRlJBTiAtIFVu\naXZlcnNpZGFkZSBkZSBGcmFuY2ExITAfBgNVBAsTGFRlY25vbG9naWEgZGEgSW5m\nb3JtYWNhbzEtMCsGCSqGSIb3DQEJARYeZ3VzdGF2by5jYXJyaWpvQHVuaWZyYW4u\nZWR1LmJyMQ8wDQYDVQQHEwZGcmFuY2ExEjAQBgNVBAgTCVNhbyBQYXVsbzELMAkG\nA1UEBhMCQlIxGDAWBgNVBAMTD2NhZmUudW5pZnJhbi5icjCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAKv46oStnlmR1Fa6hbCcOlgYZVOUCmF9pjXQDR3S\nyNBRtukPkfw/BxrhwnG0jwEVmoHfV0qgTk7gMjNtrJRoFctRQWLzglbxf1yBMTgw\nPqwv5pJRslIOXJLytk5oOlNgDAzyW9olb4ZH3ykq96ssGxiBN/OqgeLB7jLcQfE6\nt5fPWA8s7fC3OmLvrf9DR/5JV489FjqrJUA2OqOa3ZYGPsOb7Iu+/ZgS3KzbjK/R\npKOrV2GJBoRBylSW4QyNSjFHjnKWk5nG8AbArPzxc4Rf196xjgrcG6EUn9MgkN+H\nqK33rLEjPYinVgJhVutl4RPf3crIQnH40RlrfLseDxCnN8kCAwEAATANBgkqhkiG\n9w0BAQUFAAOCAQEAMb1OtL57m0uv+XnYIKq7PCPy+mgyfaEzMSLI6rVLiIcHkA6I\nwc46b67j9mG0xkipDaOci/fnSqA+VaVw8dM2NLOVRUgKLwyZ51jm0OojoIxxoXW3\nyQyvEPC3TxFT3C2aVA6u6HaxutoTc3X1iFN0Chp3RhQO1wUIuEpGoDYA4AzBHgsL\nJ0KJhJ8we4MfG8Ykhosw2NGe+3KELjm87cy/BWjcfXBGGQ8O14DyEp+xAApMpBlj\nTq9Q9YkdEX4XhRNU+qD6RUFPA+9a9H8dpeGECQEr6WWP2rhUecqnKFxIkodEJ90z\nmZfMvotH7YIPwtaPNUU2cOEWqWtBS/9iv/WBjQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNIFRAN - Universidade de Franca"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNIFRAN - Universidade de Franca"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unifran.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unifran.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNIFRAN - Universidade de Franca"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNIFRAN - Universidade de Franca"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp1.glos.ac.uk/entity",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Maller"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pmaller@glos.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pete"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Maller"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pmaller@glos.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pete"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp1.glos.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-08-08T10:27:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUCsJYB48Mz3bcb/dTeJJEcFS9NPQwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGjEYMBYGA1UEAxMPaWRwMS5nbG9zLmFjLnVrMB4XDTE0MDUyNzE1NDkxMVoX\n\t\t\t\t\t\tDTM0MDUyNzE1NDkxMVowGjEYMBYGA1UEAxMPaWRwMS5nbG9zLmFjLnVrMIIBIjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAhlNvzpLXrExyTGgdo924dAhh+8T+\n\t\t\t\t\t\tDDyFnfMBX74lgFvk9/Os73dq7ooAudnJW21c8vpD+24bMcgI8NPZchHvTKZNEciI\n\t\t\t\t\t\t3xkwyWvR0zV3pdQimojUmiX1fPfa7IOhZZ6qGFHGrucXs883wUoc/rLK3Xm7blV2\n\t\t\t\t\t\tjeHM7GiKYHs/WO2a3ITWkJqgeh7gXL/kRNNHGrLbgFloNOCT74KT01SNBgzWxiq9\n\t\t\t\t\t\tQBjqZR+tnaiu6dzeCMbB+wWmLLP3VOUDFxS9uNQGb8ZgOv3/n7Az7umt9xE5FfLu\n\t\t\t\t\t\tvOwEqpkoOxTsEootS2b6+tzbX0ZVaPAVjaKMWyXuPBU2wlPPbVU5r8cxEQIDAQAB\n\t\t\t\t\t\to2UwYzBCBgNVHREEOzA5gg9pZHAxLmdsb3MuYWMudWuGJmh0dHBzOi8vaWRwMS5n\n\t\t\t\t\t\tbG9zLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBR+Xmt33O3jaMudgIUV\n\t\t\t\t\t\tOLYp7RYNIzANBgkqhkiG9w0BAQUFAAOCAQEAZhozuufgK2Jm2NDfyWti7ANRfe3I\n\t\t\t\t\t\tBo++sDx8LwdL7obTwDKn4+Yco3vOrigILfoawl2heoG16mhfUWFZgwu21Surt6uL\n\t\t\t\t\t\tc7V7f3v4ZzEIkb/DYFmk8wPx22htqAcO9sj0duHVP45pFW4Orchc6umt+ZCFgwWB\n\t\t\t\t\t\tWByMENe+1csz9xMqRT1QlkBleOjo3/nEcv24kzpOCmCVe2CMSnxekGc8Jp38GBEi\n\t\t\t\t\t\tFSs+x2SKYUI4dR4wz7nKIybUCxR5aQ0tsryYKVf7hSw6oatKD6TGmFNJYiy0Ifq3\n\t\t\t\t\t\tkOm6roKl1gcoqKYmFZfJVnU0H1rtoJ7XQMWtxX3rVtYhwHghbhfB03i6FA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "glos.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.glos.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.glos.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shiblogin.glos.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shiblogin.glos.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shiblogin.glos.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shiblogin.glos.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp1.glos.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp1.glos.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "glos.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUCsJYB48Mz3bcb/dTeJJEcFS9NPQwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGjEYMBYGA1UEAxMPaWRwMS5nbG9zLmFjLnVrMB4XDTE0MDUyNzE1NDkxMVoX\n\t\t\t\t\t\tDTM0MDUyNzE1NDkxMVowGjEYMBYGA1UEAxMPaWRwMS5nbG9zLmFjLnVrMIIBIjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAhlNvzpLXrExyTGgdo924dAhh+8T+\n\t\t\t\t\t\tDDyFnfMBX74lgFvk9/Os73dq7ooAudnJW21c8vpD+24bMcgI8NPZchHvTKZNEciI\n\t\t\t\t\t\t3xkwyWvR0zV3pdQimojUmiX1fPfa7IOhZZ6qGFHGrucXs883wUoc/rLK3Xm7blV2\n\t\t\t\t\t\tjeHM7GiKYHs/WO2a3ITWkJqgeh7gXL/kRNNHGrLbgFloNOCT74KT01SNBgzWxiq9\n\t\t\t\t\t\tQBjqZR+tnaiu6dzeCMbB+wWmLLP3VOUDFxS9uNQGb8ZgOv3/n7Az7umt9xE5FfLu\n\t\t\t\t\t\tvOwEqpkoOxTsEootS2b6+tzbX0ZVaPAVjaKMWyXuPBU2wlPPbVU5r8cxEQIDAQAB\n\t\t\t\t\t\to2UwYzBCBgNVHREEOzA5gg9pZHAxLmdsb3MuYWMudWuGJmh0dHBzOi8vaWRwMS5n\n\t\t\t\t\t\tbG9zLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBR+Xmt33O3jaMudgIUV\n\t\t\t\t\t\tOLYp7RYNIzANBgkqhkiG9w0BAQUFAAOCAQEAZhozuufgK2Jm2NDfyWti7ANRfe3I\n\t\t\t\t\t\tBo++sDx8LwdL7obTwDKn4+Yco3vOrigILfoawl2heoG16mhfUWFZgwu21Surt6uL\n\t\t\t\t\t\tc7V7f3v4ZzEIkb/DYFmk8wPx22htqAcO9sj0duHVP45pFW4Orchc6umt+ZCFgwWB\n\t\t\t\t\t\tWByMENe+1csz9xMqRT1QlkBleOjo3/nEcv24kzpOCmCVe2CMSnxekGc8Jp38GBEi\n\t\t\t\t\t\tFSs+x2SKYUI4dR4wz7nKIybUCxR5aQ0tsryYKVf7hSw6oatKD6TGmFNJYiy0Ifq3\n\t\t\t\t\t\tkOm6roKl1gcoqKYmFZfJVnU0H1rtoJ7XQMWtxX3rVtYhwHghbhfB03i6FA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Gloucestershire"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.glos.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Gloucestershire"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://expert.uhrdemo.antagning.se/aws-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al2"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://www.swamid.se/assurance-requirement",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://expert.uhrdemo.antagning.se/aws-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://expert.uhrdemo.antagning.se:444/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://expert.uhrdemo.antagning.se:444/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://expert.uhrdemo.antagning.se:444/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://expert.uhrdemo.antagning.se:444/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://expert.uhrdemo.antagning.se:444/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://expert.uhrdemo.antagning.se:444/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "expert.uhrdemo.antagning.se"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://expert.uhrdemo.antagning.se/aws-sp"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIJALz2sBBLqMf6MA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\nBAMTG2V4cGVydC51aHJkZW1vLmFudGFnbmluZy5zZTAeFw0xNDEwMjAxMzQ1MzNa\nFw0yNDEwMTcxMzQ1MzNaMCYxJDAiBgNVBAMTG2V4cGVydC51aHJkZW1vLmFudGFn\nbmluZy5zZTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALbOIRmxfwWb\nyMkMOPODCqatRVJtc0eEDa5JCTcv03K+Ctrm0ERm1tfFpgRyBMp4gTFlAb6x/sUQ\nY0LOsbupRN4jy9zLYYTMGDZtPclKWTmeYghYnVYk4uDNqRZhPoQ5jThb1ZN1cF6a\nEPde+GqpLNP/6vSlkmTb8fQMR+jTiAHIar5wgjrdy71czFrVNzLvE6aeAAj1Ltgo\nOpRkvUvv6tJvGNy/zIDWMCwXOp2g19c1fjsv9cGZDOzXUDDkDKp64yTAYVW7JlAX\n9e0mP5Y7cMVAbrygaoPqZWpuRIrLXm09rHXO1IwZr84FvslzMPga/AeUHuEOaPId\n4PqGc6M4k88CAwEAAaN1MHMwUgYDVR0RBEswSYIbZXhwZXJ0LnVocmRlbW8uYW50\nYWduaW5nLnNlhipodHRwczovL2V4cGVydC51aHJkZW1vLmFudGFnbmluZy5zZS9h\nd3Mtc3AwHQYDVR0OBBYEFDvjW1sTBeDuIGWsbEZD/P/16bwnMA0GCSqGSIb3DQEB\nBQUAA4IBAQBSlW+rxm2rcJuJrKWcrosdHV2NvebZs7hEofN2HFVc6N4i1mT72p6i\nzysIRUq+w9kJJO8DZMHnp2/jijg1zheWOmazsbNW1oEJX3xp9PCT6chxWepZpLjg\njGJgC6cCj5y+m7QKTIwVeqwzPJbDfcN2B3IXaplfuBG4psDoTYlirymCRQQtSewY\npeixelFpX7cxoKJriN2mIV9KnCyfNJIAe+fmUHhqBZKVsz1m72jr7dtbMPo6Mo8Z\nPsIf/yVavv75z7lQcOvuV3H8wECX4rTZV860ByFV6hSCYSpS7/L5M8SD2vyhhJUs\n06JLG6j3mY0H9dW9Ty9RzPYf97RSHj4k"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=expert.uhrdemo.antagning.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://expert.uhrdemo.antagning.se:444/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://expert.uhrdemo.antagning.se:444/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://expert.uhrdemo.antagning.se:444/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://expert.uhrdemo.antagning.se:444/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://expert.uhrdemo.antagning.se:444/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://expert.uhrdemo.antagning.se:444/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://expert.uhrdemo.antagning.se:444/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://expert.uhrdemo.antagning.se:444/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://expert.uhrdemo.antagning.se:444/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.condorcet.be/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+3271531578"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Technical Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "webmaster@condorcet.be"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          }
        }
      ],
      "entity_id": "https://idp.condorcet.be/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://federation.belnet.be/files/Belnet-metadata-registration-practice-statement.txt"
              }
            ],
            "registration_instant": "2012-03-27T12:00:00Z",
            "registration_authority": "http://federation.belnet.be/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.condorcet.be/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.condorcet.be/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.condorcet.be/idp/profile/SAML2/POST-SimpleSign/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.condorcet.be:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.condorcet.be/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.condorcet.be/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.condorcet.be/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.condorcet.be/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.condorcet.be/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.condorcet.be:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.condorcet.be:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "condorcet.be"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Students and Teachers from Haute-Ecole Provinciale de Hainaut-Condorcet"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Etudiants et Enseignants de Haute-Ecole Provinciale de Hainaut-Condorcet"
                  }
                ],
                "logo": [
                  {
                    "text": "https://cdn.ecampus-hainaut.be/logos/idp-condorcet-16x16.jpg",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://cdn.ecampus-hainaut.be/logos/idp-condorcet-291x88.png",
                    "height": "291",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "88"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "HEPH-Condorcet"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "HEPH-Condorcet"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "condorcet.be"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "50.41719089999999,4.448670300000003"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.190.199.64/26"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVALMBuiwacb0fss6ngQ0ewYTIrDGhMA0GCSqGSIb3DQEB\nCwUAMBsxGTAXBgNVBAMMEGlkcC5jb25kb3JjZXQuYmUwHhcNMTUxMjAzMjIzOTE5\nWhcNMzUxMjAzMjIzOTE5WjAbMRkwFwYDVQQDDBBpZHAuY29uZG9yY2V0LmJlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAgvk9OnaDFkoCIOryGzIOF9Mq\nQL/TEkYPArKYUjj9wRZGeYgUcw2KOSr5EzSXBB64fDdxzhmwYBWligcvpCGxKwOJ\niVpd7kvw01vK2DzhOm4FiDe8kUlxd554Yhq2EJE5wQzy/ny/KyF5nTegDZ8TkCua\nlpWPB0D+kRWf/xgFnpVJqTHBEpHVpw5DAqPufpAQWhZ9igzqWqrroCmrIv9+WQMb\nk79AbmYjJdKynjOGjc4UzrYkE7Hd3P8TOXCkr7sfC6qs8KsZveoJkZmvrXEe9njN\nuZtQH7oN7PuguCtStPnQMtPzyXWuC/BEQweGANyX3MagJsOM8rf+Kr1TTSacmwID\nAQABo2cwZTAdBgNVHQ4EFgQUg57FS35PSVovzamiYS9D38HM4JYwRAYDVR0RBD0w\nO4IQaWRwLmNvbmRvcmNldC5iZYYnaHR0cHM6Ly9pZHAuY29uZG9yY2V0LmJlL2lk\ncC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQB0XKyy/ILdvSv1Y1acxGR0\nCchq0uTo8w1dHc/cWskTkawb1o2IR/oogei4OM+lu1E9Ri6+2LRsQ54Wc69kdA26\n9XuG+o6RJ7UmUSnGkl08bpLNPed2Psrneb/7v8sn6G0zcpokhxLmFMMYKWmWAOW6\nSLy2w40fyTB8FxmO3/ZONg/rcz58I6JhVSanp6S/OaqjNGe+B4KSwmDS75suq0bS\nh3K1osgFBrZ3YK6BxS9ByhIBkmqOU0lF+upb529Mqeg29IkS7aNDZlxh/ZhP4JNE\n2UBsrhGATLxuAYrFlUQ+Vf+LLt/MNpRoQ1lnp5A5QDPHaksm6LOdxcCY8gNlk/kf"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAPBmR/6jQO37H6ozLvBQxojFpGugMA0GCSqGSIb3DQEB\nCwUAMBsxGTAXBgNVBAMMEGlkcC5jb25kb3JjZXQuYmUwHhcNMTUxMjAzMjIzOTE4\nWhcNMzUxMjAzMjIzOTE4WjAbMRkwFwYDVQQDDBBpZHAuY29uZG9yY2V0LmJlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmd+oyDtzupF9rGBLGW4MIHkx\ngR35uU3quBBNGvLLqq6fWDlDJMcwVbTUlseCyfrFhSMX+ptLdUbYAICydlIhIwCN\ncl1QUVg+wrkds6q2Ea698vTiwWIUMFWFo7xaz2TNUuSh2paiiETtIULEB2iQJ3a1\nH5FWI0Fp74HGek7cV2TCrG8yssELY0ilysUC/dFr6/iaxepiZehmnCysxXBsvuDR\ntyYNtcxbGi0BdRJ1IXegTofpAbaJDPp8D2gWlh+wA8mfqyc4svzOedwKJxGUAn+O\nyai0BVgnRAwh7kCg/vll/sS9S08aif1/ve+FnEECFJtJAOkuoKjVGAKCFPO9pQID\nAQABo2cwZTAdBgNVHQ4EFgQUrwNoXcSmCwJDz7YP5xx132nedmAwRAYDVR0RBD0w\nO4IQaWRwLmNvbmRvcmNldC5iZYYnaHR0cHM6Ly9pZHAuY29uZG9yY2V0LmJlL2lk\ncC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQApYNw6ZvbMVRsX7zTBvX+H\nzujWq+BytfDyCU5pGYeeyQItBb12ckOoHVCj1bLvDN4JZEXZjpO8xihlWgCSef4+\nYzDH4MBqxGurGB0hQ7UBb5UnXt2HguXL6IVOOjYIHtx6cqwJ4xOwLufdoFAY6KSH\nJKPMAY8gO2RTlBxQQ57bF7vgC1XxBgcynXCgsDr1UQWg9or9tXivzXR66wPpi1o7\n9fOjpyT43yy8NS6BxZLpbXJbLi2mDEthM3fyXkyi85LVHx+uwrhpy8MeGBhdqdiX\naYNVyrYc5coxp6GPVBJv8YKHqNG3Dw9TqI4LTTyWcJA9Hwu/+qo6eh2nk5Ps9JVX"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAKzR+oWciVWzsTL99fnG6ihy4LtOMA0GCSqGSIb3DQEB\nCwUAMBsxGTAXBgNVBAMMEGlkcC5jb25kb3JjZXQuYmUwHhcNMTUxMjAzMjIzOTE4\nWhcNMzUxMjAzMjIzOTE4WjAbMRkwFwYDVQQDDBBpZHAuY29uZG9yY2V0LmJlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1Xl9pWh2KY2ifAlxsox1IsSb\ncq9JclYprGeLU9RGynJbkA7F1+puwCuDa7/lHCYJpZDk6AmSxB0R02VpEE+CrQMt\n7xegealN2gEhRQWaEJ1H2bjWV6swVmo10AIkhmyUdKGBr+kChVYr0kq78JpRxEFA\nZ741/VOvamSVsYhXiUBaE/WnmUUCuJW/Bks+DbmNOF+W/vlQOgedL4Ox1Aj9gnCz\nsbSXpPjJcXv0aW9L7w03sJwE2M4kkWpp5DWdpXyVWjF8JvuFu8CHwTuSrJu8u0hZ\neNRJt0c+G7JI+Hgr++8VnBdNbkprcCZQTK9NYyqCLW4J0XcaDkIJJCFJ8UmV0QID\nAQABo2cwZTAdBgNVHQ4EFgQUijIkcisJLNO4M/AZ/x1ZRzQjCIgwRAYDVR0RBD0w\nO4IQaWRwLmNvbmRvcmNldC5iZYYnaHR0cHM6Ly9pZHAuY29uZG9yY2V0LmJlL2lk\ncC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQA2yyecgvrae2VNTaTyft2e\nnkXipQ6HnTCtKaJxDMlrUvUBobOWWklvd8O4hCTUL26nOIqN+X66AtRP01lwiOng\n/Xx22Vv86E37XD64oA6BOhgJVgOgelp+QzlTjdaw+1ryhCxCmkAbXIBH8yjVQ6Db\n2QZCPkNDkfPYWoldf/OUSreH9U3+PX6rY0ev/mzzZutxqMJHgEaA7IMqrR5PVzhU\nQzo5DYd+FzazDipqCATv/67WjzZny4+/apNoKIrsh6zm/tOaeGx2h9TlLt+Rxqfd\n2KZ0zVbf8I3/d+fMjwQNaSKPKqQM4u+1Ji7o0czZdsegOS4V+m3NST/VR3mHpdcp"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "HEPH-Condorcet"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "HEPH-Condorcet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.condorcet.be"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "High School from Province de Hainaut"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Enseignement Superieur de la Province de Hainaut"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.uwl.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it.convergednetworkteam@uwl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Data and Voice Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rumun"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Richard.rumun@uwl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uwl.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-05-19T11:11:56Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAJusaLWH0l8DLgcyT2qPjzTl3AF9MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBgxFjAUBgNVBAMTDWlkcC51d2wuYWMudWswHhcNMTQwNTE0MDg1MjM1WhcN\n\t\t\t\t\t\tMzQwNTE0MDg1MjM1WjAYMRYwFAYDVQQDEw1pZHAudXdsLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkFVbsCDSQPh7lQRG/+MSvuXLRmP0fouZ\n\t\t\t\t\t\tEHLD6q6WT/9/5VA0dGeBP0/jdQWUOgtRVsWszgKkQL9k7MQERK6qkJJFXxrTEvXZ\n\t\t\t\t\t\tThk4ATeCkx/X865yr4oA/149sVkL7g0ll3soccxPn64yyLg/RKzDBjurt6TogqRh\n\t\t\t\t\t\t5ig9V5Xi4R1eGIyVDBQpsmRO5i3n8wy84iMXfFc1vZ1/4ghA/gDD9zA959OGMxTL\n\t\t\t\t\t\tXXXo3HUMINWCbZm5uJC7sxDd2tDnCRm/zk+euO69RO9s7bwNSlJnqxQah7Ii3g3Y\n\t\t\t\t\t\t4YuDeCTfHMBDmXelvQw1aPoDq3j/u/FCER2ZlSHSnPs2UNadXV5IGQIDAQABo2Ew\n\t\t\t\t\t\tXzA+BgNVHREENzA1gg1pZHAudXdsLmFjLnVrhiRodHRwczovL2lkcC51d2wuYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFHXq/u7Qc+QH1JehKu4iPcxj3WkD\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQA/eNXfq/Qk9kWzb/40xD2rOUneppySpdgbt0Wr\n\t\t\t\t\t\tjL6OsJTRASxbWFZl2WYthnDCN9SV7tkDlZNp+k1JXdyYL/UzDZu3q2vo0JissFKY\n\t\t\t\t\t\t3adVBMZ351y/CcONpX9khXqosN+txwkGvTX30x/nZ4Qg3vP18NrVbcXW8+Q4c5iz\n\t\t\t\t\t\tmJxz70gW6HwoHf0M+Ee1H+HJywnUUfy1Yf6urYmvHXXbCzeeHeBf83a6rdSteY+Y\n\t\t\t\t\t\tUCxV0WZTRU0DqR8PUBQhU75iDmYiIYwirhPaS45HpdC2MKwfkSECjL/tpNGMqwBv\n\t\t\t\t\t\tVVadKoLbwPTFg6BuJaKzgxeQIJtbr6T4l/LWosU4iAY2aPng"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uwl.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uwl.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uwl.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uwl.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uwl.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uwl.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.uwl.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uwl.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.uwl.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uwl.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uwl.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uwl.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uwl.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAJusaLWH0l8DLgcyT2qPjzTl3AF9MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBgxFjAUBgNVBAMTDWlkcC51d2wuYWMudWswHhcNMTQwNTE0MDg1MjM1WhcN\n\t\t\t\t\t\tMzQwNTE0MDg1MjM1WjAYMRYwFAYDVQQDEw1pZHAudXdsLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkFVbsCDSQPh7lQRG/+MSvuXLRmP0fouZ\n\t\t\t\t\t\tEHLD6q6WT/9/5VA0dGeBP0/jdQWUOgtRVsWszgKkQL9k7MQERK6qkJJFXxrTEvXZ\n\t\t\t\t\t\tThk4ATeCkx/X865yr4oA/149sVkL7g0ll3soccxPn64yyLg/RKzDBjurt6TogqRh\n\t\t\t\t\t\t5ig9V5Xi4R1eGIyVDBQpsmRO5i3n8wy84iMXfFc1vZ1/4ghA/gDD9zA959OGMxTL\n\t\t\t\t\t\tXXXo3HUMINWCbZm5uJC7sxDd2tDnCRm/zk+euO69RO9s7bwNSlJnqxQah7Ii3g3Y\n\t\t\t\t\t\t4YuDeCTfHMBDmXelvQw1aPoDq3j/u/FCER2ZlSHSnPs2UNadXV5IGQIDAQABo2Ew\n\t\t\t\t\t\tXzA+BgNVHREENzA1gg1pZHAudXdsLmFjLnVrhiRodHRwczovL2lkcC51d2wuYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFHXq/u7Qc+QH1JehKu4iPcxj3WkD\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQA/eNXfq/Qk9kWzb/40xD2rOUneppySpdgbt0Wr\n\t\t\t\t\t\tjL6OsJTRASxbWFZl2WYthnDCN9SV7tkDlZNp+k1JXdyYL/UzDZu3q2vo0JissFKY\n\t\t\t\t\t\t3adVBMZ351y/CcONpX9khXqosN+txwkGvTX30x/nZ4Qg3vP18NrVbcXW8+Q4c5iz\n\t\t\t\t\t\tmJxz70gW6HwoHf0M+Ee1H+HJywnUUfy1Yf6urYmvHXXbCzeeHeBf83a6rdSteY+Y\n\t\t\t\t\t\tUCxV0WZTRU0DqR8PUBQhU75iDmYiIYwirhPaS45HpdC2MKwfkSECjL/tpNGMqwBv\n\t\t\t\t\t\tVVadKoLbwPTFg6BuJaKzgxeQIJtbr6T4l/LWosU4iAY2aPng"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of West London"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uwl.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of West London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://fed.id.univ-bordeaux.fr/idp_ubx/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ssr@univ-bordeaux.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://fed.id.univ-bordeaux.fr/idp_ubx/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2011-05-24T11:30:09Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://fed.id.univ-bordeaux.fr/idp_ubx/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://fed.id.univ-bordeaux.fr/idp_ubx/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://fed.id.univ-bordeaux.fr/idp_ubx/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-bordeaux.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.cue-aquitaine.fr/"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CUEA - Communaut\u00e9 d'universit\u00e9s et d'\u00e9tablissements d'Aquitaine"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CUEA - Communaut\u00e9 d'universit\u00e9s et d'\u00e9tablissements d'Aquitaine"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDlDCCAnygAwIBAgIJAMmv2toaoAEMMA0GCSqGSIb3DQEBBQUAMDoxCzAJBgNV\nBAYTAkZSMQwwCgYDVQQKEwNVQngxHTAbBgNVBAMTFGlkcC51bml2LWJvcmRlYXV4\nLmZyMB4XDTExMDUxOTEwMTMzMVoXDTMxMDUxNDEwMTMzMVowOjELMAkGA1UEBhMC\nRlIxDDAKBgNVBAoTA1VCeDEdMBsGA1UEAxMUaWRwLnVuaXYtYm9yZGVhdXguZnIw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC/fbuGXQzSGD9NIpWeKHgx\nuUOIFJnnuGTkASR2nUsiLVC5T85Pc23LHd2q+QVuEzrApgZHPaQ/dvwkoyD26K+z\nJPfsVSFNObGxTHIh3erH8ELPVSUWWBTBdxhOqqjsY2Oi6wOiiPRAHJIJ8GtR+WiY\nflaN2pyuP6E6y9klVO1a5A592ClTEJW+TjpcqE3REmcwqjEBcx2rGOlgipwBGRbt\ng2VjDWfP745U9Nu7s77bWbcP1fFlSYX6fY5jlBsS9KiTkjNEyLQv6H7f6gkA4JAf\nvtlg/+wgT5yjoeLnO1PXU94Fg9MiwXw9bmBccrdZEYbRE4Yj7erzk8yAqZkdeRx5\nAgMBAAGjgZwwgZkwHQYDVR0OBBYEFEDi7aDbyQrP92cicg3Ybs52s69CMGoGA1Ud\nIwRjMGGAFEDi7aDbyQrP92cicg3Ybs52s69CoT6kPDA6MQswCQYDVQQGEwJGUjEM\nMAoGA1UEChMDVUJ4MR0wGwYDVQQDExRpZHAudW5pdi1ib3JkZWF1eC5mcoIJAMmv\n2toaoAEMMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAK4ev4MBRPS6\njZgF6rlty35EfLflTFhQNFtTypW7O/yljgpIs1UNahDNmlJBSBZpw1DeZvuLJwsw\nsK8mb9ldbs3+euCK/6N/zXj48S7/2KIt32jUTsjMcByOvhxqrsax4APYKCqh0ErB\nf5aCPGBKrlMf99jeG4Iegf8YkkU2i+ZCq04GkBDZPawtEWNJL1LTykMvY09Wf1pU\noiMV0/Zcv53VXdVLsHwCYFg3lf1uIlGcwaJPxb4NCAGAktixPig8B2sqE7ryk8ss\nQiRmgUZzF4TgaBu7lYjlYOmUMvrC+KaOPvT+UlYrWidEok60vOY+kIJ683KK7QhE\nV+xNY9y95Z8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CUEA - Communaut\u00e9 d'universit\u00e9s et d'\u00e9tablissements d'Aquitaine"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cue-aquitaine.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CUEA - Communaut\u00e9 d'universit\u00e9s et d'\u00e9tablissements d'Aquitaine"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://athensri.forthvalley.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Robertson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:graeme.robertson@forthvalley.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Graeme"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Robertson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:graeme.robertson@forthvalley.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Graeme"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://athensri.forthvalley.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-10-02T12:17:37Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://athensri.forthvalley.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://athensri.forthvalley.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "forthvalley.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDsjCCApqgAwIBAgIJAJk2uGNIbkStMA0GCSqGSIb3DQEBBQUAMEQxHTAbBgNV\n\t\t\t\t\t\tBAoTFEZvcnRoIFZhbGxleSBDb2xsZWdlMSMwIQYDVQQDExphdGhlbnNyaS5mb3J0\n\t\t\t\t\t\taHZhbGxleS5hYy51azAeFw0xMTA5MTIxMTUxMDFaFw0yMTA5MDkxMTUxMDFaMEQx\n\t\t\t\t\t\tHTAbBgNVBAoTFEZvcnRoIFZhbGxleSBDb2xsZWdlMSMwIQYDVQQDExphdGhlbnNy\n\t\t\t\t\t\taS5mb3J0aHZhbGxleS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAK353WqmulmsLtwvvW1+hYO/kRDRRRmrAhAJvwEwopgABtd1T9a/6toJwYDJ\n\t\t\t\t\t\tpFqzT0+VojwzdvRw/RCgYAZzd+HCK/giChdHIT25NUn4bTTlBM8arIH04lmswYvm\n\t\t\t\t\t\tuTI4m+QOPTNJM5wWuD5T1plmCT/OdleDMHIsdyt5g8pMfPDT1DHcJ43aptC7mXMJ\n\t\t\t\t\t\tDK8M4URKWWvuBlIVwL4+a3URxS3VvdxOGwX+WuYZ8q1IlzUG+PEf9lcIwPGfxucl\n\t\t\t\t\t\tPbLE2Q3M3cU2yEzsZWas63vbYw6YniKjaMf3setK4A77shor7Di8wYGR3DkxJifv\n\t\t\t\t\t\tUAq8/lHMZ9dLK0wxPYZFfI8VxA0CAwEAAaOBpjCBozAdBgNVHQ4EFgQUOK0xdbaZ\n\t\t\t\t\t\tdIyNwo58vYn7Sv7Fy0kwdAYDVR0jBG0wa4AUOK0xdbaZdIyNwo58vYn7Sv7Fy0mh\n\t\t\t\t\t\tSKRGMEQxHTAbBgNVBAoTFEZvcnRoIFZhbGxleSBDb2xsZWdlMSMwIQYDVQQDExph\n\t\t\t\t\t\tdGhlbnNyaS5mb3J0aHZhbGxleS5hYy51a4IJAJk2uGNIbkStMAwGA1UdEwQFMAMB\n\t\t\t\t\t\tAf8wDQYJKoZIhvcNAQEFBQADggEBACuUxXKYJpNFw504ykZnJs0NJAOA8OhXu2UM\n\t\t\t\t\t\tUb2QDWD/84kXZSxJkFcz6TaeByhNAPXWUxrt/G5RSzy7LIC9tH4roICTkttweujO\n\t\t\t\t\t\tble6Y8bLvoKA7f+x2LGZX9Tw75vsD5dr+vdoguW5L0d43q6f0tI4GHHGsgC5KrkX\n\t\t\t\t\t\tbxzg27PJVX7V6LlRiLknVX6tfPbVu8mzEHU4t+lwcZFb+5JrEHF9c2wGf33pUZBZ\n\t\t\t\t\t\ttiQ/jyZqHEHbOpi6o/DE5plkwKQBkHkimeFyXITgwiDto8yE2Lg3ld33yB/G529g\n\t\t\t\t\t\t1e0NTIQeEWw/mB0MavXoJloNskmBulmLX3HlLMJLRgVh4hOHqkM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDsjCCApqgAwIBAgIJAJk2uGNIbkStMA0GCSqGSIb3DQEBBQUAMEQxHTAbBgNV\n\t\t\t\t\t\tBAoTFEZvcnRoIFZhbGxleSBDb2xsZWdlMSMwIQYDVQQDExphdGhlbnNyaS5mb3J0\n\t\t\t\t\t\taHZhbGxleS5hYy51azAeFw0xMTA5MTIxMTUxMDFaFw0yMTA5MDkxMTUxMDFaMEQx\n\t\t\t\t\t\tHTAbBgNVBAoTFEZvcnRoIFZhbGxleSBDb2xsZWdlMSMwIQYDVQQDExphdGhlbnNy\n\t\t\t\t\t\taS5mb3J0aHZhbGxleS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAK353WqmulmsLtwvvW1+hYO/kRDRRRmrAhAJvwEwopgABtd1T9a/6toJwYDJ\n\t\t\t\t\t\tpFqzT0+VojwzdvRw/RCgYAZzd+HCK/giChdHIT25NUn4bTTlBM8arIH04lmswYvm\n\t\t\t\t\t\tuTI4m+QOPTNJM5wWuD5T1plmCT/OdleDMHIsdyt5g8pMfPDT1DHcJ43aptC7mXMJ\n\t\t\t\t\t\tDK8M4URKWWvuBlIVwL4+a3URxS3VvdxOGwX+WuYZ8q1IlzUG+PEf9lcIwPGfxucl\n\t\t\t\t\t\tPbLE2Q3M3cU2yEzsZWas63vbYw6YniKjaMf3setK4A77shor7Di8wYGR3DkxJifv\n\t\t\t\t\t\tUAq8/lHMZ9dLK0wxPYZFfI8VxA0CAwEAAaOBpjCBozAdBgNVHQ4EFgQUOK0xdbaZ\n\t\t\t\t\t\tdIyNwo58vYn7Sv7Fy0kwdAYDVR0jBG0wa4AUOK0xdbaZdIyNwo58vYn7Sv7Fy0mh\n\t\t\t\t\t\tSKRGMEQxHTAbBgNVBAoTFEZvcnRoIFZhbGxleSBDb2xsZWdlMSMwIQYDVQQDExph\n\t\t\t\t\t\tdGhlbnNyaS5mb3J0aHZhbGxleS5hYy51a4IJAJk2uGNIbkStMAwGA1UdEwQFMAMB\n\t\t\t\t\t\tAf8wDQYJKoZIhvcNAQEFBQADggEBACuUxXKYJpNFw504ykZnJs0NJAOA8OhXu2UM\n\t\t\t\t\t\tUb2QDWD/84kXZSxJkFcz6TaeByhNAPXWUxrt/G5RSzy7LIC9tH4roICTkttweujO\n\t\t\t\t\t\tble6Y8bLvoKA7f+x2LGZX9Tw75vsD5dr+vdoguW5L0d43q6f0tI4GHHGsgC5KrkX\n\t\t\t\t\t\tbxzg27PJVX7V6LlRiLknVX6tfPbVu8mzEHU4t+lwcZFb+5JrEHF9c2wGf33pUZBZ\n\t\t\t\t\t\ttiQ/jyZqHEHbOpi6o/DE5plkwKQBkHkimeFyXITgwiDto8yE2Lg3ld33yB/G529g\n\t\t\t\t\t\t1e0NTIQeEWw/mB0MavXoJloNskmBulmLX3HlLMJLRgVh4hOHqkM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Forth Valley College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.forthvalley.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Forth Valley College of Further and Higher Education"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://signin.staging.studentmoneysaver.co.uk",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@studentmoneysaver.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Silimon"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:adrian@studentmoneysaver.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adrian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://signin.staging.studentmoneysaver.co.uk",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-11-20T11:21:13Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Student Money Saver (Test SP)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.studentmoneysaver.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Student Money Saver Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://signin.staging.studentmoneysaver.co.uk/saml/signout/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is a test\u00ad-only SP for Student Money Saver. Do not use in production."
                  }
                ],
                "logo": [
                  {
                    "text": "https://cdn.studentmoneysaver.co.uk/assets/logos/sms-logo.png",
                    "height": "61",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "107"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Student Money Saver (Test SP)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKzCCAxOgAwIBAgIJAI3xfY2iDzkeMA0GCSqGSIb3DQEBCwUAMIGrMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEQMA4GA1UECAwHRW5nbGFuZDEPMA0GA1UEBwwGTG9uZG9uMSAwHgYD\n\t\t\t\t\t\tVQQKDBdTdHVkZW50IE1vbmV5IFNhdmVyIExURDEPMA0GA1UECwwGRGV2T3BzMRcw\n\t\t\t\t\t\tFQYDVQQDDA5zbXMtc2lnbmluLWFwaTEtMCsGCSqGSIb3DQEJARYeYWRyaWFuQHN0\n\t\t\t\t\t\tdWRlbnRtb25leXNhdmVyLmNvLnVrMB4XDTE1MDYyNjA4NDcxMloXDTE3MDYyNTA4\n\t\t\t\t\t\tNDcxMlowgasxCzAJBgNVBAYTAkdCMRAwDgYDVQQIDAdFbmdsYW5kMQ8wDQYDVQQH\n\t\t\t\t\t\tDAZMb25kb24xIDAeBgNVBAoMF1N0dWRlbnQgTW9uZXkgU2F2ZXIgTFREMQ8wDQYD\n\t\t\t\t\t\tVQQLDAZEZXZPcHMxFzAVBgNVBAMMDnNtcy1zaWduaW4tYXBpMS0wKwYJKoZIhvcN\n\t\t\t\t\t\tAQkBFh5hZHJpYW5Ac3R1ZGVudG1vbmV5c2F2ZXIuY28udWswggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDDh7gKf0OElHwbGJ9tCzuifS/1qfSFRxg8wBVk\n\t\t\t\t\t\tZ8/gRSTPyr1xHRYeQMf9+W9bWejDaaDxQq/yRQDwGEOTYN/ghGlej/MD4tBlP4CS\n\t\t\t\t\t\tqUP2stV91Vp8sSyz8Ue2F7surXWk04dav7wLNR3giwpLPL7rSBF8cG3sJiAgFnSC\n\t\t\t\t\t\t3uGLBlP/BHy2UzeWYPhteD80QjBnbGFSA/ETMlDIGj48HmdHyE7gATpVJ84Bw6Db\n\t\t\t\t\t\tAc0xiNKP4rFL0QzD55q4NR1/GQB4MqZdoTA3LXKPrO8HRkIQqEDA3WjcpCQeKuqt\n\t\t\t\t\t\tVPU9mB/XSdzV3+iCVsIW1dSYNnC1FJWB5LBnQijEylcJSY2NAgMBAAGjUDBOMB0G\n\t\t\t\t\t\tA1UdDgQWBBQv1uF4H7q9kZG4TSDpZBWU+yE2BjAfBgNVHSMEGDAWgBQv1uF4H7q9\n\t\t\t\t\t\tkZG4TSDpZBWU+yE2BjAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQAL\n\t\t\t\t\t\tea2RNtk74QMKsbwzICCuADT/rllrKNzsgAkaAjcCdL+DfspFZSnav40MB7ksK16t\n\t\t\t\t\t\taebkpkCK6x3vE5eU3bosiOGektkVoAjbb+BVhuEQHSV17FaXQnkUe2t1httVIihx\n\t\t\t\t\t\tWF/bCXqIzLkbz3KhMX/oYWnLvB7R4UcmaPxImRmcJ5BFA6UXHqlU+d3/9+oOErUu\n\t\t\t\t\t\tTJBBU9BcDoIAcfgMe5MaDXNdVa2P8HD+JDeE3EWx1L7KEOVQaSfekYSTSmstnqBj\n\t\t\t\t\t\tOL0Jr2kxldHRwhrHu50f2PMJFKwvjy4/X79YwapTCn1ee7FWft255LdEqpBFz+we\n\t\t\t\t\t\ty3MXd8zZdHL4dhUTYdiF"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKzCCAxOgAwIBAgIJAI3xfY2iDzkeMA0GCSqGSIb3DQEBCwUAMIGrMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEQMA4GA1UECAwHRW5nbGFuZDEPMA0GA1UEBwwGTG9uZG9uMSAwHgYD\n\t\t\t\t\t\tVQQKDBdTdHVkZW50IE1vbmV5IFNhdmVyIExURDEPMA0GA1UECwwGRGV2T3BzMRcw\n\t\t\t\t\t\tFQYDVQQDDA5zbXMtc2lnbmluLWFwaTEtMCsGCSqGSIb3DQEJARYeYWRyaWFuQHN0\n\t\t\t\t\t\tdWRlbnRtb25leXNhdmVyLmNvLnVrMB4XDTE1MDYyNjA4NDcxMloXDTE3MDYyNTA4\n\t\t\t\t\t\tNDcxMlowgasxCzAJBgNVBAYTAkdCMRAwDgYDVQQIDAdFbmdsYW5kMQ8wDQYDVQQH\n\t\t\t\t\t\tDAZMb25kb24xIDAeBgNVBAoMF1N0dWRlbnQgTW9uZXkgU2F2ZXIgTFREMQ8wDQYD\n\t\t\t\t\t\tVQQLDAZEZXZPcHMxFzAVBgNVBAMMDnNtcy1zaWduaW4tYXBpMS0wKwYJKoZIhvcN\n\t\t\t\t\t\tAQkBFh5hZHJpYW5Ac3R1ZGVudG1vbmV5c2F2ZXIuY28udWswggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDDh7gKf0OElHwbGJ9tCzuifS/1qfSFRxg8wBVk\n\t\t\t\t\t\tZ8/gRSTPyr1xHRYeQMf9+W9bWejDaaDxQq/yRQDwGEOTYN/ghGlej/MD4tBlP4CS\n\t\t\t\t\t\tqUP2stV91Vp8sSyz8Ue2F7surXWk04dav7wLNR3giwpLPL7rSBF8cG3sJiAgFnSC\n\t\t\t\t\t\t3uGLBlP/BHy2UzeWYPhteD80QjBnbGFSA/ETMlDIGj48HmdHyE7gATpVJ84Bw6Db\n\t\t\t\t\t\tAc0xiNKP4rFL0QzD55q4NR1/GQB4MqZdoTA3LXKPrO8HRkIQqEDA3WjcpCQeKuqt\n\t\t\t\t\t\tVPU9mB/XSdzV3+iCVsIW1dSYNnC1FJWB5LBnQijEylcJSY2NAgMBAAGjUDBOMB0G\n\t\t\t\t\t\tA1UdDgQWBBQv1uF4H7q9kZG4TSDpZBWU+yE2BjAfBgNVHSMEGDAWgBQv1uF4H7q9\n\t\t\t\t\t\tkZG4TSDpZBWU+yE2BjAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQAL\n\t\t\t\t\t\tea2RNtk74QMKsbwzICCuADT/rllrKNzsgAkaAjcCdL+DfspFZSnav40MB7ksK16t\n\t\t\t\t\t\taebkpkCK6x3vE5eU3bosiOGektkVoAjbb+BVhuEQHSV17FaXQnkUe2t1httVIihx\n\t\t\t\t\t\tWF/bCXqIzLkbz3KhMX/oYWnLvB7R4UcmaPxImRmcJ5BFA6UXHqlU+d3/9+oOErUu\n\t\t\t\t\t\tTJBBU9BcDoIAcfgMe5MaDXNdVa2P8HD+JDeE3EWx1L7KEOVQaSfekYSTSmstnqBj\n\t\t\t\t\t\tOL0Jr2kxldHRwhrHu50f2PMJFKwvjy4/X79YwapTCn1ee7FWft255LdEqpBFz+we\n\t\t\t\t\t\ty3MXd8zZdHL4dhUTYdiF"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://signin.staging.studentmoneysaver.co.uk/saml/consume/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://vfu-test.su.se/Shibboleth.sso",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://vfu-test.su.se/Shibboleth.sso",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vfu-test.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vfu-test.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vfu-test.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vfu-test.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vfu-test.su.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vfu-test.su.se/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://vfu-test.su.se/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vfu-test.su.se/Shibboleth.sso/WAYF/wavelan",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://vfu-test.su.se/Shibboleth.sso/WAYF/wavelan",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vfu-test.su.se/Shibboleth.sso/WAYF/idp.secure.su.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vfu-test.su.se/Shibboleth.sso/WAYF/idp.it.su.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vfu-test.su.se/Shibboleth.sso/SWAMID",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://vfu-test.su.se/Shibboleth.sso/SWAMID",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vfu-test.su.se/Shibboleth.sso/WAYF/guest-idp.it.su.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vfu-test.su.se/Shibboleth.sso/WAYF/guest-idp-test.it.su.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "VFU \u00e4r verksamhetsf\u00f6lagd utbildning d\u00e4r utbildningen sker p\u00e5 en arbetsplats"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "VFU is workplace situated education where the education takes place at a work place"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Verksamhetsf\u00f6rlagd utbildning Stockholms universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Workplace Situated Education at Stockholm University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "vfu-test-sp01"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJAKDWuE2EOEoGMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDXZmdS10ZXN0LXNwMDEwHhcNMTUwNjAzMTMwNzUzWhcNMjUwNTMxMTMwNzUz\nWjAYMRYwFAYDVQQDEw12ZnUtdGVzdC1zcDAxMIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAqBHC96trgEAnc2lhXdp25vtIfLHe0gPdzM0NNI12zc+4WYsZ\nSlaR8+3gKI7vUf2239BfqHa7RVKAHE/r2i8d3N4caHH2R3dhqFRtat94jnCcodqj\nlZ/RXIUyqFL7MYi38+WbTUusFnMpKoHvR17r24p3veo+gaTFmpZGINu17xV5hvoG\nhkAYpkIi5SwVfbDFBU6fmfQOKKvfZKxlIUN1jpcj2V4LX6QLlS+EqVu8roaAUcMf\n4swdfr2vymiw3/+ft/Mvk1DinvCw1I6YC7Wia15KQXEFXL3qblvZE/qDGGibCDKc\nmD605oLiWYBctEGBjXmG3KwxWv54RYhpJ/O+IwIDAQABozswOTAYBgNVHREEETAP\ngg12ZnUtdGVzdC1zcDAxMB0GA1UdDgQWBBTfCdfu5uc8Vc9/Ot+TrX9gYANS3DAN\nBgkqhkiG9w0BAQUFAAOCAQEABpg1bhonX0T2nrxkMMKxO8UJeVT+Mdr5420CqqBp\npvM6yQGg6R6ezA9UZZXNoZHm957JTYuCt4Xsi22ePXXbHOMzKcWkl/v2mX72n9tx\nfN3dmyK7SDn5tJ1YEeLf5fGzxoeBBrMRJeLNAV9WY11JZCtc+f9F0fxrTebB0EUs\nQw3MbYJQSVnHXG5P6rJdKZ/hpDZ0PvKcsnZdxTUTq13M4jR+gSOV3/OKMI2oRlm4\nS93ScrA0zoYWayV9NZ1aBZW7mhaqg00AvcAbM1ZvA70pCsdhO6UH5dmGJVdE7zX+\nXOl0tx98AnNRgDTOuRoPtUa7Bg8w4puwklhK+gg+X01kZA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=vfu-test-sp01"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vfu-test.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://vfu-test.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vfu-test.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vfu-test.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vfu-test.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vfu-test.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vfu-test.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vfu-test.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vfu-test.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.exeterguild.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.exeterguild.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Membership Solutions: ExeterGuild.org"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.exeterguild.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.exeterguild.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.exeterguild.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.exeterguild.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.exeterguild.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.exeterguild.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.exeterguild.org/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.exeterguild.org/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.exeterguild.org/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.exeterguild.org/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.exeterguild.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.exeterguild.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.exeterguild.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.exeterguild.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.exeterguild.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.exeterguild.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://staging.researchprofessional.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Potter"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso@researchresearch.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Potter"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso@researchresearch.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://staging.researchprofessional.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-10-08T14:22:31Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Research Professional (Staging)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.researchresearch.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Research Research Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://staging.researchprofessional.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://staging.researchprofessional.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://staging.researchprofessional.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://staging.researchprofessional.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://staging.researchprofessional.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Research Professional is an intuitive platform for online access to news and funding services."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.researchprofessional.com/images/header-logo.png",
                    "height": "35",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "280"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Research Professional"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://staging.researchprofessional.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID+jCCAuKgAwIBAgIJANtavlaD4gXtMA0GCSqGSIb3DQEBBQUAMH4xCzAJBgNV\n\t\t\t\t\t\tBAYTAlVLMRMwEQYDVQQIEwpTb21lLVN0YXRlMQ8wDQYDVQQHEwZMb25kb24xHjAc\n\t\t\t\t\t\tBgNVBAoTFVJlc2VhcmNoIFJlc2VhcmNoIEx0ZDEpMCcGA1UEAxMgc3RhZ2luZy5y\n\t\t\t\t\t\tZXNlYXJjaHByb2Zlc3Npb25hbC5jb20wHhcNMTQxMDAzMTUyNDUwWhcNMjQwOTMw\n\t\t\t\t\t\tMTUyNDUwWjB+MQswCQYDVQQGEwJVSzETMBEGA1UECBMKU29tZS1TdGF0ZTEPMA0G\n\t\t\t\t\t\tA1UEBxMGTG9uZG9uMR4wHAYDVQQKExVSZXNlYXJjaCBSZXNlYXJjaCBMdGQxKTAn\n\t\t\t\t\t\tBgNVBAMTIHN0YWdpbmcucmVzZWFyY2hwcm9mZXNzaW9uYWwuY29tMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArdM6ozR6y5EBRjgqfDHUZPr2MicY03Gv\n\t\t\t\t\t\tB3M3UlMLH63mzyUkG/PGu44ggqPLkb52ec7Gxj5/J+9xtFdLY9h2LUyBWF01O82H\n\t\t\t\t\t\tj652edA19RigG5ph26VLy7d9fYG+PmUwhrlWlMIo4JvgopSL7Jrinn+CEMj2k7oY\n\t\t\t\t\t\tfkCezsqL9jtSprylCHOwlFFysgIVNAcGhr9enQixVczaft02+CoWluBOgeXoUDZb\n\t\t\t\t\t\txJ0GY3Hld8Q2UrtLYJjgUPRoqIS4Vpcwo3byIE7Gd++CmeD5W4oeRrXYgt6c83PC\n\t\t\t\t\t\t4L3g46OOqXyN9hb7LvaQmjsqSvpmpkHPPkUtPOcCyAGQpsx1FjOx5wIDAQABo3sw\n\t\t\t\t\t\teTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBD\n\t\t\t\t\t\tZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUle7hyLGQ0EpHrclYpACXpYbOYAMwHwYDVR0j\n\t\t\t\t\t\tBBgwFoAUle7hyLGQ0EpHrclYpACXpYbOYAMwDQYJKoZIhvcNAQEFBQADggEBABGR\n\t\t\t\t\t\t6qbmzA1hH18lj76R3XyV0ontRqZKvn8pwsK0K/GMWuKgv+OkYzEW6n6DeDL6sbSB\n\t\t\t\t\t\tcC4uiuTaS2iclxRnYud8PZttjWjuZhzO1qICnLa8sUjKqV9HUD4Gr3AXgNXtcnwW\n\t\t\t\t\t\tUMXAY2ys0GUtFoOR6vVPC0i35GErCCANcYOCw11ZRS71iNQtfXyblTHY1KVWNgsU\n\t\t\t\t\t\t3NVNwf9tq1Pk1M2UgNmllfyyoGKxiNyechbWlb1MBkmdQEqHliRvGW7UV2UVhO5b\n\t\t\t\t\t\t3kv1D2xEO0C7BaEihoy7KNWgAuhE/r9pM4nuN8s67A1PauUX+24rOtDWpf2D6IWZ\n\t\t\t\t\t\tHvPzwSwM7ejfr+CISQ4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://staging.researchprofessional.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://staging.researchprofessional.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://staging.researchprofessional.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://staging.researchprofessional.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://staging.researchprofessional.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://staging.researchprofessional.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Research Professional"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "A service that provides access to research opportunities and funding"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "false",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "false",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonTargetedID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "false",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "employeeID",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.2.840.113556.1.4.35",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "false",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:mail",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://abcidp.askham-bryan.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lea"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:andy.lea@askham-bryan.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andy"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:IT@askham-bryan.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lea"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:andy.lea@askham-bryan.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andy"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://abcidp.askham-bryan.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYjCCAkoCCQCbjHqVpdODLjANBgkqhkiG9w0BAQUFADBzMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjESMBAGA1UECBMJWW9ya3NoaXJlMQ0wCwYDVQQHEwRZb3JrMR0wGwYDVQQKExRB\n\t\t\t\t\t\tc2toYW0gQnJ5YW4gQ29sbGVnZTEiMCAGA1UEAxMZYWJjaWRwLmFza2hhbS1icnlh\n\t\t\t\t\t\tbi5hYy51azAeFw0xMzA0MDIxNjIyMjhaFw0zMzAzMjgxNjIyMjhaMHMxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRIwEAYDVQQIEwlZb3Jrc2hpcmUxDTALBgNVBAcTBFlvcmsxHTAbBgNV\n\t\t\t\t\t\tBAoTFEFza2hhbSBCcnlhbiBDb2xsZWdlMSIwIAYDVQQDExlhYmNpZHAuYXNraGFt\n\t\t\t\t\t\tLWJyeWFuLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA92dw\n\t\t\t\t\t\t/jLTq0PhWcfIRwHBB1yDYBU3l9eU+rJEjH0WXZJMmOuvHsdLeT2oMBUM60gWlwIz\n\t\t\t\t\t\t/uAoilRVQiMg48uMaodL7/etHiAGoMpzscC3CwKhHlXH7puM0QDeEb70J1t1h30q\n\t\t\t\t\t\tdDZBFtVmCs0B5CYBHjyqH+i82YWf0etzTdb73WBo1lOrRijZLcJGD/HCzijY1hPQ\n\t\t\t\t\t\tEkbTXwhcKaeU2Rk+5UpnZJbSUmBIGWO6u4K3ObrjyXalvWUo/m/6gWDsukHrmNnv\n\t\t\t\t\t\tqKGuuermOrnA4Noji85wfc8TwezFolrWvofPSdtworR8XKGejVEprQxou45d9tea\n\t\t\t\t\t\tLfBok30AvU2losYWqQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCSqC5N9FinG+AE\n\t\t\t\t\t\tZLrIMbFuudnUoVkMCtmZ9L9ItwB7fG6BtmcknMq369Bc6WeDBevEYAE900GUvb6y\n\t\t\t\t\t\tM+DB9sO4MlBi+FRnFjPI//X7IIhSP7gER7W5l+ZBTxe+KqeJ+p5etShh/q+A/u6f\n\t\t\t\t\t\tLHlwgzLRh/4NUIFiKRzG8Zebt5mYv1Bv3RIjHRr1kc9IfVpBljjidPgcRb3Kg8Yr\n\t\t\t\t\t\t5OomYsqDIo+BJBq/4r6tJ3chZTH65s6nlROA6EJmfgM46053tjWiZ9AQ8oh6hXTH\n\t\t\t\t\t\t/4IxUtQavt3994NTOWbuZyBOVkafzCiO8dVj00/fk/Gx6SNb+oKNHSfkcM7x8RPh\n\t\t\t\t\t\tUp+S4ts+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "askham-bryan.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://abcidp.askham-bryan.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://abcidp.askham-bryan.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://abcidp.askham-bryan.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://abcidp.askham-bryan.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://abcidp.askham-bryan.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://abcidp.askham-bryan.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://abcidp.askham-bryan.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://abcidp.askham-bryan.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "askham-bryan.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDYjCCAkoCCQCbjHqVpdODLjANBgkqhkiG9w0BAQUFADBzMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjESMBAGA1UECBMJWW9ya3NoaXJlMQ0wCwYDVQQHEwRZb3JrMR0wGwYDVQQKExRB\n\t\t\t\t\t\tc2toYW0gQnJ5YW4gQ29sbGVnZTEiMCAGA1UEAxMZYWJjaWRwLmFza2hhbS1icnlh\n\t\t\t\t\t\tbi5hYy51azAeFw0xMzA0MDIxNjIyMjhaFw0zMzAzMjgxNjIyMjhaMHMxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRIwEAYDVQQIEwlZb3Jrc2hpcmUxDTALBgNVBAcTBFlvcmsxHTAbBgNV\n\t\t\t\t\t\tBAoTFEFza2hhbSBCcnlhbiBDb2xsZWdlMSIwIAYDVQQDExlhYmNpZHAuYXNraGFt\n\t\t\t\t\t\tLWJyeWFuLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA92dw\n\t\t\t\t\t\t/jLTq0PhWcfIRwHBB1yDYBU3l9eU+rJEjH0WXZJMmOuvHsdLeT2oMBUM60gWlwIz\n\t\t\t\t\t\t/uAoilRVQiMg48uMaodL7/etHiAGoMpzscC3CwKhHlXH7puM0QDeEb70J1t1h30q\n\t\t\t\t\t\tdDZBFtVmCs0B5CYBHjyqH+i82YWf0etzTdb73WBo1lOrRijZLcJGD/HCzijY1hPQ\n\t\t\t\t\t\tEkbTXwhcKaeU2Rk+5UpnZJbSUmBIGWO6u4K3ObrjyXalvWUo/m/6gWDsukHrmNnv\n\t\t\t\t\t\tqKGuuermOrnA4Noji85wfc8TwezFolrWvofPSdtworR8XKGejVEprQxou45d9tea\n\t\t\t\t\t\tLfBok30AvU2losYWqQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCSqC5N9FinG+AE\n\t\t\t\t\t\tZLrIMbFuudnUoVkMCtmZ9L9ItwB7fG6BtmcknMq369Bc6WeDBevEYAE900GUvb6y\n\t\t\t\t\t\tM+DB9sO4MlBi+FRnFjPI//X7IIhSP7gER7W5l+ZBTxe+KqeJ+p5etShh/q+A/u6f\n\t\t\t\t\t\tLHlwgzLRh/4NUIFiKRzG8Zebt5mYv1Bv3RIjHRr1kc9IfVpBljjidPgcRb3Kg8Yr\n\t\t\t\t\t\t5OomYsqDIo+BJBq/4r6tJ3chZTH65s6nlROA6EJmfgM46053tjWiZ9AQ8oh6hXTH\n\t\t\t\t\t\t/4IxUtQavt3994NTOWbuZyBOVkafzCiO8dVj00/fk/Gx6SNb+oKNHSfkcM7x8RPh\n\t\t\t\t\t\tUp+S4ts+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Askham Bryan College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.askham-bryan.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Askham Bryan College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.tce.ar.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.tce.ar.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.tce.ar.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.tce.ar.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.tce.ar.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.tce.ar.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.tce.ar.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.tce.ar.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.tce.ar.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.tce.ar.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.tce.ar.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.tce.ar.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.tce.ar.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.tce.ar.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIJAKijRK1R7GS+MA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE3d3dy50Y2UuYXIubGFkb2suc2UwHhcNMTUwMzIzMTQ0NzMzWhcNMjUwMzIw\nMTQ0NzMzWjAeMRwwGgYDVQQDExN3d3cudGNlLmFyLmxhZG9rLnNlMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvVpy5ngZYaMpRy+sy1amoEfCRKst5cBh\nTci5tPNvZ/DDOhrcIWPmKG9R28eKLizYOHRmnH76bqY3d+BmnSgc78g/ILoyC0+8\nM0qnQh+209fGQRNB5ecvP7EA3D/FbnrCnZAbuUBwn6tTgCjSiO89TGjBRnyTEPK+\nuCUXtX2lrtqKgYDL+SKjUq1u9i4CXDh1sjBzr897mlGADK4wfatKCXJ8nnT/t9fT\nlfBcLY0ZKvDL0F9fU2wpQ7SzfKu1Gm+Ql4TdLcqLFMX50RgQrr4FUVjnhgJoREvm\n9jwsDorfvdD16vN79hVgky3/FZvaWDaUOQydustLHSupSRk6jw26iQIDAQABo2Uw\nYzBCBgNVHREEOzA5ghN3d3cudGNlLmFyLmxhZG9rLnNlhiJodHRwczovL3d3dy50\nY2UuYXIubGFkb2suc2UvZ3VpLXNwMB0GA1UdDgQWBBRMGFL5pn7W1LnuRFIcdFhD\nJ2a97DANBgkqhkiG9w0BAQUFAAOCAQEAooK8saDzzSUkkaWX+3RcQTsciJMmdFTo\noeQT84gN/iStJ43Hgw7MUUMJ+WV4SqJ08pBE6xiDv0k1gybJGIKUzVw7TeHElQP1\nZLz4bhyxHzidhrk4Ua0MWjbupYB15IxaJmGHvs+eFKYy9mhBP8LSjRReqaFTi7Hh\nvBLPrtM7P8GWZqe0jIpgoZhe0jkM5F1otZdHJqeB7xk/PFdWwbELYjbdhXmXlTVt\nmZS33NdlAK9V0/FNPnNIc6Kp8tNsw1a6dDhhY7qJ2guy8p0pkl9MNou+kPU1oiGR\nYFNEqHost6AnCf4RHHlu4PsSB7fG3M/oXgj9z2rUfqRGrFbUIfJOkg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.tce.ar.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.tce.ar.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.tce.ar.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.tce.ar.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.tce.ar.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.tce.ar.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.tce.ar.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.tce.ar.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.tce.ar.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.tce.ar.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sso.kolola.net/default-sp/",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@kolola.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "KOLOLA Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gomer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:richard@kolola.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.kolola.net/default-sp/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-03-04T10:42:06Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "KOLOLA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.kolola.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "KOLOLA Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.kolola.net/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "KOLOLA collaborative e-portfolio platform"
                  }
                ],
                "logo": [
                  {
                    "text": "https://sso.kolola.net/logo-ext.png",
                    "height": "89",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "260"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "KOLOLA"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID5TCCAs2gAwIBAgIJALchZtem4xoGMA0GCSqGSIb3DQEBCwUAMIGIMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjESMBAGA1UECAwJSGFtcHNoaXJlMRQwEgYDVQQHDAtTb3V0aGFtcHRv\n\t\t\t\t\t\tbjETMBEGA1UECgwKS09MT0xBIEx0ZDEXMBUGA1UEAwwOc3NvLmtvbG9sYS5uZXQx\n\t\t\t\t\t\tITAfBgkqhkiG9w0BCQEWEnN1cHBvcnRAa29sb2xhLm5ldDAeFw0xNjAyMjQxNzI4\n\t\t\t\t\t\tMTRaFw0yNjAyMjMxNzI4MTRaMIGIMQswCQYDVQQGEwJHQjESMBAGA1UECAwJSGFt\n\t\t\t\t\t\tcHNoaXJlMRQwEgYDVQQHDAtTb3V0aGFtcHRvbjETMBEGA1UECgwKS09MT0xBIEx0\n\t\t\t\t\t\tZDEXMBUGA1UEAwwOc3NvLmtvbG9sYS5uZXQxITAfBgkqhkiG9w0BCQEWEnN1cHBv\n\t\t\t\t\t\tcnRAa29sb2xhLm5ldDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALqn\n\t\t\t\t\t\tqn/5OOL3O888Y2EafbCB4xqmIiRYeeJWzVajkGIIqsCmaUpkrlVW5I/dfVs8YmiZ\n\t\t\t\t\t\tuy1HiOQOjnDsRbI718Qco5kzAaCyrHvZK1emEYVt5kJXzkMwqjlGqp4tA+03DtKw\n\t\t\t\t\t\tlr2nRKXXScA/o8y0z03hH61SibkcHb4NRqmLxK2n9vaEzj1ASKLYAPuAsJQYaVG8\n\t\t\t\t\t\tZsnYa/lpQad/yAFLE+Cqek7qEcR7sWIv4b4dUOKtEvW05pkeRQD9EclKMMQA4ipl\n\t\t\t\t\t\tmRscHk8aXvnjQuMEhFEtcCLgU0tntMvj6s+nlL+tpsNS7bzh6gHVljiIx7Y0b1Lv\n\t\t\t\t\t\tC/43xDd7myfuan41zNECAwEAAaNQME4wHQYDVR0OBBYEFEhpOKosGAqfz7tTtiXB\n\t\t\t\t\t\tDpjdfsvSMB8GA1UdIwQYMBaAFEhpOKosGAqfz7tTtiXBDpjdfsvSMAwGA1UdEwQF\n\t\t\t\t\t\tMAMBAf8wDQYJKoZIhvcNAQELBQADggEBAGXTKwWzBS6dK/X3ratq0+WBkBNQQu+F\n\t\t\t\t\t\tN5tcGKgobe//jPij73IKnI20B1R61cGRFhHIHGoDEL3jmjUJZ/aaG6z74zOLqK1z\n\t\t\t\t\t\t69nM9mQR8elkXvjXuNN5gx+SJv6wpJuzF6fWbkJbp1HzJCqCxUEAFrsyae9j1t/9\n\t\t\t\t\t\thaSIueBzuWTJFFLd1K5XvOwR9/9WdtPWyLVHyOoZ/FJiL1k7y3z7sycNvIxYAY9n\n\t\t\t\t\t\tdrFk5UcJ9mN85bZspWkaNkNTk3jI/6Ix5wiClVlxgIGe+/boRTyFqx8RJcMKiVKV\n\t\t\t\t\t\tSu6P/A7hxpUS7LZ5rDB6ifXGAGPWOeYdvT6NJefkpqCJU4NySMH2kp0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID5TCCAs2gAwIBAgIJALchZtem4xoGMA0GCSqGSIb3DQEBCwUAMIGIMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjESMBAGA1UECAwJSGFtcHNoaXJlMRQwEgYDVQQHDAtTb3V0aGFtcHRv\n\t\t\t\t\t\tbjETMBEGA1UECgwKS09MT0xBIEx0ZDEXMBUGA1UEAwwOc3NvLmtvbG9sYS5uZXQx\n\t\t\t\t\t\tITAfBgkqhkiG9w0BCQEWEnN1cHBvcnRAa29sb2xhLm5ldDAeFw0xNjAyMjQxNzI4\n\t\t\t\t\t\tMTRaFw0yNjAyMjMxNzI4MTRaMIGIMQswCQYDVQQGEwJHQjESMBAGA1UECAwJSGFt\n\t\t\t\t\t\tcHNoaXJlMRQwEgYDVQQHDAtTb3V0aGFtcHRvbjETMBEGA1UECgwKS09MT0xBIEx0\n\t\t\t\t\t\tZDEXMBUGA1UEAwwOc3NvLmtvbG9sYS5uZXQxITAfBgkqhkiG9w0BCQEWEnN1cHBv\n\t\t\t\t\t\tcnRAa29sb2xhLm5ldDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALqn\n\t\t\t\t\t\tqn/5OOL3O888Y2EafbCB4xqmIiRYeeJWzVajkGIIqsCmaUpkrlVW5I/dfVs8YmiZ\n\t\t\t\t\t\tuy1HiOQOjnDsRbI718Qco5kzAaCyrHvZK1emEYVt5kJXzkMwqjlGqp4tA+03DtKw\n\t\t\t\t\t\tlr2nRKXXScA/o8y0z03hH61SibkcHb4NRqmLxK2n9vaEzj1ASKLYAPuAsJQYaVG8\n\t\t\t\t\t\tZsnYa/lpQad/yAFLE+Cqek7qEcR7sWIv4b4dUOKtEvW05pkeRQD9EclKMMQA4ipl\n\t\t\t\t\t\tmRscHk8aXvnjQuMEhFEtcCLgU0tntMvj6s+nlL+tpsNS7bzh6gHVljiIx7Y0b1Lv\n\t\t\t\t\t\tC/43xDd7myfuan41zNECAwEAAaNQME4wHQYDVR0OBBYEFEhpOKosGAqfz7tTtiXB\n\t\t\t\t\t\tDpjdfsvSMB8GA1UdIwQYMBaAFEhpOKosGAqfz7tTtiXBDpjdfsvSMAwGA1UdEwQF\n\t\t\t\t\t\tMAMBAf8wDQYJKoZIhvcNAQELBQADggEBAGXTKwWzBS6dK/X3ratq0+WBkBNQQu+F\n\t\t\t\t\t\tN5tcGKgobe//jPij73IKnI20B1R61cGRFhHIHGoDEL3jmjUJZ/aaG6z74zOLqK1z\n\t\t\t\t\t\t69nM9mQR8elkXvjXuNN5gx+SJv6wpJuzF6fWbkJbp1HzJCqCxUEAFrsyae9j1t/9\n\t\t\t\t\t\thaSIueBzuWTJFFLd1K5XvOwR9/9WdtPWyLVHyOoZ/FJiL1k7y3z7sycNvIxYAY9n\n\t\t\t\t\t\tdrFk5UcJ9mN85bZspWkaNkNTk3jI/6Ix5wiClVlxgIGe+/boRTyFqx8RJcMKiVKV\n\t\t\t\t\t\tSu6P/A7hxpUS7LZ5rDB6ifXGAGPWOeYdvT6NJefkpqCJU4NySMH2kp0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.kolola.net/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sso.kolola.net/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sso.kolola.net/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sso.kolola.net/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://slateford.edina.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Stuart"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alex.stuart@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Stuart"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:alex.stuart@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alex"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://slateford.edina.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-09-30T09:42:06Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://slateford.edina.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://slateford.edina.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://slateford.edina.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://slateford.edina.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://slateford.edina.ac.uk/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://slateford.edina.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://slateford.edina.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "slateford.edina.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUaFQBDsbQD1myaqUBq2Sfj+zNqTMwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwIDEeMBwGA1UEAwwVc2xhdGVmb3JkLmVkaW5hLmFjLnVrMB4XDTE1MDkxNzE1\n\t\t\t\t\t\tMTIzNloXDTM1MDkxNzE1MTIzNlowIDEeMBwGA1UEAwwVc2xhdGVmb3JkLmVkaW5h\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAntjVOxkCP9da\n\t\t\t\t\t\tER4feMyp9emdkDLUsIyz4ER7mfzIOX3MV4kBixou796nBXc0DW1Tamh8k1+e/y/d\n\t\t\t\t\t\txL3hX2Mje/grZMQrCgTnUUcMb4Chs1mMgA1nrYGBZcDzeCPFNe/65yohIWlR9RLo\n\t\t\t\t\t\tvGRitaHu2P8edI+Ax82woCD/eFq8uf25KT2mpY2PzFH3qsASR9vPE1SjVj9/IyEL\n\t\t\t\t\t\tvaMpPhfFhQ1cwKG9WZr6FmX3oWQwNRTUyv5Oke7S/IKk4ucogtnrGsxql8zasjpL\n\t\t\t\t\t\t7iVVHuiFYEYPDLbuags7dJ66GMyufpXYhJiWb7VJrMuTt6jjMAdGsjkOTJtha6YF\n\t\t\t\t\t\t+iB2m3NkWQIDAQABo3EwbzAdBgNVHQ4EFgQUxERMysccN0DYIXIaspFY2+9BNRkw\n\t\t\t\t\t\tTgYDVR0RBEcwRYIVc2xhdGVmb3JkLmVkaW5hLmFjLnVrhixodHRwczovL3NsYXRl\n\t\t\t\t\t\tZm9yZC5lZGluYS5hYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOC\n\t\t\t\t\t\tAQEAF4VaakgAejlEA4YlVymEXCstzhKpN66lZuL+lW3Y91EgoabxD5dyq0mezO+Y\n\t\t\t\t\t\tGt7UNGGnSRt9UxDkY7E4heeVBGmdoFPBj0wsUGXcfTOZ3/TTTJYmtEKEFLU5S5Nv\n\t\t\t\t\t\twF4O4IDVsT3VDy/5u5iOtNGT4F1wMXFgHjC7PCpgHL6VvYX2w5O/abZvFMMtFE3M\n\t\t\t\t\t\tavfm9oJO4Ai+eWZXEucqZX0HS8hVAzxLRDrZOmZLiLaYBPujvqligEa++K6WJpu0\n\t\t\t\t\t\t495tpKxyzKlo4C5QKUDpViGUP58XSD5kJCJeS4Ymi+WV+aFs/O8lmZ5hDfewOc1g\n\t\t\t\t\t\t5uS5lUQuoXJ9EWaUU4yHKgG38Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVAJXbfu0qWAZqhGmvDTbCJH2YO2I8MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMCAxHjAcBgNVBAMMFXNsYXRlZm9yZC5lZGluYS5hYy51azAeFw0xNTA5MTcx\n\t\t\t\t\t\tNTEyMzRaFw0zNTA5MTcxNTEyMzRaMCAxHjAcBgNVBAMMFXNsYXRlZm9yZC5lZGlu\n\t\t\t\t\t\tYS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJ+y62JbfCH7\n\t\t\t\t\t\tz71R9TDNbvfuuLigntMBihrLoozF2Km+yk3uLfqbQX9HDWEpQt3fS3oSdRJxR3H2\n\t\t\t\t\t\tMnk3/wfu4KeIMhN1avZsEbzN/BsnX+Cqw/SLi1V5OAqqSZI7yr6NmTE5TqW0/h0n\n\t\t\t\t\t\tS7Xq4D45zrbzGZ/3/W7X+707o/9UV/V0HLb/A3HSCJJ4oIGYbHkzqfREoO6r0fDu\n\t\t\t\t\t\tsiv5KQZBmonyi7qkkzDFtOk+zyaJxJQdUymz1XuvkUAhNf50cSjyoyiObmIdCdBg\n\t\t\t\t\t\tcPOjVFIMcbGXlb7h4q1yoCCj+eBwR8HzZ4kwHDy5M/nU0jkX9d5A3ls9Li22W3GY\n\t\t\t\t\t\teoAhtUO56a8CAwEAAaNxMG8wHQYDVR0OBBYEFOeXB8Kk8+DvOBzzPYfnPV/VDG4V\n\t\t\t\t\t\tME4GA1UdEQRHMEWCFXNsYXRlZm9yZC5lZGluYS5hYy51a4YsaHR0cHM6Ly9zbGF0\n\t\t\t\t\t\tZWZvcmQuZWRpbmEuYWMudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQAD\n\t\t\t\t\t\tggEBAIOF8rTpggkzBYuwVbvnbrlzD8tV7BgbU4QDpWCtgolHoL+qm9AYoSoxO+Uh\n\t\t\t\t\t\tJF7049JiVNdX9TgGDHTOtQkRUBQ5uirhaeJcJMlUTs7JTmQM49hTaI1fcxZ5rD5t\n\t\t\t\t\t\tQ5WoLcyiGNan46wVen32DBSqtuqKM3cfGciQPuRNWIKeD7a9TawyH9C4h0b84mFN\n\t\t\t\t\t\td+vDupXO0jo/NDCdwrG9KqSebhI6dlKerEQ5VtvAEMWBY0iAdo4SyhT3XxjLm/A8\n\t\t\t\t\t\t3/6MjSrnTGa+QNCQYYKgPYEcUi5O3Pzt5kqELoU4AEHS9UePQ5no+8VLaNrOanrk\n\t\t\t\t\t\tUgdUiNZ8Ouem7SX/w7R0VgYEvno="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVAKOoQhLtWEUvuc1BChPnl4v49qTyMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMCAxHjAcBgNVBAMMFXNsYXRlZm9yZC5lZGluYS5hYy51azAeFw0xNTA5MTcx\n\t\t\t\t\t\tNTEyMzVaFw0zNTA5MTcxNTEyMzVaMCAxHjAcBgNVBAMMFXNsYXRlZm9yZC5lZGlu\n\t\t\t\t\t\tYS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKgms50q8J1x\n\t\t\t\t\t\tsHNNtr5zF3cq5+K1cjdKekiDWNry+iPp1W8mNPm/ExP/CDHZrU4W9U5S7I+CrPOH\n\t\t\t\t\t\t1jECGhS7ezEoXs0slc9zKIetcKbOV3AcLcorQildO/y8A+Rn6qwSQ59+zGRcxccI\n\t\t\t\t\t\tOs5EXVgpNMZy9coUPk/tnVPC9javymsodJYGX3nUT/E//YmWxRWWbLtkqPf2R8N3\n\t\t\t\t\t\tqRVQ7e1Z4i1pvdG++ANGXjg6TvPHJivdLj2LfoGcJGu1YTbmfKC0sDbXNp86rFcY\n\t\t\t\t\t\tYAWqrMTiAL9kaYT+UDS5ZCnxc2IH+nXQh9OwC+qLyf1ZoXN5ezODwKxagBvH9Ypt\n\t\t\t\t\t\t6iED7+6TA58CAwEAAaNxMG8wHQYDVR0OBBYEFOwRhkPfA8Cwo0ReFdBFgQy+WqNS\n\t\t\t\t\t\tME4GA1UdEQRHMEWCFXNsYXRlZm9yZC5lZGluYS5hYy51a4YsaHR0cHM6Ly9zbGF0\n\t\t\t\t\t\tZWZvcmQuZWRpbmEuYWMudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQAD\n\t\t\t\t\t\tggEBAEcHtO97dQXmxDs3IsZcIJh+XM/m07JFm6rtcPnuuyIM7Ys7cUL460h0qe2+\n\t\t\t\t\t\tenFYdxe7FCib36zFaaSp0SYE2FWnuWMtLzg9JAIl7HBPLFdSzryJsH0gMyKOPFff\n\t\t\t\t\t\t2mF6of6K/AolKNP1enS0DgY0LiCY74VEh4S4COm4sUkHPRtMJTtRrkoiLuNXMUaL\n\t\t\t\t\t\tJQdDzzK6KZ4uQucPErvQxXjhaNCAHUQRclR+QfFM9Ibr3uIbD+Zs50fFkS/ihlhk\n\t\t\t\t\t\t1quXSXm1737rQJwd9EsXzGhUxxdRC2H/ly3H8E0NuDgeWfmBYVkXUn4JY1J2W1Dq\n\t\t\t\t\t\txnuCMY0qHTFh2QuZSh0kGrs2wcY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Slateford Test IdP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://ukfederation.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.univ-reims.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kevin D\u00e9r\u00e9"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kevin.dere@univ-reims.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.univ-reims.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-12-08T10:46:29Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.univ-reims.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.univ-reims.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.univ-reims.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-reims.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-reims.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TEST - URCA"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "TEST - URCA"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TEST - URCA"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TEST - URCA"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAPkhMvLgY2ZrI5pH4Iz9K3yEoaBnMA0GCSqGSIb3DQEB\nCwUAMB0xGzAZBgNVBAMMEnNoaWIudW5pdi1yZWltcy5mcjAeFw0xNTEyMDcxNjE4\nMjJaFw0zNTEyMDcxNjE4MjJaMB0xGzAZBgNVBAMMEnNoaWIudW5pdi1yZWltcy5m\ncjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIc3VJWa4wmjotzGHZmT\nlSwU6IWHMJv2DxLi/Rr+hu5FCIpLHC3wLTMiaAn2QT5i/M/jcbd+euaTKDncH1lF\nCDyRV+4FPDG1fM/QtneOx+90GiV0YKE0/iQ8nrhJDmZtnmqcpFsggPAAfhmf417S\nWwios6s7osiE7xoQ7zjMeIRVDW83Pqi5QCHrowSeSmMEl1cwokbHV10TDMzHCrrL\n8LuB5UN7xJgzaSWsEYRq9Vc577j6tn2NWkx/lGlRcz4yzRz9jIsdtJtKE1m/17as\n+fqiYVdaEKVZPR6OnkqdmpXqCk0zUEepq9r1bBMWLiO58aE2oky9a374tUoNXnKK\naD8CAwEAAaNrMGkwHQYDVR0OBBYEFIDldfXIKmkdTqqwVDMBJb+EiUlZMEgGA1Ud\nEQRBMD+CEnNoaWIudW5pdi1yZWltcy5mcoYpaHR0cHM6Ly9zaGliLnVuaXYtcmVp\nbXMuZnIvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBABBItTY6kO2S\nX7TrZyDJDkLRI0+i7MSxTHHLtMh7XAcqUjRuXWpgR25TGihmBFYkKmicRvyn5fDn\nEamxmtVD0Re9yjsnnOf2IMGItHQ9DQDmpIIAhVt5LFYgwJr6QMUs7uzD6Sr0zc20\nXq1XGHbsai8ilgpZhe1zWyPje489fehMhOel9WDeoEgogCWs0aY5Ia1PLXX93iIZ\nRII++BqGUGcbDULDV3QsfqmhtGIJx3zeenGcdbJlwv7mdzYywvtlXrmSpLWkdDO6\nKjXqULhEIW1vrF4ffyTEphjqptw89dWd2O972IM/xSiEWz1HDXd8BsyODRihLZq/\nLJ8gs2GQxRQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "TEST - URCA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-reims.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "TEST - URCA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.fxu.org.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.fxu.org.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-09-02T11:32:51Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Falmouth & Exeter Students' Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fxu.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.fxu.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.fxu.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.fxu.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.fxu.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.fxu.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.fxu.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.fxu.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.fxu.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.fxu.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.fxu.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.fxu.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.fxu.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.fxu.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:incommon:internet2.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "techsupport@internet2.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "techsupport@internet2.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "techsupport@internet2.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:internet2.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://origin.internet2.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://origin.internet2.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://origin.internet2.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://origin.internet2.edu/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "internet2.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.internet2.edu/about/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.internet2.edu/media/medialibrary/2013/10/15/internet2_logo_200pxtrans.gif",
                    "lang": "en",
                    "height": "200",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "200"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.internet2.edu/policies/privacy/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Internet2"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDpTCCAo2gAwIBAgIJAIFOoKy0fzFNMA0GCSqGSIb3DQEBCwUAMIGRMQswCQYD\nVQQGEwJVUzERMA8GA1UECBMITWljaGlnYW4xEjAQBgNVBAcTCUFubiBBcmJvcjES\nMBAGA1UEChMJSW50ZXJuZXQyMR0wGwYDVQQDExRvcmlnaW4uaW50ZXJuZXQyLmVk\ndTEoMCYGCSqGSIb3DQEJARYZdGVjaHN1cHBvcnRAaW50ZXJuZXQyLmVkdTAeFw0x\nNTA1MjIxMzIzMTVaFw0yNTA1MTkxMzIzMTVaMIGRMQswCQYDVQQGEwJVUzERMA8G\nA1UECBMITWljaGlnYW4xEjAQBgNVBAcTCUFubiBBcmJvcjESMBAGA1UEChMJSW50\nZXJuZXQyMR0wGwYDVQQDExRvcmlnaW4uaW50ZXJuZXQyLmVkdTEoMCYGCSqGSIb3\nDQEJARYZdGVjaHN1cHBvcnRAaW50ZXJuZXQyLmVkdTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAPBzFvoogACW6IKB0HnwFX09zQ9UAP/xdW4MQHD5nvJO\nUbKBW2Jqm+XfRwjgJnpDUokjj7mikDKS63YNHkNfTacH2i/Y7NsArXC/qik2bwW6\nrlYEWDJTjmQRJXUEGYY21UT8MAiyuDdLUrkHqYjUA5pQIWkzvIXudZ06Wa57jf3w\nEBOAnlyGhi7PyDzkkoJhpB/8A598zi/OBGNHU/QfVAN9ohrQW/7a4xM4aBx9n9QW\nohDsDI7sY+N7xTOmbxvt+vPyvAo5EwneUbZsF3QHTnysIWxMfrRUNMszj0vOv6to\nEYW0b+rGY7pc6wU3KkIC8D7Obym7GvlLl3Rp2cwRF0cCAwEAATANBgkqhkiG9w0B\nAQsFAAOCAQEAry/zf0b8D0C46Q5dqsZxyEIKFikqB/4MBFqESenAm/xkvdUk/OdV\ng9ih+jAuZC3M1TqB6A4OV6awnNocH61Ko5DF0BO3uU9JKUzJhrew8Kb81TSB7akV\nNDyhn66iudRNaPthvJ79NYugbx1SjJYznqfLgw/PolLfjpW7DACIa9CMliXJTOVP\nhDtzphzWaOjXdfU904A3QuaeQq2LYOsYkG+GmFLSvzJ1UbvQ/NUTFeTpIVgsaUOb\nFaaEtp/LBAgwDJl9hoToLsRJHZdXevqmqKokP5I6LjXianwSgYDzku3sOwt/YwZM\nO5DEpKOPF/GsgEfq0uuXyFwYqiJLJFuEbw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "error_url": "https://origin.internet2.edu/error.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Internet2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.internet2.edu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Internet2"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://duck-dev.bournemouth.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Foy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mfoy@bournemouth.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wilkinson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:wilkinsonc@bournemouth.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Claire"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://duck-dev.bournemouth.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://duck-dev.bournemouth.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://duck-dev.bournemouth.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bournemouth.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDXzCCAkegAwIBAgIJAO6CYqChSs/9MA0GCSqGSIb3DQEBBQUAMEYxHzAdBgNV\n\t\t\t\t\t\tBAoMFkJvdXJuZW1vdXRoIFVuaXZlcnNpdHkxIzAhBgNVBAMMGmR1Y2stZGV2LmJv\n\t\t\t\t\t\tdXJuZW1vdXRoLmFjLnVrMB4XDTE0MDEyNzEzMzczOFoXDTI0MDEyNTEzMzczOFow\n\t\t\t\t\t\tRjEfMB0GA1UECgwWQm91cm5lbW91dGggVW5pdmVyc2l0eTEjMCEGA1UEAwwaZHVj\n\t\t\t\t\t\tay1kZXYuYm91cm5lbW91dGguYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQC8D4pXasrHRGOOesMTZ+4+sX9RMHMZ/OU9NXTxXFPIdNEB8HImGayd\n\t\t\t\t\t\tVNXCUmhGIRySMBNhvHdMEui5OFq0hHd/Rxe6FO8itPxsxLvbW0K6pb5r7yI8s/mc\n\t\t\t\t\t\tRws8qC17OvhX0vgbWXAdp2/zPTCAYSoIA960f41KOc1jVO3gKXELkGV0rc8Fte2h\n\t\t\t\t\t\tTuTHSVo1u0kg8IXoSTsyDVIBbkWmL8XJp39VZ8Im++N6l+vajxF8TH2oqz70xi60\n\t\t\t\t\t\tkhQy8JTBg2F5PPcCRIWauo9TXJiHFUHWaMZcl8RucOXNOcDts1yTZaFLD4kzTCE9\n\t\t\t\t\t\tWqgFEOqpjD/IM4pPFAum0Z2oB08WaLDpAgMBAAGjUDBOMB0GA1UdDgQWBBSSJsuN\n\t\t\t\t\t\tR63OgPcAndwv6yQOhWNjwDAfBgNVHSMEGDAWgBSSJsuNR63OgPcAndwv6yQOhWNj\n\t\t\t\t\t\twDAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCfNUSVwmAjZdsH3md3\n\t\t\t\t\t\tv9cfud8n5gNFKjnB54zZXZsa8inlIQ0pSfqqkxrffCeVlhWiZf9EIL30FDP1M5mX\n\t\t\t\t\t\t88oj4mNj0hkVtujIFmd4cpf/Kij+96dOVhfXyezsvHFy/exyD94NUdTdrs53uZN/\n\t\t\t\t\t\tLoeWfZyusHKVAQsa8Rm127ydCiCv+AQkAnYGPHD/DlGKJQ3V6QbZsNe0aEWDTiLE\n\t\t\t\t\t\t3ZDX+jV9I0pM2AZemD6qlS2x7vxds8V9QI9yA7sFO1Ee/atoLO4R0e2Tqa3zzlqj\n\t\t\t\t\t\tjzoKTt9nOBpUxTZMlQBNjpQZl6XHSk/dM3ECz+trlYpRcp8wMy9l6bku6zxxS4b1\n\t\t\t\t\t\tuq1+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bournemouth University_DEV"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bournemouth.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Bournemouth University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://identites.ec-lyon.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cheval R\u00e9gis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "regis.cheval@ec-lyon.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://identites.ec-lyon.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-04-20T10:17:21Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://identites.ec-lyon.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://identites.ec-lyon.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://identites.ec-lyon.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ec-lyon.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ec-lyon.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Centrale de Lyon"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Centrale de Lyon"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVAJrguR/jXhFque4KJfEyebuerBj4MA0GCSqGSIb3DQEB\nBQUAMCAxHjAcBgNVBAMTFXNoaWJib2xldGguZWMtbHlvbi5mcjAeFw0xMjAzMDcx\nMzUxMDFaFw0zMjAzMDcxMzUxMDFaMCAxHjAcBgNVBAMTFXNoaWJib2xldGguZWMt\nbHlvbi5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMFBE2ZGRJed\nX1yuAPuuFwufY2BHUSXDcF+pYE5e9YpBcljwE9DWgoQLRtBzsEBR7EyRZJDe+XZI\nDGe+gT7p0yrIsNjVXAJld3l9YHo3EKZ2YcTDC9EtUVDF70EqQL1+KFzMqHLmnojr\n/7FYR5iiRwcQ7+dQa8RBLwgXckpTzsjiJyuHzvUrDJmatKMsct5a16Hk/UG/BEjz\nm270xkFclPImp5hgG3Y0yLcuPAVoj/0aydnp8+/ZRaRL03EHbuSt2ewf4OvoQeAm\nJ/xtpiOpVFQwApeCx+G7YEgC4W48lo797QlCpaw7fXUPxKhBxU38yDXE27mIt6Zh\nk0/JtUTCCG0CAwEAAaNxMG8wTgYDVR0RBEcwRYIVc2hpYmJvbGV0aC5lYy1seW9u\nLmZyhixodHRwczovL3NoaWJib2xldGguZWMtbHlvbi5mci9pZHAvc2hpYmJvbGV0\naDAdBgNVHQ4EFgQUQwnjctonyj2JIsIKaPFhCV9oIFEwDQYJKoZIhvcNAQEFBQAD\nggEBAC0S2ZzH4X+GcKFny1NkFcMz6z1tlJ+iDgcKrv44m1ZyqOtiPm8k91rYYr5f\nNqezE6TGWH/taqN+/Y5+cTnPOjmJKwbIGu56Pt3nilhtcRShgVmW6msVdaKtf5Sr\n2dfNYQTHRm/YBAU+VzBUraMijeL2XnR+PFm3VNE+TdfParaLAMHurmYBE/6tQfXt\n4D6wA3/uLosIJ9ofWuJlPEsmYBTm5RukxnH0Qb1Gb5n2E8V+ZNCImpjZFsxSSrYz\nRiwCcgJOD+DOge8blZpwqnL6EKHFiSVauCzZAQ4B/k+9m0kZBXapgA2Fs3FI8uC3\nywgk8luEHvdrWWSkFWa4yb2TuI4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ecole Centrale de Lyon"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ec-lyon.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ecole Centrale de Lyon"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://kantarainitiative.org/shibboleth-sp",
    {
      "entity_id": "https://kantarainitiative.org/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "vps586.inmotionhosting.com"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDTCCAfWgAwIBAgIBADANBgkqhkiG9w0BAQUFADAlMSMwIQYDVQQDExp2cHM1\nODYuaW5tb3Rpb25ob3N0aW5nLmNvbTAeFw0wOTAzMzEwNjA4NDhaFw0xOTAzMjkw\nNjA4NDhaMCUxIzAhBgNVBAMTGnZwczU4Ni5pbm1vdGlvbmhvc3RpbmcuY29tMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApfoh2kCRBMGXa9B6pp/1EXoo\nwhUDFFlXj4I5ghElE8uDt7yMJCkjvmgrdN/kbzNR8lTzrFX0zXhazIQ97apU9Wl6\nZGVcqXv/nFV4L8RjtzF2JhfIjQdWEAUHE33JiX/ymCHW7dzOiThstcLVWEBfP2Ek\n5M0MQNXSro79Tezuwx+XTnJdMEJM62zeKE0Vd3FSPQiY/VqFE27B/NxlFtUXgEvm\ng5zNsyluvszDL4JGdQhFha8A6a0xEVMQGpXZ2O39O5p0iDOzYCm1G1qjxKkpIMvw\n1KZ3dp1yUPry+fhwqgZomisiKMj1a1RnUE3lcqPSo0WRTsfBEo7MjY1IvDw2swID\nAQABo0gwRjAlBgNVHREEHjAcghp2cHM1ODYuaW5tb3Rpb25ob3N0aW5nLmNvbTAd\nBgNVHQ4EFgQUguxIYPzd0C9X18COxccJXTiIFwkwDQYJKoZIhvcNAQEFBQADggEB\nAJaXKkAKAvrtmB4R1hKrYaEFQLz9YKca6zkB6m2rPz6zNN8w50sJh6CjPAgItMXR\nL6VkRed+ccQh8432/+/vV8vH/Ws9HhSsUJuo3COqEcZj03OdvAKuSvkPshMNjIsr\n/yrr5ODITEgfomOD4QIgUdfQAqHjNyxCiIVKNflVsTeeM8amGLLSQ9sXKjRGSUH8\nY/SClb8dKmpaqoc0H3f/GHpjvV5CnUonfPbfmyf+xuQs3OKJfWdf40kIUXroaZwD\ntA+MB0Ypuj6NzW5Fv/9Vl/zA5LsFOb+yL/Y5XZfibdZYR5Nb37vTD7Ap6tb1Femb\nltKszGgmznwcoz5Uxs1KF1E="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=vps586.inmotionhosting.com"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "vps586.inmotionhosting.com"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDTCCAfWgAwIBAgIBADANBgkqhkiG9w0BAQUFADAlMSMwIQYDVQQDExp2cHM1\nODYuaW5tb3Rpb25ob3N0aW5nLmNvbTAeFw0wOTAzMzEwNjA4NDhaFw0xOTAzMjkw\nNjA4NDhaMCUxIzAhBgNVBAMTGnZwczU4Ni5pbm1vdGlvbmhvc3RpbmcuY29tMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApfoh2kCRBMGXa9B6pp/1EXoo\nwhUDFFlXj4I5ghElE8uDt7yMJCkjvmgrdN/kbzNR8lTzrFX0zXhazIQ97apU9Wl6\nZGVcqXv/nFV4L8RjtzF2JhfIjQdWEAUHE33JiX/ymCHW7dzOiThstcLVWEBfP2Ek\n5M0MQNXSro79Tezuwx+XTnJdMEJM62zeKE0Vd3FSPQiY/VqFE27B/NxlFtUXgEvm\ng5zNsyluvszDL4JGdQhFha8A6a0xEVMQGpXZ2O39O5p0iDOzYCm1G1qjxKkpIMvw\n1KZ3dp1yUPry+fhwqgZomisiKMj1a1RnUE3lcqPSo0WRTsfBEo7MjY1IvDw2swID\nAQABo0gwRjAlBgNVHREEHjAcghp2cHM1ODYuaW5tb3Rpb25ob3N0aW5nLmNvbTAd\nBgNVHQ4EFgQUguxIYPzd0C9X18COxccJXTiIFwkwDQYJKoZIhvcNAQEFBQADggEB\nAJaXKkAKAvrtmB4R1hKrYaEFQLz9YKca6zkB6m2rPz6zNN8w50sJh6CjPAgItMXR\nL6VkRed+ccQh8432/+/vV8vH/Ws9HhSsUJuo3COqEcZj03OdvAKuSvkPshMNjIsr\n/yrr5ODITEgfomOD4QIgUdfQAqHjNyxCiIVKNflVsTeeM8amGLLSQ9sXKjRGSUH8\nY/SClb8dKmpaqoc0H3f/GHpjvV5CnUonfPbfmyf+xuQs3OKJfWdf40kIUXroaZwD\ntA+MB0Ypuj6NzW5Fv/9Vl/zA5LsFOb+yL/Y5XZfibdZYR5Nb37vTD7Ap6tb1Femb\nltKszGgmznwcoz5Uxs1KF1E="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=vps586.inmotionhosting.com"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://kantarainitiative.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "http://kantarainitiative.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://funk.chs.chalmers.se/saml/www/module.php/saml/sp/metadata.php/Funk",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jensen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "robin@montania.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://funk.chs.chalmers.se/saml/www/module.php/saml/sp/metadata.php/Funk",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://funk.chs.chalmers.se/saml/www/module.php/saml/sp/saml2-logout.php/Funk",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Funktion\u00e4rsregistret f\u00f6r Chalmers Studentk\u00e5r"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Funktion\u00e4rsregistret"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://funk.chs.chalmers.se/saml/www/module.php/saml/sp/saml2-acs.php/Funk",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://funk.chs.chalmers.se/saml/www/module.php/saml/sp/saml1-acs.php/Funk",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://funk.chs.chalmers.se/saml/www/module.php/saml/sp/saml2-acs.php/Funk",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://funk.chs.chalmers.se/saml/www/module.php/saml/sp/saml1-acs.php/Funk/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.fullerton.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jodell@fullerton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James O'Dell"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.fullerton.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.fullerton.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE7jCCA9agAwIBAgIJAKJvT9iELa2jMA0GCSqGSIb3DQEBBQUAMIGqMQswCQYD\nVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTESMBAGA1UEBxMJRnVsbGVydG9u\nMS4wLAYDVQQKEyVDYWxpZm9ybmlhIFN0YXRlIFVuaXZlcnNpdHkgRnVsbGVydG9u\nMR8wHQYDVQQLExZJbmZvcm1hdGlvbiBUZWNobm9sb2d5MSEwHwYDVQQDExhzaGli\nYm9sZXRoLmZ1bGxlcnRvbi5lZHUwHhcNMTEwNTA1MjI0OTE3WhcNMzEwNTA1MjI0\nOTE3WjCBqjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCkNhbGlmb3JuaWExEjAQBgNV\nBAcTCUZ1bGxlcnRvbjEuMCwGA1UEChMlQ2FsaWZvcm5pYSBTdGF0ZSBVbml2ZXJz\naXR5IEZ1bGxlcnRvbjEfMB0GA1UECxMWSW5mb3JtYXRpb24gVGVjaG5vbG9neTEh\nMB8GA1UEAxMYc2hpYmJvbGV0aC5mdWxsZXJ0b24uZWR1MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAvHq9C03zghSdwmcxhBuvfsE+75ZZHQMUMXhzpSiV\n8/xOmcbYuqqLZfx4fnwKtAebj1qsrG8my4cHI99+phQaDZsrsBjfsd/eiYjol6iy\nKkwQlrTni3KuXH7akeKA5xNEcu/sUbT30a1nwG0aB1PgyHievHEkgvnA0FPXCefb\nUuEpGhCVF6O9oHdHVw19sKWuwBYU/vXC2WqVtsTANyIQO/AkMBkGmlDRrYHanRBB\nP2XtovZ2IqL1wXH8UofvNtgrWqcD8VV7zzPww7yKxLUDc4HTMQL98sulmeDwyL8M\nd55uMgYoFTwiQy9HIaGNdWpIYp6mBcdB9gvRpxXlCuNfnwIDAQABo4IBEzCCAQ8w\nHQYDVR0OBBYEFK3UuxZpYqB/HCc+iN5At67mWuKgMIHfBgNVHSMEgdcwgdSAFK3U\nuxZpYqB/HCc+iN5At67mWuKgoYGwpIGtMIGqMQswCQYDVQQGEwJVUzETMBEGA1UE\nCBMKQ2FsaWZvcm5pYTESMBAGA1UEBxMJRnVsbGVydG9uMS4wLAYDVQQKEyVDYWxp\nZm9ybmlhIFN0YXRlIFVuaXZlcnNpdHkgRnVsbGVydG9uMR8wHQYDVQQLExZJbmZv\ncm1hdGlvbiBUZWNobm9sb2d5MSEwHwYDVQQDExhzaGliYm9sZXRoLmZ1bGxlcnRv\nbi5lZHWCCQCib0/YhC2tozAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IB\nAQB2mWlr3Gf0uCYnn6OIc8W9ciHYwYKH2SW+RlkLJ7TaP+KDHn53/bIe1Wpxx3i0\n69ExK8IjgkKr2QBjxJ8ovM4BS3qmFU90ktscyE7Gyv46KqnZ1mN2LTKview+Vwup\nR8QDOdsOKEbGAe5VpfIADW8Ld+Lf8H3EyUACMmS39QrlLOsliv+caAAMfzMYaLZv\n971G1LFkSC7x3MiRcTWILPysYyXNyzY5inrd6tq1/mKvPJznDrIuB5/GeuHVWDXF\nXWs1h62037Zvh7EB/R1xe50WroBer+UaY/wYHGI/3fvNGL+kqLPTr4/AlvQqxvy3\nGc2F/ykKIjW0nT9SvOyCxjGw"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fullerton.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.fullerton.edu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.fullerton.edu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.fullerton.edu:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.fullerton.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.fullerton.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.fullerton.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.fullerton.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fullerton.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "California State University, Fullerton"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE7jCCA9agAwIBAgIJAKJvT9iELa2jMA0GCSqGSIb3DQEBBQUAMIGqMQswCQYD\nVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTESMBAGA1UEBxMJRnVsbGVydG9u\nMS4wLAYDVQQKEyVDYWxpZm9ybmlhIFN0YXRlIFVuaXZlcnNpdHkgRnVsbGVydG9u\nMR8wHQYDVQQLExZJbmZvcm1hdGlvbiBUZWNobm9sb2d5MSEwHwYDVQQDExhzaGli\nYm9sZXRoLmZ1bGxlcnRvbi5lZHUwHhcNMTEwNTA1MjI0OTE3WhcNMzEwNTA1MjI0\nOTE3WjCBqjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCkNhbGlmb3JuaWExEjAQBgNV\nBAcTCUZ1bGxlcnRvbjEuMCwGA1UEChMlQ2FsaWZvcm5pYSBTdGF0ZSBVbml2ZXJz\naXR5IEZ1bGxlcnRvbjEfMB0GA1UECxMWSW5mb3JtYXRpb24gVGVjaG5vbG9neTEh\nMB8GA1UEAxMYc2hpYmJvbGV0aC5mdWxsZXJ0b24uZWR1MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAvHq9C03zghSdwmcxhBuvfsE+75ZZHQMUMXhzpSiV\n8/xOmcbYuqqLZfx4fnwKtAebj1qsrG8my4cHI99+phQaDZsrsBjfsd/eiYjol6iy\nKkwQlrTni3KuXH7akeKA5xNEcu/sUbT30a1nwG0aB1PgyHievHEkgvnA0FPXCefb\nUuEpGhCVF6O9oHdHVw19sKWuwBYU/vXC2WqVtsTANyIQO/AkMBkGmlDRrYHanRBB\nP2XtovZ2IqL1wXH8UofvNtgrWqcD8VV7zzPww7yKxLUDc4HTMQL98sulmeDwyL8M\nd55uMgYoFTwiQy9HIaGNdWpIYp6mBcdB9gvRpxXlCuNfnwIDAQABo4IBEzCCAQ8w\nHQYDVR0OBBYEFK3UuxZpYqB/HCc+iN5At67mWuKgMIHfBgNVHSMEgdcwgdSAFK3U\nuxZpYqB/HCc+iN5At67mWuKgoYGwpIGtMIGqMQswCQYDVQQGEwJVUzETMBEGA1UE\nCBMKQ2FsaWZvcm5pYTESMBAGA1UEBxMJRnVsbGVydG9uMS4wLAYDVQQKEyVDYWxp\nZm9ybmlhIFN0YXRlIFVuaXZlcnNpdHkgRnVsbGVydG9uMR8wHQYDVQQLExZJbmZv\ncm1hdGlvbiBUZWNobm9sb2d5MSEwHwYDVQQDExhzaGliYm9sZXRoLmZ1bGxlcnRv\nbi5lZHWCCQCib0/YhC2tozAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IB\nAQB2mWlr3Gf0uCYnn6OIc8W9ciHYwYKH2SW+RlkLJ7TaP+KDHn53/bIe1Wpxx3i0\n69ExK8IjgkKr2QBjxJ8ovM4BS3qmFU90ktscyE7Gyv46KqnZ1mN2LTKview+Vwup\nR8QDOdsOKEbGAe5VpfIADW8Ld+Lf8H3EyUACMmS39QrlLOsliv+caAAMfzMYaLZv\n971G1LFkSC7x3MiRcTWILPysYyXNyzY5inrd6tq1/mKvPJznDrIuB5/GeuHVWDXF\nXWs1h62037Zvh7EB/R1xe50WroBer+UaY/wYHGI/3fvNGL+kqLPTr4/AlvQqxvy3\nGc2F/ykKIjW0nT9SvOyCxjGw"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://shibboleth.fullerton.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California State University, Fullerton"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fullerton.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California State University, Fullerton"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://attribute-viewer.aai.switch.ch/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41 44 268 15 05"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@switch.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SWITCHaai"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41 44 268 15 05"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai@switch.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SWITCHaai"
          }
        }
      ],
      "entity_id": "https://attribute-viewer.aai.switch.ch/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2015-11-20T07:40:54Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "friendly_name": "swissEduPersonHomeOrganization",
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "switch.ch"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:2.16.756.1.2.5.1.1.4",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "friendly_name": "swissEduPersonHomeOrganizationType",
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "others"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:2.16.756.1.2.5.1.1.5",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SWITCH"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SWITCH"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SWITCH"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SWITCH"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.switch.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.switch.ch/"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.switch.ch/"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.switch.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "switch.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://attribute-viewer.aai.switch.ch/?lang=it"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://attribute-viewer.aai.switch.ch/"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://attribute-viewer.aai.switch.ch/?lang=fr"
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://attribute-viewer.aai.switch.ch/?lang=de"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "AAI Attributes Viewer"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "AAI Attributes Viewer"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "AAI Attributes Viewer"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "AAI Attributes Viewer"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Zeigt zu Test und Informationszwecken alle Attribute eines Benutzers."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Displays all available attributes of a user for debugging and informational purposes."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Pr\u00e9sente tous les attributs d'un utilisateur pour tester et pour obtenir des renseignements."
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ha tutti gli attributi di un utente per testare e per ottenere informazioni."
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://attribute-viewer.aai.switch.ch/privacy_statement.php"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://attribute-viewer.aai.switch.ch/privacy_statement.php?lang=it"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://attribute-viewer.aai.switch.ch/privacy_statement.php?lang=fr"
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://attribute-viewer.aai.switch.ch/privacy_statement.php?lang=de"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIJAKGvh4Rjh+jgMA0GCSqGSIb3DQEBBQUAMCkxJzAlBgNV\nBAMTHmF0dHJpYnV0ZS12aWV3ZXIuYWFpLnN3aXRjaC5jaDAeFw0xNDA1MTQxNDQ1\nMzhaFw0xNzA1MTMxNDQ1MzhaMCkxJzAlBgNVBAMTHmF0dHJpYnV0ZS12aWV3ZXIu\nYWFpLnN3aXRjaC5jaDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAK7w\nbFh51f8XC/y1CJiXg32dC1TojB6F7RHxRuxpPuNh/zp9/7kWStnddGaaOtw9e2fU\nQ/BOe+ztIT5njJ34lKJqfY4mFj3SbuKjDEBk24o/M15IWTLR+0qx5l0uc/U/CSqu\n2wqS6H6u0BMfuRVGFM8NWXJ55SeKBLXbKJVyboweP2pO5AyRBXZHsM8ZEue9hKbn\nqTrXCMS//OfzLarQ7baYtHr+nRbcihJWa2xa+5swiOuf5vEG6sKJT7NbtVbI5b1v\ntzPiCH36ACSHaKkDMsPGCeu5ectunqxQWbufLijzvurKf7EHilIhNvfT+63CIfCp\nt5ViglqeiMJ1tDqham8CAwEAAaN/MH0wXAYDVR0RBFUwU4IeYXR0cmlidXRlLXZp\nZXdlci5hYWkuc3dpdGNoLmNohjFodHRwczovL2F0dHJpYnV0ZS12aWV3ZXIuYWFp\nLnN3aXRjaC5jaC9zaGliYm9sZXRoMB0GA1UdDgQWBBSDmwCkWamUzbmbv6h8wpic\n9PoE7jANBgkqhkiG9w0BAQUFAAOCAQEAms0jw2xzz2dsT+y1sG6Omc9idxl2ffzf\nKm6t4tEACaDFWxGhP1xGZ9omE+UyuiftW8Tj/8+c4bVUTd/UhhiIdkmhld5M7awF\n8xtzM979p+uL5abezo5D/8O4IYFWpHZdQ+VSl/Wr9tc9N6dmB5c0xzUm4/YzCaNz\nanih2XoBQzYD8ZpxYWopH/Uwt6KiUf9TV92rR2EkmZloH3HyfxdmaOIxQU1boi8e\nGCyqkxNBftgYk65n7Yn5UVBeUr7IBTmzXLFmluhpNYmcslYf/ClArFLNGhHpI5F0\nUDgBXcQzpXHOg7ks4xbcEPCe0gaQhOKyWjMDALDCmiA7f7/Rnam3CA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://attribute-viewer.aai.switch.ch/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://attribute-viewer.aai.switch.ch/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://attribute-viewer.aai.switch.ch/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://attribute-viewer.aai.switch.ch/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://attribute-viewer.aai.switch.ch/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ],
          "error_url": "http://www.switch.ch/aai/support/help",
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "AAI Attributes Viewer"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "AAI Attributes Viewer"
                },
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "AAI Attributes Viewer"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "AAI Attributes Viewer"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Zeigt zu Test und Informationszwecken alle Attribute eines Benutzers."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Displays all available attributes of a user for debugging and informational purposes."
                },
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Pr\u00e9sente tous les attributs d'un utilisateur pour tester et pour obtenir des renseignements."
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Ha tutti gli attributi di un utente per testare e per ottenere informazioni."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "commonName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonUniqueId",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.13",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganizationType",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAssurance",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.11",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "telephoneNumber",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.20",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "postalAddress",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.16",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "employeeNumber",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "homePostalAddress",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.39",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mobile",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.41",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonNickname",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.2",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonOrgDN",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonOrgUnitDN",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "preferredLanguage",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.39",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrimaryOrgUnitDN",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.8",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "homePhone",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.20",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "uid",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "isMemberOf",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.5.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "ou",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.11",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrimaryAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.5",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-demo-02.its.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-demo-02.its.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-02.its.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-02.its.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-02.its.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-02.its.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-02.its.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-demo-02.its.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-demo-02.its.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;demo-02"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;demo-02"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-demo-02.its.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-demo-02.its.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSTCCAjGgAwIBAgIJAMVbo/yQV7JWMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\nBAMTGWxhZG9rMy1kZW1vLTAyLml0cy51bXUuc2UwHhcNMTQxMDEwMDkzNTI0WhcN\nMjQxMDA3MDkzNTI0WjAkMSIwIAYDVQQDExlsYWRvazMtZGVtby0wMi5pdHMudW11\nLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA4Nuc1eTRGUFZON4w\nX3uokaEyJUcjGB82f9XWIUcraOVREAhLUQm/FPkOQQO2+WslwAe0otbqMTLFVKL0\nXdI+O0rqp2sgX3YdIepLUz03Lh/jbWFqm3ZWnIrNozaTNdedVlqMaQZHNDq8aHYx\nd6AgV+js4lIjbZUY3NHHISwE6ghxMtfg/0Ok6U0/KN6YbUpALV0hoGTYVIep2Y4/\nQPL8oPYLf2n4x2yLh9+c0GQ/OIPzcrZv0q5Ik18UkVQs7Ki4DOtjkPRm3/tthnQk\nnnwla9UMnDeceYECTj6qMSflhaVWpVLbGOS3Jp4fQOEo7DPwERjEOq4Uf6RgIySn\npcMNCQIDAQABo34wfDBbBgNVHREEVDBSghlsYWRvazMtZGVtby0wMi5pdHMudW11\nLnNlhjVodHRwczovL2xhZG9rMy1kZW1vLTAyLml0cy51bXUuc2Uvc3R1ZGVudC1m\ncm9udGVuZC1zcDAdBgNVHQ4EFgQUbOXVTx2U4lRY/yJvTr77t5M06I4wDQYJKoZI\nhvcNAQEFBQADggEBAKycVqpsgiW3IwW4DvBieorz3sa3qsgVckznLuUbZIXXpEHu\nJhFXdDYxxQwFfJThbTf57g6FxkLi2RYi5Cd3ZSZlK0/oGEnJ6yFcJ0Ip8TcJEEuL\nA9io/dCrUcOt7PBv4tlx32u0pdpPaNpQPYni4viv4FRJJnyM9ftsm2j8Bdj5GgUL\nnEutH0uEcWAlsF0OwRz2eRMJwe0Y2fnFnu7uGEOlXrpwGChin8UiuXt3cRLUJjR+\n/B8xPec4+f1VkwfZpnonDIv7B8ukpCIwv92sdYhFdrcMiA8ubD+nicffPhE7KDSE\nsfAksU5zX5TLN6UmXQeW0u0pLpk4YCOXJJ5mX6E="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-demo-02.its.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-02.its.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-02.its.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-02.its.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-02.its.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-02.its.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-02.its.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-demo-02.its.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-demo-02.its.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-demo-02.its.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://memso.tannerritchie.com/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tanner"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:roland@tannerritchie.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roland"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tanner"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:roland@tannerritchie.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roland"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://memso.tannerritchie.com/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "TannerRitchie Publishing: Medieval and Early Modern Sources Online"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tannerritchie.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "TannerRitchie Publishing"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://tannerritchie.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://tannerritchie.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://tannerritchie.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://tannerritchie.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://tannerritchie.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://tannerritchie.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Medieval and Early Modern Sources Online (MEMSO) is an essential resource for the study of Britain and its place in the world during the medieval and early modern period (c. 1100-1800)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://tannerritchie.com/img/logo-blackonwhite-master.png",
                    "height": "116",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "491"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "TannerRitchie Publishing"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKTCCAhGgAwIBAgIJAJuTjrsyhFeQMA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\n\t\t\t\t\t\tBAMTEXRhbm5lcnJpdGNoaWUuY29tMB4XDTExMDcyMjE4NDMxOFoXDTIxMDcxOTE4\n\t\t\t\t\t\tNDMxOFowHDEaMBgGA1UEAxMRdGFubmVycml0Y2hpZS5jb20wggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQCyqSLwWCSrAJFK+BTDF52BRSvMaAXNFn5KWtXc\n\t\t\t\t\t\tpfeV3Zma0MI54MUqc0SPirRK/fmIsQkSPk7HVaXFYZ6nkvBL8Ke3rHBA3ViMlGsJ\n\t\t\t\t\t\tUMLs8qhlSfQn9d+J3DJVRqdV9RRZY9G0iKoBi0lM32kuX9cGVq71EJdjm2Nwfz3Z\n\t\t\t\t\t\t5UyDoVfVMqVPnlESlY/bomcDjqwyz15z7cIRCbmZPqHyPqdsFRiKWUuVa+uwvxoB\n\t\t\t\t\t\tCpwKxbfviJaYu9j0oQGzwSHse+fEOTCwV96Kr28PSqisolHhVaIxHjfCj3fAZQHm\n\t\t\t\t\t\tEX8klaku9AnNItvTY5BJsdt3+DIFf6N9XIpSUuNeso+e497LAgMBAAGjbjBsMEsG\n\t\t\t\t\t\tA1UdEQREMEKCEXRhbm5lcnJpdGNoaWUuY29thi1odHRwczovL21lbXNvLnRhbm5l\n\t\t\t\t\t\tcnJpdGNoaWUuY29tL3NoaWJib2xldGgtc3AwHQYDVR0OBBYEFLbIWzGGpN1GGb1c\n\t\t\t\t\t\tG8hXwXpvUiF/MA0GCSqGSIb3DQEBBQUAA4IBAQAeB5k8DkVkBHTP2LD2M8A3K5SC\n\t\t\t\t\t\tOe8jL3An51jBa+r9B7UGVNiC20DOYOVAsauMHYMP+lqaOKHIhSEBlQXHx61fWQQ5\n\t\t\t\t\t\tmhN+0GUVbfKmqiOQmSLYeyzMiT5sb6JqSVVcAErBcN3nKxIhWMi9NJd+UntPLRYt\n\t\t\t\t\t\tlbpIp+I1zWkV9kzElE1CzAq9pOuQQlL+7f4nbYYwppTyXQ5Gl6hW24oje4WtiHl/\n\t\t\t\t\t\tmXSnza8yA2NPDhefbmxqxbVeU+1Qu1PyHQaUX/mdzAXVOXgaM0F72BimTAXQ4Zxr\n\t\t\t\t\t\t/1WxEAHX32o1DtTZC+Pspbm0oN2KG0dyUSoFR2R8XYShQowVVtr7glWJTcdo"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKTCCAhGgAwIBAgIJAJuTjrsyhFeQMA0GCSqGSIb3DQEBBQUAMBwxGjAYBgNV\n\t\t\t\t\t\tBAMTEXRhbm5lcnJpdGNoaWUuY29tMB4XDTExMDcyMjE4NDMxOFoXDTIxMDcxOTE4\n\t\t\t\t\t\tNDMxOFowHDEaMBgGA1UEAxMRdGFubmVycml0Y2hpZS5jb20wggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQCyqSLwWCSrAJFK+BTDF52BRSvMaAXNFn5KWtXc\n\t\t\t\t\t\tpfeV3Zma0MI54MUqc0SPirRK/fmIsQkSPk7HVaXFYZ6nkvBL8Ke3rHBA3ViMlGsJ\n\t\t\t\t\t\tUMLs8qhlSfQn9d+J3DJVRqdV9RRZY9G0iKoBi0lM32kuX9cGVq71EJdjm2Nwfz3Z\n\t\t\t\t\t\t5UyDoVfVMqVPnlESlY/bomcDjqwyz15z7cIRCbmZPqHyPqdsFRiKWUuVa+uwvxoB\n\t\t\t\t\t\tCpwKxbfviJaYu9j0oQGzwSHse+fEOTCwV96Kr28PSqisolHhVaIxHjfCj3fAZQHm\n\t\t\t\t\t\tEX8klaku9AnNItvTY5BJsdt3+DIFf6N9XIpSUuNeso+e497LAgMBAAGjbjBsMEsG\n\t\t\t\t\t\tA1UdEQREMEKCEXRhbm5lcnJpdGNoaWUuY29thi1odHRwczovL21lbXNvLnRhbm5l\n\t\t\t\t\t\tcnJpdGNoaWUuY29tL3NoaWJib2xldGgtc3AwHQYDVR0OBBYEFLbIWzGGpN1GGb1c\n\t\t\t\t\t\tG8hXwXpvUiF/MA0GCSqGSIb3DQEBBQUAA4IBAQAeB5k8DkVkBHTP2LD2M8A3K5SC\n\t\t\t\t\t\tOe8jL3An51jBa+r9B7UGVNiC20DOYOVAsauMHYMP+lqaOKHIhSEBlQXHx61fWQQ5\n\t\t\t\t\t\tmhN+0GUVbfKmqiOQmSLYeyzMiT5sb6JqSVVcAErBcN3nKxIhWMi9NJd+UntPLRYt\n\t\t\t\t\t\tlbpIp+I1zWkV9kzElE1CzAq9pOuQQlL+7f4nbYYwppTyXQ5Gl6hW24oje4WtiHl/\n\t\t\t\t\t\tmXSnza8yA2NPDhefbmxqxbVeU+1Qu1PyHQaUX/mdzAXVOXgaM0F72BimTAXQ4Zxr\n\t\t\t\t\t\t/1WxEAHX32o1DtTZC+Pspbm0oN2KG0dyUSoFR2R8XYShQowVVtr7glWJTcdo"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://tannerritchie.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://tannerritchie.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://tannerritchie.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://tannerritchie.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://tannerritchie.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://tannerritchie.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://tannerritchie.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://tannerritchie.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://tannerritchie.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://tannerritchie.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.osfc.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Clarke"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:JCA@osfc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Clarke"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:JCA@osfc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.osfc.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-05-18T17:10:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEaDCCA1CgAwIBAgIJAO0V7MENsS9VMA0GCSqGSIb3DQEBBQUAMIG0MQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEbMBkGA1UECBMSR3JlYXRlciBNYW5jaGVzdGVyMQ8wDQYDVQQHEwZP\n\t\t\t\t\t\tbGRoYW0xIjAgBgNVBAoTGU9sZGhhbSBTaXh0aCBGb3JtIENvbGxlZ2UxFDASBgNV\n\t\t\t\t\t\tBAsTC0lUIFNlcnZpY2VzMRcwFQYDVQQDEw5pZHAub3NmYy5hYy51azEkMCIGCSqG\n\t\t\t\t\t\tSIb3DQEJARYVcG9zdG1hc3RlckBvc2ZjLmFjLnVrMB4XDTEzMDUwNzEwNTkyM1oX\n\t\t\t\t\t\tDTMzMDUwMjEwNTkyM1owgbQxCzAJBgNVBAYTAkdCMRswGQYDVQQIExJHcmVhdGVy\n\t\t\t\t\t\tIE1hbmNoZXN0ZXIxDzANBgNVBAcTBk9sZGhhbTEiMCAGA1UEChMZT2xkaGFtIFNp\n\t\t\t\t\t\teHRoIEZvcm0gQ29sbGVnZTEUMBIGA1UECxMLSVQgU2VydmljZXMxFzAVBgNVBAMT\n\t\t\t\t\t\tDmlkcC5vc2ZjLmFjLnVrMSQwIgYJKoZIhvcNAQkBFhVwb3N0bWFzdGVyQG9zZmMu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDHw1xtdxKY8QAa\n\t\t\t\t\t\ttUJWNuHBz8iqOByRx/I3fmSQxvRKaoB6c0UYoPikbq1WDKfjivk+PjJ4p1md8WWp\n\t\t\t\t\t\t1TGF6xyd3zSe36LWJHI1D6SNMmk8z88FDbZrAG2O5H8KzRC1xQpin8k3WXHLzIvy\n\t\t\t\t\t\tqpsiiCOWphTAAXTsPzNS3BOfAeghvApzWrM2vXLxlxHsSKZS5J6wP4rIuK2P1X51\n\t\t\t\t\t\tokIJv8p7AUXQdv3Lyoyba7b0CuuEwEplmXEIv2cB2++eb1Eu7IUnOq0OIjMdAQo1\n\t\t\t\t\t\tYwXAtAwKs8u53FQ++T+ZSe0SM9VbZsUljUVV3QAtGN3yq54ntaBI1d4mC0NT+iPe\n\t\t\t\t\t\tTVOlUHIDAgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5T\n\t\t\t\t\t\tU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBSWogXD4Ld0Dzl6YokJ\n\t\t\t\t\t\tDP1PO/PRWTAfBgNVHSMEGDAWgBSWogXD4Ld0Dzl6YokJDP1PO/PRWTANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAZvquJlijNbVU7OnKoJ/UgpyXh31VfKQAKJ7LP+TWDCCUwgyJ\n\t\t\t\t\t\tklumKlUh7c0JG7D3RRXim7mOxXEvkf4F1njUXWgv8mJmxRPzMkivhEFfnR0MFkjd\n\t\t\t\t\t\tKFNHuarG3a8pAzFV8aeJSmIVfr7VwGO+pcdQrD7ScLi0ssNi4tf6wz1JaOSz/SUO\n\t\t\t\t\t\t8llqRWB1ZyEQ1+d28Uzi90R2qu7MVn1Y2RdWfsFNwhcuBh44+a62kexUiYQIv7jb\n\t\t\t\t\t\tcJkJdvZUqWpZmHLUwdS/ApQGvWPpZqoB8XHXIvjvncnpnX6wwz2wI9//KbHpEnXP\n\t\t\t\t\t\t7dwWurC7U32FErPq2FW9K41yaFsfpI1kDXtNRw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osfc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.osfc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.osfc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.osfc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.osfc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.osfc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.osfc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.osfc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.osfc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osfc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEaDCCA1CgAwIBAgIJAO0V7MENsS9VMA0GCSqGSIb3DQEBBQUAMIG0MQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEbMBkGA1UECBMSR3JlYXRlciBNYW5jaGVzdGVyMQ8wDQYDVQQHEwZP\n\t\t\t\t\t\tbGRoYW0xIjAgBgNVBAoTGU9sZGhhbSBTaXh0aCBGb3JtIENvbGxlZ2UxFDASBgNV\n\t\t\t\t\t\tBAsTC0lUIFNlcnZpY2VzMRcwFQYDVQQDEw5pZHAub3NmYy5hYy51azEkMCIGCSqG\n\t\t\t\t\t\tSIb3DQEJARYVcG9zdG1hc3RlckBvc2ZjLmFjLnVrMB4XDTEzMDUwNzEwNTkyM1oX\n\t\t\t\t\t\tDTMzMDUwMjEwNTkyM1owgbQxCzAJBgNVBAYTAkdCMRswGQYDVQQIExJHcmVhdGVy\n\t\t\t\t\t\tIE1hbmNoZXN0ZXIxDzANBgNVBAcTBk9sZGhhbTEiMCAGA1UEChMZT2xkaGFtIFNp\n\t\t\t\t\t\teHRoIEZvcm0gQ29sbGVnZTEUMBIGA1UECxMLSVQgU2VydmljZXMxFzAVBgNVBAMT\n\t\t\t\t\t\tDmlkcC5vc2ZjLmFjLnVrMSQwIgYJKoZIhvcNAQkBFhVwb3N0bWFzdGVyQG9zZmMu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDHw1xtdxKY8QAa\n\t\t\t\t\t\ttUJWNuHBz8iqOByRx/I3fmSQxvRKaoB6c0UYoPikbq1WDKfjivk+PjJ4p1md8WWp\n\t\t\t\t\t\t1TGF6xyd3zSe36LWJHI1D6SNMmk8z88FDbZrAG2O5H8KzRC1xQpin8k3WXHLzIvy\n\t\t\t\t\t\tqpsiiCOWphTAAXTsPzNS3BOfAeghvApzWrM2vXLxlxHsSKZS5J6wP4rIuK2P1X51\n\t\t\t\t\t\tokIJv8p7AUXQdv3Lyoyba7b0CuuEwEplmXEIv2cB2++eb1Eu7IUnOq0OIjMdAQo1\n\t\t\t\t\t\tYwXAtAwKs8u53FQ++T+ZSe0SM9VbZsUljUVV3QAtGN3yq54ntaBI1d4mC0NT+iPe\n\t\t\t\t\t\tTVOlUHIDAgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5T\n\t\t\t\t\t\tU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBSWogXD4Ld0Dzl6YokJ\n\t\t\t\t\t\tDP1PO/PRWTAfBgNVHSMEGDAWgBSWogXD4Ld0Dzl6YokJDP1PO/PRWTANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAZvquJlijNbVU7OnKoJ/UgpyXh31VfKQAKJ7LP+TWDCCUwgyJ\n\t\t\t\t\t\tklumKlUh7c0JG7D3RRXim7mOxXEvkf4F1njUXWgv8mJmxRPzMkivhEFfnR0MFkjd\n\t\t\t\t\t\tKFNHuarG3a8pAzFV8aeJSmIVfr7VwGO+pcdQrD7ScLi0ssNi4tf6wz1JaOSz/SUO\n\t\t\t\t\t\t8llqRWB1ZyEQ1+d28Uzi90R2qu7MVn1Y2RdWfsFNwhcuBh44+a62kexUiYQIv7jb\n\t\t\t\t\t\tcJkJdvZUqWpZmHLUwdS/ApQGvWPpZqoB8XHXIvjvncnpnX6wwz2wI9//KbHpEnXP\n\t\t\t\t\t\t7dwWurC7U32FErPq2FW9K41yaFsfpI1kDXtNRw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Oldham Sixth Form College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.osfc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Oldham Sixth Form College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://infra.clarin.dk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Seaton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:seaton@hum.ku.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mitchell"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@clarin.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CLARIN-DK"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administration"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:admin@clarin.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CLARIN-DK"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://infra.clarin.dk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-02-10T20:41:29Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://clarin.eu/category/clarin-member"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://infra.clarin.dk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://infra.clarin.dk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://infra.clarin.dk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://infra.clarin.dk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CLARIN-DK-UCPH"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CLARIN-DK-UCPH"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Dieser Service Provider erm\u00f6glicht den Zugriff auf das CLARIN Zentrum an der Universit\u00e4t Kopenhagen und seine Dienstleistungen f\u00fcr sprachbasierte Materialien und Werkzeuge."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "This Service Provider enables access to the CLARIN center at University of Copenhagen and its services for language-based materials and tools."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrimaryAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.5",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://infra.clarin.dk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://info.clarin.dk/en/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CLARIN-DK-UCPH"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CLARIN-DK-UCPH"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Dieser Service Provider erm\u00f6glicht den Zugriff auf das CLARIN Zentrum an der Universit\u00e4t Kopenhagen und seine Dienstleistungen f\u00fcr sprachbasierte Materialien und Werkzeuge."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This Service Provider enables access to the CLARIN center at University of Copenhagen and its services for language-based materials and tools."
                  }
                ],
                "logo": [
                  {
                    "text": "https://clarin.dk/clarindk/img/clarin-dk.logo.jpg",
                    "height": "53",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "250"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://info.clarin.dk/en/overview/privacypolicy/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "infra.clarin.dk"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMjCCAhqgAwIBAgIJAOTsxgZuTQFoMA0GCSqGSIb3DQEBCwUAMBoxGDAWBgNV\nBAMTD2luZnJhLmNsYXJpbi5kazAeFw0xNTAyMDQxMzUyMjJaFw0yNTAyMDExMzUy\nMjJaMBoxGDAWBgNVBAMTD2luZnJhLmNsYXJpbi5kazCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBALxh1F3m7++sELN0g7ZsIsqtbAWPDu08/Yo3i8kRJmP+\nLZeTOEVjftBH1xhEfwnABXduPG6EABOEJSH9y/rZlUIzvJjrWgXgmP921J2o/jj9\nuofRuk4vVXvoPyq+nGE3icuq+5GLoJ3RlpeUPDapE93PQ+7XfNUqq6q72IMG7+VW\nuZmPW8ZUSnuC1V1ZW2b979tNeqbzm7yTznH7iNHldg45phiOyH3DGqGO3d0cM9B9\nS/lZYXXPI95FiYlYkj8MZtJkXP6ra+mPn+qWWVb0pQ6ShVBzJFwEYy+ycCxBBYGv\nUC1rmDC6ZWsGlQdkNDVu51n2uORd2ZEMp7KnL0iY7m8CAwEAAaN7MHkwHQYDVR0O\nBBYEFMNksJ3UQ+acGvk4anGIX74SyxmrMEoGA1UdIwRDMEGAFMNksJ3UQ+acGvk4\nanGIX74SyxmroR6kHDAaMRgwFgYDVQQDEw9pbmZyYS5jbGFyaW4uZGuCCQDk7MYG\nbk0BaDAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQBz4aKy//uKtBMa\nlJQ23OvirmG7uktfsvRSFlagZgz2CrYlj1mnwhrMBgQP6sY8+8839WPRlXZYfnDt\n/ymxFNT/c3vDgZ+6R6DvJsyaMdpqyO3cF6YVW4Ziy2pd1VPocfT2xLvZkuoyYikY\nUWS6MXXLxx0YNf34tYMAy87THE7+IVOWzjqJKZN7ES6rOsQkWhtG1LVvkLY0e1AT\nHUQ3NG7ubyG1oGFMYqHkJY83aZGgUxsKcS2TsAkY5iz42ZhnHTZUTiu9GXyYdKDj\n8Uh2QptwTDlncmuRJL64djt9iKmLL2dDm1K38WLjQn2NwbWtCD2jLX3CvF3z07qQ\nCnbRCoj2"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=infra.clarin.dk"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://infra.clarin.dk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://infra.clarin.dk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://infra.clarin.dk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://infra.clarin.dk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://infra.clarin.dk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://infra.clarin.dk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://infra.clarin.dk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://infra.clarin.dk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://infra.clarin.dk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://infra.clarin.dk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.msacademicverify.com/shibboleth-sp",
    {
      "entity_id": "https://shibboleth.msacademicverify.com/shibboleth-sp",
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:avesupp@microsoft.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AVE Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hansi.reddy@microsoft.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jhansi Reddy"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:avesupp@microsoft.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AVE Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Microsoft"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.microsoft.com/en/us/default.aspx"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Microsoft"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.msacademicverify.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.msacademicverify.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.msacademicverify.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.msacademicverify.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Microsoft Academic Verification Engine"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDXTCCAkWgAwIBAgIJAIPNJpzdV/nXMA0GCSqGSIb3DQEBBQUAMCoxKDAmBgNV\n\t\t\t\t\t\tBAMTH3NoaWJib2xldGgubXNhY2FkZW1pY3ZlcmlmeS5jb20wHhcNMTMwNzEyMDc0\n\t\t\t\t\t\tODEwWhcNMTYwNzExMDc0ODEwWjAqMSgwJgYDVQQDEx9zaGliYm9sZXRoLm1zYWNh\n\t\t\t\t\t\tZGVtaWN2ZXJpZnkuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\ty8xlr8kDHGHgLvfGzdFlV4gWov5IpGy9dtMWjkf5xE5817sGXhBNIt1ejQN6Nj3w\n\t\t\t\t\t\ty3ZwPWaDJ/tOXDhncPJ2+ur2L6a4IuNlTg0FcqEwc/VnofaRC5iyihtSGuttheQY\n\t\t\t\t\t\t6T+ptcdvbLDp4Wsq5hpQJrL3W6f4KfFkDr+3iqzLMFbw1IbhGSmpuS6xfHE7nTdR\n\t\t\t\t\t\tNheBF1pZgeUsNvgacwrKpZN4pdU9kmaEy3Iti59uOwGACOydxE6LHKCYcjVVjOmb\n\t\t\t\t\t\tZ65jPB+P3mnW0gdcz4U26jlThTJ+4E6DbLbeBZ2tGGWNZ9xvSrJzTqrh6wJbpXbg\n\t\t\t\t\t\tZ0F+FUfPtfT1uHBezSolZQIDAQABo4GFMIGCMGEGA1UdEQRaMFiCH3NoaWJib2xl\n\t\t\t\t\t\tdGgubXNhY2FkZW1pY3ZlcmlmeS5jb22GNWh0dHBzOi8vc2hpYmJvbGV0aC5tc2Fj\n\t\t\t\t\t\tYWRlbWljdmVyaWZ5LmNvbS9zaGliYm9sZXRoLXNwMB0GA1UdDgQWBBSl6x2NAW3h\n\t\t\t\t\t\toeUBLh7lSL+yIFmolTANBgkqhkiG9w0BAQUFAAOCAQEAGimMyBN15TiohXYEeg+7\n\t\t\t\t\t\tKy0ggztUQVHcvlZZL+E4bo048H2hZYD2mYwtbYfa9GQdWv+H2qy0Q9rjkWupdz6J\n\t\t\t\t\t\taudemQiHo2otVR/QQLRaj8KJAieheIMfnH9UB4ZJBGPhVlO9eMuU5fpwKtPZMahY\n\t\t\t\t\t\tZ2eUEvuRzidSTbSHWxeQ0lwbeFjEsO+vPTsWG+khGESA9fb/WhndZk+Qvn8Gdlfb\n\t\t\t\t\t\tI36H8KRs3YIJ7eKIg6CS6g1/n1MP65pAvitTtY/yf7Oy5BGDBVJ0c8vhaDx0NMdm\n\t\t\t\t\t\toqv/H3FB0kYoLtSxthUd1GcV2kgO0brHNSobuzYi4yePTH9rkY8Kn/ZF5pDVu4SK\n\t\t\t\t\t\t/Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.msacademicverify.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.msacademicverify.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.msacademicverify.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth.msacademicverify.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.msacademicverify.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.msacademicverify.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Microsoft Academic Verification Engine"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.lboro.ac.uk/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it.services@lboro.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Loughborough University IT Services"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it.services@lboro.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Loughborough University IT Services"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.lboro.ac.uk/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-03-10T17:31:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.lboro.ac.uk/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.lboro.ac.uk/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lboro.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID8zCCAtugAwIBAgIJAJC1ySyy8NnHMA0GCSqGSIb3DQEBBQUAMIGPMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEXMBUGA1UECAwOTGVpY2VzdGVyc2hpcmUxFTATBgNVBAcMDExvdWdo\n\t\t\t\t\t\tYm9yb3VnaDEgMB4GA1UECgwXTG91Z2hib3JvdWdoIFVuaXZlcnNpdHkxFDASBgNV\n\t\t\t\t\t\tBAsMC0lUIFNlcnZpY2VzMRgwFgYDVQQDDA9pZHAubGJvcm8uYWMudWswHhcNMTQw\n\t\t\t\t\t\tNjI2MTQ0NTMzWhcNMzQwNjI2MTQ0NTMzWjCBjzELMAkGA1UEBhMCR0IxFzAVBgNV\n\t\t\t\t\t\tBAgMDkxlaWNlc3RlcnNoaXJlMRUwEwYDVQQHDAxMb3VnaGJvcm91Z2gxIDAeBgNV\n\t\t\t\t\t\tBAoMF0xvdWdoYm9yb3VnaCBVbml2ZXJzaXR5MRQwEgYDVQQLDAtJVCBTZXJ2aWNl\n\t\t\t\t\t\tczEYMBYGA1UEAwwPaWRwLmxib3JvLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEA3bzqGATB5A3Ve1tYdKK33TzyiojOKh32KKxQSsULl4HAY+tW\n\t\t\t\t\t\tK6ecQB56Meq7vxkQ0eIau/uyfk7Q87qhH4gX/tTpfsbvrPaaB/X0/AU0uNnaCVK0\n\t\t\t\t\t\tVh7AZYzZF+nTgzFxCq+aOiVPCR7f5LLBY3BFj6QdBzKalAShozuwHiLtnL3nYpVt\n\t\t\t\t\t\tyEwEbbBS1BuKmsGSKAncrMiWKdmzMTMyCZtu0u1dmtpnwbfppFoPlj/zM8KDjBdr\n\t\t\t\t\t\tAehg5Rflrj8lifnkJSEpIHT+BTlx6zyvbCPSWdk9VTzXpPM3JlQwIs0dlJzPMh6w\n\t\t\t\t\t\tCAw66N393Awd9ilkpoGrkdG/hFzPD2D/0RNX7wIDAQABo1AwTjAdBgNVHQ4EFgQU\n\t\t\t\t\t\t18Vf/8a7klrMfl3UMChCt8tzOG8wHwYDVR0jBBgwFoAU18Vf/8a7klrMfl3UMChC\n\t\t\t\t\t\tt8tzOG8wDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAtlrSXUAKW4tV\n\t\t\t\t\t\t0I7JkmVUvKhrlFlZJMqR8WNwxG5l6+5BFvXLb0DoGH1YdynAWn9MtdvWTm/hGOZ5\n\t\t\t\t\t\tVr/FYBbHHjZN4HK6DMceZSq9YAMdEUtpIPMd1sGdplVKofHqYUEbKL+VJnBYSYnr\n\t\t\t\t\t\tJ1VQhScUX0PjM5rAwlXxdh2kBNlyeC1ZsjNvLPH95T+Ev8i6BFVrSbe09I40mBiQ\n\t\t\t\t\t\tJThq5JpngMmPGZg5r/H3PnAJdN5OwUyLPLj4D/raVOAk7tiySTPWzWRyPxzbRXr0\n\t\t\t\t\t\ttDPQasPZEABCL4E0cEK4YHwrffT/nd3I0KQ2wS/C17z3798QYPQJ9f6KHty2X5mf\n\t\t\t\t\t\tPmG2OinSJg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Loughborough University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lboro.ac.uk/it/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Loughborough University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib2idp.ntu.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cross"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:richard.cross@ntu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hallam"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ITSShibbolethTechnical@ntu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lee"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib2idp.ntu.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFETCCA/mgAwIBAgIUf6ORiSVI2C32bVc/pw0qlk211l4wDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwTTELMAkGA1UEBhMCQk0xGTAXBgNVBAoTEFF1b1ZhZGlzIExpbWl0ZWQxIzAh\n\t\t\t\t\t\tBgNVBAMTGlF1b1ZhZGlzIEdsb2JhbCBTU0wgSUNBIEcyMB4XDTE1MTEwMzEyMDQy\n\t\t\t\t\t\tM1oXDTE4MTEwMzEyMDQxOVowgZ0xCzAJBgNVBAYTAkdCMRgwFgYDVQQIEw9Ob3R0\n\t\t\t\t\t\taW5naGFtc2hpcmUxEzARBgNVBAcTCk5PVFRJTkdIQU0xJDAiBgNVBAoTG05vdHRp\n\t\t\t\t\t\tbmdoYW0gVHJlbnQgVW5pdmVyc2l0eTEcMBoGA1UECxMTSW5mb3JtYXRpb24gU3lz\n\t\t\t\t\t\tdGVtczEbMBkGA1UEAxMSc2hpYjJpZHAubnR1LmFjLnVrMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtn3OZnkj82U1qep4KBD8tMy2A84GtKZj14us/mCz\n\t\t\t\t\t\tU4JBMQWoBUhihZfhLNErE4EQllz5wUAEDfYYwnclcngY2X6nzgqTJuGmrQLZfukF\n\t\t\t\t\t\tRPzBfdrQnJGTg/3/dIvCGJ+KfqIt5fGEAwYVpMJaDg6LjBcZSgjmppOocEKVQJyd\n\t\t\t\t\t\tZWEZtKp5+PLDIfQ4btrxw1mCOo/ngEGB8owPeFXstxIweC+9XNhJp4c8L2iZEsfy\n\t\t\t\t\t\trNSE+0KFb7DI2sdEbFyaDixLSFlX5CY7fhUStPUzMOnhXnl2UR9hdgH8x60zu0iU\n\t\t\t\t\t\tAIXLx0cs81W+VtX2xgsg42oB/dw/6rfFWT37EmXuJi+cQQIDAQABo4IBljCCAZIw\n\t\t\t\t\t\tcwYIKwYBBQUHAQEEZzBlMCoGCCsGAQUFBzABhh5odHRwOi8vb2NzcC5xdW92YWRp\n\t\t\t\t\t\tc2dsb2JhbC5jb20wNwYIKwYBBQUHMAKGK2h0dHA6Ly90cnVzdC5xdW92YWRpc2ds\n\t\t\t\t\t\tb2JhbC5jb20vcXZzc2xnMi5jcnQwHQYDVR0RBBYwFIISc2hpYjJpZHAubnR1LmFj\n\t\t\t\t\t\tLnVrMFEGA1UdIARKMEgwRgYMKwYBBAG+WAACZAEBMDYwNAYIKwYBBQUHAgEWKGh0\n\t\t\t\t\t\tdHA6Ly93d3cucXVvdmFkaXNnbG9iYWwuY29tL3JlcG9zaXRvcnkwDgYDVR0PAQH/\n\t\t\t\t\t\tBAQDAgWgMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAfBgNVHSMEGDAW\n\t\t\t\t\t\tgBSRGWKtWxenMPvw3jklsb2MubhRJzA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8v\n\t\t\t\t\t\tY3JsLnF1b3ZhZGlzZ2xvYmFsLmNvbS9xdnNzbGcyLmNybDAdBgNVHQ4EFgQUdOYX\n\t\t\t\t\t\tCiIw/0+Pmuy3G+dj7ShaC0kwDQYJKoZIhvcNAQELBQADggEBAEG6I9qcqCWJzXDe\n\t\t\t\t\t\tYzumSW1UKABfa3lSs8F+7G5cWHPq39C5Eas8+ZUpDytTug6pg2CLn9qWIjW2hstY\n\t\t\t\t\t\tBuPkFULUL1nmJP8iLiY5YtdfFG9GS7gHAPy9urAAR7i6UMSlqJgfyIHlY6kPxv4+\n\t\t\t\t\t\tIUHPQC0LVUFzQhHrFkjdBj5IcH1KIT0/b7T8IwovtRDGCyBoXeUr5y7uZjzmVGF4\n\t\t\t\t\t\tUq+fiME+67uMhY9TV9ERdn+NiYkxScu/2WSve5ZrsfrwxQTe9FhgYnMDv2JNGSUk\n\t\t\t\t\t\tJxl/t3PafEIUbWMpcSWZinaLGZ/2nZ9cRH3fgu45o1co8CjjrDHTGSrWdjhKrmgM\n\t\t\t\t\t\tfjw7AVA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ntu.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib2idp.ntu.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib2idp.ntu.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib2idp.ntu.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib2idp.ntu.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib2idp.ntu.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib2idp.ntu.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib2idp.ntu.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib2idp.ntu.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ntu.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://shib2idp.ntu.ac.uk/cas/themes/ntu/ntushib-v2.PNG",
                    "height": "33",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "38"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Nottingham Trent University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFETCCA/mgAwIBAgIUf6ORiSVI2C32bVc/pw0qlk211l4wDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwTTELMAkGA1UEBhMCQk0xGTAXBgNVBAoTEFF1b1ZhZGlzIExpbWl0ZWQxIzAh\n\t\t\t\t\t\tBgNVBAMTGlF1b1ZhZGlzIEdsb2JhbCBTU0wgSUNBIEcyMB4XDTE1MTEwMzEyMDQy\n\t\t\t\t\t\tM1oXDTE4MTEwMzEyMDQxOVowgZ0xCzAJBgNVBAYTAkdCMRgwFgYDVQQIEw9Ob3R0\n\t\t\t\t\t\taW5naGFtc2hpcmUxEzARBgNVBAcTCk5PVFRJTkdIQU0xJDAiBgNVBAoTG05vdHRp\n\t\t\t\t\t\tbmdoYW0gVHJlbnQgVW5pdmVyc2l0eTEcMBoGA1UECxMTSW5mb3JtYXRpb24gU3lz\n\t\t\t\t\t\tdGVtczEbMBkGA1UEAxMSc2hpYjJpZHAubnR1LmFjLnVrMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtn3OZnkj82U1qep4KBD8tMy2A84GtKZj14us/mCz\n\t\t\t\t\t\tU4JBMQWoBUhihZfhLNErE4EQllz5wUAEDfYYwnclcngY2X6nzgqTJuGmrQLZfukF\n\t\t\t\t\t\tRPzBfdrQnJGTg/3/dIvCGJ+KfqIt5fGEAwYVpMJaDg6LjBcZSgjmppOocEKVQJyd\n\t\t\t\t\t\tZWEZtKp5+PLDIfQ4btrxw1mCOo/ngEGB8owPeFXstxIweC+9XNhJp4c8L2iZEsfy\n\t\t\t\t\t\trNSE+0KFb7DI2sdEbFyaDixLSFlX5CY7fhUStPUzMOnhXnl2UR9hdgH8x60zu0iU\n\t\t\t\t\t\tAIXLx0cs81W+VtX2xgsg42oB/dw/6rfFWT37EmXuJi+cQQIDAQABo4IBljCCAZIw\n\t\t\t\t\t\tcwYIKwYBBQUHAQEEZzBlMCoGCCsGAQUFBzABhh5odHRwOi8vb2NzcC5xdW92YWRp\n\t\t\t\t\t\tc2dsb2JhbC5jb20wNwYIKwYBBQUHMAKGK2h0dHA6Ly90cnVzdC5xdW92YWRpc2ds\n\t\t\t\t\t\tb2JhbC5jb20vcXZzc2xnMi5jcnQwHQYDVR0RBBYwFIISc2hpYjJpZHAubnR1LmFj\n\t\t\t\t\t\tLnVrMFEGA1UdIARKMEgwRgYMKwYBBAG+WAACZAEBMDYwNAYIKwYBBQUHAgEWKGh0\n\t\t\t\t\t\tdHA6Ly93d3cucXVvdmFkaXNnbG9iYWwuY29tL3JlcG9zaXRvcnkwDgYDVR0PAQH/\n\t\t\t\t\t\tBAQDAgWgMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAfBgNVHSMEGDAW\n\t\t\t\t\t\tgBSRGWKtWxenMPvw3jklsb2MubhRJzA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8v\n\t\t\t\t\t\tY3JsLnF1b3ZhZGlzZ2xvYmFsLmNvbS9xdnNzbGcyLmNybDAdBgNVHQ4EFgQUdOYX\n\t\t\t\t\t\tCiIw/0+Pmuy3G+dj7ShaC0kwDQYJKoZIhvcNAQELBQADggEBAEG6I9qcqCWJzXDe\n\t\t\t\t\t\tYzumSW1UKABfa3lSs8F+7G5cWHPq39C5Eas8+ZUpDytTug6pg2CLn9qWIjW2hstY\n\t\t\t\t\t\tBuPkFULUL1nmJP8iLiY5YtdfFG9GS7gHAPy9urAAR7i6UMSlqJgfyIHlY6kPxv4+\n\t\t\t\t\t\tIUHPQC0LVUFzQhHrFkjdBj5IcH1KIT0/b7T8IwovtRDGCyBoXeUr5y7uZjzmVGF4\n\t\t\t\t\t\tUq+fiME+67uMhY9TV9ERdn+NiYkxScu/2WSve5ZrsfrwxQTe9FhgYnMDv2JNGSUk\n\t\t\t\t\t\tJxl/t3PafEIUbWMpcSWZinaLGZ/2nZ9cRH3fgu45o1co8CjjrDHTGSrWdjhKrmgM\n\t\t\t\t\t\tfjw7AVA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Nottingham Trent University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ntu.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Nottingham Trent University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dlib-tirnanog.ucs.ed.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Glover"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve.glover@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Glover"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve.glover@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dlib-tirnanog.ucs.ed.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_instant": "2013-07-03T10:53:42Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUEwRtoz5We3lWVCaSgWi+vl+dHUgwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJTEjMCEGA1UEAwwaZGxpYi10aXJuYW5vZy51Y3MuZWQuYWMudWswHhcNMTYw\n\t\t\t\t\t\tMjA1MTEyNDQyWhcNMzYwMjA1MTEyNDQyWjAlMSMwIQYDVQQDDBpkbGliLXRpcm5h\n\t\t\t\t\t\tbm9nLnVjcy5lZC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tANT/WcMILmfTZzolbzjVoXPW4S3G8FQFImvobnOCN7vXTKZc07r2y3E39axZ7uZ8\n\t\t\t\t\t\thlNzy+Imjs6EfrupBjK8X2arj0wW5PZrrjzJze7NL1nWH9BednuwClK9s4p9lF3I\n\t\t\t\t\t\tB7RnWEaqBikAvul/RDoXU0sfrhguiGHNwp2+A7+Rg/nhMGuc8OL4nAxw7/N9A/hl\n\t\t\t\t\t\tZ9aA8O38iyy0gFUR73SMTUXUebthyfT6RWywRyxrlO1U4gEHsQK0xHkqpuTuwjMt\n\t\t\t\t\t\t0iicwRDasX72hPUlytekoF5PuNbW5V/hlyxAvteQ+X5Kj26jsG1m3hgDrz893P07\n\t\t\t\t\t\t0KI3QlsnMz1dupNYlgMc0UsCAwEAAaN7MHkwHQYDVR0OBBYEFE6ZvUPf8neVhnSw\n\t\t\t\t\t\thov1G/uMPcJyMFgGA1UdEQRRME+CGmRsaWItdGlybmFub2cudWNzLmVkLmFjLnVr\n\t\t\t\t\t\thjFodHRwczovL2RsaWItdGlybmFub2cudWNzLmVkLmFjLnVrL2lkcC9zaGliYm9s\n\t\t\t\t\t\tZXRoMA0GCSqGSIb3DQEBBQUAA4IBAQCPYn0tDyyopNzfXPV1s/twrpyjiW0Nt1IU\n\t\t\t\t\t\tuG+c9Jksm4knD/MFbDR+s1BL4yZqrAagJFEG+wrdEDzGHYVCe2bhQB+DElO29qVI\n\t\t\t\t\t\t0D1SvHcfeUT0EN4blqUOhrxDN1oTb8T7QUKxcHqkQYMnL1+ZW2ToPvKaTdpyeqDK\n\t\t\t\t\t\tnAwgPJa9u3PRk7hPMHc25taUc4ArgdidbUXyHBpfM8PMsCm8Ebu96StZ2dY95+zT\n\t\t\t\t\t\tE5ZcGzTGnxhQgyoT1P7+ggRHr8y1+dDz5IbLaQQ/bC2ibFyEyy06ympu8Cx08iMp\n\t\t\t\t\t\tzf5skApOOgqvimQll5qRtx9IknLdw79d96BVWZAXlhKh0MPbwFyM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dlib-tirnanog.ucs.ed.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://dlib-tirnanog.ucs.ed.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-tirnanog.ucs.ed.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dlib-tirnanog.ucs.ed.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dlib-tirnanog.ucs.ed.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-tirnanog.ucs.ed.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://dlib-tirnanog.ucs.ed.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dlib-tirnanog.ucs.ed.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dlib-tirnanog.ucs.ed.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dlib-tirnanog.ucs.ed.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://dlib-tirnanog.ucs.ed.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-tirnanog.ucs.ed.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dlib-tirnanog.ucs.ed.ac.uk"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This \"fairy portal\" is the UK federation Tirnanog Test IdP"
                  }
                ],
                "logo": [
                  {
                    "text": "https://dlib-tirnanog.ucs.ed.ac.uk/idp/images/rec-detail.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "86"
                  },
                  {
                    "text": "https://dlib-tirnanog.ucs.ed.ac.uk/idp/images/recon.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Tirnanog Test IdP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUEwRtoz5We3lWVCaSgWi+vl+dHUgwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJTEjMCEGA1UEAwwaZGxpYi10aXJuYW5vZy51Y3MuZWQuYWMudWswHhcNMTYw\n\t\t\t\t\t\tMjA1MTEyNDQyWhcNMzYwMjA1MTEyNDQyWjAlMSMwIQYDVQQDDBpkbGliLXRpcm5h\n\t\t\t\t\t\tbm9nLnVjcy5lZC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tANT/WcMILmfTZzolbzjVoXPW4S3G8FQFImvobnOCN7vXTKZc07r2y3E39axZ7uZ8\n\t\t\t\t\t\thlNzy+Imjs6EfrupBjK8X2arj0wW5PZrrjzJze7NL1nWH9BednuwClK9s4p9lF3I\n\t\t\t\t\t\tB7RnWEaqBikAvul/RDoXU0sfrhguiGHNwp2+A7+Rg/nhMGuc8OL4nAxw7/N9A/hl\n\t\t\t\t\t\tZ9aA8O38iyy0gFUR73SMTUXUebthyfT6RWywRyxrlO1U4gEHsQK0xHkqpuTuwjMt\n\t\t\t\t\t\t0iicwRDasX72hPUlytekoF5PuNbW5V/hlyxAvteQ+X5Kj26jsG1m3hgDrz893P07\n\t\t\t\t\t\t0KI3QlsnMz1dupNYlgMc0UsCAwEAAaN7MHkwHQYDVR0OBBYEFE6ZvUPf8neVhnSw\n\t\t\t\t\t\thov1G/uMPcJyMFgGA1UdEQRRME+CGmRsaWItdGlybmFub2cudWNzLmVkLmFjLnVr\n\t\t\t\t\t\thjFodHRwczovL2RsaWItdGlybmFub2cudWNzLmVkLmFjLnVrL2lkcC9zaGliYm9s\n\t\t\t\t\t\tZXRoMA0GCSqGSIb3DQEBBQUAA4IBAQCPYn0tDyyopNzfXPV1s/twrpyjiW0Nt1IU\n\t\t\t\t\t\tuG+c9Jksm4knD/MFbDR+s1BL4yZqrAagJFEG+wrdEDzGHYVCe2bhQB+DElO29qVI\n\t\t\t\t\t\t0D1SvHcfeUT0EN4blqUOhrxDN1oTb8T7QUKxcHqkQYMnL1+ZW2ToPvKaTdpyeqDK\n\t\t\t\t\t\tnAwgPJa9u3PRk7hPMHc25taUc4ArgdidbUXyHBpfM8PMsCm8Ebu96StZ2dY95+zT\n\t\t\t\t\t\tE5ZcGzTGnxhQgyoT1P7+ggRHr8y1+dDz5IbLaQQ/bC2ibFyEyy06ympu8Cx08iMp\n\t\t\t\t\t\tzf5skApOOgqvimQll5qRtx9IknLdw79d96BVWZAXlhKh0MPbwFyM"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Tirnanog Test IdP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ukfederation.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://bath.topdesk.net/tas/public/login/verify",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webmaster@bath.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Webmaster"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Phillips"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:R.I.Phillips@bath.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bath.topdesk.net/tas/public/login/verify",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-01-05T10:44:56Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Bath: TOPdesk"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://bath.topdesk.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Bath"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZzCCAk+gAwIBAgIJANCIcdjqpry3MA0GCSqGSIb3DQEBCwUAMCsxDTALBgNV\n\t\t\t\t\t\tBAMTBGJhdGgxDTALBgNVBAoTBGJhdGgxCzAJBgNVBAYTAlVLMB4XDTE2MDEwNDA5\n\t\t\t\t\t\tNTEzNVoXDTI2MDEwMTA5NTEzNVowKzENMAsGA1UEAxMEYmF0aDENMAsGA1UEChME\n\t\t\t\t\t\tYmF0aDELMAkGA1UEBhMCVUswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCwvaahZ5kXMwXof8Ae1E2YyVAs39/DIVxtNwot2aldaBNTnUeKeEzpyjuuMgNV\n\t\t\t\t\t\tmXQxp0XDMpWjSUnWvTrAS7MqafWhC0rLFWFKyuCtw6ZQW8YYOnf+Lv4bF2gyOXnP\n\t\t\t\t\t\t/XSUH9RPqJler6xU/4C6k96x47hRPTZYzDpuSsrtw80HUBnblWHZ0ID6YTCGb2Df\n\t\t\t\t\t\tzPAFq/0wCiYuFyZFyWgJ2PBpNQRnUeMyjiUsiOf9xe5Fo2P7vo9SJ3HDYpLGeKON\n\t\t\t\t\t\tZ00iXf7+k8DFr89jKKW7DF1viy1+kG/rqYIrn4wU7wWA77l5SyNLekhdkgwD8JIg\n\t\t\t\t\t\tgtp9j3YDap/y9+wclBkMrDW1AgMBAAGjgY0wgYowHQYDVR0OBBYEFNT03jM3IxyK\n\t\t\t\t\t\tbi2RIfCBnKYoGmXzMFsGA1UdIwRUMFKAFNT03jM3IxyKbi2RIfCBnKYoGmXzoS+k\n\t\t\t\t\t\tLTArMQ0wCwYDVQQDEwRiYXRoMQ0wCwYDVQQKEwRiYXRoMQswCQYDVQQGEwJVS4IJ\n\t\t\t\t\t\tANCIcdjqpry3MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQELBQADggEBAItqA/JO\n\t\t\t\t\t\tMLI6+oEcFXLv6UmQAZgyQH4BrbrsqIZjUQqT8moPeAYx+c6FBJJCfpP/020kn9ZY\n\t\t\t\t\t\triRJg0HEidZSYlXIOrLbsuKLdD4QvZ2ujvXxraBW4afz6pwG4Dpai/I+RmHb4U5d\n\t\t\t\t\t\tmXkSbkJnc6IafiwWHm93+iLFp1Rlhhd0DKuLibjZ2SnaoMoP9++PabaNkpaUfvSd\n\t\t\t\t\t\t26s45S31+sW4gvLymvClectetGTtQbIsceuvCDSlpDE1kaxRtZe8knC4QVXoZyqS\n\t\t\t\t\t\tQq88+taDfX0Txl0htpg3+wO+iygQIP8ERr8QhoCXUckoaWGusd8ZgLGveeXwq4Cb\n\t\t\t\t\t\t8Oi2R3LTJ9/2fRQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZzCCAk+gAwIBAgIJANCIcdjqpry3MA0GCSqGSIb3DQEBCwUAMCsxDTALBgNV\n\t\t\t\t\t\tBAMTBGJhdGgxDTALBgNVBAoTBGJhdGgxCzAJBgNVBAYTAlVLMB4XDTE2MDEwNDA5\n\t\t\t\t\t\tNTEzNVoXDTI2MDEwMTA5NTEzNVowKzENMAsGA1UEAxMEYmF0aDENMAsGA1UEChME\n\t\t\t\t\t\tYmF0aDELMAkGA1UEBhMCVUswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQCwvaahZ5kXMwXof8Ae1E2YyVAs39/DIVxtNwot2aldaBNTnUeKeEzpyjuuMgNV\n\t\t\t\t\t\tmXQxp0XDMpWjSUnWvTrAS7MqafWhC0rLFWFKyuCtw6ZQW8YYOnf+Lv4bF2gyOXnP\n\t\t\t\t\t\t/XSUH9RPqJler6xU/4C6k96x47hRPTZYzDpuSsrtw80HUBnblWHZ0ID6YTCGb2Df\n\t\t\t\t\t\tzPAFq/0wCiYuFyZFyWgJ2PBpNQRnUeMyjiUsiOf9xe5Fo2P7vo9SJ3HDYpLGeKON\n\t\t\t\t\t\tZ00iXf7+k8DFr89jKKW7DF1viy1+kG/rqYIrn4wU7wWA77l5SyNLekhdkgwD8JIg\n\t\t\t\t\t\tgtp9j3YDap/y9+wclBkMrDW1AgMBAAGjgY0wgYowHQYDVR0OBBYEFNT03jM3IxyK\n\t\t\t\t\t\tbi2RIfCBnKYoGmXzMFsGA1UdIwRUMFKAFNT03jM3IxyKbi2RIfCBnKYoGmXzoS+k\n\t\t\t\t\t\tLTArMQ0wCwYDVQQDEwRiYXRoMQ0wCwYDVQQKEwRiYXRoMQswCQYDVQQGEwJVS4IJ\n\t\t\t\t\t\tANCIcdjqpry3MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQELBQADggEBAItqA/JO\n\t\t\t\t\t\tMLI6+oEcFXLv6UmQAZgyQH4BrbrsqIZjUQqT8moPeAYx+c6FBJJCfpP/020kn9ZY\n\t\t\t\t\t\triRJg0HEidZSYlXIOrLbsuKLdD4QvZ2ujvXxraBW4afz6pwG4Dpai/I+RmHb4U5d\n\t\t\t\t\t\tmXkSbkJnc6IafiwWHm93+iLFp1Rlhhd0DKuLibjZ2SnaoMoP9++PabaNkpaUfvSd\n\t\t\t\t\t\t26s45S31+sW4gvLymvClectetGTtQbIsceuvCDSlpDE1kaxRtZe8knC4QVXoZyqS\n\t\t\t\t\t\tQq88+taDfX0Txl0htpg3+wO+iygQIP8ERr8QhoCXUckoaWGusd8ZgLGveeXwq4Cb\n\t\t\t\t\t\t8Oi2R3LTJ9/2fRQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bath.topdesk.net/tas/public/login/verify",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://lmuza-idp.lanet.lv",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ITserviss"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itserviss@lu.lv"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://lmuza-idp.lanet.lv",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://laife.lanet.lv/wiki/Latvian-Academic-Identity-Federation-Policy.pdf"
              }
            ],
            "registration_instant": "2013-10-10T10:10:10Z",
            "registration_authority": "http://laife.lanet.lv/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lmuza-idp.lanet.lv/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lmuza-idp.lanet.lv/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:56.950974,24.116292"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Latvian Academy of Music"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Latvian Academy of Music - LMUZA IDP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://laife.lanet.lv/"
          },
          {
            "lang": "lv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jvlma.lv/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LAIFE - LMUZA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp01.ogs.trieste.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@ogs.trieste.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp01.ogs.trieste.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2014-11-19T18:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUWOUmLa4FhkqSqR1HxQX3JeEdVy4wDQYJKoZIhvcNAQEF\nBQAwHzEdMBsGA1UEAxMUaWRwMDEub2dzLnRyaWVzdGUuaXQwHhcNMTQwNjI0MTE0\nMDA2WhcNMzQwNjI0MTE0MDA2WjAfMR0wGwYDVQQDExRpZHAwMS5vZ3MudHJpZXN0\nZS5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMgIgZhhFV7QPbWz\n1duF55NhnNoUPiSKzWYC+aj/MA9vg3Nyi+iy3hiSN4c2AVHTwS2vBUjovE85ac2c\nKODrPJTSaKrk0HgQFtp/D2SMvx1eO15gjiMHbf3KQ8TTSzx4VMtbzIX6w3wd3Utv\noznA+XqD5bWJhS0zXDAa1st+LrjQbjKShDIbwOpvQVe93A95EuwP258rxs9GSjVD\nmq0T4jKn7IIgTk0P32ak/4xCRHhHQRvJ2ZLERRR1cEdhcI65wsW6csXZ+4SpNR9E\nvo1GvdoIRnufsFvat+WTkYQFSmIpfUffm5Ijxr4EsjOy4fHeA2AjauVV9TASqj3h\nt8SMyy8CAwEAAaNvMG0wTAYDVR0RBEUwQ4IUaWRwMDEub2dzLnRyaWVzdGUuaXSG\nK2h0dHBzOi8vaWRwMDEub2dzLnRyaWVzdGUuaXQvaWRwL3NoaWJib2xldGgwHQYD\nVR0OBBYEFAEcqKk0bzXfdE72LQ+3BUcv5CHDMA0GCSqGSIb3DQEBBQUAA4IBAQCC\nT6c9VpgBD5GeM1tsXYkG+n047bAv4g9G9+E/80HdqwpU314Nw697I/wN7pqiOE7j\nWkTTH+4bGK5ErGKOHuJCWCILHDQG8qk94Ni9rgXkhUM4ChfZ6nROLQsD9+r2X7/8\nnaPDewMZqE3c/dn3yG8gkP6oSrmY0a49pQVKaP8/aHHVE89s9hEGKuf6AeX7CUuA\ndKeDceJjeS5urGQn65bc7Mzsk16rI5W7o0itlt/+Xpka1Dp+7U+eT/FyiLGGWdQ0\n1xesztEexwtTIxCSBsGrIM9Sy0NJ0CcGgQ8osR4cARCu+qVyouKPb0yWeRK6r0Z9\norEGOduQPPy+HJjILGav"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ogs.trieste.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp01.ogs.trieste.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp01.ogs.trieste.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp01.ogs.trieste.it/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp01.ogs.trieste.it/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp01.ogs.trieste.it:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp01.ogs.trieste.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp01.ogs.trieste.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp01.ogs.trieste.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp01.ogs.trieste.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp01.ogs.trieste.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp01.ogs.trieste.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ogs.trieste.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://cesit.inogs.it/node/100"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://cesit.inogs.it/node/98"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "National Institute of Oceanography and Experimental Geophysics"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "OGS (Istituto Nazionale di Oceanografia e di Geofisica Sperimentale)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for National Institute of Oceanography and Experimental Geophysics's users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider per utenti dell'Istituto Nazionale di Oceanografia e di Geofisica Sperimentale"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp01.ogs.trieste.it/idp/images/logo-32x32.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp01.ogs.trieste.it/idp/images/logo-32x32.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp01.ogs.trieste.it/idp/images/logo-160x120.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idp01.ogs.trieste.it/idp/images/logo-160x120.png",
                    "lang": "it",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://cesit.inogs.it/node/99"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://cesit.inogs.it/node/97"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUWOUmLa4FhkqSqR1HxQX3JeEdVy4wDQYJKoZIhvcNAQEF\nBQAwHzEdMBsGA1UEAxMUaWRwMDEub2dzLnRyaWVzdGUuaXQwHhcNMTQwNjI0MTE0\nMDA2WhcNMzQwNjI0MTE0MDA2WjAfMR0wGwYDVQQDExRpZHAwMS5vZ3MudHJpZXN0\nZS5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMgIgZhhFV7QPbWz\n1duF55NhnNoUPiSKzWYC+aj/MA9vg3Nyi+iy3hiSN4c2AVHTwS2vBUjovE85ac2c\nKODrPJTSaKrk0HgQFtp/D2SMvx1eO15gjiMHbf3KQ8TTSzx4VMtbzIX6w3wd3Utv\noznA+XqD5bWJhS0zXDAa1st+LrjQbjKShDIbwOpvQVe93A95EuwP258rxs9GSjVD\nmq0T4jKn7IIgTk0P32ak/4xCRHhHQRvJ2ZLERRR1cEdhcI65wsW6csXZ+4SpNR9E\nvo1GvdoIRnufsFvat+WTkYQFSmIpfUffm5Ijxr4EsjOy4fHeA2AjauVV9TASqj3h\nt8SMyy8CAwEAAaNvMG0wTAYDVR0RBEUwQ4IUaWRwMDEub2dzLnRyaWVzdGUuaXSG\nK2h0dHBzOi8vaWRwMDEub2dzLnRyaWVzdGUuaXQvaWRwL3NoaWJib2xldGgwHQYD\nVR0OBBYEFAEcqKk0bzXfdE72LQ+3BUcv5CHDMA0GCSqGSIb3DQEBBQUAA4IBAQCC\nT6c9VpgBD5GeM1tsXYkG+n047bAv4g9G9+E/80HdqwpU314Nw697I/wN7pqiOE7j\nWkTTH+4bGK5ErGKOHuJCWCILHDQG8qk94Ni9rgXkhUM4ChfZ6nROLQsD9+r2X7/8\nnaPDewMZqE3c/dn3yG8gkP6oSrmY0a49pQVKaP8/aHHVE89s9hEGKuf6AeX7CUuA\ndKeDceJjeS5urGQn65bc7Mzsk16rI5W7o0itlt/+Xpka1Dp+7U+eT/FyiLGGWdQ0\n1xesztEexwtTIxCSBsGrIM9Sy0NJ0CcGgQ8osR4cARCu+qVyouKPb0yWeRK6r0Z9\norEGOduQPPy+HJjILGav"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "National Institute of Oceanography and Experimental Geophysics"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "OGS - Istituto Nazionale di Oceanografia e di Geofisica Sperimentale)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ogs.trieste.it/en"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ogs.trieste.it"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National Institute of Oceanography and Experimental Geophysics"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "OGS (Istituto Nazionale di Oceanografia e di Geofisica Sperimentale)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://uu.test.diva-portal.org/shibboleth",
    {
      "entity_id": "https://uu.test.diva-portal.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uu.test.diva-portal.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://uu.test.diva-portal.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uu.test.diva-portal.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uu.test.diva-portal.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://uu.test.diva-portal.org/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "diva-portal1.diva-portal.org"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIJAJ58L93niyUPMA0GCSqGSIb3DQEBBQUAMCcxJTAjBgNV\nBAMTHGRpdmEtcG9ydGFsMS5kaXZhLXBvcnRhbC5vcmcwHhcNMDkxMTIwMTQ1NDEx\nWhcNMTkxMTE4MTQ1NDExWjAnMSUwIwYDVQQDExxkaXZhLXBvcnRhbDEuZGl2YS1w\nb3J0YWwub3JnMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxPHENdev\ncanBV0qZ66FSROHK0WvEgxTmYMGkEPqSKt8cYgSFmxxWrbAWl4LnN4x/Ie0GZziR\nXSbzE3aGPYmxfXOWnVqdlwk50SHpt5MA+gVK8Ola8tQ7sMg0tgg6MsgykKJ1F9JF\n2PGUPaE09kzW10jkaH1sUfbBi5vOLkVONWhmD05LvE95kSzkyQLONuBgJnc3H8dw\nvwTqOgiLDa/eRLUucpGA7sFsi+ngGGgd4Ci0DRrOgwH4vXoLQpdNQ7SppommWkqr\nfDSEoOfsU1t3CFzUAq9cccNYHIsqL1lZD6L5ywhOUpkwQ7IGpZTOjJT1HTaSxqVD\nJj2uzZV6ISPDjwIDAQABo0owSDAnBgNVHREEIDAeghxkaXZhLXBvcnRhbDEuZGl2\nYS1wb3J0YWwub3JnMB0GA1UdDgQWBBR9EtM9e7Pu3SJPhrEbTgOe7V+VEDANBgkq\nhkiG9w0BAQUFAAOCAQEApeb7TrTmVVR13KnKjSIkDyDfs5U+NNDU7N9CnqG8ag5j\nNom8pmOKDmNs5xC2qQ/q8JuxIsaev6NyRcyD2M0AkwCdCagY4Ynrj/4CQnViyySy\nSFuYPq+gUhhSfKii7b+B41RogFtEd0SO+QWGvqhHY1JdnXsYJ3efKUrC0yVJGM54\nC/8BzU0RLd+mOogKpgmoqWE0vSrEh94dotMT/EfSikjCMJ9QHEyGncpY+uoQLw6n\nfBSKIAfLSFYUN5auSXpdicfgZQbkj6Mn7cjvVHo8dgAKnkk79gXcZ37JUHsGbuWG\nOLrNDnMD/v+8CR8xqwOFEKC7BwAJB1HWfDwaKaRRbg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=diva-portal1.diva-portal.org"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "diva-portal1.diva-portal.org"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIJAJ58L93niyUPMA0GCSqGSIb3DQEBBQUAMCcxJTAjBgNV\nBAMTHGRpdmEtcG9ydGFsMS5kaXZhLXBvcnRhbC5vcmcwHhcNMDkxMTIwMTQ1NDEx\nWhcNMTkxMTE4MTQ1NDExWjAnMSUwIwYDVQQDExxkaXZhLXBvcnRhbDEuZGl2YS1w\nb3J0YWwub3JnMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxPHENdev\ncanBV0qZ66FSROHK0WvEgxTmYMGkEPqSKt8cYgSFmxxWrbAWl4LnN4x/Ie0GZziR\nXSbzE3aGPYmxfXOWnVqdlwk50SHpt5MA+gVK8Ola8tQ7sMg0tgg6MsgykKJ1F9JF\n2PGUPaE09kzW10jkaH1sUfbBi5vOLkVONWhmD05LvE95kSzkyQLONuBgJnc3H8dw\nvwTqOgiLDa/eRLUucpGA7sFsi+ngGGgd4Ci0DRrOgwH4vXoLQpdNQ7SppommWkqr\nfDSEoOfsU1t3CFzUAq9cccNYHIsqL1lZD6L5ywhOUpkwQ7IGpZTOjJT1HTaSxqVD\nJj2uzZV6ISPDjwIDAQABo0owSDAnBgNVHREEIDAeghxkaXZhLXBvcnRhbDEuZGl2\nYS1wb3J0YWwub3JnMB0GA1UdDgQWBBR9EtM9e7Pu3SJPhrEbTgOe7V+VEDANBgkq\nhkiG9w0BAQUFAAOCAQEApeb7TrTmVVR13KnKjSIkDyDfs5U+NNDU7N9CnqG8ag5j\nNom8pmOKDmNs5xC2qQ/q8JuxIsaev6NyRcyD2M0AkwCdCagY4Ynrj/4CQnViyySy\nSFuYPq+gUhhSfKii7b+B41RogFtEd0SO+QWGvqhHY1JdnXsYJ3efKUrC0yVJGM54\nC/8BzU0RLd+mOogKpgmoqWE0vSrEh94dotMT/EfSikjCMJ9QHEyGncpY+uoQLw6n\nfBSKIAfLSFYUN5auSXpdicfgZQbkj6Mn7cjvVHo8dgAKnkk79gXcZ37JUHsGbuWG\nOLrNDnMD/v+8CR8xqwOFEKC7BwAJB1HWfDwaKaRRbg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=diva-portal1.diva-portal.org"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uu.test.diva-portal.org/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://uu.test.diva-portal.org/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uu.test.diva-portal.org/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uu.test.diva-portal.org/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uu.test.diva-portal.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://uu.test.diva-portal.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uu.test.diva-portal.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://uu.test.diva-portal.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://uu.test.diva-portal.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://uu.test.diva-portal.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cafe.usf.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Eduardo Souza"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jose.goncalves@usf.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.usf.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID7jCCAtYCAQAwDQYJKoZIhvcNAQEFBQAwgbwxKjAoBgNVBAoUIVVTRiAtIFVu\naXZlcnNpZGFkZSBTw6NvIEZyYW5jaXNjbzELMAkGA1UECxMCVEkxKDAmBgkqhkiG\n9w0BCQEWGWpvc2UuZ29uY2FsdmVzQHVzZi5lZHUuYnIxGzAZBgNVBAcUEkJyYWdh\nbsOnYSBQYXVsaXN0YTETMBEGA1UECBQKU8OjbyBQYXVsbzELMAkGA1UEBhMCQlIx\nGDAWBgNVBAMTD2NhZmUudXNmLmVkdS5icjAeFw0xNTA5MzAxNzIyMjRaFw0xODA5\nMjkxNzIyMjRaMIG8MSowKAYDVQQKFCFVU0YgLSBVbml2ZXJzaWRhZGUgU8OjbyBG\ncmFuY2lzY28xCzAJBgNVBAsTAlRJMSgwJgYJKoZIhvcNAQkBFhlqb3NlLmdvbmNh\nbHZlc0B1c2YuZWR1LmJyMRswGQYDVQQHFBJCcmFnYW7Dp2EgUGF1bGlzdGExEzAR\nBgNVBAgUClPDo28gUGF1bG8xCzAJBgNVBAYTAkJSMRgwFgYDVQQDEw9jYWZlLnVz\nZi5lZHUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQD2ylg01o7h\n2ql3tCcMIym2xD373BCc9k1ndxmwJ3IE3cuEIQR8tOO5zrVt42yslb0Cm6DpXNHK\ncYxms2OI9DYS1SkGeJyXDMe7tPy4IE4b3RYprbRwTOaQLlePt5MgIhiAek8oPzuh\nC3LxgPqdtzd7aBxq8fu++fYdrTESBa8bCmcqdnU9jmob5jDnxDcDkQ1ertxhlOtn\nsD7iEeoZGWGaIqYlH11+b+UlyYKSqNtKVnqcDWMaRuxYwbe4xUmx2E8LJt+jHQn5\nXyFDkDcwfxetj0FIlhe9umg9vk1L+hCiynyFSXFBgXqUvz0rIIui6yYmAOWrboCY\nYM97hwpC4v2TAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAGnkYSv7gZYAbJ2cUUFM\n0Nbd6h77Riukwdw3tL8goc30ats4zwnh8EbDXtAWAQ8dFy8fcGdmLOi7Vq1CmNP2\nzWYqpxIQbPTxJ4PznnzrlxOyfwHROAe52Go0ceFtMd51GUueFV2jioLjn5TaJgey\nAgVlrHPQaJCNPEYFf8tNjgurj6NRtabPpMW8ogr/pX5AJv3xE9OuwCPJ34HO+o7O\nn4OS2VjKptCeJrfZN/7Km5tHaS/xjH5WJkKsZlubo2PrxlgSy1gt11wAhucqWB7v\nHd/uhgyrVLEXYsMoXfEW2SZCuF4wHOX5RQds9Kmh/F8N9iVjElM3co5gHufh5cxx\n8IY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.usf.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.usf.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.usf.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.usf.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.usf.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.usf.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.usf.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.usf.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.usf.edu.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.usf.edu.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "USF - Universidade Sao Francisco"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "USF - Universidade Sao Francisco"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "USF - Universidade Sao Francisco"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "USF - Universidade Sao Francisco"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID7jCCAtYCAQAwDQYJKoZIhvcNAQEFBQAwgbwxKjAoBgNVBAoUIVVTRiAtIFVu\naXZlcnNpZGFkZSBTw6NvIEZyYW5jaXNjbzELMAkGA1UECxMCVEkxKDAmBgkqhkiG\n9w0BCQEWGWpvc2UuZ29uY2FsdmVzQHVzZi5lZHUuYnIxGzAZBgNVBAcUEkJyYWdh\nbsOnYSBQYXVsaXN0YTETMBEGA1UECBQKU8OjbyBQYXVsbzELMAkGA1UEBhMCQlIx\nGDAWBgNVBAMTD2NhZmUudXNmLmVkdS5icjAeFw0xNTA5MzAxNzIyMjRaFw0xODA5\nMjkxNzIyMjRaMIG8MSowKAYDVQQKFCFVU0YgLSBVbml2ZXJzaWRhZGUgU8OjbyBG\ncmFuY2lzY28xCzAJBgNVBAsTAlRJMSgwJgYJKoZIhvcNAQkBFhlqb3NlLmdvbmNh\nbHZlc0B1c2YuZWR1LmJyMRswGQYDVQQHFBJCcmFnYW7Dp2EgUGF1bGlzdGExEzAR\nBgNVBAgUClPDo28gUGF1bG8xCzAJBgNVBAYTAkJSMRgwFgYDVQQDEw9jYWZlLnVz\nZi5lZHUuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQD2ylg01o7h\n2ql3tCcMIym2xD373BCc9k1ndxmwJ3IE3cuEIQR8tOO5zrVt42yslb0Cm6DpXNHK\ncYxms2OI9DYS1SkGeJyXDMe7tPy4IE4b3RYprbRwTOaQLlePt5MgIhiAek8oPzuh\nC3LxgPqdtzd7aBxq8fu++fYdrTESBa8bCmcqdnU9jmob5jDnxDcDkQ1ertxhlOtn\nsD7iEeoZGWGaIqYlH11+b+UlyYKSqNtKVnqcDWMaRuxYwbe4xUmx2E8LJt+jHQn5\nXyFDkDcwfxetj0FIlhe9umg9vk1L+hCiynyFSXFBgXqUvz0rIIui6yYmAOWrboCY\nYM97hwpC4v2TAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAGnkYSv7gZYAbJ2cUUFM\n0Nbd6h77Riukwdw3tL8goc30ats4zwnh8EbDXtAWAQ8dFy8fcGdmLOi7Vq1CmNP2\nzWYqpxIQbPTxJ4PznnzrlxOyfwHROAe52Go0ceFtMd51GUueFV2jioLjn5TaJgey\nAgVlrHPQaJCNPEYFf8tNjgurj6NRtabPpMW8ogr/pX5AJv3xE9OuwCPJ34HO+o7O\nn4OS2VjKptCeJrfZN/7Km5tHaS/xjH5WJkKsZlubo2PrxlgSy1gt11wAhucqWB7v\nHd/uhgyrVLEXYsMoXfEW2SZCuF4wHOX5RQds9Kmh/F8N9iVjElM3co5gHufh5cxx\n8IY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "USF - Universidade Sao Francisco"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "USF - Universidade Sao Francisco"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.usf.edu.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.usf.edu.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "USF - Universidade Sao Francisco"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "USF - Universidade Sao Francisco"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.u-paris2.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ssri@u-paris2.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.u-paris2.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2010-05-04T13:52:38Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.u-paris2.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.u-paris2.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.u-paris2.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "u-paris2.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.u-paris2.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Paris 2 - Panth\u00e9on Assas"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Paris 2 - Panth\u00e9on Assas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAINFA2whEjq7dIPf8YLpG746hePRMA0GCSqGSIb3DQEB\nBQUAMBoxGDAWBgNVBAMTD2lkcC51LXBhcmlzMi5mcjAeFw0xNDA0MjkwNzQ4MjJa\nFw0zNDA0MjkwNzQ4MjJaMBoxGDAWBgNVBAMTD2lkcC51LXBhcmlzMi5mcjCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANXXoMeffbh8zBylAJsvJYWVAvsl\n1i1KpJ4xVDftwXJAAc2rpzSH2vWZ4qXKm677GYWyrD6U5SC7tFrYKhnCIuTKyzyg\nWa93DyjDngc92+ci6ESR3DbpTkLtu5QqCzp+MNy1X7ggo24YagZHwYSpu+ftIZtr\nbZhK0xou+sEXg7kap+QTCYI1WHs/S84p53FRzKdDENg3JwLY8bVSwHK/Ikdanq0S\n4HpCVS7nIxh/Pxj0dL7X7GqclJS5CQZWTvNgGfeI5pbtuN9EvUyYzIn7DL/ADhRh\n60Q8RAmFx6i7touVzWuLAaIOYKrQhf2BKZnRrRj27mxHfee9vWPryla0UBUCAwEA\nAaNlMGMwQgYDVR0RBDswOYIPaWRwLnUtcGFyaXMyLmZyhiZodHRwczovL2lkcC51\nLXBhcmlzMi5mci9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU0UgDCtUMhwUc/VRK\nAG2CRoL4NpMwDQYJKoZIhvcNAQEFBQADggEBALyLQEriutI0U1ObNVQPGIT7qien\n9mvExaFkO4B0a4lIEpK19Mv2nVLxuJgd3Ov32GACN8kF8M+rldrlNEVNd6l3kW2I\nXhHLjOr4MHhWp9bzAOYZ6Nr28iOwcylDloHAcEUo+8iBwgiCrfcMAeF5EhRbyTIw\npwo+ghS3u/1WiZwpZV7rQVaEWkW/fwaZBmELmI6C9clq9+qG0/a86tU1Caqjn34g\nxrX/4JKfdKHNuguH4eowRTHgjvkQKyTDcphzAnOr6CE8islttFut36iPvYYJO7t9\nZOq3IDpQLAcll+GhtVWTmM1041GbGkbqzThB/ADpE/wl5efhlsP7vQEcOkE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Paris 2 - Panth\u00e9on Assas"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.u-paris2.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Paris 2 - Panth\u00e9on Assas"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-05.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-05.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-05.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-05.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-05.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-05.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-05.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-05.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-05.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;05"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;05"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-05.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-05.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJAPDhwPdGcyx3MA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wNS5sYWRvay51bXUuc2UwHhcNMTIwNjI5MTIwODEwWhcNMjIw\nNjI3MTIwODEwWjAhMR8wHQYDVQQDExZsYWRvazMtMDUubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAxWwMUAWTSXZEZna0VhGPOocl\njY+eNJ1VdGfNKH4naUenG3KRqK87K9hKiwI4t1e8YU28hTR2uRtxyeUF3iHBU1DM\nwAT0C0AJ5dCYMq24BTrkvs98/mpkWTFgT3l2zNjNUBASWjXvgTeeIlqeX+Dh/Nzw\nEfWx50yfKNOiWPWV14QhdwjMJvIJPBHWbzxhmURlGzUQ3/H8HwuW1vqe/gU4zCOR\nqE5EccNgWzzy2tZheRAi0Upm0+Ge4c9QrrrQLQQrorkuLVxCSgoIO2/4vLz9O39W\n0fxQdt9vIk94IMdGGB+1IAzMNiHDYUY9odU8wdkHinzZhWaWQ6F8mmBs1y+h/wID\nAQABo2swaTBIBgNVHREEQTA/ghZsYWRvazMtMDUubGFkb2sudW11LnNlhiVodHRw\nczovL2xhZG9rMy0wNS5sYWRvay51bXUuc2UvZ3VpLXNwMB0GA1UdDgQWBBRIMIrP\ntMdrVcWNtYYFCXhZzcu7/jANBgkqhkiG9w0BAQUFAAOCAQEAD31ZFs87nSUzgMGM\nRCR6WZ+sYYejsjikiq7nPvCclHWPoa2cn0q8LPtKGuWAfTR6u+3NXUpHHvpR+MEZ\nWHeoF7atdEl4ecvk+cWO830Cq4Kthwzd3hHQnqe4YNLPwNiVHeizZLxDrtXuQtqW\n0lPCIu9EsRhIHw1R0oxZ8b/rCmHyGFtVjv9Sre3nAlGC4ZwRM04jc5NoUfTfFjZi\nQ5cOumnObMzqS5d00Hr0BvCuUng2Ms/ZpF+BzxLyyw6LGq8oE10+d1NMMwrYqiRk\nqmThXK3vArMK9TCy4XBUdjbsXhwMSJ1Zez2abXJmkykRHgoWHKdULuGjAld/gaWm\nIj/QYw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-05.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-05.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-05.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-05.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-05.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-05.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-05.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-05.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-05.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-05.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.sthelens.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Brooker"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kbrooker@sthelens.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Karl"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Brooker"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:kbrooker@sthelens.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Karl"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.sthelens.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-09-23T09:19:50Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.sthelens.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sthelens.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.sthelens.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sthelens.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sthelens.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sthelens.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sthelens.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUefeWPtobMsRj91ZcJr632XXNAJQwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwHTEbMBkGA1UEAwwSaWRwLnN0aGVsZW5zLmFjLnVrMB4XDTE1MDcxMzA5MTc1\n\t\t\t\t\t\tMloXDTM1MDcxMzA5MTc1MlowHTEbMBkGA1UEAwwSaWRwLnN0aGVsZW5zLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAs6UhCjiogNIMFgyXluRJ\n\t\t\t\t\t\tLKskxjAUDlx7sUCweHPsYPxlz64zGSM8S7nRAG1yQzW0JA+RTyg//BOIASoX0T51\n\t\t\t\t\t\tXT7slINVEGGJPFZVrs8ovl8czb1BSZn+vEbL4UkOQIs3VAszc6sjufq9dVbFJs/Q\n\t\t\t\t\t\tzoESK85IN3k/IsCMnkwEe/q2pSU/UFcLxB+q0Ltjx0Eo2DyLb8gktYya8ITt4U6i\n\t\t\t\t\t\tQD1ZCBr9AFUBIrM1AgZwWEsWr5u69h391Jz6AsT7hyjkwoDsXVdEXx/kCJ7gMmT8\n\t\t\t\t\t\tY478h8teBSXHzjifPClzoRok7jaoqIykU7IooAl0Lgs+MlYeIJyGu+8a4Vj9Q3Ww\n\t\t\t\t\t\tFQIDAQABo2swaTAdBgNVHQ4EFgQU3tu/fpLFu35DC6bbe+H742hS/rQwSAYDVR0R\n\t\t\t\t\t\tBEEwP4ISaWRwLnN0aGVsZW5zLmFjLnVrhilodHRwczovL2lkcC5zdGhlbGVucy5h\n\t\t\t\t\t\tYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAfzGPK9GKQA75\n\t\t\t\t\t\tcYh1YziFi6MZ1FhB7YGVpkKfKXQuvFnIZqHMXvrdYrWmIIARmolte2WCWGSCWh56\n\t\t\t\t\t\t2QXQONMn0AUATCeCoEZJ0JdxGv6OkEzjztQJYAuXqX2h6rpc8TQtb+kRXR6dMI6Z\n\t\t\t\t\t\t70cZXzTy6HEzg+ILvissEpqK3doTjFTaoYyTkF2gVsJL1uaQvSKfzJMzsmVbxc3l\n\t\t\t\t\t\tSZF3c6J+ZVrldkCCLB33LtcpjeQ6wa7pwab7+B8Anp811A9ph7cZJf+CPh7nguem\n\t\t\t\t\t\tZ6++KzCFtBpmip6fxXOxq+T9DCtObKuu/Zwj7ALaV2Anx3+1eV9xUXvPyKKowtio\n\t\t\t\t\t\txGWZquR2PA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUSnhx1xX6LnWWTI0VWAtszPKeSlQwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwHTEbMBkGA1UEAwwSaWRwLnN0aGVsZW5zLmFjLnVrMB4XDTE1MDcxMzA5MTc0\n\t\t\t\t\t\tOVoXDTM1MDcxMzA5MTc0OVowHTEbMBkGA1UEAwwSaWRwLnN0aGVsZW5zLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtVjoha+zFXc2AXRgz7AA\n\t\t\t\t\t\tsm0b/jLeMcR0wIDjQJmYsa4sAtZHw++Kv5vnvFhsEMm5STxez54J66X9he0ahy/n\n\t\t\t\t\t\t4HUun4xOziqD32zxbE4FuJxU36zlxvsL/UTRLtNbI6iRy/+8zYBEVRP4Vxk8Vh4o\n\t\t\t\t\t\tgGMJ+05Z7GtKZ+qaG8UCs8kBgl+Z9VrmvnXrS9ne+SpY4o6k6cevG4/QzjWgDV8L\n\t\t\t\t\t\tF4g2Hh8WBeLRYwe5l5XGMKW2wGDkuYV0Wx8dAwxEm8koWkaxHPfk2aFLaLu40e0K\n\t\t\t\t\t\tc0IfWaiRnZ0YGdHLA3MkhUZf/fH2i1AZM4eXrXZEpN3lWC0Pptgc/MyLm6mV+/gm\n\t\t\t\t\t\tiQIDAQABo2swaTAdBgNVHQ4EFgQUy6N7cUuaZkXCHZUw5uNI8XFCrVkwSAYDVR0R\n\t\t\t\t\t\tBEEwP4ISaWRwLnN0aGVsZW5zLmFjLnVrhilodHRwczovL2lkcC5zdGhlbGVucy5h\n\t\t\t\t\t\tYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQsFAAOCAQEAmLvRi3/9nXFJ\n\t\t\t\t\t\trxiU7R4oZSEeCaWGAwmhvSkwJnXXcOnapmHA8NVwYxagpaAAUDkXclyVeWgXMEW7\n\t\t\t\t\t\t7fuLAhhvEH4M3fpzvkQpju9sumcFha9x+lGe88EP9DEC6qmjgrs+bnM25/WLisy4\n\t\t\t\t\t\t5GR1oUfqpoadlq3nhKZqwpDgI0xqGQPYvqIdeg4tBUC90zWMtbnB2RAebDq8G2jr\n\t\t\t\t\t\tuyAVx30gTcaiBFmYnoijzUSR7erf4+EQrPh2Dv59Rm1MvuSMUwB/YSew/B4KTXBr\n\t\t\t\t\t\tEKZxmfNDR/osPrE+Imy1pWidTkSoe23dKlk+nqKWedsYEr+HKMS5NSTUY9X4+ul1\n\t\t\t\t\t\tXEMB4j98UA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVANqZjdgjQDinPjHK15o/evwkJ47nMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMB0xGzAZBgNVBAMMEmlkcC5zdGhlbGVucy5hYy51azAeFw0xNTA3MTMwOTE3\n\t\t\t\t\t\tNTBaFw0zNTA3MTMwOTE3NTBaMB0xGzAZBgNVBAMMEmlkcC5zdGhlbGVucy5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIY0GyGm5/AZrki7cc+i\n\t\t\t\t\t\tqDdg48NDv/ofknRve/WD177ZyQMl5ROYQT/jxtidivl2LyQ4cUf4/eDr/VXq7ln2\n\t\t\t\t\t\tcEssI+idPbdY8oySivcwNyx/+HbOOUM9y1Z4Y1qzUXPVIw0ekksXcRW+zWR2hltg\n\t\t\t\t\t\twWfuflEZPMNeuI3hcLUsS8QxqTtgYxyiIYzZJj4hPz8eS/D0NA4UEyWGf4YbknJv\n\t\t\t\t\t\tn2UwchnNOY09vvzo2+nM4qIGTcGeqazwH4tHRdBYhBWCCIsT5jjuqESSUgnX/Wws\n\t\t\t\t\t\tL5xoGMNJ30g+hjd2zZOs4uBPPCpPvd+YT3o5CZO4usj8gZYXg5RY13ooN6ri6VEi\n\t\t\t\t\t\tSV8CAwEAAaNrMGkwHQYDVR0OBBYEFOgfhUabmVfWGgzFcIxIqNM4dYBdMEgGA1Ud\n\t\t\t\t\t\tEQRBMD+CEmlkcC5zdGhlbGVucy5hYy51a4YpaHR0cHM6Ly9pZHAuc3RoZWxlbnMu\n\t\t\t\t\t\tYWMudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQELBQADggEBAE+zg+HRMTto\n\t\t\t\t\t\toT4fq9cU7M+3evZeVlIdY3YMFhB9ltXmN6qjbjSucL+sZBssmTorx2RK+wjEyRmM\n\t\t\t\t\t\tmXiOCXb3KezzLUyLxTSIjzOtDkF6epvzq1ObsIKcpLf+wx6+yWA/RyjyIvbDcDcZ\n\t\t\t\t\t\tupZ9JDCBvv0U9Ml1JBCfEyIjW/7ssIaVh2PzxQs0uIAuCKL4IdwDwVd/2+/j1rgH\n\t\t\t\t\t\t4GESmz925rqMM5ZippAileHB6LMvDaX939Cx89mOpBy1GCE8Sf7RbQgdH46S3DID\n\t\t\t\t\t\tgQv8K/szMt60cSeU+yWCjRT3tGsEOe+Upn041k4KHZUvg4pXtNe0ssienaJjd2bv\n\t\t\t\t\t\tPIGItBCgWGc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "St Helens College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sthelens.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "St Helens College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.wolvcoll.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mills"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:millsash@wolvcoll.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ashley"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mills"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:millsash@wolvcoll.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ashley"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dean"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:deani@wolvcoll.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.wolvcoll.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-07-08T11:12:40Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTzCCAjegAwIBAgIUQ4d3Glz5yjW7FW9jd2mP9LsAUe8wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJDEiMCAGA1UEAxMZc2hpYmJvbGV0aC53b2x2Y29sbC5hYy51azAeFw0xNDA2\n\t\t\t\t\t\tMjQwOTA1MTdaFw0zNDA2MjQwOTA1MTdaMCQxIjAgBgNVBAMTGXNoaWJib2xldGgu\n\t\t\t\t\t\td29sdmNvbGwuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCl\n\t\t\t\t\t\tAWQo9/uMAecnAsdN9csAGTK2489RtQ7rJcRbozcr64BT1/w1iuh+RrWWqACgoNJP\n\t\t\t\t\t\taC2cGGm4DAEtguZlxv/EIm2YhKNQaDSgA472GPHRLslb2pRfNVJyFRfKJeVn2H/L\n\t\t\t\t\t\t/StgbnczUp1gj81bZpdT6LoT0kw6SBh42H4ktTQQcdchiLqapDdLl+mx/x6F+BuH\n\t\t\t\t\t\tHH6Pa4TwIKyu7FM7sTKek/Q4PLrLuHDFP7rg43lqjL2pQntsF4cNPewN+bcQujKn\n\t\t\t\t\t\t+aQ/sUzUtLsi0bAuTJeU0rPZgJtg5Y3XnmZTlHyVvyBODtQhXhU2OfYH2FWiEZmj\n\t\t\t\t\t\tD886Zakepq44z9wE19c5AgMBAAGjeTB3MFYGA1UdEQRPME2CGXNoaWJib2xldGgu\n\t\t\t\t\t\td29sdmNvbGwuYWMudWuGMGh0dHBzOi8vc2hpYmJvbGV0aC53b2x2Y29sbC5hYy51\n\t\t\t\t\t\tay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUEPnyUWWLLersRzyV9z/bHlXyz0Ew\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAJmDjexTbXsG8J5SYzXt8hda+nyrnlraOl6E6ql8\n\t\t\t\t\t\tyIazs9Tg2nKgLhlAalyERD712mwL+lSE+qHHFifdSO44YuOgVNJ0e+vWxISrhNpt\n\t\t\t\t\t\td59kjd1l8b1ZeQ3P507rDz2Uw+cA5YxkEVdlBrkb9fR26kPXDsXiz1P1DhHh/Qt0\n\t\t\t\t\t\t48PkIQdrwiSygWvNQGgMaB76XA3hqVyadpokVL/F1MFP2mKRIG4kGlDoV6iemLP6\n\t\t\t\t\t\tSEtWwENvyTZ9VwAGYNoZaEmAjl1eVGaQANlcpXGuTRTLNHFYE+aCa7vYJuxdeU/N\n\t\t\t\t\t\tZ+YEKF+K/tNlHmpEZ2x/tIv8PvDWgGsK+1FaCPoBrzZmKLo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wolvcoll.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.wolvcoll.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.wolvcoll.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.wolvcoll.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.wolvcoll.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.wolvcoll.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.wolvcoll.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.wolvcoll.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.wolvcoll.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wolvcoll.ac.uk"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "City of Wolverhampton College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTzCCAjegAwIBAgIUQ4d3Glz5yjW7FW9jd2mP9LsAUe8wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJDEiMCAGA1UEAxMZc2hpYmJvbGV0aC53b2x2Y29sbC5hYy51azAeFw0xNDA2\n\t\t\t\t\t\tMjQwOTA1MTdaFw0zNDA2MjQwOTA1MTdaMCQxIjAgBgNVBAMTGXNoaWJib2xldGgu\n\t\t\t\t\t\td29sdmNvbGwuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCl\n\t\t\t\t\t\tAWQo9/uMAecnAsdN9csAGTK2489RtQ7rJcRbozcr64BT1/w1iuh+RrWWqACgoNJP\n\t\t\t\t\t\taC2cGGm4DAEtguZlxv/EIm2YhKNQaDSgA472GPHRLslb2pRfNVJyFRfKJeVn2H/L\n\t\t\t\t\t\t/StgbnczUp1gj81bZpdT6LoT0kw6SBh42H4ktTQQcdchiLqapDdLl+mx/x6F+BuH\n\t\t\t\t\t\tHH6Pa4TwIKyu7FM7sTKek/Q4PLrLuHDFP7rg43lqjL2pQntsF4cNPewN+bcQujKn\n\t\t\t\t\t\t+aQ/sUzUtLsi0bAuTJeU0rPZgJtg5Y3XnmZTlHyVvyBODtQhXhU2OfYH2FWiEZmj\n\t\t\t\t\t\tD886Zakepq44z9wE19c5AgMBAAGjeTB3MFYGA1UdEQRPME2CGXNoaWJib2xldGgu\n\t\t\t\t\t\td29sdmNvbGwuYWMudWuGMGh0dHBzOi8vc2hpYmJvbGV0aC53b2x2Y29sbC5hYy51\n\t\t\t\t\t\tay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUEPnyUWWLLersRzyV9z/bHlXyz0Ew\n\t\t\t\t\t\tDQYJKoZIhvcNAQEFBQADggEBAJmDjexTbXsG8J5SYzXt8hda+nyrnlraOl6E6ql8\n\t\t\t\t\t\tyIazs9Tg2nKgLhlAalyERD712mwL+lSE+qHHFifdSO44YuOgVNJ0e+vWxISrhNpt\n\t\t\t\t\t\td59kjd1l8b1ZeQ3P507rDz2Uw+cA5YxkEVdlBrkb9fR26kPXDsXiz1P1DhHh/Qt0\n\t\t\t\t\t\t48PkIQdrwiSygWvNQGgMaB76XA3hqVyadpokVL/F1MFP2mKRIG4kGlDoV6iemLP6\n\t\t\t\t\t\tSEtWwENvyTZ9VwAGYNoZaEmAjl1eVGaQANlcpXGuTRTLNHFYE+aCa7vYJuxdeU/N\n\t\t\t\t\t\tZ+YEKF+K/tNlHmpEZ2x/tIv8PvDWgGsK+1FaCPoBrzZmKLo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "City of Wolverhampton College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wolvcoll.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "City of Wolverhampton College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://problem.math.su.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://problem.math.su.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://problem.math.su.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://problem.math.su.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://problem.math.su.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://problem.math.su.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://problem.math.su.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Kurssidor som riktar sig mot studenter utanf\u00f6r Matematiska institutionen."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Course pages dedicated to students residing outside of the Mathematical institution."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Externa kurssidor"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "External course pages"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://problem.math.su.se/Shibboleth.sso/WAYF/idp.it.su.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://problem.math.su.se/Shibboleth.sso/WAYF/idp.hig.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://problem.math.su.se/shibboleth"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "problem.math.su.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIJAKSK0oo3s8y6MA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEnByb2JsZW0ubWF0aC5zdS5zZTAeFw0xMzA1MjcxMjUwNDhaFw0yMzA1MjUx\nMjUwNDhaMB0xGzAZBgNVBAMTEnByb2JsZW0ubWF0aC5zdS5zZTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALDdkgq2IazhunksULC0l93MzAIL04t81kRg\nctcbk5Ytlp+KayUxevazYkQ+MMjNH1/DuAuYW2TBQ3C+aS0tBuRlwC3XrrKtu40I\nTcNYfwdvzDZ7ZTH81jKY8KDzMlCo6Lh5jkit6VHGanoamGIIQKm5JaXp12kOZAlw\nQozEjhzevlRQye1kS/BEEvQz2/lD7cbw1aayMgCNpsS41q45oei/WjFdRndK2AEa\n9zW+7C7EPw/RE2DeZSPv78FJ770AdUdeGrbPJY5DqQ101xz3T5s4RW6j7+tLswMM\nyE45EBHG1sJ/yw7fg3HGOvNUk30lwa/G+VWJ+KC3PgaLBGh7M/sCAwEAAaNnMGUw\nRAYDVR0RBD0wO4IScHJvYmxlbS5tYXRoLnN1LnNlhiVodHRwczovL3Byb2JsZW0u\nbWF0aC5zdS5zZS9zaGliYm9sZXRoMB0GA1UdDgQWBBRthQjSmK5vYAU2mFvUqVPI\nNIPN9TANBgkqhkiG9w0BAQUFAAOCAQEARp9dFh9cb3SigfGaKuUFdt8I356FHIom\nhQKk+5UlhWU13i0R+vs968VrT2V2A8t4RkEoASiTroegaqhISTGCnm82yX0sok43\nNLNFgjhZS2/V9heb/ui9TAmTuUa/tIHEypeSNwwSO54xdQtI5F7oI+6v479tyIKm\n4KlVSE1DqUTqJsei+jRYP000g8+Ooq69TEiSMnB9R+BSxW8iLTeiCjDVt2tkykF3\nu2jFiSjk4z1Jl6hxIqZfire7p7dzpvxXY/OnzKiG/4TBEc8xEMmSp/Huj6cPsUJt\nBYg6EHJWH+STzIe9LWWBS1ielXYFLLbSz38sMKEvtlZw5rnUbhXvhw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=problem.math.su.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://problem.math.su.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://problem.math.su.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://problem.math.su.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://problem.math.su.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://problem.math.su.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://problem.math.su.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://problem.math.su.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://problem.math.su.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://problem.math.su.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://problem.math.su.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.emplaw.co.uk/simplesaml/sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mike@juic3.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mike@juic3.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.emplaw.co.uk/simplesaml/sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-04-10T09:33:23Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Emplaw Online"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.emplaw.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Constantia Associates Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.emplaw.co.uk/simplesaml/module.php/saml/sp/saml2-logout.php/sp1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.emplaw.co.uk/simplesaml/module.php/saml/sp/saml2-logout.php/sp1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Online access to up to date employment law information and cases"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.emplaw.co.uk/sites/default/files/emplawlogo.png",
                    "lang": "en",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "298"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Emplaw Online"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDizCCAnOgAwIBAgIJANLzbWrFslBjMA0GCSqGSIb3DQEBCwUAMFwxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRMwEQYDVQQIDApTb21lLVN0YXRlMSEwHwYDVQQKDBhJbnRlcm5ldCBX\n\t\t\t\t\t\taWRnaXRzIFB0eSBMdGQxFTATBgNVBAMMDGVtcGxhdy5jby51azAeFw0xNTAzMjMx\n\t\t\t\t\t\tMDUxMjVaFw0yNTAzMjIxMDUxMjVaMFwxCzAJBgNVBAYTAkdCMRMwEQYDVQQIDApT\n\t\t\t\t\t\tb21lLVN0YXRlMSEwHwYDVQQKDBhJbnRlcm5ldCBXaWRnaXRzIFB0eSBMdGQxFTAT\n\t\t\t\t\t\tBgNVBAMMDGVtcGxhdy5jby51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAMg+PezNYDj4phkotRmP48BsQh6ZFTooomIUMAXBtjboftdWTSeyV+ro+z/l\n\t\t\t\t\t\tDeFMFXl2ocpuUYAfyLQO2khfiCHmjIVnM0YAdxth7ypZmLF7KbEH29b9S8eONfE6\n\t\t\t\t\t\t4rN8lJNDyucV6jQAhYoZYVKQ6eRjhxQcBWdpKt6vzzE4U6+TJE0EUhWfEVD83scJ\n\t\t\t\t\t\tfHC6TqgVYtrda8jwRqEUj9rzgYE9o/1WYmU+eMViN7oIb6wxobzw8UY9YgtKs9Hy\n\t\t\t\t\t\tRpWDcKHb0AdXdZ6KeuIvHW8CAn0lc7Fp+Qfnar2PDqz16UaZbO2TssgUZGhYf9f2\n\t\t\t\t\t\t0YlE/vI7uCFpIblGJYlBEdKqTmECAwEAAaNQME4wHQYDVR0OBBYEFNfjAuRajysE\n\t\t\t\t\t\t1apfQ+D3ud6NRm5DMB8GA1UdIwQYMBaAFNfjAuRajysE1apfQ+D3ud6NRm5DMAwG\n\t\t\t\t\t\tA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQELBQADggEBAEpPCOvsmiNjKzIz8dV2kf76\n\t\t\t\t\t\t5/LfcnGlNO/zs+trKABtgJEVu3erO+jsSgLmRgYZ+Kk/79dmmV5a2dPDVMSYZ8x0\n\t\t\t\t\t\tyJgai4uNYZpL6Ys7s4XV4UXm0wYfc2DslIM7Dm6xO9DL/wECpw03+5zkOUrmGSIG\n\t\t\t\t\t\tvOR4FuBfzELPdkMYPfK88lk4MrLPsWk54742Obu/cW6XGhH+1YLwb3RkpzqW/RLU\n\t\t\t\t\t\tQdkRmWoWVJ2sip3jvJq+JuFtJr2Y0Kps/vq9oSUK6SjS8hSU7vKIS+9OsZeJzHTz\n\t\t\t\t\t\tN0+As8bWQHWAY/vBGBv/lSY3DVItLlILfPqM8MH62/fiYaHD5D1l67w4hB2Mg70="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDizCCAnOgAwIBAgIJANLzbWrFslBjMA0GCSqGSIb3DQEBCwUAMFwxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRMwEQYDVQQIDApTb21lLVN0YXRlMSEwHwYDVQQKDBhJbnRlcm5ldCBX\n\t\t\t\t\t\taWRnaXRzIFB0eSBMdGQxFTATBgNVBAMMDGVtcGxhdy5jby51azAeFw0xNTAzMjMx\n\t\t\t\t\t\tMDUxMjVaFw0yNTAzMjIxMDUxMjVaMFwxCzAJBgNVBAYTAkdCMRMwEQYDVQQIDApT\n\t\t\t\t\t\tb21lLVN0YXRlMSEwHwYDVQQKDBhJbnRlcm5ldCBXaWRnaXRzIFB0eSBMdGQxFTAT\n\t\t\t\t\t\tBgNVBAMMDGVtcGxhdy5jby51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAMg+PezNYDj4phkotRmP48BsQh6ZFTooomIUMAXBtjboftdWTSeyV+ro+z/l\n\t\t\t\t\t\tDeFMFXl2ocpuUYAfyLQO2khfiCHmjIVnM0YAdxth7ypZmLF7KbEH29b9S8eONfE6\n\t\t\t\t\t\t4rN8lJNDyucV6jQAhYoZYVKQ6eRjhxQcBWdpKt6vzzE4U6+TJE0EUhWfEVD83scJ\n\t\t\t\t\t\tfHC6TqgVYtrda8jwRqEUj9rzgYE9o/1WYmU+eMViN7oIb6wxobzw8UY9YgtKs9Hy\n\t\t\t\t\t\tRpWDcKHb0AdXdZ6KeuIvHW8CAn0lc7Fp+Qfnar2PDqz16UaZbO2TssgUZGhYf9f2\n\t\t\t\t\t\t0YlE/vI7uCFpIblGJYlBEdKqTmECAwEAAaNQME4wHQYDVR0OBBYEFNfjAuRajysE\n\t\t\t\t\t\t1apfQ+D3ud6NRm5DMB8GA1UdIwQYMBaAFNfjAuRajysE1apfQ+D3ud6NRm5DMAwG\n\t\t\t\t\t\tA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQELBQADggEBAEpPCOvsmiNjKzIz8dV2kf76\n\t\t\t\t\t\t5/LfcnGlNO/zs+trKABtgJEVu3erO+jsSgLmRgYZ+Kk/79dmmV5a2dPDVMSYZ8x0\n\t\t\t\t\t\tyJgai4uNYZpL6Ys7s4XV4UXm0wYfc2DslIM7Dm6xO9DL/wECpw03+5zkOUrmGSIG\n\t\t\t\t\t\tvOR4FuBfzELPdkMYPfK88lk4MrLPsWk54742Obu/cW6XGhH+1YLwb3RkpzqW/RLU\n\t\t\t\t\t\tQdkRmWoWVJ2sip3jvJq+JuFtJr2Y0Kps/vq9oSUK6SjS8hSU7vKIS+9OsZeJzHTz\n\t\t\t\t\t\tN0+As8bWQHWAY/vBGBv/lSY3DVItLlILfPqM8MH62/fiYaHD5D1l67w4hB2Mg70="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.emplaw.co.uk/simplesaml/module.php/saml/sp/saml2-acs.php/sp1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.emplaw.co.uk/simplesaml/module.php/saml/sp/saml1-acs.php/sp1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.emplaw.co.uk/simplesaml/module.php/saml/sp/saml2-acs.php/sp1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.emplaw.co.uk/simplesaml/module.php/saml/sp/saml1-acs.php/sp1/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://test-sp.aco.net/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Federation Operator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:eduid@aco.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "eduID.at"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Federation Operator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:eduid@aco.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "eduID.at"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Federation Operator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:eduid@aco.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "eduID.at"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test-sp.aco.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2008-07-15T13:42:53Z",
            "registration_authority": "http://eduid.at",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ACOnet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ACOnet"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aco.net/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aco.net/?L=1"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ACOnet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ACOnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.eduid.at/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.eduid.at/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.eduid.at/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.eduid.at/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sp.eduid.at/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp.eduid.at/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://wiki.univie.ac.at/display/federation/SAML+Demo+SP"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ein SAML2 Service Provider, der allen eduID.at Teilnehmern zur Demonstration und f\u00fcr Tests zur Verf\u00fcgung steht."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "A demo Service Provider for the SAML2-based eduID.at Federation. Open to all eduID.at member institutions."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.aco.net/fileadmin/aconet/Logos/aconetlogo.gif",
                    "height": "94",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "195"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "eduID.at Demo Service"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "eduID.at Demo Service"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJAObaiwc63DWQMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD3Rlc3Qtc3AuYWNvLm5ldDAeFw0wODA3MDkxMTQ1NTVaFw0xODA3MDcxMTQ1\nNTVaMBoxGDAWBgNVBAMTD3Rlc3Qtc3AuYWNvLm5ldDCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBALZXEDbiffZnDnsWcJlVUBlaAyEycf+0Bjg/DjsQAz4l\nvG9poVFKlPjaQCQCyk56PXhN0ZuZZJEylHHfMrJvfM6bpylY/a+KFyeNi28acrlg\nu+BRx7uXg+wac0mfp9Z9nj93qQBP4iC7Lbv9AUDrHvp6ig/MF8P8sEb3VZRwwJDc\nx2fLuro/TueYcT0Xw3Y70vkjaAbkugjNE2pU3OL7TxgXx+qzsOmoPiWI61VgpSkm\npmxsN1bjiKJs1sqQ/K3pQ9mcR6Mb5STShcpKf6ZqmuUD53oPeWyB03vmi0AzCXeU\nuGftaM2iWwhaxLApEE6cgxctR2lc91sQtoCo0B1FIMkCAwEAAaNhMF8wPgYDVR0R\nBDcwNYIPdGVzdC1zcC5hY28ubmV0hiJodHRwczovL3Rlc3Qtc3AuYWNvLm5ldC9z\naGliYm9sZXRoMB0GA1UdDgQWBBTyPUKdsFFI3eqmI9OQsgaDw6e8fjANBgkqhkiG\n9w0BAQUFAAOCAQEAeD0OZAEjUr2RJFCbW820q0iG49x0jvL3lSvbYKaUY+4zthXj\n394fALks0blb7XceA857NfIXHn2NI9ZrHllmpTjc6IeD332c6NW8AevYjU+mwGuM\nejLfUgi137jrXaP7jlGSL85aFIWTGoBT6IZu+qiVo8qbWY5EH+3gSIQYCYpfKuaJ\n6EbpYsqZ1tEg6tfUGJK4Ly87HHBCRNwDV9/85yGt+puwvjsPeaXELsGOpTaA8lGJ\ni0o8V/egkPa0mbqghudG9cwZluJCJSWxvxv7yersHIdedRwZyv7vSGu4FI4g39Km\nvNzoGHMHg8pOo6cx9Arah88V+SEsBxtCh3V9Fg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.eduid.at/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp.eduid.at/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp.eduid.at/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "eduID.at Demo Service"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "eduID.at Demo Service"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Ein SAML2 Service Provider, der allen eduID.at Teilnehmern zur Demonstration und f\u00fcr Tests zur Verf\u00fcgung steht."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "A demo Service Provider for the SAML2-based eduID.at Federation. Open to all eduID.at member institutions."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganizationType",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://dev.keynote.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sole"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ssole@keynote.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shaun"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Shah"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ashah@mintel.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ameet"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dev.keynote.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-07-28T15:54:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Keynote Development"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.keynote.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Key Note Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGDzCCBPegAwIBAgIQJh9i1AJonsnAFcGwgs/cvzANBgkqhkiG9w0BAQUFADCB\n\t\t\t\t\t\ttTELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMR8wHQYDVQQL\n\t\t\t\t\t\tExZWZXJpU2lnbiBUcnVzdCBOZXR3b3JrMTswOQYDVQQLEzJUZXJtcyBvZiB1c2Ug\n\t\t\t\t\t\tYXQgaHR0cHM6Ly93d3cudmVyaXNpZ24uY29tL3JwYSAoYykxMDEvMC0GA1UEAxMm\n\t\t\t\t\t\tVmVyaVNpZ24gQ2xhc3MgMyBTZWN1cmUgU2VydmVyIENBIC0gRzMwHhcNMTIwNDE2\n\t\t\t\t\t\tMDAwMDAwWhcNMTgwNDE3MjM1OTU5WjCB+TELMAkGA1UEBhMCR0IxEjAQBgNVBAgT\n\t\t\t\t\t\tCU1pZGRsZXNleDEQMA4GA1UEBxQHSGFtcHRvbjERMA8GA1UEChQIS2V5IE5vdGUx\n\t\t\t\t\t\tETAPBgNVBAsUCEtleSBOb3RlMTUwMwYDVQQLFCxUZXJtcyBvZiB1c2UgYXQgd3d3\n\t\t\t\t\t\tLnZlcmlzaWduLmNvLnVrL3JwYSAoYykwNTEiMCAGA1UECxMZQXV0aGVudGljYXRl\n\t\t\t\t\t\tZCBieSBWZXJpU2lnbjEnMCUGA1UECxMeTWVtYmVyLCBWZXJpU2lnbiBUcnVzdCBO\n\t\t\t\t\t\tZXR3b3JrMRowGAYDVQQDFBF3d3cua2V5bm90ZS5jby51azCCASIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEBBQADggEPADCCAQoCggEBANjKlKP40hmfmHrQdPo2rI+zJUl9eMvL5qNzLgAN\n\t\t\t\t\t\tQnOgojsZFwpQ3UJxIcm8Od2eIWd1xJne5ijHaeTniBxeJOj2PfDVzFxuvPWXcMYs\n\t\t\t\t\t\twusvAOgEcSDjhe2Qk4hBY0dd1T0IvU+8zRK6I+lGfZGkP7kNc+jq6ATyxXB3ayb1\n\t\t\t\t\t\t1/3yCljsnj27CH5hrym8IA7MCOZhYFXux66LGhT0c4WpKICIGapM6NLDDRI+zqQO\n\t\t\t\t\t\tC7JUh/7bteC332DJlpp/hEedtcytwdznAsfuFYAqLW0m2C1+F0m42hRYRsdK/8BE\n\t\t\t\t\t\twZVvmVEtQ5nD0PhWJle+p5qY2vOsnCoux4w2d8vMnCVQWSECAwEAAaOCAdMwggHP\n\t\t\t\t\t\tMAkGA1UdEwQCMAAwCwYDVR0PBAQDAgWgMEUGA1UdHwQ+MDwwOqA4oDaGNGh0dHA6\n\t\t\t\t\t\tLy9TVlJTZWN1cmUtRzMtY3JsLnZlcmlzaWduLmNvbS9TVlJTZWN1cmVHMy5jcmww\n\t\t\t\t\t\tRgYDVR0gBD8wPTA7BgtghkgBhvhFAQcXAzAsMCoGCCsGAQUFBwIBFh5odHRwczov\n\t\t\t\t\t\tL3d3dy52ZXJpc2lnbi5jby51ay9ycGEwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsG\n\t\t\t\t\t\tAQUFBwMCMB8GA1UdIwQYMBaAFA1EXBZTRMGCfh0gqyX0AWPYvnmlMHYGCCsGAQUF\n\t\t\t\t\t\tBwEBBGowaDAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AudmVyaXNpZ24uY29tMEAG\n\t\t\t\t\t\tCCsGAQUFBzAChjRodHRwOi8vU1ZSU2VjdXJlLUczLWFpYS52ZXJpc2lnbi5jb20v\n\t\t\t\t\t\tU1ZSU2VjdXJlRzMuY2VyMG4GCCsGAQUFBwEMBGIwYKFeoFwwWjBYMFYWCWltYWdl\n\t\t\t\t\t\tL2dpZjAhMB8wBwYFKw4DAhoEFEtruSiWBgy70FI4mymsSweLIQUYMCYWJGh0dHA6\n\t\t\t\t\t\tLy9sb2dvLnZlcmlzaWduLmNvbS92c2xvZ28xLmdpZjANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAVwvsWtkpYSAGQkJ2TV0wfnFg+tMRCSu3nB4KEYCremLxItsnnGuyDLb8/EYT\n\t\t\t\t\t\tMfwdr26NKunr+50Ry85EwmAPeYbx6NY9kLb2s/XyujeGHQaDOQTXMRtXvEYoJ5vw\n\t\t\t\t\t\tlNqMPy5O1Ih3W4TJi+CeX2TVaX4PNS2PKv6GKfIKZC0aWP6ZSurvyBUoI5jaMcoj\n\t\t\t\t\t\t0/2IqQ9HIxlRdTEIXGuvPfCMzQmQ48RmLHw3ImTb91JkQM31/FwsiIidjWkkgq5M\n\t\t\t\t\t\t5z9CF7Rt++PysgVB2M6swP3qVegOAFnkHGvuQExRS3dSQK4wUYXwKUoeXKBfTE60\n\t\t\t\t\t\tiIcX2da2+HnwyJ4195yPUocmnA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGDzCCBPegAwIBAgIQJh9i1AJonsnAFcGwgs/cvzANBgkqhkiG9w0BAQUFADCB\n\t\t\t\t\t\ttTELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMR8wHQYDVQQL\n\t\t\t\t\t\tExZWZXJpU2lnbiBUcnVzdCBOZXR3b3JrMTswOQYDVQQLEzJUZXJtcyBvZiB1c2Ug\n\t\t\t\t\t\tYXQgaHR0cHM6Ly93d3cudmVyaXNpZ24uY29tL3JwYSAoYykxMDEvMC0GA1UEAxMm\n\t\t\t\t\t\tVmVyaVNpZ24gQ2xhc3MgMyBTZWN1cmUgU2VydmVyIENBIC0gRzMwHhcNMTIwNDE2\n\t\t\t\t\t\tMDAwMDAwWhcNMTgwNDE3MjM1OTU5WjCB+TELMAkGA1UEBhMCR0IxEjAQBgNVBAgT\n\t\t\t\t\t\tCU1pZGRsZXNleDEQMA4GA1UEBxQHSGFtcHRvbjERMA8GA1UEChQIS2V5IE5vdGUx\n\t\t\t\t\t\tETAPBgNVBAsUCEtleSBOb3RlMTUwMwYDVQQLFCxUZXJtcyBvZiB1c2UgYXQgd3d3\n\t\t\t\t\t\tLnZlcmlzaWduLmNvLnVrL3JwYSAoYykwNTEiMCAGA1UECxMZQXV0aGVudGljYXRl\n\t\t\t\t\t\tZCBieSBWZXJpU2lnbjEnMCUGA1UECxMeTWVtYmVyLCBWZXJpU2lnbiBUcnVzdCBO\n\t\t\t\t\t\tZXR3b3JrMRowGAYDVQQDFBF3d3cua2V5bm90ZS5jby51azCCASIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEBBQADggEPADCCAQoCggEBANjKlKP40hmfmHrQdPo2rI+zJUl9eMvL5qNzLgAN\n\t\t\t\t\t\tQnOgojsZFwpQ3UJxIcm8Od2eIWd1xJne5ijHaeTniBxeJOj2PfDVzFxuvPWXcMYs\n\t\t\t\t\t\twusvAOgEcSDjhe2Qk4hBY0dd1T0IvU+8zRK6I+lGfZGkP7kNc+jq6ATyxXB3ayb1\n\t\t\t\t\t\t1/3yCljsnj27CH5hrym8IA7MCOZhYFXux66LGhT0c4WpKICIGapM6NLDDRI+zqQO\n\t\t\t\t\t\tC7JUh/7bteC332DJlpp/hEedtcytwdznAsfuFYAqLW0m2C1+F0m42hRYRsdK/8BE\n\t\t\t\t\t\twZVvmVEtQ5nD0PhWJle+p5qY2vOsnCoux4w2d8vMnCVQWSECAwEAAaOCAdMwggHP\n\t\t\t\t\t\tMAkGA1UdEwQCMAAwCwYDVR0PBAQDAgWgMEUGA1UdHwQ+MDwwOqA4oDaGNGh0dHA6\n\t\t\t\t\t\tLy9TVlJTZWN1cmUtRzMtY3JsLnZlcmlzaWduLmNvbS9TVlJTZWN1cmVHMy5jcmww\n\t\t\t\t\t\tRgYDVR0gBD8wPTA7BgtghkgBhvhFAQcXAzAsMCoGCCsGAQUFBwIBFh5odHRwczov\n\t\t\t\t\t\tL3d3dy52ZXJpc2lnbi5jby51ay9ycGEwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsG\n\t\t\t\t\t\tAQUFBwMCMB8GA1UdIwQYMBaAFA1EXBZTRMGCfh0gqyX0AWPYvnmlMHYGCCsGAQUF\n\t\t\t\t\t\tBwEBBGowaDAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AudmVyaXNpZ24uY29tMEAG\n\t\t\t\t\t\tCCsGAQUFBzAChjRodHRwOi8vU1ZSU2VjdXJlLUczLWFpYS52ZXJpc2lnbi5jb20v\n\t\t\t\t\t\tU1ZSU2VjdXJlRzMuY2VyMG4GCCsGAQUFBwEMBGIwYKFeoFwwWjBYMFYWCWltYWdl\n\t\t\t\t\t\tL2dpZjAhMB8wBwYFKw4DAhoEFEtruSiWBgy70FI4mymsSweLIQUYMCYWJGh0dHA6\n\t\t\t\t\t\tLy9sb2dvLnZlcmlzaWduLmNvbS92c2xvZ28xLmdpZjANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAVwvsWtkpYSAGQkJ2TV0wfnFg+tMRCSu3nB4KEYCremLxItsnnGuyDLb8/EYT\n\t\t\t\t\t\tMfwdr26NKunr+50Ry85EwmAPeYbx6NY9kLb2s/XyujeGHQaDOQTXMRtXvEYoJ5vw\n\t\t\t\t\t\tlNqMPy5O1Ih3W4TJi+CeX2TVaX4PNS2PKv6GKfIKZC0aWP6ZSurvyBUoI5jaMcoj\n\t\t\t\t\t\t0/2IqQ9HIxlRdTEIXGuvPfCMzQmQ48RmLHw3ImTb91JkQM31/FwsiIidjWkkgq5M\n\t\t\t\t\t\t5z9CF7Rt++PysgVB2M6swP3qVegOAFnkHGvuQExRS3dSQK4wUYXwKUoeXKBfTE60\n\t\t\t\t\t\tiIcX2da2+HnwyJ4195yPUocmnA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://dev.keynote.co.uk/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dev.keynote.co.uk/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dev.keynote.co.uk/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dev.keynote.co.uk/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.utorauth.utoronto.ca/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wiseman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mike.wiseman@utoronto.ca"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fardy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul.fardy@utoronto.ca"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.utorauth.utoronto.ca/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://www.canarie.ca",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIVAKBtctYdDHOwvkS2Cae5mn6+SG12MA0GCSqGSIb3DQEB\nBQUAMCMxITAfBgNVBAMTGGlkcC51dG9yYXV0aC51dG9yb250by5jYTAeFw0xMDAy\nMTcwNDM2MzZaFw0zMDAyMTcwNDM2MzZaMCMxITAfBgNVBAMTGGlkcC51dG9yYXV0\naC51dG9yb250by5jYTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANsi\nlyIZHSDZPNT7GJAnB6sydHDoezYsO5k6OqQaY1iVJnx8dFkY+mdI5zwmUgDV3LKY\nM+vh/1v1tDx/5G6eVPckZPn6WobTd+GQgwUsXFRGZ5svkHSxQhAzBuc4ltFAFXPI\nJnbgD29oukIE3S6YCo7pQBORbbizsoHbwZ2pzk1u6iEbf7DuiPy8i8+CjdHHs3BS\nwXJ9cG7Yah9ouXK8g44Jy6KqoFKhPckKbZfJ2reojSAQEZm4hu6Rn38PRSAIFJFb\nHFZlqDpvFnLwQXkrB1bcoWoePPRjwkUPWqPjOkqBmTgSRlitKNUpnrQMjzckTaVX\n70r73+hA2L0YbWp2Xt0CAwEAAaN3MHUwVAYDVR0RBE0wS4IYaWRwLnV0b3JhdXRo\nLnV0b3JvbnRvLmNhhi9odHRwczovL2lkcC51dG9yYXV0aC51dG9yb250by5jYS9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUrp0AR4X36F4QukpWTPrl7SpIVLUwDQYJ\nKoZIhvcNAQEFBQADggEBAJl0Wi8qk8D02AaPu0XdqoQekjvmZFyi6rcoCKDzCKWd\njyuF+gqEPWIWg+Ee8zqVvx0XNXx6YqqU5WyXjp1vvcNTE33+kq8eCMGWHrpW+mwn\nFwMXexviS6z/TLsSMwTbbTb7G900iMl81B7++v9KkRzg5KSx3UILKr3t39hmf/nP\nv6q8Ut3UQ5EjnV5J+PTDePSSVhsauAqQgdXJk6e5D0Y6BOYQGKsncBvmmz3LRuEO\nJA6YHVtPjl1wNwGOMImUX4ZT0G0YAGrxx0VN7rU9RCGlLaasDFQCIuNrOOM94w6W\nx5P0oxvLtqiOA5Sbm0KW5p7Fpzig9Hm+7M5dxGJd0L0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utoronto.ca"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.utorauth.utoronto.ca:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.utorauth.utoronto.ca:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.utorauth.utoronto.ca/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.utorauth.utoronto.ca/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.utorauth.utoronto.ca/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.utorauth.utoronto.ca/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.utorauth.utoronto.ca/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.utorauth.utoronto.ca:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.utorauth.utoronto.ca:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utoronto.ca"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.utoronto.ca/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://sites.utoronto.ca/image/U-of-T-logo.png",
                    "lang": "en-ca",
                    "height": "93",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "255"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Toronto"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIVAKBtctYdDHOwvkS2Cae5mn6+SG12MA0GCSqGSIb3DQEB\nBQUAMCMxITAfBgNVBAMTGGlkcC51dG9yYXV0aC51dG9yb250by5jYTAeFw0xMDAy\nMTcwNDM2MzZaFw0zMDAyMTcwNDM2MzZaMCMxITAfBgNVBAMTGGlkcC51dG9yYXV0\naC51dG9yb250by5jYTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANsi\nlyIZHSDZPNT7GJAnB6sydHDoezYsO5k6OqQaY1iVJnx8dFkY+mdI5zwmUgDV3LKY\nM+vh/1v1tDx/5G6eVPckZPn6WobTd+GQgwUsXFRGZ5svkHSxQhAzBuc4ltFAFXPI\nJnbgD29oukIE3S6YCo7pQBORbbizsoHbwZ2pzk1u6iEbf7DuiPy8i8+CjdHHs3BS\nwXJ9cG7Yah9ouXK8g44Jy6KqoFKhPckKbZfJ2reojSAQEZm4hu6Rn38PRSAIFJFb\nHFZlqDpvFnLwQXkrB1bcoWoePPRjwkUPWqPjOkqBmTgSRlitKNUpnrQMjzckTaVX\n70r73+hA2L0YbWp2Xt0CAwEAAaN3MHUwVAYDVR0RBE0wS4IYaWRwLnV0b3JhdXRo\nLnV0b3JvbnRvLmNhhi9odHRwczovL2lkcC51dG9yYXV0aC51dG9yb250by5jYS9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUrp0AR4X36F4QukpWTPrl7SpIVLUwDQYJ\nKoZIhvcNAQEFBQADggEBAJl0Wi8qk8D02AaPu0XdqoQekjvmZFyi6rcoCKDzCKWd\njyuF+gqEPWIWg+Ee8zqVvx0XNXx6YqqU5WyXjp1vvcNTE33+kq8eCMGWHrpW+mwn\nFwMXexviS6z/TLsSMwTbbTb7G900iMl81B7++v9KkRzg5KSx3UILKr3t39hmf/nP\nv6q8Ut3UQ5EjnV5J+PTDePSSVhsauAqQgdXJk6e5D0Y6BOYQGKsncBvmmz3LRuEO\nJA6YHVtPjl1wNwGOMImUX4ZT0G0YAGrxx0VN7rU9RCGlLaasDFQCIuNrOOM94w6W\nx5P0oxvLtqiOA5Sbm0KW5p7Fpzig9Hm+7M5dxGJd0L0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Toronto"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utoronto.ca/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Toronto"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.northern.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.northern.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/northern.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/northern.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "northern.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Northern College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.northern.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://falcon-test.csi.cam.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:falcon-support@ucs.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Falcon Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:falcon-support@ucs.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Falcon Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://falcon-test.csi.cam.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-04-26T10:17:33Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Cambridge: Falcon CMS Test Site"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cam.ac.uk/cs/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Cambridge"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://falcon-test.csi.cam.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://falcon-test.csi.cam.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://falcon-test.csi.cam.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://falcon-test.csi.cam.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://falcon-test.csi.cam.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://falcon-test.csi.cam.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://falcon-test.csi.cam.ac.uk/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://falcon-test.csi.cam.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://falcon-test.csi.cam.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAOB8D/FajzX8MA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHd3dy1mYWxjb24uY3N4LmNhbS5hYy51azAeFw0xMDAxMTgxMTAwMDdaFw0y\n\t\t\t\t\t\tMDAxMTYxMTAwMDdaMCMxITAfBgNVBAMTGHd3dy1mYWxjb24uY3N4LmNhbS5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKpU2AuemKJSIeDmgjkZ\n\t\t\t\t\t\ttPgKaPPkM5CKu3QUHm5JzmtnG3UFMxbOumt6sxWWF72ceXQNPgBNGqFI/sFdaCIo\n\t\t\t\t\t\tHxZj+Z2i+k7/IVXhc4wjs72YUfrjvTMDhHHzndm3KkJS8imsIYQ8/bBnJEF93zVJ\n\t\t\t\t\t\tgPYTrX1C8JxqF/wfY/XCGbEqHgJtqDrSEvK+vLF7LaYI4oTotZOg/vhN7uwaEa7n\n\t\t\t\t\t\tGU2+bKuhcAL+rolEM6sbdrQAj3KarTafacfh9IiAclzyOQTA6pfjFWrucNIuWXc4\n\t\t\t\t\t\tYhaEPyOMubMsp+0eXZAwEPTJ61x+nQZd3UAf7Rm5v7agrzRAdqdwpnqb4yyprJlI\n\t\t\t\t\t\t+lkCAwEAAaNGMEQwIwYDVR0RBBwwGoIYd3d3LWZhbGNvbi5jc3guY2FtLmFjLnVr\n\t\t\t\t\t\tMB0GA1UdDgQWBBTz/ES/EvNaSsqqXUxLuIFc9YHi/TANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAAvFTJS2L6StZuqKA935AD3bBOHe5pg+LCF6ydHdTuyWEJYIWBRJ1WXsKMyaG\n\t\t\t\t\t\tyvdlX60XziJARq2UiYxt4yRjuGLAjQl9kNdrlqeb2AJFnA5E1Mt56FtzPiwu2zrC\n\t\t\t\t\t\tTQlklC4Xfie1Yaw2kEVO2vAoRfg9bgSBfyvFC4oR3vCery3Z687oCeQqDp7LPRcn\n\t\t\t\t\t\t+k5qQD8pout57IYzwyo7GPeVkYEPb3GO2KYmoENlDR/xah2VcsTZF7aIsMBFxaPv\n\t\t\t\t\t\tO+oqrQcnQXTviY9yWLbAlSrPPqGNYDxayVHn+zDSO4scLlOoqZJ8iC5NboNKqFyB\n\t\t\t\t\t\tRsenNm/aXp0wIU+jHVmi/GAPCQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://falcon-test.csi.cam.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://falcon-test.csi.cam.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://falcon-test.csi.cam.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://falcon-test.csi.cam.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://falcon-test.csi.cam.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://falcon-test.csi.cam.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://falcon-test.csi.cam.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://falcon-test.csi.cam.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://falcon-test.csi.cam.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://falcon-test.csi.cam.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.cssd.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cssd.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/cssd.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/cssd.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cssd.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Royal Central School of Speech and Drama"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cssd.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://wiki.idem.garrservices.it/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Staff"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem-staff@garr.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IDEM"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://wiki.idem.garrservices.it/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2016-02-29T15:26:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Wiki per la federazione IDEM erogato da GARR"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Wiki for the IDEM Federation provided by GARR"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.garr.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.garr.it/b/eng"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consortium GARR"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Consortium GARR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://wiki.idem.garrservices.it/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://wiki.idem.garrservices.it/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wiki.idem.garrservices.it/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wiki.idem.garrservices.it/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://wiki.idem.garrservices.it/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://wiki.idem.garrservices.it/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://wiki.idem.garrservices.it/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://wiki.idem.garrservices.it/GARR-AAI-fed/index.php/About_(EN)"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://wiki.idem.garrservices.it/GARR-AAI-fed/index.php/About_(IT)"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Wiki for IDEM Federation provided by GARR"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Wiki per la federazione IDEM erogato da GARR"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://wiki.idem.garrservices.it/GARR-AAI-fed/index.php/Privacy_Policy_(EN)"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://wiki.idem.garrservices.it/GARR-AAI-fed/index.php/Privacy_Policy_(IT)"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IDEM GARR AAI Wiki"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IDEM GARR AAI Wiki"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIJAKTzjRttnw28MA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\nBAMTGXdpa2kuaWRlbS5nYXJyc2VydmljZXMuaXQwHhcNMTYwMjI5MTM1NzI4WhcN\nMjYwMjI2MTM1NzI4WjAkMSIwIAYDVQQDExl3aWtpLmlkZW0uZ2FycnNlcnZpY2Vz\nLml0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtiuSi0XDOefR0d/R\nREPM2SbEEx01tgsDvfKTzMiS3d2Yz6icdKzrv2ilE5FuJ7c3cXlY87igjyvTCgH3\nXgX5ntltxtL7OrOgbJOzFnyqiPpnXjlxHyNZwN1hGlwPpvPfeDjRvmHP/XToeaWK\nFV6sic41MhFNpsSRbtGQ/tpI+dlKQ1aaltI4ddmIaCMmyBrUj1a4Uu2u5LECHL6d\ndcWeNH5jL8wbJ07bmYEPC9VKeuKP76325PwM+KaWZSDGDAJTZxbWAAio3Ig4UXcv\n5mzyn6UZlyR4asyg3DJ1lqIshYDSidBarihmI1q4I5XE7IT+0eyZBEPcMkZeSKvb\nK4szYwIDAQABo3UwczBSBgNVHREESzBJghl3aWtpLmlkZW0uZ2FycnNlcnZpY2Vz\nLml0hixodHRwczovL3dpa2kuaWRlbS5nYXJyc2VydmljZXMuaXQvc2hpYmJvbGV0\naDAdBgNVHQ4EFgQU3KghcsYg19GtNWdR8R7kNS5u2CkwDQYJKoZIhvcNAQEFBQAD\nggEBAHkrvUH347jbNT/ENdukjZhNJJACfx3TVESQMHYzDOvWzcY/sYlthDLx8W6k\nBWNiQj3YVH3+3okIumM65ciGkOdvXuMB57kicjt2czVIC8DsdQdsZcWOxwXD0QvU\nvjkolcS3OOJOCtqvHM9CD2F3TXnJyh7HmxmbcO+2OjM+wtujinlz2cOq+vdiYCfr\nDjHfs4IoDccg5qAXMfFpRA7YcPpnq302RNSRSQB9Ua1fu5tjpUfMiaEZpZAuJYjh\n2HX7QTpJMY99+nan1QBSY8XEZn69EZToLctNW/sgn+eD9+R8JPL0MtMwl5UwncVs\nkZgH+efgngYNisvrFmBVVu7k1/E="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wiki.idem.garrservices.it/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://wiki.idem.garrservices.it/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://wiki.idem.garrservices.it/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://wiki.idem.garrservices.it/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "IDEM GARR AAI Wiki"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "IDEM GARR AAI Wiki"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Wiki for IDEM Federation provided by GARR"
                },
                {
                  "lang": "it",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Wiki per la federazione IDEM erogato da GARR"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://e-localcourses.unibo.it",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cesia-sso-support@unibo.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://e-localcourses.unibo.it",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2014-02-17T11:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "E-LOCAL courses of languages and cultures provided by University of Bologna"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Corsi E-LOCAL di lingue e culture erogato da Universit\u00e0 di Bologna"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unibo.it"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unibo.it"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Bologna"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 di Bologna"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://e-localcourses.unibo.it/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://e-localcourses.unibo.it/mod/resource/view.php?id=291"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://e-localcourses.unibo.it/mod/resource/view.php?id=292"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Language and culture courses of Dutch, Finnish, Hungarian, Italian, Polish and Portuguese."
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Corsi di lingua e cultura finlandese, italiana, nederlandese, polacca, portoghese e ungherese."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://e-localcourses.unibo.it/mod/resource/view.php?id=289"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://e-localcourses.unibo.it/mod/resource/view.php?id=290"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "E-LOCAL courses of languages and cultures."
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Corsi E-LOCAL di lingue e culture."
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://e-localcourses.unibo.it/Shibboleth.sso/UniboAuth",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAJQYlu3GGLHwMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2UtbG9jYWxjb3Vyc2VzLnVuaWJvLml0MB4XDTEzMDkzMDE1MzU1NVoXDTE4\nMDkyOTE1MzU1NVowIjEgMB4GA1UEAxMXZS1sb2NhbGNvdXJzZXMudW5pYm8uaXQw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDAWEo6p5B59kOr233RKoan\nvSs7+6MP9DMeLgFE2IGbhiTtr8E9FAvCw2lWB1Xew5GHzQ1rVZl9DHQB3xYj3K1b\nvQ6ZTsgITqh65VJHtNguLWezB98rl8LkxPRP0iUH1BLfoL4Dg9BPm/PIxUCv0+Bf\nHl5G8aLzSrdTnrd7tAIw8aLsy0At/5v5ShlU8KcM4K5mqrCS7SSZ7micIp6IFQkH\nL6Ctqu8u9NznYvhEBmtz7N/z4CIk2yUTx7zjwPs68Ke79T/rAbvuAb8dTSwrgKDq\nMtTR9Romp57roAfS60NH8fVOs+wsGD/q36fV7Gd98SsP9nmHwf1z+dlt6VXSA+Px\nAgMBAAGjRTBDMCIGA1UdEQQbMBmCF2UtbG9jYWxjb3Vyc2VzLnVuaWJvLml0MB0G\nA1UdDgQWBBT+SDB/78eV3AEQ1vDdZeTY+VBHQDANBgkqhkiG9w0BAQUFAAOCAQEA\nhTIVSita3rHPnKHeMKo17BjlrAZWihiAqKQe8WYxlkH/84FC3ZX0Y9U5rP41bYEV\nAjWaF22S1/zbVIxexnYLSiClxRykeEF/wsvFlDmLWSNaPFU8lEwlRUWPg3QOQOX0\ncX4GWkWRbeqjJNk9glo03imCXd6b8YVFJS5TxWTSzpzRrNkS3RMGRGKNZENWbyI5\nbreUwiWdYuGgtTg4LZAjpb/ZygN0jF9b53lmKFpUEWXKblRluTcQQCss5Y8/Q82O\nXV33ikbzfFfZt6+Vl/jpXoforcFOpiiAbgKIsBnd95VtuBsBvRl+pzh3xdA2YQXS\nVrUi/sMWebysPZ53w+Pc5Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://e-localcourses.unibo.it/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": ">E-LOCAL courses of languages and cultures."
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Language and culture courses of Dutch, Finnish, Hungarian, Italian, Polish and Portuguese."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eppn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ac-w01.nordu.net/shibboleth",
    {
      "entity_id": "https://ac-w01.nordu.net/shibboleth",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ac-w01.nordu.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ac-w01.nordu.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ac-w01.nordu.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ac-w01.nordu.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ac-w01.nordu.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ac-w01.nordu.net/Shibboleth.sso/DS/nordu.net",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ac-w01.nordu.net/Shibboleth.sso/DS/nordu.net",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ac-w01.nordu.net/Shibboleth.sso/DS/nordu.net",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ac-w01.nordu.net/Shibboleth.sso/DS/nordu.net",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ac-w01.nordu.net/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ac-w01.nordu.net/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ac-w01.nordu.net/Shibboleth.sso/DS/kalmar2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ac-w01.nordu.net/Shibboleth.sso/DS/kalmar2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "4"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ac-w01.nordu.net/Shibboleth.sso/Login/feide",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ac-w01.nordu.net/Shibboleth.sso/DS/haka.funet.fi",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ac-w01.nordu.net/Shibboleth.sso/DS/haka.funet.fi",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "5"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ac-w01.nordu.net/Shibboleth.sso/Login/idp.funet.fi",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ac-w01.nordu.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAK6IEFZqeYNkMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGFjLXcwMS5ub3JkdS5uZXQwHhcNMTUxMTI1MTQzMTMxWhcNMjUxMTIyMTQz\nMTMxWjAbMRkwFwYDVQQDExBhYy13MDEubm9yZHUubmV0MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAm5n/c1jQxsE6ZLDCaLkxAzMkYAveKeF0uMosuZAm\nLbKK88nSMRvrM4XZWUxw4Y7Hhuy4CaI2ief6DEIeCvp1zL1akcRARLKR2dcZwhaI\nXk5ZmSk0nZFmfCx/Q1/1QkWRtlTWZN5QWjKYhMf8v6NWQUkPkzcnTn5JsFRC53XB\nZGm4PDxbsj4iHoR+fL78gqcZ/lNlWkico8dF1Gb5ECT7RoFLwYg3j9mJegEueZCd\nzI9xK4J8D1gCv98JhMFDnUuzOsUetKI+ztzgk2kvA4UUXSg5jNQmw4CXXvR4On9F\nzuyrlB7fxfHIUW4+msGDlSIcG4D9fkpgJVggYYfogslzTQIDAQABoz4wPDAbBgNV\nHREEFDASghBhYy13MDEubm9yZHUubmV0MB0GA1UdDgQWBBTSzNfSHtoiM3DkR1ki\nUjaoX4s3KzANBgkqhkiG9w0BAQUFAAOCAQEAkKma/1Q8c9Bfhya5ZjZeVoTD/q0m\nrM+K4C7a88+bEHyIAVi5iKXrGRqcYRxiOFJ90Bqrif5Lu1kXk//WfAoijVVO7LHR\nDstraFrFHnAk+Tqz4hgN7ttzgM63hR9uEe9M5euw00UQ1MTDX2EjUtB22T9m1IPn\nA9ToIGUpGX3izWzTLU+7h2do56ZxbVwH5c+NtQAGEIqDCEbtLvAaWu4XVor8Shj7\npdi0ryFf9fQWwe8aUhmC8BNl5KNnDMgo3ka39txGyo9bxjJHEHJDwiZNasMgHoCa\no53aOf7QIMq0SMHnBJXRznGwibXlXP0Wtbl2hpcO5QxiZHziD434b0eYqQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ac-w01.nordu.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ac-w01.nordu.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.barnsley.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.barnsley.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/barnsley.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/barnsley.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "barnsley.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Barnsley College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.barnsley.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://stats-qa.ukdataservice.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Noble"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Susan.Noble@manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Susan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Syrotiuk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nicholas.syrotiuk@jisc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nick"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://stats-qa.ukdataservice.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-03-06T10:10:02Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UK Data Service Dotstat Quality Assurance server"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://ukdataservice.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Essex"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://stats-qa.ukdataservice.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://stats-qa.ukdataservice.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://stats-qa.ukdataservice.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://stats-qa.ukdataservice.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://stats-qa.ukdataservice.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://stats-qa.ukdataservice.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://stats-qa.ukdataservice.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAPpH6NVGj1XdMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\n\t\t\t\t\t\tBAMTF2RhZG90c3dlYnN0LmVzc2V4LmFjLnVrMB4XDTE1MDIxMjE0NTQxM1oXDTI1\n\t\t\t\t\t\tMDIwOTE0NTQxM1owIjEgMB4GA1UEAxMXZGFkb3Rzd2Vic3QuZXNzZXguYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDsGGwsGqLlefqf9/trBWbE\n\t\t\t\t\t\txMSEW2OX4wNs+z2HTDqknWz3iMsiGiKwWCHWX1ZoQ/wtTNWm2ZrwJEoJaddI7Sz4\n\t\t\t\t\t\tGM2TA4P21HdYjzXrW1pjU0kiZSU+pxVXVK4PXvuUwB6kxBaKe308r6GBMHItLh7F\n\t\t\t\t\t\thGe9A2SvWgDBBlblyw+edNw4L8CebjXhqy9FjySpMYbSOf5EPgSZk65F0nJpAWNP\n\t\t\t\t\t\tVJGORlYolNR/ida5zT6nrNZNKkNONGJNecduaA4Gz8wpdh/130MFdkvxfcubPSA6\n\t\t\t\t\t\tzj/2gx1YSKiX21GFTwJ6IpbgfCEbva0AUoeqiUnDQeMj9tDRJsvig++n4IyXvgYb\n\t\t\t\t\t\tAgMBAAGjRTBDMCIGA1UdEQQbMBmCF2RhZG90c3dlYnN0LmVzc2V4LmFjLnVrMB0G\n\t\t\t\t\t\tA1UdDgQWBBS+yIbRvhlwfAoaYco+n9wYnqCH6TANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tW5xAKRmFGiobOWK3XSS7vVIdw53mxNeX8V7ktOPPZfc7btPc9+T72YPS5E+qEGyg\n\t\t\t\t\t\tGbyhL1KhZQl7TBeXVurcU8ZiSZcqhBKlW2e35OXh2ayt1s7dZI4FRwmlwnCWYrWV\n\t\t\t\t\t\t4L0omNrpUJehBBN8YocDnewHmOxgdwp8xEg+8sQwJGCOUgIEW7RqPz9Ac1jUQYeI\n\t\t\t\t\t\tlA45WldwBjDa9kEY+2RWISHZ1suZU3lZiSZuev8MT6OWGn5p7+Jg0Kp9DjZB/92L\n\t\t\t\t\t\t6W8wXxM6Bx2xperc3d0sbkT3cbAnZwz5BWQHhsGZjHjRY/NzVLGwXgvG5w3VfDby\n\t\t\t\t\t\tyMJeeTVd+zS0q0I6Z0aHYA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://stats-qa.ukdataservice.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://stats-qa.ukdataservice.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://stats-qa.ukdataservice.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://stats-qa.ukdataservice.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://stats-qa.ukdataservice.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://stats-qa.ukdataservice.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://saml.edusafe.qalab.geant.net",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "labedzki@man.poznan.pl"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "PSNC"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://saml.edusafe.qalab.geant.net",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2016-02-24T11:14:58Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "DeIC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://deic.dk"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Danish e-Infrastructure Cooperation"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://edusafe.psnc.pl/edusafe-portal/saml/LogoutServiceHTTPRedirectResponse",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Form\u00e5let er at g\u00f8re det nemt at forbinde til MDVPN via et softwarebaseret VPN."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The purpose is to provide an easy way to connect to MDVPN instances via a software-based VPN."
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "eduSAFE-MDVPN"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "eduSAFE-MDVPN"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://edusafe.psnc.pl/edusafe-portal/saml/SAMLAssertionConsumer",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Form\u00e5let er at g\u00f8re det nemt at forbinde til MDVPN via et softwarebaseret VPN."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The purpose is to provide an easy way to connect to MDVPN instances via a software-based VPN."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "eduSAFE-MDVPN"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "eduSAFE-MDVPN"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "http://adfs.knmi.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs.knmi.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-04-24T12:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/49e6eb397d84ccc1d02259930aa89567",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "KNMI"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "KNMI"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/knmi.png",
                    "height": "36",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "KNMI"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "KNMI"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "KNMI"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.surffederatie.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "KNMI"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://serviceadmin-test.company.ja.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jtag@ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "JANET TAG"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jtag@ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "JANET TAG"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://serviceadmin-test.company.ja.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-12-17T13:22:46Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Service Admin (test)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ja.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "JISC Collections and Janet Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://serviceadmin-test.company.ja.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://serviceadmin-test.company.ja.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://serviceadmin-test.company.ja.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://serviceadmin-test.company.ja.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://serviceadmin-test.company.ja.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://serviceadmin-test.company.ja.net/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://serviceadmin-test.company.ja.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4jCCAcqgAwIBAgIJAKyF+vahRReuMA0GCSqGSIb3DQEBBQUAMBQxEjAQBgNV\n\t\t\t\t\t\tBAMTCWhhcjAwMzkxODAeFw0wOTExMjAwODM4MTVaFw0xOTExMTgwODM4MTVaMBQx\n\t\t\t\t\t\tEjAQBgNVBAMTCWhhcjAwMzkxODCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAKyGnAXQpTnriKaVLhBxB2V01KEV7JFljb6JyCUgmPzhjozQV78Lt6wnrlVE\n\t\t\t\t\t\tPMJUFzx6MhVOOFdmoud9f4uEt3eLeNNBkXy6F1hLsK93MmEq7NycC9f+RTGkXuI9\n\t\t\t\t\t\tZZ6bHpCQg4cgLlo+e+oSmyFrqdwHkKXRxhx7sLDpmrBRt4WS1Yom/sf1roaj/HYJ\n\t\t\t\t\t\tI09jwKfl5mlFhWqHoprT6zHYZ/q4HIgo8CYFzRPTBYP2WoakD87P3UPpVZj6uLAz\n\t\t\t\t\t\td8LCuv1ZX2HJTHYrUyEM4tbqA2cv/CN8W6cgTkm5puZAMvPmFeNnoQlkBnUpH/oc\n\t\t\t\t\t\toGDmT026FyBGQ6yXva1uZVOX0xMCAwEAAaM3MDUwFAYDVR0RBA0wC4IJaGFyMDAz\n\t\t\t\t\t\tOTE4MB0GA1UdDgQWBBQST9Pog/haMAhYi8W9rY0cKz3XfjANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAERDcKAB+oNKMF14ys3MjR7NgPZzAnxNjyDizDMsPug9ZqfXKTfU1NFZx\n\t\t\t\t\t\tnx1ihIXHOBZgLU4RKLJSopHZ57V+HlOebXCckx/je1y4a30B0sIg3yk9ZZlMNcVI\n\t\t\t\t\t\tJWEIEGc6kkIhgQBMAtTaae+Yd1gqk4MQBQG08iDy9M3E4jp3BmgZbJL2lBYwCoRc\n\t\t\t\t\t\tU2soIdQNoQS5WDuqwDVXqOljUfijVZU9YRpjPDsXqDQDVO+7v/EbPxVtRThQChxY\n\t\t\t\t\t\tLwXeoQe6wBNtmeBEdm16Ik+PCxkgQlTCLythjkwmB+AjmqoW6Kp9bNfh7/Tlv/lM\n\t\t\t\t\t\tbYW9q2/JzwJW2LhAXTV1ev8D9e3peg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://serviceadmin-test.company.ja.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://serviceadmin-test.company.ja.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://serviceadmin-test.company.ja.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://serviceadmin-test.company.ja.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://serviceadmin-test.company.ja.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://serviceadmin-test.company.ja.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://serviceadmin-test.company.ja.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://serviceadmin-test.company.ja.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://serviceadmin-test.company.ja.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://serviceadmin-test.company.ja.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.ate.legion02.led.its.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.ate.legion02.led.its.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ate.legion02.led.its.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.ate.legion02.led.its.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ate.legion02.led.its.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ate.legion02.led.its.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ate.legion02.led.its.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.ate.legion02.led.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.ate.legion02.led.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "N\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Next generation of the administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.ate.legion02.led.its.umu.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok Legion02 ATE"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok Legion02 ATE"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.ate.legion02.led.its.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.ate.legion02.led.its.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIJAKu3ozzE2pLPMA0GCSqGSIb3DQEBBQUAMCoxKDAmBgNV\nBAMTH3d3dy5hdGUubGVnaW9uMDIubGVkLml0cy51bXUuc2UwHhcNMTQxMTI4MTQz\nNDEwWhcNMjQxMTI1MTQzNDEwWjAqMSgwJgYDVQQDEx93d3cuYXRlLmxlZ2lvbjAy\nLmxlZC5pdHMudW11LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n5b572lEk0A13LIJxScLWu81igNYPnUkUnVk/3C69kB9CxCXnNsqmj5kfhJjdmN77\nfpTVoHwnaSguN9nuDPB0QuJhT//c3wrNI7JjJDRSQRbyq5c7Mgz5hh2yzfOOrAZs\nXHGPjpk1z/XXYiWxqkHRPEOrBRs6AtM8NOyPrS68odgZ3a9X81jUacxnGs0O6ncf\nGGe4cREuESRRjnUNPmUw9/g1ZgnC8xQ+XQNT6XaGEnYcknwvubQqQLkZJ4ucOeCJ\nkPrDJUWNWqdM1iLK5zXtJoR9R5ny2D+oPM1bdcG1i9yl4OlNgw/6WAjKWTqQdv16\nPzN5TK8aSC04Nwbz3bPRkQIDAQABo30wezBaBgNVHREEUzBRgh93d3cuYXRlLmxl\nZ2lvbjAyLmxlZC5pdHMudW11LnNlhi5odHRwczovL3d3dy5hdGUubGVnaW9uMDIu\nbGVkLml0cy51bXUuc2UvZ3VpLXNwMB0GA1UdDgQWBBSA4AJyI8TCNBhV3a/7YQTa\nyVatvjANBgkqhkiG9w0BAQUFAAOCAQEAbdaLpz5gs2HSqbl84YbdAU2kB9cfduzl\nZISXkyA9fLTLnU6kD2rU+yMYDGwqvEpoM1Q6kEOB/EivhicipNhzMwQBSePNfKT5\nzY8CbqMQpy+C/VQKRGwROc91LRpOmyukx3ut8qE2GnfYHbiVGNbQAL++nKHIwDZL\nz5A7rSMSFPGWRTjG0xtGYvA3MFD0gGziE3GXsSS1nRsmDA3M8tFas5vEtwQwRln2\nB6LB28Xf4ZFA+za2fX/6nWvQdNnayPXmST0XzmzHY83N+33PBlzQc9x9osrbcbg1\ngi5C9LLZ+6+nXk1WlzdS3eJVAbYzfLrU8Y1Kw1Wx9oVTD/OqrYwWZQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.ate.legion02.led.its.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ate.legion02.led.its.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.ate.legion02.led.its.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ate.legion02.led.its.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ate.legion02.led.its.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ate.legion02.led.its.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ate.legion02.led.its.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.ate.legion02.led.its.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.ate.legion02.led.its.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.ate.legion02.led.its.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.yourstudentsunion.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.yourstudentsunion.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-11-19T13:50:13Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Gloucestershire Students Union"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.yourstudentsunion.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.yourstudentsunion.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.yourstudentsunion.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.yourstudentsunion.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.yourstudentsunion.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.yourstudentsunion.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.yourstudentsunion.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAN0Uxjm5stWsMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHllbGxvdy51a21zbC5uZXQwHhcNMTEwODI1MTEwMDIxWhcNMjEwODIyMTEw\n\t\t\t\t\t\tMDIxWjAbMRkwFwYDVQQDExB5ZWxsb3cudWttc2wubmV0MIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAtFMa6Gs4goG8AQMCG6E/ESnBnRXVA6U4twXZwojK\n\t\t\t\t\t\t6WTD6USmloihRaZ6v27J54vEIkIxkZuGfN6LW0e93gLFCyM+LHu7UdOBLmOANek0\n\t\t\t\t\t\thx1eN/x5FIa/+hB2mTkw2OFvNAvb7fYvVkEY/XrRFJHxgkjTgYndptXTfxhRAyhI\n\t\t\t\t\t\tMrXYHedowBnTSX5J5/tV5eyi/pnNYrqe9IUWqVfREe8nSqLGmjMqU4ge5B+OTLUh\n\t\t\t\t\t\taNyQTMstDSVFaZTy5wBNStWpLeJF0faXwdiX1oAJiMD2aM/djw9CeCkBx/UEMIjn\n\t\t\t\t\t\tIpu6ZDrsF7afIMdzaZqBtS71lRcgTRAXq9f07LIUI1CatwIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB5ZWxsb3cudWttc2wubmV0MB0GA1UdDgQWBBSYe9hob4wACE6/WbTT\n\t\t\t\t\t\tdaFXvasZxjANBgkqhkiG9w0BAQUFAAOCAQEAU5RF7k0a0SVdgUivXdgpJI549su7\n\t\t\t\t\t\tFGECVI177+zyWl9+TMNRIiIyvvfbZ2zoUVcXxLqTcDL7akaQ51u9v9u2QaJHx0Ex\n\t\t\t\t\t\twbjfuCVXmIghq/2Cuo1Tt48mEEwD9Jnqdtl37Ajqchd6CpmIh1Gr7k7zMQ6zARrv\n\t\t\t\t\t\t4lARD/ryWB8WoK7gy0LlV/AQaLukAudxHmtqqnabu546xoETvY0r9b/wug7D4uzs\n\t\t\t\t\t\trcyOEnW1CT29ftdLvhclQAr3NM5Vwd/a6r67Ng9yU77qlZmacQ9OV4tllf5Nd0gH\n\t\t\t\t\t\teWVjyrg/8qUvf9xyC0AokyN5upRH2FYmdGs2vtnL4cA+Vum/TRGgdvyEFA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.yourstudentsunion.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.yourstudentsunion.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.yourstudentsunion.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.yourstudentsunion.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.yourstudentsunion.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.yourstudentsunion.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.yourstudentsunion.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.yourstudentsunion.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.yourstudentsunion.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.yourstudentsunion.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.cdd.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cdd.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/cdd.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/cdd.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cdd.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Conservatoire for Dance and Drama"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cdd.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://projecteuclid.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ruddy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dwr4@cornell.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kim"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:EUCLID-TECH-L@cornell.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shinwoo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://projecteuclid.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-11-11T13:43:07Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Project Euclid"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://projecteuclid.org/about"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cornell University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://projecteuclid.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://projecteuclid.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://projecteuclid.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://projecteuclid.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://projecteuclid.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://projecteuclid.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://projecteuclid.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://projecteuclid.org/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://projecteuclid.org/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Project Euclid, an online publishing service for theoretical and applied mathematics and statistics."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Project Euclid"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNjCCAh6gAwIBAgIJANq1a2ZDBykIMA0GCSqGSIb3DQEBBQUAMDAxLjAsBgNV\n\t\t\t\t\t\tBAMTJXNmLWxpYi1hcHAtMDA4LnNlcnZlcmZhcm0uY29ybmVsbC5lZHUwHhcNMTMw\n\t\t\t\t\t\tNTMxMTUwNjIyWhcNMjMwNTI5MTUwNjIyWjAwMS4wLAYDVQQDEyVzZi1saWItYXBw\n\t\t\t\t\t\tLTAwOC5zZXJ2ZXJmYXJtLmNvcm5lbGwuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAs3Hxfw7oGscg+A30MSnTHdbuukajMhIlCtrm+bfsayPDApUE\n\t\t\t\t\t\tQLxW643U876lLNxMA5wmU0NV07gjj87yqv7ECGPLq95tIoTcTzI0MXLr8s3GTzwT\n\t\t\t\t\t\tM9N0LEWdp37CRH2kgvYA3Cf5Oba8FxpEDHgc6rzAc2LccucdpWvi8Zon9OLZuEsH\n\t\t\t\t\t\tqAjQlfIeuSB7YIe6z2/7VbZM9CcAb80cwYButlqMdIOcS7jBqofGq9YvovXJr7F0\n\t\t\t\t\t\tvEXJtiL7fW28Lmv2SHdS2mL/34ud2fj5CEDaXAzKWCiDR0L7a1qYNW7upxD+w6no\n\t\t\t\t\t\trDAYfWrO8E6mcXv1d8P1JKLzsaZKopsuHE3BtQIDAQABo1MwUTAwBgNVHREEKTAn\n\t\t\t\t\t\tgiVzZi1saWItYXBwLTAwOC5zZXJ2ZXJmYXJtLmNvcm5lbGwuZWR1MB0GA1UdDgQW\n\t\t\t\t\t\tBBSu8boXmoNWqSqD0y4uSmiE8p1EHzANBgkqhkiG9w0BAQUFAAOCAQEAQXOGXl4Y\n\t\t\t\t\t\tfTXnrJQuD1xaOmLgUkLpN4eq89OisGTsdefpvAJ1SD6QSaIj1UFchfQ6Qb4vK2Fp\n\t\t\t\t\t\tE1Ss6sZNU0rCE/C1EpQplAkQve8+IhQdIOQM7B/Yp4lHWd+3snJLF+fmIczVu9DB\n\t\t\t\t\t\todqQ2YbmpxPDBzZMRAIppajebSXLz2r65Uj8+cB28v4WhCt7v/T3M8w4h591pePO\n\t\t\t\t\t\txW2fpyIqGsGpuVRd2EOkYGmm7nqrAH9WGyUsRT1YHFY25mjgExVPYpah7eTsNYql\n\t\t\t\t\t\tfQHR5b61zSESkl8vo6eFRgzRnETr/fNIj08nhs3UCEfuYVy1yVKv2lHLzIvDTot/\n\t\t\t\t\t\tTyOzJ1GTj16SNA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://projecteuclid.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://projecteuclid.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://projecteuclid.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://projecteuclid.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://projecteuclid.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://projecteuclid.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Project Euclid"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Project Euclid, an online publishing service for theoretical and applied mathematics and statistics."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonScopedAffiliation",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonTargetedID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://meta.eduroam.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://meta.eduroam.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://meta.eduroam.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://meta.eduroam.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://meta.eduroam.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://meta.eduroam.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://meta.eduroam.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://meta.eduroam.se/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "meta.eduroam.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBTCCAe2gAwIBAgIJAPh6o9VnEARbMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD21ldGEuZWR1cm9hbS5zZTAeFw0xMTEwMDcxNDM5MDBaFw0yMTEwMDQxNDM5\nMDBaMBoxGDAWBgNVBAMTD21ldGEuZWR1cm9hbS5zZTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBANZ98HMQtCgIEsR8nwsnLFK0THbzS/mBg5RZLn6N72Ev\nLh1m/IjUEb6biqsRIaq3e377tABcvgD4UnCFi5yX6DQvwV6U46G4CJ6M4ilOAM01\nKWNhcX3JNUo2/vczWX4dSj3/u1uBc9DwqBdkCNeOBluzQuYJtIOd7bb3SBGomDbP\ncwwzk4RbUR4D/6i14+zLhivx6sFcFxLzZw3cyb8+bmlHwNdoyZYpXJpwXVLc1iFI\n650ZXw8jUNg7XZHqKEnnzIIjNmo3NwywBosLDUmksjNJlftvHBAVWo2lKgUffS/z\n8gfRUT10NBJGVasy84cm60R+scuvBLtIxxHezUJO2cMCAwEAAaNOMEwwKwYDVR0R\nBCQwIoIPbWV0YS5lZHVyb2FtLnNlhg9tZXRhLmVkdXJvYW0uc2UwHQYDVR0OBBYE\nFJdh5hCOYUWIC7Ftaflm0xXkfwaYMA0GCSqGSIb3DQEBBQUAA4IBAQAopSB0Jj6G\n7nHlsblCirgCvFwvIEoKxyBLCsdjhzG6YdwzPPAKEnHBsrx02CNesHe1i8ksTlRK\n8KUEmf+L2PG0LXZNeYO02W+3mr18MOxt0z6f4QIAp1tpsDJkoERuEVVQOcthRA/J\nJAF6/j66o21JsCuXnrPmjCVRS8xtxRIeJ7AitKIVQOcYVsHafw0QbHgz1t+uWI0U\n7OnL+DyOpCQ7eiqwdYOwcWjOoR/McIMzQ0oTIl03Gqe1aRzuOPkszANfNXhbWtKw\noc1+nqi2B03IRK/9s4QsOZVrcdczbrq97zE8pZcHVCzwgD9L3pWIYNY1WGE7qwTx\nVHwj8+XpYqMH"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=meta.eduroam.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "meta.eduroam.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBTCCAe2gAwIBAgIJAPh6o9VnEARbMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD21ldGEuZWR1cm9hbS5zZTAeFw0xMTEwMDcxNDM5MDBaFw0yMTEwMDQxNDM5\nMDBaMBoxGDAWBgNVBAMTD21ldGEuZWR1cm9hbS5zZTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBANZ98HMQtCgIEsR8nwsnLFK0THbzS/mBg5RZLn6N72Ev\nLh1m/IjUEb6biqsRIaq3e377tABcvgD4UnCFi5yX6DQvwV6U46G4CJ6M4ilOAM01\nKWNhcX3JNUo2/vczWX4dSj3/u1uBc9DwqBdkCNeOBluzQuYJtIOd7bb3SBGomDbP\ncwwzk4RbUR4D/6i14+zLhivx6sFcFxLzZw3cyb8+bmlHwNdoyZYpXJpwXVLc1iFI\n650ZXw8jUNg7XZHqKEnnzIIjNmo3NwywBosLDUmksjNJlftvHBAVWo2lKgUffS/z\n8gfRUT10NBJGVasy84cm60R+scuvBLtIxxHezUJO2cMCAwEAAaNOMEwwKwYDVR0R\nBCQwIoIPbWV0YS5lZHVyb2FtLnNlhg9tZXRhLmVkdXJvYW0uc2UwHQYDVR0OBBYE\nFJdh5hCOYUWIC7Ftaflm0xXkfwaYMA0GCSqGSIb3DQEBBQUAA4IBAQAopSB0Jj6G\n7nHlsblCirgCvFwvIEoKxyBLCsdjhzG6YdwzPPAKEnHBsrx02CNesHe1i8ksTlRK\n8KUEmf+L2PG0LXZNeYO02W+3mr18MOxt0z6f4QIAp1tpsDJkoERuEVVQOcthRA/J\nJAF6/j66o21JsCuXnrPmjCVRS8xtxRIeJ7AitKIVQOcYVsHafw0QbHgz1t+uWI0U\n7OnL+DyOpCQ7eiqwdYOwcWjOoR/McIMzQ0oTIl03Gqe1aRzuOPkszANfNXhbWtKw\noc1+nqi2B03IRK/9s4QsOZVrcdczbrq97zE8pZcHVCzwgD9L3pWIYNY1WGE7qwTx\nVHwj8+XpYqMH"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=meta.eduroam.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://meta.eduroam.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://meta.eduroam.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://meta.eduroam.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://meta.eduroam.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://meta.eduroam.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://meta.eduroam.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://meta.eduroam.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://meta.eduroam.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://meta.eduroam.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://meta.eduroam.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://play.smdb.kb.se",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:saml_admin@kaltura.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://play.smdb.kb.se",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SMDB Play"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://play.smdb.kb.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SMDB Play"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://play.smdb.kb.se/user/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Detta \u00e4r KBs play tj\u00e4nst"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is the National Library of Sweden's streaming service"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kungliga biblioteket play"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "National Library of Sweden play"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.smdb.kb.se/user/authenticate",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.brookes.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@brookes.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:obis-sysadmin@brookes.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OBIS Sysadmin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.brookes.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-05-24T15:34:16Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAJUaJYwXesdgxfeIuyhEEzVnxSpLMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBwxGjAYBgNVBAMTEWlkcC5icm9va2VzLmFjLnVrMB4XDTEyMTAyMzEwNTUz\n\t\t\t\t\t\tNFoXDTMyMTAyMzEwNTUzNFowHDEaMBgGA1UEAxMRaWRwLmJyb29rZXMuYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCWkInyc7OtvgQF9bYDoP1+\n\t\t\t\t\t\tDUiDKJBZBCzzK6soKUD6WGVcKUsqN9ACyKj/i0kYEMigaYZE3XSLYENrWxA+sPbd\n\t\t\t\t\t\tKW6V1ko3TDzmJF/COoCMXUHWsp5JK8HWO5NncY6ruapEYdkjBpUN0LKJBaQBvbz8\n\t\t\t\t\t\tteaQ6LXt7zFm67+9B2GCsRd7WO3snUVNtiD2/7Q6lfCl5MnCzDex0xRZwHkN358n\n\t\t\t\t\t\tF5kAMhl8+dX+O4hzMiCeMSxyh4exQoGE6kPUy4v/1v74EVmnhHZfmF0Wb05QIESL\n\t\t\t\t\t\t671BS0ztGBPPHmgmyfM3uwRYqp0kIiZRU+vSHMZn1w7pad42O+HDjW5CTbONEhNb\n\t\t\t\t\t\tAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEWlkcC5icm9va2VzLmFjLnVrhihodHRwczov\n\t\t\t\t\t\tL2lkcC5icm9va2VzLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBShqU0t\n\t\t\t\t\t\t7KfNrqRSbJXdLu1nKL5U9zANBgkqhkiG9w0BAQUFAAOCAQEALY66hUj/NgEuTmQB\n\t\t\t\t\t\t38jSG6Cy8Po8btADRxDq21TpoBoP0yqQRk/7dgB/9xa3kYDTJHrhA8FD1Piv+tDZ\n\t\t\t\t\t\tP8Nx/6hJwDn0GIIonx3Kxkn1PYmUsG8tQAmIBXGN+g1X/gjKcKrAPCyWqGzrqRuX\n\t\t\t\t\t\to8KO6F6oQ8P6q6XVkJVEEAus2dkzJg1BxLxbWR9h9rEH2UCjWrTAgCSi0nRaqpZk\n\t\t\t\t\t\ttx+h/tvZMJljItE3iOWjnxOagFweI1EUoGW1JCaTCl/MCB+jGG45W7JCWqSqI/CQ\n\t\t\t\t\t\tXY8id/1W4LtBx8ydd17dZx5v8SV8fXIsoO46FfPns3K/B104YQm2mqDyqvkHQMbq\n\t\t\t\t\t\tdoYQJw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brookes.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.brookes.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.brookes.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.brookes.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.brookes.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.brookes.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.brookes.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.brookes.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.brookes.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.brookes.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.brookes.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.brookes.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brookes.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAJUaJYwXesdgxfeIuyhEEzVnxSpLMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBwxGjAYBgNVBAMTEWlkcC5icm9va2VzLmFjLnVrMB4XDTEyMTAyMzEwNTUz\n\t\t\t\t\t\tNFoXDTMyMTAyMzEwNTUzNFowHDEaMBgGA1UEAxMRaWRwLmJyb29rZXMuYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCWkInyc7OtvgQF9bYDoP1+\n\t\t\t\t\t\tDUiDKJBZBCzzK6soKUD6WGVcKUsqN9ACyKj/i0kYEMigaYZE3XSLYENrWxA+sPbd\n\t\t\t\t\t\tKW6V1ko3TDzmJF/COoCMXUHWsp5JK8HWO5NncY6ruapEYdkjBpUN0LKJBaQBvbz8\n\t\t\t\t\t\tteaQ6LXt7zFm67+9B2GCsRd7WO3snUVNtiD2/7Q6lfCl5MnCzDex0xRZwHkN358n\n\t\t\t\t\t\tF5kAMhl8+dX+O4hzMiCeMSxyh4exQoGE6kPUy4v/1v74EVmnhHZfmF0Wb05QIESL\n\t\t\t\t\t\t671BS0ztGBPPHmgmyfM3uwRYqp0kIiZRU+vSHMZn1w7pad42O+HDjW5CTbONEhNb\n\t\t\t\t\t\tAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEWlkcC5icm9va2VzLmFjLnVrhihodHRwczov\n\t\t\t\t\t\tL2lkcC5icm9va2VzLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBShqU0t\n\t\t\t\t\t\t7KfNrqRSbJXdLu1nKL5U9zANBgkqhkiG9w0BAQUFAAOCAQEALY66hUj/NgEuTmQB\n\t\t\t\t\t\t38jSG6Cy8Po8btADRxDq21TpoBoP0yqQRk/7dgB/9xa3kYDTJHrhA8FD1Piv+tDZ\n\t\t\t\t\t\tP8Nx/6hJwDn0GIIonx3Kxkn1PYmUsG8tQAmIBXGN+g1X/gjKcKrAPCyWqGzrqRuX\n\t\t\t\t\t\to8KO6F6oQ8P6q6XVkJVEEAus2dkzJg1BxLxbWR9h9rEH2UCjWrTAgCSi0nRaqpZk\n\t\t\t\t\t\ttx+h/tvZMJljItE3iOWjnxOagFweI1EUoGW1JCaTCl/MCB+jGG45W7JCWqSqI/CQ\n\t\t\t\t\t\tXY8id/1W4LtBx8ydd17dZx5v8SV8fXIsoO46FfPns3K/B104YQm2mqDyqvkHQMbq\n\t\t\t\t\t\tdoYQJw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Oxford Brookes University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.brookes.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Oxford Brookes University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://openstack.hbit.sztaki.hu/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "H\u00e9der Mih\u00e1ly"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mihaly.heder@sztaki.mta.hu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "H\u00e9der Mih\u00e1ly"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mihaly.heder@sztaki.mta.hu"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "H\u00e9der Mih\u00e1ly"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mihaly.heder@sztaki.mta.hu"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://openstack.hbit.sztaki.hu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "sztaki"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-edugain"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "hexaa"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:geant:niif.hu:eduid.hu:entity-attributes:processing-info",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "hu",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://metadata.eduid.hu/registration_policy_1_0.txt"
              }
            ],
            "registration_instant": "2013-08-01T07:17:19.807Z",
            "registration_authority": "http://eduid.hu",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "MTA SZTAKI - Magyar Tudom\u00e1nyos Akad\u00e9mia Sz\u00e1m\u00edt\u00e1stechnikai \u00e9s Automatiz\u00e1l\u00e1si Kutat\u00f3int\u00e9zet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Computer and Automation Research Institute, Hungarian Academy of Sciences"
          }
        ],
        "organization_url": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://sztaki.hu/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://sztaki.hu/?en"
          }
        ],
        "organization_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "MTA SZTAKI - Magyar Tudom\u00e1nyos Akad\u00e9mia Sz\u00e1m\u00edt\u00e1stechnikai \u00e9s Automatiz\u00e1l\u00e1si Kutat\u00f3int\u00e9zet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Computer and Automation Research Institute, Hungarian Academy of Sciences"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://openstack.hbit.sztaki.hu/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://openstack.hbit.sztaki.hu/policy/SztakiHBITOpenStackPolicyEN.pdf"
                  },
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://openstack.hbit.sztaki.hu/policy/SztakiHBITOpenStackPolicyHU.pdf"
                  }
                ],
                "description": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Sztaki HBIT OpenStack"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Sztaki HBIT OpenStack"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://openstack.hbit.sztaki.hu/policy/SztakiHBITOpenStackPolicyEN.pdf"
                  },
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://openstack.hbit.sztaki.hu/policy/SztakiHBITOpenStackPolicyHU.pdf"
                  }
                ],
                "display_name": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sztaki HBIT OpenStack"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sztaki HBIT OpenStack"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "openstack.hbit.sztaki.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://openstack.hbit.sztaki.hu/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://openstack.hbit.sztaki.hu/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "hu",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Sztaki HBIT OpenStack"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Sztaki HBIT OpenStack"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonEntitlement",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.7",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://connect.uninett.no/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://connect.uninett.no/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://connect.uninett.no/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://connect.uninett.no/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect.uninett.no/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect.uninett.no/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "UNINETT E-Meeting Service"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "UNINETT E-Meeting Service (Adobe Connect Pro)"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://connect.uninett.no/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://connect.uninett.no/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://connect.uninett.no/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://connect.uninett.no/Shibboleth.sso/DS/kalmar2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "connect.uninett.no"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJANWZWC6gwE0uMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEmNvbm5lY3QudW5pbmV0dC5ubzAeFw0xMDA5MjIxNTEyNDhaFw0yMDA5MTkx\nNTEyNDhaMB0xGzAZBgNVBAMTEmNvbm5lY3QudW5pbmV0dC5ubzCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALIM0lNQWtE3FlIgrLpfToA8d1e76MsAngiz\nh0JVNK2mMRlnC1CJ1NccY+9Qx6plb99D/FFopE3DHMcFO3x22QAR78RF6qBnvblY\nK0z+kAgiQ2T7nT5SnKQHPfy1Ji+MEDLAuWJIDbFUaKrhm1MUa2qDB5X1mKDMifup\nbz+PCvzzGkOVUrNRFT9as6PL2hzl0wiNL5Y47aX+Bd/xgwHrIjB6WmYMFNG/GptI\n5sAlY4kh4+q1MS3y4ummGM17gRFI9hsTZ8XL0Vmah+llpXGI56qCom1S2u15/IiI\n4sEfUd137KsjnID24qhRBpx/yVt8VDMcSi2SI0ONTCDvyNUi8lECAwEAAaNAMD4w\nHQYDVR0RBBYwFIISY29ubmVjdC51bmluZXR0Lm5vMB0GA1UdDgQWBBQbibmqTOyh\ncscfToiKe/IbZYKwPDANBgkqhkiG9w0BAQUFAAOCAQEABMRM+2kFSrzMEW1BI7zX\n+4Ef+6Q8Yk/KmVc7w6P7Z2x4UdxrEIiK7O9/toGFO8j3iOGCYQ+KEbGtZ/E+BbDX\n4mQL+i3B1oS3PG84WNrgV26gHG0PTHn9yAD9gkFKNRG7QIyIlg1wgbO8zdht02vK\nQTyM4x8uqziirHV4zzOWDwVR2pZbkIMQ0pJWxbcGViFo/ZtdSiKzt8/hwcWR1DyG\n+Pi6oxtIm0md9BvlzGp9UxK6xDHFfZF4ZRQI4+nhT7bBCrBFW/8NGjlPCM9TIH7j\nao7+7w52jMiiBR55pJftvE13MdhRq7Gb/AfWu08CuCSJ5Ge2DV13OMm0vtlLjkPC\nJw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=connect.uninett.no"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "connect.uninett.no"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJANWZWC6gwE0uMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMTEmNvbm5lY3QudW5pbmV0dC5ubzAeFw0xMDA5MjIxNTEyNDhaFw0yMDA5MTkx\nNTEyNDhaMB0xGzAZBgNVBAMTEmNvbm5lY3QudW5pbmV0dC5ubzCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALIM0lNQWtE3FlIgrLpfToA8d1e76MsAngiz\nh0JVNK2mMRlnC1CJ1NccY+9Qx6plb99D/FFopE3DHMcFO3x22QAR78RF6qBnvblY\nK0z+kAgiQ2T7nT5SnKQHPfy1Ji+MEDLAuWJIDbFUaKrhm1MUa2qDB5X1mKDMifup\nbz+PCvzzGkOVUrNRFT9as6PL2hzl0wiNL5Y47aX+Bd/xgwHrIjB6WmYMFNG/GptI\n5sAlY4kh4+q1MS3y4ummGM17gRFI9hsTZ8XL0Vmah+llpXGI56qCom1S2u15/IiI\n4sEfUd137KsjnID24qhRBpx/yVt8VDMcSi2SI0ONTCDvyNUi8lECAwEAAaNAMD4w\nHQYDVR0RBBYwFIISY29ubmVjdC51bmluZXR0Lm5vMB0GA1UdDgQWBBQbibmqTOyh\ncscfToiKe/IbZYKwPDANBgkqhkiG9w0BAQUFAAOCAQEABMRM+2kFSrzMEW1BI7zX\n+4Ef+6Q8Yk/KmVc7w6P7Z2x4UdxrEIiK7O9/toGFO8j3iOGCYQ+KEbGtZ/E+BbDX\n4mQL+i3B1oS3PG84WNrgV26gHG0PTHn9yAD9gkFKNRG7QIyIlg1wgbO8zdht02vK\nQTyM4x8uqziirHV4zzOWDwVR2pZbkIMQ0pJWxbcGViFo/ZtdSiKzt8/hwcWR1DyG\n+Pi6oxtIm0md9BvlzGp9UxK6xDHFfZF4ZRQI4+nhT7bBCrBFW/8NGjlPCM9TIH7j\nao7+7w52jMiiBR55pJftvE13MdhRq7Gb/AfWu08CuCSJ5Ge2DV13OMm0vtlLjkPC\nJw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=connect.uninett.no"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://connect.uninett.no/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://connect.uninett.no/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect.uninett.no/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect.uninett.no/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://connect.uninett.no/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://connect.uninett.no/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://connect.uninett.no/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://connect.uninett.no/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://connect.uninett.no/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://connect.uninett.no/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cerbere2.mines-douai.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "net.supervision@mines-douai.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cerbere2.mines-douai.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-10-03T09:42:09Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cerbere2.mines-douai.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cerbere2.mines-douai.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cerbere2.mines-douai.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mines-douai.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.mines-douai.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mines Douai"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mines Douai"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAPf+z/Alo2UGcIQMpD8+yoRE9DjEMA0GCSqGSIb3DQEB\nBQUAMCIxIDAeBgNVBAMTF2NlcmJlcmUyLm1pbmVzLWRvdWFpLmZyMB4XDTEzMDkz\nMDEyMTA0N1oXDTMzMDkzMDEyMTA0N1owIjEgMB4GA1UEAxMXY2VyYmVyZTIubWlu\nZXMtZG91YWkuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCsehUd\nQZAcFM8YQRAuQ4MSbuE5yrEu7ZpH8ICDmKMlVudlEWSLSkCZqrbtNYOev8gdHQTh\nOvKd5IzIph5TaRjY1qQI5v2ud/ov+Xk0JLWkYWnh2wMIQ07LoQ66zQqHxVbfq6lR\nlNtaHXhcPNPp/61j4OOoHNbztglqpAeVnkgUqMksnDofsjVsVMYG+9naGfwHKJlH\nI9HW7aUEvYYl/mUKrHbu9+QWpLsJukiJEF6hyRgijs/kr2pm0pBB4djy1NTgrqfz\nqjYmCzxtkbogHsOs0KGdoMg6R5PmHojtQ00beeKC8/hfHP+sU3wnNO+Hb14B/NLB\nveexLjO3AQpMtMY5AgMBAAGjdTBzMFIGA1UdEQRLMEmCF2NlcmJlcmUyLm1pbmVz\nLWRvdWFpLmZyhi5odHRwczovL2NlcmJlcmUyLm1pbmVzLWRvdWFpLmZyL2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBTHtKE6G3SkaEo+yuSQU4KTB9wxkDANBgkqhkiG\n9w0BAQUFAAOCAQEAqXrF4OYsvzcJ6djLo7hq52yqhYJtEdSGJkJ4n7CKX4WrHs5M\nYwWM3B6qbIjni0+cel8TJTCPG94ZZZOKZIPRv6eS2j77sRgnsht+mYpl9o4+zjrE\nCPVr99SlBCSuArEnnqDe26EJyV5M0fALwgHaBTPUlHhObgUuPuzlQQGEZKpoSlGT\nHx5ewqQ+m/jii2h1IOzex/1uFA3euE8trn5LMmNZpvQ24yRBCVQ1LyTmmdTkNeHk\nGiluYTYk7G0sXbJWur7gK8jpHdojNfR2SUay9Z2lAllZ2V/cwxVOgOMgaFkaHAq1\n1Zj4drFJWcGthEvZ8uVYsc6wJoIy1fbrkBcMng=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mines Douai"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mines-douai.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Mines Douai"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://federation.bsigroup.com/oa/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rab"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Yaqub.Rab@bsigroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Yaqub"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rab"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Yaqub.Rab@bsigroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Yaqub"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federation.bsigroup.com/oa/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-05-02T13:31:55Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "British Standards Institution subscription services"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bsigroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "British Standards Institution"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Access to the British Standards Institution's online standards subscription services"
                  }
                ],
                "logo": [
                  {
                    "text": "https://federationsupportdata.bsigroup.com/logo_116x73.png",
                    "height": "73",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "116"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "British Standards Institution subscription services"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFITCCBAmgAwIBAgIJAOUhlNL9S5KmMA0GCSqGSIb3DQEBBQUAMIG7MQswCQYD\n\t\t\t\t\t\tVQQGEwJVSzERMA8GA1UECBMIQ2hpc3dpY2sxDzANBgNVBAcTBkxvbmRvbjEmMCQG\n\t\t\t\t\t\tA1UEChMdQnJpdGlzaCBTdGFuZGFyZHMgSW5zdGl0dXRpb24xETAPBgNVBAsTCEdy\n\t\t\t\t\t\tb3VwIElUMSAwHgYDVQQDExdmZWRlcmF0aW9uLmJzaWdyb3VwLmNvbTErMCkGCSqG\n\t\t\t\t\t\tSIb3DQEJARYcbWFyay5vJ3N1bGxpdmFuQGJzaWdyb3VwLmNvbTAeFw0xNDEwMTUx\n\t\t\t\t\t\tMzQ2MTVaFw0yNDEwMTIxMzQ2MTVaMIG7MQswCQYDVQQGEwJVSzERMA8GA1UECBMI\n\t\t\t\t\t\tQ2hpc3dpY2sxDzANBgNVBAcTBkxvbmRvbjEmMCQGA1UEChMdQnJpdGlzaCBTdGFu\n\t\t\t\t\t\tZGFyZHMgSW5zdGl0dXRpb24xETAPBgNVBAsTCEdyb3VwIElUMSAwHgYDVQQDExdm\n\t\t\t\t\t\tZWRlcmF0aW9uLmJzaWdyb3VwLmNvbTErMCkGCSqGSIb3DQEJARYcbWFyay5vJ3N1\n\t\t\t\t\t\tbGxpdmFuQGJzaWdyb3VwLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAMEYRpNo2uI1Rt7yykpMc66SqN16ona2qZihqSkhIVKOEWgiQ7UaF9W1lOeX\n\t\t\t\t\t\tpByClRBzQkgSdOc6bJ+A+YCR4kzbkXeV96fawhhiZKeYwHgXoEq9Tg7TCkLFxs97\n\t\t\t\t\t\tZZXUE8IJsundnXfOJe/E4WuFFXNqxI7dLsjClIKbpweGH8/P0dpq2B54BHGlsjeQ\n\t\t\t\t\t\tWg2uPlt01VO9r/9VTxk/NzkomwdtbuKtKROkLIa30mEOhR+ZnsTb50hqOpBWWtia\n\t\t\t\t\t\tQIPJlCtQ2KsnLzUCEN+Ud/CuMkNpw7mv/J0L3KYb3tktfj/ehzusXPtuEOExlRdS\n\t\t\t\t\t\tC+nq4myT7nWaTt1wyi9vxYcmIiUCAwEAAaOCASQwggEgMB0GA1UdDgQWBBRALFY3\n\t\t\t\t\t\tlIzStlyzGgxzFb/uCruPIDCB8AYDVR0jBIHoMIHlgBRALFY3lIzStlyzGgxzFb/u\n\t\t\t\t\t\tCruPIKGBwaSBvjCBuzELMAkGA1UEBhMCVUsxETAPBgNVBAgTCENoaXN3aWNrMQ8w\n\t\t\t\t\t\tDQYDVQQHEwZMb25kb24xJjAkBgNVBAoTHUJyaXRpc2ggU3RhbmRhcmRzIEluc3Rp\n\t\t\t\t\t\tdHV0aW9uMREwDwYDVQQLEwhHcm91cCBJVDEgMB4GA1UEAxMXZmVkZXJhdGlvbi5i\n\t\t\t\t\t\tc2lncm91cC5jb20xKzApBgkqhkiG9w0BCQEWHG1hcmsubydzdWxsaXZhbkBic2ln\n\t\t\t\t\t\tcm91cC5jb22CCQDlIZTS/UuSpjAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUA\n\t\t\t\t\t\tA4IBAQAaFsGT0hV9hZTchsFy4jMxCGd3XA0efbnkn95k1epRtJz4/Tk604MZ7NTa\n\t\t\t\t\t\tXuAZEuqvyi3gxW2xSPFYg9kIjq6E00QpxqPxkytJmut28Nr7pi6TIDXcyBn/eWg1\n\t\t\t\t\t\t9gXpvcypeEQTS8LIioyB2ipfK5Zbz7hW8NMzXdRV7sqRmH7d8v9BB46+X5SHkTab\n\t\t\t\t\t\t84iL5r/Iivv75c/AiB2a6SsaRNNYUrlNTVrQPAlMNaYhXL9YJZ7cdzNfSYh6X/Ob\n\t\t\t\t\t\tfLfVi10Ulv83wbOU5XAYHtsEhnOQQooohsrKEKcRDC0pkUuiOpvgloC4HxRmVrsZ\n\t\t\t\t\t\tnQzraqnKpsGJ8Pc9j4fEJesIGB0J"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://federation.bsigroup.com/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://federation.bsigroup.com/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.bsigroup.com/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://federation.bsigroup.com/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.uel.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uel.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/uel.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/uel.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uel.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of East London"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uel.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://student.utb.uppfoljning.ladok.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://student.utb.uppfoljning.ladok.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.utb.uppfoljning.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.utb.uppfoljning.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.utb.uppfoljning.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.utb.uppfoljning.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.utb.uppfoljning.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://student.utb.uppfoljning.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://student.utb.uppfoljning.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://student.utb.uppfoljning.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok student.utb.uppfoljning.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok student.utb.uppfoljning.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://student.utb.uppfoljning.ladok.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "student.utb.uppfoljning.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkCgAwIBAgIJANRIJvqprHNXMA0GCSqGSIb3DQEBCwUAMCsxKTAnBgNV\nBAMTIHN0dWRlbnQudXRiLnVwcGZvbGpuaW5nLmxhZG9rLnNlMB4XDTE2MDMxODA4\nMzgzOVoXDTI2MDMxNjA4MzgzOVowKzEpMCcGA1UEAxMgc3R1ZGVudC51dGIudXBw\nZm9sam5pbmcubGFkb2suc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQDHjfupZnJ8UUpOMpVTJcaliULDj1v+XeZ5zYmKe4Ufl9py/S7akmkq7PFoKUzn\nkBgi3XLBRfGfQPhupfCTnSID4j/BRRQTyfkuVOWbuvFLYUxaBkm5M4KLzr5GZEID\nj1EUiUoLBjksFJ5HC40H14psoAaRqwD53XoFJOjXd7ipCNeH3JgGz/C91ERzauCB\n9DYUZZfc8PB194uHm3EwwG6w8VGmxWaTNi0C0YWnQXs77nFlx86JK49G5j8Mib8h\nSrwyQ8nYoMkBgxhymh1IA5G1aKgyWabw7bqoKrelvus+ja4Y39yNdPiGmPSk27zo\nyoz05SaEnjTf2yCBvC7NELUVAgMBAAGjfzB9MFwGA1UdEQRVMFOCIHN0dWRlbnQu\ndXRiLnVwcGZvbGpuaW5nLmxhZG9rLnNlhi9odHRwczovL3N0dWRlbnQudXRiLnVw\ncGZvbGpuaW5nLmxhZG9rLnNlL2d1aS1zcDAdBgNVHQ4EFgQUwD9J7Pnqr8ElOe0f\nxNrNd+M8HckwDQYJKoZIhvcNAQELBQADggEBAJBrD9xcMsYcgBJfiAZpezzwVHbv\nE/27kqZ22MxR+r3JljGfejLsjC3G8Tjn8RQgpUYpPV/OyX4WkYMHL+4eWM4Z0gpD\nVYmcaCdX0LbxYikDlaSWLhH8sDBKdleFg+NFd0pP1WX/iOTJX40IP8yyliwhGBfy\nOvsSj/YrtegFw8ldfmiM+GTsFBrVYvOMgrnN1wxQA3U0kjAnc+Ca8LIAYRnRuqHY\nhHgTDaGq27tcqC99MT5eOQBGn+C/rX8NYo7aoaYRA3bQiBpvTiwVwMxitp9L4gtG\nERSUoBLzl0s9hzeUVctbKwHWqVcKqz7KWX+X7Zu/1Sh7pmJTUUwgoChDnXc="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=student.utb.uppfoljning.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.utb.uppfoljning.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.utb.uppfoljning.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.utb.uppfoljning.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.utb.uppfoljning.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.utb.uppfoljning.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.utb.uppfoljning.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://student.utb.uppfoljning.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://student.utb.uppfoljning.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://student.utb.uppfoljning.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3edit.its.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3edit.its.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3edit.its.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3edit.its.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3edit.its.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3edit.its.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3edit.its.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3edit.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3edit.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3edit"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3edit"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3edit.its.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3edit.its.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAOUQv+esHSQiMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\nBAMTFWxhZG9rM2VkaXQuaXRzLnVtdS5zZTAeFw0xNjA0MjkxMTI3MzVaFw0yNjA0\nMjcxMTI3MzVaMCAxHjAcBgNVBAMTFWxhZG9rM2VkaXQuaXRzLnVtdS5zZTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANoK0uyU7Kx91zBNTX4IU/qh7S0q\nP5CRW5lEDZmwjJRBsrIuYjumAW4h42iwK+zGgJ5vvqZ3wG8GfTejV7Gm5/v596/T\nvFhzpdvvho54sASGPID0jVwUnFd9XpB1cKxmdquj7CWxQmWnTTVdPfmeqYjulhOd\nJbvW1JSYExY2g21sDgMZlkN4eWA8tuVYruX6GzT7Xg1VEY5TXU3yInObiSOJDqUA\n3XqaTK0DzIhbsjTqt1IhEq8cSi6wpXpMe/ei9GosZ7sq4eGjzq1dPuZMQzBrr3K4\nzLWero4WKuGp+GdcoZIVYCGX4ESoN+fo4mtdfuyAmUw5Xhb0I9B0wgenj9UCAwEA\nAaNpMGcwRgYDVR0RBD8wPYIVbGFkb2szZWRpdC5pdHMudW11LnNlhiRodHRwczov\nL2xhZG9rM2VkaXQuaXRzLnVtdS5zZS9ndWktc3AwHQYDVR0OBBYEFNL5KblA3k+z\nvJW5lobq0Tgt918hMA0GCSqGSIb3DQEBBQUAA4IBAQBdsW3bVxKIfPKNkIEtkdXH\ngTiagL9DaBXpWLqBzr7qflPQvcIZtNjjmw+y34UI5j13UVLdeHJ7+Iutu0tJp/PI\nN8yzVlULCkm9DvuPRPIODEpA8VQZaNzI+90wy2p1XRw09h1s9O9hnMKkpBDn9f/m\nQEIBH/cBaJdemajGeYDMrYOZYXBGqbPonnsbdUMBpcqMsUNvwCTI4CIF6hjDN+oK\nOtxy3VC+n5I53dv05k5OFDXedHiS3cv3HzaAo9+GbahNOp22lIoPSg79bTfM+n2s\naYnmCVGoNUbA+6Va0n9luhsqnA1TyI9HPOIbtbvAQ8kvU4ALw31YPGAxvzO1majX"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3edit.its.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3edit.its.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3edit.its.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3edit.its.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3edit.its.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3edit.its.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3edit.its.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3edit.its.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3edit.its.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3edit.its.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sp.tshhosting.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ts.cts.emea@thomson.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "European Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:websupp@thomsonreuters.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.tshhosting.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2008-07-14T10:17:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Thomson Scientific Inc: Thomson Reuters"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.thomsonreuters.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Thomson Scientific Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.isiknowledge.com/",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.webofknowledge.com/",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://admin-router.webofknowledge.com/",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Explore literature in the sciences, social sciences, arts and humanities and publish bibliographies."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.myendnoteweb.com/Download/logos/tr-wok-logo.png",
                    "height": "84",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "292"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Thomson Reuters SP (Web of Knowledge & EndNote Web)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF7jCCBNagAwIBAgIQH5TpeUp+Ukx0gMOWeqLCZDANBgkqhkiG9w0BAQUFADCB\n\t\t\t\t\t\ttTELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMR8wHQYDVQQL\n\t\t\t\t\t\tExZWZXJpU2lnbiBUcnVzdCBOZXR3b3JrMTswOQYDVQQLEzJUZXJtcyBvZiB1c2Ug\n\t\t\t\t\t\tYXQgaHR0cHM6Ly93d3cudmVyaXNpZ24uY29tL3JwYSAoYykxMDEvMC0GA1UEAxMm\n\t\t\t\t\t\tVmVyaVNpZ24gQ2xhc3MgMyBTZWN1cmUgU2VydmVyIENBIC0gRzMwHhcNMTIwNjIy\n\t\t\t\t\t\tMDAwMDAwWhcNMTYwNzExMjM1OTU5WjCB2jELMAkGA1UEBhMCVVMxFDASBgNVBAgT\n\t\t\t\t\t\tC0Nvbm5lY3RpY3V0MRMwEQYDVQQHFApFYXN0IEhhdmVuMTAwLgYDVQQKFCdUaG9t\n\t\t\t\t\t\tc29uIFJldXRlcnMgKFRheCAmIEFjY291bnRpbmcpIEluYy4xGzAZBgNVBAsUElRo\n\t\t\t\t\t\tb21zb24gU2NpZW50aWZpYzEzMDEGA1UECxQqVGVybXMgb2YgdXNlIGF0IHd3dy52\n\t\t\t\t\t\tZXJpc2lnbi5jb20vcnBhIChjKTA1MRwwGgYDVQQDFBNzaGliLnRzaGhvc3Rpbmcu\n\t\t\t\t\t\tY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAyW3478pCuAxKLWVx\n\t\t\t\t\t\tn6RDCOsnRHN4GP9Z10GWhuE9CTCe+Z95sfeMhwwbpYgclX0ygYv8ZTsDqfu6Ln78\n\t\t\t\t\t\tRDg/5G4H6ceA0dgiE7FT3yWCR/puIb8kWYgaq5XD5jq+e0cCWWeLhkL836D8LDuI\n\t\t\t\t\t\tOwKXvbbzaRql38RxJj59lg/XARc7j6UdMUPcKcJrkSeuMrn6gw626x4yL01R5uEc\n\t\t\t\t\t\t5s+VuwodLo1hTiRsewCOyfX0N7Fv16j8bxEecZtTfGOSL5FoxcjXjAf3JQcFoKr7\n\t\t\t\t\t\t76IY5ImPxNnS1vwfx84tWN0m/481ho/Q9rH15jChF/QXvIENCu/LUfURO0UajjHs\n\t\t\t\t\t\tyGADdQIDAQABo4IB0TCCAc0wCQYDVR0TBAIwADALBgNVHQ8EBAMCBaAwRQYDVR0f\n\t\t\t\t\t\tBD4wPDA6oDigNoY0aHR0cDovL1NWUlNlY3VyZS1HMy1jcmwudmVyaXNpZ24uY29t\n\t\t\t\t\t\tL1NWUlNlY3VyZUczLmNybDBEBgNVHSAEPTA7MDkGC2CGSAGG+EUBBxcDMCowKAYI\n\t\t\t\t\t\tKwYBBQUHAgEWHGh0dHBzOi8vd3d3LnZlcmlzaWduLmNvbS9ycGEwHQYDVR0lBBYw\n\t\t\t\t\t\tFAYIKwYBBQUHAwEGCCsGAQUFBwMCMB8GA1UdIwQYMBaAFA1EXBZTRMGCfh0gqyX0\n\t\t\t\t\t\tAWPYvnmlMHYGCCsGAQUFBwEBBGowaDAkBggrBgEFBQcwAYYYaHR0cDovL29jc3Au\n\t\t\t\t\t\tdmVyaXNpZ24uY29tMEAGCCsGAQUFBzAChjRodHRwOi8vU1ZSU2VjdXJlLUczLWFp\n\t\t\t\t\t\tYS52ZXJpc2lnbi5jb20vU1ZSU2VjdXJlRzMuY2VyMG4GCCsGAQUFBwEMBGIwYKFe\n\t\t\t\t\t\toFwwWjBYMFYWCWltYWdlL2dpZjAhMB8wBwYFKw4DAhoEFEtruSiWBgy70FI4myms\n\t\t\t\t\t\tSweLIQUYMCYWJGh0dHA6Ly9sb2dvLnZlcmlzaWduLmNvbS92c2xvZ28xLmdpZjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAJ+ckyvFj6ePTWp6PMkHSonNavE43FfEIw0cRoKWv\n\t\t\t\t\t\tSgEwHPLRVpvS+iOwTzeTjy3Srph58ZbZugvjjp3Bc1vdbwcmUEsXGm2MN+M6tYK0\n\t\t\t\t\t\tqIIvS9hGIKClhzKR43BEybO2BttESL2Bv2UUJcVH0Ds3//6pcUyaHuIxbnKbezfn\n\t\t\t\t\t\tj5ijhM3Bth829thSjIr9zYbqKdYl2sBFhzBQe5oPdCNEger4Nn8SqbrMMbP4IhIX\n\t\t\t\t\t\tIP8ivy/IUHCt3nZongEQgQsPnG1m3LHyWdTQ98XeHbgn8YOJdRPbsRFtNIYyXurv\n\t\t\t\t\t\tPDhe2VbSBBIUxBcGBTWkewIXexyKjQlfjFXQiOdS0M6zfQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.webofknowledge.com/?auth=Shibboleth",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.webofknowledge.com/?auth=Shibboleth",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://admin-router.webofknowledge.com/?auth=Shibboleth",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://admin-router.webofknowledge.com/?auth=Shibboleth",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cortellis.thomsonreuterslifesciences.com/ngg/sso/saml2/responseGateway.do",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.incites.thomsonreuters.com/?DestApp=IC2&auth=Shibboleth",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "111"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.incites.thomsonreuters.com/?DestApp=PROF&auth=Shibboleth",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "112"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.incites.thomsonreuters.com/?DestApp=IC2ESI&auth=Shibboleth",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "113"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.incites.thomsonreuters.com/?DestApp=IC2JCR&auth=Shibboleth",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "114"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.incites.thomsonreuters.com/?auth=Shibboleth1_IC2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "115"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.incites.thomsonreuters.com/?auth=Shibboleth1_IC2ESI",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "116"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.incites.thomsonreuters.com/?auth=Shibboleth1_IC2JCR",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "117"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.incites.thomsonreuters.com/?auth=Shibboleth1_PROF",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "118"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://vm-jorum-live.mimas.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ryan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Benjamin.ryan@manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ben"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ryan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Benjamin.ryan@manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ben"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://vm-jorum-live.mimas.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-10-04T13:11:04Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Jorum Server"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jorum.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Manchester"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://vm-jorum-live.mimas.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://content.resourceshare.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dashboard.jorum.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://vm-jorum-live.mimas.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://content.resourceshare.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dashboard.jorum.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://vm-jorum-live.mimas.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://content.resourceshare.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dashboard.jorum.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Through Jorum, you can find and share open learning and teaching resources"
                  }
                ],
                "logo": [
                  {
                    "text": "https://census.mimas.ac.uk/jorum_logo_blue20mm.gif",
                    "height": "236",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "236"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Jorum Server"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIJANQP2jdRCfzwMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\n\t\t\t\t\t\tBAMTGXZtLWpvcnVtLWxpdmUubWltYXMuYWMudWswHhcNMTIxMDAyMTM1MjE0WhcN\n\t\t\t\t\t\tMjIwOTMwMTM1MjE0WjAkMSIwIAYDVQQDExl2bS1qb3J1bS1saXZlLm1pbWFzLmFj\n\t\t\t\t\t\tLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA8gYKF0xuU66m0RX5\n\t\t\t\t\t\tOd3jfU9l0GGu18RGmMjfEqWapq0jKgrcQJ7lnIK3ZXaCAk1tcNS1qOnm9KhXK5KA\n\t\t\t\t\t\t7wKS0g6Mlp7xeT+rOHpKvSCC/TDPtf1XId4jA0HMTcSnDE1hmI/wauY+QRHWs7Ur\n\t\t\t\t\t\toIEUZMPOcMNhPZrJUoVxKaikXvSAyCqFN5R76MDToDDgOfPM1yNnNzyrnpUTQiEq\n\t\t\t\t\t\t3GKo75cyT7T0G11CWQ8D8iJlOFepN4B0cZirgGl36z43TwJAXHLiAY3D9B60zI+R\n\t\t\t\t\t\tom/0QSPaTkwh+HRedV3z0nz+fgjedVZ6pJeWzHOD3eSuXaP0curw44D7WqjjYjHL\n\t\t\t\t\t\t4KIzTwIDAQABo3UwczBSBgNVHREESzBJghl2bS1qb3J1bS1saXZlLm1pbWFzLmFj\n\t\t\t\t\t\tLnVrhixodHRwczovL3ZtLWpvcnVtLWxpdmUubWltYXMuYWMudWsvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQUqorggIzoMEc9fZmWa6roOYbqzSswDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAFb756zkwksgAxFut4fJ+IcKubtWZbmDTu2TnWyEQL8WKiAhi2jxdf7m/Y8M\n\t\t\t\t\t\t+Bj2j1ukkoAxRUklRF4B1tdGIIcD8wB3pHDVjnPnH8rPeIOP8WCKPoWEBozpAb9B\n\t\t\t\t\t\try1OnaoxidZBQRAB6Nv8YQ62UiOodcCaOeajRcdbGy3x4n47q/nLGc/rpcQEIBtV\n\t\t\t\t\t\tasDFXqeKspdgzaZAvXmSPOVvRB/QYnLdjkVRTVfSx1+Lf55Rgvb1f0IqFlVhJtxJ\n\t\t\t\t\t\tXu5sshZWFQXfzhiXmZNHQ9StFCt9ZZ7g+ozYkRcqwicS8n3kx14xe4GiOnbQl1id\n\t\t\t\t\t\tMeubT2ge0DJHn1WTCVIhuNIylBw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://vm-jorum-live.mimas.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://vm-jorum-live.mimas.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://vm-jorum-live.mimas.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://vm-jorum-live.mimas.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://vm-jorum-live.mimas.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://vm-jorum-live.mimas.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://content.resourceshare.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://content.resourceshare.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://content.resourceshare.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://content.resourceshare.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://content.resourceshare.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://content.resourceshare.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dashboard.jorum.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dashboard.jorum.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dashboard.jorum.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dashboard.jorum.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dashboard.jorum.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dashboard.jorum.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://federatedaccess.hrc.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Featherstone"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dfeatherstone@hrc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Denis"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Featherstone"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dfeatherstone@hrc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Denis"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federatedaccess.hrc.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_instant": "2013-07-11T17:18:34Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVAOg3Fb090dB9p32MB4EgjYEXyiOxMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCQxIjAgBgNVBAMTGWZlZGVyYXRlZGFjY2Vzcy5ocmMuYWMudWswHhcNMTMw\n\t\t\t\t\t\tNzA2MDcyMjMxWhcNMzMwNzA2MDcyMjMxWjAkMSIwIAYDVQQDExlmZWRlcmF0ZWRh\n\t\t\t\t\t\tY2Nlc3MuaHJjLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tkoOul030k6LhcQ2zW3YErb4osJQwvj7gskGciL2HdKH/BKI1EFOqfayB3QKS7cJ6\n\t\t\t\t\t\tekdeHdkhhwamDnXGW2IZO3xaeGXiebT9vy/m3bi3VScUZsydhCC5vZ6vKJHqA2aN\n\t\t\t\t\t\tqWPH6uNqS9D9X+BXQ1Yaa0zaB671M1gbZ9TwCP473+jtBjRh3b5LaNh41MbOJ4xk\n\t\t\t\t\t\t7UyQvG1Q2tiO1+0OfBnjen3cKnL2u8HrKXq0aZFV1FXmL/S/C7RSlXp3+FX3+VZa\n\t\t\t\t\t\tPn/jlBBQHn7j8hEoQ3KkrnO7PFIiD4szmm40ubKk9m1iR3JKu8wsP/wkFll1MCxq\n\t\t\t\t\t\t3QDeoo8c6I/RHgIa7zzHgQIDAQABo3kwdzBWBgNVHREETzBNghlmZWRlcmF0ZWRh\n\t\t\t\t\t\tY2Nlc3MuaHJjLmFjLnVrhjBodHRwczovL2ZlZGVyYXRlZGFjY2Vzcy5ocmMuYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFB7hyBviehtzOyJTo/85hiqrmtaS\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQCPwEmDe/HVq9orxzy9lS7qYg4tte2dqJHpsLD+\n\t\t\t\t\t\tAxcI5Uamg1/7IbuG5P6r9gPgdVzB1qo5DWaXbJSo8wY+003v2kvdXYK2x0/85DZ4\n\t\t\t\t\t\tdtkftolCrgwGJqeEePUV4TWCoihdSjaqr7/0Qe27nZi83hNjy3OipfMm/lDZQDgB\n\t\t\t\t\t\t3mIg0IbbBXVh4BjnnaJZqGj7qqhCJduCaU0hUK1cvb31Po/Ub+8fqmobstCFxcw4\n\t\t\t\t\t\t6YExHZsPvcbWhVk8bZEn1bBKjXlozIL46pATE/ApTj955UAocZs/0HeTbPTszOjM\n\t\t\t\t\t\t2+lio+vkIsRiGCzd1QgB/JmMbZ3I0016UR31P7+M5AaOiJ0s"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hrc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://federatedaccess.hrc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://federatedaccess.hrc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federatedaccess.hrc.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federatedaccess.hrc.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://federatedaccess.hrc.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://federatedaccess.hrc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federatedaccess.hrc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://federatedaccess.hrc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federatedaccess.hrc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://federatedaccess.hrc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://federatedaccess.hrc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hrc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVAOg3Fb090dB9p32MB4EgjYEXyiOxMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCQxIjAgBgNVBAMTGWZlZGVyYXRlZGFjY2Vzcy5ocmMuYWMudWswHhcNMTMw\n\t\t\t\t\t\tNzA2MDcyMjMxWhcNMzMwNzA2MDcyMjMxWjAkMSIwIAYDVQQDExlmZWRlcmF0ZWRh\n\t\t\t\t\t\tY2Nlc3MuaHJjLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tkoOul030k6LhcQ2zW3YErb4osJQwvj7gskGciL2HdKH/BKI1EFOqfayB3QKS7cJ6\n\t\t\t\t\t\tekdeHdkhhwamDnXGW2IZO3xaeGXiebT9vy/m3bi3VScUZsydhCC5vZ6vKJHqA2aN\n\t\t\t\t\t\tqWPH6uNqS9D9X+BXQ1Yaa0zaB671M1gbZ9TwCP473+jtBjRh3b5LaNh41MbOJ4xk\n\t\t\t\t\t\t7UyQvG1Q2tiO1+0OfBnjen3cKnL2u8HrKXq0aZFV1FXmL/S/C7RSlXp3+FX3+VZa\n\t\t\t\t\t\tPn/jlBBQHn7j8hEoQ3KkrnO7PFIiD4szmm40ubKk9m1iR3JKu8wsP/wkFll1MCxq\n\t\t\t\t\t\t3QDeoo8c6I/RHgIa7zzHgQIDAQABo3kwdzBWBgNVHREETzBNghlmZWRlcmF0ZWRh\n\t\t\t\t\t\tY2Nlc3MuaHJjLmFjLnVrhjBodHRwczovL2ZlZGVyYXRlZGFjY2Vzcy5ocmMuYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFB7hyBviehtzOyJTo/85hiqrmtaS\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQCPwEmDe/HVq9orxzy9lS7qYg4tte2dqJHpsLD+\n\t\t\t\t\t\tAxcI5Uamg1/7IbuG5P6r9gPgdVzB1qo5DWaXbJSo8wY+003v2kvdXYK2x0/85DZ4\n\t\t\t\t\t\tdtkftolCrgwGJqeEePUV4TWCoihdSjaqr7/0Qe27nZi83hNjy3OipfMm/lDZQDgB\n\t\t\t\t\t\t3mIg0IbbBXVh4BjnnaJZqGj7qqhCJduCaU0hUK1cvb31Po/Ub+8fqmobstCFxcw4\n\t\t\t\t\t\t6YExHZsPvcbWhVk8bZEn1bBKjXlozIL46pATE/ApTj955UAocZs/0HeTbPTszOjM\n\t\t\t\t\t\t2+lio+vkIsRiGCzd1QgB/JmMbZ3I0016UR31P7+M5AaOiJ0s"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hertford Regional College - Test"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hrc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hertford Regional College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.vfu.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "\u017d\u016frek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "zurekl@vfu.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ladislav"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "\u010cejka"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cejkap@vfu.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dole\u017eal"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dolezalo@vfu.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ond\u0159ej"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.vfu.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2015-12-17T11:13:02Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/university"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.vfu.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.vfu.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVANp/jeTWFQlkALd2zvuQM0NNal7QMA0GCSqGSIb3DQEB\nCwUAMBUxEzARBgNVBAMMCmlkcC52ZnUuY3owHhcNMTUxMTExMTQzMTM5WhcNMzUx\nMTExMTQzMTM5WjAVMRMwEQYDVQQDDAppZHAudmZ1LmN6MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAj+iqNpJyp61VIUE+Uiuf70mpL3M+abjmqVPR8/XD\nOvsRiGwVCJTdYSjAKzEofzo7x8St/RB9yLqQJiPQ+ooTnJ661FjrCNrq714DYZh8\npjEz0ybzWR0ATIUz4WYBEeFHgVX2KZjUrCsw5x51xTppIHSKtlH1aUt8Xy/TbMV/\nCVuouE5oSMJrjgwQOU+4AnGT3XV5EH1u9WlSbGtG/DRzGo61emww8GXu4srsPetx\ni8wEgeWbCxQ4Gwe7EZmpEPa1cCBSFFh6DJ6pH8HO0wcDs38YxhLBMtdDEkscilBK\nXEsIYkn/7lfLxgx7ixr+iCxc04DiZxHacWi+KaGThblWQQIDAQABo1swWTAdBgNV\nHQ4EFgQUZsHdPToEdg76yRcx9wzG0GW/nVYwOAYDVR0RBDEwL4IKaWRwLnZmdS5j\neoYhaHR0cHM6Ly9pZHAudmZ1LmN6L2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\nCwUAA4IBAQCNVAy1JdEkvnY9bJetr9ZXFxRaiuQoLrlkGAxGt3OibQJQ4zZvHibr\nYlUhbTEHXNjlThfwL90Rd65ikw3rPa3l/6zV5+Z9SqKykuKHfn+SjCW4XRF0Qhr9\nB6S7XyKMQK+QnZmN44IS+5ZtGpydEwduCv8uWuQI5vaq3NDJ0dUiBWPDh0SKIEH9\nSGRzwuLfThykPFAGd/HjzGGvkeYmhY0J3XmtvlXBgMNVgWO3eJun6lVDwFLLX/fT\n4zcd0uNIaHCPalZni/fJJZZ1OnpqGCcojEkbSZuSNj63zJpRIbX8+2Suwit2C8pR\nOCIUB28HPQitwXyHjHKbbja76a/IB8id"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEzCCAfugAwIBAgIUZ9X/+ig6ipqz5tuTFlWeaseDk1gwDQYJKoZIhvcNAQEL\nBQAwFTETMBEGA1UEAwwKaWRwLnZmdS5jejAeFw0xNTExMTExNDMxMzhaFw0zNTEx\nMTExNDMxMzhaMBUxEzARBgNVBAMMCmlkcC52ZnUuY3owggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQCd944PWmJDHy0+mNrQ9kH/cd6dJCNzHDWngw4WPmPf\ngzpJJobllCpvfMi0aW7ZdwbVun4otm70w8WhXBITYDcagXPdZX32CTx+5uCBmzPL\nWWp/W/AA9jIYvpygPUB1torPYt+WGP2kt5MNFkN8yN+XWr520jiPaZ5Aqqomkezl\nSwFbHD4pCYKxN11A/JFkNRlZjFIe9mdMOEecvRCSdPewfYkEEyEzVgX2ID2j22KD\nOSIaEIdqoAjoqye9YNIPtS5+Q4Ut7pQBRdc6l8rPBOlb66okxotf8McbPW6NV0tX\nU/kESRZxlr1vtBAirs9aFP0S9YkRx5Gbf8h0SiiK88QVAgMBAAGjWzBZMB0GA1Ud\nDgQWBBSBB7uc02LKj3kiKpQj57O25TZOWTA4BgNVHREEMTAvggppZHAudmZ1LmN6\nhiFodHRwczovL2lkcC52ZnUuY3ovaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEL\nBQADggEBABrhb7FN/oWizvVpDZRqTdW87x/I2A4AQhDDMT2Xh4VEBveP3H4agIs1\nPmPQW8cAgr+SyvXpgN4hpC9xm5dE1GE+dT/2EK4QnAGogldwn5m9BjXc3okEyg46\nOf1COpKLZexcbN4i2JC6sUq3w96yNX0/WZCRbiye5+zVquovphOqL0t7PkOPMMqK\nfDtx0zOl6SCJB7cSVQd9BqvzWfT+/hUZiLlvrE88tIWLQatUC+Frjw9c+z9EcZ+B\n4VMcjUyqivNpcfjuHHAgimF0xW5eazK4lB9f76dgJNvhm0r4VcmuluOhzDDc8HV7\n11vR6XmJ2seiNk9k1bKJnEqIqWW7y9Y="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVALawx1psOeuNB/Q2nKO0A/D3JVB/MA0GCSqGSIb3DQEB\nCwUAMBUxEzARBgNVBAMMCmlkcC52ZnUuY3owHhcNMTUxMTExMTQzMTM5WhcNMzUx\nMTExMTQzMTM5WjAVMRMwEQYDVQQDDAppZHAudmZ1LmN6MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAtwMyNgUHQbL2qrspcFBtqMyqYn9A2hGR5RB/vzX0\ni4TdZqE23R5IPgi8OCVrI/PDZBqF0pNA/Y7GY0YlLbw/0g/lnVYuUq1W+E8i1v9C\n+/DsD8G3K1xMerC/q3JVt7ukPDN+SJJp6DP/lAoKWYATUDq8ERm1BKIw2PBhiDCg\n13AfaVymOdbfWMZqtQp53fVCRnNiD5zHdmzK4z65zj1e4EOLrJaGqe3O2XUzJxrv\n8NNGNF2dZdHZ5tS5lyY0n65wPIPOyE8CI+uryYy26LxE8HxX4blcyoQwR9SWxG1B\neRroPi1gtqJwAfEjheI45uCHUEWDwq3Sh6z6VlYxukotDwIDAQABo1swWTAdBgNV\nHQ4EFgQUTqnt/OEAflr2PGNfD7bji3eG54EwOAYDVR0RBDEwL4IKaWRwLnZmdS5j\neoYhaHR0cHM6Ly9pZHAudmZ1LmN6L2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\nCwUAA4IBAQAIs7X2dSUVS8wc+UsDNYrXtiAouHGoqdaZDJgig9GVK4HPZLlIZbz4\nJJZ/82N9ySsUMv/yt6fG/NtamnaSBWw8wd+3ICdCALEgH05OoJyqIX9GJPqcxPKX\n0v2J4xtzNVACyxxy7fbu0fxxU9EqgMehL0tRaZAjZBYubZZoT/2CXSPIJ3PCk7RZ\nMs37IJpACqCJ0i8oQ1KTYqoUZFOigzdFv3O3pa7EjcHUI4KBtSlUADvG7x9G+EQS\nQzbFdRvuJ9SzN5kZ8Cv2hZUdLhp8/GsBO7mWqv5AlYT92fk3aSxXI86nzbAYkPNX\n2VD3vAL+nYSRZTKDTCV0dFKXgixuQNQX"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vfu.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.vfu.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.vfu.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.vfu.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.vfu.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.vfu.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.vfu.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.vfu.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.vfu.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.vfu.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vfu.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.vfu.cz/index_en.html"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.vfu.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for employees and students of University of Veterinary and Pharmaceutical Sciences Brno."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance a studenty Veterin\u00e1rn\u00ed a farmaceutick\u00e9 univerzity Brno."
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.vfu.cz/vfu_logo_40x40.jpg",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "40"
                  },
                  {
                    "text": "https://idp.vfu.cz/vfu_logo_50x50.jpg",
                    "height": "50",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "50"
                  },
                  {
                    "text": "https://idp.vfu.cz/vfu_logo_100x101.jpg",
                    "height": "101",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  },
                  {
                    "text": "https://idp.vfu.cz/vfu_logo_200x203.jpg",
                    "height": "203",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "200"
                  },
                  {
                    "text": "https://idp.vfu.cz/vfu_logo_400x407.jpg",
                    "height": "407",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "400"
                  },
                  {
                    "text": "https://idp.vfu.cz/vfu_logo_800x814.jpg",
                    "height": "814",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "800"
                  },
                  {
                    "text": "https://idp.vfu.cz/vfu_logo_3182x3238.jpg",
                    "height": "3238",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "3182"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Veterinary and Pharmaceutical Sciences Brno"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Veterin\u00e1rn\u00ed a farmaceutick\u00e1 univerzita Brno"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVANp/jeTWFQlkALd2zvuQM0NNal7QMA0GCSqGSIb3DQEB\nCwUAMBUxEzARBgNVBAMMCmlkcC52ZnUuY3owHhcNMTUxMTExMTQzMTM5WhcNMzUx\nMTExMTQzMTM5WjAVMRMwEQYDVQQDDAppZHAudmZ1LmN6MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAj+iqNpJyp61VIUE+Uiuf70mpL3M+abjmqVPR8/XD\nOvsRiGwVCJTdYSjAKzEofzo7x8St/RB9yLqQJiPQ+ooTnJ661FjrCNrq714DYZh8\npjEz0ybzWR0ATIUz4WYBEeFHgVX2KZjUrCsw5x51xTppIHSKtlH1aUt8Xy/TbMV/\nCVuouE5oSMJrjgwQOU+4AnGT3XV5EH1u9WlSbGtG/DRzGo61emww8GXu4srsPetx\ni8wEgeWbCxQ4Gwe7EZmpEPa1cCBSFFh6DJ6pH8HO0wcDs38YxhLBMtdDEkscilBK\nXEsIYkn/7lfLxgx7ixr+iCxc04DiZxHacWi+KaGThblWQQIDAQABo1swWTAdBgNV\nHQ4EFgQUZsHdPToEdg76yRcx9wzG0GW/nVYwOAYDVR0RBDEwL4IKaWRwLnZmdS5j\neoYhaHR0cHM6Ly9pZHAudmZ1LmN6L2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\nCwUAA4IBAQCNVAy1JdEkvnY9bJetr9ZXFxRaiuQoLrlkGAxGt3OibQJQ4zZvHibr\nYlUhbTEHXNjlThfwL90Rd65ikw3rPa3l/6zV5+Z9SqKykuKHfn+SjCW4XRF0Qhr9\nB6S7XyKMQK+QnZmN44IS+5ZtGpydEwduCv8uWuQI5vaq3NDJ0dUiBWPDh0SKIEH9\nSGRzwuLfThykPFAGd/HjzGGvkeYmhY0J3XmtvlXBgMNVgWO3eJun6lVDwFLLX/fT\n4zcd0uNIaHCPalZni/fJJZZ1OnpqGCcojEkbSZuSNj63zJpRIbX8+2Suwit2C8pR\nOCIUB28HPQitwXyHjHKbbja76a/IB8id"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDEzCCAfugAwIBAgIUZ9X/+ig6ipqz5tuTFlWeaseDk1gwDQYJKoZIhvcNAQEL\nBQAwFTETMBEGA1UEAwwKaWRwLnZmdS5jejAeFw0xNTExMTExNDMxMzhaFw0zNTEx\nMTExNDMxMzhaMBUxEzARBgNVBAMMCmlkcC52ZnUuY3owggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQCd944PWmJDHy0+mNrQ9kH/cd6dJCNzHDWngw4WPmPf\ngzpJJobllCpvfMi0aW7ZdwbVun4otm70w8WhXBITYDcagXPdZX32CTx+5uCBmzPL\nWWp/W/AA9jIYvpygPUB1torPYt+WGP2kt5MNFkN8yN+XWr520jiPaZ5Aqqomkezl\nSwFbHD4pCYKxN11A/JFkNRlZjFIe9mdMOEecvRCSdPewfYkEEyEzVgX2ID2j22KD\nOSIaEIdqoAjoqye9YNIPtS5+Q4Ut7pQBRdc6l8rPBOlb66okxotf8McbPW6NV0tX\nU/kESRZxlr1vtBAirs9aFP0S9YkRx5Gbf8h0SiiK88QVAgMBAAGjWzBZMB0GA1Ud\nDgQWBBSBB7uc02LKj3kiKpQj57O25TZOWTA4BgNVHREEMTAvggppZHAudmZ1LmN6\nhiFodHRwczovL2lkcC52ZnUuY3ovaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEL\nBQADggEBABrhb7FN/oWizvVpDZRqTdW87x/I2A4AQhDDMT2Xh4VEBveP3H4agIs1\nPmPQW8cAgr+SyvXpgN4hpC9xm5dE1GE+dT/2EK4QnAGogldwn5m9BjXc3okEyg46\nOf1COpKLZexcbN4i2JC6sUq3w96yNX0/WZCRbiye5+zVquovphOqL0t7PkOPMMqK\nfDtx0zOl6SCJB7cSVQd9BqvzWfT+/hUZiLlvrE88tIWLQatUC+Frjw9c+z9EcZ+B\n4VMcjUyqivNpcfjuHHAgimF0xW5eazK4lB9f76dgJNvhm0r4VcmuluOhzDDc8HV7\n11vR6XmJ2seiNk9k1bKJnEqIqWW7y9Y="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVALawx1psOeuNB/Q2nKO0A/D3JVB/MA0GCSqGSIb3DQEB\nCwUAMBUxEzARBgNVBAMMCmlkcC52ZnUuY3owHhcNMTUxMTExMTQzMTM5WhcNMzUx\nMTExMTQzMTM5WjAVMRMwEQYDVQQDDAppZHAudmZ1LmN6MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAtwMyNgUHQbL2qrspcFBtqMyqYn9A2hGR5RB/vzX0\ni4TdZqE23R5IPgi8OCVrI/PDZBqF0pNA/Y7GY0YlLbw/0g/lnVYuUq1W+E8i1v9C\n+/DsD8G3K1xMerC/q3JVt7ukPDN+SJJp6DP/lAoKWYATUDq8ERm1BKIw2PBhiDCg\n13AfaVymOdbfWMZqtQp53fVCRnNiD5zHdmzK4z65zj1e4EOLrJaGqe3O2XUzJxrv\n8NNGNF2dZdHZ5tS5lyY0n65wPIPOyE8CI+uryYy26LxE8HxX4blcyoQwR9SWxG1B\neRroPi1gtqJwAfEjheI45uCHUEWDwq3Sh6z6VlYxukotDwIDAQABo1swWTAdBgNV\nHQ4EFgQUTqnt/OEAflr2PGNfD7bji3eG54EwOAYDVR0RBDEwL4IKaWRwLnZmdS5j\neoYhaHR0cHM6Ly9pZHAudmZ1LmN6L2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\nCwUAA4IBAQAIs7X2dSUVS8wc+UsDNYrXtiAouHGoqdaZDJgig9GVK4HPZLlIZbz4\nJJZ/82N9ySsUMv/yt6fG/NtamnaSBWw8wd+3ICdCALEgH05OoJyqIX9GJPqcxPKX\n0v2J4xtzNVACyxxy7fbu0fxxU9EqgMehL0tRaZAjZBYubZZoT/2CXSPIJ3PCk7RZ\nMs37IJpACqCJ0i8oQ1KTYqoUZFOigzdFv3O3pa7EjcHUI4KBtSlUADvG7x9G+EQS\nQzbFdRvuJ9SzN5kZ8Cv2hZUdLhp8/GsBO7mWqv5AlYT92fk3aSxXI86nzbAYkPNX\n2VD3vAL+nYSRZTKDTCV0dFKXgixuQNQX"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Veterinary and Pharmaceutical Sciences Brno"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Veterin\u00e1rn\u00ed a farmaceutick\u00e1 univerzita Brno"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vfu.cz/index_en.html"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vfu.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Veterinary and Pharmaceutical Sciences Brno"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Veterin\u00e1rn\u00ed a farmaceutick\u00e1 univerzita Brno"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://fdm.sisoshibboleth.co.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Info"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Oates"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://fdm.sisoshibboleth.co.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-01-25T10:29:17Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SiSo Roehampton Online Resource Booking"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.siso.uk.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "TechEthika Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://fdm.siso.co/sso/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://fdm.siso.co/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://fdm.siso.co/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SiSo Roehampton Online Resource Booking"
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth.siso.co/siso-logo64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SiSo Roehampton Online Resource Booking"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAOSUhyDXVj7AMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB3Npc28uY28wHhcNMTMwMTA3MTYzMTIxWhcNMjMwMTA1MTYzMTIxWjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdzaXNvLmNvMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\txDnj9YFJVXclawo/8rs1aWYAgk6rKi8A/Cyycq0mW5yOKLLh8MUIgDeOGL7bLl7p\n\t\t\t\t\t\tMBeZM4ILlNaeJhICWm1tuLB6SYzREnXwpO7+lvx13xsRHW2TjCPGV3yUgz55vRYj\n\t\t\t\t\t\tbseFrwFHJ8IrL24UTLcpX/R//9cMkZpSqM+77Hn22dxbYvGUOQCHOQzL78AO91qz\n\t\t\t\t\t\tdUaxKzYWyWM7w2U4APP41Zvd0flyUtRZXp8W+WwlUDffFoNndsjR4L/9wuXvOcrH\n\t\t\t\t\t\t+VZtMLy60+cB9bpvVlaQVlt+1stEABdMVvuGNkJ9wIjRjP2b9OLUI76QmgwIDtdE\n\t\t\t\t\t\t5BS0Bv0Puz66L96r2MunRQIDAQABozUwMzASBgNVHREECzAJggdzaXNvLmNvMB0G\n\t\t\t\t\t\tA1UdDgQWBBRRosxNbUQXXwtWDl/kYMScRImh5TANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tgrfjza9Btcz+9WvzcjDTZ+KSrWWvrthA3zc6Q+C/MIBG8CCuxMO+uwFBnXIopGlX\n\t\t\t\t\t\tbLa/QtVLjOugsnizFxjaEFTG4jGndtPJ8+9V8Eja5RlOazuM2LT738+Um8/1Frhr\n\t\t\t\t\t\tGXa0Hdv9ZWEbIhil65fFqZNOmOteja6xxAQ9NgGG/XUnTVTbr7msihEAYTTcS40/\n\t\t\t\t\t\tGSYpT9nQwiryfSWDNJ17Zyl44389kSw+FCUsu8Ns9VSDEDWr/R+97ZMcjN6hAfJL\n\t\t\t\t\t\tdji3X1aaAC/JbnJl/v+yR1TH/sdHyObVaM7FToUGKiyjX9VpfOe64d0hjogzEr0x\n\t\t\t\t\t\tfirJubLNu96jbGctasqcpQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://fdm.siso.co/sso/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://fdm.siso.co/sso/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://fdm.siso.co/sso/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://fdm.siso.co/sso/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://fdm.siso.co/sso/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://fdm.siso.co/sso/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp-iov.irccs.garr.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@ioveneto.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Admin IdP IOV Veneto"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-iov.irccs.garr.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2013-10-30T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVAKZ6hm3VBBJOouu37feeqiHLQhlAMA0GCSqGSIb3DQEB\nBQUAMCAxHjAcBgNVBAMTFWlkcC1pb3YuaXJjY3MuZ2Fyci5pdDAeFw0xMzA3MjQx\nMzIzMzNaFw0zMzA3MjQxMzIzMzNaMCAxHjAcBgNVBAMTFWlkcC1pb3YuaXJjY3Mu\nZ2Fyci5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL1xUKxiZIEL\nP35mXSO10mng2aL/TVZJAj9Z3NfTq7SrfdfFnEWX/VT6or/p9s4RgUYOZosRfY98\nH8IpOuDfpiUWv0bQRUe+pjk6IPBTreQf6GwwqeojmpG2BLsllq8vvb0am0yl/rn6\nUv9yCfsFAtIm3cmhHkS0AI8mOcsh+0BVT794pDz70W+o3DdiNF0Dp+VINpXXSUoE\nF72QcC9SkOVryiGjErJL97YzHGXRZmY1Rqqjf/jQFJovxvBh9ATBOF90ilHHKeR6\ny6Ey4vrXgez/WDWsHm0lS0S6LzuUf0keT3yoeFQgnCW/PTUqw/jv4/v1v+e2yBUz\nugZCI9kqhqMCAwEAAaNxMG8wTgYDVR0RBEcwRYIVaWRwLWlvdi5pcmNjcy5nYXJy\nLml0hixodHRwczovL2lkcC1pb3YuaXJjY3MuZ2Fyci5pdC9pZHAvc2hpYmJvbGV0\naDAdBgNVHQ4EFgQU2lu3OlDrvKjMBNWa0xF78Dlx4TgwDQYJKoZIhvcNAQEFBQAD\nggEBAFIYXX2LtDHTX+yX8plAqqgBuud3FGUa3id/jsnQ8ODoHRT31tbsfLkvXYjU\nH4JJaNVP563A0sEnPTzunIStxDwp8dAylqWNNspGRtN/a5YUx+psjp/05ishMwKE\naIUFfOUa5DvEyGOLXp5jaSvcgUEMKWc8naSQ6JA0W9gQeaK+knz3ayK6TSzLFTAP\nAudn0iIIkzUxpLnNr8MZhRGXyX+zjsePxg4BfPtaLi0fA3aQg84Quf9E0mcnTcAo\ngd3FYweSWBnbIC1TQgBYoCexPPkeKLunXiZDnOV7JW4lysMfm87YERWJjjpJuqj6\n2V5Vl5f33hs+jOp95tFlpm+RzwU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ioveneto.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-iov.irccs.garr.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-iov.irccs.garr.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-iov.irccs.garr.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-iov.irccs.garr.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-iov.irccs.garr.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-iov.irccs.garr.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-iov.irccs.garr.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-iov.irccs.garr.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ioveneto.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idp-iov.irccs.garr.it/idp/info.html"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idp-iov.irccs.garr.it/idp/info.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Istituto Oncologico Veneto - IOV IRCCS"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Istituto Oncologico Veneto - IOV IRCCS"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider of Istituto Oncologico Veneto - IOV IRCCS"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider di Istituto Oncologico Veneto - IOV IRCCS"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp-iov.irccs.garr.it/idp/images/institutionLogo-32x32_en.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp-iov.irccs.garr.it/idp/images/institutionLogo-160x120_en.png",
                    "lang": "en",
                    "height": "120",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "160"
                  },
                  {
                    "text": "https://idp-iov.irccs.garr.it/idp/images/institutionLogo-32x32_it.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp-iov.irccs.garr.it/idp/images/institutionLogo-160x120_it.png",
                    "lang": "it",
                    "height": "120",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "160"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.ioveneto.it/index.php?page=privacy"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.ioveneto.it/index.php?page=privacy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVAKZ6hm3VBBJOouu37feeqiHLQhlAMA0GCSqGSIb3DQEB\nBQUAMCAxHjAcBgNVBAMTFWlkcC1pb3YuaXJjY3MuZ2Fyci5pdDAeFw0xMzA3MjQx\nMzIzMzNaFw0zMzA3MjQxMzIzMzNaMCAxHjAcBgNVBAMTFWlkcC1pb3YuaXJjY3Mu\nZ2Fyci5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL1xUKxiZIEL\nP35mXSO10mng2aL/TVZJAj9Z3NfTq7SrfdfFnEWX/VT6or/p9s4RgUYOZosRfY98\nH8IpOuDfpiUWv0bQRUe+pjk6IPBTreQf6GwwqeojmpG2BLsllq8vvb0am0yl/rn6\nUv9yCfsFAtIm3cmhHkS0AI8mOcsh+0BVT794pDz70W+o3DdiNF0Dp+VINpXXSUoE\nF72QcC9SkOVryiGjErJL97YzHGXRZmY1Rqqjf/jQFJovxvBh9ATBOF90ilHHKeR6\ny6Ey4vrXgez/WDWsHm0lS0S6LzuUf0keT3yoeFQgnCW/PTUqw/jv4/v1v+e2yBUz\nugZCI9kqhqMCAwEAAaNxMG8wTgYDVR0RBEcwRYIVaWRwLWlvdi5pcmNjcy5nYXJy\nLml0hixodHRwczovL2lkcC1pb3YuaXJjY3MuZ2Fyci5pdC9pZHAvc2hpYmJvbGV0\naDAdBgNVHQ4EFgQU2lu3OlDrvKjMBNWa0xF78Dlx4TgwDQYJKoZIhvcNAQEFBQAD\nggEBAFIYXX2LtDHTX+yX8plAqqgBuud3FGUa3id/jsnQ8ODoHRT31tbsfLkvXYjU\nH4JJaNVP563A0sEnPTzunIStxDwp8dAylqWNNspGRtN/a5YUx+psjp/05ishMwKE\naIUFfOUa5DvEyGOLXp5jaSvcgUEMKWc8naSQ6JA0W9gQeaK+knz3ayK6TSzLFTAP\nAudn0iIIkzUxpLnNr8MZhRGXyX+zjsePxg4BfPtaLi0fA3aQg84Quf9E0mcnTcAo\ngd3FYweSWBnbIC1TQgBYoCexPPkeKLunXiZDnOV7JW4lysMfm87YERWJjjpJuqj6\n2V5Vl5f33hs+jOp95tFlpm+RzwU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Istituto Oncologico Veneto - IOV IRCCS"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Istituto Oncologico Veneto - IOV IRCCS"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ioveneto.it/"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ioveneto.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Istituto Oncologico Veneto - IOV IRCCS"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Istituto Oncologico Veneto - IOV IRCCS"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://artisan-idp.sunet.se/simplesaml/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NOC"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@sunet.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SUNET"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://artisan-idp.sunet.se/simplesaml/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish University Network (SUNET)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sunet.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SUNET"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://artisan-idp.sunet.se/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://artisan-idp.sunet.se/simplesaml/module.php/saml/sp/discoresp.php",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://artisan-idp.sunet.se/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://artisan-idp.sunet.se/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://artisan-idp.sunet.se/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://artisan-idp.sunet.se/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:profiles:holder-of-key:SSO:browser",
              "location": "https://artisan-idp.sunet.se/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://encecafe.ibge.gov.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mendonca"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mauro.mendonca@ibge.gov.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://encecafe.ibge.gov.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEGjCCAwICAQAwDQYJKoZIhvcNAQEFBQAwgdIxODA2BgNVBAoTL0VOQ0UgLSBF\nU0NPTEEgTkFDSU9OQUwgREUgQ0lFTkNJQVMgRVNUQVRJU1RJQ0FTMQ4wDAYDVQQL\nEwVDT1RFTDEoMCYGCSqGSIb3DQEJARYZc3Vwb3J0ZS5jb3RlbEBpYmdlLmdvdi5i\ncjEXMBUGA1UEBxMOUklPIERFIEpBTkVJUk8xFzAVBgNVBAgTDlJJTyBERSBKQU5F\nSVJPMQswCQYDVQQGEwJCUjEdMBsGA1UEAxMURU5DRUNBRkUuSUJHRS5HT1YuQlIw\nHhcNMTQwNDE3MTQ1OTQzWhcNMTkwNDE2MTQ1OTQzWjCB0jE4MDYGA1UEChMvRU5D\nRSAtIEVTQ09MQSBOQUNJT05BTCBERSBDSUVOQ0lBUyBFU1RBVElTVElDQVMxDjAM\nBgNVBAsTBUNPVEVMMSgwJgYJKoZIhvcNAQkBFhlzdXBvcnRlLmNvdGVsQGliZ2Uu\nZ292LmJyMRcwFQYDVQQHEw5SSU8gREUgSkFORUlSTzEXMBUGA1UECBMOUklPIERF\nIEpBTkVJUk8xCzAJBgNVBAYTAkJSMR0wGwYDVQQDExRFTkNFQ0FGRS5JQkdFLkdP\nVi5CUjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKcKBwOhT6Gr6FgQ\n4uSzluNmpMlM/vrmI0pqYr8QI8V1lYQnr4ezAdoUNXlaJx2CMCDUPFi47uIRhlXy\nGh8OZi4WwAEprrIToui2a0Mv6y+JgD/RR4+pm6JggjIlJjijLDjU5VYxoM3TsVQ4\nVk6RYx81pPhUgnckZ3IV4A5pNtLzxdsEwkPpnoCNFlsKEAVUkMfTAQokQji0aWwc\niAwAp+dl045oNY1xRiJ4tCZk7VE/Dm7WoddSxAceYJtbUxvH+oE1xD0ZOW3ts7sj\nE4s1W4Eai1femBRrv19dWTXtPG2RWw6I6bYYLQetAvs1kRSqKrJHiHbVBzZ9InpC\nF/vS8tcCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAC78+ABZ2uxuYLkTI3uPi5Wtc\n/HN58FWUyPq+l8/6RrSDI6/uPJ0g490/j5U3L4B4LdjSs3y9kq4sDQ44MSglLcWS\n3WeHhEDiIwWEYy8ZQkEtQfvAxXMkmEfCBaS57dwwzNNaj7CWpo8OBQrsjjboK9tM\nohbLi2e2DPJtdWztwGYxjAl/b5f2gQVLYgAuoDFs6NEk8wqjuH3fyjs5BrHigzJD\ny/CFOm3UyxZuE6AXLTDxqEzCzdHDAtZP8tK/32zu7Kv7pCP6OI6RdVphaLOxKn7X\nxG6lNFUhNi72Kxw/UnI9yYKJzYkw2v8rC6VfbJ4UOyenQeR27aELT9w3tGOOYg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gov.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://encecafe.ibge.gov.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://encecafe.ibge.gov.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://encecafe.ibge.gov.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://encecafe.ibge.gov.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://encecafe.ibge.gov.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://encecafe.ibge.gov.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://encecafe.ibge.gov.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://encecafe.ibge.gov.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gov.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ence.ibge.gov.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ence.ibge.gov.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ENCE(IBGE) - Escola Nacional de Ciencias Estatisticas"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "ENCE(IBGE) - Escola Nacional de Ciencias Estatisticas"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENCE(IBGE) - Escola Nacional de Ciencias Estatisticas"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENCE(IBGE) - Escola Nacional de Ciencias Estatisticas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEGjCCAwICAQAwDQYJKoZIhvcNAQEFBQAwgdIxODA2BgNVBAoTL0VOQ0UgLSBF\nU0NPTEEgTkFDSU9OQUwgREUgQ0lFTkNJQVMgRVNUQVRJU1RJQ0FTMQ4wDAYDVQQL\nEwVDT1RFTDEoMCYGCSqGSIb3DQEJARYZc3Vwb3J0ZS5jb3RlbEBpYmdlLmdvdi5i\ncjEXMBUGA1UEBxMOUklPIERFIEpBTkVJUk8xFzAVBgNVBAgTDlJJTyBERSBKQU5F\nSVJPMQswCQYDVQQGEwJCUjEdMBsGA1UEAxMURU5DRUNBRkUuSUJHRS5HT1YuQlIw\nHhcNMTQwNDE3MTQ1OTQzWhcNMTkwNDE2MTQ1OTQzWjCB0jE4MDYGA1UEChMvRU5D\nRSAtIEVTQ09MQSBOQUNJT05BTCBERSBDSUVOQ0lBUyBFU1RBVElTVElDQVMxDjAM\nBgNVBAsTBUNPVEVMMSgwJgYJKoZIhvcNAQkBFhlzdXBvcnRlLmNvdGVsQGliZ2Uu\nZ292LmJyMRcwFQYDVQQHEw5SSU8gREUgSkFORUlSTzEXMBUGA1UECBMOUklPIERF\nIEpBTkVJUk8xCzAJBgNVBAYTAkJSMR0wGwYDVQQDExRFTkNFQ0FGRS5JQkdFLkdP\nVi5CUjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKcKBwOhT6Gr6FgQ\n4uSzluNmpMlM/vrmI0pqYr8QI8V1lYQnr4ezAdoUNXlaJx2CMCDUPFi47uIRhlXy\nGh8OZi4WwAEprrIToui2a0Mv6y+JgD/RR4+pm6JggjIlJjijLDjU5VYxoM3TsVQ4\nVk6RYx81pPhUgnckZ3IV4A5pNtLzxdsEwkPpnoCNFlsKEAVUkMfTAQokQji0aWwc\niAwAp+dl045oNY1xRiJ4tCZk7VE/Dm7WoddSxAceYJtbUxvH+oE1xD0ZOW3ts7sj\nE4s1W4Eai1femBRrv19dWTXtPG2RWw6I6bYYLQetAvs1kRSqKrJHiHbVBzZ9InpC\nF/vS8tcCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAC78+ABZ2uxuYLkTI3uPi5Wtc\n/HN58FWUyPq+l8/6RrSDI6/uPJ0g490/j5U3L4B4LdjSs3y9kq4sDQ44MSglLcWS\n3WeHhEDiIwWEYy8ZQkEtQfvAxXMkmEfCBaS57dwwzNNaj7CWpo8OBQrsjjboK9tM\nohbLi2e2DPJtdWztwGYxjAl/b5f2gQVLYgAuoDFs6NEk8wqjuH3fyjs5BrHigzJD\ny/CFOm3UyxZuE6AXLTDxqEzCzdHDAtZP8tK/32zu7Kv7pCP6OI6RdVphaLOxKn7X\nxG6lNFUhNi72Kxw/UnI9yYKJzYkw2v8rC6VfbJ4UOyenQeR27aELT9w3tGOOYg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ENCE(IBGE) - Escola Nacional de Ciencias Estatisticas"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ENCE(IBGE) - Escola Nacional de Ciencias Estatisticas"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ence.ibge.gov.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ence.ibge.gov.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ENCE(IBGE) - Escola Nacional de Ciencias Estatisticas)"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ENCE(IBGE) - Escola Nacional de Ciencias Estatisticas)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://netlogin.strath.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ukfed-support@strath.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ukfed-tech@strath.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://netlogin.strath.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-08-04T11:48:02Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVALntfhDpdib1U8g0APCYQ0HzFX4HMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCQxIjAgBgNVBAMMGW5ldGxvZ2luLWRldi5zdHJhdGguYWMudWswHhcNMTQx\n\t\t\t\t\t\tMTA3MTQ1MDAzWhcNMzQxMTA3MTQ1MDAzWjAkMSIwIAYDVQQDDBluZXRsb2dpbi1k\n\t\t\t\t\t\tZXYuc3RyYXRoLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tn5KFxtDXYrp4ChYev6BWlmqRZWRKiGVKqukVMC9qEkRiDWkwCUU5IgPkKH3IwJfW\n\t\t\t\t\t\tAO1xGZ+s+kZ2hwjgCVXCYMmlwk5RlRKkcCTTjqHjSZ7ZNKA2hEWOaBJF3F9lFbwk\n\t\t\t\t\t\tAyvMUi4qn7f+mDybZHr9pbl4phANo8Fs3gnPr+yAp+G6F0EyL3At5SKpnanQ/lRy\n\t\t\t\t\t\tdTCuXMTukeI1TDtvptr7jV2HjpO4KmEILiCsqDvnjNMT2YEFlgxa8bX+YGXG/8cH\n\t\t\t\t\t\t6LKIQOtvSsg0D3xZvmazOWo6xg9XMAgKh6J+tE0HUr6Js16g/GxXghxfQA/rXmh+\n\t\t\t\t\t\tlK0bYueUgkjyXSclGQe9uwIDAQABo3kwdzAdBgNVHQ4EFgQUHCmyxQT1A5E7uqal\n\t\t\t\t\t\txfUiaDHwCgowVgYDVR0RBE8wTYIZbmV0bG9naW4tZGV2LnN0cmF0aC5hYy51a4Yw\n\t\t\t\t\t\taHR0cHM6Ly9uZXRsb2dpbi1kZXYuc3RyYXRoLmFjLnVrL2lkcC9zaGliYm9sZXRo\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQCbAbHeCjRT5CzbWDX9I1VLo3Y0hEjlmiwCvAZX\n\t\t\t\t\t\tyKPZ5FO5fJVCtI2aqOToFbF2BVOe3/mYV8sC6dsoS38Sarwhzbh6GRRE3FywuPbp\n\t\t\t\t\t\tUkQGTeAmB7jZ7kXLRS/tgVJbWzChljeVqofhwXjW4PfPugSuslpC+elp9PoTj/BP\n\t\t\t\t\t\tOrfOIm9jSMG2/HPbaVR9VynfXThx+mYa261FIVQuaha6K+s4Y3vGU3qgyTtnyNYv\n\t\t\t\t\t\tpOIaOiV5+TEokiP5oOHdbyH5Ax5+w/Tx400X/jebeY6vTW6WTKDlYMnmP/Fbv8d6\n\t\t\t\t\t\tAZTALOEzlYlDfuws2MF1Tc3K10VtbOMIL90R5JROBwVMKw0j"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "strath.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://netlogin-dev.strath.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://netlogin-dev.strath.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://netlogin-dev.strath.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://netlogin-dev.strath.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://netlogin-dev.strath.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://netlogin-dev.strath.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://netlogin-dev.strath.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://netlogin-dev.strath.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://netlogin-dev.strath.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://netlogin-dev.strath.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://netlogin-dev.strath.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "strath.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://netlogin.strath.ac.uk/img/strath_logo_82x60.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "82"
                  },
                  {
                    "text": "https://netlogin.strath.ac.uk/img/strath_logo_16x12.png",
                    "height": "12",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://netlogin.strath.ac.uk/img/strath_logo_22x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "22"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Strathclyde"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVALntfhDpdib1U8g0APCYQ0HzFX4HMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCQxIjAgBgNVBAMMGW5ldGxvZ2luLWRldi5zdHJhdGguYWMudWswHhcNMTQx\n\t\t\t\t\t\tMTA3MTQ1MDAzWhcNMzQxMTA3MTQ1MDAzWjAkMSIwIAYDVQQDDBluZXRsb2dpbi1k\n\t\t\t\t\t\tZXYuc3RyYXRoLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\tn5KFxtDXYrp4ChYev6BWlmqRZWRKiGVKqukVMC9qEkRiDWkwCUU5IgPkKH3IwJfW\n\t\t\t\t\t\tAO1xGZ+s+kZ2hwjgCVXCYMmlwk5RlRKkcCTTjqHjSZ7ZNKA2hEWOaBJF3F9lFbwk\n\t\t\t\t\t\tAyvMUi4qn7f+mDybZHr9pbl4phANo8Fs3gnPr+yAp+G6F0EyL3At5SKpnanQ/lRy\n\t\t\t\t\t\tdTCuXMTukeI1TDtvptr7jV2HjpO4KmEILiCsqDvnjNMT2YEFlgxa8bX+YGXG/8cH\n\t\t\t\t\t\t6LKIQOtvSsg0D3xZvmazOWo6xg9XMAgKh6J+tE0HUr6Js16g/GxXghxfQA/rXmh+\n\t\t\t\t\t\tlK0bYueUgkjyXSclGQe9uwIDAQABo3kwdzAdBgNVHQ4EFgQUHCmyxQT1A5E7uqal\n\t\t\t\t\t\txfUiaDHwCgowVgYDVR0RBE8wTYIZbmV0bG9naW4tZGV2LnN0cmF0aC5hYy51a4Yw\n\t\t\t\t\t\taHR0cHM6Ly9uZXRsb2dpbi1kZXYuc3RyYXRoLmFjLnVrL2lkcC9zaGliYm9sZXRo\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQCbAbHeCjRT5CzbWDX9I1VLo3Y0hEjlmiwCvAZX\n\t\t\t\t\t\tyKPZ5FO5fJVCtI2aqOToFbF2BVOe3/mYV8sC6dsoS38Sarwhzbh6GRRE3FywuPbp\n\t\t\t\t\t\tUkQGTeAmB7jZ7kXLRS/tgVJbWzChljeVqofhwXjW4PfPugSuslpC+elp9PoTj/BP\n\t\t\t\t\t\tOrfOIm9jSMG2/HPbaVR9VynfXThx+mYa261FIVQuaha6K+s4Y3vGU3qgyTtnyNYv\n\t\t\t\t\t\tpOIaOiV5+TEokiP5oOHdbyH5Ax5+w/Tx400X/jebeY6vTW6WTKDlYMnmP/Fbv8d6\n\t\t\t\t\t\tAZTALOEzlYlDfuws2MF1Tc3K10VtbOMIL90R5JROBwVMKw0j"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Strathclyde"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.strath.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Strathclyde"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://repository.jisc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smyth"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itservicedesk@jisc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Laura"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bradley"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jb4@ecs.soton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Justin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://repository.jisc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-09-27T14:57:21Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "JISC Repository"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.jisc.ac.uk/aboutus.aspx"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Jisc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://repository.jisc.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://repository.jisc.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://repository.jisc.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://repository.jisc.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://repository.jisc.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://repository.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://repository.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Online access for registered users to JISC Repository."
                  }
                ],
                "logo": [
                  {
                    "text": "https://repository.jisc.ac.uk/shib/shib_repository_logo.png",
                    "height": "68",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "JISC Repository"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJALWBNu60kA8RMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGGpyZXBsdjAxLmppc2MudWxjYy5hYy51azAeFw0xMjA3MDUxMzQ1NTlaFw0y\n\t\t\t\t\t\tMjA3MDMxMzQ1NTlaMCMxITAfBgNVBAMTGGpyZXBsdjAxLmppc2MudWxjYy5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBANMowFcUBw/JzuJmgKZj\n\t\t\t\t\t\tFOomnF2WVKgHSx/o9t7qz1M2nFTDdPVyOoofneLhp2PMPfpOaymaM2wVby+bqn/Y\n\t\t\t\t\t\tchnbZlG4+QwVP5sPl0DmlYu3PTnI/rsEpE1rZYVn0KAM9TR45wgE6LeA7PDuJd2J\n\t\t\t\t\t\ty15bi7h3rXCuQRQ1aZ8tRHD1fjBf6KiLm9B4bguHwLGeDgDrkA/JdY1Xeh4XTVar\n\t\t\t\t\t\tWHrnXdvY9V3vlN7uBNSd1O/eWNwE0pd0Y4a1ysf4BfNoYKjgH1AL8+7BSJDyTX2C\n\t\t\t\t\t\t7KP6oHRSNyN1vNE3UXVSC7cYH0tFGzEim0U+y5iM2zUdtnK1+EhwgAo8brILd1As\n\t\t\t\t\t\t8tECAwEAAaNGMEQwIwYDVR0RBBwwGoIYanJlcGx2MDEuamlzYy51bGNjLmFjLnVr\n\t\t\t\t\t\tMB0GA1UdDgQWBBQ0t7spq60qClWktBGJSUPQIRVaxjANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEApE0apWehglMp9y1cB0UdhOyXmfTq5pZ2C0alGrlEbNVT0Em7F8grWUylhTe4\n\t\t\t\t\t\tawNjE+xlABLi6tpG2KuMoHIhf1rrh5cdj/ghFupuhYM8f7I7lnXAGbJ4qHciHEyE\n\t\t\t\t\t\tocQQCWlh5ad/iAQttMmOoXhvDafSP/Qo+HQCLK6DuhWWCySMdMHOYuqnQeQTFsC/\n\t\t\t\t\t\tXCvc3RmAP9XqWR/l5KW9IwdMXkrZRle9VYOjsx7BKKufVb5OTScl5B94AHrJvc4P\n\t\t\t\t\t\tSfFVmy2rkht+5rqtDhiHHVkQyr1p40RnXgRNdk1MmkmhXkt4odKYTvTqscnVYvR9\n\t\t\t\t\t\tfHsDbj+iVNwcJSOlMecWJDLdeA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://repository.jisc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://repository.jisc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://repository.jisc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://repository.jisc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://repository.jisc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://repository.jisc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.reed.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "benp@reed.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ben Poliakoff"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mcolgrov@reed.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marianne Colgrove"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cus@reed.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Computer User Services"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tis@reed.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technology Infrastucture Services"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.reed.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.reed.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.reed.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.reed.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.reed.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.reed.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "reed.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Reed College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAPuLDfin459bH1TviFJwMkClxzSZMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDGlkcC5yZWVkLmVkdTAeFw0xMDEwMTMxODE1MjJaFw0z\nMDEwMTMxODE1MjJaMBcxFTATBgNVBAMTDGlkcC5yZWVkLmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAI0JgYyDRVnupzwsap5SRjk6vQc4KY3A4GcT\naWmwkbLILkXsK7+LqiJDcfQtyHQwZoJqJVBnd7NDXb1wPidAitC3m+bgOmf0SCM3\ncJ1u0giQGXxKqWW4Netq5ZWG/fZE7wR4rNqbYtQ31WPl5s5dkqVrq6na9NDKyCNb\n6qLd9306BiSCjAagJYN+xyMfCwZ2J2uBPwa1cTlv6B1M9k77v78PlwHeZTRBXQ7z\nJ385E+iMnxhuyKhj6bHjFplPJmHTBF1NcK1HLBuraocmwyhyXt6hc/pG1fLhhZ6+\n7RtgsH5RLQgE15MSW0e6UDbZHgxze0g13LfaQBa92KZOesO7V5kCAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMaWRwLnJlZWQuZWR1hiNodHRwczovL2lkcC5yZWVkLmVkdS9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU+ZuMoVaqb0MEU+U21XvPJLeCVlowDQYJ\nKoZIhvcNAQEFBQADggEBAC1ygplLdMG2sQC47jxquc0L/QJEZsn91dPv4pb5RbhP\nICvwKMhHqbG+4gc97ZRa5EzyuGNceHLJaG/MH18MPOyz06KlOL0zy3SdvFpRJMBV\nPfPWTRB/moSkz5lnBadHX3TQqdo/1AZvlzoPrWjz8lOu8//pIP7MxnzMxlm2KNuI\nTg5D2SHhV9dQur/QGSlkJ2REjrqKhyw9yAogB3AH0IY3rGnpmbmAc3ian+C6IZXH\nBpQPMrLCFksiKP4tBOH88PLItWn3uFc4Q8f1s+5qDxVIqWVTdjOkZnysMRob1y+w\nROMyInz+7gYPcFok9V3ghjhHj3POw+ZqlJA25Ap6v9Y="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Reed College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://reed.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Reed College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://federation.bretagne.iufm.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "federation@espe-bretagne.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federation.bretagne.iufm.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-10-12T16:14:58Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.bretagne.iufm.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federation.bretagne.iufm.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://federation.bretagne.iufm.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bretagne.iufm.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "espe-bretagne.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.espe-bretagne.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnels et \u00e9tudiant de l'ESPE de Bretagne"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ESPE de Bretagne"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ESPE de Bretagne"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVzCCAj+gAwIBAgIUKmBCYXflPLtHr7RZnoMPn/DvtmgwDQYJKoZIhvcNAQEF\nBQAwJjEkMCIGA1UEAxMbZmVkZXJhdGlvbi5icmV0YWduZS5pdWZtLmZyMB4XDTEz\nMDIwNTEzMTQxNVoXDTMzMDIwNTEzMTQxNVowJjEkMCIGA1UEAxMbZmVkZXJhdGlv\nbi5icmV0YWduZS5pdWZtLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAnGjACvIl7EYKjKCH0NF4ebs+TiUOvceisAhINr5e4O/BgsEV0pdwWky84VW4\n34IOhhS1OZfNof3DGqIFjIG10D+MMYR56+VWjLV1l4jTzPhxEM1Da4B9opclIqfa\nTuvYTG5taAQ0zH5F0/igiQwgfdQnb8JUb4GlKfvjrwGBEBrV4EdCwuII5gPTWlJP\nq5g5b4fYuLoCxpd21mzi85oVMB39IHCi8r3hlVHvnmdPCINW7DGF9ZSeQzmhJnCB\nD6qm+tOmLtj8PJTNvQ+w89BYCbcdEUOIc8QnGPcupP3eYbp3O03YE4Dslwxed2pT\nS/rBd8Nug44TIPqTPX5V7DaRNQIDAQABo30wezBaBgNVHREEUzBRghtmZWRlcmF0\naW9uLmJyZXRhZ25lLml1Zm0uZnKGMmh0dHBzOi8vZmVkZXJhdGlvbi5icmV0YWdu\nZS5pdWZtLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQs9Bw6sfV70qXt48wu\nK1zo2uyoYzANBgkqhkiG9w0BAQUFAAOCAQEAY3y7sMljpfd/g1fNhDxnOYRevqi1\nEe88d37yE/yVPapmcSHdIzV6vrDl+g+2cD1+sPB5Y5dMVixiptVX5+1ey55Mpb4e\nMTzmP7yDaL1eHKN+7NndjBOdF8nXheaB+/PRXuwp3dlSQrumH2kIPGA2iLHXHDlp\nytKmSaXH1HkcgcjQe5cgHinQd9sA22s4pMJ309e6Y/8+IUq7Vc75+1YrnnDHF7mx\nXwWUOQkoMHoHa30vcT2jQVKThDWJj7WLPSDv9t0CTUy8ToOSBTfvooHJOZhsLQzG\nIgfeq0NJEYoEobPu+TwPdcY7Mzham8UC11Kt0r95Ti9Wpfe7OfMDHhPmfA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEhDCCA2ygAwIBAgIRAPSODBFpc8g+0TGgl6Q8SN8wDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xMzAyMTEwMDAwMDBaFw0xNjA0MDUyMzU5NTlaMEkxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEkMCIGA1UEAxMbZmVkZXJhdGlv\nbi5icmV0YWduZS5pdWZtLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEA0W8trO2zbN+5N30+4N+JpWEmcmUbp2wYAJB0v4rinl6MzMs007wHfKj14rKC\n5eIvkbtgzbhs/biZVvA+/Xky7TyIL/Z/34Ha1JeoYsezfmdf0qT8J2jOcuG8DVU3\n/J6Mtg9Zfz4GwNq4NFO4qx0vXZhX3LT3+8sQmPH96a9XmrPQB514Flc1mWZmZ/he\nXdTkhmu/o9/3fx2guNwjddQ9ruWalmSpTD7FSt5LMsavWfp4niATTcGXR+yQsWuG\nULjIMfWUjmaY+0s+658WSZzD+o9sFknoQpNKjufCkEFUMQuUfFfZGJlGxZOYRhDq\neHNFgFBHzZHXixrjge2HVA1fxQIDAQABo4IBeDCCAXQwHwYDVR0jBBgwFoAUDL2T\naAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFC4C3PlQ1bY/T8VIR4gpUtQKnfm8\nMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUF\nBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAEC\nATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RF\nUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6\nLy9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzAB\nhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAmBgNVHREEHzAdghtmZWRlcmF0\naW9uLmJyZXRhZ25lLml1Zm0uZnIwDQYJKoZIhvcNAQEFBQADggEBABBedNTktIew\nJsv/6U2BjnnBtL7+nRX5nHE5M+oqIO39NJg0iDuWNAXJK9p36C31ucuNTAYrFvQq\nvBrMiwjDwpaNCAs6/3c1J9iH8GH9r2FONFFXHGswvKhlwqE7MaQh2l/+qHs4wfRe\nnsP2N+nWD1nvxIlQvfcF5W2mZWxE5ZT73etDiilcorRvI423P5BeeRYciBa8im8A\nGrGTlcvHZkTfuZ01NQiTnXnWmghzyqug72nwj42FLThQgDdeDOrzTEKREtehNcpp\nPULGkDErBea0SdXtVN3swhySNl9Ba69OYezLZ8hdDCrcN3wPw8VGi6xDMa4ENkKL\nhjz3pTN+SFo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ESPE de Bretagne"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.espe-bretagne.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ESPE de Bretagne"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.csub.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "netops@csub.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Network Operations Center"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.csub.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.csub.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.csub.edu/idp/profile/Shibboleth/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.csub.edu/idp/profile/Shibboleth/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.csub.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.csub.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csub.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "California State University, Bakersfield"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFxTCCBK2gAwIBAgIQPc05I8UKJsaaDlPUHfscQzANBgkqhkiG9w0BAQUFADCB\niTELMAkGA1UEBhMCR0IxGzAZBgNVBAgTEkdyZWF0ZXIgTWFuY2hlc3RlcjEQMA4G\nA1UEBxMHU2FsZm9yZDEaMBgGA1UEChMRQ09NT0RPIENBIExpbWl0ZWQxLzAtBgNV\nBAMTJkNPTU9ETyBIaWdoLUFzc3VyYW5jZSBTZWN1cmUgU2VydmVyIENBMB4XDTEw\nMTIwMzAwMDAwMFoXDTExMTIwMzIzNTk1OVowgeMxCzAJBgNVBAYTAlVTMRMwEQYD\nVQQREwo5MzMxMS0xMDIyMQswCQYDVQQIEwJDQTEUMBIGA1UEBxMLQmFrZXJzZmll\nbGQxHDAaBgNVBAkTEzkwMDEgU3RvY2tmaWVsZCBId3kxMTAvBgNVBAoTKENhbGlm\nb3JuaWEgU3RhdGUgVW5pdmVyc2l0eSwgQmFrZXJzZmllbGQxDDAKBgNVBAsTA0lU\nUzEgMB4GA1UECxMXQ29tb2RvIE11bHRpLURvbWFpbiBTU0wxGzAZBgNVBAMTEmlk\ncDAuc2hpYi5jc3ViLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAL/HZKeM0Qvx2uKJD6Gtp4yw7B8WAAANMFOTT9I37tU24Bopb5XMC9kLskfvo3/B\ntgK4hfLTomHCtpUbQ9BaO6VSOGo7+8WaLRvPiBjwROfPML7vuf6nY7+j7VxsvXim\ndD/irAv+F3yLJv8sx/wHm9g30fxlc/3fUzpthatHKlIMFPOnwwCKS6ZMuGPZJO+A\nyDk6HJPLK+kEiZDutI0vlAUaKYL/J1clbCpZ5n0CDYy6dQVLQTZY8gn6tW4AcBSY\ng5yPbU5Q3mYSgr5JsCt8xdGcp+ujDceRGYdFmHtHiUGo6QR8UK74KCsiojyB/dl/\niXzp6GDZzoL9bx+75P9LhX0CAwEAAaOCAcswggHHMB8GA1UdIwQYMBaAFD/VtdDW\nRHlQShejm4xK3LiwImRrMB0GA1UdDgQWBBRAziDZJaj+HbwF8pSLF2l1nf4MLTAO\nBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcD\nAQYIKwYBBQUHAwIwRgYDVR0gBD8wPTA7BgwrBgEEAbIxAQIBAwQwKzApBggrBgEF\nBQcCARYdaHR0cHM6Ly9zZWN1cmUuY29tb2RvLmNvbS9DUFMwTwYDVR0fBEgwRjBE\noEKgQIY+aHR0cDovL2NybC5jb21vZG9jYS5jb20vQ09NT0RPSGlnaC1Bc3N1cmFu\nY2VTZWN1cmVTZXJ2ZXJDQS5jcmwwgYAGCCsGAQUFBwEBBHQwcjBKBggrBgEFBQcw\nAoY+aHR0cDovL2NydC5jb21vZG9jYS5jb20vQ09NT0RPSGlnaC1Bc3N1cmFuY2VT\nZWN1cmVTZXJ2ZXJDQS5jcnQwJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmNvbW9k\nb2NhLmNvbTAsBgNVHREEJTAjghJpZHAwLnNoaWIuY3N1Yi5lZHWCDXNoaWIuY3N1\nYi5lZHUwDQYJKoZIhvcNAQEFBQADggEBAB+4/dnbNTB1MBfjj43ltyzTVBUa2V7B\nSZc5CoZNdsNrXEAyFGxR6MJWfqz0WyNYtEyj66MrJKGFvxaEhcvhBbQFkymfZOGG\nj82KRyAEk4BfyJl+0B1w1jcVQp0EyWT45B3mXhDNdEW4MC83QHdcrk75TEFaUR7f\nCuph5aZTUR+pAj4g+ks54l5X6Q0hj6VBKInLv7DwXcwizR56O3e/fV6E49qNm2YF\n4tYQJZJ8/YKA8V2GzKr2k64ZpHIBYg3k3XLEJ6mSpP2XWYc5Lkx0VgTk9PiSPrzz\nQF+Q3+1t51b68ryVpJeqcC9J/6pKQDd18xvgtLXJFKoIzs68rKYsUfA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVANTK3G8C7AHnSEGrmCj2kqRBk2pBMA0GCSqGSIb3DQEB\nBQUAMB0xGzAZBgNVBAMTEmlkcDAuc2hpYi5jc3ViLmVkdTAeFw0xMDA1MjQyMTQw\nMzZaFw0zMDA1MjQyMTQwMzZaMB0xGzAZBgNVBAMTEmlkcDAuc2hpYi5jc3ViLmVk\ndTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJB8I56qhCOavz3K3BfC\ns/LhLDlXTPfV6d7pbkH6XGIlSpUGS4wtuqiSVec1o8PDHZmZfpbYA79RmOEcPJAW\n323LYk15GSYZSgW5kJjbegIdnYdzm4UgBQbbvfYRdoM7Zklyv/qJ+gzTuENuTHqI\nPOe2/OSHXzn/XFAhB4vwEtvh4oR9Hwf73zS/JedVNXrz67XqRYCLsGi9c/C8Wa98\nPyU2yBHuXFmfkpmW1g52pF8NLTKmUwVV/iq+zMXWqnMLKJh3Nzj808r0OJ0eLtsZ\nVsmpYtxD6yNJTFvRUvwpCDdq04mQq6W9oNFh+5QqToaq9Xa2KLIyWMsUYpIkcnE3\nQGkCAwEAAaNrMGkwSAYDVR0RBEEwP4ISaWRwMC5zaGliLmNzdWIuZWR1hilodHRw\nczovL2lkcDAuc2hpYi5jc3ViLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\nZ7PJGtKy5x6V8xiLXG9VS+ogZhQwDQYJKoZIhvcNAQEFBQADggEBAEeX1PL/cFH6\nnDjkH9u7WjfBP0etCr1SWOcpADrdv/9y1QkfP9vW5pk9UTf1/qdZw0SyPq+OC6+y\nqn+7ljz4TbuMcqmdwjPQW5WmMFeamJCU8EoXYOmLzmiigAai3lxNefzrmvFleV9j\nxA787/E2iA7cpHq89gGQNH/jlGMnyAjV69VO6v7X/CD7E5pIIlYzw0ZMAC1a1tie\no+UtOXA0Di8W4M4d00na+QjugX9++yOX+88VYqnbzldY5M1VTWJCSsSY9kbtNtRO\nxMhd5OBqZzYJDvXNjaJrMGbFjw+lYQfFaR6/SYVfjihaGN38RlOqxMLZlIV/DwSZ\nWYA2GI4Dt+c="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California State University, Bakersfield"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csub.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California State University, Bakersfield"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://lmuidp.lrz.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ebner"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth@lrz.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ralf"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "LMU-Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@campus.lmu.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LMU-Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://lmuidp.lrz.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2009-11-11T14:59:40Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://aai.dfn.de/category/vetmed-member"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "lmuidp.lrz.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGKTCCBRGgAwIBAgIHGEI+4+lgoTANBgkqhkiG9w0BAQsFADCBnTELMAkGA1UE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"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=lmuidp.lrz.de,OU=Leibniz-Rechenzentrum,O=Bayerische Akademie der Wissenschaften,L=Garching b. Muenchen,ST=Bayern,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "lmuidp.lrz.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGKTCCBRGgAwIBAgIHGEI+4+lgoTANBgkqhkiG9w0BAQsFADCBnTELMAkGA1UE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"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=lmuidp.lrz.de,OU=Leibniz-Rechenzentrum,O=Bayerische Akademie der Wissenschaften,L=Garching b. Muenchen,ST=Bayern,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lmu.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://lmuidp.lrz.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lmuidp.lrz.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://lmuidp.lrz.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lmuidp.lrz.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://lmuidp.lrz.de/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lmuidp.lrz.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://lmuidp.lrz.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lmuidp.lrz.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lmu.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://lmuidp.lrz.de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://lmuidp.lrz.de"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity-Provider f\u00fcr die LMU"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for LMU"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e4t M\u00fcnchen (LMU)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e4t of Munich (LMU)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "lmuidp.lrz.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGKTCCBRGgAwIBAgIHGEI+4+lgoTANBgkqhkiG9w0BAQsFADCBnTELMAkGA1UE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"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=lmuidp.lrz.de,OU=Leibniz-Rechenzentrum,O=Bayerische Akademie der Wissenschaften,L=Garching b. Muenchen,ST=Bayern,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "lmuidp.lrz.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGKTCCBRGgAwIBAgIHGEI+4+lgoTANBgkqhkiG9w0BAQsFADCBnTELMAkGA1UE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"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=lmuidp.lrz.de,OU=Leibniz-Rechenzentrum,O=Bayerische Akademie der Wissenschaften,L=Garching b. Muenchen,ST=Bayern,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ludwig-Maximilians-Universit\u00e4t M\u00fcnchen"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ludwig-Maximilians-Universit\u00e4t M\u00fcnchen"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://lmuidp.lrz.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://lmuidp.lrz.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e29"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e29"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.west-lothian.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.west-lothian.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/west-lothian.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/west-lothian.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "west-lothian.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "West Lothian College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.west-lothian.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.morganclaypool.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.morganclaypool.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Morgan & Claypool Publishers"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.morganclaypool.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEbjCCA1agAwIBAgIJANEyiht0lGz3MA0GCSqGSIb3DQEBBQUAMIG3MQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEUMBIGA1UEBxMLU2FudGEgQ2xh\n\t\t\t\t\t\tcmExHTAbBgNVBAoTFEF0eXBvbiBTeXN0ZW1zLCBJbmMuMR0wGwYDVQQLExRBdHlw\n\t\t\t\t\t\tb24gU3lzdGVtcywgSW5jLjEfMB0GA1UEAxMWd3d3Lm1vcmdhbmNsYXlwb29sLmNv\n\t\t\t\t\t\tbTEeMBwGCSqGSIb3DQEJARYPdmFrZUBhdHlwb24uY29tMB4XDTA5MDcyMzE4MjQz\n\t\t\t\t\t\tM1oXDTE5MDcyMTE4MjQzM1owgbcxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpDYWxp\n\t\t\t\t\t\tZm9ybmlhMRQwEgYDVQQHEwtTYW50YSBDbGFyYTEdMBsGA1UEChMUQXR5cG9uIFN5\n\t\t\t\t\t\tc3RlbXMsIEluYy4xHTAbBgNVBAsTFEF0eXBvbiBTeXN0ZW1zLCBJbmMuMR8wHQYD\n\t\t\t\t\t\tVQQDExZ3d3cubW9yZ2FuY2xheXBvb2wuY29tMR4wHAYJKoZIhvcNAQkBFg92YWtl\n\t\t\t\t\t\tQGF0eXBvbi5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC1jZrb\n\t\t\t\t\t\tEIm3NwRJ8SkkHkvjKSWe4vuqyfO1D1MAVZzy5FzSLOeup4qEyCDkwtzrN3vSYNa1\n\t\t\t\t\t\t4qovhIs+Eeap6FXH3XkhzZluSn4rKM/IoetfcP74l99cIzn4xMZfknhk9NNnb2vE\n\t\t\t\t\t\tL/dJSu/8LyGFxr2b8c5cdYzgFiN77peyf4kOYCMJhC5xYXogrtFlmzkhbk6CRK36\n\t\t\t\t\t\tQELJmbcegneoglceycLwmunJvhbkIagouT/AFxm7m9FFR2AbGQ2m52DdCSJdY6Q/\n\t\t\t\t\t\t+cRnIO3p3Jar0D+huhNPlTyH5XNw41kPH4WvQiYAq7j40cFEwYHU4hOrBkKrdLUz\n\t\t\t\t\t\thPjVz1iquFai4gY1AgMBAAGjezB5MAkGA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8W\n\t\t\t\t\t\tHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRpZmljYXRlMB0GA1UdDgQWBBSntSFOeKeT\n\t\t\t\t\t\tNvcbAlIaG09llX2rAzAfBgNVHSMEGDAWgBSntSFOeKeTNvcbAlIaG09llX2rAzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAQguA1fll3LnjT1NokQTeSc1gmZIlbD318j6SKojU\n\t\t\t\t\t\tzDYXinKZtzK9T0t1e1BFlOnbPGN1Fu1VkGLuOp5Z5/AJqMJJ9hfSOTjtz99AUk20\n\t\t\t\t\t\tOjgsw76oZ5nwqvk2lxKregha/GIkT7nJp8ycuQVI1ahnh142BDrfuB5DFAcHvi1q\n\t\t\t\t\t\tv3NXHQuorkykb0mBuduNW+Uvk2T7wiNzruCOpBJGZzJZw3/FNXGCb3MmtaJgf7Br\n\t\t\t\t\t\t+B02aD7lQHX2jczKW50vxU46gvji7sBWUlCeYT+JeBQpBKT6SOPtHBLcSNIwhDzG\n\t\t\t\t\t\tU5jsgJ4S54QwA12aggwYfLERyqoQLPepkxvA2QygkK7JeQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.morganclaypool.com/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.morganclaypool.com/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.morganclaypool.com/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.techlib.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Koch"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ondrej.koch@techlib.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ondrej"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.techlib.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2013-08-05T12:59:38Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/library"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUX+osnvtxGkyyLqc3Z6xHhgMJP1cwDQYJKoZIhvcNAQEF\nBQAwIDEeMBwGA1UEAxMVc2hpYmJvbGV0aC50ZWNobGliLmN6MB4XDTEwMDIxNzEy\nMjYwM1oXDTMwMDIxNzEyMjYwM1owIDEeMBwGA1UEAxMVc2hpYmJvbGV0aC50ZWNo\nbGliLmN6MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAi5FN6efQHuiH\nzERWjziRdD9X4sF76m0v9dest6lxrVXdxBIMjo52h7zkmZnWTwr402rCu6MLr2rX\nLfz050FcEGSBDQyVr47QsUEQkvsThjdb2LZtjHzxiMc20fngB5+7nrZG4pBwragw\nXxfklvQ9VVdhQ1evD4QLn9Vj0LavZi9BzyOtbO6nPzzw624u0buU/QNeZAs2gNgj\nDJKx2UQW50R/YJUHz7XEd/q8r48+gSWkqh0KPvAbqaQJkZJ2lwyggcqPCV9i9wlF\naUuE8aDyVKUkmT6Z8HfJKsFUgoGbiUvMMHTKuasiT4UP9hBvVrwgsIjOvSVu9NnL\nuxtP5VnHvQIDAQABo3EwbzBOBgNVHREERzBFghVzaGliYm9sZXRoLnRlY2hsaWIu\nY3qGLGh0dHBzOi8vc2hpYmJvbGV0aC50ZWNobGliLmN6L2lkcC9zaGliYm9sZXRo\nMB0GA1UdDgQWBBRvpKOl45kZis1SGQnbs2WT6PX2UjANBgkqhkiG9w0BAQUFAAOC\nAQEAbtw87jOn1csGq3iYcEzPXyNO9j+YX1OFhjWhnjhD0z14FYOJKvr2yZ49hJoA\nUoxLanwsquNEE5MyxwlFjE0J9KAg+gTYZ/RQtUWI4qPMOGHzfT02U6HdXtMJVZOO\nCKGd9enAzy87bQ6lSYLMDgwDSvnTy47Xlv3z4a4IPy8+OJrMs5uE2vRs3+iYlDu3\nX/rdSE1Mpx7yDu7Zb/g1xGNOvmIMrZj1rS5rett+ODN9ewGj64Jm0dbfkjoquz7K\ncz9PxjipO+0hvnpmik2TpUCMnPwgLo7RXw0P0huR/qnT5LK6LWpfoNY4ZVEQ3FMu\nmYyU0qeHcluLxU/GrWy+OGqcqQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "techlib.cz"
              },
              {
                "logo": [
                  {
                    "text": "http://www.techlib.cz/public/images/logo-eduid.png",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "67"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "National Library of Technology"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "N\u00e1rodn\u00ed technick\u00e1 knihovna"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.techlib.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.techlib.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.techlib.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.techlib.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.techlib.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.techlib.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.techlib.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.techlib.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "techlib.cz"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for National Library of Technology in Prague."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro N\u00e1rodn\u00ed technickou knihovnu v Praze."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.techlib.cz/public/images/logo-eduid.png",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "67"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "National Library of Technology"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "N\u00e1rodn\u00ed technick\u00e1 knihovna"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUX+osnvtxGkyyLqc3Z6xHhgMJP1cwDQYJKoZIhvcNAQEF\nBQAwIDEeMBwGA1UEAxMVc2hpYmJvbGV0aC50ZWNobGliLmN6MB4XDTEwMDIxNzEy\nMjYwM1oXDTMwMDIxNzEyMjYwM1owIDEeMBwGA1UEAxMVc2hpYmJvbGV0aC50ZWNo\nbGliLmN6MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAi5FN6efQHuiH\nzERWjziRdD9X4sF76m0v9dest6lxrVXdxBIMjo52h7zkmZnWTwr402rCu6MLr2rX\nLfz050FcEGSBDQyVr47QsUEQkvsThjdb2LZtjHzxiMc20fngB5+7nrZG4pBwragw\nXxfklvQ9VVdhQ1evD4QLn9Vj0LavZi9BzyOtbO6nPzzw624u0buU/QNeZAs2gNgj\nDJKx2UQW50R/YJUHz7XEd/q8r48+gSWkqh0KPvAbqaQJkZJ2lwyggcqPCV9i9wlF\naUuE8aDyVKUkmT6Z8HfJKsFUgoGbiUvMMHTKuasiT4UP9hBvVrwgsIjOvSVu9NnL\nuxtP5VnHvQIDAQABo3EwbzBOBgNVHREERzBFghVzaGliYm9sZXRoLnRlY2hsaWIu\nY3qGLGh0dHBzOi8vc2hpYmJvbGV0aC50ZWNobGliLmN6L2lkcC9zaGliYm9sZXRo\nMB0GA1UdDgQWBBRvpKOl45kZis1SGQnbs2WT6PX2UjANBgkqhkiG9w0BAQUFAAOC\nAQEAbtw87jOn1csGq3iYcEzPXyNO9j+YX1OFhjWhnjhD0z14FYOJKvr2yZ49hJoA\nUoxLanwsquNEE5MyxwlFjE0J9KAg+gTYZ/RQtUWI4qPMOGHzfT02U6HdXtMJVZOO\nCKGd9enAzy87bQ6lSYLMDgwDSvnTy47Xlv3z4a4IPy8+OJrMs5uE2vRs3+iYlDu3\nX/rdSE1Mpx7yDu7Zb/g1xGNOvmIMrZj1rS5rett+ODN9ewGj64Jm0dbfkjoquz7K\ncz9PxjipO+0hvnpmik2TpUCMnPwgLo7RXw0P0huR/qnT5LK6LWpfoNY4ZVEQ3FMu\nmYyU0qeHcluLxU/GrWy+OGqcqQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "National Library of Technology"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Narodni technicka knihovna"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.techlib.cz/en/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.techlib.cz/cs/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National Library of Technology"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Narodni technicka knihovna"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp4.londonlibrary.co.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "David"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:will.david@londonlibrary.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Will"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "David"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:will.david@londonlibrary.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Will"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp4.londonlibrary.co.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-02-18T18:00:43Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp4.londonlibrary.co.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp4.londonlibrary.co.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp4.londonlibrary.co.uk/idp/profile/SAML2/POST-SimpleSign/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp4.londonlibrary.co.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp4.londonlibrary.co.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp4.londonlibrary.co.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp4.londonlibrary.co.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp4.londonlibrary.co.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp4.londonlibrary.co.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp4.londonlibrary.co.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "londonlibrary.co.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://idp4.londonlibrary.co.uk/idp/images/logo.png",
                    "height": "122",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "122"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "London Library"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIVANU4ahFCyREJu8AncXjGLDT0D6P3MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMCMxITAfBgNVBAMMGGlkcDQubG9uZG9ubGlicmFyeS5jby51azAeFw0xNTEy\n\t\t\t\t\t\tMjMxNDM2MzVaFw0zNTEyMjMxNDM2MzVaMCMxITAfBgNVBAMMGGlkcDQubG9uZG9u\n\t\t\t\t\t\tbGlicmFyeS5jby51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIdm\n\t\t\t\t\t\t9sxIIEnGhBRlShf/UXF9fWpV990yAbCiPMJui3CB2Mqjq9bOGpGFacDmm9qGOxNi\n\t\t\t\t\t\t9/XAY1VQgctuOy4FacW8c09vmz92eEoF9+6SdS3cfoMo8hV2n0ZxeJ1jNdH/S4YL\n\t\t\t\t\t\tdMntK6E2SUr9dO8CNSHnoIgG/scg56WEpT+b8Zzv5I5eUf60U7AMdE5fkAwhTGeL\n\t\t\t\t\t\tPUrYvJae2iFrvOKukJnyZKihhYCDAhK9MzRdycoqWNoPzLYLxbVN0GkPsxtJ0eWN\n\t\t\t\t\t\tfn6ZhN7CpoGKcz1LwNT/3kSDClEm2toezSFI52YetrgYBhYThrPXZHqLXdhBV3+z\n\t\t\t\t\t\tI4fk566WWuoYshz92fUCAwEAAaN3MHUwHQYDVR0OBBYEFCYKRXFSNHDJ79VP0TsZ\n\t\t\t\t\t\tBpqR80g3MFQGA1UdEQRNMEuCGGlkcDQubG9uZG9ubGlicmFyeS5jby51a4YvaHR0\n\t\t\t\t\t\tcHM6Ly9pZHA0LmxvbmRvbmxpYnJhcnkuY28udWsvaWRwL3NoaWJib2xldGgwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQELBQADggEBAHTql6rs+rBNVUL3iVNGdaQZdmYlZNfFs6F9JFML6ukx\n\t\t\t\t\t\t3LGSkyPsaWy9Dz2qCuUZAfuKUDYbMxqn+d6CwuJPuWxJ33zezBRfktSLYUo/+OeG\n\t\t\t\t\t\t/21a/Q/kwW6VVNMga2klDmPX7IfFx9aZcHgr4Aa5zbeZZzxCOK6TshjSBS/vWEjU\n\t\t\t\t\t\tOSXoxDlYcrryb54VDA2adseYCO4ysfPYvWfQyKruFyJ6XQfz8lLgCe7U3alpBUvT\n\t\t\t\t\t\t4QUpkVc51DHl17kX6EFmwtB8KPVd0qOl4MgPueYN+vYpkqvXdsXmClX0BHH7D9/l\n\t\t\t\t\t\twziHAcu2ZDvDd+U7O3U8bcnV/jUXt4PDHcDarKvmHDg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSzCCAjOgAwIBAgIUX2TNeT7B9swpWFpSgg3etUWCg/8wDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwIzEhMB8GA1UEAwwYaWRwNC5sb25kb25saWJyYXJ5LmNvLnVrMB4XDTE1MTIy\n\t\t\t\t\t\tMzE0MzYzNloXDTM1MTIyMzE0MzYzNlowIzEhMB8GA1UEAwwYaWRwNC5sb25kb25s\n\t\t\t\t\t\taWJyYXJ5LmNvLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAjkEN\n\t\t\t\t\t\tJ+iiJH+fDNmXkUmf+kfICxDw1ziW0vomUw0P+FEkaOPlIgHGH9r7ZVj/ScZ0mP3F\n\t\t\t\t\t\txijL8HWluS5ZTqHuwxRJu8droMG+cvxkEzxCt1cT1Qf+pf6UswluNtV7Iih2EoLx\n\t\t\t\t\t\t10k5tRiAEWAgDAjyJ6+Z+eTyHtYBu+ThTI8NQu6oG3Q2bb4qS0LQ3PlAT6Q8ofGZ\n\t\t\t\t\t\tTwycp1qAKlzGpyod19YXeSxiT2aO5/z29w0ziQdzjGDtMt4vtrTrPES7MVdvvsOg\n\t\t\t\t\t\tCTlJJe26W2xV58HGeoeOA2EQCe/cQHotci8bpUHGK0Pwse0FyMRYy8c1Gqm+ACDn\n\t\t\t\t\t\tvQom4D0fKMxa4CfFRwIDAQABo3cwdTAdBgNVHQ4EFgQUmwJoqaPoeqf82tnA22/W\n\t\t\t\t\t\twFC1CkAwVAYDVR0RBE0wS4IYaWRwNC5sb25kb25saWJyYXJ5LmNvLnVrhi9odHRw\n\t\t\t\t\t\tczovL2lkcDQubG9uZG9ubGlicmFyeS5jby51ay9pZHAvc2hpYmJvbGV0aDANBgkq\n\t\t\t\t\t\thkiG9w0BAQsFAAOCAQEAP3dVYhUJEi6PKOZWdlRiwJPxn3RImzOi+uL/te7HOnyc\n\t\t\t\t\t\tqW5bCY34GB7GNznavh1j6UKVOFYNJW+/Zx9F5DmVT3drrsDCrA9OP/ypJiWUUUXX\n\t\t\t\t\t\tCTGAXwkNDGOGLz+8PB/MpSYSV5sw8myS6qH4+rgeDDTUImXy7SnZ4kXVYu3rz5Gc\n\t\t\t\t\t\to+W4T6h8tHRYY7QgzP+KyNW4UUeVb8Ihc1OKDdJOh4YWUy/W1pi5tn/BIM8Q83Lf\n\t\t\t\t\t\tTFCEQzRqrF4Ce3rqTwWUgpNOAENvJpwAyxpL7RdNB2SbDW9+cdOxVikgj7kzOD+j\n\t\t\t\t\t\tqWH4Y40DCwr1AzCC4oXb3df22B9y8VqKMDVQU1aHVw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDuTCCAqGgAwIBAgIJALXV9dV3yr97MA0GCSqGSIb3DQEBCwUAMHMxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMRMwEQYDVQQIDApTb21lLVN0YXRlMQ8wDQYDVQQHDAZMb25kb24xGzAZ\n\t\t\t\t\t\tBgNVBAoMElRoZSBMb25kb24gTGlicmFyeTEhMB8GA1UEAwwYaWRwNC5sb25kb25s\n\t\t\t\t\t\taWJyYXJ5LmNvLnVrMB4XDTE2MDMyMTA5NDU0NVoXDTMxMDMxODA5NDU0NVowczEL\n\t\t\t\t\t\tMAkGA1UEBhMCR0IxEzARBgNVBAgMClNvbWUtU3RhdGUxDzANBgNVBAcMBkxvbmRv\n\t\t\t\t\t\tbjEbMBkGA1UECgwSVGhlIExvbmRvbiBMaWJyYXJ5MSEwHwYDVQQDDBhpZHA0Lmxv\n\t\t\t\t\t\tbmRvbmxpYnJhcnkuY28udWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDV1NnpBxZ+8jUIoU6mDDXHn8JjiNluzvjpCBn+GSThSIbkLygZPlyp6kxmsS26\n\t\t\t\t\t\tKld9MsyS7pZHSUGARjrGfvXxwgw6ET1xlCS+7KIHKxBMvagBSAy+h7Ci6lj3xT5u\n\t\t\t\t\t\tekqBzdanJROSer2V9NiKRlCNo5kRBJiVmqy4CDndVUnsCn3hm51qv4cGChdCspuV\n\t\t\t\t\t\tS8Yx3c1pBahRNiaCB6fZJ+H98VEXKmFscXXfj6ypmK1+lFtOhS+AAYM2Y53fZI/D\n\t\t\t\t\t\tcqzwCvRcffCJTrKdo9Y7zAkv6FS/X1ygaLUHIhIU1aZbkP+3XrkGnnuLXC+EHwdB\n\t\t\t\t\t\tae6O514c1OXdvlbwz3CM3puXAgMBAAGjUDBOMB0GA1UdDgQWBBTlTj4+ktNJjO6S\n\t\t\t\t\t\tdK+sSRpsVlAxxzAfBgNVHSMEGDAWgBTlTj4+ktNJjO6SdK+sSRpsVlAxxzAMBgNV\n\t\t\t\t\t\tHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQATaIK5eGEZS0KCsxIEX5yE0GwU\n\t\t\t\t\t\tKfdn10aeA2pM+vB54e/2MmS8IObRBKDKKgubeFFC63BfabjLZx5KnLzU/hfaDnRq\n\t\t\t\t\t\tzomhmPV17n5zaBOtLAeG+8VoGVN6VNEP4Iuv/HbqEujXdLn/lN1qbuJTD1IwqdzE\n\t\t\t\t\t\tiOobLUS3hLOYAxb6HhaBrU4GoEH1rR9NirRtF6LtRu4VuULZUkDjDcCJHmREGIwM\n\t\t\t\t\t\ts+8EuCx+rPd//ZgkZbXpBQSjJ1hlzvTOWlle48d/9LuHdink5vvRKNiOHSFk2cLe\n\t\t\t\t\t\t8ysYf5LGOy9GSO12g2+E24IJYWIedNgCMyTz9zwCcIFuVmaam1Xgdwhp8DhO"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "London Library"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.londonlibrary.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "London Library"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.gallaudet.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "earl.parks@gallaudet.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Earl Parks"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "hatim.vali@gallaudet.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hatim Vali"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mohib@gluu.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mohib"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.gallaudet.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.gallaudet.edu:9443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.gallaudet.edu:9443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID9DCCAtwCCQCbiUruOaohoTANBgkqhkiG9w0BAQsFADCBuzELMAkGA1UEBhMC\nVVMxCzAJBgNVBAgMAkRDMRMwEQYDVQQHDApXYXNoaW5ndG9uMR0wGwYDVQQKDBRH\nYWxsYXVkZXQgVW5pdmVyc2l0eTEmMCQGA1UECwwdR2FsbGF1ZGV0IFRlY2hub2xv\nZ3kgU2VydmljZXMxGjAYBgNVBAMMEWlkcC5nYWxsYXVkZXQuZWR1MScwJQYJKoZI\nhvcNAQkBFhhoYXRpbS52YWxpQGdhbGxhdWRldC5lZHUwHhcNMTYwMzE0MTcwNjA1\nWhcNMjYwMzEyMTcwNjA1WjCBuzELMAkGA1UEBhMCVVMxCzAJBgNVBAgMAkRDMRMw\nEQYDVQQHDApXYXNoaW5ndG9uMR0wGwYDVQQKDBRHYWxsYXVkZXQgVW5pdmVyc2l0\neTEmMCQGA1UECwwdR2FsbGF1ZGV0IFRlY2hub2xvZ3kgU2VydmljZXMxGjAYBgNV\nBAMMEWlkcC5nYWxsYXVkZXQuZWR1MScwJQYJKoZIhvcNAQkBFhhoYXRpbS52YWxp\nQGdhbGxhdWRldC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDC\nCpDB7laSCH5dkdNPvy4UemNCqPHBA4dAAIgU8519wQzlqCbyRrSMjM8QSVG10IqX\nYCQURh06ehb4Tm5glLRw3v4es5HFwfqPPbJQY1VBap4L7kqS0il64pC5QeJqXee2\n8jSEPH1avyaBufl8lrAuhWJPea3S2+ORliui2LO6DB2BetlSt6tjxeYQUQ1UmZ+L\nH1V3unqxmKaBGVPu8WZ4AJKdfVCICJNiEu+IaZhQXlTXaJoTzXeVvUQXogCL+epg\nVDPrmFYzZIalLDyRZG5q7mcKCPFRjNCTUYjW2hW7r3uJYVoaRoo9DloSw3y91Egv\nj/Hb6UcpxEDpdrWrVrIBAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAEBVLlNPT/XM\n/BabCIBIcQkZ0PZ5+Vu8GOwfhI/CQKEQFJV3ud/RG/w1Kt87EGzgYWS1LoxhAmAb\nv4Ejl4qRsLpk98EyUF/ioe729deTvu9vSV9uMtHSGM7zKvEhN7AI7Mx1ALFt/yrr\nFfRnCY35FzGCqI0IWZqIK1eNl2NVCGv3SBKYH1zm5oUC7L91VVJQpZrqyuuR1kv+\nZ8YfHrIc/AOFSxSRuhgFxfmySBMxU+TUcp0aJfKCaiCyp7efsLYtJIxECsjjurH8\nDayK/60bhdYbIxZzr88h48yaz99WJf/5Y2Yc5f8G5kaldFI56yVjx4dxSuD1SfhQ\nmzisXEBrL04="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gallaudet.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.gallaudet.edu:443/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.gallaudet.edu:443/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.gallaudet.edu:443/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.gallaudet.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.gallaudet.edu:9443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.gallaudet.edu:9443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gallaudet.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Gallaudet University IDP"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Gallaudet University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID9DCCAtwCCQCbiUruOaohoTANBgkqhkiG9w0BAQsFADCBuzELMAkGA1UEBhMC\nVVMxCzAJBgNVBAgMAkRDMRMwEQYDVQQHDApXYXNoaW5ndG9uMR0wGwYDVQQKDBRH\nYWxsYXVkZXQgVW5pdmVyc2l0eTEmMCQGA1UECwwdR2FsbGF1ZGV0IFRlY2hub2xv\nZ3kgU2VydmljZXMxGjAYBgNVBAMMEWlkcC5nYWxsYXVkZXQuZWR1MScwJQYJKoZI\nhvcNAQkBFhhoYXRpbS52YWxpQGdhbGxhdWRldC5lZHUwHhcNMTYwMzE0MTcwNjA1\nWhcNMjYwMzEyMTcwNjA1WjCBuzELMAkGA1UEBhMCVVMxCzAJBgNVBAgMAkRDMRMw\nEQYDVQQHDApXYXNoaW5ndG9uMR0wGwYDVQQKDBRHYWxsYXVkZXQgVW5pdmVyc2l0\neTEmMCQGA1UECwwdR2FsbGF1ZGV0IFRlY2hub2xvZ3kgU2VydmljZXMxGjAYBgNV\nBAMMEWlkcC5nYWxsYXVkZXQuZWR1MScwJQYJKoZIhvcNAQkBFhhoYXRpbS52YWxp\nQGdhbGxhdWRldC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDC\nCpDB7laSCH5dkdNPvy4UemNCqPHBA4dAAIgU8519wQzlqCbyRrSMjM8QSVG10IqX\nYCQURh06ehb4Tm5glLRw3v4es5HFwfqPPbJQY1VBap4L7kqS0il64pC5QeJqXee2\n8jSEPH1avyaBufl8lrAuhWJPea3S2+ORliui2LO6DB2BetlSt6tjxeYQUQ1UmZ+L\nH1V3unqxmKaBGVPu8WZ4AJKdfVCICJNiEu+IaZhQXlTXaJoTzXeVvUQXogCL+epg\nVDPrmFYzZIalLDyRZG5q7mcKCPFRjNCTUYjW2hW7r3uJYVoaRoo9DloSw3y91Egv\nj/Hb6UcpxEDpdrWrVrIBAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAEBVLlNPT/XM\n/BabCIBIcQkZ0PZ5+Vu8GOwfhI/CQKEQFJV3ud/RG/w1Kt87EGzgYWS1LoxhAmAb\nv4Ejl4qRsLpk98EyUF/ioe729deTvu9vSV9uMtHSGM7zKvEhN7AI7Mx1ALFt/yrr\nFfRnCY35FzGCqI0IWZqIK1eNl2NVCGv3SBKYH1zm5oUC7L91VVJQpZrqyuuR1kv+\nZ8YfHrIc/AOFSxSRuhgFxfmySBMxU+TUcp0aJfKCaiCyp7efsLYtJIxECsjjurH8\nDayK/60bhdYbIxZzr88h48yaz99WJf/5Y2Yc5f8G5kaldFI56yVjx4dxSuD1SfhQ\nmzisXEBrL04="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idp.gallaudet.edu/identity/feedback.htm"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Gallaudet University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gallaudet.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Gallaudet University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.wmich.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "oit-shibadmin@wmich.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WMU OIT Shibboleth Authentication Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "oit-shibadmin@wmich.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WMU OIT Shibboleth Authentication Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@wmich.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WMU Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.wmich.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.wmich.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.wmich.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.wmich.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.wmich.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.wmich.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wmich.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.wmich.edu/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Western Michigan University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Western Michigan University"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.wmich.edu/idp/images/w_logo.png",
                    "lang": "en",
                    "height": "150",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "172"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.wmich.edu/it/policies/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUa4EI2jTt6ViDq1EIcA/j+LW97W4wDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNaWRwLndtaWNoLmVkdTAeFw0xMjA4MDExOTI0NTFaFw0z\nMjA4MDExOTI0NTFaMBgxFjAUBgNVBAMTDWlkcC53bWljaC5lZHUwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC7nBw1E5fmU+Nd+wyb1/YCO3pKUw+C+6Uw\nKk0SF5daJWbZDI3UWKdQjl0aVp53yml3oEzQFbsRl9KXSC43Wy1zAWNYF2MSUxOQ\n2//8K1omFvWDaa1teaOVn+o8ID56FN3WCj0H1JGXsS/Ub6xgArLvQP4qwIbWAkw8\ngG2OxOwve5xWdyhI2kgALR57vWjx4IXPGcbrqcH5mQmh5G0T08b6yVd/QAm+eUqG\niu2U0E2u5nYaGBUrbJhESwi1BUG5skVohdM7pywwkI89EX8kC55zo9f3PkTkI81+\nBW/4GYNq3jZdnOkQikwBD+BpZNYHwiIC0x7H6dVzxd/etmTJQ5enAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDWlkcC53bWljaC5lZHWGJGh0dHBzOi8vaWRwLndtaWNoLmVk\ndS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUr3+xm4m0gO5W3F0sK6Hbfy0tQeAw\nDQYJKoZIhvcNAQEFBQADggEBAIXq7tJZSGV+V6fTXpk31EIKEXqI4dpw/r2lb1cx\nPh6pAyQ9SYBxOrdS1CDo0+OC5WvtgRYArnhgdajCwhtvbfMCufT4w3bCTU6/P6SE\nnhjIGWdZIfTvEEv9m3R6Q6tyTfW143IsSHA++aowZ4Vup5fBwOKqzclrWRWyIlr+\nRchDpIDX4nMpzZpWXmOuqXNbUjb5nejgUmF8jELzsNIsnouAOqYg8n9+cgYd+2w+\np57il9Y4UDMnswbxscZKwp32B+e5o6Mc6YrFVeVuR6zWR6+FQaDG8YFesmTDBvTv\n8Pbk+Hx1N2rqKvwenWT850/va3DwTJBeKdJGwCN2d4QNqMM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idp.wmich.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Western Michigan University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wmich.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Western Michigan University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://prd.thieme.de/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shib-support@thieme.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shib-support@thieme.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://prd.thieme.de/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-05-01T13:14:11Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Georg Thieme Verlag KG"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.thieme.de/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Georg Thieme Verlag KG"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICtDCCAZygAwIBAgIEUX/qATANBgkqhkiG9w0BAQUFADAcMRowGAYDVQQDExFw\n\t\t\t\t\t\tcm9maWxlLnRoaWVtZS5kZTAeFw0xMzA0MzAxNTU3NTNaFw0xNjA0MjkxNTU3NTNa\n\t\t\t\t\t\tMBwxGjAYBgNVBAMTEXByb2ZpbGUudGhpZW1lLmRlMIIBIjANBgkqhkiG9w0BAQEF\n\t\t\t\t\t\tAAOCAQ8AMIIBCgKCAQEA04gpJrPW9OU6dyBVlNQgapngsHYAZc2m1ZbGohqA82Kw\n\t\t\t\t\t\twH2Q2hYvbIP3cHReCRkgj4rrehbrbR0smkFVrbk/lIv0/nEe191KNKYSf+2s29NO\n\t\t\t\t\t\tSiLcGSXonAsapEH8jGx5y3rubPXQRobiz/6Wr9Xd9ojbRcaYpM+noiMYdjwGdFdV\n\t\t\t\t\t\tUGk1R5MWa8cSc+RIfbPUOpVcGGEszDnQsiqKe+etUM01Bj8ya29uovxP2QPjt52i\n\t\t\t\t\t\tIlny/cTWzYkp0FkTRw8YNULgt021BavPSNQiVfF23fbN0t7CrprBGdWiqe7ski3s\n\t\t\t\t\t\tRyVCxrd59enndAcxwG/rh2KJ8dSB/XBlcxn666xxhwIDAQABMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQC6BbU3qM+zYtG9gTvC5DjCU7loA9SPqP3cxvZdccZ+3Md8Op0cRVIM\n\t\t\t\t\t\tWSyCwyNfNd6keQ3oFpMWwbebpUoyN5bs9TLzvLyVZ62eTxzMIbRa2ExZ05kZefpq\n\t\t\t\t\t\tbK6qbEPkTGE8JMRTo7X44I/ymhKvAHPAdb8Y4nSj0i+td/Fwr/mPvreZ8/l22HCQ\n\t\t\t\t\t\tNgm9TpbnmenLhSckNt4gPRZNh9qffqWgT8g73pR5ZDcRKCkjUn0Z91ivcMggBhjF\n\t\t\t\t\t\tfueU1fclrPqsuWG41V/1ffiLVsq8iok7N1hm0YIfI2Up81sAz+xqa2LntJQDPxso\n\t\t\t\t\t\tiV7miXl0O9QZaSRSXuCmtnNbIcR4K9Mg"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICtDCCAZygAwIBAgIEUX/qATANBgkqhkiG9w0BAQUFADAcMRowGAYDVQQDExFw\n\t\t\t\t\t\tcm9maWxlLnRoaWVtZS5kZTAeFw0xMzA0MzAxNTU3NTNaFw0xNjA0MjkxNTU3NTNa\n\t\t\t\t\t\tMBwxGjAYBgNVBAMTEXByb2ZpbGUudGhpZW1lLmRlMIIBIjANBgkqhkiG9w0BAQEF\n\t\t\t\t\t\tAAOCAQ8AMIIBCgKCAQEA04gpJrPW9OU6dyBVlNQgapngsHYAZc2m1ZbGohqA82Kw\n\t\t\t\t\t\twH2Q2hYvbIP3cHReCRkgj4rrehbrbR0smkFVrbk/lIv0/nEe191KNKYSf+2s29NO\n\t\t\t\t\t\tSiLcGSXonAsapEH8jGx5y3rubPXQRobiz/6Wr9Xd9ojbRcaYpM+noiMYdjwGdFdV\n\t\t\t\t\t\tUGk1R5MWa8cSc+RIfbPUOpVcGGEszDnQsiqKe+etUM01Bj8ya29uovxP2QPjt52i\n\t\t\t\t\t\tIlny/cTWzYkp0FkTRw8YNULgt021BavPSNQiVfF23fbN0t7CrprBGdWiqe7ski3s\n\t\t\t\t\t\tRyVCxrd59enndAcxwG/rh2KJ8dSB/XBlcxn666xxhwIDAQABMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQC6BbU3qM+zYtG9gTvC5DjCU7loA9SPqP3cxvZdccZ+3Md8Op0cRVIM\n\t\t\t\t\t\tWSyCwyNfNd6keQ3oFpMWwbebpUoyN5bs9TLzvLyVZ62eTxzMIbRa2ExZ05kZefpq\n\t\t\t\t\t\tbK6qbEPkTGE8JMRTo7X44I/ymhKvAHPAdb8Y4nSj0i+td/Fwr/mPvreZ8/l22HCQ\n\t\t\t\t\t\tNgm9TpbnmenLhSckNt4gPRZNh9qffqWgT8g73pR5ZDcRKCkjUn0Z91ivcMggBhjF\n\t\t\t\t\t\tfueU1fclrPqsuWG41V/1ffiLVsq8iok7N1hm0YIfI2Up81sAz+xqa2LntJQDPxso\n\t\t\t\t\t\tiV7miXl0O9QZaSRSXuCmtnNbIcR4K9Mg"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://profile.thieme.de/shibboleth/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://profile.thieme.de/shibboleth/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://profile.thieme.de/shibboleth/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://profile.thieme.de/shibboleth/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://profile.thieme.de/shibboleth/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://b2access.eudat.eu:8443/unitygw/saml-sp-metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Technical"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:b2access@fz-juelich.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "B2ACCESS"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:b2access@fz-juelich.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "B2ACCESS"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://b2access.eudat.eu:8443/unitygw/saml-sp-metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-10-22T13:13:53Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Forschungszentrum J\u00fclich GmbH"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Forschungszentrum J\u00fclich GmbH"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fz-juelich.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fz-juelich.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e234"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e234"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://b2access.eudat.eu/files/about-b2access.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EUDAT B2ACCESS"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EUDAT B2ACCESS"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "AAI f\u00fcr EUDAT B2-Services"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "AAI for EUDAT B2-Services"
                  }
                ],
                "logo": [
                  {
                    "text": "https://b2access.eudat.eu/files/logo-small.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://b2access.eudat.eu/files/logo-huge.png",
                    "height": "146",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "146"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://b2access.eudat.eu/files/data-privacy-statement.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "b2access.eudat.eu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGLDCCBRSgAwIBAgIQAeV/HfOyLr/KjB6ZHxlt7zANBgkqhkiG9w0BAQsFADBk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"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=b2access.eudat.eu,O=CSC - Tieteen tietotekniikan keskus Oy,L=Espoo,ST=Uusimaa,C=FI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://b2access.eudat.eu:8443/unitygw/spSAMLResponseConsumer",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "EUDAT B2ACCESS"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "EUDAT B2ACCESS"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "AAI f\u00fcr EUDAT B2-Services"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "AAI for EUDAT B2-Services"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sso.unt.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@untsystem.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UNT System Directory Services Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@untsystem.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Yancey Yeargan"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@unt.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UNT Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.unt.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.unt.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.unt.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "untsystem.edu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unt.edu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unthsc.edu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "untsystem.edu"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "untdallas.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for UNT (Denton), UNT Health Science Center, UNT Dallas, and UNT System."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of North Texas System"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAPTkPnFeEQriNu0kKxDjCOeiKxITMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC3Nzby51bnQuZWR1MB4XDTEwMTAwMTE4MjgzMloXDTMw\nMTAwMTE4MjgzMlowFjEUMBIGA1UEAxMLc3NvLnVudC5lZHUwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCynjH66Mz6D5Fc2lCUjnpF2n2POevHv5l33VMi\nobO2dc/YzSwiENmr6tY9ReX9FF4ML8NobLUcTXqPLfL4mWKfWBI39gcyBwD/ddZ5\nXmqywa/DLgIS4bp9KrcashOM44jSfCNkUfGW21FA+N/vfpBIx2Cgofz5mg8XeqHr\nelVQKQeZ2ARomjmU083YD9yi3e+ddmqX3FlCTTmbo8oTBRONSm8YjpG9/7DjVD2L\nJMLiwc2N9V6zmHgnfe2YFbgt8vo7pMg8XsH3yGCNl4AJbhN0GvQIS05SALSxr52x\nSAPQYDkTtkMHuCl+p11nlMJpkXAvKWc3ml8QTz7Uu5HKaKZLAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC3Nzby51bnQuZWR1hiJodHRwczovL3Nzby51bnQuZWR1L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBRlgBonW6cGeb6J4ssh77iPml26tzANBgkqhkiG\n9w0BAQUFAAOCAQEAVGgGN5ma/FeByXpL0jqMKaobKp7dNtTCTUXYIQAAorsdRTu5\noqDTSV18WsEY83ulL+sEB6zz2mewTAFe/0zQ0jNs5F7jgaBCIkGGa0iVbrNKk+3G\nKCGYmKWOmg5ZT/a8aJZ5FEryy5Z9cOdrgK8KaYXpB7nvXvonGmCbakmE2a6okszF\n5pbm2rnx2hXdaJyWb/SbEsZ8oCVck/t/0eKSIzWZJtVP2/5MmAnKdAdgVlMN0/y6\nzZ1Ow0IRVl+nB1IHBZ20Tfo9JcrHSbHDT1/BLhGZ1Cb+6lTfgHH+lKDQkjmIPJ+x\nh+1Xx63dQAtHY7dZh0dxtwfqKg2YtR6sldg3Qg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "error_url": "https://sso.unt.edu/error/"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of North Texas System"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://untsystem.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of North Texas System"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.univ-amu.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "LALOT Dominique"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dominique.lalot@univ-amu.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "AIMAR Michel"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "michel.aimar@univ-amu.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.univ-amu.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-04-16T08:27:18Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univ-amu.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univ-amu.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.univ-amu.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-amu.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-amu.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 d'Aix-Marseille"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 d'Aix-Marseille"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIULCzb5nQYuu/jKvNfhCenMAkGKm8wDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPaWRwLnVuaXYtYW11LmZyMB4XDTEyMDQxMzE1MTIzM1oX\nDTMyMDQxMzE1MTIzM1owGjEYMBYGA1UEAxMPaWRwLnVuaXYtYW11LmZyMIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnIH5qfsDRJQDkVQ70lGQbkcAoT2g\nwCu7QruDZGG/Bk6qzCx8vNJh9rfAmrQ33GmsKOVQOxWIfImgdYgmZWsV52CPobHy\nrPsiE64INWyM/W/TEJP79GAQzGsiZ7xID6CfMbhVG83hNpWg3SxXyoh+B0/SVr/8\nIBNUtcVTe0d4Jjiv7ztHFwZXT2UBYxRJKU45V6y9Wss5RH7aAz9QVPK0K4f3r5pi\n+Y+dxiw7dEWHO5QEZqx/9gQayfatac5lzX03QBZr1me5EePFwQJ3eM9raUuS1cbi\ndUxFptkQHJWoUGImaFcTHsuny2G438sM4s+ao6CkE/8WIQYTEBu0jwfIZwIDAQAB\no2UwYzBCBgNVHREEOzA5gg9pZHAudW5pdi1hbXUuZnKGJmh0dHBzOi8vaWRwLnVu\naXYtYW11LmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQP7J5/7grId0BA/iS3\nEQAuh8HTUzANBgkqhkiG9w0BAQUFAAOCAQEAZT28dZUnmtUIuiob36b/jNzT/3dY\niBZDHu3z1HMzFc6efhPhBuJ20SpLfH9oMBVDCUCktH9tv4VO5LJv0N02FL+r9uuo\nfbeNry2w9g78LM/z/0IWGtcdfEHnHA+6nYad1PEf0vv+K5v82l+atRSDoOR/s9dk\nm3A/gjFibKMSIIXDFvLncxiHYHLrhsrMFeG5HlWXx+pVCunuvo2nNk2uL1ZBWW0Z\nJRO79CP7W1ndIuM+8v1G7C1gjYqkO6rdEKdJArm7hqEMzjUdL60okDqsVX+IYFUX\nVmCmZvTACtUurXS0zocVZTUfQcTaSXkKLSKLU6TQQy4Wf/c9CfNalbv6Sw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 d'Aix-Marseille"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-amu.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 d'Aix-Marseille"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.uni-wuppertal.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Zeipelt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:zeipelt@uni-wuppertal.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rene"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Zeipelt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:zeipelt@uni-wuppertal.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rene"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uni-wuppertal.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-10-05T14:09:03Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.uni-wuppertal.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGITCCBQmgAwIBAgIHGSjsdOuLTjANBgkqhkiG9w0BAQsFADCBuDELMAkGA1UE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\nkJ3/tUy85gUFTbHNPD8TBNxW57v6A2RTc+MXQbWhInEOGxuKdg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.uni-wuppertal.de,O=Bergische Universitaet Wuppertal,L=Wuppertal,ST=Nordrhein-Westfalen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.uni-wuppertal.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGITCCBQmgAwIBAgIHGSjsdOuLTjANBgkqhkiG9w0BAQsFADCBuDELMAkGA1UE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\nkJ3/tUy85gUFTbHNPD8TBNxW57v6A2RTc+MXQbWhInEOGxuKdg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.uni-wuppertal.de,O=Bergische Universitaet Wuppertal,L=Wuppertal,ST=Nordrhein-Westfalen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uni-wuppertal.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uni-wuppertal.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uni-wuppertal.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.uni-wuppertal.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uni-wuppertal.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.uni-wuppertal.de/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uni-wuppertal.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uni-wuppertal.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uni-wuppertal.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uni-wuppertal.de"
              },
              {
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Mitglieder der Bergischen Universit\u00e4t Wuppertal"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Members at University of Wuppertal"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.uni-wuppertal.de/idp/images/buw-mini.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp.uni-wuppertal.de/idp/images/buw_log.png",
                    "height": "70",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "200"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Bergische Universit\u00e4t Wuppertal"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Wuppertal"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.uni-wuppertal.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGITCCBQmgAwIBAgIHGSjsdOuLTjANBgkqhkiG9w0BAQsFADCBuDELMAkGA1UE\nBhMCREUxHDAaBgNVBAgTE05vcmRyaGVpbi1XZXN0ZmFsZW4xEjAQBgNVBAcTCVd1\ncHBlcnRhbDEpMCcGA1UEChMgQmVyZ2lzY2hlIFVuaXZlcnNpdGFldCBXdXBwZXJ0\nYWwxDDAKBgNVBAsTA1pJTTEZMBcGA1UEAxMQVW5pLVd1cHBlcnRhbCBDQTEjMCEG\nCSqGSIb3DQEJARYUcGtpQHVuaS13dXBwZXJ0YWwuZGUwHhcNMTUwMzE4MTIyNjEz\nWhcNMTkwNzA5MjM1OTAwWjCBiTELMAkGA1UEBhMCREUxHDAaBgNVBAgME05vcmRy\naGVpbi1XZXN0ZmFsZW4xEjAQBgNVBAcMCVd1cHBlcnRhbDEpMCcGA1UECgwgQmVy\nZ2lzY2hlIFVuaXZlcnNpdGFldCBXdXBwZXJ0YWwxHTAbBgNVBAMMFGlkcC51bmkt\nd3VwcGVydGFsLmRlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAncKY\nnT23i7mXryQsRo9hoc0c5MLAA8Tffh8xJtLrdHZgt5NwyjXeFxTgFa6EAGfbJVOq\nRzPzTvrRKmfbv6rftqMNs2m3qoNePiESt77Nw14G1mPOEA2nY5nxz59qHQOCkOuO\nj3hB3CV43WGMrn8uxWcIPb7eQQGPE/DNX2NyEKpbkgVM3rSYHY8wbwtvRcqlhnQf\nEsNWMykBo3GjbTMvuK+nN/xbES8T623N6MVPlCDgNCTOAI3+VGAz2NOMNA4J1hrA\n+xj3TQ76uwm85E6nDcVITe1uDCW7aSW5/0zLXuX0WL+YQTdm721Mcy4RraZ5Nht3\n5fM7Yd/AYs1g6BfAXQIDAQABo4ICWzCCAlcwTwYDVR0gBEgwRjARBg8rBgEEAYGt\nIYIsAQEEAwMwEQYPKwYBBAGBrSGCLAIBBAMBMA8GDSsGAQQBga0hgiwBAQQwDQYL\nKwYBBAGBrSGCLB4wCQYDVR0TBAIwADALBgNVHQ8EBAMCBeAwHQYDVR0lBBYwFAYI\nKwYBBQUHAwIGCCsGAQUFBwMBMB0GA1UdDgQWBBQHaE47CvxpJd6L83/B5MjuYAX6\nczAfBgNVHSMEGDAWgBQLpNtTFRSiYzkI4dRpouy3IHkMGjAfBgNVHREEGDAWghRp\nZHAudW5pLXd1cHBlcnRhbC5kZTCBjQYDVR0fBIGFMIGCMD+gPaA7hjlodHRwOi8v\nY2RwMS5wY2EuZGZuLmRlL3VuaS13dXBwZXJ0YWwtY2EvcHViL2NybC9jYWNybC5j\ncmwwP6A9oDuGOWh0dHA6Ly9jZHAyLnBjYS5kZm4uZGUvdW5pLXd1cHBlcnRhbC1j\nYS9wdWIvY3JsL2NhY3JsLmNybDCB2wYIKwYBBQUHAQEEgc4wgcswMwYIKwYBBQUH\nMAGGJ2h0dHA6Ly9vY3NwLnBjYS5kZm4uZGUvT0NTUC1TZXJ2ZXIvT0NTUDBJBggr\nBgEFBQcwAoY9aHR0cDovL2NkcDEucGNhLmRmbi5kZS91bmktd3VwcGVydGFsLWNh\nL3B1Yi9jYWNlcnQvY2FjZXJ0LmNydDBJBggrBgEFBQcwAoY9aHR0cDovL2NkcDIu\ncGNhLmRmbi5kZS91bmktd3VwcGVydGFsLWNhL3B1Yi9jYWNlcnQvY2FjZXJ0LmNy\ndDANBgkqhkiG9w0BAQsFAAOCAQEAFUjGgPg4NuNIoi7FRNSrv1a6qy3k0wWUaJJH\nmWsoQI5OT42Z9l6ifkInmyMPtvD1ldedlVxuM858gDIo/0CLa0H5cfq72hKZ+sW2\nLOohAAXb1b7hHq2a9Wf+ENal79LcQvd3sVW3bdgIXt/HKBPOC0LwMKjkylwaqwzm\nQ5M214/3Pn24DCLPo1lsfBNX5ObHtSf1ganwEc7sml/pb1ja/W/JDhwrPOuyZUs2\n/m3eQbz+tfpT6b28oogqyQL0US+Mu/zSTJzIGD6DiK4cwmstjmlPGJ1LhK3ZaAKy\nkJ3/tUy85gUFTbHNPD8TBNxW57v6A2RTc+MXQbWhInEOGxuKdg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.uni-wuppertal.de,O=Bergische Universitaet Wuppertal,L=Wuppertal,ST=Nordrhein-Westfalen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.uni-wuppertal.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGITCCBQmgAwIBAgIHGSjsdOuLTjANBgkqhkiG9w0BAQsFADCBuDELMAkGA1UE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\nkJ3/tUy85gUFTbHNPD8TBNxW57v6A2RTc+MXQbWhInEOGxuKdg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=idp.uni-wuppertal.de,O=Bergische Universitaet Wuppertal,L=Wuppertal,ST=Nordrhein-Westfalen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bergische Universit\u00e4t Wuppertal"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Wuppertal"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-wuppertal.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-wuppertal.de/en/home.html"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e168"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e168"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.eenet.ee/sso/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "eenet@eenet.ee"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "TAAT"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.eenet.ee/sso/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://taat.edu.ee/main/documents/?lang=en"
              }
            ],
            "registration_authority": "http://taat.edu.ee",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.eenet.ee/sso/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "want_authn_requests_signed": "true",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.eenet.ee/sso/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eenet.ee"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "et",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EENet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EENet"
          }
        ],
        "organization_url": [
          {
            "lang": "et",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eenet.ee"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eenet.ee/EENet/EENet_en"
          }
        ],
        "organization_name": [
          {
            "lang": "et",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eesti Hariduse ja Teaduse Andmesidev\u00f5rk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Estonian Education and Research Network"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.eastridingcollege.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.eastridingcollege.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/eastridingcollege.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/eastridingcollege.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eastridingcollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "East Riding College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eastridingcollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:uiowa.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "its-dna-identity-services@uiowa.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ITS DNA Identity Services"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "iowa-federation-requests@uiowa.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "University of Iowa Federation Requests"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "iowa-federation-requests@uiowa.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "University of Iowa Federation Requests"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "security@uiowa.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Information Security and Policy Office"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "urn:mace:incommon:uiowa.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uiowa.edu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uiowa.edu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.uiowa.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uiowa.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.uiowa.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uiowa.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uiowa.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://its.uiowa.edu/shibboleth"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Iowa"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The University of Iowa"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.uiowa.edu/static/ui-incommon-metadata-logo.png",
                    "lang": "en",
                    "height": "262",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "286"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://opsmanual.uiowa.edu/community-policies/acceptable-use-information-technology-resources#19.3"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVANC3p2UisM0yO/80OL67JqcqNiLJMA0GCSqGSIb3DQEB\nBQUAMBgxFjAUBgNVBAMTDWlkcC51aW93YS5lZHUwHhcNMTMwNjIxMTY0NjQyWhcN\nMzMwNjIxMTY0NjQyWjAYMRYwFAYDVQQDEw1pZHAudWlvd2EuZWR1MIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAinCXyhRt/vS/7aVBFKE2GWx7Au/+QQ1j\n/6+VQWEP5ONaJGfgNoRsd9dLT6nNpClQb2h8ExHpHFA+41NPyvt53Y/A3XHWfmMc\nMXMMdFzijA5OkPehyigxp43pS5BJf6BOJAYIsffilPPGj4TdUNVokd1I7FvbKVIH\nrnd15ob9lIAoJdBUsiMwvky0wByNKpmiRiEU2n/gCP1owr3RVLePMOvgoU3cS0Tm\nPQsr/r4UZffEDKxCwp7YyM3jteXiPgr6IdZtAm7tKw/9GE00SQbDZehuBK5xfSSR\nLO5pL598B9Cj+NTE3tZD8GTYyl4UzZSQuBMwSrmAeJdVYyqsgD3wLwIDAQABo2Ew\nXzA+BgNVHREENzA1gg1pZHAudWlvd2EuZWR1hiRodHRwczovL2lkcC51aW93YS5l\nZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFN3ESwhqgFQoUXJWKHeu6Y4Nn4OF\nMA0GCSqGSIb3DQEBBQUAA4IBAQCEgd5dT1fxCXGtiV4mS4bNBoKzS2909vFEmnt8\nrUBp5wLmFF+K71cm0XJzlD/faYgGo1d6COT2vbklzPnOziQZVh3RUeYqmbltOFY/\n8sW2NNQ6htsDb2JDH1X2oFucXuSzAcPjNgs7//IqvDw7H3gbtYLMyIrhEA7Q9qy/\n+5j/nvhza9LKyDXiugdWEevMTb20FcAvFZcR5v/kMHRjgQlMwPg2yIngxi5vC0E3\n6qD50/b9pCOR30EbZxLv/oxhpKXKv2nVZBcG4IhEhXdXH1rd0JPug4nhrslRdx4N\nfU6A4c+0Aj/vLEIjWne+wPdi+1bIhUAtEMg/CPBZSrokX2N0"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "error_url": "http://its.uiowa.edu/support/article/61"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Iowa"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uiowa.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Iowa"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.enitab.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "MEUNIER Richard"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "r-meunier@enitab.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "PRIOUX Pascal"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pascal.prioux@agro-bordeaux.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.enitab.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2010-09-15T13:59:18Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.enitab.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.enitab.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.enitab.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "agro-bordeaux.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "enitab.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.enitab.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "students and staff of Bordeaux Sciences Agro"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Etudiants et personnels de Bordeaux Sciences Agro"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Bordeaux Sciences Agro"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Bordeaux Sciences Agro"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUE3+YG/RODtnMAftUk+3SD6KCU4cwDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNaWRwLmVuaXRhYi5mcjAeFw0xMDA3MDYxNDQzMjZaFw0z\nMDA3MDYxNDQzMjZaMBgxFjAUBgNVBAMTDWlkcC5lbml0YWIuZnIwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCmAH5cAW+LbvKpIc1p6okFSKDpURUGUZrz\n58lRZ+/3G6Ec1sP25XXIoQYFH6M+9/SY6dxEKG3KdcdCp5bU7P2x32zuiIFSbefk\nwhaKouyaDgqyl04ow0Dt1MsbxQ3f6RKZN1dTJe1B1VBG5xPdvCRX/E3qlslvpl/q\n1zoI73C4buazgandQQbqhlvPJgQHNjD5wPevxhNRdysnywxO3Zo4lmM3vDNv6/R4\niHUDhyOz0MaJoSyeLLAOAXlOQRqaNJoMC1EDgSD2M8763XvCjTyvs4Wz5/jp3CxP\nfwtDJ0gq9jPFrBj8v8Ls62Ps32p1LS9mEy9Q8wvc06ePY6XQSy+nAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDWlkcC5lbml0YWIuZnKGJGh0dHBzOi8vaWRwLmVuaXRhYi5m\nci9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQULabgfYRKdPMaeTNuFAvY4XAW8p4w\nDQYJKoZIhvcNAQEFBQADggEBAJUlgO7TmUkBy+szO2JL3nc4ZdfPrGzBqkcfSQPq\nJlY3pZjMX9AJOuRUTXfwuc6A5sTZMu56lHoncJZr/crOHXj7NCMiV99V0M9DNk3s\n8iZ7Kdnziura1Btg3158+rNpgbgbtjOxq5tQbxDw41W4M+VOT76ttdJjq3QIiAvQ\nOCuuoL5lcVnAieikeHHCSwqgj6RRMf+EWSMO+eW8YqTlpdMvavscMOAjr3Lqhrlw\nwBA6a+2VH2OCL4wwK43tVucNVmqIEl7ShfcO5MmdRDwvjA03MPIzYO8a415s/2g3\niq+XHGvfQ2g2DFN4oXfSkv/A0TVmwWxiqyd8SJ77zNILG4o="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bordeaux Sciences Agro"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.enitab.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Bordeaux Sciences Agro"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://pingpong.chalmers.se/shibboleth",
    {
      "entity_id": "https://pingpong.chalmers.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://pingpong.chalmers.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://pingpong.chalmers.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pingpong.chalmers.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAMLwpt/5/eu6MA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFHBpbmdwb25nLmNoYWxtZXJzLnNlMB4XDTEyMDQyMzE1Mzg1NloXDTIyMDQy\nMTE1Mzg1NlowHzEdMBsGA1UEAxMUcGluZ3BvbmcuY2hhbG1lcnMuc2UwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDEv+Gw3RQeoVOamW80/g7vVEpgDIqy\n/pCrndJOnrSSxjBFwO3KfCnkioGjvzV/N+jt2AdtGucwY107CNp541hEjm9xMLeC\n8hR+khu1HWl1/IAht8EgMx0HnAFYJlVUjFcgYibjaaBIRQfGlfQorlWdBHnDXn0O\nKPRlyXv5p+lmJIl5vDCBkbzd4wapa3eyT6tBiDrH3sSunU/DTiEcJOwp3BOgY1zy\nZu/JuVQfG9l4/s7qjWp5c5IEXBSvQ1+Ho/kMB/mVHbU/PZaZTOjMXKUvNdYhpgST\nCNXCaWnasUq1UrAo0FD0Kbr6Ams19l+7p1bIzFKdqFc9SYt0pc5RGSFxAgMBAAGj\nQjBAMB8GA1UdEQQYMBaCFHBpbmdwb25nLmNoYWxtZXJzLnNlMB0GA1UdDgQWBBTX\nmSIhbeoUjlYpHmRjlF2+78PIRzANBgkqhkiG9w0BAQUFAAOCAQEAbOH4yUozvbEB\nUtOkIWC6qaoUKPf9VHIQveDqZdULpW3m2Q4vSzMKb/yo/tBLERUTgZ0NXYuT6iLv\nZdgs0Cld6kS9UvZURqe8fKjfkJOnu4RI7VJASWfJsypoguih0fzIXiLxcbvXmJhV\nqiRt8BRZJjaWYvtzk711YfJFqV4vOpcU1+IpBX6gbyjzHY5adNVk3t568qPJxKU/\nKOUNSC34z9qxk4SIPE498SFpAYlJo5HnIN3aTa2WnzFUlcQFmFbuHTRDQ/v3X7dL\neN939szhtbDgjf2BL5D0KmkrRPVsCVbqAcvWZ6j5u7tznMUK7l3IuWaTaRIdumnC\n0BPmIT4uxg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pingpong.chalmers.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://pingpong.chalmers.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://pingpong.chalmers.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-10.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-10.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-10.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-10.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-10.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-10.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-10.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-10.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-10.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;10"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;10"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-10.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-10.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIJANmj0562UQtEMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0xMC5sYWRvay51bXUuc2UwHhcNMTIwNjI5MTIwNzQ4WhcNMjIw\nNjI3MTIwNzQ4WjAhMR8wHQYDVQQDExZsYWRvazMtMTAubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1lxdpJYHPqC33HDuMGg3MZB9\ncLSxZo3PACViWvTf8Czcpyrao2IXBhERwU1BhOke+HgqZ5/tndWx0f7ExIMVYEEb\n6WddV3DpukOZYiVIA9y0Wdvgb51sLDragY7qAkwfiqCNdSJ1/yPKOXuMHk5Krc1W\nLm/DPmNTFOeCQNCdMb33Bt84dFFhCKYuk/XngHp8XaSw9xpWblWyRA5kBRVFzmA6\nuQrFL7jA0fxnTtTqrXu1PGZ1fyGpO1py9GNCDgSe0vv1u8m3lr7gABDX4+YckZtr\nEPnA6oSpOtL7OFjZlH90eLNSJ8afAD5vVmwsx+cPPlAHTXfDWgICdyReSAvltQID\nAQABo2swaTBIBgNVHREEQTA/ghZsYWRvazMtMTAubGFkb2sudW11LnNlhiVodHRw\nczovL2xhZG9rMy0xMC5sYWRvay51bXUuc2UvZ3VpLXNwMB0GA1UdDgQWBBQ/xUVb\nXS9rp7K9M1ySZEloKQT1UzANBgkqhkiG9w0BAQUFAAOCAQEAqtzsoU/uEDRAqrgg\nR3VG5mvdt5rUkKJtC6naX0lrwliqAK2FZsqSiYoxmxG2noxFMVxyqKHLoF9DbJkt\nWriQD97cMkgc81muFuk+Sl+QQhNf7pY7wEneNZP8EEPsXGQRBfWeZ2mPoOJwbOoY\nxtQUwjCZxXuzEok3JP7ILGBOxOveHANp/CCZZBlRErsCb4sC+6+GZy/UJuTuJdgJ\nPqFQikTAA8nfwIOr7T65d1FnGzpWnCsZSZ2lEldLclyWOpP9/eXe8hZNWrgDxoNi\noa9eOIASf1NXOsACA5C0aAfW+WF9zOWB42z4E+r9szJ74C/y9FsaUz9++eOOV+vz\nzL2y+w=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-10.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-10.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-10.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-10.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-10.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-10.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-10.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-10.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-10.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-10.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://uiowa.infoready4.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jtesta@infoready4.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Testa"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://uiowa.infoready4.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "InfoReady Corp"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.infoready4.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "InfoReady Corp"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uiowa.infoready4.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://uiowa.infoready4.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uiowa.infoready4.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://uiowa.infoready4.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "InfoReady Review - University of Iowa"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6zCCAdOgAwIBAgIJAOO9wmxE2PCSMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\nBAMTDGluZm9yZHl3aW4wMjAeFw0xMzEwMjkwNjE0NDlaFw0yMzEwMjcwNjE0NDla\nMBcxFTATBgNVBAMTDGluZm9yZHl3aW4wMjCCASIwDQYJKoZIhvcNAQEBBQADggEP\nADCCAQoCggEBAMpdE35LzF2eEaAhLfxtotv6XhMXfkOMbugHq8xk5rhyx7RKS+Ku\nt9wW8Mv2rG7NAJw+8167dP6N2RQKpRBn17FIOhm/cuSNtiTBJtA9QiTEkyN5D1ma\nykJjlD95ymo0XdRDWwz/6IP5v+d95BlfbnlkswWOGOMLxCtaWCSZQ00RJFDKudL5\nIrK+2A1KwF4O+DxqivhdLsd/yA+IjX1efYnT7MPsd7Yyh5wKXKkGbKEg9yAW65Dt\nx2xbBCjDT2PCBhJ4ZuRfUv8whBCT2qgH6+pQ5JBN9ZDz1iGDFp8XfQ27UtzlFdBc\ncjvWmtOh/V35fBXl5LIbJdU/ypJMBwehxbcCAwEAAaM6MDgwFwYDVR0RBBAwDoIM\naW5mb3JkeXdpbjAyMB0GA1UdDgQWBBQTyklRhSLuL0VcI0Nv4tQhZYqHITANBgkq\nhkiG9w0BAQUFAAOCAQEAJyNYKdKAFdp7xvqnjszw+AF3dYl3HQKe5bC0M+gu7G+2\nhJL2D70cFCXXi2bNcdyLsFVPiecMo69QinOP3kqCPNL7S5pSjm48T9bTiRr4WNy1\nhkxJ7nCV++z696YqbE7WYec9LEpcNDnDnmDfQOxvxzdtpIyM3Egw+koKEZu13ebw\nzAs2xgBj3V5YWmzS7nk1wPPJBKpr+9W5xixEGfaKfrrQXayP/LVyN+u/3BjZCZfE\nbfqmalH+rjpJ7ZCck4CQFxCvnLhwl+L5DEuEFXmgTzk7EDb65no+rXaZQd3/IEre\nsazovBHNw8FPYGiOCi2757flvBsb6gW+FbN0SPmtSQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uiowa.infoready4.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://uiowa.infoready4.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uiowa.infoready4.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://uiowa.infoready4.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "InfoReady Review - University of Iowa"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://test.myplace.strath.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Todd"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:iain.todd@strath.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Iain"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Todd"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:iain.todd@strath.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Iain"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test.myplace.strath.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-10-13T11:41:56Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Myplace test server"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.strath.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Strathclyde"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://test.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://test.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://test.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6zCCAdOgAwIBAgIJAO7nQtYFnLcLMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\n\t\t\t\t\t\tBAMTDG1vby10ZXN0LXdlYjAeFw0xNDA2MjUxNDMxMzhaFw0yNDA2MjIxNDMxMzha\n\t\t\t\t\t\tMBcxFTATBgNVBAMTDG1vby10ZXN0LXdlYjCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBANJssMJIvaAfEEk5XRDsOtquZ0z6hN61EalbRPyGDs7+YKu6jUJz\n\t\t\t\t\t\tYj8Hzxyu3y0Y3TRmacHK6o7kWDas2yqSFKX7nllEiEmNtpdKL5XrkFDhpI63DJ/5\n\t\t\t\t\t\tv79V8z1rLV0dNJNmWiI70oPI80U4sTn0esgOCPArrb2vJXUwGiOHeyORBM05NN70\n\t\t\t\t\t\tEHDDVChkfr59QYkGuftsF5nk8oeHS/znPurVyab0q6AF5on5KO2c2uApmOGIqElI\n\t\t\t\t\t\tCka55N9J7FRcVKTR6vzNx9HxV8Py+cJuuIaW3ARQQwSmBqnNu4zLzZva3izSkVm1\n\t\t\t\t\t\tky55z5IuP5k+xb/njyKl0e98Lq0RrESTXmUCAwEAAaM6MDgwFwYDVR0RBBAwDoIM\n\t\t\t\t\t\tbW9vLXRlc3Qtd2ViMB0GA1UdDgQWBBTnSEhfktDUO6pGBtFLZOOXE7YFWDANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAj2dOUifWSmIwqMwGkxdFXdJUv5IXu7bzWVsD+6mImbj9\n\t\t\t\t\t\t31jazfu+RN4ipskDI/gQ6Rkn+0TYPKEBu3ZlB6V1HZjK+w7cQxjIHyoYMH9nQXzh\n\t\t\t\t\t\tcCp3r98w8pKMyZZqvrX/jLbHPr7F2urvxsPjltk1TMTYWxBnePqrqPCp8o81kxbF\n\t\t\t\t\t\tL4qsDwiUVrTqCoFoxja2IATYBQQHt5k77lAmNTinKsdpNkOv8CjRc5ZqNJXj1VvM\n\t\t\t\t\t\tBRaRRbVGnjCpokPlIXUH82qKedSLn5O4XEr1hHhKjP3zIgExQqKw3ulXO6ZZ6gzY\n\t\t\t\t\t\tM4FvArC++SGhK6YOaX2wH7KB8mWKKYtTM2ykDky3xw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://test.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://test.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://test.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://test.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://test.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://test.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://test.myplace.strath.ac.uk/auth/shibexternal/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://federation.napier.ac.uk/idp/pingfederate",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:citsupport@napier.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Todd"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:j.todd@napier.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federation.napier.ac.uk/idp/pingfederate",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-09-11T13:43:48Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://federation.napier.ac.uk:8443/idp/attrsvc.ssaml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://federation.napier.ac.uk:8443/idp/soap.ssaml1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDeDCCAmCgAwIBAgIGAU+sUxvAMA0GCSqGSIb3DQEBCwUAMH0xCzAJBgNVBAYT\n\t\t\t\t\t\tAkdCMRIwEAYDVQQIEwlFZGluYnVyZ2gxEjAQBgNVBAcTCUVkaW5idXJnaDEkMCIG\n\t\t\t\t\t\tA1UEChMbRWRpbmJ1cmdoIE5hcGllciBVbml2ZXJzaXR5MSAwHgYDVQQDExdmZWRl\n\t\t\t\t\t\tcmF0aW9uLm5hcGllci5hYy51azAeFw0xNTA5MDgwOTM5MzFaFw0zNTA5MDQwOTM5\n\t\t\t\t\t\tMzFaMH0xCzAJBgNVBAYTAkdCMRIwEAYDVQQIEwlFZGluYnVyZ2gxEjAQBgNVBAcT\n\t\t\t\t\t\tCUVkaW5idXJnaDEkMCIGA1UEChMbRWRpbmJ1cmdoIE5hcGllciBVbml2ZXJzaXR5\n\t\t\t\t\t\tMSAwHgYDVQQDExdmZWRlcmF0aW9uLm5hcGllci5hYy51azCCASIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEBBQADggEPADCCAQoCggEBAMLtdCNUtcf8tt0/nq07hzjF8TIJMkPXwPCRxo0o\n\t\t\t\t\t\trBYOH3NB6GYbDODXu4W7AmhF8p+BsgKL0wkl+Zl53+AJdThMfU1rN+Ih3co3qpjZ\n\t\t\t\t\t\txDHmnj4HzKGAdRWTQsnSA5/gY9WWWsIT/7aannP7yAQXeOO1Qch8+D8ZqGpkoLYK\n\t\t\t\t\t\thNMeILHIBnuaTit2DsTuFaCaibJ9ky2TxUZQXh8h+InChCGYY6bnKQKRaFszD/B6\n\t\t\t\t\t\tN5JfYWyNqwHcnx1qTWmQWWLbt1ZlGE7/OwkMVzdNOalOf5SunDjA17U0lX0gpO/0\n\t\t\t\t\t\tNpOLHGCx9RgDlQzJ1fXGLGQ+iLWNCcUlbxCyPWPZxb1ATmUCAwEAATANBgkqhkiG\n\t\t\t\t\t\t9w0BAQsFAAOCAQEAhUHBGidQ7SPwgSDIOFKuYfoKBqeziRp675SACxVMS+wqrAlx\n\t\t\t\t\t\thNqAyJVmc4+pslEggwaVL3MKvXQHKizd2dS1U4Gd7Ew43/FzDoRpeQ33aASS1FR1\n\t\t\t\t\t\tZkPAfhNsVtcW+fGrx/vg9bmf2BUcYkHKAJ69wkuHhfhEyqU0Jplerlr1q0+XcE4K\n\t\t\t\t\t\tTH0FxhmDjCJyKEgW7SBU1CU7Vb3EKDw43NSkEoex89I5Ck0GPGLkCK7roP+jTQ6K\n\t\t\t\t\t\ttg0UI45sJhsTp/JvciP1XK6JHgiIWp6L/TcRQeCsX04Binb8WerPgDWdP9A4oroB\n\t\t\t\t\t\t0UsLuEW0FBsLhnMyCVSJt+xbR0ctVu12LuYcIA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "napier.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.napier.ac.uk/idp/SSO.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federation.napier.ac.uk/idp/SSO.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://federation.napier.ac.uk/idp/isx.saml1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://federation.napier.ac.uk:8443/idp/soap.ssaml1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "napier.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDeDCCAmCgAwIBAgIGAU+sUxvAMA0GCSqGSIb3DQEBCwUAMH0xCzAJBgNVBAYT\n\t\t\t\t\t\tAkdCMRIwEAYDVQQIEwlFZGluYnVyZ2gxEjAQBgNVBAcTCUVkaW5idXJnaDEkMCIG\n\t\t\t\t\t\tA1UEChMbRWRpbmJ1cmdoIE5hcGllciBVbml2ZXJzaXR5MSAwHgYDVQQDExdmZWRl\n\t\t\t\t\t\tcmF0aW9uLm5hcGllci5hYy51azAeFw0xNTA5MDgwOTM5MzFaFw0zNTA5MDQwOTM5\n\t\t\t\t\t\tMzFaMH0xCzAJBgNVBAYTAkdCMRIwEAYDVQQIEwlFZGluYnVyZ2gxEjAQBgNVBAcT\n\t\t\t\t\t\tCUVkaW5idXJnaDEkMCIGA1UEChMbRWRpbmJ1cmdoIE5hcGllciBVbml2ZXJzaXR5\n\t\t\t\t\t\tMSAwHgYDVQQDExdmZWRlcmF0aW9uLm5hcGllci5hYy51azCCASIwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEBBQADggEPADCCAQoCggEBAMLtdCNUtcf8tt0/nq07hzjF8TIJMkPXwPCRxo0o\n\t\t\t\t\t\trBYOH3NB6GYbDODXu4W7AmhF8p+BsgKL0wkl+Zl53+AJdThMfU1rN+Ih3co3qpjZ\n\t\t\t\t\t\txDHmnj4HzKGAdRWTQsnSA5/gY9WWWsIT/7aannP7yAQXeOO1Qch8+D8ZqGpkoLYK\n\t\t\t\t\t\thNMeILHIBnuaTit2DsTuFaCaibJ9ky2TxUZQXh8h+InChCGYY6bnKQKRaFszD/B6\n\t\t\t\t\t\tN5JfYWyNqwHcnx1qTWmQWWLbt1ZlGE7/OwkMVzdNOalOf5SunDjA17U0lX0gpO/0\n\t\t\t\t\t\tNpOLHGCx9RgDlQzJ1fXGLGQ+iLWNCcUlbxCyPWPZxb1ATmUCAwEAATANBgkqhkiG\n\t\t\t\t\t\t9w0BAQsFAAOCAQEAhUHBGidQ7SPwgSDIOFKuYfoKBqeziRp675SACxVMS+wqrAlx\n\t\t\t\t\t\thNqAyJVmc4+pslEggwaVL3MKvXQHKizd2dS1U4Gd7Ew43/FzDoRpeQ33aASS1FR1\n\t\t\t\t\t\tZkPAfhNsVtcW+fGrx/vg9bmf2BUcYkHKAJ69wkuHhfhEyqU0Jplerlr1q0+XcE4K\n\t\t\t\t\t\tTH0FxhmDjCJyKEgW7SBU1CU7Vb3EKDw43NSkEoex89I5Ck0GPGLkCK7roP+jTQ6K\n\t\t\t\t\t\ttg0UI45sJhsTp/JvciP1XK6JHgiIWp6L/TcRQeCsX04Binb8WerPgDWdP9A4oroB\n\t\t\t\t\t\t0UsLuEW0FBsLhnMyCVSJt+xbR0ctVu12LuYcIA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Edinburgh Napier University (PingFederate)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.napier.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Edinburgh Napier University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://scalear-staging2.herokuapp.com",
    {
      "entity_id": "https://scalear-staging2.herokuapp.com",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Scalable Learning"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "www.scalable-learning.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Scalable Learning"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.scalable-learning.com/home/about"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Scalable Learning"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Blended learning platform for interactive in-class and online education."
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Plattform f\u00f6r st\u00f6d av \"flipped classroom\" utbildning."
                  }
                ],
                "logo": [
                  {
                    "text": "https://scalear-staging2.herokuapp.com/assets/logo-a66e557f3f93b4d5195033ba1a1527a3.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.scalable-learning.com/home/privacy"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDljCCAn4CCQCqbKeZgkK/pTANBgkqhkiG9w0BAQsFADCBjDELMAkGA1UEBhMC\nU0UxEjAQBgNVBAgMCVNUT0NLSE9MTTESMBAGA1UEBwwJU1RPQ0tIT0xNMRowGAYD\nVQQKDBFTQ0FMQUJMRSBMRUFSTklORzEQMA4GA1UECwwHc2NhbGVhcjEnMCUGA1UE\nAwwec2NhbGVhci1zdGFnaW5nMi5oZXJva3VhcHAuY29tMB4XDTE2MDIyNTExMzI0\nNVoXDTE3MDIyNDExMzI0NVowgYwxCzAJBgNVBAYTAlNFMRIwEAYDVQQIDAlTVE9D\nS0hPTE0xEjAQBgNVBAcMCVNUT0NLSE9MTTEaMBgGA1UECgwRU0NBTEFCTEUgTEVB\nUk5JTkcxEDAOBgNVBAsMB3NjYWxlYXIxJzAlBgNVBAMMHnNjYWxlYXItc3RhZ2lu\nZzIuaGVyb2t1YXBwLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nAJt5KVMamR4VM+orgoHIXhdY4YCjojE+NLpUTlQhVY+FHnBxEf5NbZoX617qoys1\nXY+X4wWgGEKqzaGryWh2d7vKjkhyRkYyTTMnnMEVeRx2B9d1dtWXwn+VLob6LbGJ\nAtt/yJnj9N4YdYsE4wQ96KBTcEOzDjXaMlhkR1DD2v2iGqmlE+rfwAfOJjWe1sD8\nVvIYyTKfoA3QbF3M75TR77RrEDr//rsAWLd0WGv77NxiSrGVes5pPEZlH/s5DUh3\nnanhrStyLZUPpVZDgzWfnntZnnV2Y18EwmFtbfiP3uoQOQBCrPCRplcqSfXxmGDT\nVveQGP10ZpJAEZPVDM9lhrkCAwEAATANBgkqhkiG9w0BAQsFAAOCAQEAJD01OmDH\nfYT/KcRxAAWi7+RwOZsQmv+t3wkmzEQ3BDOETQ4XMVAtommwGtSaL24Z7Mo6lxSJ\nv0yCCkBCxkeKST8Rsx0iaTKdFpKc8DesPplEmNjbud+BoA7VNyXBAiGsifOzHXW3\nMQytZReHD/l0AO6DSjukXZADKQQtfQIJplMyCfBJMBtNlG6PH6oPiGxI6NhDytHO\nZXxK1uQ+5ZunqauacDK2idAh/Oe4aaAfxYMp1Oh7/oXU80nM3RDz2hVSeQVy85y8\npq7jZ9OX3q5P9y5agNP6P1SaXNjgSUdAFMSbaltu5/I5LPo8RYXZUScKW1N9LEx7\nqONqqzvm+WBOIQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://scalear-staging2.herokuapp.com/saml/consume",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.lincoln.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Varol"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athens@lincoln.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Elif"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Tompkins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:stompkins@lincoln.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.lincoln.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-05-24T09:14:03Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.lincoln.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.lincoln.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lincoln.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSjCCAjKgAwIBAgIIc6UBcBsQyJgwDQYJKoZIhvcNAQEFBQAwPDEeMBwGA1UE\n\t\t\t\t\t\tCgwVVW5pdmVyc2l0eSBvZiBMaW5jb2xuMRowGAYDVQQDDBFpZHAubGluY29sbi5h\n\t\t\t\t\t\tYy51azAeFw0xMzAxMjkxMDQ5MTFaFw0yMzAxMjkxMDQ5MTFaMDwxHjAcBgNVBAoM\n\t\t\t\t\t\tFVVuaXZlcnNpdHkgb2YgTGluY29sbjEaMBgGA1UEAwwRaWRwLmxpbmNvbG4uYWMu\n\t\t\t\t\t\tdWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCmBWA3X5TBChNdRKB7\n\t\t\t\t\t\tmFrqf85x00gTT72GwVFqsV7BEMZ2UvMqauSS0oWHsCmKr7Q34DcJ1ExFdEI5jfQW\n\t\t\t\t\t\tInbW2b7AcmnE+oKJEbIhqKBEYeu5Hc/Dw03SyDPH+iSh9bx6EJaH5eugzF9U08tk\n\t\t\t\t\t\tXME2DEduj3AUIWvUPK9Dv8JXv9VJODB0VtbydHqLNO5mFFarlmXiDeS1nfIP/EaG\n\t\t\t\t\t\tcgpgeodbYQNksRwlCr+42CDmKEeL9xBPSHffl067Dhdn/BerjGfhhRPIcKGyqqW1\n\t\t\t\t\t\tdIeIxf4dE7mSjU+Vgi9rAkYYiYmS6VZ+xqUOENBiwmB15U16Zn6RwWRfC+ws1QYl\n\t\t\t\t\t\tndEFAgMBAAGjUDBOMB0GA1UdDgQWBBTsQIaEu965VZKaGcma7WN0SOeXAjAfBgNV\n\t\t\t\t\t\tHSMEGDAWgBTsQIaEu965VZKaGcma7WN0SOeXAjAMBgNVHRMEBTADAQH/MA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQBOdgr9ODArnjsqvC2pl/UlyStM2J98FrkuliC5N8LXnKPV\n\t\t\t\t\t\tGnJq8oBk3gt5y0q+79Om3jyN+olZl2htdSx2YWN742ft40532abT/B4/aItMqInZ\n\t\t\t\t\t\teZju9+41GQzhRVXwmJTsVIeJi7J4cHj8sVg+AppdfhM9gWfBcBaG+pHjrJPVAzwq\n\t\t\t\t\t\tKKhlaB5h3oGZW8A6OWJda/+y8JhoAXQMNwP7TriiNxyHeDBhoHZDOwTGw5qMexeA\n\t\t\t\t\t\thi/GatyZw+G/0dmCdpKTeUIm1XLmcBya6DJmLvT9hgKjhS/YBfS8pzXYSHSccmmx\n\t\t\t\t\t\tlhH0f8puYVYzEpQri0i10R25xmhRpI1gEieJUqNQ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSjCCAjKgAwIBAgIIc6UBcBsQyJgwDQYJKoZIhvcNAQEFBQAwPDEeMBwGA1UE\n\t\t\t\t\t\tCgwVVW5pdmVyc2l0eSBvZiBMaW5jb2xuMRowGAYDVQQDDBFpZHAubGluY29sbi5h\n\t\t\t\t\t\tYy51azAeFw0xMzAxMjkxMDQ5MTFaFw0yMzAxMjkxMDQ5MTFaMDwxHjAcBgNVBAoM\n\t\t\t\t\t\tFVVuaXZlcnNpdHkgb2YgTGluY29sbjEaMBgGA1UEAwwRaWRwLmxpbmNvbG4uYWMu\n\t\t\t\t\t\tdWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCmBWA3X5TBChNdRKB7\n\t\t\t\t\t\tmFrqf85x00gTT72GwVFqsV7BEMZ2UvMqauSS0oWHsCmKr7Q34DcJ1ExFdEI5jfQW\n\t\t\t\t\t\tInbW2b7AcmnE+oKJEbIhqKBEYeu5Hc/Dw03SyDPH+iSh9bx6EJaH5eugzF9U08tk\n\t\t\t\t\t\tXME2DEduj3AUIWvUPK9Dv8JXv9VJODB0VtbydHqLNO5mFFarlmXiDeS1nfIP/EaG\n\t\t\t\t\t\tcgpgeodbYQNksRwlCr+42CDmKEeL9xBPSHffl067Dhdn/BerjGfhhRPIcKGyqqW1\n\t\t\t\t\t\tdIeIxf4dE7mSjU+Vgi9rAkYYiYmS6VZ+xqUOENBiwmB15U16Zn6RwWRfC+ws1QYl\n\t\t\t\t\t\tndEFAgMBAAGjUDBOMB0GA1UdDgQWBBTsQIaEu965VZKaGcma7WN0SOeXAjAfBgNV\n\t\t\t\t\t\tHSMEGDAWgBTsQIaEu965VZKaGcma7WN0SOeXAjAMBgNVHRMEBTADAQH/MA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQBOdgr9ODArnjsqvC2pl/UlyStM2J98FrkuliC5N8LXnKPV\n\t\t\t\t\t\tGnJq8oBk3gt5y0q+79Om3jyN+olZl2htdSx2YWN742ft40532abT/B4/aItMqInZ\n\t\t\t\t\t\teZju9+41GQzhRVXwmJTsVIeJi7J4cHj8sVg+AppdfhM9gWfBcBaG+pHjrJPVAzwq\n\t\t\t\t\t\tKKhlaB5h3oGZW8A6OWJda/+y8JhoAXQMNwP7TriiNxyHeDBhoHZDOwTGw5qMexeA\n\t\t\t\t\t\thi/GatyZw+G/0dmCdpKTeUIm1XLmcBya6DJmLvT9hgKjhS/YBfS8pzXYSHSccmmx\n\t\t\t\t\t\tlhH0f8puYVYzEpQri0i10R25xmhRpI1gEieJUqNQ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Lincoln"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://lincoln.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Lincoln"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://appdb.egi.eu/edugain-connect",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chatziangelou"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mhaggel@iasa.gr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marios"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Chatziangelou"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "appdb-support@iasa.gr"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marios"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://appdb.egi.eu/edugain-connect",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Accelerating Systems and Applications - Greek Research and Technology Network"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u0399\u03bd\u03c3\u03c4\u03b9\u03c4\u03bf\u03cd\u03c4\u03bf \u0395\u03c0\u03b9\u03c4\u03b1\u03c7\u03c5\u03bd\u03c4\u03b9\u03ba\u03ce\u03bd \u03a3\u03c5\u03c3\u03c4\u03b7\u03bc\u03ac\u03c4\u03c9\u03bd \u03ba\u03b1\u03b9 \u0395\u03c6\u03b1\u03c1\u03bc\u03bf\u03b3\u03ce\u03bd - \u0395\u03b8\u03bd\u03b9\u03ba\u03cc \u0394\u03af\u03ba\u03c4\u03c5\u03bf \u0388\u03c1\u03b5\u03c5\u03bd\u03b1\u03c2 \u03ba\u03b1\u03b9 \u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03af\u03b1\u03c2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iasa.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iasa.gr/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.grnet.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.grnet.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IASA - GRNET"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u0399\u0395\u03a3\u0395 - \u0395\u0394\u0395\u03a4"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://appdb.egi.eu/auth/module.php/saml/sp/saml2-logout.php/edugain-connect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://appdb.egi.eu/auth/module.php/saml/sp/saml2-logout.php/edugain-connect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://wiki.appdb.egi.eu/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EGI Applications Database (Connect)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "EGI Software & Cloud Marketplace (Connect)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://appdb.egi.eu/images/appdblogo.png",
                    "height": "128",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "120"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://wiki.appdb.egi.eu/main:about:terms"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://wiki.appdb.egi.eu/main:about:terms"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://appdb.egi.eu/auth/module.php/saml/sp/saml2-acs.php/edugain-connect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://appdb.egi.eu/auth/module.php/saml/sp/saml1-acs.php/edugain-connect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://appdb.egi.eu/auth/module.php/saml/sp/saml2-acs.php/edugain-connect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://appdb.egi.eu/auth/module.php/saml/sp/saml1-acs.php/edugain-connect/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "EGI Applications Database (Connect)"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "EGI Software & Cloud Marketplace (Connect)"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.st-davids-coll.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Vinall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jvinall@st-davids-coll.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Vinall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jvinall@st-davids-coll.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.st-davids-coll.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDajCCAlICCQCTJJAxaWzfAzANBgkqhkiG9w0BAQUFADB3MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEOMAwGA1UECBMFV2FsZXMxEDAOBgNVBAcTB0NhcmRpZmYxIzAhBgNVBAoTGlN0\n\t\t\t\t\t\tIERhdmlkcyBDYXRob2xpYyBDb2xsZWdlMSEwHwYDVQQDExhpZHAuc3QtZGF2aWRz\n\t\t\t\t\t\tLWNvbGwuYWMudWswHhcNMTIwMzIzMTY0NzEwWhcNMzIwMzE4MTY0NzEwWjB3MQsw\n\t\t\t\t\t\tCQYDVQQGEwJHQjEOMAwGA1UECBMFV2FsZXMxEDAOBgNVBAcTB0NhcmRpZmYxIzAh\n\t\t\t\t\t\tBgNVBAoTGlN0IERhdmlkcyBDYXRob2xpYyBDb2xsZWdlMSEwHwYDVQQDExhpZHAu\n\t\t\t\t\t\tc3QtZGF2aWRzLWNvbGwuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\n\t\t\t\t\t\tAoIBAQDhWg9tcwBj95jVLLEgOP8z6tGRNbmSExldo8+hA740TNTFkJPrNlYBgSCa\n\t\t\t\t\t\tDu+eyeADmK9qSNDcTUEvU0WA9pVkywALqeW1+DVCPY7MhhD1duv1zcQIeqdQ9luY\n\t\t\t\t\t\tV7pQq0cFLuN3vgzuh+MLWOcmz45jcSbIa4EGhgQn0nWKzMzi1HG4kDWAeGzpdG0q\n\t\t\t\t\t\te1UV3a/IqvwYR3+OLSJYHMcGXmhpi5AEadpJtE/w7fZymmIHaWsn7WrBxhXE7xXy\n\t\t\t\t\t\tolIr7FEx9af1nR5fEXWnUdW/QSn8o9GNijLq8ZIpr1dh33QiFy+lB4OicTZdC8fj\n\t\t\t\t\t\tUn8ySwdIscH7kQM63URZxSsB7YNjAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBACDS\n\t\t\t\t\t\tMdkGKQhJ1E0Wmz7ZdUmJugpBoxKEGzr4GpvRc5TZVUf7BkzGNCC2NxvaILuxK26e\n\t\t\t\t\t\tdeR03Q8QOpw10Wk09PFH59EsZyKWR+RgWPNaeTYsCUnPptMgrcYEOjuf8yt95XLL\n\t\t\t\t\t\tOAoOa6VzuvG5z2cFuiY5jgqCr1WtiQeJ5HW2YN8I/3aFuw+tV55C321lYby5RuUc\n\t\t\t\t\t\tBVI9kTZqCOvCiF32WBLlyf0dD6NqFAYwe1/sXgF2MS7E+toNUqh+j7LEeDBZhraV\n\t\t\t\t\t\t4Os8vJ7kUY0JJ2pGbN+1FwEU6e2hKEWwrX7Iet4mBkC9L2qnDRxsFzyNir1bAJLx\n\t\t\t\t\t\tmxjEbDBSMeoSEI5WYOQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "st-davids-coll.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.st-davids-coll.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.st-davids-coll.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.st-davids-coll.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.st-davids-coll.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.st-davids-coll.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.st-davids-coll.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.st-davids-coll.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.st-davids-coll.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "st-davids-coll.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDajCCAlICCQCTJJAxaWzfAzANBgkqhkiG9w0BAQUFADB3MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEOMAwGA1UECBMFV2FsZXMxEDAOBgNVBAcTB0NhcmRpZmYxIzAhBgNVBAoTGlN0\n\t\t\t\t\t\tIERhdmlkcyBDYXRob2xpYyBDb2xsZWdlMSEwHwYDVQQDExhpZHAuc3QtZGF2aWRz\n\t\t\t\t\t\tLWNvbGwuYWMudWswHhcNMTIwMzIzMTY0NzEwWhcNMzIwMzE4MTY0NzEwWjB3MQsw\n\t\t\t\t\t\tCQYDVQQGEwJHQjEOMAwGA1UECBMFV2FsZXMxEDAOBgNVBAcTB0NhcmRpZmYxIzAh\n\t\t\t\t\t\tBgNVBAoTGlN0IERhdmlkcyBDYXRob2xpYyBDb2xsZWdlMSEwHwYDVQQDExhpZHAu\n\t\t\t\t\t\tc3QtZGF2aWRzLWNvbGwuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\n\t\t\t\t\t\tAoIBAQDhWg9tcwBj95jVLLEgOP8z6tGRNbmSExldo8+hA740TNTFkJPrNlYBgSCa\n\t\t\t\t\t\tDu+eyeADmK9qSNDcTUEvU0WA9pVkywALqeW1+DVCPY7MhhD1duv1zcQIeqdQ9luY\n\t\t\t\t\t\tV7pQq0cFLuN3vgzuh+MLWOcmz45jcSbIa4EGhgQn0nWKzMzi1HG4kDWAeGzpdG0q\n\t\t\t\t\t\te1UV3a/IqvwYR3+OLSJYHMcGXmhpi5AEadpJtE/w7fZymmIHaWsn7WrBxhXE7xXy\n\t\t\t\t\t\tolIr7FEx9af1nR5fEXWnUdW/QSn8o9GNijLq8ZIpr1dh33QiFy+lB4OicTZdC8fj\n\t\t\t\t\t\tUn8ySwdIscH7kQM63URZxSsB7YNjAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBACDS\n\t\t\t\t\t\tMdkGKQhJ1E0Wmz7ZdUmJugpBoxKEGzr4GpvRc5TZVUf7BkzGNCC2NxvaILuxK26e\n\t\t\t\t\t\tdeR03Q8QOpw10Wk09PFH59EsZyKWR+RgWPNaeTYsCUnPptMgrcYEOjuf8yt95XLL\n\t\t\t\t\t\tOAoOa6VzuvG5z2cFuiY5jgqCr1WtiQeJ5HW2YN8I/3aFuw+tV55C321lYby5RuUc\n\t\t\t\t\t\tBVI9kTZqCOvCiF32WBLlyf0dD6NqFAYwe1/sXgF2MS7E+toNUqh+j7LEeDBZhraV\n\t\t\t\t\t\t4Os8vJ7kUY0JJ2pGbN+1FwEU6e2hKEWwrX7Iet4mBkC9L2qnDRxsFzyNir1bAJLx\n\t\t\t\t\t\tmxjEbDBSMeoSEI5WYOQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "St David's Catholic College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.st-davids-coll.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "St David's Catholic College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.uni-lj.si/idp/20100525",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rebernik"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:majda.rebernik@uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Majda"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jagodic"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:anton.jagodic@uni-lj.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Anton"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uni-lj.si/idp/20100525",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_general.pdf"
              },
              {
                "lang": "sl",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_splosni_pogoji.pdf"
              }
            ],
            "registration_instant": "2014-11-06T18:11:09Z",
            "registration_authority": "http://aai.arnes.si",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uni-lj.si/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uni-lj.si/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ctk.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "student.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ag.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "agrft.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aluo.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bf1.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ef1.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fa.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fdv.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fe1.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ff.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ffa.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fgg.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fkkt1.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fmf.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fpp.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fri1.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fs1.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fsd.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fsp.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fu.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mef.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ntf.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pef.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pf.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "teof.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vf.uni-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "zf.uni-lj.si"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uni-lj.si/en"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uni-lj.si"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Ljubljana"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Univerza v Ljubljani"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for organization University of Ljubljana"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ponudnik identitet organizacije Univerza v Ljubljani"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "239",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "240"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.uni-lj.si/en"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.uni-lj.si"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Ljubljana"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Univerza v Ljubljani"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-lj.si/en"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-lj.si"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Ljubljana"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Univerza v Ljubljani"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.w-hs.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hotline"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hotline@aai.dfn.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "DFN-AAI"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hotline"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hotline@aai.dfn.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "DFN-AAI"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.w-hs.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-01-13T13:45:59Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "login.w-hs.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIHCzCCBfOgAwIBAgIHGI6IZfmuSjANBgkqhkiG9w0BAQsFADCBozELMAkGA1UE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\n1flnDftTm/jsXvc+lc5/qA60dRU52CfJhDfc0kVY6g=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=login.w-hs.de,OU=ZIM-IT,O=Westfaelische Hochschule Gelsenkirchen\\, Bocholt\\, Recklinghausen,L=Gelsenkirchen,ST=Nordrhein-Westfalen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "w-hs.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.w-hs.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.w-hs.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.w-hs.de/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.w-hs.de/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.w-hs.de:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.w-hs.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.w-hs.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.w-hs.de/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.w-hs.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.w-hs.de/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.w-hs.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.w-hs.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "w-hs.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.w-hs.de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.en.w-hs.de"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Westf\u00e4lische Hochschule Gelsenkirchen Bocholt Recklinghausen"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Westf\u00e4lische Hochschule, University of Applied Sciences Gelsenkirchen Bocholt Recklinghausen"
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.w-hs.de/idp/images/favicon.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://login.w-hs.de/idp/images/logo.png",
                    "height": "103",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "393"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Westf\u00e4lische Hochschule"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Westf\u00e4lische Hochschule, University of Applied Sciences"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "login.w-hs.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIHCzCCBfOgAwIBAgIHGI6IZfmuSjANBgkqhkiG9w0BAQsFADCBozELMAkGA1UE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\n1flnDftTm/jsXvc+lc5/qA60dRU52CfJhDfc0kVY6g=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=login.w-hs.de,OU=ZIM-IT,O=Westfaelische Hochschule Gelsenkirchen\\, Bocholt\\, Recklinghausen,L=Gelsenkirchen,ST=Nordrhein-Westfalen,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Westf\u00e4lische Hochschule"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Westf\u00e4lische Hochschule, University of Applied Sciences"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.w-hs.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.en.w-hs.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e441"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e441"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.tandfonline.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SSO-Tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SSO-Tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.tandfonline.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Atypon Systems: Taylor & Francis Online"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tandfonline.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIJAMO9zKBOInK0MA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\n\t\t\t\t\t\tBAMTE3d3dy50YW5kZm9ubGluZS5jb20wHhcNMTQwMzE0MDUwNDAyWhcNMTcwMzEz\n\t\t\t\t\t\tMDUwNDAyWjAeMRwwGgYDVQQDExN3d3cudGFuZGZvbmxpbmUuY29tMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA+7mPo1QcQmquZzEQh1lPd0/52x3tUmeS\n\t\t\t\t\t\th+BnInF0Ddi412jA/73bOkJw8DUCeFMpyDLq5KIEh5hpWko/hiN2MV440jHOOz4c\n\t\t\t\t\t\tC6q6FIKo0VbnIG1J8W3llePya/7RgXMApLZIO9JlTbru2qcCibgk9cjnKdLYGRLQ\n\t\t\t\t\t\tOQYZJs4QyA9nN9n53e7Ov7JVOb7R1y77o8h39JhLNCvDlySfhDTeggal2yNb24xf\n\t\t\t\t\t\teL4Ee5cKOWdgyo6g5FkHmXn5jsIeBhdI26PyJa46s2/v+3vRzYg/7SpXPj5jZ5JH\n\t\t\t\t\t\t9VmweGU01MjqvHQVYd7Bfi0Ndik4otfE5nneOQngI3fR5nWV5oGngwIDAQABo2kw\n\t\t\t\t\t\tZzBGBgNVHREEPzA9ghN3d3cudGFuZGZvbmxpbmUuY29thiZodHRwczovL3d3dy50\n\t\t\t\t\t\tYW5kZm9ubGluZS5jb20vc2hpYmJvbGV0aDAdBgNVHQ4EFgQUTh9Dhbn3dZ+Os2eC\n\t\t\t\t\t\tRsJIDjh7+mowDQYJKoZIhvcNAQEFBQADggEBABhElasaAVvlbl3ZvZQlhEcQpqQD\n\t\t\t\t\t\tTvZRxncGrz6moC3pHnUho0L3ZphAnMyHUQlZfg8uZuJBeWTOPYCIYuqQXn+pQ+Si\n\t\t\t\t\t\tS9n2L8UnoCgNI3df9DDYb7tzpSipYGEXGOw2RUWr1PUD8GQtzP5jkzMPs0eAm/U3\n\t\t\t\t\t\tpmChGsS7HZbNle9fyBUha2UFebCWFhjUm2iLsN2+kCOkfxEpwLTy26cz1MBqkhDN\n\t\t\t\t\t\thNI51amuMNcL46a8+E1IW8L59W656YzJnJ8I2A9nuHdmWQGs5jICuG4dr7+70wCP\n\t\t\t\t\t\tLv0VNFSwnTxjA5Rocmae95yzHIE0I4tW7VD+q+yeEStXHCCN1rWHgLWJb/U="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.tandfonline.com/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.tandfonline.com/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.tandfonline.com/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://elegitimation2.inloggning.se/simplesaml/module.php/saml/sp/metadata.php/frontwalkersp",
    {
      "entity_id": "https://elegitimation2.inloggning.se/simplesaml/module.php/saml/sp/metadata.php/frontwalkersp",
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Westoo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mikael.westoo@e-identitet.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mikael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Retendo"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.e-identitet.se/"
          }
        ],
        "organization_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Retendo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://elegitimation2.inloggning.se/simplesaml/module.php/saml/sp/saml2-logout.php/frontwalkersp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://elegitimation2.inloggning.se/simplesaml/module.php/saml/sp/discoresp.php",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Retendo provider"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Retendo provider"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Retendo AB"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Retendo AB"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://elegitimation2.inloggning.se/simplesaml/module.php/saml/sp/saml2-acs.php/frontwalkersp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://elegitimation2.inloggning.se/simplesaml/module.php/saml/sp/saml1-acs.php/frontwalkersp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://elegitimation2.inloggning.se/simplesaml/module.php/saml/sp/saml2-acs.php/frontwalkersp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://elegitimation2.inloggning.se/simplesaml/module.php/saml/sp/saml1-acs.php/frontwalkersp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://franklin-shib01.franklin.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Baker"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:john.e.baker@franklin.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bottomley"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve.bottomley@franklin.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://franklin-shib01.franklin.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZTCCAk2gAwIBAgIUcOe08w8KtBXNXbH+PNNNyO51KrswDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwKTEnMCUGA1UEAxMeZnJhbmtsaW4tc2hpYjAxLmZyYW5rbGluLmFjLnVrMB4X\n\t\t\t\t\t\tDTEwMDMwMjEzNDYxN1oXDTMwMDMwMjEzNDYxN1owKTEnMCUGA1UEAxMeZnJhbmts\n\t\t\t\t\t\taW4tc2hpYjAxLmZyYW5rbGluLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\n\t\t\t\t\t\tMIIBCgKCAQEA0ffs3wu73Gh7k0HUFbl9H0cdSF9Elc11El7uJGXEthMHau0HYCdt\n\t\t\t\t\t\tBE645S7EpW0poknu1HaLVqv9aSmEcTRI77bZ4xjGbODR8PiVlxVCfPT+FDDAulY8\n\t\t\t\t\t\tOs7ORD099SbgMJtkU/JLheEzZpgFqFf8TgLNDazfdRryi3MVgWeEoKwYOO2H9BV0\n\t\t\t\t\t\tKSETpu9Wn7miyt0salbeX9bjpSEURqNRX0WymJT/dxDTKSh1bVx02+BcqbUDyQQ4\n\t\t\t\t\t\tjo6xBJARO+c5idPv85E/NFd2WVrA4vWYiXdGQns99n2YQbG2gECw5vxQr/MyWzt1\n\t\t\t\t\t\t2xhzjsR0pno6QdveIWMmAMw/og69QjRIiQIDAQABo4GEMIGBMGAGA1UdEQRZMFeC\n\t\t\t\t\t\tHmZyYW5rbGluLXNoaWIwMS5mcmFua2xpbi5hYy51a4Y1aHR0cHM6Ly9mcmFua2xp\n\t\t\t\t\t\tbi1zaGliMDEuZnJhbmtsaW4uYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYE\n\t\t\t\t\t\tFPD7x48+M7C+18p79NOvITXP81FxMA0GCSqGSIb3DQEBBQUAA4IBAQAYPiPM9HJm\n\t\t\t\t\t\t900vq4X29iZz4r8gFEly/D3YN/8KqIAbKTY3CUZBcBse0NEOXwkw5JJrMbFSYcPN\n\t\t\t\t\t\tMUyp7GCuYXGxfJ79SLwuI/fzZE/DDpXy9DsG9oNFsr2svJl03hOx3myXngbmZGQZ\n\t\t\t\t\t\tqxMGVl3tJHV4GARfeo9p9hknnPt59sjPX+r9+ppG/V80jcD0CMHynW1/sxpcUOSN\n\t\t\t\t\t\tyXPJFkmpdhrtXRsebF4g2O93bc+8pJETG16teg4zGHeF7iKsjnQSISvFV4xj5vIu\n\t\t\t\t\t\tvtssyMJTau2MHvDz6ms4FaiMY5L+vzXXMMQ2pkfqSuOAjEkhd0WEOPY54L/fpBFE\n\t\t\t\t\t\t1tR0bsDdT1Yt"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "franklin.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://franklin-shib01.franklin.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://franklin-shib01.franklin.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://franklin-shib01.franklin.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://franklin-shib01.franklin.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://franklin-shib01.franklin.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://franklin-shib01.franklin.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://franklin-shib01.franklin.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://franklin-shib01.franklin.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "franklin.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDZTCCAk2gAwIBAgIUcOe08w8KtBXNXbH+PNNNyO51KrswDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwKTEnMCUGA1UEAxMeZnJhbmtsaW4tc2hpYjAxLmZyYW5rbGluLmFjLnVrMB4X\n\t\t\t\t\t\tDTEwMDMwMjEzNDYxN1oXDTMwMDMwMjEzNDYxN1owKTEnMCUGA1UEAxMeZnJhbmts\n\t\t\t\t\t\taW4tc2hpYjAxLmZyYW5rbGluLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\n\t\t\t\t\t\tMIIBCgKCAQEA0ffs3wu73Gh7k0HUFbl9H0cdSF9Elc11El7uJGXEthMHau0HYCdt\n\t\t\t\t\t\tBE645S7EpW0poknu1HaLVqv9aSmEcTRI77bZ4xjGbODR8PiVlxVCfPT+FDDAulY8\n\t\t\t\t\t\tOs7ORD099SbgMJtkU/JLheEzZpgFqFf8TgLNDazfdRryi3MVgWeEoKwYOO2H9BV0\n\t\t\t\t\t\tKSETpu9Wn7miyt0salbeX9bjpSEURqNRX0WymJT/dxDTKSh1bVx02+BcqbUDyQQ4\n\t\t\t\t\t\tjo6xBJARO+c5idPv85E/NFd2WVrA4vWYiXdGQns99n2YQbG2gECw5vxQr/MyWzt1\n\t\t\t\t\t\t2xhzjsR0pno6QdveIWMmAMw/og69QjRIiQIDAQABo4GEMIGBMGAGA1UdEQRZMFeC\n\t\t\t\t\t\tHmZyYW5rbGluLXNoaWIwMS5mcmFua2xpbi5hYy51a4Y1aHR0cHM6Ly9mcmFua2xp\n\t\t\t\t\t\tbi1zaGliMDEuZnJhbmtsaW4uYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYE\n\t\t\t\t\t\tFPD7x48+M7C+18p79NOvITXP81FxMA0GCSqGSIb3DQEBBQUAA4IBAQAYPiPM9HJm\n\t\t\t\t\t\t900vq4X29iZz4r8gFEly/D3YN/8KqIAbKTY3CUZBcBse0NEOXwkw5JJrMbFSYcPN\n\t\t\t\t\t\tMUyp7GCuYXGxfJ79SLwuI/fzZE/DDpXy9DsG9oNFsr2svJl03hOx3myXngbmZGQZ\n\t\t\t\t\t\tqxMGVl3tJHV4GARfeo9p9hknnPt59sjPX+r9+ppG/V80jcD0CMHynW1/sxpcUOSN\n\t\t\t\t\t\tyXPJFkmpdhrtXRsebF4g2O93bc+8pJETG16teg4zGHeF7iKsjnQSISvFV4xj5vIu\n\t\t\t\t\t\tvtssyMJTau2MHvDz6ms4FaiMY5L+vzXXMMQ2pkfqSuOAjEkhd0WEOPY54L/fpBFE\n\t\t\t\t\t\t1tR0bsDdT1Yt"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Franklin College, Grimsby"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.franklin.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Franklin Sixth Form College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibdev2.stir.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:infocentre@stir.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Information Centre"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "White"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:michael.white@stir.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibdev2.stir.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-10-23T10:56:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUVk73b1csIS7JJF+7A9VPKzf1PS8wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHjEcMBoGA1UEAwwTc2hpYmRldjIuc3Rpci5hYy51azAeFw0xNjAzMTEwOTMx\n\t\t\t\t\t\tNDdaFw0zNjAzMTEwOTMxNDdaMB4xHDAaBgNVBAMME3NoaWJkZXYyLnN0aXIuYWMu\n\t\t\t\t\t\tdWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDFev9VTpqeE8r1KqX0\n\t\t\t\t\t\tafFxRTTQ46ei99zPn+B1/VR5ylq+0pc4RxV1PxQiyWH8Xf5hPBGjUUqShzDJmLMq\n\t\t\t\t\t\tTlSrXh3ZiFNkUrjtdIaOvsfixiIqqicsN9Ez3yCsjRyG2sVBgtb/zwozAfL5c91A\n\t\t\t\t\t\t9fy7Kc9DvWTxUSIqBU01WfbQzzX54l1jKiFAKlkEuU1U/7jNqykTSvG/Q8FlXrxz\n\t\t\t\t\t\ta1ecP4TSM+wvrWQ7xuEmjhuaFJN9R6+HvKL9ic0GlsrvAieiBq15pJsLMw6nm6l/\n\t\t\t\t\t\tK+tI6OQiH9iV0+gfq98GjqXkFOsdFfI/h5hM+edMMfP9R5p0qORPek8NKY7D/92v\n\t\t\t\t\t\tjGmxAgMBAAGjbTBrMB0GA1UdDgQWBBQIvRtwMjQnUk+Tpw5+eIYWSMQiAzBKBgNV\n\t\t\t\t\t\tHREEQzBBghNzaGliZGV2Mi5zdGlyLmFjLnVrhipodHRwczovL3NoaWJkZXYyLnN0\n\t\t\t\t\t\taXIuYWMudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEFBQADggEBAJaFgKrp\n\t\t\t\t\t\twIn5rITMlAs3JJhcTtAwitoEOqAqiXm4wA+TclnSNAWj1Nmw0yvJwFK0iJ3AjOAh\n\t\t\t\t\t\tmuwQWLc1lB1PUXLG56TPtn/63cNEz/iO3giDx0GexFHgDKU67OFUR25HaPcV8/H+\n\t\t\t\t\t\tNOawLxTFmFbZfauyeE4j0VpDzTqvc2KycEJ/DlXeBycCdmoMG/i8UKNkUsiUiMTD\n\t\t\t\t\t\t1LY7/xj2dnAHRX3M9ISYwt4jkrQxomNPJ0YTDbG/MJCxDss0wCwNjkeumopmgsLv\n\t\t\t\t\t\t32K+lbBcxuokL0inWGyoh8R24mjFDsbVtLr0kMG192gXxWcF9RNJKx5uXe9CNN2j\n\t\t\t\t\t\tadwAW4bubm1Whaw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stir.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibdev2.stir.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibdev2.stir.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibdev2.stir.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibdev2.stir.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibdev2.stir.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibdev2.stir.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibdev2.stir.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibdev2.stir.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stir.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNzCCAh+gAwIBAgIUVk73b1csIS7JJF+7A9VPKzf1PS8wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHjEcMBoGA1UEAwwTc2hpYmRldjIuc3Rpci5hYy51azAeFw0xNjAzMTEwOTMx\n\t\t\t\t\t\tNDdaFw0zNjAzMTEwOTMxNDdaMB4xHDAaBgNVBAMME3NoaWJkZXYyLnN0aXIuYWMu\n\t\t\t\t\t\tdWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDFev9VTpqeE8r1KqX0\n\t\t\t\t\t\tafFxRTTQ46ei99zPn+B1/VR5ylq+0pc4RxV1PxQiyWH8Xf5hPBGjUUqShzDJmLMq\n\t\t\t\t\t\tTlSrXh3ZiFNkUrjtdIaOvsfixiIqqicsN9Ez3yCsjRyG2sVBgtb/zwozAfL5c91A\n\t\t\t\t\t\t9fy7Kc9DvWTxUSIqBU01WfbQzzX54l1jKiFAKlkEuU1U/7jNqykTSvG/Q8FlXrxz\n\t\t\t\t\t\ta1ecP4TSM+wvrWQ7xuEmjhuaFJN9R6+HvKL9ic0GlsrvAieiBq15pJsLMw6nm6l/\n\t\t\t\t\t\tK+tI6OQiH9iV0+gfq98GjqXkFOsdFfI/h5hM+edMMfP9R5p0qORPek8NKY7D/92v\n\t\t\t\t\t\tjGmxAgMBAAGjbTBrMB0GA1UdDgQWBBQIvRtwMjQnUk+Tpw5+eIYWSMQiAzBKBgNV\n\t\t\t\t\t\tHREEQzBBghNzaGliZGV2Mi5zdGlyLmFjLnVrhipodHRwczovL3NoaWJkZXYyLnN0\n\t\t\t\t\t\taXIuYWMudWsvaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEFBQADggEBAJaFgKrp\n\t\t\t\t\t\twIn5rITMlAs3JJhcTtAwitoEOqAqiXm4wA+TclnSNAWj1Nmw0yvJwFK0iJ3AjOAh\n\t\t\t\t\t\tmuwQWLc1lB1PUXLG56TPtn/63cNEz/iO3giDx0GexFHgDKU67OFUR25HaPcV8/H+\n\t\t\t\t\t\tNOawLxTFmFbZfauyeE4j0VpDzTqvc2KycEJ/DlXeBycCdmoMG/i8UKNkUsiUiMTD\n\t\t\t\t\t\t1LY7/xj2dnAHRX3M9ISYwt4jkrQxomNPJ0YTDbG/MJCxDss0wCwNjkeumopmgsLv\n\t\t\t\t\t\t32K+lbBcxuokL0inWGyoh8R24mjFDsbVtLr0kMG192gXxWcF9RNJKx5uXe9CNN2j\n\t\t\t\t\t\tadwAW4bubm1Whaw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Stirling - Development"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.stir.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Stirling"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.aai.arnes.si/idp/20090116",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@arnes.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Arnes"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Podpora"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aaa-podpora@arnes.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAA"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Arnes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:arnes@arnes.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Arnes"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.aai.arnes.si/idp/20090116",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_general.pdf"
              },
              {
                "lang": "sl",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_splosni_pogoji.pdf"
              }
            ],
            "registration_instant": "2014-08-25T15:08:00Z",
            "registration_authority": "http://aai.arnes.si",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.aai.arnes.si/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.aai.arnes.si/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "arnes.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "test.arnes.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "guest.arnes.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-pirnice.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "zvkds.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osrace.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ddvic.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iam.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sola-zetale.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osmalecnik.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-volicina.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vrtec-ljutomer.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vrtec-logatec.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-zelezniki.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ostrzic.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "8talcev.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ososkar.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-bistrica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ostomaz.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vergerio.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mps.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-gracisce.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-preserjeradomlje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-dobravlje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-starse.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucenec.os-starse.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vist.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oscg-info.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-preddvor.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vrtci-brezovica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-strocjavas.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cufar.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sola-miklavz.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oslesce.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-dutovlje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-danilekumar.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osenams.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-hrvatini.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os2ms.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-svjurij.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "seps.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sc-sezana.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osbeltinci.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osmesto.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-breg.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-raka.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucenec.os-raka.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oslava.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-tabor1.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-gpetrovci.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ospg.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osik.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gimnazija-ormoz.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "poldestrazisar.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "11sola.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ossvj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osormoz.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oskolezija.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "abesednjak.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ostrojica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-dornberk.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-iroba.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-cerknica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oskoseze.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-laporje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-dk.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-ljudskivrtptuj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oscankova.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-podgrad.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-verzej.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "konsak.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "miroslav-vilhar.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ss-crnomelj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-franaerjavca.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-brusnice.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-sentjernej.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucenec.os-sentjernej.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oszuzemberk.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-cirkovce.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ossmartno-sg.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-gabrovka-dole.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-kapela.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vstp.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-sentjanz.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osgorjup.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucenec.osgorjup.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-mostnasoci.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cirkulane-zavrc.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osblanca.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gros-radgona.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osdravlje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osmokronog.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osmetlika.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osmsn.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hrusevec.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osvodmat.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ssjj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-kutezevo.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vrtec-kamnik.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-ljubecna.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sola-podlehnik.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "helpdesk.arnes.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-dragatus.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osmislinja.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ospuconci.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ospreska.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-kosana.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ospreserje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oszalog.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "icp-mb.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-radenci.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oslucija.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vrteczala.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ospo-slb.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osbakovci.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-divaca.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ekonomska-ms.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hinko-smrekar.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osdragomelj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sc-s.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "arrs.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sssb.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dos-prosenjakovci.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osbos.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osstopice.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-odranci.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oshjh-staritrg.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-leon.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-ajdovscina.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-igroharja.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kis.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "o-azilb.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-kanal.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-trebnje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mklj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "okrogar.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-kamnica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osfrsmb.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-dobrna.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-jelsane.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-dobrovo.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osmoravce.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osferdavesela.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ossmartno-tuhinj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-pivka.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-sladki-vrh.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cdi-univerzum.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-miklavz.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osbohinj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gimjes.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-brezovica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oslimbus.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osorehek.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osmslj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oslag.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-loka-crnomelj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-turnisce.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osgusi.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oszrece.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "jozmos.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-negova.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bic-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "koseze.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osmjc.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-ivantavcar.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oskm.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osvp.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osicljutomer.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ospoljane.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osflv.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osfram.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oskosmac.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osld.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mdj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ng-slo.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dssl.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gimidrija.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sszagorje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fmalgaja.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "slivnica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osdobje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vzgojni-zavod-verzej.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "konservatorij-maribor.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-majdevrhovnik.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-fokovci.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-novejarse.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osgradec.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gfml.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "prezihovvoranc.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oszboraodposlancev.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ponikva.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gimsen.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-bled.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-bostanj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-smarje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-predoslje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cirius-vipava.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vrtec-sentjernej.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gro.sik.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gsv.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-atl.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osjenka.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-mojstrana.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-rence.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osdobrova.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gimoste.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-hoce.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "egss.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "o-cezanjevci.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ossiska.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-vodice.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osrovte.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-spidrija.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osagpostojna.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "koroskijeklarji.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-prestranek.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "askerc.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-sencur.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osribnica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osbistricaobsotli.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osvsmuc.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osminka.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ossevnica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cerkljeobkrki.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-sostro.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-podbocje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ingoliceva.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tretja.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-mozirje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osrakek.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osfrslj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osborovnica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mpt-velenje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osms.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osvelikadolina.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "francebevk.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vrtec-trzic.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osmnr.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osrihardajakopica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osrj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-naklo.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cmepius.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "slomskov-zavod.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osfpmaribor.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "prvagim.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dijaki.prvagim.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mg-lj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ospodzemelj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os4ms.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ossecovlje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "grm-nm.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "students.grm-nm.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osprule.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osgorje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-tabor.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-vojnik.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-litija.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ostb.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-sostanj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-makole.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-podcetrtek.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mfdps.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ssfkz.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gfp.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-salovci.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bc-naklo.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osmj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-sentrupert.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gcc1.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hvu.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oslovrenc.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vsnm.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "scpo.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ges-sb.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "viviss.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "inz.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-podbrdo.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "zgnl.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "student.zgnl.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-koper.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucenec.os-koper.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-iskvarce.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-loskipotok.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ospvmb.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vrtec-tezno.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "facka.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oscv.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gskranj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "seslj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sts-koper.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ossempas.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vizvisnjagora.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ssdomzale.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stps-trbovlje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ludvik.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sveta-ana.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-kozara.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dd-msobota.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oskomenda-moste.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "padeznik-mojasola.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "centerjanezalevca.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osdj-cerklje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gimnazija-brezice.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-duplek.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-sodrazica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-frana-rosa.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sggos.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osbi.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-sturje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oskorena.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-smartno.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-domzale.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-velikigaber.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-kidricevo.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oslasko.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-marijevere.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osribnicanapohorju.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "makspecar.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucenec.makspecar.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oskoroskabela.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-vipava.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ssof.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-hajdina.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "acs.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gimvic.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pedag.gimvic.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "admin.gimvic.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-sticna.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-jakobaaljaza.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ospolje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-strazisce-kr.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gcc.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ossentvid.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-petrovce.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stanislav.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osvic.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-vv.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-mirna.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ossavskonaselje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osbogojina.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-jd.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vrtec-vodice.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-skofljica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-ev-prade.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "solavidem.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-mk.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucenci.os-mk.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "glazer.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-kdk.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucenci.os-kdk.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iosce.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oskrize.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osnovna-sola-idrija.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-novefuzine.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osbenedikt.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-hrpelje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ossjsmlednik.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iios-rogaska.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-cerkvenjak.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-kobarid.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-ivanjkovci.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-vrhovci.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "1osrogaska.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "3os-celje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "net.3os-celje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "zssm.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osapace.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-zadobrova.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-borcev.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osjkb.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-zirovnica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osmklj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osmezica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-franakranjca.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "svsgl.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osszkr.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gozdis.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-branik.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "opvbistricams.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osdobova.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-dravograd.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oslivade.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oskobilje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osziri.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "antonukmar.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-col.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mladika.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gimng.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "szks.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-cerkno.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-dekani.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osartice.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-smartnolitija.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-fgp.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-stranje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oslivada.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ospodgorje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-komen.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-trzin.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osmuta.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ospesnica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osmmsentjanz.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sola-poljane.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-selnica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-frankolovo.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-globoko.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-jela-janezica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "slodrs.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ostpavcka.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucenec.ostpavcka.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sc-konjice-zrece.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cresnjevec.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ssgt-mb.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gim-ms.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ostrzisce.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ossredisceobdravi.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sc-krsko.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oshorjul.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osrogatec.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-lipnica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "zveza-slepih.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oskrsko.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-knezak.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "olgica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ospoljcane.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osmarezige.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-planina.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osic.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dusanabordona.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-sempeter.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "knjiznica-velenje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "presernova.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-miren.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-tsaljose.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "solaklavora.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-gsve.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osmatijecopa.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-vavta-vas.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gimtol.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-tolmin.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "2os-slb.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dos1-lendava.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osgorisnica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osjvkg.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osdramlje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "scuoladecastro.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sckr.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sesgs.sckr.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sser.sckr.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sts.sckr.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vss.sckr.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sg.sckr.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mic.sckr.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sola-rodica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osoplotnica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ostrnovo.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ssj-jesenice.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osams.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gimnazija-skofjaloka.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osvelikanedelja.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-pregarje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osig.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-crna.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vitakraigherja.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tonecufar.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ddmaribor.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vrtec-trbovlje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-cepovan.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ossmartno.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-destrnik.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lu-koper.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osbrezice.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oslenart.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dosdobrovnik.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osbraslovce.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "slander.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-bozidarjajakca.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ribalon.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osdobrepolje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os3ms.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osbrestanica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osgrad.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osgorica-velenje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osjursinci.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-brinje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osbezigrad.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-krizevci.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ssom.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ossenovo.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-maksadurjave.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osbicevje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-otlica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osgrm.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucenec.osgrm.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-toncke-cec.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-leskovec.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osobrinzi.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osjarenina.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osljubno.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-brezno.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bolnisnicna-sola.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osloce.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-lesicno.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osvinica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osobdravinji.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ossalek.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-livada.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oskozje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ss-venopilon.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dgnp-mb.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bts.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-fa.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osbrod.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osdeskle.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-vperka.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osmedvode.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-velikapolana.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucenec.os-velikapolana.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tonetacufarja.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-tinje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucenec.os-tinje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oskuzma.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-tisina.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-dob.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ddkoper.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ossentilj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-majsperk.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-smarjeta.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "scrm.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-smihel.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-markovci.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "smartno-poh.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-store.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osradlje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "1os-zalec.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucenec.1os-zalec.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ptrubar.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osfpcrensovci.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vrtec-ravne.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osvuzenica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dantealighieri.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-luce.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-dornava.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-grize.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hudinja.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dosgenterovci.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osbizeljsko.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "scpet.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "knjiznica-skofjaloka.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oskrmelj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gasp.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osgornjigrad.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osnovna-sola-polzela.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ospisece.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ugm.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-rimsketoplice.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oskaselj.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osnhr.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vrtec-tolmin.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osfara.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osnovnasolaprevole.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "podgoro.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osstaracerkev.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-kungota.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ostrbovlje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-nazarje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "solavitanje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sola-skofije.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-antonajanse.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osrecica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "voranc.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osbovec.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-razkrizje.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "srednjasolaizola.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "knjiznica-slovenskabistrica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "zelenajama.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-stari-trg-ok.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-koprivnica.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-vransko.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sfpkr.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "osjdol.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-malanedelja.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "os-montessori.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pei.si"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.arnes.si/en.html"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.arnes.si/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ARNES"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Arnes"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for organization Arnes"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ponudnik identitet organizacije Arnes"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "135",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "150"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.arnes.si/en.html"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.arnes.si/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ARNES"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Arnes"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.arnes.si/en.html"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.arnes.si/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ARNES"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Arnes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://infp-shib-01.uthct.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "david.nettleton@uthct.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David Nettleton"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://infp-shib-01.uthct.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://infp-shib-01.uthct.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://infp-shib-01.uthct.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://infp-shib-01.uthct.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://infp-shib-01.uthct.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://infp-shib-01.uthct.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uthct.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Texas Health Science Center At Tyler"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUPrqY2FoL3o+Is2MLqnRmpQ3pMKIwDQYJKoZIhvcNAQEF\nBQAwITEfMB0GA1UEAxMWaW5mcC1zaGliLTAxLnV0aGN0LmVkdTAeFw0wOTEyMTYx\nNTE3MTdaFw0yOTEyMTYxNTE3MTdaMCExHzAdBgNVBAMTFmluZnAtc2hpYi0wMS51\ndGhjdC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDfz4vaWker\nHmA0h6ZXOHYCQt1TpyUyq3/36EmA6xvjfA4Sg+/AUEoIL6MWuuI/UDT+OfiZ1m13\nNvkCcml2zVmCGqChpkPlBDAwrUwIVk5npsmcFo1ma6iVKCTOoBTikjCW+bg1r1n8\nd6YpRQZEajJiha4bs1hHjI+JdKbEnUWLoJQHujp+VqyuxhZXLL3wHJiSladVtgYv\nz3ItkscuTgAF0qe4zcHltZ//WChn9xt32h9BMe1y26a/qRxdb8kjMASkdOgP/APZ\nU1eAZEzY0y+fEO8fvd9u9WGYX1PqljR2E68GNhlZuuFYyFDT90lm6Sd+YXNxNk3b\n2VwQ78LuJSGpAgMBAAGjczBxMFAGA1UdEQRJMEeCFmluZnAtc2hpYi0wMS51dGhj\ndC5lZHWGLWh0dHBzOi8vaW5mcC1zaGliLTAxLnV0aGN0LmVkdS9pZHAvc2hpYmJv\nbGV0aDAdBgNVHQ4EFgQU7VtVhXMzkf2nd29ca6BBH+sMG1AwDQYJKoZIhvcNAQEF\nBQADggEBAEzUrhm5VQuj3y2uEA9Y2vkOSfMkBU7BB7loLpF9EKtHpLS9aKp1lQgv\nzQSXyDWBDGAry3h+RPCrVQAf+BTomagR4/nK6gd0Vche7iZWmYxmGJPUfHHsxa3I\n/HT6c7SkJCOeoF79ZVWoy8oV+2oMn8ZuAabw2+winVnT7/h1H/1DO4jkQDrltnG6\n8yGwEGriQZIKzvKRs/xxc0ERuzVxf+Hz1qy5NJO6QEg/upCFgq8QByU+VEBRKEJ2\ntjvTYXIPtDwkjXDvnGNiDGXwEEhieOBfGdW8gNJoaFG1JIn4gS4yT+9vs88ujUbs\njOT4n2SYHIFJfAfYw8JnSJ7PWVKQ4F4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "http://www.uthealth.org/about-us/contact-us/"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Texas Health Science Center At Tyler"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uthct.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Texas Health Science Center At Tyler"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.student.ladok.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.student.ladok.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.student.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.student.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.student.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.student.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.student.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.student.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.student.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.student.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.student.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.student.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.student.ladok.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.student.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIJAOCnVBGvbu36MA0GCSqGSIb3DQEBCwUAMB8xHTAbBgNV\nBAMTFHd3dy5zdHVkZW50LmxhZG9rLnNlMB4XDTE2MDQyNTExMjczMloXDTI2MDQy\nMzExMjczMlowHzEdMBsGA1UEAxMUd3d3LnN0dWRlbnQubGFkb2suc2UwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDHGKGOBwvvrybht4ptf12h7SjSW4WQ\nV7FdfyLJxAtoVH++3XgnsS88BhYNaOWYysUL2q+YH5qdq8ZfOrw0//VaHz2LEqqW\nLloG1sADvw1GyN+YZLmTOayhxpMp2MHxxM9tynhoyYeFF3GEvME9zJxkcmBN0oe0\nP+QLicuYnJNU8wDzpiV+k70DZttRTDp7z+ewVMaOPcrhkItiEzdDD0NE5YGo1kIg\nn8ZC7SdhWcIvgM/POeWM74VPmsTlN3Muf7+7T80EzhfbexANf4srflZLN7VS+Os4\nJWsbTh8qycOFu0M4llmOBgdC2BYKDoNXZGDCYE5ImWkjcn2pBMlsvp5HAgMBAAGj\nZzBlMEQGA1UdEQQ9MDuCFHd3dy5zdHVkZW50LmxhZG9rLnNlhiNodHRwczovL3d3\ndy5zdHVkZW50LmxhZG9rLnNlL2d1aS1zcDAdBgNVHQ4EFgQUxMCnw4eJUufZfek3\nvLBmzfWrcw0wDQYJKoZIhvcNAQELBQADggEBADl0sb5+Ct83vuwR8m6DtxAy+QfG\nVJQsSHVzQw6n9XeWx5pREWNEDMUcZZ4/On+bi7KdY2WpDqgNJSTlSKKZ5b4vbQ4P\n0v0hyeHIvHYW+3QnQPta+oMf0lCi2+GTupVihw9NvwZgK0PjhXyG3ci5aWBWjd3a\nQvnJKt3hDgOf4Fvtih8OXhl89hyb6VsXA5v2wZk9M4QOoIraNOxnNH0ntqa/dSjU\nixZQm1zM5PRAweCt9rLUgTrAwbfSykzaeHiRm5j4zJn/3frVs/b2ZyBNvVkujS1H\nxz4HZx54okaK76e3jPW6Hw8lPm8WEg05QDIkgjEKpQCY9hDXukP8NnV685Q="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.student.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.student.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.student.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.student.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.student.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.student.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.student.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.student.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.student.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.student.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://naming.ja.net/bcp-dns/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:corporate.servicedesk@ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Janet Corporate Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:corporate.servicedesk@ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Janet Corporate Service Desk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://naming.ja.net/bcp-dns/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-04-11T14:10:32Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Janet Naming Service (BCP)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ja.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "JISC Collections and Janet Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bcp-naming.ja.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bcp-naming.ja.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://bcp-naming.ja.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bcp-naming.ja.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bcp-naming.ja.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://bcp-naming.ja.net/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://bcp-naming.ja.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://bcp-domainregistry.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://bcp-naming.ja.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://bcp-domainregistry.jisc.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4jCCAcqgAwIBAgIJAKvL1FR4I0BGMA0GCSqGSIb3DQEBBQUAMBQxEjAQBgNV\n\t\t\t\t\t\tBAMTCWJjcDAwNDI3OTAeFw0xMTEyMDcxMjE3MzBaFw0yMTEyMDQxMjE3MzBaMBQx\n\t\t\t\t\t\tEjAQBgNVBAMTCWJjcDAwNDI3OTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAON8mrdgSPpMs4dHJC6hBIE10lGEzsoS35vckVgFUoyhMfHZEJu2t9SVTC0T\n\t\t\t\t\t\tGUGYIyArxQt0KSK1qHHGw+2l99xPLEH2rMAiR4JCyeer9EvQrN/mn+aERKMNX8Dd\n\t\t\t\t\t\tmXIoM/8rqIvqA3ftE/c3H/+C3hKvTRbN7wpG9Vam/olfkujCljqd9Ve4y+uokGry\n\t\t\t\t\t\t6rqi+5IKcb/FM8ARfZ1uFWOzUj1+THWEJgC2w8dkquMUUlYNylOvdBrY6PTeTGmh\n\t\t\t\t\t\tEItXPsq/P1fx2hn23vahUDelahUDgE7vQY0h4DlF2iRJSV6+zfVw51cgxUZ67xko\n\t\t\t\t\t\tjDYNPpKD1QA4x9NsIwZ7sTpVPqUCAwEAAaM3MDUwFAYDVR0RBA0wC4IJYmNwMDA0\n\t\t\t\t\t\tMjc5MB0GA1UdDgQWBBRasuhXna2QNf3yqFpBP2RC5kpfTDANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEA4Lepl7qoBfXJZ7t4zmd5ihlIuGEiFIlXBKiAtQYiPmK0ADxYHn87f1qq\n\t\t\t\t\t\t5i1/Hmx9jLXSmtts1uCzotkRtvYrrJRMWfUKiyPbfhRjy7rvx57VVe568QYpRKia\n\t\t\t\t\t\txk86+ZRKnckWG/jo5EFFhGrjBEh+Puw+9a/RqHf7C371HF0QmQA7isNGE0n9o28p\n\t\t\t\t\t\tPvz4RA25T97WH7AHcdNy5uokObzKg8lI3FqM8YFDWk6RPyq5lZzhftcNfU148nyH\n\t\t\t\t\t\tgvNqP58O7WCznLitHB+FV1vK1NNKTN5uCD1Uohm/vE3kGTb009KkzLMSnmArOiM8\n\t\t\t\t\t\t61C72Um8LiBt1IJwhXSvB7eOST78dw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bcp-naming.ja.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bcp-naming.ja.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://bcp-naming.ja.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://bcp-naming.ja.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://bcp-domainregistry.jisc.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://bcp-domainregistry.jisc.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bcp-domainregistry.jisc.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://bcp-domainregistry.jisc.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bcp-domainregistry.jisc.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://bcp-domainregistry.jisc.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://bcp-naming.ja.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://bcp-naming.ja.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://bcp-naming.ja.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://bcp-naming.ja.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://bcp-naming.ja.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://bcp-naming.ja.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:cru.fr:federation:univ-poitiers.fr",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Duthilleul Benjamin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "benjamin.duthilleul@univ-poitiers.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lionel Lombardi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lionel.lombardi@univ-poitiers.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:cru.fr:federation:univ-poitiers.fr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-05-18T10:46:20Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.univ-poitiers.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.univ-poitiers.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.univ-poitiers.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "etu.univ-poitiers.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-poitiers.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-poitiers.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Poitiers"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Poitiers"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEsDCCA5igAwIBAgIQUMcwKhTYAJRU4aUw5HaMrDANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMjAeFw0xNDEwMjEwMDAwMDBaFw0xNzEwMjAyMzU5NTlaMEkxITAfBgNVBAsT\nGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEkMCIGA1UEAxMbc2hpYmJvbGV0aC51\nbml2LXBvaXRpZXJzLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n1RVveanaMybAIRz/nZF/4XqBKU2rMLEbis9diusj/44VXzaRlXcjyfaoZa+SK8bI\nJQVsT/yGXI/WWaqhHXXaB0chqkrYfHZPdoYweFwTjynD1hJUhxamlGSBD30u0BPD\n7jTPKZxYvjwLJqppV9oZsCMSfWTznFotfBtmxIWMlF6bpR5c1foca0IL620MUzLC\nDBz4f0UyiWOL3kOkd4b8OauXR/YwfJiVckJjkk0F5WffPRDnDNj3/pLd+PFbhShS\nqT8gRkx7pF/XlJwTrXZMnQpcSNbY9XF6tkhaaLoA18XC7iWgsOhIjzJbDYuaFRQd\nXGlzCbWkM+dqX+vKPWgy8wIDAQABo4IBdzCCAXMwHwYDVR0jBBgwFoAUW9CKHJoy\nW+C13ZZUG+GGKLD9tr0wHQYDVR0OBBYEFGvidQi286gq4y5V1p4rm72/NncwMA4G\nA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMB\nBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6\nBgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnVzZXJ0cnVzdC5jb20vVEVSRU5B\nU1NMQ0EyLmNybDBsBggrBgEFBQcBAQRgMF4wNQYIKwYBBQUHMAKGKWh0dHA6Ly9j\ncnQudXNlcnRydXN0LmNvbS9URVJFTkFTU0xDQTIuY3J0MCUGCCsGAQUFBzABhhlo\ndHRwOi8vb2NzcC51c2VydHJ1c3QuY29tMCYGA1UdEQQfMB2CG3NoaWJib2xldGgu\ndW5pdi1wb2l0aWVycy5mcjANBgkqhkiG9w0BAQsFAAOCAQEAP4KsWoHSMRjZYLyu\nBuoF2RGmBsH02+QB9og6g6FBGEzSoFlKTonSOzSINKVI8hLSAG/AH0qEoscIRHkU\ntg1DWMbvz5m6vH3jBX35hjY9W2R2ajE0UBRXAjJG7duQ0t5qb5OlOO8OUcsVp8hq\nfZ321PY8oouA8yDBPL+G1k/Qf5rPZKfTG2l9CTjW3biiKHY8jyJBQIT8UQTFKX2j\nWxJcX4OyP3Ryyoc1e+ElHZdGRjKKpDd24hKUHiBtwaiio4jXRSzVw7dUUblKCMVN\n27h8pxrE4bUEWHkfxXKfWihDx6GPfk+exNY0mhn1Eunh288jAyt96C7uq2rXL9wg\nYjdn9A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEhTCCA22gAwIBAgIQBJ1RI0pR2rrSRRLdVKx5rTANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTExMTAyMDAwMDAwMFoXDTE0MTAxOTIzNTk1OVowVTELMAkGA1UE\nBhMCRlIxIDAeBgNVBAoMF1VuaXZlcnNpdMOpIGRlIFBvaXRpZXJzMSQwIgYDVQQD\nExtzaGliYm9sZXRoLnVuaXYtcG9pdGllcnMuZnIwggEiMA0GCSqGSIb3DQEBAQUA\nA4IBDwAwggEKAoIBAQC1XxY06+ZPTDJka2NP1PlhuHEcWC/21H1BsZGGrxbrHlbz\ns4sYedSqLpR3Zt9wsPrkXGnyIenQNG1v5u3UjTSal94cWpkuRJGXHxBzIqFlrgdP\nfFYHn97O4efhzE/vI5tCmX8goWN/o6dTYqCXI2p0zBg/QVmkSWsNbCxj/jx/V2eZ\n70lMqt5HdJKrAEEBx6Tfn1Ru4+8Bq4YovcSMDf72PBvasCxoQVrmeJ9sJhLopv2r\n4+Rp1PTyuHTd1byJCi5/0ljpT83UrTmhJUMwWJxWMA9YMLmOBhIeB6k4/azxdrne\nDnu9ahLuM9jhzJazuPebmc74IMe17vzclelyx8+7AgMBAAGjggFuMIIBajAfBgNV\nHSMEGDAWgBQMvZNoDPPeq6NJays3V0fqkOO57TAdBgNVHQ4EFgQUj3qD3F4yQ3cR\nudqfsQda8hqTZ/8wDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0l\nBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMBgGA1UdIAQRMA8wDQYLKwYBBAGyMQEC\nAh0wOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9U\nRVJFTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRw\nOi8vY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcw\nAYYaaHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwJgYDVR0RBB8wHYIbc2hpYmJv\nbGV0aC51bml2LXBvaXRpZXJzLmZyMA0GCSqGSIb3DQEBBQUAA4IBAQB35DdMvMd/\nG/GOPo1URiKh4LWbGQ1P6AcYNwuhCMr4DZaiQX00sezEizuAjnFjnc/wax3zaESS\nIvpJEuuAM7rIrwLGm9zcKPhbceus9OiMffWENEB0sKT0fAZBsfuO4Q8akk2EfoUp\nsYq3kH65TYG4BLtYzVdY0MkE/fUxNT97YLoVwFgIglQPhvamLi1xFnEc5H/1mLHQ\nHg1wq8LaDsoAUv1hG6Oalvl56Sa3y9FIhueUv0Z+kNvvTyK9hHtC1iDRyoLANajH\nag7GwpQkZHUpuTGM1wrdwNJAN7lcXenuuAivqj6wxk11YMxw/38jH2rKtpXyxdnv\n1eZuFfizJq0c"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Poitiers"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-poitiers.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Poitiers"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://hau.idm.oclc.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support-uk@oclc.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OCLC UK Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://hau.idm.oclc.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-06-20T14:51:18Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Harper Adams University Hosted EZProxy"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oclc.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "OCLC (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEAjCCAuqgAwIBAgIBAjANBgkqhkiG9w0BAQUFADBjMRswGQYDVQQDFBIqLmhh\n\t\t\t\t\t\tdS5pZG0ub2NsYy5vcmcxCzAJBgNVBAYTAlVLMQ0wCwYDVQQKEwRPQ0xDMSgwJgYJ\n\t\t\t\t\t\tKoZIhvcNAQkBFhlqYW1lcy5odXRjaGluc29uQG9jbGMub3JnMB4XDTEzMDYxOTEz\n\t\t\t\t\t\tNDI0OVoXDTIzMDYxOTEzNDI0OVowYzEbMBkGA1UEAxQSKi5oYXUuaWRtLm9jbGMu\n\t\t\t\t\t\tb3JnMQswCQYDVQQGEwJVSzENMAsGA1UEChMET0NMQzEoMCYGCSqGSIb3DQEJARYZ\n\t\t\t\t\t\tamFtZXMuaHV0Y2hpbnNvbkBvY2xjLm9yZzCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBAL+VJNJG4tqZr20wvtzRlanUsfO1ABtqgQlFBYcD4DHqxHa/uCi9\n\t\t\t\t\t\trXpelbL/JA0VbfCImusX41lvY+lQmCit2KX1+3UxDcP7HEhifQS2GQeu4Mddfyyt\n\t\t\t\t\t\tVIzWGB0Nf5rBATk8lZoQ7zQyICP9/829pxkVAhBh0jUy5u8dYNfftK+IZ5nO6CpW\n\t\t\t\t\t\tTcySNz5jFUgYwIdwVFYUMaPqOLVeqe75LdHkrjdGcpKZGyfy1/sXVL/Ckq5sinhK\n\t\t\t\t\t\tVNVH1ECU49lkO64gLbg/6/ySjDjayFzFB8mPSAtWrlQgujYkfxIeqTTxZ25HJtGA\n\t\t\t\t\t\teLcdYVL9qAz7G7BtvJRY6eOnN06d1F+rLmkCAwEAAaOBwDCBvTAdBgNVHQ4EFgQU\n\t\t\t\t\t\teOxbtlcwwkedaRnaoihkJ55Bn9QwgY0GA1UdIwSBhTCBgoAUeOxbtlcwwkedaRna\n\t\t\t\t\t\toihkJ55Bn9ShZ6RlMGMxGzAZBgNVBAMUEiouaGF1LmlkbS5vY2xjLm9yZzELMAkG\n\t\t\t\t\t\tA1UEBhMCVUsxDTALBgNVBAoTBE9DTEMxKDAmBgkqhkiG9w0BCQEWGWphbWVzLmh1\n\t\t\t\t\t\tdGNoaW5zb25Ab2NsYy5vcmeCAQIwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAM+XxeKigNVAlRB9uju8MoJPMIyzGFl4//GuDmPwvPj28FHRziy2f38L2\n\t\t\t\t\t\tUOua3OfllHjzY+rTCpuiC5FLKWDR/x4Zk6JNEC5NWZFszBhv5QK+T2qoa7ZqLdfL\n\t\t\t\t\t\taUOa+zIXkG9oqJv8V+cjvikl3y03GVPIJaSnqZ8ZqvZHUD6LTL1i6jbDmQS56B8w\n\t\t\t\t\t\tY20Exlm2l53EUtht3XyuABZiPmhAEly26MlvzWz4y6FkvVWAFph9aKwa1m+W5ZgD\n\t\t\t\t\t\tKwXsAjQzn0TR9ccTAc0le+5wVW8BEqvJZOsF3ZJBB3G3zoss1E1y6bXkO5UOWRhz\n\t\t\t\t\t\tMWGYa0Oj1hdjm0Tf2O/qQdfY6+X6Fw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://login.hau.idm.oclc.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.hau.idm.oclc.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://login.hau.idm.oclc.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://courses.scholar.hw.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ithelp@hw.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Livie"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:G.Livie@hw.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "George"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://courses.scholar.hw.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-08-07T10:57:32Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Heriot-Watt University: The SCHOLAR Programme"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://scholar.hw.ac.uk/sco.html"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Heriot-Watt University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://courses.scholar.hw.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://courses.scholar.hw.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://courses.scholar.hw.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://courses.scholar.hw.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://courses.scholar.hw.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://courses.scholar.hw.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://courses.scholar.hw.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIJAM7EPA/nD/eEMA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGGNvdXJzZXMuc2Nob2xhci5ody5hYy51azAeFw0xNTA5MDcxMTE2MjdaFw0z\n\t\t\t\t\t\tNTA5MDIxMTE2MjdaMCMxITAfBgNVBAMTGGNvdXJzZXMuc2Nob2xhci5ody5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMzKoqbL/fZaIQy3HsYJ\n\t\t\t\t\t\tuDgCLtU1PgyGzrCHEzuV7sH7nAW4I/dou7gkj+u/caP7tUhEalCb3fTBRY8/3DXU\n\t\t\t\t\t\t5I9WhKnp7+LxFMHDw4cO9HyOvwJdRujslQ+7GrL4uIepK3k9Fmx9CmfB6yFKHIfW\n\t\t\t\t\t\tuT609R56h5Mkx33g00zl0d8S924vSekJffZZDHjhArL0Zl9Qom2XNvAzq8+OHdk2\n\t\t\t\t\t\tjoeCO4Bmhm2EJBnTdKm9BM20dlUNaChkGSPkpjQo0GubaZIzGjHUsjmb5piM7kgW\n\t\t\t\t\t\tukVXY8qeXLbnvtWMWUU0aXziuuMhjevvG0P/9dH6SW1SiLpd3K7RX/EbmoXFKnqb\n\t\t\t\t\t\tdNcCAwEAAaNzMHEwUAYDVR0RBEkwR4IYY291cnNlcy5zY2hvbGFyLmh3LmFjLnVr\n\t\t\t\t\t\thitodHRwczovL2NvdXJzZXMuc2Nob2xhci5ody5hYy51ay9zaGliYm9sZXRoMB0G\n\t\t\t\t\t\tA1UdDgQWBBQqdJBNFjutcZ9JhQuzIMXajOpKTTANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\toffYX9o1jOUAjLqipA3H33r+eC5fGRmXpxQTHT9TCidb86Gx6A3JslV9dzVAyDdq\n\t\t\t\t\t\tC8VHtyW++a8+Pc+F/oGAK6EW1XQjGw29VDkYR+ZYxCtiPwxxnhcxftQVqu2vyFyP\n\t\t\t\t\t\t36UIi/e9U7OWUBQGF/cCtfNLd0PtsTXUo1cXNqED3vN0AdV8DZALXOewkZSZHdrx\n\t\t\t\t\t\tCmm47hMBm8VoE8NuQXd/fnWAdb99DFtuNygxdQ4tpK+vdqg5WnPiW894lKQtjQUg\n\t\t\t\t\t\t/ywRrMA3eJPKtYdxaIdIcW8TisYCILOXF5mgkQpssytSAN4H34jtO7nlfepcJI4d\n\t\t\t\t\t\t7H4HdRHL1gb7AIARX4zWKA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://courses.scholar.hw.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://courses.scholar.hw.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://courses.scholar.hw.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://courses.scholar.hw.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://courses.scholar.hw.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://courses.scholar.hw.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibidp.unipr.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Panella"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@unipr.it"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marco"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibidp.unipr.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2009-12-31T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVANMt6NQyQVgOzMWv6tQmeV5iMyCNMA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEHNoaWJpZHAudW5pcHIuaXQwHhcNMDkwOTAyMDgwMjMz\nWhcNMjkwOTAyMDgwMjMzWjAbMRkwFwYDVQQDExBzaGliaWRwLnVuaXByLml0MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2vzK0+t0DPv0CugzVEeroctE\nN4VdJggVTqeQVexIM4sFW7q3kVQvmA8kgVMmcZ9RHYyZac6Uw3Dj0ooO+DjYsJBg\nYRB4eN13gCpeWZQ1gcbbgV9FhLZGs9r+SRPtWgOjPb1Sns88XFBftjy9fZ7RJqQo\nvbvklEOHgWhhuz4xy6YMOItT01Z+amabYrh6pDG0007vPZjhT10LqcEExwvZjo6I\n5xd5s0w8z84EtDry2FhSaWs5AX3sQZYIiPONp/11uRZSvBBFKmCMDEIA32bGEcEO\nDQLUNKNPs/9AYdj+JFhehtILdVFVmHj3U76P9z6x7Brhrr6bMZ+wdvj+t+kabQID\nAQABo2cwZTBEBgNVHREEPTA7ghBzaGliaWRwLnVuaXByLml0hidodHRwczovL3No\naWJpZHAudW5pcHIuaXQvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFMlXoLjlhaJD\nmLtp1r0Upn1PYpYlMA0GCSqGSIb3DQEBBQUAA4IBAQCzfKVH8RL3qOrpo6ZAh/AV\n2vYGkeV1RlSc1yc07K/hKG3HKkBim5HvGxeT5jMRNLlXZRkWEnrzmfCoyeyTgbis\n4YWyqKT4VKLCqsOGBdn00mbRUVDhQSH2MSTEy6Iqa+3SDeQ8iyolKinYnBu0LDg7\naU+b3F6vQHeLEdJvX1V6c/z7gV3YdNEA3Z9dCQavw47LLDB5QlCKtWuKklpBrQao\nddU75GdAb8W4csgACMgqBSU30w/yJ79q8O9ajffJta01wOXXJhvtlGtNnV42ACg4\nPqwh2EyQjPtYYja8SrAmwgp4k705jtn+QNLUs1VD6hw9LmoRFpxn1zb21fL3rZAs"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unipr.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.unipr.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.unipr.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.unipr.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.unipr.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibidp.unipr.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.unipr.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.unipr.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.unipr.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unipr.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unipr.it/idem"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://en.unipr.it/idem"
                  }
                ],
                "description": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti dell'Universit\u00e0 degli Studi di Parma"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for users of University of di Parma"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.unipr.it/ateneo/albo-online/privacy"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://en.unipr.it/privacy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 degli Studi di Parma"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Parma"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:44.76630697035048,10.314061939716339"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVANMt6NQyQVgOzMWv6tQmeV5iMyCNMA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEHNoaWJpZHAudW5pcHIuaXQwHhcNMDkwOTAyMDgwMjMz\nWhcNMjkwOTAyMDgwMjMzWjAbMRkwFwYDVQQDExBzaGliaWRwLnVuaXByLml0MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2vzK0+t0DPv0CugzVEeroctE\nN4VdJggVTqeQVexIM4sFW7q3kVQvmA8kgVMmcZ9RHYyZac6Uw3Dj0ooO+DjYsJBg\nYRB4eN13gCpeWZQ1gcbbgV9FhLZGs9r+SRPtWgOjPb1Sns88XFBftjy9fZ7RJqQo\nvbvklEOHgWhhuz4xy6YMOItT01Z+amabYrh6pDG0007vPZjhT10LqcEExwvZjo6I\n5xd5s0w8z84EtDry2FhSaWs5AX3sQZYIiPONp/11uRZSvBBFKmCMDEIA32bGEcEO\nDQLUNKNPs/9AYdj+JFhehtILdVFVmHj3U76P9z6x7Brhrr6bMZ+wdvj+t+kabQID\nAQABo2cwZTBEBgNVHREEPTA7ghBzaGliaWRwLnVuaXByLml0hidodHRwczovL3No\naWJpZHAudW5pcHIuaXQvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFMlXoLjlhaJD\nmLtp1r0Upn1PYpYlMA0GCSqGSIb3DQEBBQUAA4IBAQCzfKVH8RL3qOrpo6ZAh/AV\n2vYGkeV1RlSc1yc07K/hKG3HKkBim5HvGxeT5jMRNLlXZRkWEnrzmfCoyeyTgbis\n4YWyqKT4VKLCqsOGBdn00mbRUVDhQSH2MSTEy6Iqa+3SDeQ8iyolKinYnBu0LDg7\naU+b3F6vQHeLEdJvX1V6c/z7gV3YdNEA3Z9dCQavw47LLDB5QlCKtWuKklpBrQao\nddU75GdAb8W4csgACMgqBSU30w/yJ79q8O9ajffJta01wOXXJhvtlGtNnV42ACg4\nPqwh2EyQjPtYYja8SrAmwgp4k705jtn+QNLUs1VD6hw9LmoRFpxn1zb21fL3rZAs"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 di Parma"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Parma"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unipr.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://en.unipr.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli Studi di Parma"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Parma"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.csuchico.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dfuhs@csuchico.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David Fuhs"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dfuhs@csuchico.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David Fuhs"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lamiller@csuchico.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andy Miller"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.csuchico.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.csuchico.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.csuchico.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAIEEdq+4nDzx9lzoLHgf0Lhl3d8BMA0GCSqGSIb3DQEB\nBQUAMCIxIDAeBgNVBAMTF3NoaWJib2xldGguY3N1Y2hpY28uZWR1MB4XDTE0MDQx\nODE2MzY1M1oXDTM0MDQxODE2MzY1M1owIjEgMB4GA1UEAxMXc2hpYmJvbGV0aC5j\nc3VjaGljby5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC3/5KV\nRgaUyoR2AZ+mVvR2V4Dw1bjeD42RRWupVlEu6u1HajYNeK77ZV18vZo6J0Hxx7yJ\nHfogEo1cpD7rnDwMwm4lnwSqnsobp8dyOQXX57n0qseciEMxV6t9YyFTFSnA2qBb\n1KmCS5omeV2YEbviTUW+6S9Af63bH2qomPID7Vt7Waw6FFIQVHWrqOQtrThDQPSy\n2sG1WFt4Z3yhhWjMZLGCJdNaBJK6dK9iibTsTJU2H0GKs4NX7RmUXYGtNloGjDU7\nAttNrff44h5+Vc+Qs76XELsVUji9LUvBu0a9sdMMhqyUVaiDt59e7eZgQ0LWWOuq\nRH364SCmr7AvPn2JAgMBAAGjdTBzMFIGA1UdEQRLMEmCF3NoaWJib2xldGguY3N1\nY2hpY28uZWR1hi5odHRwczovL3NoaWJib2xldGguY3N1Y2hpY28uZWR1L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBSjK/qfcx+jwvdDasx4M2PX+ieL0jANBgkqhkiG\n9w0BAQUFAAOCAQEARTR+CWxWOP7VdCYo/YgCXi0Bk7voOVcyAgrrp/DWYVp7aY4s\nsx1JEAIKFJI2ImBqHLuAZFztJoxN/GGvbVNM4QG0288EJOkO5I/UwgQyzczW5TRD\nhjHmSYru01r9ax/hTqK0Xirc3NOquAz5FOSFfg2dmFKjp/nzJbcLAlnuAlkmUjrM\nelF6prjEAvRxdRHg3O1TQoo6xdxR/Iod+wPTgmg9G0gKQPL/4++eiUvotCMMraUR\nC4mfTA0pqKLnIIqgfW7AathlVBdQnDhubTVT1OEp7E7TgG4U6uzsx4qvEkA66C4l\nhERQRKfoE96zHmakc8SmiMASUbUzxjbMYVyJ3g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIJANla2HUGoCmtMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF3NoaWJib2xldGguY3N1Y2hpY28uZWR1MB4XDTExMDQxMzE3MzIyMloXDTIx\nMDQxMDE3MzIyMlowIjEgMB4GA1UEAxMXc2hpYmJvbGV0aC5jc3VjaGljby5lZHUw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDuAtVw7i6Z4VPL2459YGeS\nTqzHz8durVObETdARko4QGWgnDaGIOJrmPlTJkdP4IZEm53BxIZxhWGutnwrTCrF\nyOJO+brKJtfbMD5JT7ib5EVNQzn3cJ819EBJm2tklJ2OS4WFrhhvkpUOoKHrsJQf\n63/jZbFdw7vcmbpUIH5WDPKVyC/w87+Oqcf7ZUkYPlhWZLAo3WzNwCJI+HwdZHDF\nSo+66qwu2v8HiH9uKLqVGVU3luF8ySY/lnMfeYdkfpMsnxnyqaeODzcopgNgm34s\n/fYkvrU7TGQdDW5FYX4RddrwnWi4/7PODyPtzhLPfXh75Li3RTS/RbVbuyJ1OZ9R\nAgMBAAGjgYQwgYEwHQYDVR0OBBYEFG9E0fMYVCbrIVX2fb5gpFD731apMFIGA1Ud\nIwRLMEmAFG9E0fMYVCbrIVX2fb5gpFD731apoSakJDAiMSAwHgYDVQQDExdzaGli\nYm9sZXRoLmNzdWNoaWNvLmVkdYIJANla2HUGoCmtMAwGA1UdEwQFMAMBAf8wDQYJ\nKoZIhvcNAQEFBQADggEBAJeeNHArje/LUYrXVXD2BsXfL6c701vaatOMY67HoOyu\nC+7SlU0zHTo4f2VBPlzvEjeG4LvHJHI8k2g5/EperiaS11JOErz9C2fACua9VfxI\nkzQjkC5NVimeBy8Q86wWivt+1J5+6Nd/CTx0Bac7/CjTghsNy0AUWC4dR8vHa+Fv\nIfvBrCjTxarHxA+2wGD0CLrYXcFj7yo3NjQClmhkMTxquTSq6LBgeRuJyNcUnA8L\n/TudO9r//xU7h/rrRz+WhUH7KCNk/fkZDNiriqfj90yExFeDILr5g0G9swLYZoqU\nOkvoU7bZUozGMD6b/VOon3gG54/d9WM2+vQ+hP282rM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csuchico.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.csuchico.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.csuchico.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.csuchico.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.csuchico.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.csuchico.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.csuchico.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csuchico.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.csuchico.edu/isec/incommonpop.shtml"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "California State University, Chico"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Provides authentication and authorization functions for federated applications used by faculty, staff, and students at California State University, Chico."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.csuchico.edu/weblogos/logos/seal154r.gif",
                    "lang": "en",
                    "height": "154",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "154"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.csuchico.edu/isec/incommonpop.shtml"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAIEEdq+4nDzx9lzoLHgf0Lhl3d8BMA0GCSqGSIb3DQEB\nBQUAMCIxIDAeBgNVBAMTF3NoaWJib2xldGguY3N1Y2hpY28uZWR1MB4XDTE0MDQx\nODE2MzY1M1oXDTM0MDQxODE2MzY1M1owIjEgMB4GA1UEAxMXc2hpYmJvbGV0aC5j\nc3VjaGljby5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC3/5KV\nRgaUyoR2AZ+mVvR2V4Dw1bjeD42RRWupVlEu6u1HajYNeK77ZV18vZo6J0Hxx7yJ\nHfogEo1cpD7rnDwMwm4lnwSqnsobp8dyOQXX57n0qseciEMxV6t9YyFTFSnA2qBb\n1KmCS5omeV2YEbviTUW+6S9Af63bH2qomPID7Vt7Waw6FFIQVHWrqOQtrThDQPSy\n2sG1WFt4Z3yhhWjMZLGCJdNaBJK6dK9iibTsTJU2H0GKs4NX7RmUXYGtNloGjDU7\nAttNrff44h5+Vc+Qs76XELsVUji9LUvBu0a9sdMMhqyUVaiDt59e7eZgQ0LWWOuq\nRH364SCmr7AvPn2JAgMBAAGjdTBzMFIGA1UdEQRLMEmCF3NoaWJib2xldGguY3N1\nY2hpY28uZWR1hi5odHRwczovL3NoaWJib2xldGguY3N1Y2hpY28uZWR1L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBSjK/qfcx+jwvdDasx4M2PX+ieL0jANBgkqhkiG\n9w0BAQUFAAOCAQEARTR+CWxWOP7VdCYo/YgCXi0Bk7voOVcyAgrrp/DWYVp7aY4s\nsx1JEAIKFJI2ImBqHLuAZFztJoxN/GGvbVNM4QG0288EJOkO5I/UwgQyzczW5TRD\nhjHmSYru01r9ax/hTqK0Xirc3NOquAz5FOSFfg2dmFKjp/nzJbcLAlnuAlkmUjrM\nelF6prjEAvRxdRHg3O1TQoo6xdxR/Iod+wPTgmg9G0gKQPL/4++eiUvotCMMraUR\nC4mfTA0pqKLnIIqgfW7AathlVBdQnDhubTVT1OEp7E7TgG4U6uzsx4qvEkA66C4l\nhERQRKfoE96zHmakc8SmiMASUbUzxjbMYVyJ3g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIJANla2HUGoCmtMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF3NoaWJib2xldGguY3N1Y2hpY28uZWR1MB4XDTExMDQxMzE3MzIyMloXDTIx\nMDQxMDE3MzIyMlowIjEgMB4GA1UEAxMXc2hpYmJvbGV0aC5jc3VjaGljby5lZHUw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDuAtVw7i6Z4VPL2459YGeS\nTqzHz8durVObETdARko4QGWgnDaGIOJrmPlTJkdP4IZEm53BxIZxhWGutnwrTCrF\nyOJO+brKJtfbMD5JT7ib5EVNQzn3cJ819EBJm2tklJ2OS4WFrhhvkpUOoKHrsJQf\n63/jZbFdw7vcmbpUIH5WDPKVyC/w87+Oqcf7ZUkYPlhWZLAo3WzNwCJI+HwdZHDF\nSo+66qwu2v8HiH9uKLqVGVU3luF8ySY/lnMfeYdkfpMsnxnyqaeODzcopgNgm34s\n/fYkvrU7TGQdDW5FYX4RddrwnWi4/7PODyPtzhLPfXh75Li3RTS/RbVbuyJ1OZ9R\nAgMBAAGjgYQwgYEwHQYDVR0OBBYEFG9E0fMYVCbrIVX2fb5gpFD731apMFIGA1Ud\nIwRLMEmAFG9E0fMYVCbrIVX2fb5gpFD731apoSakJDAiMSAwHgYDVQQDExdzaGli\nYm9sZXRoLmNzdWNoaWNvLmVkdYIJANla2HUGoCmtMAwGA1UdEwQFMAMBAf8wDQYJ\nKoZIhvcNAQEFBQADggEBAJeeNHArje/LUYrXVXD2BsXfL6c701vaatOMY67HoOyu\nC+7SlU0zHTo4f2VBPlzvEjeG4LvHJHI8k2g5/EperiaS11JOErz9C2fACua9VfxI\nkzQjkC5NVimeBy8Q86wWivt+1J5+6Nd/CTx0Bac7/CjTghsNy0AUWC4dR8vHa+Fv\nIfvBrCjTxarHxA+2wGD0CLrYXcFj7yo3NjQClmhkMTxquTSq6LBgeRuJyNcUnA8L\n/TudO9r//xU7h/rrRz+WhUH7KCNk/fkZDNiriqfj90yExFeDILr5g0G9swLYZoqU\nOkvoU7bZUozGMD6b/VOon3gG54/d9WM2+vQ+hP282rM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California State University, Chico"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csuchico.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California State University, Chico"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.fzu.cas.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Van\u00ed\u010dek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vanicekp@utia.cas.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.fzu.cas.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2014-03-18T10:07:35Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/avcr"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAMXPvsGlLRsX7hPpMRUVsTPL9MPjMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC5menUuY2FzLmN6MB4XDTE0MDMxMjExMDc0NloX\nDTM0MDMxMjExMDc0NlowGTEXMBUGA1UEAxMOaWRwLmZ6dS5jYXMuY3owggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCmAUy5v5OguNKkfufBQPmszJ3GgMqf\ntFaLshqlu0D4IPwaHk76cXqMzp0l/tUMuhKyXxaQ1X/3cVPDJKkxqNCjE7etqnj1\nfz1FnRP/rJGpbacmAT2T3IqHKZpatJV6kbWxOOytOdJk4Uadmap4mAyHLISYyhpD\nsgWxcioFCsbtTPmM8GVKfj1IlnGYD19nKm7D9ocF5gCy9dbQZ/QyvOAd+jMDHGJ+\nn59nJD+GjwpdoDOB7agHhn7806Ui98lo8XK1SeSo47FFCMhwgeB59KjUzlySEEDv\nZn8/HM3nJWQ54/ty/qknoWDnh2cNGLS2EdWCu9FNNGcfdJGg41ipvD0DAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC5menUuY2FzLmN6hiVodHRwczovL2lkcC5menUu\nY2FzLmN6L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQfOSvunhqNoO2v13uWFsFu\nqYqDUzANBgkqhkiG9w0BAQUFAAOCAQEAjTGlMBUwRmH8nt9WDJSKaZU6rRcqY9Yi\nh+GrzpduiAz8WQcMD6ijUcOZuBRNpXZ5vOWPNtIWCoG8W7xxqRBVwROsczGaBQbf\nlo5uEzDGMVBh9tkqhwnXev1YbGai/K/frBQP5Ck1z9OAWwrGvlZnc1OM54ChKFYs\nTvwRI12g6UcV7OCIOc6Iq3xXMtP6H2A71KexofWNosrwMi7GMErnL3p8vc58akrs\nNE5wyp2MfieNYDfUsQsIUqAzYmrXHxfOJF7nPK1j8bcTZWCTcc0K3GAlL3MppJSn\nZBbnqng3wtUIk0MVMjUGkG8j5FViFkmAI5Nxa6KUAtrrOu/LFh3nIg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fzu.cas.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.fzu.cas.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.fzu.cas.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.fzu.cas.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.fzu.cas.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.fzu.cas.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.fzu.cas.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.fzu.cas.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.fzu.cas.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.fzu.cas.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.fzu.cas.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.fzu.cas.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "fzu.cas.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.fzu.cz/en"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.fzu.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider FZU AV CR employees."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance FZ\u00da AV \u010cR"
                  }
                ],
                "logo": [
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-fzu-40.png",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "40"
                  },
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-fzu-100.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Physics AS CR"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Fyzik\u00e1ln\u00ed \u00fastav Akademie v\u011bd \u010cR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAMXPvsGlLRsX7hPpMRUVsTPL9MPjMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC5menUuY2FzLmN6MB4XDTE0MDMxMjExMDc0NloX\nDTM0MDMxMjExMDc0NlowGTEXMBUGA1UEAxMOaWRwLmZ6dS5jYXMuY3owggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCmAUy5v5OguNKkfufBQPmszJ3GgMqf\ntFaLshqlu0D4IPwaHk76cXqMzp0l/tUMuhKyXxaQ1X/3cVPDJKkxqNCjE7etqnj1\nfz1FnRP/rJGpbacmAT2T3IqHKZpatJV6kbWxOOytOdJk4Uadmap4mAyHLISYyhpD\nsgWxcioFCsbtTPmM8GVKfj1IlnGYD19nKm7D9ocF5gCy9dbQZ/QyvOAd+jMDHGJ+\nn59nJD+GjwpdoDOB7agHhn7806Ui98lo8XK1SeSo47FFCMhwgeB59KjUzlySEEDv\nZn8/HM3nJWQ54/ty/qknoWDnh2cNGLS2EdWCu9FNNGcfdJGg41ipvD0DAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC5menUuY2FzLmN6hiVodHRwczovL2lkcC5menUu\nY2FzLmN6L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQfOSvunhqNoO2v13uWFsFu\nqYqDUzANBgkqhkiG9w0BAQUFAAOCAQEAjTGlMBUwRmH8nt9WDJSKaZU6rRcqY9Yi\nh+GrzpduiAz8WQcMD6ijUcOZuBRNpXZ5vOWPNtIWCoG8W7xxqRBVwROsczGaBQbf\nlo5uEzDGMVBh9tkqhwnXev1YbGai/K/frBQP5Ck1z9OAWwrGvlZnc1OM54ChKFYs\nTvwRI12g6UcV7OCIOc6Iq3xXMtP6H2A71KexofWNosrwMi7GMErnL3p8vc58akrs\nNE5wyp2MfieNYDfUsQsIUqAzYmrXHxfOJF7nPK1j8bcTZWCTcc0K3GAlL3MppJSn\nZBbnqng3wtUIk0MVMjUGkG8j5FViFkmAI5Nxa6KUAtrrOu/LFh3nIg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Physics AS CR"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Fyzik\u00e1ln\u00ed \u00fastav Akademie v\u011bd \u010cR, v.v.i."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fzu.cz/en"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.fzu.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Physics AS CR"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Fyzik\u00e1ln\u00ed \u00fastav Akademie v\u011bd \u010cR, v.v.i."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib1.univ-nc.nc/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dsi-srs@univ-nc.nc"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib1.univ-nc.nc/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-04-07T06:55:06Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib1.univ-nc.nc/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib1.univ-nc.nc/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib1.univ-nc.nc/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-nc.nc"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-nc.nc"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Users from the University of New-Caledonia"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Les usagers de l'Universit\u00e9 de la Nouvelle-Cal\u00e9donie"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of New-Caledonia"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de la Nouvelle-Cal\u00e9donie"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKzCCAhOgAwIBAgIUKHSh1ylYLiRjTuGeUpFo+BFI/NswDQYJKoZIhvcNAQEF\nBQAwGzEZMBcGA1UEAwwQc2hpYjEudW5pdi1uYy5uYzAeFw0xNTA0MDcwMjU3NTda\nFw0zNTA0MDcwMjU3NTdaMBsxGTAXBgNVBAMMEHNoaWIxLnVuaXYtbmMubmMwggEi\nMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDIS9HXIQ3OAVzkUY67B8btSmU6\nhqpJDtN/uFlX6sx7ceaJUAGA647RutZE8iYNx7w3cxaR5HircULm4XUhwsGxAjGv\nkbHLNCyilXx3leF268cjaFE5q/OVVcn8ZhH1UPQ5sMHs9i93X9BnJfkJVjl0EZQB\nX+Q3N2ToI8bXIqSHvJOLZDKHfVYuzrMfJlxZMvtGdeLafST5gAiTpacZ3nSy5eH4\nMZT2kj8c0AzVE8gFRb0RdoJvOrsJvNCHo0mlVKhOF2K4tPc5tmUPyH0Qz9raXaJV\nCGTQiHDlQKm93b45gHgsiH5SnvJzjXgxjfiufRWLdODKigq2w5Wd8V5c5QZTAgMB\nAAGjZzBlMB0GA1UdDgQWBBTR9hQtChLxyxmf/sFiJ8l8mxvZNTBEBgNVHREEPTA7\nghBzaGliMS51bml2LW5jLm5jhidodHRwczovL3NoaWIxLnVuaXYtbmMubmMvaWRw\nL3NoaWJib2xldGgwDQYJKoZIhvcNAQEFBQADggEBALGrtfzm7UuiNtns7ZfJa79M\nFyaK2XzboYw4LbE21RQa8YrHfuLytZi3xYZE/1Z88n5MgEFuUnFqqqZ0/qwax7Wb\n6DHtiBtpVzD6bI/IYQHRBUZHEkfItEe6gOUX43ndaXum/qb1ojEqsSAttvyDSkIZ\ndZMZ4qfiTgpW69Qb1z6CGCouZC2ssxSc4YK6lDO9fKhnbE+9N0nFYrJNwONPy5Sv\n+XhkKPoxbZ2BMnwQZlbCzoJPt9mG1hcpxrjEDpu5MDl4Ma12ycSHOAjLedMvv2Xv\nIsXFZf9tlVP3B/KFbcFPpRJviR3uaiwWsahu7Zd0ojoS20riz5LOdWi8i281QUU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de la Nouvelle-Cal\u00e9donie"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-nc.nc"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de la Nouvelle-Cal\u00e9donie"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://smile.informatik.uni-freiburg.de/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sester"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:smile@informatik.uni-freiburg.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sebastian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Sester"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:smile@informatik.uni-freiburg.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sebastian"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Feiten"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:feiten@informatik.uni-freiburg.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Linus"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://smile.informatik.uni-freiburg.de/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2014-09-18T12:59:06Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Albert-Ludwigs-Universit\u00e4t Freiburg"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Albert-Ludwigs-Universit\u00e4t Freiburg"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-freiburg.de/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-freiburg.de/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e14"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e14"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://smile.informatik.uni-freiburg.de/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://smile.informatik.uni-freiburg.de/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://smile.informatik.uni-freiburg.de/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://smile.informatik.uni-freiburg.de/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.smile.informatik.uni-freiburg.de/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.smile.informatik.uni-freiburg.de/"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Die SMILE-App f\u00fcr Smartphones, Tablets und Internetbrowser erm\u00f6glicht Live-Feedback, Quiz-Fragen und Lernfragen w\u00e4hrend sehr gro\u00dfen Lehrveranstaltungen. Mit der Q&A-Funktion k\u00f6nnen Studierende Fragen genau dann stellen, wenn Sie auftreten - ohne den Vortragenden zu st\u00f6ren."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SMILE serves as a lecture-supporting system which students and lecturers can use with their usual login data given by their home institution. The system offers - among other functions - live feedback for the lecturer and quizzes for checking the learning process of the students."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://smile.informatik.uni-freiburg.de/CoC/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SMILE - Smartphones in der Lehre"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SMILE - Smartphones in der Lehre"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "smile.informatik.uni-freiburg.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIHxzCCBq+gAwIBAgIHGIKSSfQ6RTANBgkqhkiG9w0BAQsFADCBhjELMAkGA1UE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\nSA1QPBvLr4BMM0YEyE5oqagy03A8rmgvpFDJ"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=ira-web@informatik.uni-freiburg.de,CN=smile.informatik.uni-freiburg.de,OU=Institut fuer Informatik,O=Universitaet Freiburg,L=Freiburg,ST=Baden-Wuerttemberg,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "smile.informatik.uni-freiburg.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIHxzCCBq+gAwIBAgIHGIKSSfQ6RTANBgkqhkiG9w0BAQsFADCBhjELMAkGA1UE\nBhMCREUxHjAcBgNVBAoTFVVuaXZlcnNpdGFldCBGcmVpYnVyZzEWMBQGA1UECxMN\nUmVjaGVuemVudHJ1bTEYMBYGA1UEAxMPVW5pLUZSIENBIC0gRzAyMSUwIwYJKoZI\nhvcNAQkBFhZwa2lAcnoudW5pLWZyZWlidXJnLmRlMB4XDTE0MTExMjA4MDUxNFoX\nDTE5MDcwOTIzNTkwMFowgd4xCzAJBgNVBAYTAkRFMRswGQYDVQQIExJCYWRlbi1X\ndWVydHRlbWJlcmcxETAPBgNVBAcTCEZyZWlidXJnMR4wHAYDVQQKExVVbml2ZXJz\naXRhZXQgRnJlaWJ1cmcxITAfBgNVBAsTGEluc3RpdHV0IGZ1ZXIgSW5mb3JtYXRp\nazEpMCcGA1UEAxMgc21pbGUuaW5mb3JtYXRpay51bmktZnJlaWJ1cmcuZGUxMTAv\nBgkqhkiG9w0BCQEWImlyYS13ZWJAaW5mb3JtYXRpay51bmktZnJlaWJ1cmcuZGUw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCYSbgNbyDYBOdqS7dDOA+x\n8IkgR+SYA4qbNrgytwTp3UKHUX6Um+LMhiKcAwjL7DtT/OBE/SmS9WbSlzrclIfB\n6wGiMUpZadWn7kegpFGlpijy7tZK525+FVd24KUVwW5nePHcD2oHCjgxJgbf+dj4\nJ5IcLJzpno0GKr81TVwp97zavSsYh41Pwhhy+EWFm4vGK14rbaOl2TeQqGBGLwEJ\nX2s58zgYdLevLD2u74wy6mVGS7PjyK8PEWI7yzttZT4kfQeEseK64qWquYuGIsW4\nXYd4JGG226Jf0BZn1pKY3hIQN+2/ZQpnkXxYCQzlSE+TM60AGTJbj6dchLyeaq9L\nAgMBAAGjggPeMIID2jBPBgNVHSAESDBGMBEGDysGAQQBga0hgiwBAQQDAjARBg8r\nBgEEAYGtIYIsAgEEAwEwDwYNKwYBBAGBrSGCLAEBBDANBgsrBgEEAYGtIYIsHjAJ\nBgNVHRMEAjAAMAsGA1UdDwQEAwIF4DAdBgNVHSUEFjAUBggrBgEFBQcDAgYIKwYB\nBQUHAwEwHQYDVR0OBBYEFIJWV6FrgUU9Zfwucawz8nLm1xHPMB8GA1UdIwQYMBaA\nFDNnqdbxk1U2rKEyvcHkljn/THAxMIIBnAYDVR0RBIIBkzCCAY+CJ2NoYW5nZS5z\nbWlsZS5pbmZvcm1hdGlrLnVuaS1mcmVpYnVyZy5kZYIlZGVtby5zbWlsZS5pbmZv\ncm1hdGlrLnVuaS1mcmVpYnVyZy5kZYIkZG9jLnNtaWxlLmluZm9ybWF0aWsudW5p\nLWZyZWlidXJnLmRlgitwbGF5Z3JvdW5kLnNtaWxlLmluZm9ybWF0aWsudW5pLWZy\nZWlidXJnLmRlgihyZWRtaW5lLnNtaWxlLmluZm9ybWF0aWsudW5pLWZyZWlidXJn\nLmRlgiBzbWlsZS5pbmZvcm1hdGlrLnVuaS1mcmVpYnVyZy5kZYInc3RhYmxlLnNt\naWxlLmluZm9ybWF0aWsudW5pLWZyZWlidXJnLmRlgiV0ZXN0LnNtaWxlLmluZm9y\nbWF0aWsudW5pLWZyZWlidXJnLmRlgih0ZXN0aW5nLnNtaWxlLmluZm9ybWF0aWsu\ndW5pLWZyZWlidXJnLmRlgiR3d3cuc21pbGUuaW5mb3JtYXRpay51bmktZnJlaWJ1\ncmcuZGUwgY8GA1UdHwSBhzCBhDBAoD6gPIY6aHR0cDovL2NkcDEucGNhLmRmbi5k\nZS91bmktZnJlaWJ1cmctY2EvcHViL2NybC9nX2NhY3JsLmNybDBAoD6gPIY6aHR0\ncDovL2NkcDIucGNhLmRmbi5kZS91bmktZnJlaWJ1cmctY2EvcHViL2NybC9nX2Nh\nY3JsLmNybDCB3QYIKwYBBQUHAQEEgdAwgc0wMwYIKwYBBQUHMAGGJ2h0dHA6Ly9v\nY3NwLnBjYS5kZm4uZGUvT0NTUC1TZXJ2ZXIvT0NTUDBKBggrBgEFBQcwAoY+aHR0\ncDovL2NkcDEucGNhLmRmbi5kZS91bmktZnJlaWJ1cmctY2EvcHViL2NhY2VydC9n\nX2NhY2VydC5jcnQwSgYIKwYBBQUHMAKGPmh0dHA6Ly9jZHAyLnBjYS5kZm4uZGUv\ndW5pLWZyZWlidXJnLWNhL3B1Yi9jYWNlcnQvZ19jYWNlcnQuY3J0MA0GCSqGSIb3\nDQEBCwUAA4IBAQA72D4fmLKd2ZyTnuy/Ma1pkT5/BcBFxEuYCUnrmiEFJIQAs85L\npvghgeuoJFPXIqzGHdBdhQMNlAGKveE94pDCUzsb5KeYQfx1cxv7WHtrBiSFCNU9\nUoittffeRdPTKVbgYky7fvT1bNVSdjcY6XJeHsWGM9VEz3a8P418BuJD5r6ieta0\nEMjPtDVQCM0J2ubHFyrlaUPExBLlR+4Nw+w2zCII/ToDW3dpEW19Qh9aqrNvaCtp\nA3WX+PsJTXiVTe3aMB8naNylEm4JfyvMSzWP09kuPVF0WQP7+t5pZwXcqNPDuFJF\nSA1QPBvLr4BMM0YEyE5oqagy03A8rmgvpFDJ"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=ira-web@informatik.uni-freiburg.de,CN=smile.informatik.uni-freiburg.de,OU=Institut fuer Informatik,O=Universitaet Freiburg,L=Freiburg,ST=Baden-Wuerttemberg,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://smile.informatik.uni-freiburg.de/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://smile.informatik.uni-freiburg.de/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://smile.informatik.uni-freiburg.de/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://smile.informatik.uni-freiburg.de/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SMILE - Smartphones in der Lehre"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SMILE - Smartphones in der Lehre"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Die SMILE-App f\u00fcr Smartphones, Tablets und Internetbrowser erm\u00f6glicht Live-Feedback, Quiz-Fragen und Lernfragen w\u00e4hrend sehr gro\u00dfen Lehrveranstaltungen. Mit der Q&A-Funktion k\u00f6nnen Studierende Fragen genau dann stellen, wenn Sie auftreten - ohne den Vortragenden zu st\u00f6ren."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "SMILE serves as a lecture-supporting system which students and lecturers can use with their usual login data given by their home institution. The system offers - among other functions - live feedback for the lecturer and quizzes for checking the learning process of the students."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "persistentId",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibdev.rsc.org/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://shibdev.rsc.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibdev.rsc.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibdev.rsc.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibdev.rsc.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibdev.rsc.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibdev.rsc.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibdev.rsc.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shibdev.rsc.org"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJANH7Kwp5r0WjMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD3NoaWJkZXYucnNjLm9yZzAeFw0xMDA2MTQxNTE5MjBaFw0yMDA2MTExNTE5\nMjBaMBoxGDAWBgNVBAMTD3NoaWJkZXYucnNjLm9yZzCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBANXdJVQy7HckKzrtrdZN1+wT/4pWOxgSUSx98WCGymZc\nN+n8HhDJ6Cb9YARDqj228Z2d7MaqugSrAxlM9cPzdOOR4P3h2unydQ/fh7Z6boAx\n/Ai0hwCWdNESxcvR2F2vJIFWHJp77vvfd54mPQiXnwoFWEaxz1fKzexKdw+ydFRR\ngos2zv9Uq5jbG5kD18+vmEttJLtCgLRlNc3CFLeBjgeYb4CUGgzN+reCl0XHFl5f\ndliR5fpr3vkh6EwkOrY1BNsHXWxXVz6Cgih9S+n55llTx2Tot+YR7Lyuvb0OLu7n\n14RqgqZ85BCBBZJv0HruYlxXYE73gqCwcMwSIok3WgMCAwEAAaM9MDswGgYDVR0R\nBBMwEYIPc2hpYmRldi5yc2Mub3JnMB0GA1UdDgQWBBRF7hAyP0xNOaEzRu34T+xw\nr1JoezANBgkqhkiG9w0BAQUFAAOCAQEACxnhXSXF7GZldyE9AcBbd1Wxbpr7YTYf\n/2fsqgdQwfq/9CsTg779vse2bzaCCOUs0LsdTFGoKm8CxPVhpBZDbrnPN/Mdq6sM\nXuiIxjku7fgPZTipTfDGzhERrN5VHBsexNxr5UHQ96bXGK4CxJ+XsCfBQrSZMer0\nz1ld1q/Y+R2/+2ztiVPbdRoOlqNWPPD/RSGuqklw4qxRY9JgMt9ItDDjOlU4T+KN\n4RovAJ1M+L70iM+fdb6zdKVTevO3gW8b7uGE0KqkSv90sEEDCPRSbxxcSwdr1d5x\nGV51mKkJSvO0CwKUTbSeK9Cn+Y0rAn2Hck2OojCaYY/SeNYkhe0vhQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=shibdev.rsc.org"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibdev.rsc.org/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibdev.rsc.org/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibdev.rsc.org/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibdev.rsc.org/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibdev.rsc.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibdev.rsc.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibdev.rsc.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibdev.rsc.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibdev.rsc.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibdev.rsc.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://signin.studentmoneysaver.co.uk",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@studentmoneysaver.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Silimon"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:adrian@studentmoneysaver.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adrian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://signin.studentmoneysaver.co.uk",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-07-03T08:33:07Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Student Money Saver"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.studentmoneysaver.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Student Money Saver Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://signin.studentmoneysaver.co.uk/saml/signout/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "We specialise in student discounts, deals and free stuff, as well as ways to make money quickly. Plus, everything you need to know about student finance, made simple."
                  }
                ],
                "logo": [
                  {
                    "text": "https://cdn.studentmoneysaver.co.uk/assets/logos/sms-logo.png",
                    "height": "61",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "107"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Student Money Saver"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKzCCAxOgAwIBAgIJAI3xfY2iDzkeMA0GCSqGSIb3DQEBCwUAMIGrMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEQMA4GA1UECAwHRW5nbGFuZDEPMA0GA1UEBwwGTG9uZG9uMSAwHgYD\n\t\t\t\t\t\tVQQKDBdTdHVkZW50IE1vbmV5IFNhdmVyIExURDEPMA0GA1UECwwGRGV2T3BzMRcw\n\t\t\t\t\t\tFQYDVQQDDA5zbXMtc2lnbmluLWFwaTEtMCsGCSqGSIb3DQEJARYeYWRyaWFuQHN0\n\t\t\t\t\t\tdWRlbnRtb25leXNhdmVyLmNvLnVrMB4XDTE1MDYyNjA4NDcxMloXDTE3MDYyNTA4\n\t\t\t\t\t\tNDcxMlowgasxCzAJBgNVBAYTAkdCMRAwDgYDVQQIDAdFbmdsYW5kMQ8wDQYDVQQH\n\t\t\t\t\t\tDAZMb25kb24xIDAeBgNVBAoMF1N0dWRlbnQgTW9uZXkgU2F2ZXIgTFREMQ8wDQYD\n\t\t\t\t\t\tVQQLDAZEZXZPcHMxFzAVBgNVBAMMDnNtcy1zaWduaW4tYXBpMS0wKwYJKoZIhvcN\n\t\t\t\t\t\tAQkBFh5hZHJpYW5Ac3R1ZGVudG1vbmV5c2F2ZXIuY28udWswggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDDh7gKf0OElHwbGJ9tCzuifS/1qfSFRxg8wBVk\n\t\t\t\t\t\tZ8/gRSTPyr1xHRYeQMf9+W9bWejDaaDxQq/yRQDwGEOTYN/ghGlej/MD4tBlP4CS\n\t\t\t\t\t\tqUP2stV91Vp8sSyz8Ue2F7surXWk04dav7wLNR3giwpLPL7rSBF8cG3sJiAgFnSC\n\t\t\t\t\t\t3uGLBlP/BHy2UzeWYPhteD80QjBnbGFSA/ETMlDIGj48HmdHyE7gATpVJ84Bw6Db\n\t\t\t\t\t\tAc0xiNKP4rFL0QzD55q4NR1/GQB4MqZdoTA3LXKPrO8HRkIQqEDA3WjcpCQeKuqt\n\t\t\t\t\t\tVPU9mB/XSdzV3+iCVsIW1dSYNnC1FJWB5LBnQijEylcJSY2NAgMBAAGjUDBOMB0G\n\t\t\t\t\t\tA1UdDgQWBBQv1uF4H7q9kZG4TSDpZBWU+yE2BjAfBgNVHSMEGDAWgBQv1uF4H7q9\n\t\t\t\t\t\tkZG4TSDpZBWU+yE2BjAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQAL\n\t\t\t\t\t\tea2RNtk74QMKsbwzICCuADT/rllrKNzsgAkaAjcCdL+DfspFZSnav40MB7ksK16t\n\t\t\t\t\t\taebkpkCK6x3vE5eU3bosiOGektkVoAjbb+BVhuEQHSV17FaXQnkUe2t1httVIihx\n\t\t\t\t\t\tWF/bCXqIzLkbz3KhMX/oYWnLvB7R4UcmaPxImRmcJ5BFA6UXHqlU+d3/9+oOErUu\n\t\t\t\t\t\tTJBBU9BcDoIAcfgMe5MaDXNdVa2P8HD+JDeE3EWx1L7KEOVQaSfekYSTSmstnqBj\n\t\t\t\t\t\tOL0Jr2kxldHRwhrHu50f2PMJFKwvjy4/X79YwapTCn1ee7FWft255LdEqpBFz+we\n\t\t\t\t\t\ty3MXd8zZdHL4dhUTYdiF"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEKzCCAxOgAwIBAgIJAI3xfY2iDzkeMA0GCSqGSIb3DQEBCwUAMIGrMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEQMA4GA1UECAwHRW5nbGFuZDEPMA0GA1UEBwwGTG9uZG9uMSAwHgYD\n\t\t\t\t\t\tVQQKDBdTdHVkZW50IE1vbmV5IFNhdmVyIExURDEPMA0GA1UECwwGRGV2T3BzMRcw\n\t\t\t\t\t\tFQYDVQQDDA5zbXMtc2lnbmluLWFwaTEtMCsGCSqGSIb3DQEJARYeYWRyaWFuQHN0\n\t\t\t\t\t\tdWRlbnRtb25leXNhdmVyLmNvLnVrMB4XDTE1MDYyNjA4NDcxMloXDTE3MDYyNTA4\n\t\t\t\t\t\tNDcxMlowgasxCzAJBgNVBAYTAkdCMRAwDgYDVQQIDAdFbmdsYW5kMQ8wDQYDVQQH\n\t\t\t\t\t\tDAZMb25kb24xIDAeBgNVBAoMF1N0dWRlbnQgTW9uZXkgU2F2ZXIgTFREMQ8wDQYD\n\t\t\t\t\t\tVQQLDAZEZXZPcHMxFzAVBgNVBAMMDnNtcy1zaWduaW4tYXBpMS0wKwYJKoZIhvcN\n\t\t\t\t\t\tAQkBFh5hZHJpYW5Ac3R1ZGVudG1vbmV5c2F2ZXIuY28udWswggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDDh7gKf0OElHwbGJ9tCzuifS/1qfSFRxg8wBVk\n\t\t\t\t\t\tZ8/gRSTPyr1xHRYeQMf9+W9bWejDaaDxQq/yRQDwGEOTYN/ghGlej/MD4tBlP4CS\n\t\t\t\t\t\tqUP2stV91Vp8sSyz8Ue2F7surXWk04dav7wLNR3giwpLPL7rSBF8cG3sJiAgFnSC\n\t\t\t\t\t\t3uGLBlP/BHy2UzeWYPhteD80QjBnbGFSA/ETMlDIGj48HmdHyE7gATpVJ84Bw6Db\n\t\t\t\t\t\tAc0xiNKP4rFL0QzD55q4NR1/GQB4MqZdoTA3LXKPrO8HRkIQqEDA3WjcpCQeKuqt\n\t\t\t\t\t\tVPU9mB/XSdzV3+iCVsIW1dSYNnC1FJWB5LBnQijEylcJSY2NAgMBAAGjUDBOMB0G\n\t\t\t\t\t\tA1UdDgQWBBQv1uF4H7q9kZG4TSDpZBWU+yE2BjAfBgNVHSMEGDAWgBQv1uF4H7q9\n\t\t\t\t\t\tkZG4TSDpZBWU+yE2BjAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQAL\n\t\t\t\t\t\tea2RNtk74QMKsbwzICCuADT/rllrKNzsgAkaAjcCdL+DfspFZSnav40MB7ksK16t\n\t\t\t\t\t\taebkpkCK6x3vE5eU3bosiOGektkVoAjbb+BVhuEQHSV17FaXQnkUe2t1httVIihx\n\t\t\t\t\t\tWF/bCXqIzLkbz3KhMX/oYWnLvB7R4UcmaPxImRmcJ5BFA6UXHqlU+d3/9+oOErUu\n\t\t\t\t\t\tTJBBU9BcDoIAcfgMe5MaDXNdVa2P8HD+JDeE3EWx1L7KEOVQaSfekYSTSmstnqBj\n\t\t\t\t\t\tOL0Jr2kxldHRwhrHu50f2PMJFKwvjy4/X79YwapTCn1ee7FWft255LdEqpBFz+we\n\t\t\t\t\t\ty3MXd8zZdHL4dhUTYdiF"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://signin.studentmoneysaver.co.uk/saml/consume/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://portal.clarin.inl.nl/",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "INL"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@inl.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "servicedesk@inl.nl"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "INL"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@inl.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "servicedesk@inl.nl"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "INL"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:systeembeheer@inl.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "systeembeheer@inl.nl"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://portal.clarin.inl.nl/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-02-13T16:29:50Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://clarin.eu/category/clarin-member"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://portal.clarin.inl.nl/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://portal.clarin.inl.nl/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INL Portal - CLARIN Dienste"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "INL portal - CLARIN services"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Institut f\u00fcr Niederl\u00e4ndische Lexikologie (INL) Vorhaben, die CLARIN-Infrastruktur angeschlossen."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Institute for Dutch Lexicology (INL) projects attached to the CLARIN infrastructure."
                  }
                ],
                "logo": [
                  {
                    "text": "https://portal.clarin.inl.nl/images/logo_portal_verysmall.jpg",
                    "height": "9",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://portal.clarin.inl.nl/images/logo_portal.jpg",
                    "height": "281",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "500"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://portal.clarin.inl.nl/doc/Data_Protection_Code_of_Conduct_INL.pdf"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "portal.clarin.inl.nl"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFwTCCBKmgAwIBAgIQYT/URYqjuNs5Wvey06PWozANBgkqhkiG9w0BAQUFADCB\niTELMAkGA1UEBhMCR0IxGzAZBgNVBAgTEkdyZWF0ZXIgTWFuY2hlc3RlcjEQMA4G\nA1UEBxMHU2FsZm9yZDEaMBgGA1UEChMRQ09NT0RPIENBIExpbWl0ZWQxLzAtBgNV\nBAMTJkNPTU9ETyBIaWdoLUFzc3VyYW5jZSBTZWN1cmUgU2VydmVyIENBMB4XDTEx\nMDgyNTAwMDAwMFoXDTE2MDgyNDIzNTk1OVowgdIxCzAJBgNVBAYTAk5MMRAwDgYD\nVQQREwcyMzExIEJaMRUwEwYDVQQIEwxadWlkLUhvbGxhbmQxDzANBgNVBAcTBkxl\naWRlbjEhMB8GA1UECRMYTWF0dGhpYXMgZGUgVnJpZXNob2YgMi0zMTIwMAYDVQQK\nEylTdCBJbnN0aXR1dXQgdm9vciBOZWRlcmxhbmRzZSBMZXhpY29sb2dpZTETMBEG\nA1UECxMKSW5zdGFudFNTTDEdMBsGA1UEAxMUcG9ydGFsLmNsYXJpbi5pbmwubmww\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC+faM4kQs7smclVpmqWzzX\nZbhhPBW4ulwloBRQY7iR0unaMAGbxobpHvar28sASdvZ7W8IL+Az2J714pceJpit\ns/1Q10cJBzmcopvHtR4Hp6PZxjdEUljrCifQt+IZeZw99TMH4gpeC9zhAdzyubFs\nd452dy8+oljTOlTumbr1zACGU5ZGUInru467GJtMHYTJDDS1/BGuVx0XKwo0idCC\ngoGF8ZIxyHQq/2Q37Py10238nKx614U6KtE//dHP5KkLEHow1Vfm90N+czIkRt+4\n4jl91Cel58jfvjXF3I/Cspi7vFDjRMaeBHsrxtDBWVUOo9GSMWRUiCOeQvGASXcb\nAgMBAAGjggHYMIIB1DAfBgNVHSMEGDAWgBQ/1bXQ1kR5UEoXo5uMSty4sCJkazAd\nBgNVHQ4EFgQUbmgntbNatGZ2IBRNLqazqtbpwGAwDgYDVR0PAQH/BAQDAgWgMAwG\nA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMEYGA1Ud\nIAQ/MD0wOwYMKwYBBAGyMQECAQMEMCswKQYIKwYBBQUHAgEWHWh0dHBzOi8vc2Vj\ndXJlLmNvbW9kby5jb20vQ1BTME8GA1UdHwRIMEYwRKBCoECGPmh0dHA6Ly9jcmwu\nY29tb2RvY2EuY29tL0NPTU9ET0hpZ2gtQXNzdXJhbmNlU2VjdXJlU2VydmVyQ0Eu\nY3JsMIGABggrBgEFBQcBAQR0MHIwSgYIKwYBBQUHMAKGPmh0dHA6Ly9jcnQuY29t\nb2RvY2EuY29tL0NPTU9ET0hpZ2gtQXNzdXJhbmNlU2VjdXJlU2VydmVyQ0EuY3J0\nMCQGCCsGAQUFBzABhhhodHRwOi8vb2NzcC5jb21vZG9jYS5jb20wOQYDVR0RBDIw\nMIIUcG9ydGFsLmNsYXJpbi5pbmwubmyCGHd3dy5wb3J0YWwuY2xhcmluLmlubC5u\nbDANBgkqhkiG9w0BAQUFAAOCAQEARI37zQIk6P0aQkSMyambDpkm+ciyvWTur0Z4\nwVaPQRJ8CAJ75BRokKozs/dbRFsK7nykWIz4ryP8ygPDVVOxVdvweTZY6iRrMhhm\nipw6JOA9+S12wS4ZVDTw1Lnqx55zhvZufKE/IcYUtXQG9zIThXvkSaZsbl81PeiJ\nJzPwUvRo8xI+nUirIcO80HN9FlZJ2MUHnt5EJNvdzWMOrwVyvIkSPllFsVLwRIih\nEYedRymWuO/OSGWReWSkDjCXxPNrqd4aaZSZH67bOcYLz4FUMR64+4JXSN8/gchW\nzq4XJzocDxUe2X15eEg+Nw6f/ORaY9V9249atYZCavmDX/4vXw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=portal.clarin.inl.nl,OU=InstantSSL,O=St Instituut voor Nederlandse Lexicologie,street=Matthias de Vrieshof 2-3,L=Leiden,ST=Zuid-Holland,postalCode=2311 BZ,C=NL"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://portal.clarin.inl.nl/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://portal.clarin.inl.nl/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://portal.clarin.inl.nl/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://portal.clarin.inl.nl/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://portal.clarin.inl.nl/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://portal.clarin.inl.nl/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "INL Portal - CLARIN Dienste"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "INL portal - CLARIN services"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Institut f\u00fcr Niederl\u00e4ndische Lexikologie (INL) Vorhaben, die CLARIN-Infrastruktur angeschlossen."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Institute for Dutch Lexicology (INL) projects attached to the CLARIN infrastructure."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.uchastings.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "proschan@uchastings.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ronald Proschan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "proschan@uchastings.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ronald Proschan"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.uchastings.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.uchastings.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.uchastings.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.uchastings.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.uchastings.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.uchastings.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uchastings.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of California Hastings College of the Law"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTzCCAjegAwIBAgIULgOAs/Tf+A5icFcGA4Rhib2qyiIwDQYJKoZIhvcNAQEF\nBQAwJDEiMCAGA1UEAxMZc2hpYmJvbGV0aC51Y2hhc3RpbmdzLmVkdTAeFw0xMjEx\nMjAwMjUzMTRaFw0zMjExMjAwMjUzMTRaMCQxIjAgBgNVBAMTGXNoaWJib2xldGgu\ndWNoYXN0aW5ncy5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCI\n3hbJpnF1jSXmIkYcgbkQihqtmY9kdeKweWZlnUq/9nGMDig7EEurRci7DPVf4an9\nnNqaFO9SnfXjkcK50XUlojtQReKu2y9XEtqP2bpb24NPeJZVC5lGKo14USBtXLQs\nh4SMipV2p9JbhgVVBoc5HK/+XN+ceSUJdQWDAGOb/plSBnT3Xpr5yEg88kiG+Ogl\nPawAqXBcTf7GX5pcIdRaivnCCVuMs1jdtjlOOZrm3jNpQ9lLluUjzlTJeQEaKdSp\n8lNhPXGYOK+nvjzzz7Q4WjhCOzBvJEQ65j7rG7xv67BPJaq/Z39NblYOorPyHyg0\n8bwyxTmByXDsv89GsAFNAgMBAAGjeTB3MFYGA1UdEQRPME2CGXNoaWJib2xldGgu\ndWNoYXN0aW5ncy5lZHWGMGh0dHBzOi8vc2hpYmJvbGV0aC51Y2hhc3RpbmdzLmVk\ndS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU1AIdyJ3tLG0jtHse7Et6r/0wHHAw\nDQYJKoZIhvcNAQEFBQADggEBAF/MjsAp1CUH0HHW/IFm2RaYFkkTDTpsYgkiK9nR\n9lO0uBTLMPb4OAUSh0lWLCHGDI3XGcs88eOgrfUfMeEF0ZSzG5Re0XrdpdRr+08R\nuvwMOAkOffYOyj+QKnZ8Rc2wJ3lNjC4XJXDUAPms5KhKBcvS3OKdv9j4UIMZLihL\nlrY2fAeErFDqKpITwtKShev1mjxe/XdvgkWhSudryLi6KAiXZVAI58YJjDvnenXq\ncNfywjmUvtBaLs4PBLUGOdECvQ9b/yAV4OrVAkQhJmv2Qa8SRVCLVzhs9pui8DlJ\nBd22SCSfMLz0OSX/8PQPqMyFNzt+pG3rP4r+8yHg/8wjgtE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of California Hastings College of the Law"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uchastings.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of California Hastings College of the Law"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://nbcol.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://nbcol.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/nbcol.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/nbcol.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nbcol.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Northbrook College Sussex"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nbcol.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://mylogin.uni-freiburg.de/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mylogin@uni-freiburg.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "myLogin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mylogin@uni-freiburg.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "myLogin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Oberknapp"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:bo@ub.uni-freiburg.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Bernd"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://mylogin.uni-freiburg.de/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2009-05-26T08:35:10Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://aai.dfn.de/category/bwidm-member"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "mylogin.uni-freiburg.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGcTCCBVmgAwIBAgIHGHFzy9wsiTANBgkqhkiG9w0BAQsFADCBhjELMAkGA1UE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\nBvSLKfixDbm6WbObPgh+5qnIJT3Y"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=mylogin@uni-freiburg.de,CN=mylogin.uni-freiburg.de,OU=Universitaetsbibliothek,O=Universitaet Freiburg,L=Freiburg,ST=Baden-Wuerttemberg,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uni-freiburg.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://mylogin.ub.uni-freiburg.de:8443/idp2/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mylogin.ub.uni-freiburg.de:8443/idp2/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://mylogin.ub.uni-freiburg.de/idp2/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mylogin.ub.uni-freiburg.de/idp2/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://mylogin.ub.uni-freiburg.de/idp2/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://mylogin.ub.uni-freiburg.de/idp2/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mylogin.ub.uni-freiburg.de/idp2/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://mylogin.ub.uni-freiburg.de:8443/idp2/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://mylogin.ub.uni-freiburg.de:8443/idp2/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uni-freiburg.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uni-freiburg.de/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uni-freiburg.de/"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Die Universit\u00e4t Freiburg bietet mit myLogin einen zentralen Authentifizierung- und Autorisierungsdienst an. Technische Basis ist ein Shibboleth Identity-Provider. <a href=\"https://mylogin.uni-freiburg.de/\" target=\"_blank\">Weitere Informationen...</a>"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Die Universit\u00e4t Freiburg bietet mit myLogin einen zentralen Authentifizierung- und Autorisierungsdienst an. Technische Basis ist ein Shibboleth Identity-Provider. <a href=\"https://mylogin.uni-freiburg.de/\" target=\"_blank\">Weitere Informationen...</a>"
                  }
                ],
                "logo": [
                  {
                    "text": "https://mylogin.ub.uni-freiburg.de/themes/freiburg/icons/unilogo-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://mylogin.ub.uni-freiburg.de/themes/freiburg/icons/unilogo-42x60.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "42"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Albert-Ludwigs-Universit\u00e4t Freiburg"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Albert-Ludwigs-Universit\u00e4t Freiburg"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "mylogin.uni-freiburg.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGcTCCBVmgAwIBAgIHGHFzy9wsiTANBgkqhkiG9w0BAQsFADCBhjELMAkGA1UE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\nBvSLKfixDbm6WbObPgh+5qnIJT3Y"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=mylogin@uni-freiburg.de,CN=mylogin.uni-freiburg.de,OU=Universitaetsbibliothek,O=Universitaet Freiburg,L=Freiburg,ST=Baden-Wuerttemberg,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Albert-Ludwigs-Universit\u00e4t Freiburg"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Albert-Ludwigs-Universit\u00e4t Freiburg"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-freiburg.de/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-freiburg.de/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e14"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e14"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.img.cas.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Zacek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "michal.zacek@img.cas.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michal"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.img.cas.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2014-06-09T12:29:04Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/avcr"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAOD0HnToPYposQvSZOwdUVtqwictMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC5pbWcuY2FzLmN6MB4XDTE0MDUyOTA2MjgxOVoX\nDTM0MDUyOTA2MjgxOVowGTEXMBUGA1UEAxMOaWRwLmltZy5jYXMuY3owggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDaG1eJjjOGWyA26l3zWvg7oxWlyxO4\nXka8cJYUupiV80Swq+oo2PlUqbL8ciHP7g0Vjdw4wTq1/R9i1sA1i1JLj3TRFoy6\ncvCFH4m8aeQKnSjcpUJiQXkGE/rM4Hf1qegyrjKqnbk83azOODv1IbndJMXMdf/9\n7Nl/1+3UDy8LsVsNKkN/8fplSHC2exAOZlPVX/uwlgwXDo5AsM4VvZjhB3fDNeLr\nwcfXmvohMhp3u5KJhQS4oPCpX5ULjo1EPRuRhKsOBCQHX6fH4Ac1E2b8as3HvzJ2\nfgqG1QETTyZZAhlovWHEVRncu8k8jMwbCIq3UgQMP+WK8fGP/sPRbpPnAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC5pbWcuY2FzLmN6hiVodHRwczovL2lkcC5pbWcu\nY2FzLmN6L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRU+/iETTc1Nh9rJ+L2sBT4\ny68xFjANBgkqhkiG9w0BAQUFAAOCAQEAvFtxSjURNIGODMraRKn9En4YjARqtyN1\n3uoXTbgc3GE6O/PgWwu1I1VndTTnIBoOC6bviKSu1sVpe7yhHjkoilR3EuZDuZGl\n0YBnlrmWcwXQOH08zfdiqtApDO761LRtYEaXJnyCTmLFRquMUxQy/Z0NXMCNEOps\neCR5zkOYQadY9TLPoyrKWidxar0mjW96yK1uWiVKWqt1bU/zWhFxLYPN8bLNB2JU\nRTuMCTO4d4Zdp5uhCbnM4F+Zlipu2ojbhJiHHqJ0SOrsfXWHsdpp8S2nJcPlERgd\nN9KAr6lHQsSuYiw6Lt0HG1Q4TAFYTaPnA40uN+zzOomz27Chnsg/Sw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "img.cas.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.img.cas.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.img.cas.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.img.cas.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.img.cas.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.img.cas.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.img.cas.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.img.cas.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.img.cas.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.img.cas.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.img.cas.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.img.cas.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "img.cas.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.img.cas.cz/en/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.img.cas.cz/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for IMG ASCR employees."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Poskytovatel identity pro zam\u011bstnance \u00daMG AV \u010cR."
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.img.cas.cz/images/img_logo_small.png",
                    "height": "40",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "104"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Molecular Genetics of the ASCR"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u00dastav molekul\u00e1rn\u00ed genetiky AV \u010cR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAOD0HnToPYposQvSZOwdUVtqwictMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC5pbWcuY2FzLmN6MB4XDTE0MDUyOTA2MjgxOVoX\nDTM0MDUyOTA2MjgxOVowGTEXMBUGA1UEAxMOaWRwLmltZy5jYXMuY3owggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDaG1eJjjOGWyA26l3zWvg7oxWlyxO4\nXka8cJYUupiV80Swq+oo2PlUqbL8ciHP7g0Vjdw4wTq1/R9i1sA1i1JLj3TRFoy6\ncvCFH4m8aeQKnSjcpUJiQXkGE/rM4Hf1qegyrjKqnbk83azOODv1IbndJMXMdf/9\n7Nl/1+3UDy8LsVsNKkN/8fplSHC2exAOZlPVX/uwlgwXDo5AsM4VvZjhB3fDNeLr\nwcfXmvohMhp3u5KJhQS4oPCpX5ULjo1EPRuRhKsOBCQHX6fH4Ac1E2b8as3HvzJ2\nfgqG1QETTyZZAhlovWHEVRncu8k8jMwbCIq3UgQMP+WK8fGP/sPRbpPnAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC5pbWcuY2FzLmN6hiVodHRwczovL2lkcC5pbWcu\nY2FzLmN6L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRU+/iETTc1Nh9rJ+L2sBT4\ny68xFjANBgkqhkiG9w0BAQUFAAOCAQEAvFtxSjURNIGODMraRKn9En4YjARqtyN1\n3uoXTbgc3GE6O/PgWwu1I1VndTTnIBoOC6bviKSu1sVpe7yhHjkoilR3EuZDuZGl\n0YBnlrmWcwXQOH08zfdiqtApDO761LRtYEaXJnyCTmLFRquMUxQy/Z0NXMCNEOps\neCR5zkOYQadY9TLPoyrKWidxar0mjW96yK1uWiVKWqt1bU/zWhFxLYPN8bLNB2JU\nRTuMCTO4d4Zdp5uhCbnM4F+Zlipu2ojbhJiHHqJ0SOrsfXWHsdpp8S2nJcPlERgd\nN9KAr6lHQsSuYiw6Lt0HG1Q4TAFYTaPnA40uN+zzOomz27Chnsg/Sw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Molecular Genetics of the ASCR, v. v. i."
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u00dastav molekul\u00e1rn\u00ed genetiky AV \u010cR, v. v. i."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.img.cas.cz/en/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.img.cas.cz/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IMG"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://federation.utbm.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Arnaud Sinteff"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "arnaud.sinteff@utbm.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dominique Dal Ponte"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dominique.dalponte@utbm.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federation.utbm.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-12-13T13:48:40Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.utbm.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federation.utbm.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://federation.utbm.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utbm.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.utbm.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Technologie de Belfort-Montb\u00e9liard"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Technologie de Belfort-Montb\u00e9liard"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUb4XRw/k+kZc+WFwzq1F9FsvDbwEwDQYJKoZIhvcNAQEF\nBQAwHTEbMBkGA1UEAxMSZmVkZXJhdGlvbi51dGJtLmZyMB4XDTEyMDcxMjEyNDEw\nNFoXDTMyMDcxMjEyNDEwNFowHTEbMBkGA1UEAxMSZmVkZXJhdGlvbi51dGJtLmZy\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApR6JQmSaezaESAFmv21B\nsXk5DXZmezdLDuKlPjQJp68eOc/1MDaS+b0UCQzjW9CJGNKRGecNkts0EYlnS+fd\n9I3hukKCpKbQB+fzqyLfEbOktQ8HeSXCOVuZqbKyWn/tAeqRXPWa60j6aouZHGcs\nQsCxdN4A5H3m3BxRBUKZWl9YPhshoYS0X5s1cN3ryEM0F178F4Dx/d7wJSxjcqYp\nTkmwYOYLrDxIG34/12JrWhheephvSV6KHGqylZGm8PieeU/dMfYoqlPDygx3lLmG\nWYJ4czikUXYXutSxa9sx1YqjslDNjN/opVnL5ej/H7L0I6XaBuxvZ7EY8Ez5l8gW\nEwIDAQABo2swaTBIBgNVHREEQTA/ghJmZWRlcmF0aW9uLnV0Ym0uZnKGKWh0dHBz\nOi8vZmVkZXJhdGlvbi51dGJtLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBRn\nKDMEILCZOOzXatLQKA9dtx9RMzANBgkqhkiG9w0BAQUFAAOCAQEAAxvjTcRA2lsE\nMdepN1Pw8qgKgIVT8ptE7xspkSp3vbiMbFB6WUCBbmo9OGRXz/ml034OqIEmtOQA\nHD4bLKWak9FlZmvtKisClNpFUblWcHHCdEkw6gHNj+GEuLSREVDiXlyuPMiHIiM/\nNBS2NevXTCRtrWWYtLsy/8/9DIqp5wl+Tw4KhYzbnmAp1HXijhjQTlEU9so74g9M\np1/I8t00rET4cbu2OgNnsnJsJ7eYlxs2/7r7ym92Brq94Cq+DqlVo6lAsnumtDFY\npWS70X7hmXF+uwJn5EAqK6m4fQdJouyaQD1Eyosj5vYiQG02H8/+HE+FTthzgvq7\nDM8klPBfXg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Technologie de Belfort-Montb\u00e9liard"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utbm.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Technologie de Belfort-Montb\u00e9liard"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso.augsburg.edu/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "fortier@augsburg.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Josef Fortier"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "schornst@augsburg.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matthew Schornstein"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.augsburg.edu/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.augsburg.edu/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.augsburg.edu/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.augsburg.edu/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.augsburg.edu/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "augsburg.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Augsburg College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFDDCCA/SgAwIBAgIJAN9RPGLGQC4WMA0GCSqGSIb3DQEBBQUAMIG0MQswCQYD\nVQQGEwJVUzESMBAGA1UECBMJTWlubmVzb3RhMRQwEgYDVQQHEwtNaW5uZWFwb2xp\nczEZMBcGA1UEChMQQXVnc2J1cmcgQ29sbGVnZTEfMB0GA1UECxMWSW5mb3JtYXRp\nb24gVGVjaG5vbG9neTEZMBcGA1UEAxMQc3NvLmF1Z3NidXJnLmVkdTEkMCIGCSqG\nSIb3DQEJARYVc3lzYWRtaW5AYXVnc2J1cmcuZWR1MB4XDTEzMDgyNzEyNTUxNVoX\nDTIzMDgyNzEyNTUxNVowgbQxCzAJBgNVBAYTAlVTMRIwEAYDVQQIEwlNaW5uZXNv\ndGExFDASBgNVBAcTC01pbm5lYXBvbGlzMRkwFwYDVQQKExBBdWdzYnVyZyBDb2xs\nZWdlMR8wHQYDVQQLExZJbmZvcm1hdGlvbiBUZWNobm9sb2d5MRkwFwYDVQQDExBz\nc28uYXVnc2J1cmcuZWR1MSQwIgYJKoZIhvcNAQkBFhVzeXNhZG1pbkBhdWdzYnVy\nZy5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDLTYBIadLgBdht\n2vNPov8lsGsQ/sjr/5dX6UjbSxWiA9rPqgY9DJftjF/CNSvhB2CCIOSItVPLf1me\n7UJIZbcwRh+PtTGMAJgMDdUr6FfKFU/IGGIJMML6Z63QYog6YFE63olVNCI/DuY3\nxdieNo+jhNwUG56ZnupYmR18GDHoGEVA1YbR1DcRa24N2zuewgVyzoOg7k6BCN5I\nl+ijtPqbDdMg+8CQNDShgrfnkIxP2eiIK3IKiDkvv/zcSYpzQNDaCR05AoY+5I+X\ng7Vn10VtnrGtM1q0pk/phmCo7WQF6DwVBA5veLzLor5Jx0byZwnQed9ivN4Aq0kW\nivu4qq3LAgMBAAGjggEdMIIBGTAdBgNVHQ4EFgQUTdesxg1z4qAex7c4gw4DTw29\n3MEwgekGA1UdIwSB4TCB3oAUTdesxg1z4qAex7c4gw4DTw293MGhgbqkgbcwgbQx\nCzAJBgNVBAYTAlVTMRIwEAYDVQQIEwlNaW5uZXNvdGExFDASBgNVBAcTC01pbm5l\nYXBvbGlzMRkwFwYDVQQKExBBdWdzYnVyZyBDb2xsZWdlMR8wHQYDVQQLExZJbmZv\ncm1hdGlvbiBUZWNobm9sb2d5MRkwFwYDVQQDExBzc28uYXVnc2J1cmcuZWR1MSQw\nIgYJKoZIhvcNAQkBFhVzeXNhZG1pbkBhdWdzYnVyZy5lZHWCCQDfUTxixkAuFjAM\nBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCuVbzHRsSs2W4/soC5MhMU\nmevVY2FW5A92eFIaa6iTHNvUA5SoXDhlMYMCgmqcsEWJ8I8xmilSg0HJDvC1wHsG\nH1r9XxjK2lW9PXlCGFGW4Rh4ljVsQqQZXAWUtOpuom+H9TNF4/pzZxdIhUCOyt9v\n5IwAeos0dMBQ7CJ0qbecFUzbMK4ZwNXpyvGzr5cRsiclW9U7MEcyHOVBcfU8blvj\nNukaLdL+qBhOqX+0/c8TREyoz8esHYXrfpeIW5LjCd0uP+4gKz+xfLbIhPIjf0wB\nMS7pk1MzPh5mGaGDDnSTI0qeaw25K2CtvbzShdcrOdjSk0PQfspH1v/JYIQgxOot"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Augsburg College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.augsburg.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Augsburg College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://bolton.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Charlson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:I.Charlson@bolton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Nikrooz"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:A.Nikrooz@bolton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Antony"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://bolton.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.bolton.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.bolton.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bolton.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID9jCCAt6gAwIBAgIJAMeNs3EXVaFlMA0GCSqGSIb3DQEBBQUAMHwxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMQ4wDAYDVQQIEwVMYW5jczEPMA0GA1UEBxMGQm9sdG9uMSEwHwYDVQQK\n\t\t\t\t\t\tExhUaGUgVW5pdmVyc2l0eSBvZiBCb2x0b24xDDAKBgNVBAsTA0lTVDEbMBkGA1UE\n\t\t\t\t\t\tAxMSbG9naW4uYm9sdG9uLmFjLnVrMB4XDTEzMDExNjE0MzAwOVoXDTIzMDExNDE0\n\t\t\t\t\t\tMzAwOVowfDELMAkGA1UEBhMCR0IxDjAMBgNVBAgTBUxhbmNzMQ8wDQYDVQQHEwZC\n\t\t\t\t\t\tb2x0b24xITAfBgNVBAoTGFRoZSBVbml2ZXJzaXR5IG9mIEJvbHRvbjEMMAoGA1UE\n\t\t\t\t\t\tCxMDSVNUMRswGQYDVQQDExJsb2dpbi5ib2x0b24uYWMudWswggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQDOjOVfVGLNGxU5idZ0TXO650ieACNjmzKRmsij\n\t\t\t\t\t\teGIOWRR1JdDt1f/Qzn3J4i44AwgTSQOTUb7LLEBXxGZ2IOdyg0Eo2sbdhfrakXSj\n\t\t\t\t\t\tqupgMXzaRlJqS3Aj1dOPwD7sAoWieZaU9YUaci93pUdReWWRFJNS8+caRb2J86il\n\t\t\t\t\t\tNUh3KGjFeChv/W5YjYKJJzYTz4I1bIiwxdmkaLKz1xItsrxlVJLb6FbpPQspf+4m\n\t\t\t\t\t\taR8odp3zp2C0p2VxCKB7bGrVjz8GtG+C9FLuqr14UAOUkP8gCM5bh5juAqFhiRxq\n\t\t\t\t\t\tvjqKkt8E1U0GGSA/wrOmfee7jre3a9ZEQ2XDBnhL/vyl/o23AgMBAAGjezB5MAkG\n\t\t\t\t\t\tA1UdEwQCMAAwLAYJYIZIAYb4QgENBB8WHU9wZW5TU0wgR2VuZXJhdGVkIENlcnRp\n\t\t\t\t\t\tZmljYXRlMB0GA1UdDgQWBBQRjeujYHnHVAgjBV2q/kOIkS9oKzAfBgNVHSMEGDAW\n\t\t\t\t\t\tgBQRjeujYHnHVAgjBV2q/kOIkS9oKzANBgkqhkiG9w0BAQUFAAOCAQEAHNtOuZaJ\n\t\t\t\t\t\tD0zq7F+m2S/aRNcRldTcYg/SQJprEKG2v+N66K1xtVJRUqy0XaeRl5rXlDwVqgFc\n\t\t\t\t\t\tIcWzxCQhc2p65iQMTp6ZAnyKFiIY0jGEfCQPYeSTV5rklZo/u1lfO5vruqEZCFsS\n\t\t\t\t\t\taoSTBFMoZZg1ERrwWk1KH1LXF+WjDNfRIDAgBr2OUDatFF+n1PMDtNxxXjeb/32d\n\t\t\t\t\t\tTXO45yY5/ddNJywFOCm5293empnNnBsu/OSkkUX7RhYUr1IFwZXmUiNzvUDMtJym\n\t\t\t\t\t\t3WiZ+NTdc2zIc4zfAgssu/HL6GwUTKSAGRVPcmJn8UqPawT00r2lqtzDb+54kv27\n\t\t\t\t\t\tKCsozEp6AzhAYA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Bolton"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bolton.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Bolton"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.sans-ec.nl",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.sans-ec.nl",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2016-03-09T11:30:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/7e77e73001803e8ba5c0122b7dd2f024",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sans-ec.nl"
              },
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SaNS Expertisecentrum"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SaNS Expertisecentrum"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/sansec.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "120"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SaNS Expertisecentrum"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sans-ec.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SaNS Expertisecentrum"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://edit.kau.se/simplesaml/module.php/saml/sp/metadata.php/default-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webbteknik@kau.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT-Avdelningen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://edit.kau.se/simplesaml/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://edit.kau.se/simplesaml/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Logga in f\u00f6r att redigera inneh\u00e5llet p\u00e5 www.kau.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Login to to create and edit content for www.kau.se"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kau.se webbserver"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kau.se webbserver"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://edit.kau.se/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://edit.kau.se/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://edit.kau.se/simplesaml/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://edit.kau.se/simplesaml/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-demo-p00.its.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-demo-p00.its.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-p00.its.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-p00.its.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-p00.its.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-p00.its.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-p00.its.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-demo-p00.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-demo-p00.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;demo-p00"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;demo-p00"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-demo-p00.its.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-demo-p00.its.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIJAK6YQRZEKIPhMA0GCSqGSIb3DQEBBQUAMCUxIzAhBgNV\nBAMTGmxhZG9rMy1kZW1vLXAwMC5pdHMudW11LnNlMB4XDTE0MTAxNzA4MjQyNVoX\nDTI0MTAxNDA4MjQyNVowJTEjMCEGA1UEAxMabGFkb2szLWRlbW8tcDAwLml0cy51\nbXUuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDE/4dts9/Mj3WT\nleCBGvJe+NN/fu7uTZJLEPUceMfTfOjKruewC31rnunQJNdZKwO1FbCkXDA37NLb\n4B1E2HcKJ3uPJ0sIgK41UbwOMmzgYwtxQCqK//BSc8PeFSP25xbtTntMnbXZ2QNs\n4xRvS29AoiubCExes6u3rdJCPZJn6Nwl6cyt0r9QKH49rZugKxHbl74SNst4h6JH\nfk9RWXP+L8AID3M/zCLMdaN6jP6m9aIQrR4+gmUcORl6ZERxXsiLPXLMGv9DZ1wV\nKDhjQQUx5xVWzd3N7O1UrJNojlkEuXxcy42TJRQxzT44XTA4NBAEZ2Mzcpu8ftid\nEawqoCmNAgMBAAGjczBxMFAGA1UdEQRJMEeCGmxhZG9rMy1kZW1vLXAwMC5pdHMu\ndW11LnNlhilodHRwczovL2xhZG9rMy1kZW1vLXAwMC5pdHMudW11LnNlL2d1aS1z\ncDAdBgNVHQ4EFgQUFWIiDeX9AGGpxGi7b70f5PlasQ4wDQYJKoZIhvcNAQEFBQAD\nggEBAFBLnPLQeFZlSm+HLgrxLBOG4rTgqFGTSDYmj2z/eRcexI/M2swiRhjBGP5g\n8N8v1AXy5vpfh1tbQXb1iayHrfCFLQ1PV13WukzpOFoF2rXmzriYUN+Jf1jzz8Qd\n6Zl2nV+SSvXFW4ABA7t4MG7REX6AHJa3oeRW0hx3p3+TmHhpgyevTMLLeOP9f5fl\nEh9OHP9ZxDShl/7sKMcy/33qRDe834nQ9R4TVvr/6oKJtCDisoSx3a01/DHRJkyI\najX6FIHD08/JILYXL0vYj2qdYGHyOd6NsIkgmwLuCBI8r/FLyd3jqI/lwvLGqezD\nRjGy4hnZ0d0E1vkLI2/F/uLaVuE="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-demo-p00.its.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-p00.its.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-p00.its.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-p00.its.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-p00.its.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-p00.its.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-p00.its.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-demo-p00.its.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-demo-p00.its.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-demo-p00.its.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.univille.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Paulo Sergio da Silva"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pssilva@univille.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.univille.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEGjCCAwICAQAwDQYJKoZIhvcNAQEFBQAwgdIxNjA0BgNVBAoULVVOSVZJTExF\nIC0gVW5pdmVyc2lkYWRlIGRhIFJlZ2nDo2RlIEpvaW52aWxsZTEUMBIGA1UECxML\nVEktVW5pdmlsbGUxIjAgBgkqhkiG9w0BCQEWE3Bzc2lsdmFAdW5pdmlsbGUuYnIx\nEjAQBgNVBAcTCUpvaW52aWxsZTEXMBUGA1UECBMOU2FudGEgQ2F0YXJpbmExCzAJ\nBgNVBAYTAkJSMSQwIgYDVQQDExtpZHAudW5pdmlsbGUuYnIudW5pdmlsbGUuYnIw\nHhcNMTUxMDE5MTkwNzI3WhcNMTgxMDE4MTkwNzI3WjCB0jE2MDQGA1UEChQtVU5J\nVklMTEUgLSBVbml2ZXJzaWRhZGUgZGEgUmVnacOjZGUgSm9pbnZpbGxlMRQwEgYD\nVQQLEwtUSS1Vbml2aWxsZTEiMCAGCSqGSIb3DQEJARYTcHNzaWx2YUB1bml2aWxs\nZS5icjESMBAGA1UEBxMJSm9pbnZpbGxlMRcwFQYDVQQIEw5TYW50YSBDYXRhcmlu\nYTELMAkGA1UEBhMCQlIxJDAiBgNVBAMTG2lkcC51bml2aWxsZS5ici51bml2aWxs\nZS5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOBHDxFbBxBna9+g\nXPHHpa7vb+tJQKfisMcCdz0wFQEq0N8izKfYmns8fkrmL2qnDkMSqGsGCPe5pNar\n4+gCfeDMK+S57NvS/z6ccryjN6UpA3yUzm7mNf9K1z9EoBd+aA+wBNGNZKaiaSfo\nyL5w8k7Kny/LbYtybJWDSigS3lrMLmgItFhG1d/CYOiVkn49IrBfdfRI0QfhAZli\n3OE+SjQ5uUUw2HkjCYY1Ju/5euCCD0WaYLT5cZ+iA8I1Cg8ctE+vIRjf3W6zmk48\n8rCr56VX4ZaWWFitME7Y0Zv8N7DfI9znUR6LzWJt7O2AyRjE6i99RTE8bPo93Txk\ne1SiXK8CAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAhiiZnxvBvcBTS0R7QO1h5ilf\n32hCyZRPjvtqmQpRBG/7Gvex5ONBztABL0yrckkVtalZyntg4w5CdbrkRKC7k8tK\n7/HYVzo49ZQ6FzpAQdLEAhCLA0hY65anEFlifUmClYNtex8gL8dzF8o9yp/Hu0Wm\nK9avfqWDLuk4tC6BxBdgFlIMBv1B4maEGmac3NNGIk6OU1Iboq1TDPA8OkfRFYEf\nqp8r8NBaC+0BzpVtqUu3g8AFM6PJD46g35EzlP8K1hMAqrlsqEZ7IlD2n91XW5J7\nnP4wY1kEldpD1CfHvNSzk1HuF/Q2VHTjUN2sDaQr1y/qhqBEkNiEhDd78YmPVA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univille.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.univille.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.univille.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.univille.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univille.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.univille.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univille.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.univille.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.univille.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univille.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univille.edu.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univille.edu.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNIVILLE - Universidade da Regiao de Joinville"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNIVILLE - Universidade da Regiao de Joinville"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNIVILLE - Universidade da Regiao de Joinville"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNIVILLE - Universidade da Regiao de Joinville"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEGjCCAwICAQAwDQYJKoZIhvcNAQEFBQAwgdIxNjA0BgNVBAoULVVOSVZJTExF\nIC0gVW5pdmVyc2lkYWRlIGRhIFJlZ2nDo2RlIEpvaW52aWxsZTEUMBIGA1UECxML\nVEktVW5pdmlsbGUxIjAgBgkqhkiG9w0BCQEWE3Bzc2lsdmFAdW5pdmlsbGUuYnIx\nEjAQBgNVBAcTCUpvaW52aWxsZTEXMBUGA1UECBMOU2FudGEgQ2F0YXJpbmExCzAJ\nBgNVBAYTAkJSMSQwIgYDVQQDExtpZHAudW5pdmlsbGUuYnIudW5pdmlsbGUuYnIw\nHhcNMTUxMDE5MTkwNzI3WhcNMTgxMDE4MTkwNzI3WjCB0jE2MDQGA1UEChQtVU5J\nVklMTEUgLSBVbml2ZXJzaWRhZGUgZGEgUmVnacOjZGUgSm9pbnZpbGxlMRQwEgYD\nVQQLEwtUSS1Vbml2aWxsZTEiMCAGCSqGSIb3DQEJARYTcHNzaWx2YUB1bml2aWxs\nZS5icjESMBAGA1UEBxMJSm9pbnZpbGxlMRcwFQYDVQQIEw5TYW50YSBDYXRhcmlu\nYTELMAkGA1UEBhMCQlIxJDAiBgNVBAMTG2lkcC51bml2aWxsZS5ici51bml2aWxs\nZS5icjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAOBHDxFbBxBna9+g\nXPHHpa7vb+tJQKfisMcCdz0wFQEq0N8izKfYmns8fkrmL2qnDkMSqGsGCPe5pNar\n4+gCfeDMK+S57NvS/z6ccryjN6UpA3yUzm7mNf9K1z9EoBd+aA+wBNGNZKaiaSfo\nyL5w8k7Kny/LbYtybJWDSigS3lrMLmgItFhG1d/CYOiVkn49IrBfdfRI0QfhAZli\n3OE+SjQ5uUUw2HkjCYY1Ju/5euCCD0WaYLT5cZ+iA8I1Cg8ctE+vIRjf3W6zmk48\n8rCr56VX4ZaWWFitME7Y0Zv8N7DfI9znUR6LzWJt7O2AyRjE6i99RTE8bPo93Txk\ne1SiXK8CAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAhiiZnxvBvcBTS0R7QO1h5ilf\n32hCyZRPjvtqmQpRBG/7Gvex5ONBztABL0yrckkVtalZyntg4w5CdbrkRKC7k8tK\n7/HYVzo49ZQ6FzpAQdLEAhCLA0hY65anEFlifUmClYNtex8gL8dzF8o9yp/Hu0Wm\nK9avfqWDLuk4tC6BxBdgFlIMBv1B4maEGmac3NNGIk6OU1Iboq1TDPA8OkfRFYEf\nqp8r8NBaC+0BzpVtqUu3g8AFM6PJD46g35EzlP8K1hMAqrlsqEZ7IlD2n91XW5J7\nnP4wY1kEldpD1CfHvNSzk1HuF/Q2VHTjUN2sDaQr1y/qhqBEkNiEhDd78YmPVA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNIVILLE - Universidade da Regiao de Joinville"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNIVILLE - Universidade da Regiao de Joinville"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univille.edu.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univille.edu.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNIVILLE - Universidade da Regiao de Joinville"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNIVILLE - Universidade da Regiao de Joinville"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.shibboleth.ttu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "nis@ttu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Telecommunications Network Systems"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "nis@ttu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Telecommunications Network Systems"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "nis@ttu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Telecommunications Network Systems"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.shibboleth.ttu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.shibboleth.ttu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.shibboleth.ttu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.shibboleth.ttu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.shibboleth.ttu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.shibboleth.ttu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ttu.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Texas Tech University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVAPD3XAIRckWiM8m7Oiu6nDm4mM/QMA0GCSqGSIb3DQEB\nBQUAMCExHzAdBgNVBAMMFmlkcC5zaGliYm9sZXRoLnR0dS5lZHUwHhcNMTUwNDAx\nMTQyOTU0WhcNMzUwNDAxMTQyOTU0WjAhMR8wHQYDVQQDDBZpZHAuc2hpYmJvbGV0\naC50dHUuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmFA9i78E\nOy4fx44dGkzvx19T9RvdgKNFOX6JqLiHWPjXtWF8kfH/9vfjjO7eoAMWpZS0N2o3\ndDJeCaWsdKXJZ+xZ6c/OW7J/qByN62kH84PDaGWOURPy1FXNBjwvXhB0rnWVcdie\nmdgH/LLBP1+zwiq/FKglLHB+ltPxe6kNVCsMNb2A7BOtavkl8W89a/6jQXVeVA2h\nyounKcOKBuB2KndkAEcvUS584JfJaNmDUCnwk2EJszJAvXYLZoi30sa0kDVBKDbI\nkX7i3zVz5+fgG9TdxeFE98ueG7z67xfQ5Rvik2P2tGXSAn1VttoLmFZwB4hoxdBN\nvImc/CBHUTPoUQIDAQABo3MwcTAdBgNVHQ4EFgQUGt0EVRSJ/mOA7ASHmOzyC5nR\nbE4wUAYDVR0RBEkwR4IWaWRwLnNoaWJib2xldGgudHR1LmVkdYYtaHR0cHM6Ly9p\nZHAuc2hpYmJvbGV0aC50dHUuZWR1L2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\nBQUAA4IBAQAZQAkMw1LQhEroAOaurZEjaOwACJ0sAUQ7aM1jDEoy5DvJ6A9thRi5\n+GuveN3l6xh9W0srXCAQoqaImONOlMFF5w+qL83iGozfNBwrK5UEPnVQZnewZPDd\n/pB02ehS2nhwZOf4GHHR+SXsGhJ+w7qu10qFNE2p2BtqQPdWW4Wt76+J7bCqHhGb\noQb5rHmWTJWcROONosbFNaGMIv204ljvkxN4JPAtpGSyVcDYUElbZcUgWmAZ7Y4c\nvVObMDl/Nb5UoB1tj4zq8Gf1WpDj1iOpv9QkH9+X1jZWlrnTNqc5pTgXu9Jd4WtM\np/PLUr+DuI3pWSnU6Qfj7IpU/pTFoIOR"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Texas Tech University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ttu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Texas Tech University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://crowd.nordu.net/shibboleth",
    {
      "entity_id": "https://crowd.nordu.net/shibboleth",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://crowd.nordu.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://crowd.nordu.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://crowd.nordu.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://crowd.nordu.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "NORDUnet Tools"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "NORDUnet Tools (confluence, jira)"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://crowd.nordu.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://crowd.nordu.net/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://crowd.nordu.net/Shibboleth.sso/DS/nordu.net",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://crowd.nordu.net/Shibboleth.sso/DS/kalmar2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://portal.nordu.net"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://portal.nordu.net"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "NORDUnet Project and Issue tracking tools (JIRA and Confluence)."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "NORDUnet Project and Issue tracking tools (JIRA and Confluence)."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NORDUnet Tools"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NORDUnet Tools"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "crowd.nordu.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJANmt8Ciw6kb/MA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2Nyb3dkLm5vcmR1Lm5ldDAeFw0xMDA1MzExMTI4MzVaFw0yMDA1MjgxMTI4\nMzVaMBoxGDAWBgNVBAMTD2Nyb3dkLm5vcmR1Lm5ldDCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAPX2dT9VdcfFwxu7VA00KB7MmJj43/ReptLZNF1qEIEY\nLurgE63gRpalC1RLNx40V0a692ae9vlUJwr5SSuPE///KcIGe7MqKYqxMNR0EVUM\ngkLl/Iws6X6IKPXZFg/WeE/C/cmU6OzaTwdPBmg360Ys9veUOnt/3/ddRhSGRlr/\nQhrFJwZpeRQG/G7f8wIrvVT6HvsY1QOjW6YV43fon8eMBFz1WV7dAAx4L5d1JXX3\nEH+vY6a1nRj98qZPXZ7MY4HBMS8uU/B2/zTN+N9DFBpbwHYWvZQynIviGrUlgGi6\nbDMJH2k+sTGgy9EGZcaAqb2AECMidmXJk3/nOsX5cFECAwEAAaM9MDswGgYDVR0R\nBBMwEYIPY3Jvd2Qubm9yZHUubmV0MB0GA1UdDgQWBBTvR6U7d9zdmqbIl+g3SLa9\n8CChvzANBgkqhkiG9w0BAQUFAAOCAQEAWvDhU3Tk+cCZoThs2I2HLChX7cEjsjz9\n3ZHdWbsgJzPS0xVAdoR1FraNf6PYUvZxbDhsoO2UEZS5IUyOxdWWuP2jaqUpVxY/\n1fSTQQbvOujO+fZzNhJ8nIy/4FgFDWWqABHbVTfGVzImcxC1AJoQ8jkU9Dio5dIl\nuKQCDz8fu1hbkQZ/NP53cNDkTV0t/bvRtEHGrOJYc1rEFRuTLSkPvItsGffWHhIC\nmCrhgP7LeIv2iiNK7qgbhaFRHXAs/JMXAc/Y4YD1renUQCA4cLPF679N4oixMvxD\nNeib9lWMnEYRIynoqQE3UXYnb3GDinEg/soKH73QAq0dyjcfuk30FA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=crowd.nordu.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "crowd.nordu.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJANmt8Ciw6kb/MA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2Nyb3dkLm5vcmR1Lm5ldDAeFw0xMDA1MzExMTI4MzVaFw0yMDA1MjgxMTI4\nMzVaMBoxGDAWBgNVBAMTD2Nyb3dkLm5vcmR1Lm5ldDCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAPX2dT9VdcfFwxu7VA00KB7MmJj43/ReptLZNF1qEIEY\nLurgE63gRpalC1RLNx40V0a692ae9vlUJwr5SSuPE///KcIGe7MqKYqxMNR0EVUM\ngkLl/Iws6X6IKPXZFg/WeE/C/cmU6OzaTwdPBmg360Ys9veUOnt/3/ddRhSGRlr/\nQhrFJwZpeRQG/G7f8wIrvVT6HvsY1QOjW6YV43fon8eMBFz1WV7dAAx4L5d1JXX3\nEH+vY6a1nRj98qZPXZ7MY4HBMS8uU/B2/zTN+N9DFBpbwHYWvZQynIviGrUlgGi6\nbDMJH2k+sTGgy9EGZcaAqb2AECMidmXJk3/nOsX5cFECAwEAAaM9MDswGgYDVR0R\nBBMwEYIPY3Jvd2Qubm9yZHUubmV0MB0GA1UdDgQWBBTvR6U7d9zdmqbIl+g3SLa9\n8CChvzANBgkqhkiG9w0BAQUFAAOCAQEAWvDhU3Tk+cCZoThs2I2HLChX7cEjsjz9\n3ZHdWbsgJzPS0xVAdoR1FraNf6PYUvZxbDhsoO2UEZS5IUyOxdWWuP2jaqUpVxY/\n1fSTQQbvOujO+fZzNhJ8nIy/4FgFDWWqABHbVTfGVzImcxC1AJoQ8jkU9Dio5dIl\nuKQCDz8fu1hbkQZ/NP53cNDkTV0t/bvRtEHGrOJYc1rEFRuTLSkPvItsGffWHhIC\nmCrhgP7LeIv2iiNK7qgbhaFRHXAs/JMXAc/Y4YD1renUQCA4cLPF679N4oixMvxD\nNeib9lWMnEYRIynoqQE3UXYnb3GDinEg/soKH73QAq0dyjcfuk30FA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=crowd.nordu.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://crowd.nordu.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://crowd.nordu.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://crowd.nordu.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://crowd.nordu.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://crowd.nordu.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://crowd.nordu.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://crowd.nordu.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://crowd.nordu.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://crowd.nordu.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://crowd.nordu.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://oala-runtime.eastleigh.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lc@eastleigh.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Eastleigh College Learning Centre"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kennedy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ikennedy@eastleigh.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://oala-runtime.eastleigh.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-03-29T10:34:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://oala-runtime.eastleigh.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://oala-runtime.eastleigh.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "eastleigh.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkCgAwIBAgIIFsnOesAaesswDQYJKoZIhvcNAQEFBQAwQzEaMBgGA1UE\n\t\t\t\t\t\tCgwRRWFzdGxlaWdoIENvbGxlZ2UxJTAjBgNVBAMMHG9hbGEtcnVudGltZS5lYXN0\n\t\t\t\t\t\tbGVpZ2guYWMudWswHhcNMTIwMjI0MTYxMzQ2WhcNMjIwMjI0MTYxMzQ2WjBDMRow\n\t\t\t\t\t\tGAYDVQQKDBFFYXN0bGVpZ2ggQ29sbGVnZTElMCMGA1UEAwwcb2FsYS1ydW50aW1l\n\t\t\t\t\t\tLmVhc3RsZWlnaC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAJbpGbVq+3W87P3LSE9yvoZPJWOQpvodKGXQvZpgCpw42A7z9w3DiW36ssWDOhbN\n\t\t\t\t\t\trS+E1Inklx6meSmLCuTYhRVNL8xBnaqL6zWfIHnO00ELD5ZhOMWzKQQ5RNm6HbF5\n\t\t\t\t\t\t8SdPVqbwt4IVq2NhqvH7Om5AruMBXp/S8r4v8ajgnp85gZ7XgGNoCacSi6M5ykfr\n\t\t\t\t\t\tw5LMOlE7vXHF9ysFyGLPcidUZvE4QDChNxX0FZWcqHwfAhuj1CEunry9STQHIXkr\n\t\t\t\t\t\typcE3I5Xg4OA9qRC4J7wyHkG5uiJImjYHcmnM/3EzbL94wT9Gd8ddYrlN9E9tray\n\t\t\t\t\t\tOdsf7pPpbVAmKNNxeQo3FocCAwEAAaNQME4wHQYDVR0OBBYEFJDbbznYPa+ALKbL\n\t\t\t\t\t\tIigXdI0UE13lMB8GA1UdIwQYMBaAFJDbbznYPa+ALKbLIigXdI0UE13lMAwGA1Ud\n\t\t\t\t\t\tEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAGkxUw38I8xJdFvH3/j+GY1GulB5\n\t\t\t\t\t\tvAN7o+JTPxXToGx9O6mQvv5ZKT/TmVmGHz7CdeToVW1JWICQGCm9pXCjIZoJs3cJ\n\t\t\t\t\t\t+hdHncZrUPm0ZkibNNd2Ix4TSs7NAm0aaYlgTR37+8Gpl67/rjm7psuUZL5UBtST\n\t\t\t\t\t\tSxWzN84a0Zpsx8lZvkt0aVCY3jJpbmYRaDalkG1DJAEH6AqdF18GmTS9c8CN75uB\n\t\t\t\t\t\tLF7eq7Pbu0wySSUW9TyRqC5YHK1CFsrNr3+7Cwtj+A+UWPs0JmNoCyYUr41R+Xic\n\t\t\t\t\t\tl43JJ3g6lAOr8U1MkvjzwnA93CFJC1S1PSxJq8j7OXwCunqqpFrME8sqrcw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWDCCAkCgAwIBAgIIFsnOesAaesswDQYJKoZIhvcNAQEFBQAwQzEaMBgGA1UE\n\t\t\t\t\t\tCgwRRWFzdGxlaWdoIENvbGxlZ2UxJTAjBgNVBAMMHG9hbGEtcnVudGltZS5lYXN0\n\t\t\t\t\t\tbGVpZ2guYWMudWswHhcNMTIwMjI0MTYxMzQ2WhcNMjIwMjI0MTYxMzQ2WjBDMRow\n\t\t\t\t\t\tGAYDVQQKDBFFYXN0bGVpZ2ggQ29sbGVnZTElMCMGA1UEAwwcb2FsYS1ydW50aW1l\n\t\t\t\t\t\tLmVhc3RsZWlnaC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAJbpGbVq+3W87P3LSE9yvoZPJWOQpvodKGXQvZpgCpw42A7z9w3DiW36ssWDOhbN\n\t\t\t\t\t\trS+E1Inklx6meSmLCuTYhRVNL8xBnaqL6zWfIHnO00ELD5ZhOMWzKQQ5RNm6HbF5\n\t\t\t\t\t\t8SdPVqbwt4IVq2NhqvH7Om5AruMBXp/S8r4v8ajgnp85gZ7XgGNoCacSi6M5ykfr\n\t\t\t\t\t\tw5LMOlE7vXHF9ysFyGLPcidUZvE4QDChNxX0FZWcqHwfAhuj1CEunry9STQHIXkr\n\t\t\t\t\t\typcE3I5Xg4OA9qRC4J7wyHkG5uiJImjYHcmnM/3EzbL94wT9Gd8ddYrlN9E9tray\n\t\t\t\t\t\tOdsf7pPpbVAmKNNxeQo3FocCAwEAAaNQME4wHQYDVR0OBBYEFJDbbznYPa+ALKbL\n\t\t\t\t\t\tIigXdI0UE13lMB8GA1UdIwQYMBaAFJDbbznYPa+ALKbLIigXdI0UE13lMAwGA1Ud\n\t\t\t\t\t\tEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAGkxUw38I8xJdFvH3/j+GY1GulB5\n\t\t\t\t\t\tvAN7o+JTPxXToGx9O6mQvv5ZKT/TmVmGHz7CdeToVW1JWICQGCm9pXCjIZoJs3cJ\n\t\t\t\t\t\t+hdHncZrUPm0ZkibNNd2Ix4TSs7NAm0aaYlgTR37+8Gpl67/rjm7psuUZL5UBtST\n\t\t\t\t\t\tSxWzN84a0Zpsx8lZvkt0aVCY3jJpbmYRaDalkG1DJAEH6AqdF18GmTS9c8CN75uB\n\t\t\t\t\t\tLF7eq7Pbu0wySSUW9TyRqC5YHK1CFsrNr3+7Cwtj+A+UWPs0JmNoCyYUr41R+Xic\n\t\t\t\t\t\tl43JJ3g6lAOr8U1MkvjzwnA93CFJC1S1PSxJq8j7OXwCunqqpFrME8sqrcw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Eastleigh College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.eastleigh.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eastleigh College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso.man.poznan.pl/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "SSO Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso@man.poznan.pl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "PSNC"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.man.poznan.pl/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.pionier.net.pl/en/index.php?page=rps"
              }
            ],
            "registration_instant": "2014-02-11T00:00:00Z",
            "registration_authority": "https://aai.pionier.net.pl",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAIiHfqRGuhN+o7Ms3VgcU94Sn4aaMA0GCSqGSIb3DQEB\nBQUAMBwxGjAYBgNVBAMTEXNzby5tYW4ucG96bmFuLnBsMB4XDTEyMDIxNzE1MDAx\nNVoXDTMyMDIxNzE1MDAxNVowHDEaMBgGA1UEAxMRc3NvLm1hbi5wb3puYW4ucGww\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCCsfe3J1Kxj8jL697Vw7r7\ntGu6li0IDa/8JecsxjRTFkMxl/6qrzs5A8x1i1jWO3Q58xYMjgrlBp4cevH1dbHn\nQxZ2o/FaE5Ww2eHsFmeR7nLZSJN3LukcxEjtA40evwEZPN+p/4DZD/bBMh7Hyw9s\n8Y6YdYCF0xNLUwEFhHo2yDVPZYhWrC6yx6fwY5/NXZZCA9b91W8mRfWTGPFBY9PK\ndVS0m923P/CkudYG3o3+w34gpxkYHca3i6syI9zHOvsE1GRdbwHW1xcqRWMLece+\ndhxL/I1AnlpCvuLqG0CpMxn5nAy19QqoODrH9zVtZeOUISIzb0UhSrlk29fFe6CV\nAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEXNzby5tYW4ucG96bmFuLnBshihodHRwczov\nL3Nzby5tYW4ucG96bmFuLnBsL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTroN0C\n2g3I0ikT1kP7hjwsQbJpTDANBgkqhkiG9w0BAQUFAAOCAQEAUQXUBQQIg4UXJrCp\n9H0zd65C58uH1fAdcwjYcZUojsftYg5Uc2OIH/TVq2rcB+ZiC9ZRx1x677+WuRq5\nlA85YUQHsPYKD/mOsxU69nIdkFuJcICSZIYBQA4bq4WAsWaD4Z75doqgR2MGoQBb\nvWAAetQH90HyK98XR37vQgkndTHSt+bvwH+9M8URXk10jC4wqwYeVd9bGbIi2opk\nBRF64iGC5zaSIWqhdfyv6XZH7lmIHdydCn/PMD0bAmUDB9oKb4Wr4Dk/52xeErus\nPxMzLl9jowOTlfNZJtlecP1jazd+Hzpen8DHldiRWsH3Hel12OapCsiVfKlb1yrx\nIxWl2w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "man.poznan.pl"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.man.poznan.pl/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.man.poznan.pl/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.man.poznan.pl/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.man.poznan.pl/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.man.poznan.pl/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso.man.poznan.pl/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.man.poznan.pl/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sso.man.poznan.pl/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.man.poznan.pl/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.man.poznan.pl/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.man.poznan.pl/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "man.poznan.pl"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The PSNC Identity Provider is used by PSNC staff members."
                  },
                  {
                    "lang": "pl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Centralny Punkt Logowania dla pracownik\u00f3w PCSS."
                  }
                ],
                "logo": [
                  {
                    "text": "https://sso.man.poznan.pl/logo/psnc.png",
                    "lang": "en",
                    "height": "110",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "300"
                  },
                  {
                    "text": "https://sso.man.poznan.pl/logo/pcss.png",
                    "lang": "pl",
                    "height": "110",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "300"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PSNC - Poznan Supercomputing and Networking Center"
                  },
                  {
                    "lang": "pl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PCSS - Pozna\u0144skie Centrum Superkomputerowo-Sieciowe"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "man.poznan.pl"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:52.41180,16.91625"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:52.41160,16.91610"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:52.41400,16.89900"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:52.43140,16.80900"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:52.41140,16.91778"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:52.40840,16.90830"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:52.40680,16.95320"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "150.254.148.16/28"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "150.254.149.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "150.254.170.64/26"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "150.254.170.128/25"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "150.254.166.56/32"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "150.254.166.63/32"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "150.254.169.99/32"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "150.254.169.100/32"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:808:0:1000::/64"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:808:0:6::/64"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:808:2:3003::/64"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAIiHfqRGuhN+o7Ms3VgcU94Sn4aaMA0GCSqGSIb3DQEB\nBQUAMBwxGjAYBgNVBAMTEXNzby5tYW4ucG96bmFuLnBsMB4XDTEyMDIxNzE1MDAx\nNVoXDTMyMDIxNzE1MDAxNVowHDEaMBgGA1UEAxMRc3NvLm1hbi5wb3puYW4ucGww\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCCsfe3J1Kxj8jL697Vw7r7\ntGu6li0IDa/8JecsxjRTFkMxl/6qrzs5A8x1i1jWO3Q58xYMjgrlBp4cevH1dbHn\nQxZ2o/FaE5Ww2eHsFmeR7nLZSJN3LukcxEjtA40evwEZPN+p/4DZD/bBMh7Hyw9s\n8Y6YdYCF0xNLUwEFhHo2yDVPZYhWrC6yx6fwY5/NXZZCA9b91W8mRfWTGPFBY9PK\ndVS0m923P/CkudYG3o3+w34gpxkYHca3i6syI9zHOvsE1GRdbwHW1xcqRWMLece+\ndhxL/I1AnlpCvuLqG0CpMxn5nAy19QqoODrH9zVtZeOUISIzb0UhSrlk29fFe6CV\nAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEXNzby5tYW4ucG96bmFuLnBshihodHRwczov\nL3Nzby5tYW4ucG96bmFuLnBsL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTroN0C\n2g3I0ikT1kP7hjwsQbJpTDANBgkqhkiG9w0BAQUFAAOCAQEAUQXUBQQIg4UXJrCp\n9H0zd65C58uH1fAdcwjYcZUojsftYg5Uc2OIH/TVq2rcB+ZiC9ZRx1x677+WuRq5\nlA85YUQHsPYKD/mOsxU69nIdkFuJcICSZIYBQA4bq4WAsWaD4Z75doqgR2MGoQBb\nvWAAetQH90HyK98XR37vQgkndTHSt+bvwH+9M8URXk10jC4wqwYeVd9bGbIi2opk\nBRF64iGC5zaSIWqhdfyv6XZH7lmIHdydCn/PMD0bAmUDB9oKb4Wr4Dk/52xeErus\nPxMzLl9jowOTlfNZJtlecP1jazd+Hzpen8DHldiRWsH3Hel12OapCsiVfKlb1yrx\nIxWl2w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PSNC - Poznan Supercomputing and Networking Center"
          },
          {
            "lang": "pl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PCSS - Pozna\u0144skie Centrum Superkomputerowo-Sieciowe"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.man.poznan.pl/online/en/"
          },
          {
            "lang": "pl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.man.poznan.pl/online/pl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Poznan Supercomputing and Networking Center"
          },
          {
            "lang": "pl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Pozna\u0144skie Centrum Superkomputerowo-Sieciowe"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.univ-bpclermont.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Fed-Admin@univ-bpclermont.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.univ-bpclermont.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-04-16T09:16:56Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univ-bpclermont.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univ-bpclermont.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.univ-bpclermont.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-bpclermont.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-bpclermont.fr/"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Clermont-Ferrand 2 - Blaise Pascal"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Clermont-Ferrand 2 - Blaise Pascal"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUf8Tye3TWDTMkKybmr2WCtI8Rg7gwDQYJKoZIhvcNAQEF\nBQAwITEfMB0GA1UEAxMWaWRwLnVuaXYtYnBjbGVybW9udC5mcjAeFw0wODExMjUx\nMzE4MDlaFw0yODExMjUxMzE4MDlaMCExHzAdBgNVBAMTFmlkcC51bml2LWJwY2xl\ncm1vbnQuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCgq4L+M8Cr\nxnSB7fZmGR8wgCnDx6DxFJqAwk45muj/RFAijOjAM9i2iUmjBhpAQjatnybBaGk4\nxjLD/TbzQzpXZMzqLpRYgmvqLQ7RG6PabpLDWz+s/oneLFWtvCzFmyRQXe72Kum5\nFCeG5Jz9uDniAwdv2u5dG82mr+nO7wP+95GwlcYzs9bVfJZ3L0vBZ0wu4bqAIHAQ\n+PMX0FVX/2bmqBWjP1XaJjqIk0UnQJ7//Ccg3y888MRyIcg2d8P4OiG4VvhUl7bL\nQygrvTr0yqrw2XFHdhMAwV7P39Y84+/rAFPg94iiSesPOzZmgv4YvGcsvLjIWwa8\nPi5gOMtJQXqFAgMBAAGjczBxMFAGA1UdEQRJMEeCFmlkcC51bml2LWJwY2xlcm1v\nbnQuZnKGLWh0dHBzOi8vaWRwLnVuaXYtYnBjbGVybW9udC5mci9pZHAvc2hpYmJv\nbGV0aDAdBgNVHQ4EFgQU9VjTe9bu+B0flgm74MpOhm2yVJYwDQYJKoZIhvcNAQEF\nBQADggEBADRoaAXNoIfymTDg2CETOFI/fhK8Sok1vAQo7PJjjeq2Pue965wgWT4Q\nsJxY9lQdPKlZRonso2ABtY0vNvlB2oQK5Trz8QckUp8MEXQhSDK2EyTc8/jXLae9\n4jU4qjGrD4f6h177SSimK2tmesTRJ57EUZd/Mpoy/cpWMKfp9tx6Pe6w5MYVOSpk\niqa6wc50EWUt8/EqtC3V45+jo/6mJx1ZPQI2uPP9BK1p+UdljUKZqmQa0ZZJ4IxW\nUP/k2YNC7B4piqvd0HLqVEDHQmmeiwSPLlFsGozwdYZ+FUuXzJoMguhu3KMw8qV4\nP69e+LdcHzrBqln1xmrkY/MMjTqnJ3E="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Clermont-Ferrand 2 - Blaise Pascal"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-bpclermont.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Clermont-Ferrand 2 - Blaise Pascal"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.aco.net/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Admin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:admin@aco.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ACOnet"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Federation Operator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:eduid@aco.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "eduID.at"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.aco.net/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2009-11-23T13:36:52Z",
            "registration_authority": "http://eduid.at",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAOmKQ6SgpmK/8vtQmiMBkQ1+yZ1XMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2lkcC5hY28ubmV0MB4XDTA5MTEwMzA5MjIzOFoXDTI5\nMTEwMzA5MjIzOFowFjEUMBIGA1UEAxMLaWRwLmFjby5uZXQwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDtABRog8uPB0h8aNilZFdYFII8iLgBkDQoAXH1\nAIMLVP8dDaK6dRnwyBfrq4dfEH/BqQxxpmASXK1s6O1YbZcx5X9M48yzzpdKFkGU\n3SIdu4lLNYtR1nfePX0120NTBk9tzCR0R9mmV6YMajFQ8YQkyDzwboTTyILx1E70\nRsFIvmx59QDtdPjP8fi2X5ZsRb1kOFDKeJlI15/SQkWAJGBIjtb7Dhs5K6jlp2lh\nT3R5G+faRrC761qR0ddcmh6qkq6fBGRRydxn85N5L6XkoxfD2evTSEkTB2sKn8UG\ncDNupxjPSD6PIPQhDuQlDyg6sFcMj1N6/PvH6FDhca/WZ72hAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2lkcC5hY28ubmV0hiJodHRwczovL2lkcC5hY28ubmV0L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBStGKLf2/BAuxR9PAnCFKg1lXw+azANBgkqhkiG\n9w0BAQUFAAOCAQEAcYbfERAghPNJSFLnx4SYwmh19ln2j67IdFaEzGnZ10oNtMF5\nMXbJXqLN/JCEj7QLjRQ7PkhCpIUnKJ14ELCt/7ChnxfUHqwiYDyB3Vtm+FIlaNnJ\nBhet+AJpiVyb6xce6tLQnQ/UwNmPozPjOwEbuKhz5dO1uftI38FT4hBYzsdo76Hm\nrS4WKwBzWV43OcNVhv2sgDbsxGIi5CGnQm6POICQhXAgvG2BGH+77jwM0PVFNP1b\nCQX+4Ig0MV2Y4WCgu3y2IxpSjGtnHxRxLMyNFblaP0MTo8BROcC74n0jKvnSVXyj\nnWGBQ+FiDBdPEO2Ny3SNjJ3B67hbmXBJSEJw9g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aco.net"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.aco.net:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.aco.net:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.aco.net/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.aco.net/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.aco.net:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.aco.net/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.aco.net/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.aco.net/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.aco.net/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.aco.net/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.aco.net:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.aco.net:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aco.net"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.aco.net/organisation.html"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.aco.net/organisation.html?L=1"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider des ACOnet-Teams"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for ACOnet staff"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.aco.net/logos/137x60.gif",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "137"
                  },
                  {
                    "text": "https://eduid.at/style/aconet16x16.gif",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ACOnet Team"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ACOnet staff"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "aco.net"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:48.2132234,16.3581464"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.153.174.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAOmKQ6SgpmK/8vtQmiMBkQ1+yZ1XMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2lkcC5hY28ubmV0MB4XDTA5MTEwMzA5MjIzOFoXDTI5\nMTEwMzA5MjIzOFowFjEUMBIGA1UEAxMLaWRwLmFjby5uZXQwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDtABRog8uPB0h8aNilZFdYFII8iLgBkDQoAXH1\nAIMLVP8dDaK6dRnwyBfrq4dfEH/BqQxxpmASXK1s6O1YbZcx5X9M48yzzpdKFkGU\n3SIdu4lLNYtR1nfePX0120NTBk9tzCR0R9mmV6YMajFQ8YQkyDzwboTTyILx1E70\nRsFIvmx59QDtdPjP8fi2X5ZsRb1kOFDKeJlI15/SQkWAJGBIjtb7Dhs5K6jlp2lh\nT3R5G+faRrC761qR0ddcmh6qkq6fBGRRydxn85N5L6XkoxfD2evTSEkTB2sKn8UG\ncDNupxjPSD6PIPQhDuQlDyg6sFcMj1N6/PvH6FDhca/WZ72hAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2lkcC5hY28ubmV0hiJodHRwczovL2lkcC5hY28ubmV0L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBStGKLf2/BAuxR9PAnCFKg1lXw+azANBgkqhkiG\n9w0BAQUFAAOCAQEAcYbfERAghPNJSFLnx4SYwmh19ln2j67IdFaEzGnZ10oNtMF5\nMXbJXqLN/JCEj7QLjRQ7PkhCpIUnKJ14ELCt/7ChnxfUHqwiYDyB3Vtm+FIlaNnJ\nBhet+AJpiVyb6xce6tLQnQ/UwNmPozPjOwEbuKhz5dO1uftI38FT4hBYzsdo76Hm\nrS4WKwBzWV43OcNVhv2sgDbsxGIi5CGnQm6POICQhXAgvG2BGH+77jwM0PVFNP1b\nCQX+4Ig0MV2Y4WCgu3y2IxpSjGtnHxRxLMyNFblaP0MTo8BROcC74n0jKvnSVXyj\nnWGBQ+FiDBdPEO2Ny3SNjJ3B67hbmXBJSEJw9g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ACOnet Team"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ACOnet staff"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aco.net/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aco.net/?L=1"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ACOnet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ACOnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://its-pd0030.ad.umu.se/shibboleth",
    {
      "entity_id": "https://its-pd0030.ad.umu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/SU",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/KI",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/kth",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/Loginy",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/Loginx",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/HIG",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "its-pd0030.ad.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID/TCCAuWgAwIBAgIJANnuq9lnXo3DMA0GCSqGSIb3DQEBBQUAMIGUMQswCQYD\nVQQGEwJTRTEVMBMGA1UECAwMVmFzdGVyYm90dGVuMQ0wCwYDVQQHDARVbWVhMQww\nCgYDVQQKDANJVFMxDDAKBgNVBAsMA0lUUzEdMBsGA1UEAwwUaXRzLXBkMDAzMC5h\nZC51bXUuc2UxJDAiBgkqhkiG9w0BCQEWFXBldGVyLmhvbG1AYWRtLnVtdS5zZTAe\nFw0xMjAzMDUxNTE2MjBaFw0xNTAxMTcxNTE2MjBaMIGUMQswCQYDVQQGEwJTRTEV\nMBMGA1UECAwMVmFzdGVyYm90dGVuMQ0wCwYDVQQHDARVbWVhMQwwCgYDVQQKDANJ\nVFMxDDAKBgNVBAsMA0lUUzEdMBsGA1UEAwwUaXRzLXBkMDAzMC5hZC51bXUuc2Ux\nJDAiBgkqhkiG9w0BCQEWFXBldGVyLmhvbG1AYWRtLnVtdS5zZTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAMQc2UGad/hBaY4f4DpqAqlWEPd4kLXfa5pQ\n8BxNDW7CdHa1PZywE+x3qrEnc7ee5YKi8MljzOU3y5cnmSRuIzuTyjl2tf4/p1Z6\nnE7MvGnuqS69XK8bytAS6J2pNCBmRcKahn53o6pIAgq9BeFKa56ao3KJWyzE6Rxl\nrlgO4KnbBDERb0deGkfRZnVdRTBNNH61L9N1Qt32uKWnW8SnWk7+0jOCZTv+xbn+\nmlP11urE9Pzard/QR+y3VscQTGSjOlcQdf/E/ADcKQKXFia6FVCPXKJi3aMrn8Zz\nUWGI+qbJ6BorsassnZsriv0CurcYIEX/NkfW2FZetgCdX0pzmj8CAwEAAaNQME4w\nHQYDVR0OBBYEFIibejVm82LsZawokaVHs5NcwRlWMB8GA1UdIwQYMBaAFIibejVm\n82LsZawokaVHs5NcwRlWMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEB\nAFkwpLwvpKnotAOWxSx+ilAmv/DHA9SrTAGYQQT1P1qjpmwVAOCUHODx9iN0CBeM\ngVsjTRdImIYlo+LrwauT81kwf80XmLte4JqagelFcPEA5TmbktPKXHv1tCBje/uJ\n8nZ2o8eOZ5wKv5zp8Xxn2Imchg9DAtLzbaTv53JtPtqI+eJik2tBmfklvK55ajLO\n9ubWdsA44GhSnvWyIaTGhXfzoyQ8ZJ6idJDNOwA5u71tAmmUmkOoF5d0+Yj+J43R\n+J9Yt3EiCcvGwQ14r54USZEBGw+rGix8uOMh0fZZzE0yLpMhz7+SJ07lLAFBmG+T\nOIILi2tdLnboWi1QOOeX9+Q="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=peter.holm@adm.umu.se,CN=its-pd0030.ad.umu.se,OU=ITS,O=ITS,L=Umea,ST=Vasterbotten,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://its-pd0030.ad.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib.sou.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "christb@sou.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brad Christ"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "whipp@sou.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David Whipp"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.sou.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.sou.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.sou.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.sou.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.sou.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.sou.edu/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.sou.edu/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sou.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.sou.edu/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Southern Oregon University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "A public liberal arts university."
                  }
                ],
                "logo": [
                  {
                    "text": "https://shib.sou.edu/SOU-Logo.jpg",
                    "lang": "en",
                    "height": "96",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "96"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.sou.edu/policies/Electronic-Commerce-Privacy.pdf"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUHi1qf8ZHuuT85F7NR8j74fvWWqIwDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMc2hpYi5zb3UuZWR1MB4XDTExMDUxMjIwMDkxNVoXDTMx\nMDUxMjIwMDkxNVowFzEVMBMGA1UEAxMMc2hpYi5zb3UuZWR1MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAk9NC9AvTLSwAdcAhjkvhwGeI8muAGSCK1vVU\nFjMf0PpcizEnW2MIGV44eOCEJF3gzyBYKgkIiiMzRDpydmM3IrkiTt7s/jTsez7e\nR8GRgzjJcMsjKZH2TBGVziggs4FChv1YL3wzbVCLimZq23cj5CBQw2IiXzo/KIqE\n9xNqqg/o0e/Gdu0H15hajkVGiFxjzcERw/iy6JIOg9PyLGnTRuu6yOkacIvV78wf\nHdap/cj6TZQr//5Qs5yCebeekh5nBtOpUTdop21CbOdeKpqX4IrsLP8lBgFkm+rl\noqIK365tbY6Qjx5Bw8PYEc5zMP2DRLLq0qqnm19yVOeucfHm7QIDAQABo18wXTA8\nBgNVHREENTAzggxzaGliLnNvdS5lZHWGI2h0dHBzOi8vc2hpYi5zb3UuZWR1L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBRm7aYfeD2Lba31XzLlLLl4ojnkoTANBgkq\nhkiG9w0BAQUFAAOCAQEARUceV1FxV09Vmfg9fX+wQpFxkSLioz+0ColYNpbsbAu/\nMcxgql5hoHQIeVpFtJio2UOGEwk9gl1ZtJz8aBQ/fs0kQKf7XxWRtzz4V0xnPznE\nKbWbntYu+84X6N+d51olQ5DRBp120dBBrRsGgDxRX+l/dBneIu1Ht5+YSl7phBIb\niypEYN6U2M5cN/5un4rR6NI0950Fg6YizIh58SkPVNxkRTNyQC/Djxmz44q05oKz\nV6vQDuNw1E/38wMn3hRvr+xDshTOrgTAAdmO0g+Fnn2ewD2lBow/6aqaXPUqOqxB\nuoe4SJwHwKvWq/ZZBvDfR9GwlXaDOR9yXXDLLIcYaA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://shib.sou.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Southern Oregon University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sou.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Southern Oregon University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.e-lawstudent.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Naylor"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:simon@e-lawstudent.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Naylor"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:simon@e-lawstudent.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.e-lawstudent.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "e-lawstudent"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.e-lawstudent.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e-lawstudent"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.elawstudent.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.elawstudent.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.elawstudent.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.elawstudent.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.elawstudent.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.elawstudent.com/Shibboleth.sso/WAYF/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDADCCAeigAwIBAgIJAJlseYQQY0a6MA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\n\t\t\t\t\t\tBAMTE3M0MC5jYWxsaWR1czAwMS5uZXQwHhcNMTEwODI5MDk0OTI5WhcNMjEwODI2\n\t\t\t\t\t\tMDk0OTI5WjAeMRwwGgYDVQQDExNzNDAuY2FsbGlkdXMwMDEubmV0MIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1eUIR/msK6qUkytHjlDDNix9MOeBQYFc\n\t\t\t\t\t\tzz5ZPvTepv3We7/eKWU2mEkISXjuLproiSGl7gZqDP9mxeqkZXj8oyOpZRgFOtWn\n\t\t\t\t\t\tEzmAIH7LWJPClMcupHw9RL2IZ9fNOfqVjXiVnQYefYZg4yT5jVJNDIgLnxQRqw9M\n\t\t\t\t\t\txPllqf6kIsNqzTA6QuMzyPJtSQ3OreU3pxFBj+sRHwlcXQkWdNLS3Axc7BpMFswK\n\t\t\t\t\t\tOHUva8CT1ZPM2lblcNxgXpzLzFGemW/gwOlXVJvpWiEzjvsX2Cv5VTG5iwyOTraD\n\t\t\t\t\t\tc3bGtUbAnyYRrIZIX8Pbide8htHOkRlzDWlKyNBQYMgspbGyuu899wIDAQABo0Ew\n\t\t\t\t\t\tPzAeBgNVHREEFzAVghNzNDAuY2FsbGlkdXMwMDEubmV0MB0GA1UdDgQWBBTu83Y4\n\t\t\t\t\t\tlye8+8s6OPUR7SK51J0jfTANBgkqhkiG9w0BAQUFAAOCAQEAYiq3EmHidGJT7i8l\n\t\t\t\t\t\tvi/U4H+pi3ih8kSCu/TNZ2QLbjZYgrVJzQGOZImHZE8LDV2aNBvbiM/Il3Va52F4\n\t\t\t\t\t\tNEHbx4dIlEx4SEqeaSd0FUyvOdv79JgvoIk3pMbox0TLeowslIbSkmrW00Y6gKOk\n\t\t\t\t\t\tr7doWnBKNiAjDU6s37sUiOl6UUIxtJI4PcM7oed7T7vkR72iyK/m1Pw+E84Tu8wF\n\t\t\t\t\t\t77NVal8Al4NNNeWepX7XLqifjoZ7rgdeAr9LWAakjnNs0r++hxOaKGdB6UBA3bDE\n\t\t\t\t\t\tKmpxYZDCeeCRX2kzgxVvOCSh/EIu6FSVtYogyMJcTJhfjpIP9c++PnmKaXvvrdku\n\t\t\t\t\t\tk7tDPQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.elawstudent.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.elawstudent.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.elawstudent.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.elawstudent.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.elawstudent.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.elawstudent.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.elawstudent.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.elawstudent.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.elawstudent.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.elawstudent.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.teicrete.gr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "TEI of Crete Network Management Center"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "noc@teicrete.gr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.teicrete.gr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-en-1.1.0.pdf"
              },
              {
                "lang": "el",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://aai.grnet.gr/static/policy/policy-el-1.1.0.pdf"
              }
            ],
            "registration_authority": "http://aai.grnet.gr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIJAIL7nMA9vRODMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\n                            BAMTD2lkcC50ZWljcmV0ZS5ncjAeFw0xNDA0MTAxNTQ2NDlaFw0xOTEwMDExNTQ2\n                            NDlaMBoxGDAWBgNVBAMTD2lkcC50ZWljcmV0ZS5ncjCCASIwDQYJKoZIhvcNAQEB\n                            BQADggEPADCCAQoCggEBAL+XJx6luxBMILP1Fhne5BNBkBDtRCXKbWMbZ23Y9RQU\n                            AiaKYudm0Iv1BYLhl/S+tNQzqNJuMhgrQohsA60y2zfZ1yfsIUQkzynZ5PicyY9J\n                            f24GbIXQbzzM7axr/485VoMsQ4CXoMHdl6/1k/96ZmmHkd7iihjL7tAP7Dr7Ir8z\n                            IIUdkJbCcDPBwC/Vt+s6r6ut9f5Tt/ZvzByoJlmt5JFW/NQ8qlLx3JTalf5aQQIX\n                            ARIf+c78WSqYrLga+4V7g9oiwojOsl8p3fmPqnIvWn8erCQFnd1ygscaiPbkTzYl\n                            n/haRW3/ALiF/uy8PHwbdYCkRww9tidlb/jZ2e23sqcCAwEAAaNlMGMwQgYDVR0R\n                            BDswOYIPaWRwLnRlaWNyZXRlLmdyhiZodHRwczovL2lkcC50ZWljcmV0ZS5nci9p\n                            ZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUH4T1XBWWqDwvXJkpM1ocnGJJp+QwDQYJ\n                            KoZIhvcNAQEFBQADggEBAIsKG1Zto879oq2g0+QhUGuPi2JeB6CesyI+Ey/yxflm\n                            WvLndZVTd7NGzLBskyIZhaHcxGlWsxWzqMRGUzKctqHfjp0q16gBs8svuGlrpy2l\n                            FIZ+prAhPR9R0xLRGevFOd9WbaSXX41u1o8KWCsUVKLWfR8bc+Mz61Ujd+8X6meg\n                            LVMCOFMBp7YVze8y53lYYDhwh4iGNAOZ1KNgdFxbB4vLDCdCvdmRDnlg0uzAsAv5\n                            wWXCU5mHjk5tflcoFeQb6t9U97O62wXqfngJhbLoC8slL5btHwywdds9azTnYir1\n                            5cjli40qHZcQIA/zp9rcWC4ZgUJefHCQM62M6DuQpWU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "teicrete.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.teicrete.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "chania.teicrete.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "staff.teicrete.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nmc.teicrete.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "epp.teicrete.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cs.teicrete.gr"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.teicrete.gr:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.teicrete.gr:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.teicrete.gr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.teicrete.gr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.teicrete.gr/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.teicrete.gr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.teicrete.gr:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.teicrete.gr:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "teicrete.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.teicrete.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "chania.teicrete.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "staff.teicrete.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nmc.teicrete.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "epp.teicrete.gr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cs.teicrete.gr"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.teicrete.gr/"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.teicrete.gr/en"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.nmc.teicrete.gr/sites/default/files/images/logo-teicrete-350x76.png",
                    "height": "350",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "76"
                  },
                  {
                    "text": "https://www.nmc.teicrete.gr/sites/default/files/images/logo-teicrete-80x60.png",
                    "height": "80",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  },
                  {
                    "text": "https://www.nmc.teicrete.gr/sites/default/files/images/logo-teicrete-16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Technological Educational Institute of Crete"
                  },
                  {
                    "lang": "el",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03b9\u03ba\u03cc \u0395\u03ba\u03c0\u03b1\u03b9\u03b4\u03b5\u03c5\u03c4\u03b9\u03ba\u03cc \u038a\u03b4\u03c1\u03c5\u03bc\u03b1 \u039a\u03c1\u03ae\u03c4\u03b7\u03c2"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "teicrete.gr"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "teiher.gr"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:35.318317,25.102108"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.95.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:648:2c10::/48"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "194.177.198.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.251.48.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.92.145.243"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "194.219.126.50"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "62.1.154.40/29"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "213.16.245.205"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "194.219.117.209"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "62.1.154.200/29"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.92.77.232"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "62.1.195.171"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.92.28.48/28"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIJAIL7nMA9vRODMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\n                            BAMTD2lkcC50ZWljcmV0ZS5ncjAeFw0xNDA0MTAxNTQ2NDlaFw0xOTEwMDExNTQ2\n                            NDlaMBoxGDAWBgNVBAMTD2lkcC50ZWljcmV0ZS5ncjCCASIwDQYJKoZIhvcNAQEB\n                            BQADggEPADCCAQoCggEBAL+XJx6luxBMILP1Fhne5BNBkBDtRCXKbWMbZ23Y9RQU\n                            AiaKYudm0Iv1BYLhl/S+tNQzqNJuMhgrQohsA60y2zfZ1yfsIUQkzynZ5PicyY9J\n                            f24GbIXQbzzM7axr/485VoMsQ4CXoMHdl6/1k/96ZmmHkd7iihjL7tAP7Dr7Ir8z\n                            IIUdkJbCcDPBwC/Vt+s6r6ut9f5Tt/ZvzByoJlmt5JFW/NQ8qlLx3JTalf5aQQIX\n                            ARIf+c78WSqYrLga+4V7g9oiwojOsl8p3fmPqnIvWn8erCQFnd1ygscaiPbkTzYl\n                            n/haRW3/ALiF/uy8PHwbdYCkRww9tidlb/jZ2e23sqcCAwEAAaNlMGMwQgYDVR0R\n                            BDswOYIPaWRwLnRlaWNyZXRlLmdyhiZodHRwczovL2lkcC50ZWljcmV0ZS5nci9p\n                            ZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUH4T1XBWWqDwvXJkpM1ocnGJJp+QwDQYJ\n                            KoZIhvcNAQEFBQADggEBAIsKG1Zto879oq2g0+QhUGuPi2JeB6CesyI+Ey/yxflm\n                            WvLndZVTd7NGzLBskyIZhaHcxGlWsxWzqMRGUzKctqHfjp0q16gBs8svuGlrpy2l\n                            FIZ+prAhPR9R0xLRGevFOd9WbaSXX41u1o8KWCsUVKLWfR8bc+Mz61Ujd+8X6meg\n                            LVMCOFMBp7YVze8y53lYYDhwh4iGNAOZ1KNgdFxbB4vLDCdCvdmRDnlg0uzAsAv5\n                            wWXCU5mHjk5tflcoFeQb6t9U97O62wXqfngJhbLoC8slL5btHwywdds9azTnYir1\n                            5cjli40qHZcQIA/zp9rcWC4ZgUJefHCQM62M6DuQpWU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Technological Educational Institute of Crete"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03b9\u03ba\u03cc \u0395\u03ba\u03c0\u03b1\u03b9\u03b4\u03b5\u03c5\u03c4\u03b9\u03ba\u03cc \u038a\u03b4\u03c1\u03c5\u03bc\u03b1 \u039a\u03c1\u03ae\u03c4\u03b7\u03c2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.teicrete.gr/"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.teicrete.gr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Technological Educational Institute of Crete"
          },
          {
            "lang": "el",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u03a4\u03b5\u03c7\u03bd\u03bf\u03bb\u03bf\u03b3\u03b9\u03ba\u03cc \u0395\u03ba\u03c0\u03b1\u03b9\u03b4\u03b5\u03c5\u03c4\u03b9\u03ba\u03cc \u038a\u03b4\u03c1\u03c5\u03bc\u03b1 \u039a\u03c1\u03ae\u03c4\u03b7\u03c2"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://penn.reunioniq.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "helpdesk@alumniq.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AlumnIQ Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "steve@alumniq.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve Rittler"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://penn.reunioniq.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CounterMarch Systems LLC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.countermarch.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CounterMarch Systems LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://penn.reunioniq.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Alumni weekend registration service"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Penn Alumni Weekend"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDTCCAfWgAwIBAgIJAO7DzRSF699YMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\nBAMMEnBlbm4ucmV1bmlvbmlxLmNvbTAeFw0xNjAyMDIwMzA0NTNaFw0yNjAxMzAw\nMzA0NTNaMB0xGzAZBgNVBAMMEnBlbm4ucmV1bmlvbmlxLmNvbTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAKPPikBVtrXOdrwv3HPEjjRHXRViyZQEeZdT\nLaFSpAQhym3fWa8UV5NQV1N9LDhbeIIVDlT3enOqiPT4da9YapONkBC3BCjpby0q\nbklr11OtB3kacecjmvMccwf4fNmu5ZNJRdkWASeqxP1L0o/5CW47k5ajMPXigdnZ\nmnKhDr2dSDYrAQYeWYOBo3Fg7BT1NBdX4w3xON7iDtkUX60NKoaMvb0BbdwrrAHe\njO0HuaSklXFoO1p5nTjJ4TKvzmg7fdg8GtmmkOYtLHw1VIIWlpGrisD/pUW488gB\nHAn5Ot2BE7sev1RPXrPq6xYNnV2si0cYhjSCTK6WaURKl0JseJkCAwEAAaNQME4w\nHQYDVR0OBBYEFINUzyEygcSCIQrQDUZfVSPSzdd3MB8GA1UdIwQYMBaAFINUzyEy\ngcSCIQrQDUZfVSPSzdd3MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEB\nACs8zh2Lj58Xd+RkW0DBtRC42Dz4nt1qXm3Wy2uXL7p4n8DaYPhOb3nPbsnz3VTn\n7IcMkllD3+fToqwXIvEy9Dp1THbTOG5A1KKSwL6a5zT6aerEJpWIXlv7+v9gaBFB\nizwvn82tKxTBOCkXj9QZas9diwapn4Ruu1eYQbxkpWemv13iNv0ybAlFatElYmki\nGS3cV0xclj1qfl3yzQ6+NBqE1e5HA7zK6oeTCTOKpQ1rVuOE/JtCSU0VdDlWgGAH\naZA2oIDGIZ8tHiskhBWwlaWTR3Z3t+TZKm5cKTCtSV1AgJ0vDiOU/6AVxVD3TOKx\n2Xj5hsW27PR5iSGrVcghwg0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://penn.reunioniq.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://penn.reunioniq.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://penn.reunioniq.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://penn.reunioniq.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Penn Alumni Weekend"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Alumni weekend registration service"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "cn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.totton.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dawson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mdawson@totton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Dawson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mdawson@totton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.totton.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2007-07-04T18:55:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFbTCCBFWgAwIBAgIQcYa5PMnn8T0HjxfLbT0gKjANBgkqhkiG9w0BAQUFADA2\n\t\t\t\t\t\tMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n\t\t\t\t\t\tU1NMIENBMB4XDTEzMDQyNDAwMDAwMFoXDTE2MDQyMzIzNTk1OVowPjEhMB8GA1UE\n\t\t\t\t\t\tCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRkwFwYDVQQDExBpZHAudG90dG9u\n\t\t\t\t\t\tLmFjLnVrMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAqYhekQdpjMhc\n\t\t\t\t\t\ttcgY3MT17ejtn8XMfd9tj/g+tYFu3l+T2VvGIP9Hi+p9wLQcejeGxeA6b3i3QAft\n\t\t\t\t\t\thsqsMV8X9AEqNgxzUsaWmIrMSWjSI1X+vNkjxl/Gr7nEyc5897JT8C2kZF/rCMme\n\t\t\t\t\t\tSdDQBw2TTSMsDXLw1CVyVyCrBaMpTVWAxRZv3cj6YlaMi/0bGa9sNPvwCf2PyqAo\n\t\t\t\t\t\tYMhZvPUTeu7WYE05Myi+QlOsGL9Y2JoG8qND0g/b6KThd3Vkc+LbtVUIF4pFWZPy\n\t\t\t\t\t\tvzKagO7oOAxMK2CCGsnEDOxXaGVY/RwPCPGSRDHal9aPLBWbtIZs5f79M14O5Wdn\n\t\t\t\t\t\tYxMS+cGH+1001TWshCfKEbNhuA0SxbE4N6zdQRBgJFUViE7gRo/aPzRqjzm/x9r5\n\t\t\t\t\t\tnsYQN7FjHeJ8PSEYVyO1o09+Z7NDTedNMEgKJoc3e0+RL2RXKAmZw9tRbLFlPNxZ\n\t\t\t\t\t\thN9mFT6XEUH6ZhC8ld6PKp9qD58OzWozHmITf7mrq970yzuf7Nqi1iVUZIIYD5eD\n\t\t\t\t\t\tTkMOURoy9GvHuPAA6hDAbKnz5Abzx0lDCV+U3w1FxTdANCDGxxJJqhcaJbM7BWqx\n\t\t\t\t\t\tz89O5KHMzYB4BQVfS/Kbm1GwKPisMZbAk8+zKueuEh6naP54LXJnYFH6Nz5LcoBr\n\t\t\t\t\t\tRUF/3+9UAyOITVpLbYOgO5Spav5vyDUCAwEAAaOCAW0wggFpMB8GA1UdIwQYMBaA\n\t\t\t\t\t\tFAy9k2gM896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBS0srg73DCKIsJa07a37uBZ\n\t\t\t\t\t\t9tJt8DAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggr\n\t\t\t\t\t\tBgEFBQcDAQYIKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZn\n\t\t\t\t\t\tgQwBAgEwOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9y\n\t\t\t\t\t\tZy9URVJFTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilo\n\t\t\t\t\t\tdHRwOi8vY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEF\n\t\t\t\t\t\tBQcwAYYaaHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwGwYDVR0RBBQwEoIQaWRw\n\t\t\t\t\t\tLnRvdHRvbi5hYy51azANBgkqhkiG9w0BAQUFAAOCAQEANILKb7qX7KrvAJv7rf0t\n\t\t\t\t\t\tz9Bpo/glzvslIq1tF7v9sAQxDNzn+Y2XYa8AT1q2uzVkQc2AjxKUSMbYUAGnus2g\n\t\t\t\t\t\twFG7LgvMgKoenq+vOHmcB9Qu0JEEg9oZ32g87ZqsPCgc36F4Gq/ja6TZEIgZjmFy\n\t\t\t\t\t\tPnAbGscBk4RUfPZzxacKBsYUglpwLGc7Uxm37CxaXKzYERKWG+J7XR3nBouecCOd\n\t\t\t\t\t\tUr51EZt0BIPQ+91eza3r392o4VvyFVE4tg2YCOSKccBQ4VlgPt2H3dzF73+R69Rq\n\t\t\t\t\t\tP5YGhDQ7w1d5X4AaI29sdjFGDis3V47zw5rWuqHMR3CkD+J4OWLXmSmuXtnQj4TX\n\t\t\t\t\t\txw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "totton.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.totton.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.totton.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.totton.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.totton.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.totton.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.totton.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.totton.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.totton.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "totton.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFbTCCBFWgAwIBAgIQcYa5PMnn8T0HjxfLbT0gKjANBgkqhkiG9w0BAQUFADA2\n\t\t\t\t\t\tMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\n\t\t\t\t\t\tU1NMIENBMB4XDTEzMDQyNDAwMDAwMFoXDTE2MDQyMzIzNTk1OVowPjEhMB8GA1UE\n\t\t\t\t\t\tCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRkwFwYDVQQDExBpZHAudG90dG9u\n\t\t\t\t\t\tLmFjLnVrMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAqYhekQdpjMhc\n\t\t\t\t\t\ttcgY3MT17ejtn8XMfd9tj/g+tYFu3l+T2VvGIP9Hi+p9wLQcejeGxeA6b3i3QAft\n\t\t\t\t\t\thsqsMV8X9AEqNgxzUsaWmIrMSWjSI1X+vNkjxl/Gr7nEyc5897JT8C2kZF/rCMme\n\t\t\t\t\t\tSdDQBw2TTSMsDXLw1CVyVyCrBaMpTVWAxRZv3cj6YlaMi/0bGa9sNPvwCf2PyqAo\n\t\t\t\t\t\tYMhZvPUTeu7WYE05Myi+QlOsGL9Y2JoG8qND0g/b6KThd3Vkc+LbtVUIF4pFWZPy\n\t\t\t\t\t\tvzKagO7oOAxMK2CCGsnEDOxXaGVY/RwPCPGSRDHal9aPLBWbtIZs5f79M14O5Wdn\n\t\t\t\t\t\tYxMS+cGH+1001TWshCfKEbNhuA0SxbE4N6zdQRBgJFUViE7gRo/aPzRqjzm/x9r5\n\t\t\t\t\t\tnsYQN7FjHeJ8PSEYVyO1o09+Z7NDTedNMEgKJoc3e0+RL2RXKAmZw9tRbLFlPNxZ\n\t\t\t\t\t\thN9mFT6XEUH6ZhC8ld6PKp9qD58OzWozHmITf7mrq970yzuf7Nqi1iVUZIIYD5eD\n\t\t\t\t\t\tTkMOURoy9GvHuPAA6hDAbKnz5Abzx0lDCV+U3w1FxTdANCDGxxJJqhcaJbM7BWqx\n\t\t\t\t\t\tz89O5KHMzYB4BQVfS/Kbm1GwKPisMZbAk8+zKueuEh6naP54LXJnYFH6Nz5LcoBr\n\t\t\t\t\t\tRUF/3+9UAyOITVpLbYOgO5Spav5vyDUCAwEAAaOCAW0wggFpMB8GA1UdIwQYMBaA\n\t\t\t\t\t\tFAy9k2gM896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBS0srg73DCKIsJa07a37uBZ\n\t\t\t\t\t\t9tJt8DAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggr\n\t\t\t\t\t\tBgEFBQcDAQYIKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZn\n\t\t\t\t\t\tgQwBAgEwOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9y\n\t\t\t\t\t\tZy9URVJFTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilo\n\t\t\t\t\t\tdHRwOi8vY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEF\n\t\t\t\t\t\tBQcwAYYaaHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwGwYDVR0RBBQwEoIQaWRw\n\t\t\t\t\t\tLnRvdHRvbi5hYy51azANBgkqhkiG9w0BAQUFAAOCAQEANILKb7qX7KrvAJv7rf0t\n\t\t\t\t\t\tz9Bpo/glzvslIq1tF7v9sAQxDNzn+Y2XYa8AT1q2uzVkQc2AjxKUSMbYUAGnus2g\n\t\t\t\t\t\twFG7LgvMgKoenq+vOHmcB9Qu0JEEg9oZ32g87ZqsPCgc36F4Gq/ja6TZEIgZjmFy\n\t\t\t\t\t\tPnAbGscBk4RUfPZzxacKBsYUglpwLGc7Uxm37CxaXKzYERKWG+J7XR3nBouecCOd\n\t\t\t\t\t\tUr51EZt0BIPQ+91eza3r392o4VvyFVE4tg2YCOSKccBQ4VlgPt2H3dzF73+R69Rq\n\t\t\t\t\t\tP5YGhDQ7w1d5X4AaI29sdjFGDis3V47zw5rWuqHMR3CkD+J4OWLXmSmuXtnQj4TX\n\t\t\t\t\t\txw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Totton College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.totton.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Totton College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.stcharles.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.stcharles.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/stcharles.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/stcharles.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stcharles.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "St Charles Catholic Sixth Form College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.stcharles.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.politecnica.edu.co/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hernan Hidalgo Vallejo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "hhidalgo@politecnica.edu.co"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hernan Hidalgo Vallejo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "hhidalgo@politecnica.edu.co"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.politecnica.edu.co/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "es",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://colfire.co/?page_id=55"
              }
            ],
            "registration_instant": "2016-04-04T00:00:00Z",
            "registration_authority": "http://colfire.co",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.politecnica.edu.co/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.politecnica.edu.co/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.politecnica.edu.co/idp/profile/SAML2/POST-SimpleSign/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.politecnica.edu.co:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.politecnica.edu.co/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.politecnica.edu.co/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.politecnica.edu.co/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.politecnica.edu.co/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.politecnica.edu.co:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.politecnica.edu.co:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "politecnica.edu.co"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Corporacion Politecnica Nacional de Colombia"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Corporaci\u00c3\u00b3n Polit\u00c3\u00a9cnica Nacional de Colombia"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "POLITECNICA - Corporacion Politecnica Nacional de Colombia"
                  },
                  {
                    "lang": "es",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "POLITECNICA - Corporaci\u00c3\u00b3n Polit\u00c3\u00a9cnica Nacional de Colombia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVALLT+WTdNsEz6xx5u57WIcx8JElFMA0GCSqGSIb3DQEB\nCwUAMCExHzAdBgNVBAMMFmlkcC5wb2xpdGVjbmljYS5lZHUuY28wHhcNMTYwMjI1\nMTQ0NzI4WhcNMzYwMjI1MTQ0NzI4WjAhMR8wHQYDVQQDDBZpZHAucG9saXRlY25p\nY2EuZWR1LmNvMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAjKyNQzEY\nIDz7LLU7JhEYAguZiscGEX3B79BN5iaaEEd7NhzyYL5e4H4sFnJZ0i3lvFxGlDZj\nXtT7xEv8eS6SSbjZJ9FOmmbOMHfpGMIaYjXHx6MzkLN/jfVv/Q18JXCnQzmaY8XS\nYzQXxl5bGtBcsnv6g0TmJZpxS5y/jNIQvcZRujekkbskjyMkqlLo7fA41BjwGjgr\nRi44+/QUaGgAQzLsjyPJzC+MDfcCQWG1L9Jdw8853qboTkn5SHJqrZD1OeOTYirw\nWsQRj249Y33p7+kLBrMD+54KrPk63mLPF2lYjh2KzfBR1qbuiNjAEXXKfYAl47dz\nI/KNCNpiLVbYXwIDAQABo3MwcTAdBgNVHQ4EFgQUM43hzLJFdMk8Sxshi8WWy7ME\nJaIwUAYDVR0RBEkwR4IWaWRwLnBvbGl0ZWNuaWNhLmVkdS5jb4YtaHR0cHM6Ly9p\nZHAucG9saXRlY25pY2EuZWR1LmNvL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\nCwUAA4IBAQBOazTBGiBWAlaDmIhRxZgTmYDQeqvia95RR59uW8bhg1HSxQruz45d\nZF4XWEhJ6utKGo6QCJSXf/MsAaPUKCYT6OBvIbTArTeUeKzyOEAnH3IL3uO4F3d6\nGyQc7EOSaAWywtPe1fiCM02I//FNl1K+VIJdfO7lFGLNx8XZ4TAmxWmlCc3uaI23\nv/2bRIY12legoOZGMBD+U05hMvPozP3dawqRXKmMpIT94t7QoRUT9sLfCE1E/Obn\ns0fmhhFblLDWEWCf46oIfgd4zGZqcmLHAKeUmnCA2tMrSD7+fmXVDz6yt3ySpKCK\nTdJDiBfKuVh3IECFWZ6+L9/CVJv5Sqm7"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUNo4WuHVgmvnokxrB1OeB+1nrgn8wDQYJKoZIhvcNAQEL\nBQAwITEfMB0GA1UEAwwWaWRwLnBvbGl0ZWNuaWNhLmVkdS5jbzAeFw0xNjAyMjUx\nNDQ3MjRaFw0zNjAyMjUxNDQ3MjRaMCExHzAdBgNVBAMMFmlkcC5wb2xpdGVjbmlj\nYS5lZHUuY28wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCliUrMbHvs\nkl3COdt7P0UgoEQ5smBH9YetLsvzGo+tbLJ7SRqkITlRWQXaJFqePJ+APRo8tRIR\nmL99gl2OuOc6etN82KVB8idyE2rC/uEQnqfVZO0WPAibICEm2zjoaMMdSTgev4gI\nLqeZ2HCG50DjFhcWNglsTABhvHDk8XE/QPpqoFALepozKykcTVidHzyDQeH4+syJ\nIiwsW+mH83LnbQ1vIuqqGYwZ9+9BDy0pA3D9KWePfkcTpoVJLEMYHurgTEYSqivB\n476LFkaTd7DhlLi+ddb09OPeyqsumq/C0kGMY1GTJckk0C7hOayGwiWoZkyTUSHF\nZllwhARpj8pHAgMBAAGjczBxMB0GA1UdDgQWBBRY/2odAVt3NTy+R/k2pou6SW/r\n2DBQBgNVHREESTBHghZpZHAucG9saXRlY25pY2EuZWR1LmNvhi1odHRwczovL2lk\ncC5wb2xpdGVjbmljYS5lZHUuY28vaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEL\nBQADggEBAGbF/LoU7ZuCZoNjUyxKdfxjkJkgZ75PiQlqQ21+L5RbYbsTiMzuJtaV\nqyNJPJvT0MsXRwnKntiSChZ6nVtdLQXcXf2xWCiJHdcb0uzhGTFr3aIiPOTY9TiJ\naw1foI6WxTVPtolIj+BmeKi+1Vy+ITyJZYXqC3ZnSNGv5jxGLyyjI9WnwJ5Zonl5\nMG63FxrmNlorkaHh8K6TOWcdIw2IeqBr15f7oExN6pgijgyJ/9oeVk01K9d55NLI\nlfQnX3dTZbzhAPoGnAlCIUcJjeH+ESDAR57hVC8u8+kMjdKorq4Ohvpqc+XjAYRl\ne29cUKcPujSEW+pJdMWH+2sPqW2M3wU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQzCCAiugAwIBAgIUMgiMuAX0pbhavZ4i1yl7uO2HpAEwDQYJKoZIhvcNAQEL\nBQAwITEfMB0GA1UEAwwWaWRwLnBvbGl0ZWNuaWNhLmVkdS5jbzAeFw0xNjAyMjUx\nNDQ3MjZaFw0zNjAyMjUxNDQ3MjZaMCExHzAdBgNVBAMMFmlkcC5wb2xpdGVjbmlj\nYS5lZHUuY28wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCjhzloyYYi\noKmFqjuyzjiU0FdkR9kZx5t4kHbjnwbLfSr+umiRQOQuz1oVkJwXIkjKobMXUY5F\nSnPQlzUZyw2KxMmH4Pg+4KfEhYj0biRG/bmWkvoTqJdrYq9273j7uFT18i5SEWzX\njmG8imWFkmvK2Y6VrOEYuIRiDil27TPxvEZJ6dSHv2Q/FOIzfYD582bBmeWGcOmY\nJpMuqzi5FW1vs96QIabJ9QKJ8VTvVv6TXaj75FvvWbDbtOUWghP9IKFVSa6mPB9V\nz9lHdCOPAfzsbm82hG67Q5ipEmbIfBt5bHIRrTViWwC3cYUuJudQ4Zb6Cz40hO9u\nlCIIAvDQeDCtAgMBAAGjczBxMB0GA1UdDgQWBBSZST+CVKY+u0y9KuR6jRFg1MKk\nhDBQBgNVHREESTBHghZpZHAucG9saXRlY25pY2EuZWR1LmNvhi1odHRwczovL2lk\ncC5wb2xpdGVjbmljYS5lZHUuY28vaWRwL3NoaWJib2xldGgwDQYJKoZIhvcNAQEL\nBQADggEBAFJXD1U/w5DldguWWlpIgaGX33gpB8lmZ5DmwCAV9TCo5MtkzRd3psZf\nSW/FXvDqARzIPFiHgIr5uUagWQDTmTr9+AmRgMl12sHC6jL391TMw9k2B+ofA6pY\niWCooMb2Ua8sHfETlb1i7/oHMoKfAI+vOHN30B/3zhGuevobaLmjKPBSvfCvYRJq\nnq5OpQh1pJdNwnfOFsxD5hFctOan+Q8PQCiMhm7z2epJAoIVwpxQVYzLhhQVq7NJ\nDKxk60nmPyjgvFYuXNh9JEv0Cwe8rVzuBxssCDuJYtIKNRynILzaYFP5a3lp0/tC\nhnIvrkPFl+JtdYNgaSsOrzFBzAGRH4I="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "POLITECNICA - Corporaci\u00c3\u00b3n Polit\u00c3\u00a9cnica Nacional de Colombia"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "POLITECNICA - Corporacion Politecnica Nacional de Colombia"
          }
        ],
        "organization_url": [
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.politecnica.edu.co"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.politecnica.edu.co"
          }
        ],
        "organization_name": [
          {
            "lang": "es",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "POLITECNICA - Corporaci\u00c3\u00b3n Polit\u00c3\u00a9cnica Nacional de Colombia"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "POLITECNICA - Corporaci\u00c3\u00b3n Polit\u00c3\u00a9cnica Nacional de Colombia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib-idp.its.csufresno.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sysadmin@csufresno.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ITS Systems Group"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mikeg@csufresno.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike Garvey"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib-idp.its.csufresno.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-idp.its.csufresno.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.its.csufresno.edu/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIVALSvbUT9X5BLZlEcvo8wdsnCxnQ1MA0GCSqGSIb3DQEB\nBQUAMCUxIzAhBgNVBAMTGnNoaWItaWRwLml0cy5jc3VmcmVzbm8uZWR1MB4XDTA4\nMTExMjE2MzAzMFoXDTI4MTExMjE2MzAzMFowJTEjMCEGA1UEAxMac2hpYi1pZHAu\naXRzLmNzdWZyZXNuby5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQCgFKDm+HjolJI/esmZA9m/yoACfyeUUTnjkILD4qoJHuR8VCLBh8rSMmpdobz8\nhFjAWA11dRyYIOUE+n+MOySPHPubprAgh3wUpkJ8MqZgJHCG8leadeqt09OTHp4D\npKDMu6GAGQlK0gKDbZMWqhZcXhCQqSZ/ygPlCLlkl0VnByN/x2YmlkGTDr8SZxX8\nUyDl3t5ynOHGhGTCTZC6DF0rv+boCPyPFC6XvWMBqB/ZHf8/f3ughACG13oqFdR+\n/bKcwzllvtf3jgG8YeQmgkpwjkLpNfnvmkE6LVwiXrEIKDZUUlywztCVt3vNVxUn\nAMJbNpa94S5jUuPZKLNySTiXAgMBAAGjezB5MFgGA1UdEQRRME+CGnNoaWItaWRw\nLml0cy5jc3VmcmVzbm8uZWR1hjFodHRwczovL3NoaWItaWRwLml0cy5jc3VmcmVz\nbm8uZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTuqVs6xfq+U40s67dcTqnf\nkJm6bjANBgkqhkiG9w0BAQUFAAOCAQEAXOjFSEnFzLix+yxV0BK/kKgP9VGuunu6\noeT7bcTHJDk0GIWTD1HfN/CxMCG138U0ETjqrW2VG3XN6tN6d2YgKCNYvjMT5DTz\ng+CXvCIuHws5vUt9Y6cbzws0vgtxEP6lLP2aVsESuVJBX1BivGgpYP4gU9mVo/EK\n88x/vzEtl0TVSL2nK0tNqZCRX74uGUgOvn8aC3Yg1CQkzBt67LMrgDfl19OeZjDA\nXyFi44m87acoHxdzxSwFUz7nIvXinIB15IrsIp2BgkblbSiJudOJGxpcq0eIGI+j\nkhQt9bzJkX3J4Cg2WQo63SIREH799iBIRT7he/NurdO1UVGLStfEjw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csufresno.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib-idp.its.csufresno.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib-idp.its.csufresno.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib-idp.its.csufresno.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib-idp.its.csufresno.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib-idp.its.csufresno.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib-idp.its.csufresno.edu/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "csufresno.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "California State University, Fresno"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVDCCAjygAwIBAgIVALSvbUT9X5BLZlEcvo8wdsnCxnQ1MA0GCSqGSIb3DQEB\nBQUAMCUxIzAhBgNVBAMTGnNoaWItaWRwLml0cy5jc3VmcmVzbm8uZWR1MB4XDTA4\nMTExMjE2MzAzMFoXDTI4MTExMjE2MzAzMFowJTEjMCEGA1UEAxMac2hpYi1pZHAu\naXRzLmNzdWZyZXNuby5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQCgFKDm+HjolJI/esmZA9m/yoACfyeUUTnjkILD4qoJHuR8VCLBh8rSMmpdobz8\nhFjAWA11dRyYIOUE+n+MOySPHPubprAgh3wUpkJ8MqZgJHCG8leadeqt09OTHp4D\npKDMu6GAGQlK0gKDbZMWqhZcXhCQqSZ/ygPlCLlkl0VnByN/x2YmlkGTDr8SZxX8\nUyDl3t5ynOHGhGTCTZC6DF0rv+boCPyPFC6XvWMBqB/ZHf8/f3ughACG13oqFdR+\n/bKcwzllvtf3jgG8YeQmgkpwjkLpNfnvmkE6LVwiXrEIKDZUUlywztCVt3vNVxUn\nAMJbNpa94S5jUuPZKLNySTiXAgMBAAGjezB5MFgGA1UdEQRRME+CGnNoaWItaWRw\nLml0cy5jc3VmcmVzbm8uZWR1hjFodHRwczovL3NoaWItaWRwLml0cy5jc3VmcmVz\nbm8uZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTuqVs6xfq+U40s67dcTqnf\nkJm6bjANBgkqhkiG9w0BAQUFAAOCAQEAXOjFSEnFzLix+yxV0BK/kKgP9VGuunu6\noeT7bcTHJDk0GIWTD1HfN/CxMCG138U0ETjqrW2VG3XN6tN6d2YgKCNYvjMT5DTz\ng+CXvCIuHws5vUt9Y6cbzws0vgtxEP6lLP2aVsESuVJBX1BivGgpYP4gU9mVo/EK\n88x/vzEtl0TVSL2nK0tNqZCRX74uGUgOvn8aC3Yg1CQkzBt67LMrgDfl19OeZjDA\nXyFi44m87acoHxdzxSwFUz7nIvXinIB15IrsIp2BgkblbSiJudOJGxpcq0eIGI+j\nkhQt9bzJkX3J4Cg2WQo63SIREH799iBIRT7he/NurdO1UVGLStfEjw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "California State University, Fresno"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.csufresno.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "California State University, Fresno"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.gsm.org.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.gsm.org.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-03-26T10:55:52Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/gsm.org.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/gsm.org.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gsm.org.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GSM London"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gsm.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth2sp.cab.semcs.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cab-shibboleth-support@semantico.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cab-shibboleth-support@semantico.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth2sp.cab.semcs.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Semantico Limited: CABI Shibboleth 2 SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.semantico.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Semantico Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.cab.semcs.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.cab.semcs.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.cab.semcs.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.cab.semcs.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.cab.semcs.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0jCCArqgAwIBAgIJAKhAI5hrPtycMA0GCSqGSIb3DQEBBQUAMGsxCzAJBgNV\n\t\t\t\t\t\tBAYTAlVLMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIwEAYD\n\t\t\t\t\t\tVQQKEwlzZW1hbnRpY28xJDAiBgNVBAMTG3NoaWJib2xldGgyc3AuY2FiLnNlbWNz\n\t\t\t\t\t\tLm5ldDAeFw0xNTA0MjMxMDQwMDNaFw0zNTA0MTgxMDQwMDNaMGsxCzAJBgNVBAYT\n\t\t\t\t\t\tAlVLMQ8wDQYDVQQIEwZTdXNzZXgxETAPBgNVBAcTCEJyaWdodG9uMRIwEAYDVQQK\n\t\t\t\t\t\tEwlzZW1hbnRpY28xJDAiBgNVBAMTG3NoaWJib2xldGgyc3AuY2FiLnNlbWNzLm5l\n\t\t\t\t\t\tdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMo6HEsVY5D3FNTamNhM\n\t\t\t\t\t\tU2/zkVh6ZWNSekvPiXIXi074Vol8nTbHO18ckTQCoovUAEC8pTnMPITo4ga3m2Yr\n\t\t\t\t\t\tSDYfu/YvsTzl+caOkGqY9atp6Hpc6643PruMgf0jHn128gFP7OopZK7UN+wn8kF1\n\t\t\t\t\t\tZbjouHyKvORBbcik8eiHiRpn4k04N7JESS5CgpFB9KY7NQsPOqJ/FkYYggM8zXSe\n\t\t\t\t\t\t3lSyzIx8FzzL0vj9Q0fOkbJRDCV/TVGxL3sWo0eAD7Swq7civ3TzOuEgYVTARsxp\n\t\t\t\t\t\tzMoj7m6TjI+3VsfJKZkbhrlxp/NVyhvcUKBd1eW/5s2sjOkbj3cgKKMlalyWHWMZ\n\t\t\t\t\t\tXWUCAwEAAaN5MHcwVgYDVR0RBE8wTYIbc2hpYmJvbGV0aDJzcC5jYWIuc2VtY3Mu\n\t\t\t\t\t\tbmV0hi5odHRwczovL3NoaWJib2xldGgyc3AuY2FiLnNlbWNzLm5ldC9zaGliYm9s\n\t\t\t\t\t\tZXRoMB0GA1UdDgQWBBQsdfdbM8eHua2UVoVlNd7UMrgx3jANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAVXXqftpGfy/pw1uzmR7sqzxiFjbqak9wkfLkF4iFD4/ADgFYewY308fa\n\t\t\t\t\t\t1Rqz3hgUw/3Wtjyii39OKxb5+hJmz3Yu36OBcES7NF7jKv+XXp24O0bKHlbuyq1J\n\t\t\t\t\t\t3ktWP+klEWrBkMXMbBfP+Hxtm18XYgtrP7DIMyXO160APWFCgV+6q4clgax05EdC\n\t\t\t\t\t\tiPwvA0S2/LNrsGdyFhT2TgIoedPJzG0bRQxhR7wD+Tp7Q78TpRBMjSIh5+hN1jfG\n\t\t\t\t\t\t0m0iUUdeVcYD/QO1RmKCVKRiE/ggedRWm9kWuZndS9NKueRPBSUS+cRTrt1gjHT6\n\t\t\t\t\t\t6rueyK7gPe52OqpcIeT+P9Ubo17Llg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth2sp.cab.semcs.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth2sp.cab.semcs.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.cab.semcs.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.cab.semcs.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth2sp.cab.semcs.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth2sp.cab.semcs.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth2sp.cab.semcs.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://shibboleth2sp.cab.semcs.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth2sp.cab.semcs.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth2sp.cab.semcs.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://federatie.graafschapcollege.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://federatie.graafschapcollege.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-06-08T12:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/c1d4b6678ee39120711a03bb88ac3d7f",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Graafschap College"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Graafschap College"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/graafschapcollege.png",
                    "height": "24",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Graafschap College"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Graafschap College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Graafschap College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.graafschapcollege.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Graafschap College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.bishopg.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.bishopg.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/bishopg.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/bishopg.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bishopg.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bishop Grosseteste University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bishopg.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.montana.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mhall@montana.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike Hall"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "aedelman@montana.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam Edelman"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mhall@montana.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike Hall"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.montana.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.montana.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.montana.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.montana.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.montana.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.montana.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "montana.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Montana State University Bozeman's InCommon Identity provider."
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.montana.edu/cas/meta/img/MSU-horiz.png",
                    "lang": "en",
                    "height": "163",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "648"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Montana State University - Bozeman"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAOfP2IewNMJIbSjlEL1iQlgWdmoLMA0GCSqGSIb3DQEB\nBQUAMBwxGjAYBgNVBAMTEWxvZ2luLm1vbnRhbmEuZWR1MB4XDTEyMTAyNTIxMjU0\nMVoXDTMyMTAyNTIxMjU0MVowHDEaMBgGA1UEAxMRbG9naW4ubW9udGFuYS5lZHUw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDJbeGVsOWY+Ii1zzNkJZMs\nuzZQQMpWobWgJAmfk7qy1qS+bBXNAKC+8U3ilHsRS/CCUZAKBf9aXXL1/BAuLwU3\nTBICswpfwJ0TKjjrvYuCEwoVI6nmnzc3oo17CacvjkuOKq2vAPw9t9/7mVNs7IxK\nTYK3Z02LD/KnrFM98HHy4jGYROsDRqPKb/znz3ZkwcV9AV4BoAxnaAmbr6xMS2di\ncRYqZnT38rsoAD9JXopPtC6ipWCVX6fhIVFVPA/nIULZ3z+PKwZVYxWlyy7pCsu5\nqLGP77EcE1FJvVrRasN+G9gLm6pJmehYxmn3WQWtXqHa6Wv91HdTCDQ7S4rnf5d9\nAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEWxvZ2luLm1vbnRhbmEuZWR1hihodHRwczov\nL2xvZ2luLm1vbnRhbmEuZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQCwE0i\nmErFyh6Mep7z5gF7aQWKqjANBgkqhkiG9w0BAQUFAAOCAQEATPtND9wTPCuh8iXW\nY8/BkwHpRdqX6klfxIzIa8vj+SgX5/O0DBU232qUIrb11il274iCPRXIwjucjmaJ\nF/qx1G+9yvhx94kzymEYKqSTI9qrdGTgDigA8zAZ4LJY4O4Nyxzh6t7shD/buro5\nZot2coe9Rhr6UaZ4uIp/m+DUI+4yzbVPdXKc7uXObkLQ3214DvhBMVvLnX5i9CC9\nSq2w5CreEH+cZsLdMWuLWC/NFkRVK2AcQXnmJIwoZBpAhY4Kn1Teq0YdT7JjUZZY\nMNukIl90N4nc/ghjESnGMHNVPlUL6z+11zc/02Uy9It+hLlylZrWbwnaAxZgyTSz\n8my2pg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Montana State University - Bozeman"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.montana.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Montana State University - Bozeman"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://cafe.ibict.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Benicio Mendes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "benicio@ibict.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.ibict.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIECDCCAvACAQAwDQYJKoZIhvcNAQEFBQAwgckxQzBBBgNVBAoUOkluc3RpdHV0\nbyBCcmFzaWxlaXJvIGRlIEluZm9ybWHn428gZW0gQ2nqbmNpYSBlIFRlY25vbG9n\naWExDjAMBgNVBAsTBUlCSUNUMR8wHQYJKoZIhvcNAQkBFhBiZW5pY2lvQGliaWN0\nLmJyMREwDwYDVQQHEwhCcmFzaWxpYTEZMBcGA1UECBMQRGlzdHJpdG8gRmVkZXJh\nbDELMAkGA1UEBhMCQlIxFjAUBgNVBAMTDWNhZmUuaWJpY3QuYnIwHhcNMTUwNDMw\nMTMyOTQ3WhcNMTgwNDI5MTMyOTQ3WjCByTFDMEEGA1UEChQ6SW5zdGl0dXRvIEJy\nYXNpbGVpcm8gZGUgSW5mb3JtYefjbyBlbSBDaepuY2lhIGUgVGVjbm9sb2dpYTEO\nMAwGA1UECxMFSUJJQ1QxHzAdBgkqhkiG9w0BCQEWEGJlbmljaW9AaWJpY3QuYnIx\nETAPBgNVBAcTCEJyYXNpbGlhMRkwFwYDVQQIExBEaXN0cml0byBGZWRlcmFsMQsw\nCQYDVQQGEwJCUjEWMBQGA1UEAxMNY2FmZS5pYmljdC5icjCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAMvLiN/XFBLhWCbglIa/z8fiSgxxLl6cCq6RSPp2\n1a6YP7FOa6Yr27oI+qsMy4ppGM6brlI1jqbFjeHjidlM8vesPRX4ZTMdM/t5eT11\n45OY7vGTibAL/gcvtg/5NX3xVWEzaStCoeXIQo+ExvbdiIqbp/BgQ+WPSC7MSHJO\nOWhIDGYZlI6icmpO2+VDfIqbUuhCHhj1AUxFNyMofKl8gsicofnzqkSCiaf6gPp+\n/LqKTStwdyWV91W3MBZVUxnFRyUoiOElj7XakskECxXlvYkGvIXW2M293YAfWE1z\n9gKJeUYvhSu4Jr0icKhSAX/fsMGkUOuu13Tpdnol1dETpI8CAwEAATANBgkqhkiG\n9w0BAQUFAAOCAQEATeHDBnb6qsxkiTAt1j56dvsM+YSlxSJ3hkJjAilnIZovT+3V\nw2zDeTa0zBkXHTeD0BUYD4ycCUq3P7hEEJgjWddIdVEPeEptDwXHdtWl37W5KSHR\n2gTsYUcn+R7g5K388uJtP/9m5YZQAs2EmDHkX6U5DUI9MJq2NYGTuAA34UgFvUnF\nhmM7+xoVBLARfBd5RW32TC6zPQHE085tkEpwdrt0gpJomuDSH4xN9Cg/mpYjGu3b\nMCjWyXkvx5MWwLEhWX2wfb1OW1njrrXJED5/lfU/VXBBbIBuPYrXssrean5rsqGD\nsFFBp3cAD9Mu3T9VuMY1GztDz1PPfkSsDlsEdg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ibict.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.ibict.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.ibict.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.ibict.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.ibict.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.ibict.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.ibict.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.ibict.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.ibict.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ibict.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ibict.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ibict.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IBICT - Instituto Brasileiro de Informacao em Ciencia e Tecnologia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IBICT - Instituto Brasileiro de Informacao em Ciencia e Tecnologia"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IBICT - Instituto Brasileiro de Informacao em Ciencia e Tecnologia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IBICT - Instituto Brasileiro de Informacao em Ciencia e Tecnologia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIECDCCAvACAQAwDQYJKoZIhvcNAQEFBQAwgckxQzBBBgNVBAoUOkluc3RpdHV0\nbyBCcmFzaWxlaXJvIGRlIEluZm9ybWHn428gZW0gQ2nqbmNpYSBlIFRlY25vbG9n\naWExDjAMBgNVBAsTBUlCSUNUMR8wHQYJKoZIhvcNAQkBFhBiZW5pY2lvQGliaWN0\nLmJyMREwDwYDVQQHEwhCcmFzaWxpYTEZMBcGA1UECBMQRGlzdHJpdG8gRmVkZXJh\nbDELMAkGA1UEBhMCQlIxFjAUBgNVBAMTDWNhZmUuaWJpY3QuYnIwHhcNMTUwNDMw\nMTMyOTQ3WhcNMTgwNDI5MTMyOTQ3WjCByTFDMEEGA1UEChQ6SW5zdGl0dXRvIEJy\nYXNpbGVpcm8gZGUgSW5mb3JtYefjbyBlbSBDaepuY2lhIGUgVGVjbm9sb2dpYTEO\nMAwGA1UECxMFSUJJQ1QxHzAdBgkqhkiG9w0BCQEWEGJlbmljaW9AaWJpY3QuYnIx\nETAPBgNVBAcTCEJyYXNpbGlhMRkwFwYDVQQIExBEaXN0cml0byBGZWRlcmFsMQsw\nCQYDVQQGEwJCUjEWMBQGA1UEAxMNY2FmZS5pYmljdC5icjCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAMvLiN/XFBLhWCbglIa/z8fiSgxxLl6cCq6RSPp2\n1a6YP7FOa6Yr27oI+qsMy4ppGM6brlI1jqbFjeHjidlM8vesPRX4ZTMdM/t5eT11\n45OY7vGTibAL/gcvtg/5NX3xVWEzaStCoeXIQo+ExvbdiIqbp/BgQ+WPSC7MSHJO\nOWhIDGYZlI6icmpO2+VDfIqbUuhCHhj1AUxFNyMofKl8gsicofnzqkSCiaf6gPp+\n/LqKTStwdyWV91W3MBZVUxnFRyUoiOElj7XakskECxXlvYkGvIXW2M293YAfWE1z\n9gKJeUYvhSu4Jr0icKhSAX/fsMGkUOuu13Tpdnol1dETpI8CAwEAATANBgkqhkiG\n9w0BAQUFAAOCAQEATeHDBnb6qsxkiTAt1j56dvsM+YSlxSJ3hkJjAilnIZovT+3V\nw2zDeTa0zBkXHTeD0BUYD4ycCUq3P7hEEJgjWddIdVEPeEptDwXHdtWl37W5KSHR\n2gTsYUcn+R7g5K388uJtP/9m5YZQAs2EmDHkX6U5DUI9MJq2NYGTuAA34UgFvUnF\nhmM7+xoVBLARfBd5RW32TC6zPQHE085tkEpwdrt0gpJomuDSH4xN9Cg/mpYjGu3b\nMCjWyXkvx5MWwLEhWX2wfb1OW1njrrXJED5/lfU/VXBBbIBuPYrXssrean5rsqGD\nsFFBp3cAD9Mu3T9VuMY1GztDz1PPfkSsDlsEdg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IBICT - Instituto Brasileiro de Informacao em Ciencia e Tecnologia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IBICT - Instituto Brasileiro de Informacao em Ciencia e Tecnologia"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ibict.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ibict.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IBICT - Instituto Brasileiro de Informacao em Ciencia e Tecnologia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IBICT - Instituto Brasileiro de Informacao em Ciencia e Tecnologia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://online.statref.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pearce"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ppearce@tetondata.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Pearce"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ppearce@tetondata.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://online.statref.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-12-05T15:23:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Stat!Ref"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.statref.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Teton Data Systems"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://onlinebeta.statref.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://onlinebeta.statref.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://onlinebeta.statref.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://onlinebeta.statref.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://online.statref.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://online.statref.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://online.statref.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://online.statref.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://onlinebeta.statref.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://online.statref.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://onlinebeta.statref.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://onlinebeta.statref.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://online.statref.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://online.statref.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID+TCCAuGgAwIBAgIJAJwEXu6tonahMA0GCSqGSIb3DQEBBQUAMIGSMQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzEQMA4GA1UECAwHV3lvbWluZzEQMA4GA1UEBwwHSmFja3NvbjEbMBkG\n\t\t\t\t\t\tA1UECgwSVGV0b24gRGF0YSBTeXN0ZW1zMRswGQYDVQQDDBJvbmxpbmUuc3RhdHJl\n\t\t\t\t\t\tZi5jb20xJTAjBgkqhkiG9w0BCQEWFmptYXh3ZWxsQHRldG9uZGF0YS5jb20wHhcN\n\t\t\t\t\t\tMTAxMjAyMTY1MzE1WhcNMjAxMjAxMTY1MzE1WjCBkjELMAkGA1UEBhMCVVMxEDAO\n\t\t\t\t\t\tBgNVBAgMB1d5b21pbmcxEDAOBgNVBAcMB0phY2tzb24xGzAZBgNVBAoMElRldG9u\n\t\t\t\t\t\tIERhdGEgU3lzdGVtczEbMBkGA1UEAwwSb25saW5lLnN0YXRyZWYuY29tMSUwIwYJ\n\t\t\t\t\t\tKoZIhvcNAQkBFhZqbWF4d2VsbEB0ZXRvbmRhdGEuY29tMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAvxUW98iDiWy1rnYLXmrSut26X+wCpXsS+xit1uhr\n\t\t\t\t\t\toD83HOiE18fidOCPR2Reusw2PVS2Mv3Z2MouDxrbnxI1f40YTWmxWLJD9D+MeAbI\n\t\t\t\t\t\tDvt2uRctN82aVwL1Hy0GFsiS0RXztW0XiSZy6u/bqHVpSjYNw3AcnSadCPrt0ue0\n\t\t\t\t\t\teW1x+nvefeXxSgFfFxyjG+F/6br+CDvZk6oXNkDs8xRGiekM9mPo2DF1Qx3zxqPl\n\t\t\t\t\t\tzW5homj1P2LlaeNvtXSj5EAfob0SPpx+gnNzXMbNzqwCLcY/amQkNjTPQC4nFYpc\n\t\t\t\t\t\tJWiEOt4GKS8NuztVvrk1z6e0q4/2UUZJuiSUEB4Bk9BtEQIDAQABo1AwTjAdBgNV\n\t\t\t\t\t\tHQ4EFgQU0mxo874bLxgMm12FGngVP4j3EnYwHwYDVR0jBBgwFoAU0mxo874bLxgM\n\t\t\t\t\t\tm12FGngVP4j3EnYwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAuN4c\n\t\t\t\t\t\td4KiRWdzWokz0NV0SRulD0yBRyMpR2LjVr9y7Btg+/IbKJdooR6+kStOvmZHctvI\n\t\t\t\t\t\tKVZ5Kr9dUuOgQ2Kkyf4nXVPkwzpNj+N1+gNJ4/JlOzZEkshBf++ASMbQ8OEWkrl+\n\t\t\t\t\t\tiimaLh3BSCDp/giL8/geH+5fFSgtXyCXx7pcP0GKxdOR7vLcZ9EK+qsutOW4006w\n\t\t\t\t\t\tFaXTVDbgg006UGxD1VGW78cSfM5DGkwQvkG+52xLWNe3VhasnbqeirkuSHfmD6Ma\n\t\t\t\t\t\tfV8vvSNyvTmWbK+/nHcVDJiqmb81XOuXy/NJDOZQpcK8Rx8vc6eAlgNTbLj6iTAJ\n\t\t\t\t\t\tZHzp7ICc2EW3RkJNUQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://onlinebeta.statref.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://onlinebeta.statref.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://onlinebeta.statref.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://onlinebeta.statref.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://onlinebeta.statref.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://onlinebeta.statref.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://online.statref.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://online.statref.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://online.statref.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://online.statref.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://online.statref.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://online.statref.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.lambeth.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:networksupport@lambeth.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Network Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Preston"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:TPreston@lambethcollege.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tom"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Zhuang"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ezhuang@lambeth.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Eric"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.lambeth.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-04-26T11:10:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAOew5SzBfog/X45WRCY3nAQXwA63MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBwxGjAYBgNVBAMTEWlkcC5sYW1iZXRoLmFjLnVrMB4XDTE0MDIxOTA4MTI1\n\t\t\t\t\t\tNloXDTM0MDIxOTA4MTI1NlowHDEaMBgGA1UEAxMRaWRwLmxhbWJldGguYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDmoA8TlAc9wQSYDGtLSn8E\n\t\t\t\t\t\tDQZ9d72tC4lH45Na9OenSspeZ6l4Oekgv6xGeZcImOUFn9mQ3PZIiHJMYgmo/ouy\n\t\t\t\t\t\t7sGE+bW7lulmAWQYo6khkRKnu5HqRv2QLZmiS/z2aaqqrWqSd4JlLdVdE9u9Ki7T\n\t\t\t\t\t\tMCIp2p4HQ0cLg77b8KjRnh/y4/qj2AvDFJPFIfplIh+5mt1M6ka1Ydg5AcfvdT6d\n\t\t\t\t\t\tEZu9Ams2nJPRPax2s7qq7OETgTODyN5E/7XQTwqjGOxirTS2LHMoVqYHtjmpYq4I\n\t\t\t\t\t\tresVAqKkkSJLS/dy2hEkpqyLS91IeZF4rODfMkVg0nglPVTt7NHml36DHSkEMcbp\n\t\t\t\t\t\tAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEWlkcC5sYW1iZXRoLmFjLnVrhihodHRwczov\n\t\t\t\t\t\tL2lkcC5sYW1iZXRoLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSrBHTL\n\t\t\t\t\t\tv5ig79YvnYvc1QwZqEORqTANBgkqhkiG9w0BAQUFAAOCAQEAv3AqTafVQD9uWHJh\n\t\t\t\t\t\tpT6tp4YpFaLNvbj+jRoelUsPDLyLHWXPWqvsuxv1fCpX1UZPs0S9X/jSjCECLmFe\n\t\t\t\t\t\t51KmsDoKC3nj2KZTjcmkMo34fBxTqRCM2CX+kBPEnXqbtUVhzZ2PRrxPuzeIBmzo\n\t\t\t\t\t\tvZ1CGq+WaNFuG6dMP4nRZAhJI4pC87l8AlVCHMShcihD1YA6FFEgkPvXTHMv4/hY\n\t\t\t\t\t\tt+B8dRMudDbFxCbayT0HRBySZrCY8E3mX3FCkLDE0wtTPxxIWq8lyJrGotB5HKXY\n\t\t\t\t\t\tDq+Aacae6PXVL70A1dyUC7H5LTpcTdGejtDI+9wSwE3IL7sBh6/OprCp54UeU0Qa\n\t\t\t\t\t\tONYm4A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lambeth.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.lambeth.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.lambeth.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.lambeth.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.lambeth.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.lambeth.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.lambeth.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.lambeth.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.lambeth.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "lambeth.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAOew5SzBfog/X45WRCY3nAQXwA63MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBwxGjAYBgNVBAMTEWlkcC5sYW1iZXRoLmFjLnVrMB4XDTE0MDIxOTA4MTI1\n\t\t\t\t\t\tNloXDTM0MDIxOTA4MTI1NlowHDEaMBgGA1UEAxMRaWRwLmxhbWJldGguYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDmoA8TlAc9wQSYDGtLSn8E\n\t\t\t\t\t\tDQZ9d72tC4lH45Na9OenSspeZ6l4Oekgv6xGeZcImOUFn9mQ3PZIiHJMYgmo/ouy\n\t\t\t\t\t\t7sGE+bW7lulmAWQYo6khkRKnu5HqRv2QLZmiS/z2aaqqrWqSd4JlLdVdE9u9Ki7T\n\t\t\t\t\t\tMCIp2p4HQ0cLg77b8KjRnh/y4/qj2AvDFJPFIfplIh+5mt1M6ka1Ydg5AcfvdT6d\n\t\t\t\t\t\tEZu9Ams2nJPRPax2s7qq7OETgTODyN5E/7XQTwqjGOxirTS2LHMoVqYHtjmpYq4I\n\t\t\t\t\t\tresVAqKkkSJLS/dy2hEkpqyLS91IeZF4rODfMkVg0nglPVTt7NHml36DHSkEMcbp\n\t\t\t\t\t\tAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEWlkcC5sYW1iZXRoLmFjLnVrhihodHRwczov\n\t\t\t\t\t\tL2lkcC5sYW1iZXRoLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSrBHTL\n\t\t\t\t\t\tv5ig79YvnYvc1QwZqEORqTANBgkqhkiG9w0BAQUFAAOCAQEAv3AqTafVQD9uWHJh\n\t\t\t\t\t\tpT6tp4YpFaLNvbj+jRoelUsPDLyLHWXPWqvsuxv1fCpX1UZPs0S9X/jSjCECLmFe\n\t\t\t\t\t\t51KmsDoKC3nj2KZTjcmkMo34fBxTqRCM2CX+kBPEnXqbtUVhzZ2PRrxPuzeIBmzo\n\t\t\t\t\t\tvZ1CGq+WaNFuG6dMP4nRZAhJI4pC87l8AlVCHMShcihD1YA6FFEgkPvXTHMv4/hY\n\t\t\t\t\t\tt+B8dRMudDbFxCbayT0HRBySZrCY8E3mX3FCkLDE0wtTPxxIWq8lyJrGotB5HKXY\n\t\t\t\t\t\tDq+Aacae6PXVL70A1dyUC7H5LTpcTdGejtDI+9wSwE3IL7sBh6/OprCp54UeU0Qa\n\t\t\t\t\t\tONYm4A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Lambeth College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.lambethcollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Lambeth College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://forge.switch.ch/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41 44 268 15 05"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Team"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@switch.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "forge"
          }
        },
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41 44 268 15 42"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kerins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:fergus.kerins@switch.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Fergus"
          }
        }
      ],
      "entity_id": "https://forge.switch.ch/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2016-04-06T06:41:43Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "friendly_name": "swissEduPersonHomeOrganization",
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "switch.ch"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:2.16.756.1.2.5.1.1.4",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "friendly_name": "swissEduPersonHomeOrganizationType",
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "others"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oid:2.16.756.1.2.5.1.1.5",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SWITCH"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SWITCH"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SWITCH"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SWITCH"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.switch.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.switch.ch/"
          },
          {
            "lang": "fr",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.switch.ch/"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.switch.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "switch.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://forge.switch.ch/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Serves as project development and but tracking platform for SWITCH projects"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Forge: Project Hosting Platform"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJAMzTQ7ZX7H85MA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2ZvcmdlLnN3aXRjaC5jaDAeFw0xMzA2MDYwNjM5MjhaFw0xNjA2MDUwNjM5\nMjhaMBoxGDAWBgNVBAMTD2ZvcmdlLnN3aXRjaC5jaDCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAMRsrEbfa2dByTHw8nNmWXKluBIqNBddjm2OOssE0dIJ\nPHokGICd3fh9TvoRiB1T5xECoGDM3TmzxlFeS8a+KDSeI58lUj3ZOjjMx8c/S/5U\nyyZYkXNBvTTVXKEWVA+3SEDc92aPeUldK6D4vWwx1EeWqVxO/LoNOi5ZlkPES5qL\n5sXEAl6YFEK6Z65WOEO/KVCdBJfCooWUH3vnl2y/k1u9Iybt2sO/ugXL9ltgmdXF\no+768lPn1mpME6bvaHaJ5QlDrwXYvCusZD6PBeY8eDyeuXbA3QI9TC2L8Nc/EQgL\nLbFOH7qC1zmW5VwPROrTrKb4XTixuju57lwuoWXTz2cCAwEAAaNhMF8wPgYDVR0R\nBDcwNYIPZm9yZ2Uuc3dpdGNoLmNohiJodHRwczovL2ZvcmdlLnN3aXRjaC5jaC9z\naGliYm9sZXRoMB0GA1UdDgQWBBRInInngJvjyAHf4YVeGVTNbhSHQjANBgkqhkiG\n9w0BAQUFAAOCAQEAHw9YM3UKHdvpA2bMp1MoB765kRHU58ydqf51ydskOCpeZfv8\npTw+kbvEsE1c2RbjcQ6oB5KXh5qA/jB8Ig/Ur/lN9ben25w70rcNJmt6bxbXKXVn\nBDg+G/oxuX8JS7BTlt9oz7UKuQYA7jcdmai1TgLe/ITzX4ieEWcErlf3CR4QLo6v\nLcIY8wseU5bZaSoQLD3O1sTGsRa68TO8RgJw2REWVPbt/wDRHQut2n/+P/3dam5i\nd3GxkhfzcE0Wj9lX4dzlC6CqKBdAF8UxXYAf3BDVjheesYf2Ps1iy3KW7XBX0Lci\nD5s3OfoyrsZf5VHSjcxoteZ+NQBmcCgYkgjzXQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://forge-dev.switch.ch/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://forge.switch.ch/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://zeya.switch.ch/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://forge-dev.switch.ch/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://forge.switch.ch/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://zeya.switch.ch/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://forge-dev.switch.ch/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://forge.switch.ch/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://zeya.switch.ch/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://forge-dev.switch.ch/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://forge.switch.ch/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://zeya.switch.ch/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "12"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://forge-dev.switch.ch/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "13"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://forge.switch.ch/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "14"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://zeya.switch.ch/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "15"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://forge-dev.switch.ch/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "16"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://forge.switch.ch/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "17"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://zeya.switch.ch/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "18"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Forge: Project Hosting Platform"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Serves as project development and but tracking platform for SWITCH projects"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ufgd.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Service Desk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sd@ufgd.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ufgd.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDtDCCApwCAQAwDQYJKoZIhvcNAQEFBQAwgZ8xNzA1BgNVBAoTLlVGR0QgLSBV\nbml2ZXJzaWRhZGUgRmVkZXJhbCBkYSBHcmFuZGUgRG91cmFkb3MxDTALBgNVBAsT\nBENPSU4xETAPBgNVBAcTCERvdXJhZG9zMRswGQYDVQQIExJNYXRvIEdyb3NzbyBk\nbyBTdWwxCzAJBgNVBAYTAkJSMRgwFgYDVQQDEw9pZHAudWZnZC5lZHUuYnIwHhcN\nMTQwNjA1MTIwOTMwWhcNMTkwNjA0MTIwOTMwWjCBnzE3MDUGA1UEChMuVUZHRCAt\nIFVuaXZlcnNpZGFkZSBGZWRlcmFsIGRhIEdyYW5kZSBEb3VyYWRvczENMAsGA1UE\nCxMEQ09JTjERMA8GA1UEBxMIRG91cmFkb3MxGzAZBgNVBAgTEk1hdG8gR3Jvc3Nv\nIGRvIFN1bDELMAkGA1UEBhMCQlIxGDAWBgNVBAMTD2lkcC51ZmdkLmVkdS5icjCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMqNLCdmjAeN7pKaJ68gXkdj\nNE/hAudGd/f5o1omQTsYsBtpBs5M8awzqVkWonX2HZt+OrozxYfueACKECmzuA78\n5EGoRjl5Zj4UiOLqNYjzKOgUg3BtO2+W+8xEQ6S//zUNeqnEEyDllLy1JoSPbID1\n68sAiypFqQ/DN4MNdTQ8Tv8O5X1QDp5NWrqcCjYyMmmUk+dQyPaTXTzBpB5uO7EZ\nMMMXsfl8FUmo/iO0GZa/VrvTKd/92SZh7TQGttv6ju2DVQbo2CWofRavs8kesRKR\nHGwhBlVX+Q4XD07cyh1+RZVy5Wn895vVmstyPgA91AHBiOKFK2jg0+Cut7VKDPEC\nAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAmJkwUFwtyBI7Z9/mJpGkhNWNlGSS3l/0\nhi1NBYUn3vP16egcj+Xc6TVhayPB+D1E4nQvHI4CZ1tQFmjXIEtFIi9gUZFKC42y\nQOWyylrMMEy+wPYbdHsSkzKSzJE0+nN0KFzJCJkU61lTLPjiiq+mSiJny4u4XtUK\nQ97JwAlBXwmtN3HtQpcoK5DI4xa8RCuyU+fyV3skMNaS0JMm4iZHGB/IDuiv6AXy\nYFjfuvCwAgvQMVFWpzop1reFYPsKekFuixpcbG7X366kp2W1mTl3cunPjRP0ea1M\nNmSSKOjYv7Dwun7FmlO9lKnOxg4e2JD49bSoRIB2zTaic8zKh+lCwQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ufgd.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ufgd.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ufgd.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ufgd.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ufgd.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ufgd.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ufgd.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ufgd.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufgd.edu.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufgd.edu.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFGD - Universidade Federal da Grande Dourados"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFGD - Universidade Federal da Grande Dourados"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFGD - Universidade Federal da Grande Dourados"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFGD - Universidade Federal da Grande Dourados"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDtDCCApwCAQAwDQYJKoZIhvcNAQEFBQAwgZ8xNzA1BgNVBAoTLlVGR0QgLSBV\nbml2ZXJzaWRhZGUgRmVkZXJhbCBkYSBHcmFuZGUgRG91cmFkb3MxDTALBgNVBAsT\nBENPSU4xETAPBgNVBAcTCERvdXJhZG9zMRswGQYDVQQIExJNYXRvIEdyb3NzbyBk\nbyBTdWwxCzAJBgNVBAYTAkJSMRgwFgYDVQQDEw9pZHAudWZnZC5lZHUuYnIwHhcN\nMTQwNjA1MTIwOTMwWhcNMTkwNjA0MTIwOTMwWjCBnzE3MDUGA1UEChMuVUZHRCAt\nIFVuaXZlcnNpZGFkZSBGZWRlcmFsIGRhIEdyYW5kZSBEb3VyYWRvczENMAsGA1UE\nCxMEQ09JTjERMA8GA1UEBxMIRG91cmFkb3MxGzAZBgNVBAgTEk1hdG8gR3Jvc3Nv\nIGRvIFN1bDELMAkGA1UEBhMCQlIxGDAWBgNVBAMTD2lkcC51ZmdkLmVkdS5icjCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMqNLCdmjAeN7pKaJ68gXkdj\nNE/hAudGd/f5o1omQTsYsBtpBs5M8awzqVkWonX2HZt+OrozxYfueACKECmzuA78\n5EGoRjl5Zj4UiOLqNYjzKOgUg3BtO2+W+8xEQ6S//zUNeqnEEyDllLy1JoSPbID1\n68sAiypFqQ/DN4MNdTQ8Tv8O5X1QDp5NWrqcCjYyMmmUk+dQyPaTXTzBpB5uO7EZ\nMMMXsfl8FUmo/iO0GZa/VrvTKd/92SZh7TQGttv6ju2DVQbo2CWofRavs8kesRKR\nHGwhBlVX+Q4XD07cyh1+RZVy5Wn895vVmstyPgA91AHBiOKFK2jg0+Cut7VKDPEC\nAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAmJkwUFwtyBI7Z9/mJpGkhNWNlGSS3l/0\nhi1NBYUn3vP16egcj+Xc6TVhayPB+D1E4nQvHI4CZ1tQFmjXIEtFIi9gUZFKC42y\nQOWyylrMMEy+wPYbdHsSkzKSzJE0+nN0KFzJCJkU61lTLPjiiq+mSiJny4u4XtUK\nQ97JwAlBXwmtN3HtQpcoK5DI4xa8RCuyU+fyV3skMNaS0JMm4iZHGB/IDuiv6AXy\nYFjfuvCwAgvQMVFWpzop1reFYPsKekFuixpcbG7X366kp2W1mTl3cunPjRP0ea1M\nNmSSKOjYv7Dwun7FmlO9lKnOxg4e2JD49bSoRIB2zTaic8zKh+lCwQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFGD - Universidade Federal da Grande Dourados"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFGD - Universidade Federal da Grande Dourados"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufgd.edu.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufgd.edu.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFGD - Universidade Federal da Grande Dourados"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFGD - Universidade Federal da Grande Dourados"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sci-bath.calpendo.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Robinson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul@exprodo.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Robinson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul@exprodo.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sci-bath.calpendo.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-09-14T14:30:23Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Calpendo for University of Bath"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.exprodo.com"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Exprodo Software Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sci-bath.calpendo.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sci-bath.calpendo.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sci-bath.calpendo.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sci-bath.calpendo.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sci-bath.calpendo.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sci-bath.calpendo.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sci-bath.calpendo.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sci-bath.calpendo.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sci-bath.calpendo.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Core facility management, booking system and web-based database for research/clinical facilities."
                  }
                ],
                "logo": [
                  {
                    "text": "https://downloads.exprodo.com/images/exprodo-software_271x100.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "271"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Calpendo for University of Bath"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIJALCR79ZDW2xvMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHNoaWIuZXhwcm9kby5jb20wHhcNMTUwNjIyMTUyMTAxWhcNMjUwNjE5MTUy\n\t\t\t\t\t\tMTAxWjAbMRkwFwYDVQQDExBzaGliLmV4cHJvZG8uY29tMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAlihJNaZPZ3oGM5NQlpgwJUJxlWZ8rbWrx9Kk5rPB\n\t\t\t\t\t\t4Fb0C6CH+YIOKHb9sxVXPL5Vi9JypYE0Y7JRFEKf7qzbFNTEDAKhq0hjJ+XMWiVq\n\t\t\t\t\t\tPJjbKYW4LJtM05DoPpTe/gKZJRaktGUDGu8m5ifLtd7klhFQmV0duDriDEPiW4ik\n\t\t\t\t\t\tLeYZGiReIkvWSx4kFnQbERYuyrjXPOnhKw8pnv4HuzR/Js4tmUQbMy9VPbjbWSET\n\t\t\t\t\t\to2x9TfCubitIiOguXNGU8hcOv+ys/sWKTddPQ8208qpsfQLo+YSm9NmYDn3bJ3tg\n\t\t\t\t\t\tSdA/9OTLJSjTZrz7RUZUeCYF/yv0vhRpicDDg1Ym8kdtCQIDAQABo2MwYTBABgNV\n\t\t\t\t\t\tHREEOTA3ghBzaGliLmV4cHJvZG8uY29thiNodHRwczovL3NoaWIuZXhwcm9kby5j\n\t\t\t\t\t\tb20vc2hpYmJvbGV0aDAdBgNVHQ4EFgQU7xBaV9vU2BCTDlQLhTkL5L6/1ckwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBAChUHGR1vS+giyhBJLy6gvfWFpfmo6dJlVn9zTIiztus\n\t\t\t\t\t\tSNX3AR7Xe3KLO+YV/8r1vUz5WO+xnUwFQd7Et20M5oeeZqbDqyPJqynepUZ3NeE5\n\t\t\t\t\t\tGfzERa8Rdvr6t6HoY0H19u0IMiMemtxQpFDt2uLtkawJLw7L3A2hUdbVta8MyUAQ\n\t\t\t\t\t\t7WV7raxbNae56DlNuivOY2kkEl9T39xiLNpQ4cHtB2Z1uGLxPcE49j1AzfAM5ugk\n\t\t\t\t\t\t29ai5m2neGiTzsvlEvw88pW7CMGcfZEPNsDA4zbQNTAu0FYIhrP60+OifLLZoMen\n\t\t\t\t\t\tlT/unHR4GJe4dtKbypAo6cvgW2Uu7aCV0wO0ni7MiCE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sci-bath.calpendo.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sci-bath.calpendo.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sci-bath.calpendo.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sci-bath.calpendo.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sci-bath.calpendo.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sci-bath.calpendo.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Calpendo for University of Bath"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "http://birk.wayf.dk/birk.php/sts.statsbiblioteket.dk/adfs/services/trust",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://birk.wayf.dk/birk.php/sts.statsbiblioteket.dk/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2015-06-03T11:53:23Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/sts.statsbiblioteket.dk/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://birk.wayf.dk/birk.php/sts.statsbiblioteket.dk/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "statsbiblioteket.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Statsbiblioteket"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "State and University Library"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "statsbiblioteket.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdYCAQcwDQYJKoZIhvcNAQELBQAwPTE7MDkGA1UEAwwyaHR0cDovL3N0\ncy5zdGF0c2JpYmxpb3Rla2V0LmRrL2FkZnMvc2VydmljZXMvdHJ1c3QwHhcNMTUw\nMTAxMDAwMDAwWhcNMjUxMjMxMjM1OTU5WjA9MTswOQYDVQQDDDJodHRwOi8vc3Rz\nLnN0YXRzYmlibGlvdGVrZXQuZGsvYWRmcy9zZXJ2aWNlcy90cnVzdDCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMeIDApqEFO4jhn4gnWuA54SIILLdtH1\nAh7cGkKx6MUJTmtLORYA2pW5zU8N+nQl0hmGs9eyYMlAyaJ08IY8gNAqj5uT5p/f\n4RQVL8j/7fmxIFfa9/6HUMe9lX2OzOealJWOnsdn9ag9YHKRYEk7QA5WbMHnOVqq\nRLfonvr7DF6vB2m4TFWdhI13vdL4DJP8Rn61cA77qVDwUv9gyUmdSRJpKotIcXLT\nUPaoE2ZhHAGkJLr91RnLGLS3mPyCEpQPgEc5lVq+frknrZwl1eI5wxHJQAinnsZd\nCsvrcq2uMhxd12r4JnJnm3fsR1Q4jPjaOgVzLvcwU6e3KeUoS87DUEkCAwEAATAN\nBgkqhkiG9w0BAQsFAAOCAQEAlfi/VceCvi+u/tiaZn3se2XtRmoG3YoPQtwTMPPm\nuwRGxzxZAoRMpFbYOL1I06LRaYQM8tqGtX0sNw+z1RSV0oX5NxDs0yxSmvuUqJy+\n6Uqi6sonAmhayTD6ndNc+O2TCgZAKN8AyHPidY/1Th1T8vM4XuvRHT1kiyoQztn4\n71Qr47kSditvTCGawFd2Q3uGUVHf/w7mKHmnSpdhew3LtbDhbIw84KJwYUaPwpcW\nu9xaC+EdRNA3uXhqdF1fUEvW6mJTef2ykcBErEgLgtTTbAM6KuKrdInkJp/XCdbE\nb45SXMc+awoz7kMadUeuovVtd6ETEsnnNquJ7navnN/e7w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Statsbiblioteket"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "State and University Library"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.statsbiblioteket.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://en.statsbiblioteket.dk"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Statsbiblioteket"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "State and University Library"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.vu-wien.ac.at/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+43 1 25077 1602"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cernohorsky"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Wolfgang.Cernohorsky@vu-wien.ac.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Wolfgang"
          }
        }
      ],
      "entity_id": "https://idp.vu-wien.ac.at/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://eduid.at/policy/mdrps-20140606"
              }
            ],
            "registration_instant": "2008-11-27T16:13:02Z",
            "registration_authority": "http://eduid.at",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://aai.dfn.de/category/vetmed-member"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUArxd4kLebWsQSo73wqw//qDah+UwDQYJKoZIhvcNAQEF\nBQAwHDEaMBgGA1UEAxMRaWRwLnZ1LXdpZW4uYWMuYXQwHhcNMDgxMTIxMDkyNzQy\nWhcNMjgxMTIxMDkyNzQyWjAcMRowGAYDVQQDExFpZHAudnUtd2llbi5hYy5hdDCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJP9YiA5hoGWj3EQVMD/FzTa\nGxKmYW7yrE2IEcytXZs80z7g00WDfkvgXxPW8p8/djs2EW6Qb0Mjt3Q3U0pXSWkb\nxSsYXZyBzRpyFxeJEIMKgqAkYG2Ka9War/XJTzOZ9VjEspxgm4ROD1L8tA/6rS5o\nMwmwgKW/xowmNC+M+jnCxjZ664XqhoqZowxOSMSGJJQ8RFizmoI1Zn7XIcXQXxjF\nhsMyvpid0uYbyh5kKF+f/DyyPisvsSgeDXZgkaooCcuR70y1lOSQe9XIGsg8LRBE\nniumfn3H7CbzDfAyPar1SkuSGOR79io5ZBSSNLw05rYLWLZED0BkMl5vCQOlAeEC\nAwEAAaNpMGcwRgYDVR0RBD8wPYIRaWRwLnZ1LXdpZW4uYWMuYXSGKGh0dHBzOi8v\naWRwLnZ1LXdpZW4uYWMuYXQvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFO0XxOhl\nz8mFCvsOavIhT5M47VckMA0GCSqGSIb3DQEBBQUAA4IBAQBAbvWWzPpHX9WvPdH/\nkxg72syav82qGs94YvRugz7xQrKe9+qn/0hT8/ln0ROstr3q/1Ah9b5XDQr3cb37\nDQOuMjSu8BW0RrvZbuoHWzS3J4Ay2iAIA54fo/g9sq8xlhkDN/N+ySnhWjcJi1ag\ntnd5Kz76fXuLhdnT1jjV6e3YnvBKD7F2sKUJdm8KErwfa3IR2XpTiiCnu+5VogJZ\n1QE5FJMTgKAzci109QuYqSDgqMbBs38nU95tsSN7M8B43FtEOw4dnrz9im+Sc4yK\nIfN31Zc1iB2M7lKMIc7i9VqM+5TXp4mrJwTyl0u20ITLhxu1SNgyZyeQXMHLD8Bl\n1Tdv"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vetmeduni.ac.at"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.vu-wien.ac.at:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.vu-wien.ac.at:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.vu-wien.ac.at/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.vu-wien.ac.at/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.vu-wien.ac.at:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.vu-wien.ac.at/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.vu-wien.ac.at/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.vu-wien.ac.at/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.vu-wien.ac.at/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.vu-wien.ac.at:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.vu-wien.ac.at:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "vetmeduni.ac.at"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.vetmeduni.ac.at/"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.vetmeduni.ac.at/en/"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.vetmeduni.ac.at/favicon.ico",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://www.vetmeduni.ac.at/fileadmin/vetmed/img/logo.gif",
                    "height": "69",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "231"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Veterin\u00e4rmedizinische Universit\u00e4t Wien"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Veterinary Medicine, Vienna"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUArxd4kLebWsQSo73wqw//qDah+UwDQYJKoZIhvcNAQEF\nBQAwHDEaMBgGA1UEAxMRaWRwLnZ1LXdpZW4uYWMuYXQwHhcNMDgxMTIxMDkyNzQy\nWhcNMjgxMTIxMDkyNzQyWjAcMRowGAYDVQQDExFpZHAudnUtd2llbi5hYy5hdDCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJP9YiA5hoGWj3EQVMD/FzTa\nGxKmYW7yrE2IEcytXZs80z7g00WDfkvgXxPW8p8/djs2EW6Qb0Mjt3Q3U0pXSWkb\nxSsYXZyBzRpyFxeJEIMKgqAkYG2Ka9War/XJTzOZ9VjEspxgm4ROD1L8tA/6rS5o\nMwmwgKW/xowmNC+M+jnCxjZ664XqhoqZowxOSMSGJJQ8RFizmoI1Zn7XIcXQXxjF\nhsMyvpid0uYbyh5kKF+f/DyyPisvsSgeDXZgkaooCcuR70y1lOSQe9XIGsg8LRBE\nniumfn3H7CbzDfAyPar1SkuSGOR79io5ZBSSNLw05rYLWLZED0BkMl5vCQOlAeEC\nAwEAAaNpMGcwRgYDVR0RBD8wPYIRaWRwLnZ1LXdpZW4uYWMuYXSGKGh0dHBzOi8v\naWRwLnZ1LXdpZW4uYWMuYXQvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFO0XxOhl\nz8mFCvsOavIhT5M47VckMA0GCSqGSIb3DQEBBQUAA4IBAQBAbvWWzPpHX9WvPdH/\nkxg72syav82qGs94YvRugz7xQrKe9+qn/0hT8/ln0ROstr3q/1Ah9b5XDQr3cb37\nDQOuMjSu8BW0RrvZbuoHWzS3J4Ay2iAIA54fo/g9sq8xlhkDN/N+ySnhWjcJi1ag\ntnd5Kz76fXuLhdnT1jjV6e3YnvBKD7F2sKUJdm8KErwfa3IR2XpTiiCnu+5VogJZ\n1QE5FJMTgKAzci109QuYqSDgqMbBs38nU95tsSN7M8B43FtEOw4dnrz9im+Sc4yK\nIfN31Zc1iB2M7lKMIc7i9VqM+5TXp4mrJwTyl0u20ITLhxu1SNgyZyeQXMHLD8Bl\n1Tdv"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Veterin\u00e4rmedizinische Universit\u00e4t Wien"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Veterinary Medicine Vienna"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vetmeduni.ac.at/de/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.vetmeduni.ac.at/en/"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Veterin\u00e4rmedizinische Universit\u00e4t Wien"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Veterinary Medicine Vienna"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.unimore.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:supporto.identity@unimore.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.unimore.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2009-12-31T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAJBITnJoX92EsdoWjSdjb3G2d4VwMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC51bmltb3JlLml0MB4XDTEwMDEyNjEzMzg0MloX\nDTMwMDEyNjEzMzg0MlowGTEXMBUGA1UEAxMOaWRwLnVuaW1vcmUuaXQwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDAKvIYSyrl0QfPfFE+SlhVJ5RW7nJ7\nsDkRzEZS2q2W3Nm3PtzidHNNxH3yzely2oyOXd6PVsx/ky5KndOY9GfSm1jFdmAX\n7fwFhXwFdlPLrvSL4iFMPR966z6R7OF+Oa/kpUdGPXuAVau61KOX7wqPsuZ7f7PX\nDaGRdqKyHEBNm9XehmYukjmwmLJSfd9R1+HUfP88khxYZD7CYHX4wU2Qp5KE7OIb\ng6ZGsqRYaCkGSYqQnsJjXGvyAU1BgPBFPdsn2X/Gxz2U06JvhnvCJv1JlzIrWlsj\n3M8/HF+celfuG7+qr1vTALoNeXypHFq+y4xypu+r7lWflcadx8KSPlfzAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC51bmltb3JlLml0hiVodHRwczovL2lkcC51bmlt\nb3JlLml0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBT/4cn1m4OFDg3Iv8CDfULK\n1s8JljANBgkqhkiG9w0BAQUFAAOCAQEAq37LOUh+3GFcqxwZKBiHbbudxRFRb7Hr\nuvXTpGuuV+eb/5lE7gCzNsXGV07OM6s+of45Hd2c9rVD8+xnSZvPkUGy30USVn/s\nD/mWS08gIL09LHfrgvM3kRGxuE6kyVdTuwTdtkcSXjYtm+RZztp95w9LV8n3Jve1\np8TJi7Tjt4LZfVL5h+sDSA+FT/jLLYhLN0uy3YOBhIbdVgsDBESeM3jyOTiHxbxm\nO590yv35UKIENt7Ov87uykF3frwjIjMEBffRGYsgmrbl3HdbA5yUDs+9VQS/CXKg\nApsMFkXxazWEsSuKY+zrMAimGDVPmAjswYuG9Jl3PICYIciqz2Ll+g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unimore.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unimore.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unimore.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.unimore.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unimore.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.unimore.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unimore.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unimore.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unimore.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unimore.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unimore.it/idem.html"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unimore.it/international/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Modena e Reggio Emilia"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 degli Studi di Modena e Reggio Emilia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for University of Modena e Reggio Emilia users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti dell'Universit\u00e0 degli Studi di Modena e Reggio Emilia"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.unimore.it/unimore_80_60.png",
                    "lang": "it",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idp.unimore.it/unimore_80_60.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.unimore.it/idem.html"
                  }
                ]
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "unimore.it"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "unimo.it"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "155.185.0.0/16"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAJBITnJoX92EsdoWjSdjb3G2d4VwMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC51bmltb3JlLml0MB4XDTEwMDEyNjEzMzg0MloX\nDTMwMDEyNjEzMzg0MlowGTEXMBUGA1UEAxMOaWRwLnVuaW1vcmUuaXQwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDAKvIYSyrl0QfPfFE+SlhVJ5RW7nJ7\nsDkRzEZS2q2W3Nm3PtzidHNNxH3yzely2oyOXd6PVsx/ky5KndOY9GfSm1jFdmAX\n7fwFhXwFdlPLrvSL4iFMPR966z6R7OF+Oa/kpUdGPXuAVau61KOX7wqPsuZ7f7PX\nDaGRdqKyHEBNm9XehmYukjmwmLJSfd9R1+HUfP88khxYZD7CYHX4wU2Qp5KE7OIb\ng6ZGsqRYaCkGSYqQnsJjXGvyAU1BgPBFPdsn2X/Gxz2U06JvhnvCJv1JlzIrWlsj\n3M8/HF+celfuG7+qr1vTALoNeXypHFq+y4xypu+r7lWflcadx8KSPlfzAgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC51bmltb3JlLml0hiVodHRwczovL2lkcC51bmlt\nb3JlLml0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBT/4cn1m4OFDg3Iv8CDfULK\n1s8JljANBgkqhkiG9w0BAQUFAAOCAQEAq37LOUh+3GFcqxwZKBiHbbudxRFRb7Hr\nuvXTpGuuV+eb/5lE7gCzNsXGV07OM6s+of45Hd2c9rVD8+xnSZvPkUGy30USVn/s\nD/mWS08gIL09LHfrgvM3kRGxuE6kyVdTuwTdtkcSXjYtm+RZztp95w9LV8n3Jve1\np8TJi7Tjt4LZfVL5h+sDSA+FT/jLLYhLN0uy3YOBhIbdVgsDBESeM3jyOTiHxbxm\nO590yv35UKIENt7Ov87uykF3frwjIjMEBffRGYsgmrbl3HdbA5yUDs+9VQS/CXKg\nApsMFkXxazWEsSuKY+zrMAimGDVPmAjswYuG9Jl3PICYIciqz2Ll+g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 di Modena e Reggio Emilia"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Modena e Reggio Emilia"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unimore.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unimore.it/international/"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 di Modena e Reggio Emilia"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Modena e Reggio Emilia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.goodwin.edu/idp/saml",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "simon@9starresearch.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon Lee"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Mnowlan@goodwin.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Marilyn Nowlan"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.goodwin.edu/idp/saml",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.goodwin.edu/saml/saml2/slo",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.goodwin.edu/saml/saml1/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.goodwin.edu/saml/saml2/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "goodwin.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Goodwin College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBzCCAe+gAwIBAgIJANwMbYMK70vwMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMMD2lkcC5nb29kd2luLmVkdTAeFw0xMzA4MTIxNDQ2NTJaFw0yMzA4MTIxNDQ2\nNTJaMBoxGDAWBgNVBAMMD2lkcC5nb29kd2luLmVkdTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAM7Sif8QaDrfgy5Y6uWlq5FmYh54l7f9l/MgaYTll+VO\nI4zVFiNg7JD1+g48eCc9l+l2wxeTV/lJ3heTiQiuqZl9V4ZCsgMfQwfwu2XU9HjQ\nZcrvJbewicpy/gBnrT9VH0ez8yXsO8qt0CrPIOgGMA1OVgOcaXPHrDxyZwWgUgFT\nQoph5m8h2h5mJm0zrwGhU1/o3W/g0DdojzjL4ytQ6AhENtjj/su1C50pq93fMD/y\naPMW7CPKd4jVzXL7elzNCJ7HeHXuOR26/tOiCyZIwED6ais1syHlN3K+pZBJQiY8\nZx0mGl39chRF6JnH+mPJX/bbEY1rp6aqbiNM/ZgfYTsCAwEAAaNQME4wHQYDVR0O\nBBYEFP4r5oKBA7L4RfkrOHo0TA06ho/EMB8GA1UdIwQYMBaAFP4r5oKBA7L4Rfkr\nOHo0TA06ho/EMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEBAFDZfoCW\ndTPKWtBCRq1NIeJKq0lPBn/xrw64eSzKQwMdWQasuuSeCEkDqkMDmohe/sLxMrjv\nHMWOrLuPuZY8/8MUojLjGZQJxVtLkiXyZtkNvSZeRC2k31ADtMfpAQ4i2w7y5s7q\nLS72WeChkhTkAJrvTE/XtCI+OH9o23JLnXX0rLegXeiFWCdSOAJNon1TxQyAeNIj\nZr+Vr8S5ZCVqxbBpIOO/hB+cLQnFzt13cdc60L/YVV2UpCrFx+wOoanPpStFiRWL\nCIiU7ZioGEoYcgH4XdXKLBZfS8PQqwNFlAtHZ59KLl6Mbtzd9dZcdHS5toIbot4V\nmftEeS74CI/fFwQ="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Goodwin College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.goodwin.edu/default_flash.asp"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Goodwin College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://federationrenater.univ-montp2.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lo\u00efc Bonavent"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "loic.bonavent@univ-montp2.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Nicolas Arles"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "nicolas.arles@univ-montp2.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federationrenater.univ-montp2.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-07-02T16:09:31Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federationrenater.univ-montp2.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federationrenater.univ-montp2.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://federationrenater.univ-montp2.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-montp2.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-montp2.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Montpellier 2"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Montpellier 2"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDbTCCAlWgAwIBAgIUd7qthRFKphaqjAKa3OfPkTgoQCgwDQYJKoZIhvcNAQEF\nBQAwKzEpMCcGA1UEAxMgZmVkZXJhdGlvbnJlbmF0ZXIudW5pdi1tb250cDIuZnIw\nHhcNMDkwMTI5MTYwOTI1WhcNMjkwMTI5MTYwOTI1WjArMSkwJwYDVQQDEyBmZWRl\ncmF0aW9ucmVuYXRlci51bml2LW1vbnRwMi5mcjCCASIwDQYJKoZIhvcNAQEBBQAD\nggEPADCCAQoCggEBAKbCEkUY6PCN5cAR9Xm2tLH78tkAas47YTI8ExEkF7VBiusg\nI+xopi8kCGN3wXufANOyfHI3zsphl3eLlwhdsF6c+IbegBywKSnDfMimvB3YWFbh\njYOMOZOiFEphCdB2p6hvIKk+YFXH0m4KT1DVHMSzX8CwvXJ2am9lyI6wQdYShFdM\nzlDIqtQJR48n6HUlDQnWwq9jXxS/rXOOUzIe6w53cG6/mNMutXBoGfMVNSIoNSEC\nNHBD9RSwTJ5bzv2S2wiBjnCOj5vOpfysZ+duZgEGWM8JNpapB6M4YLoPr3OhcU+e\npRahD0suZZUqU0R14hMJgEh2phxXF5pttQM0dwkCAwEAAaOBiDCBhTBkBgNVHREE\nXTBbgiBmZWRlcmF0aW9ucmVuYXRlci51bml2LW1vbnRwMi5mcoY3aHR0cHM6Ly9m\nZWRlcmF0aW9ucmVuYXRlci51bml2LW1vbnRwMi5mci9pZHAvc2hpYmJvbGV0aDAd\nBgNVHQ4EFgQUWzhOl/tjSF/4azXQikbyjjVrPMEwDQYJKoZIhvcNAQEFBQADggEB\nAB4ts6C72K9/Wi1Tq91wHJdE83rJrfNpAVyZ1qKUSx6Okrkjga2keVBHSBXuNdfr\neYkjMNbj2xLbX+BxKRxMgUnBjmaAdfOrOJFgsN/cqc3TEYo8BQZ7MiCOvzJWAgPV\n9TVhrm5qRx8AICoXee0NenuxWoSKYzH2pv4VIkGM0IIRVkDrkOxbxTQCk3Y0yUZ4\niPn+hAxA9eFoYosSr16IJsBRCYiS0Rdr61YUCLgqf87nhWMbpKz5aPc3S0s0SEqa\ndo3SW6CiYjzJ2ZYrYdmDzP0OuN/ZZK9gzH2hyOFaKlDJRKQtkdZ7RKb2tik/PPD6\ncHXXZfLohck3GRQ/MJmd5x4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Montpellier 2"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-montp2.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Montpellier 2"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp2.port.ac.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@port.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "University IT Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Burland"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:phil.burland@port.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Phil"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp2.port.ac.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-12-19T15:19:11Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.port.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.port.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "port.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTjCCAjagAwIBAgIIftqCJVvJwqUwDQYJKoZIhvcNAQEFBQAwPjEhMB8GA1UE\n\t\t\t\t\t\tCgwYVW5pdmVyc2l0eSBvZiBQb3J0c21vdXRoMRkwFwYDVQQDDBBsb2dpbi5wb3J0\n\t\t\t\t\t\tLmFjLnVrMB4XDTE0MTAyODExNTcxMloXDTI0MTAyODExNTcxMlowPjEhMB8GA1UE\n\t\t\t\t\t\tCgwYVW5pdmVyc2l0eSBvZiBQb3J0c21vdXRoMRkwFwYDVQQDDBBsb2dpbi5wb3J0\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAk31FOVIiRM7z\n\t\t\t\t\t\tdB5k57jOpNV8XtPX9xHkG7QGfIgeQ1GXwmh6rRrvV9efqFHIpYJakQmN7D1txhj2\n\t\t\t\t\t\tKWgDCMF3tI47U/gcHs4q72V2ZMfxeAbcFdlsAuElScHENzgIRPqaNh2vg69Q3OOz\n\t\t\t\t\t\tHcFJ9jm0kHk0OMXmg2m9a8+Hm/3Vg4IxamOPgwdFarSYPq1jkSG7TatF/RaniQzw\n\t\t\t\t\t\tbBx7R0qc7DzPypf7PxqN+PHJ2NT7Fsva/NX5xpjzdbgrA+WaMdxLo3RM+nOhf/ZR\n\t\t\t\t\t\tk9sYARRU3lMdaZJFXkkzXbFoEysyjH0qntyFAgDNF1UOdQCKRhUZCdwJCZ/txg0A\n\t\t\t\t\t\tVf1L6Q41YQIDAQABo1AwTjAdBgNVHQ4EFgQUGwjLRWjwjSNmYX7Q0R4d83V+Hu0w\n\t\t\t\t\t\tHwYDVR0jBBgwFoAUGwjLRWjwjSNmYX7Q0R4d83V+Hu0wDAYDVR0TBAUwAwEB/zAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAXHzPNejZlDRxS6S9WqhPYMA5j7WHyHnRmBfSerO4\n\t\t\t\t\t\trnHRqJrXiHdGdp5ARuX54UxvNFjkVgMyCeE1Esyun6eUtqedqwzq+BEHr4m6t3ex\n\t\t\t\t\t\tg/VroisodnXdOzgM13bwkiNsVJGRF9d4aDYLC6y+tyxY98k20vSyELEgHtiderYE\n\t\t\t\t\t\tG2GsiaSRvDIVRyXcESOkQl1NEgE6v/i/qZk/C/Fp87abpjiEHqVSGTt46E7g2QvW\n\t\t\t\t\t\tbEAQDQvzIRLwc0KO1ZzMvic8OtGthOT7Hc42JEscCf0ZYrE0tSfF0EM5LIImyAve\n\t\t\t\t\t\trFsygr8Oy/HFI1289KnDVG2bO0e6qtPveZKsOHtKVwbwAA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTjCCAjagAwIBAgIIftqCJVvJwqUwDQYJKoZIhvcNAQEFBQAwPjEhMB8GA1UE\n\t\t\t\t\t\tCgwYVW5pdmVyc2l0eSBvZiBQb3J0c21vdXRoMRkwFwYDVQQDDBBsb2dpbi5wb3J0\n\t\t\t\t\t\tLmFjLnVrMB4XDTE0MTAyODExNTcxMloXDTI0MTAyODExNTcxMlowPjEhMB8GA1UE\n\t\t\t\t\t\tCgwYVW5pdmVyc2l0eSBvZiBQb3J0c21vdXRoMRkwFwYDVQQDDBBsb2dpbi5wb3J0\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAk31FOVIiRM7z\n\t\t\t\t\t\tdB5k57jOpNV8XtPX9xHkG7QGfIgeQ1GXwmh6rRrvV9efqFHIpYJakQmN7D1txhj2\n\t\t\t\t\t\tKWgDCMF3tI47U/gcHs4q72V2ZMfxeAbcFdlsAuElScHENzgIRPqaNh2vg69Q3OOz\n\t\t\t\t\t\tHcFJ9jm0kHk0OMXmg2m9a8+Hm/3Vg4IxamOPgwdFarSYPq1jkSG7TatF/RaniQzw\n\t\t\t\t\t\tbBx7R0qc7DzPypf7PxqN+PHJ2NT7Fsva/NX5xpjzdbgrA+WaMdxLo3RM+nOhf/ZR\n\t\t\t\t\t\tk9sYARRU3lMdaZJFXkkzXbFoEysyjH0qntyFAgDNF1UOdQCKRhUZCdwJCZ/txg0A\n\t\t\t\t\t\tVf1L6Q41YQIDAQABo1AwTjAdBgNVHQ4EFgQUGwjLRWjwjSNmYX7Q0R4d83V+Hu0w\n\t\t\t\t\t\tHwYDVR0jBBgwFoAUGwjLRWjwjSNmYX7Q0R4d83V+Hu0wDAYDVR0TBAUwAwEB/zAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEAXHzPNejZlDRxS6S9WqhPYMA5j7WHyHnRmBfSerO4\n\t\t\t\t\t\trnHRqJrXiHdGdp5ARuX54UxvNFjkVgMyCeE1Esyun6eUtqedqwzq+BEHr4m6t3ex\n\t\t\t\t\t\tg/VroisodnXdOzgM13bwkiNsVJGRF9d4aDYLC6y+tyxY98k20vSyELEgHtiderYE\n\t\t\t\t\t\tG2GsiaSRvDIVRyXcESOkQl1NEgE6v/i/qZk/C/Fp87abpjiEHqVSGTt46E7g2QvW\n\t\t\t\t\t\tbEAQDQvzIRLwc0KO1ZzMvic8OtGthOT7Hc42JEscCf0ZYrE0tSfF0EM5LIImyAve\n\t\t\t\t\t\trFsygr8Oy/HFI1289KnDVG2bO0e6qtPveZKsOHtKVwbwAA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Portsmouth"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.port.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Portsmouth"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.it-tallaght.ie/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McCarrick"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Martin.McCarrick@it-tallaght.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McCarrick"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Martin.McCarrick@it-tallaght.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.it-tallaght.ie/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2010-11-08T00:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.it-tallaght.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.it-tallaght.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.it-tallaght.ie/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "it-tallaght.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.it-tallaght.ie/contactus"
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/itta.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "152"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Technology Tallaght"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.2903000,-6.3631789"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUYPVjSYp7op9s7Ie2DtEL+5ZzoCIwDQYJKoZIhvcNAQEF\nBQAwHTEbMBkGA1UEAxMSaWRwLml0LXRhbGxhZ2h0LmllMB4XDTExMDcyODEyMTQz\nOVoXDTMxMDcyODEyMTQzOVowHTEbMBkGA1UEAxMSaWRwLml0LXRhbGxhZ2h0Lmll\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmSmY3owkK4unuAmRmEZT\nEaRtCmksLa2Okjl9ulhhboHYNubqTfLt/12Jxd95Md9lUi7+KdyakU60kwgImj2w\nCBtFQAhP2MNXdvFB+wSbETyFfYacKdeyPRF6BONAnkn1QUZxmQQOGO0xjxjPccJm\nSPVknQW5xE6B7ZGuvQfnM3HxAE5tXCd5L2ZDBS6MkEX+KZnDmyhltlzJpvpeb23/\nj0sYHNPeBgIhByp7bTK6blVJO0UNMK+Ts9Fi118r7fJlP6VEGPFKPtyRnrACBamx\nNfRF2ncBOBfxla8mIx9XwNJkvaX2UMCrUrcN1WBoUTfKeQae55lTisaps7auln/5\nmwIDAQABo2swaTBIBgNVHREEQTA/ghJpZHAuaXQtdGFsbGFnaHQuaWWGKWh0dHBz\nOi8vaWRwLml0LXRhbGxhZ2h0LmllL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTo\nun8552N5PrTaJaM2AOMIuyJykTANBgkqhkiG9w0BAQUFAAOCAQEARXS+XY144D9N\nK1uz60zUXXF4Ij90+ljigGxOjcce0EMRI+Zqhfiq0mYGRr3z/yyir9/WDv8/U1bo\nivvfNqimHVEl821GC1Jnjw3sLwCCvwBaq91Y2Pqfu13nv9dpGOVIxsCeNGGFM4mv\nMORRBvK+bkMmhm5rNZb1zEDkCkSKGgdQLzd4sQO7M/f46XJmqffhNjQ6FysjZYyO\nfvQkMgjKXKvMuOcowJFd2qlyR5s9mkU/vlsuG/8X03M/XC7fQ9g/Z5AZiBmT5UR7\nTz1+RVaB+0GP8hZXw6p8CGDihXoX8rV0N4aSrnG/7oJOBsdL+liIEINf0MKqSHGH\nBf7NsJw2jQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Technology Tallaght"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.it-tallaght.ie/contactus"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Technology Tallaght"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:cru.fr:federation:utc.fr",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "federation-id@utc.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:cru.fr:federation:utc.fr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-06-04T14:19:04Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.utc.fr/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.utc.fr/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.utc.fr:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.utc.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.utc.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.utc.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "utc.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.utc.fr/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Universit\u00e9 de Technologie de Compi\u00e8gne (UTC)'s staff and students identity provider."
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identit\u00e9s fournies pour le personnel et les \u00e9tudiants de l'Universit\u00e9 de Technologie de Compi\u00e8gne (UTC)"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UTC - Universit\u00e9 de Technologie de Compi\u00e8gne"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UTC - Universit\u00e9 de Technologie de Compi\u00e8gne"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVALKUNv/nTVKQIuB1xMzl8BSvmMIvMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMMCmlkcC51dGMuZnIwHhcNMTUwNzEwMjIyODExWhcNMzUw\nNzEwMjIyODExWjAVMRMwEQYDVQQDDAppZHAudXRjLmZyMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAnOor4IQUhUVR7T0jZLvGNgX52dD6jLJFXgQDbF6a\np247hfjAi3bNhzC8GEY8bSpnUPv90PntGY+vRzO/qMa1z9DVS+DZSRmsQI7Ohgp+\nhgOIq9L7+8D0DAGj3vGhfvnIv2NeVuI+f4K4uOc5mnI0wmBq8f+icxEsehP2x9zE\nL/scx0fUhg+68lCc/Dk2qJH0z9P+1eTcAIvMG46OzRuEwk/qfcXShDs4Atj/b2dX\n9SHXz3wG4Y2Me2ZUOfHbrbtNkspBga/SdGYOgE4Bgo1mBGtU5AT6qW+RPJ2bcCIA\nbQEFWDEDQ6NvrfXpyO1KLLuBILd8ogEKh1wG/aePETiGVQIDAQABo1swWTAdBgNV\nHQ4EFgQUMUZKOhU5gB7iNmnhcC4zDqujKoMwOAYDVR0RBDEwL4IKaWRwLnV0Yy5m\ncoYhaHR0cHM6Ly9pZHAudXRjLmZyL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\nBQUAA4IBAQCDz2xzAmxO+TBVcgqOcoceVmD9G5QI2UzwFOGSuC31ILeYqGSN/Mwv\nqpjEwC1Msb+t9TGabAq1rgk1vok+1GISwFIN2AVr+GgIjQojmCyerntWGOdKFyOa\n52JvPUYN9HQVNOKLHTo0Ug1v9qTVGdYupj78xy8NYX1HRtBct8rj4QmrcFAWraHa\ntURWo1OcTcNS0KQcSRrxhNOl8+C3M1Enx9peJSSE25MgFZbeERzBm22PweFQNqr+\nlTMGjfitokokh3z4Mr+YgnPTSH/PLm2XuEbFIZLiWL60VrYyxBsMuBIJvk/xgMpU\nXaUj+MhAJNdwwHHIGwKjoAotbCEk+rTR"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAJniTskfMWtBbgn1nDzPa0dObhFfMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMMC2lkcDIudXRjLmZyMB4XDTE0MDkwOTE3MTgwN1oXDTM0\nMDkwOTE3MTgwN1owFjEUMBIGA1UEAwwLaWRwMi51dGMuZnIwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQChJP7adTd4jM4tVNHqfy8wqZIyax5XcxktD/dH\nTZRP949/SW78cBdhOb48iAUOoKptSXMbGCV7n5Vot2NGLwRxJ7DA+ngLhlGV0WS7\nzRf493yGMxvCm/oVCVSr7TuPDGlvGLGw8RmiCGfHXdBeWQ3UitNOnjjM8VoJEJFL\nOLN5dNIBny4WUXSEbvQil7Mtqt1EkZ6qMzJNnhyTZ66N+bPlZYfn+utgYVESCEM6\n8TO8sl1fAMigmM5CTvvoIzq4sjNQO9qr2FPKt5teyc/wnQd4KNG5n0iZzTcZPZBI\njB65WQckck6WFeivFo2za0hy+cQAoeFZQ8IWMFQnmPn7zDGNAgMBAAGjXTBbMB0G\nA1UdDgQWBBSyZxcO36hdIS1YmPncz3vrMUlK+jA6BgNVHREEMzAxggtpZHAyLnV0\nYy5mcoYiaHR0cHM6Ly9pZHAyLnV0Yy5mci9pZHAvc2hpYmJvbGV0aDANBgkqhkiG\n9w0BAQUFAAOCAQEAOkGmALzrLobKru+8b8LQKTyl/pL+DXHkwa6U0HVkGf8cOJzK\nfmHG8VYmGgcsRkD8kiVN0Kk3QNOuqFOG+fv096PYEmM8jwIxirH4H4YMP01Jdds0\nSmGHT2g4R8Ll446Jd2vkrMR0FXiYEoFM1DUB+b/tLARw4NQuIfooXBGzsVcLJucM\n7ZbFeSpPfDVWKkBPsk105We7BemyXJGpEhx12j7nd1TAK0p0T2P8XnMIDOaxrl0v\nv+C1uEftjADboIz5BDy5wIZITGG/yELlCVoLyBri2ozPaUFpEetbzKdmfcG6wk+z\n3zuwoSLKhPoHFPCoVMaxjYpXmPobZG6PumciJg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UTC - Universit\u00e9 de Technologie de Compi\u00e8gne"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.utc.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UTC - Universit\u00e9 de Technologie de Compi\u00e8gne"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://web.oriel.ox.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it-support@oriel.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it-support@oriel.ox.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://web.oriel.ox.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-11-16T16:12:22Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Oxford, Oriel College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oriel.ox.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Oxford"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://web.oriel.ox.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://web.oriel.ox.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://web.oriel.ox.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://web.oriel.ox.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://web.oriel.ox.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://web.oriel.ox.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC/TCCAeWgAwIBAgIJAM1GWdcimaKPMA0GCSqGSIb3DQEBBQUAMB0xGzAZBgNV\n\t\t\t\t\t\tBAMTEndlYi5vcmllbC5veC5hYy51azAeFw0xNTExMTAxMjQxMDRaFw0yNTExMDcx\n\t\t\t\t\t\tMjQxMDRaMB0xGzAZBgNVBAMTEndlYi5vcmllbC5veC5hYy51azCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBAL+gbrPC66dBinzrKiqL9VHf+sG3mv6BbanV\n\t\t\t\t\t\tKGAKuXZzHfgJvOvxr0q1DcbIjrhuFiP1w7G8eIJk2wSh699xNnI7PceclpKWCB0J\n\t\t\t\t\t\t19PbKMIM5RF0M0PJU4W1QjLZmFLKcj+fJbQHhD50jvgaECoSWo1Z0nmLYEF94hw+\n\t\t\t\t\t\t9xVoCASdegNe3peRL1NbUjIvfdd6OCj8o1QtAkrCBiH3HNHe4m5vu9t/EAlHVTlZ\n\t\t\t\t\t\tWtzHDLdPgwYJ+i/kl4ZiQRX1pYjOxPBHxSjh43uoKsqb/qkulHV7gTkwfVv7iUd9\n\t\t\t\t\t\tPKj7dVVgK6bpSR/2qPkdap1XLZRRZyiCKE5o3LElRn/0AevbEvECAwEAAaNAMD4w\n\t\t\t\t\t\tHQYDVR0RBBYwFIISd2ViLm9yaWVsLm94LmFjLnVrMB0GA1UdDgQWBBQO+H5D8rud\n\t\t\t\t\t\tH06/aqz/wM/uj4bK+DANBgkqhkiG9w0BAQUFAAOCAQEAqlbzy4HbCYgTTSnqtOxb\n\t\t\t\t\t\tDfN9FY1l8PSLKyG2qO9v8YWSuGnUvXWl5fiP5q2PjzThUOOKM4yWPQDI0QaN5N/+\n\t\t\t\t\t\tDu1/NY4gJy7LFzKAzBytl+jw82wHkb3OMoaMYEa5vL1EIBmeJhzkN4Zr5FQ+0ass\n\t\t\t\t\t\tK93VA9bjb3pm5c2emWQEtBKASCIUOnCqHOF9FqtCSne98k07mVH+E8d4UjSlzbBp\n\t\t\t\t\t\teOSODUc8FHyLaUNy44vM0IEwsoH66LCKctsw4B1taLxNgi3I7sJuxW6AYN5/dgT9\n\t\t\t\t\t\ttzJrFvKSNaYWk6SyEoDAYus7GsvcL+zzCKmKuXzzZgj8ih4GnUH6OtdNXvGz4YjU\n\t\t\t\t\t\tIA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://web.oriel.ox.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://web.oriel.ox.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://web.oriel.ox.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://web.oriel.ox.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://web.oriel.ox.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://web.oriel.ox.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://sso.mathletics.com/ukfederation",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:techsupport@3plearning.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:techsupport@3plearning.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.mathletics.com/ukfederation",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "3P Learning Limited: Mathletics"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.mathletics.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "3P Learning Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.mathletics.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.mathletics.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.mathletics.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sso.mathletics.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.mathletics.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAP4D/fTY0gATMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\n\t\t\t\t\t\tBAMTD3dpbi1vaDJvMW1tZDM5MzAeFw0xMDA3MDIxNDQzMThaFw0yMDA2MjkxNDQz\n\t\t\t\t\t\tMThaMBoxGDAWBgNVBAMTD3dpbi1vaDJvMW1tZDM5MzCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBAMy+Vo/nUmNICl1EaHkt4ufsLfVzxrlwyOGA24oGCKFu\n\t\t\t\t\t\tLjnWDFJDvj6QuT6k917FdFwDbzdflttObWI23WRdbptSoVb9Y4DBuaTCpTLxbcSl\n\t\t\t\t\t\tYJ16wlNGd8CFijxwIt9a/oMyQLOPzP+5DGnodBRXSG0xkEhXEPe2rDP5v1NvHErD\n\t\t\t\t\t\tNctMEGV9zBfrxbokDHeJH2xrO1OStSsIbngcY5IVCSneifJEz0HlGoUrVw5CRIBM\n\t\t\t\t\t\tFi4uoZYCQ9f7wPPvMb/GACYj441EXAvN1hAl4L/AmtrihUGmhA+45YXnvuGe3xOq\n\t\t\t\t\t\tBP0mxerTLBHZtedkWS5Wg3oZxCeIFQ3nS9ibB7h1UjMCAwEAAaM9MDswGgYDVR0R\n\t\t\t\t\t\tBBMwEYIPd2luLW9oMm8xbW1kMzkzMB0GA1UdDgQWBBQvlfJiq/7Uz+/L2t17aQ4L\n\t\t\t\t\t\tI8tR5zANBgkqhkiG9w0BAQUFAAOCAQEAkXHpy1kVpS7z+KKJYqjIJWHpJ8AEpn/9\n\t\t\t\t\t\tFP4ty2Y1cQVD6W/S31BoMOckY+SCxwzQZ/pnLXWenwbozRkDPnE9N4dw4hdpZyVz\n\t\t\t\t\t\ttM2/rWzaYj14qqnIO2QNU0s4PSdLYL7YeANYNdqSeUljFqN1qp+eQCaVs/EKHwFk\n\t\t\t\t\t\tclV69FtCaNVDaPCD2rQT+VzLdUc0PXGsSa6NS20kC9Ol3ZNdIY1OuA1eJNm6LEEb\n\t\t\t\t\t\tNWK1rVTqrnuIil6Sx2eifjXd8KSGi5N223oCZ4SV+Httbr+TmL2dTl+YNPn9DguP\n\t\t\t\t\t\tLkR1mUqyrB/LlLXkJ/GZyTYpfsN+AATxyzg5Jtsn3c8rbkkPf/KfZw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAP4D/fTY0gATMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\n\t\t\t\t\t\tBAMTD3dpbi1vaDJvMW1tZDM5MzAeFw0xMDA3MDIxNDQzMThaFw0yMDA2MjkxNDQz\n\t\t\t\t\t\tMThaMBoxGDAWBgNVBAMTD3dpbi1vaDJvMW1tZDM5MzCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBAMy+Vo/nUmNICl1EaHkt4ufsLfVzxrlwyOGA24oGCKFu\n\t\t\t\t\t\tLjnWDFJDvj6QuT6k917FdFwDbzdflttObWI23WRdbptSoVb9Y4DBuaTCpTLxbcSl\n\t\t\t\t\t\tYJ16wlNGd8CFijxwIt9a/oMyQLOPzP+5DGnodBRXSG0xkEhXEPe2rDP5v1NvHErD\n\t\t\t\t\t\tNctMEGV9zBfrxbokDHeJH2xrO1OStSsIbngcY5IVCSneifJEz0HlGoUrVw5CRIBM\n\t\t\t\t\t\tFi4uoZYCQ9f7wPPvMb/GACYj441EXAvN1hAl4L/AmtrihUGmhA+45YXnvuGe3xOq\n\t\t\t\t\t\tBP0mxerTLBHZtedkWS5Wg3oZxCeIFQ3nS9ibB7h1UjMCAwEAAaM9MDswGgYDVR0R\n\t\t\t\t\t\tBBMwEYIPd2luLW9oMm8xbW1kMzkzMB0GA1UdDgQWBBQvlfJiq/7Uz+/L2t17aQ4L\n\t\t\t\t\t\tI8tR5zANBgkqhkiG9w0BAQUFAAOCAQEAkXHpy1kVpS7z+KKJYqjIJWHpJ8AEpn/9\n\t\t\t\t\t\tFP4ty2Y1cQVD6W/S31BoMOckY+SCxwzQZ/pnLXWenwbozRkDPnE9N4dw4hdpZyVz\n\t\t\t\t\t\ttM2/rWzaYj14qqnIO2QNU0s4PSdLYL7YeANYNdqSeUljFqN1qp+eQCaVs/EKHwFk\n\t\t\t\t\t\tclV69FtCaNVDaPCD2rQT+VzLdUc0PXGsSa6NS20kC9Ol3ZNdIY1OuA1eJNm6LEEb\n\t\t\t\t\t\tNWK1rVTqrnuIil6Sx2eifjXd8KSGi5N223oCZ4SV+Httbr+TmL2dTl+YNPn9DguP\n\t\t\t\t\t\tLkR1mUqyrB/LlLXkJ/GZyTYpfsN+AATxyzg5Jtsn3c8rbkkPf/KfZw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.mathletics.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.mathletics.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.mathletics.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sso.mathletics.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.mathletics.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sso.mathletics.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sso.mathletics.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sso.mathletics.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sso.mathletics.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sso.mathletics.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://dmz-shib-dg-01.dmz.roehampton.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Eka"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:A.Eka@roehampton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Amos"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Eka"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:A.Eka@roehampton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Amos"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dmz-shib-dg-01.dmz.roehampton.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDejCCAmKgAwIBAgIVAJw0niI78J9LVDelS/WX6kLw2ONrMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMC4xLDAqBgNVBAMTI2Rtei1zaGliLWRnLTAxLmRtei5yb2VoYW1wdG9uLmFj\n\t\t\t\t\t\tLnVrMB4XDTA5MDQwNjEzNTgxOVoXDTI5MDQwNjEzNTgxOVowLjEsMCoGA1UEAxMj\n\t\t\t\t\t\tZG16LXNoaWItZGctMDEuZG16LnJvZWhhbXB0b24uYWMudWswggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQCLewrO3PRLdkLPc0WQ8pyV3lUyqjQotbAoCwAD\n\t\t\t\t\t\tJ82zAjGEjM2f7ItT0znjoOeL+0mk82lGNLpnUgdlCN1/CCWsVtpDHiX/cONcetfB\n\t\t\t\t\t\tLApwbhlC/VkyVw64Q31BpDpmwRR8xl0G7wIDyGLgm65F4YGwLAIJ29ekX0iPW23G\n\t\t\t\t\t\t3cnRB+Qxuss+ltLppKbKOg0RRHw8rGMqvpcl5RNaG5RoDd75ke4sulXzmnsiT1kX\n\t\t\t\t\t\tzJ3N6gbYuKuYGDFbTNPxmUn8tDOY9XiMYmSXYAPC76Tm67yrsACybYfhamAKGLDJ\n\t\t\t\t\t\tLzRPcdb+4ztpSwg3JAmoV9Wh71x/QY5xqRFYc6BFR+qr49sTAgMBAAGjgY4wgYsw\n\t\t\t\t\t\tagYDVR0RBGMwYYIjZG16LXNoaWItZGctMDEuZG16LnJvZWhhbXB0b24uYWMudWuG\n\t\t\t\t\t\tOmh0dHBzOi8vZG16LXNoaWItZGctMDEuZG16LnJvZWhhbXB0b24uYWMudWsvaWRw\n\t\t\t\t\t\tL3NoaWJib2xldGgwHQYDVR0OBBYEFMBb1DPf728KsP2L5BR2RK8T3MDIMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQBQsK2G0NUmIAzUjnxKvM29W2BCPmXAntHFOku6g3eLuh8b\n\t\t\t\t\t\tmvIgoQ+vRpPTdw9rN0hmz7Rohq5CiL7avvIbhYrbvC4UX86eAiss224K7OVHZxUc\n\t\t\t\t\t\tjQOd40XcNctmhu558CeKQGqfurB1k9l78q9rNgrIyx+TfcyXI7Imy+koBVDk+m0P\n\t\t\t\t\t\tPzdno7nVF6ijBmrRcO1f6Tjn84RIn6Vv6beCZzwe99TUaV3hQt2f+k/yeZmebKK4\n\t\t\t\t\t\tCvUiVr5csHXAtF2UoDIIvaXipHbaN7g3XU8D3xPCIgism64TuiZZSnTQa4nNv1ZZ\n\t\t\t\t\t\ttsCE45WFHTtwjDr3fhwnrvOO0mnQQ1sRXig53IR1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "roehampton.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://dmz-shib-dg-01.dmz.roehampton.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dmz-shib-dg-01.dmz.roehampton.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://dmz-shib-dg-01.dmz.roehampton.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dmz-shib-dg-01.dmz.roehampton.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dmz-shib-dg-01.dmz.roehampton.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dmz-shib-dg-01.dmz.roehampton.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://dmz-shib-dg-01.dmz.roehampton.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dmz-shib-dg-01.dmz.roehampton.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "roehampton.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://www2.roehampton.ac.uk/roehampton/resources/images/url-logo-166x60.gif",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "166"
                  },
                  {
                    "text": "https://www2.roehampton.ac.uk/roehampton/resources/images/url-quad.gif",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Roehampton"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDejCCAmKgAwIBAgIVAJw0niI78J9LVDelS/WX6kLw2ONrMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMC4xLDAqBgNVBAMTI2Rtei1zaGliLWRnLTAxLmRtei5yb2VoYW1wdG9uLmFj\n\t\t\t\t\t\tLnVrMB4XDTA5MDQwNjEzNTgxOVoXDTI5MDQwNjEzNTgxOVowLjEsMCoGA1UEAxMj\n\t\t\t\t\t\tZG16LXNoaWItZGctMDEuZG16LnJvZWhhbXB0b24uYWMudWswggEiMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBAQUAA4IBDwAwggEKAoIBAQCLewrO3PRLdkLPc0WQ8pyV3lUyqjQotbAoCwAD\n\t\t\t\t\t\tJ82zAjGEjM2f7ItT0znjoOeL+0mk82lGNLpnUgdlCN1/CCWsVtpDHiX/cONcetfB\n\t\t\t\t\t\tLApwbhlC/VkyVw64Q31BpDpmwRR8xl0G7wIDyGLgm65F4YGwLAIJ29ekX0iPW23G\n\t\t\t\t\t\t3cnRB+Qxuss+ltLppKbKOg0RRHw8rGMqvpcl5RNaG5RoDd75ke4sulXzmnsiT1kX\n\t\t\t\t\t\tzJ3N6gbYuKuYGDFbTNPxmUn8tDOY9XiMYmSXYAPC76Tm67yrsACybYfhamAKGLDJ\n\t\t\t\t\t\tLzRPcdb+4ztpSwg3JAmoV9Wh71x/QY5xqRFYc6BFR+qr49sTAgMBAAGjgY4wgYsw\n\t\t\t\t\t\tagYDVR0RBGMwYYIjZG16LXNoaWItZGctMDEuZG16LnJvZWhhbXB0b24uYWMudWuG\n\t\t\t\t\t\tOmh0dHBzOi8vZG16LXNoaWItZGctMDEuZG16LnJvZWhhbXB0b24uYWMudWsvaWRw\n\t\t\t\t\t\tL3NoaWJib2xldGgwHQYDVR0OBBYEFMBb1DPf728KsP2L5BR2RK8T3MDIMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQBQsK2G0NUmIAzUjnxKvM29W2BCPmXAntHFOku6g3eLuh8b\n\t\t\t\t\t\tmvIgoQ+vRpPTdw9rN0hmz7Rohq5CiL7avvIbhYrbvC4UX86eAiss224K7OVHZxUc\n\t\t\t\t\t\tjQOd40XcNctmhu558CeKQGqfurB1k9l78q9rNgrIyx+TfcyXI7Imy+koBVDk+m0P\n\t\t\t\t\t\tPzdno7nVF6ijBmrRcO1f6Tjn84RIn6Vv6beCZzwe99TUaV3hQt2f+k/yeZmebKK4\n\t\t\t\t\t\tCvUiVr5csHXAtF2UoDIIvaXipHbaN7g3XU8D3xPCIgism64TuiZZSnTQa4nNv1ZZ\n\t\t\t\t\t\ttsCE45WFHTtwjDr3fhwnrvOO0mnQQ1sRXig53IR1"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Roehampton"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.roehampton.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Roehampton University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.esher.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Loughlin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:operations@esher.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Daniel"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Loughlin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:operations@esher.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Daniel"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.esher.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-12-19T11:08:16Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUTqf68WmrG3w0sWAxe9mg3otFIZswDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGjEYMBYGA1UEAwwPaWRwLmVzaGVyLmFjLnVrMB4XDTE0MTIxNzEyMTMzNVoX\n\t\t\t\t\t\tDTM0MTIxNzEyMTMzNVowGjEYMBYGA1UEAwwPaWRwLmVzaGVyLmFjLnVrMIIBIjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0HdpuV5htwYC8WF3zeFZTKJ2AYbP\n\t\t\t\t\t\tWZ7SU/LvVYqrD9cfm68KNG7HBpECZ7eZ1JggqUZDiFQToRGfBGH4jhsxjjhDP0KV\n\t\t\t\t\t\tOo8mKB/vNkKwd+bBjg9IGko4k/LfT0hxyGIPMG0CJWBazhPwG7JHj2Dh8kuJwCJA\n\t\t\t\t\t\tCebu+zRQeKgOdwtM2C08GmqYKRksRTqyLCaYUvF8wRF9J1aIMjOvwhyzgzSlw12w\n\t\t\t\t\t\ty7brj8XBHwoY5oNpZEM9Zu8cv7uQNTrI7Up6pNYcEEVIp1KFLk+biBg6zPFykBNQ\n\t\t\t\t\t\tOaatiJscuqjjX29hfraT1gbEaMgTXzjrlzMPOns04HNx+mrE0kIUdQ8prQIDAQAB\n\t\t\t\t\t\to2UwYzAdBgNVHQ4EFgQUUHA9nhSU3TIZcNn44UKjCf5sIxMwQgYDVR0RBDswOYIP\n\t\t\t\t\t\taWRwLmVzaGVyLmFjLnVrhiZodHRwczovL2lkcC5lc2hlci5hYy51ay9pZHAvc2hp\n\t\t\t\t\t\tYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAGDEpLkm/u08qjo/CnqYyHB5Oh7LF\n\t\t\t\t\t\tKoorx5Ag47xgR0l2rtnTe5KO88IhnkBLzU15RzPAH8yZacto0Yp06Eq/2EoMjfRd\n\t\t\t\t\t\t1CeeAFrDPZsBuMLKqXYcGeFkIkCPZMrRkhN4EzYRiJzs6IzJdqNnNSOJ4yYu6iga\n\t\t\t\t\t\tCqrktgZRjlFK/WRiGD7KfTOanA4PUw5EPovKKM5vcIsBO/5dSjmZSWbBK0hTWUCr\n\t\t\t\t\t\thetlcmrGJDayU8XF/HZYDRPIe+ZABsaaqkrFgLGjTHeHv95TNk9r7oVF3V+G4M2q\n\t\t\t\t\t\tXTPQTiNsUr7+4LYPFUtOa6fi1GHeYLkqLiuuhX9v2GW8jXtV+XUA7+r1MQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "esher.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.esher.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.esher.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.esher.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.esher.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.esher.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.esher.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.esher.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.esher.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.esher.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.esher.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.esher.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "esher.ac.uk"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Esher College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUTqf68WmrG3w0sWAxe9mg3otFIZswDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwGjEYMBYGA1UEAwwPaWRwLmVzaGVyLmFjLnVrMB4XDTE0MTIxNzEyMTMzNVoX\n\t\t\t\t\t\tDTM0MTIxNzEyMTMzNVowGjEYMBYGA1UEAwwPaWRwLmVzaGVyLmFjLnVrMIIBIjAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0HdpuV5htwYC8WF3zeFZTKJ2AYbP\n\t\t\t\t\t\tWZ7SU/LvVYqrD9cfm68KNG7HBpECZ7eZ1JggqUZDiFQToRGfBGH4jhsxjjhDP0KV\n\t\t\t\t\t\tOo8mKB/vNkKwd+bBjg9IGko4k/LfT0hxyGIPMG0CJWBazhPwG7JHj2Dh8kuJwCJA\n\t\t\t\t\t\tCebu+zRQeKgOdwtM2C08GmqYKRksRTqyLCaYUvF8wRF9J1aIMjOvwhyzgzSlw12w\n\t\t\t\t\t\ty7brj8XBHwoY5oNpZEM9Zu8cv7uQNTrI7Up6pNYcEEVIp1KFLk+biBg6zPFykBNQ\n\t\t\t\t\t\tOaatiJscuqjjX29hfraT1gbEaMgTXzjrlzMPOns04HNx+mrE0kIUdQ8prQIDAQAB\n\t\t\t\t\t\to2UwYzAdBgNVHQ4EFgQUUHA9nhSU3TIZcNn44UKjCf5sIxMwQgYDVR0RBDswOYIP\n\t\t\t\t\t\taWRwLmVzaGVyLmFjLnVrhiZodHRwczovL2lkcC5lc2hlci5hYy51ay9pZHAvc2hp\n\t\t\t\t\t\tYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAGDEpLkm/u08qjo/CnqYyHB5Oh7LF\n\t\t\t\t\t\tKoorx5Ag47xgR0l2rtnTe5KO88IhnkBLzU15RzPAH8yZacto0Yp06Eq/2EoMjfRd\n\t\t\t\t\t\t1CeeAFrDPZsBuMLKqXYcGeFkIkCPZMrRkhN4EzYRiJzs6IzJdqNnNSOJ4yYu6iga\n\t\t\t\t\t\tCqrktgZRjlFK/WRiGD7KfTOanA4PUw5EPovKKM5vcIsBO/5dSjmZSWbBK0hTWUCr\n\t\t\t\t\t\thetlcmrGJDayU8XF/HZYDRPIe+ZABsaaqkrFgLGjTHeHv95TNk9r7oVF3V+G4M2q\n\t\t\t\t\t\tXTPQTiNsUr7+4LYPFUtOa6fi1GHeYLkqLiuuhX9v2GW8jXtV+XUA7+r1MQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Esher College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.esher.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Esher College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://staging.portal.euromonitor.com/athens",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wiehan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Jurgen.wiehan@euromonitor.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "J\u00fcrgen"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wiehan"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Jurgen.wiehan@euromonitor.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "J\u00fcrgen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://staging.portal.euromonitor.com/athens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-10-29T10:53:46Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Passport (Staging) - Euromonitor International"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.euromonitor.com/contact.aspx"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Euromonitor International plc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://staging.portal.euromonitor.com/portal/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://staging.portal.euromonitor.com/portal/oa/auth/rcv/shib/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://staging.portal.euromonitor.com/portal/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://staging.portal.euromonitor.com/portal/oa/auth/rcv/saml2/art",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://staging.portal.euromonitor.com/athensgateway/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://staging.portal.euromonitor.com/athensgateway/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDzTCCArWgAwIBAgIJAKY1zcaXHG70MA0GCSqGSIb3DQEBBQUAME0xIjAgBgNV\n\t\t\t\t\t\tBAoTGUV1cm9tb25pdG9yIEludGVybmF0aW9uYWwxJzAlBgNVBAMTHnN0YWdpbmcu\n\t\t\t\t\t\tcG9ydGFsLmV1cm9tb25pdG9yLmNvbTAeFw0xMzEwMDMwOTQ1NDFaFw0yMzEwMDEw\n\t\t\t\t\t\tOTQ1NDFaME0xIjAgBgNVBAoTGUV1cm9tb25pdG9yIEludGVybmF0aW9uYWwxJzAl\n\t\t\t\t\t\tBgNVBAMTHnN0YWdpbmcucG9ydGFsLmV1cm9tb25pdG9yLmNvbTCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBAMeswt5WPQ+4Df7A4WKjSgvrfS+O0NbD+Zr1\n\t\t\t\t\t\tmzxgCovcVsYjCXfMgN6ylaYEKSb2rdB33RrtcA4U+9GUX7jV6czcSn+q9smEOiUP\n\t\t\t\t\t\t01id8xU09xB+xKvfqxHlzm3WtvtNDAMkLQokEzEiuR+QORwqO0ylK7ngFyr3QN9A\n\t\t\t\t\t\tKk8nU8PPOAJ3DAPRpFnAAiUaAKHyNlZLqWONr+5jVQAJGlnWc7Z3ian57YLKcG6Z\n\t\t\t\t\t\tPmnqt9n9gfBUmk6Oh1mxvN2mf+bStCXNjSmIV6X39Xl1RWNnl6SIIEB8ibrAZqpE\n\t\t\t\t\t\tGbb40d+/Ki3Whzh1wS4Mr/V/Yxo6Klqr4VqQoIfDq6J5CVa8GwsCAwEAAaOBrzCB\n\t\t\t\t\t\trDAdBgNVHQ4EFgQUA0geA/VQ7QAYL0gI5OnhkuUEgPIwfQYDVR0jBHYwdIAUA0ge\n\t\t\t\t\t\tA/VQ7QAYL0gI5OnhkuUEgPKhUaRPME0xIjAgBgNVBAoTGUV1cm9tb25pdG9yIElu\n\t\t\t\t\t\tdGVybmF0aW9uYWwxJzAlBgNVBAMTHnN0YWdpbmcucG9ydGFsLmV1cm9tb25pdG9y\n\t\t\t\t\t\tLmNvbYIJAKY1zcaXHG70MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEB\n\t\t\t\t\t\tAJAi5ZB4lhOmbmzFuLUCyELol15fQA/iRfQqDmuCx2pcZhKrcU2d3suWYaBKu5eT\n\t\t\t\t\t\tVX8MMHAHeO/7hdFbbjmTRcXJNnLMfRs5V5pnOj3F8GZtetDt0oU808w7fGESWifs\n\t\t\t\t\t\tRljP0mxWzKQoiBxZXU9XJLJa64Nkfpr5Ohb95YhLr3i+K/HnHsYZw2wGonekCqFB\n\t\t\t\t\t\tWMAzY3lJ/UoRe6MIMFGB/LX/uXkVXtjTldrauOik4NiDX1Z8AwYfU8f0T4iWUzrh\n\t\t\t\t\t\trlPlWyGoSgT23vdw9IKNL7msMOA8dOfzIClDtBbcOYlDpGI5gEMTiSbBhKLwuMT5\n\t\t\t\t\t\tzcL17P70Sn+9n3DUm+MpLWw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDzTCCArWgAwIBAgIJAKY1zcaXHG70MA0GCSqGSIb3DQEBBQUAME0xIjAgBgNV\n\t\t\t\t\t\tBAoTGUV1cm9tb25pdG9yIEludGVybmF0aW9uYWwxJzAlBgNVBAMTHnN0YWdpbmcu\n\t\t\t\t\t\tcG9ydGFsLmV1cm9tb25pdG9yLmNvbTAeFw0xMzEwMDMwOTQ1NDFaFw0yMzEwMDEw\n\t\t\t\t\t\tOTQ1NDFaME0xIjAgBgNVBAoTGUV1cm9tb25pdG9yIEludGVybmF0aW9uYWwxJzAl\n\t\t\t\t\t\tBgNVBAMTHnN0YWdpbmcucG9ydGFsLmV1cm9tb25pdG9yLmNvbTCCASIwDQYJKoZI\n\t\t\t\t\t\thvcNAQEBBQADggEPADCCAQoCggEBAMeswt5WPQ+4Df7A4WKjSgvrfS+O0NbD+Zr1\n\t\t\t\t\t\tmzxgCovcVsYjCXfMgN6ylaYEKSb2rdB33RrtcA4U+9GUX7jV6czcSn+q9smEOiUP\n\t\t\t\t\t\t01id8xU09xB+xKvfqxHlzm3WtvtNDAMkLQokEzEiuR+QORwqO0ylK7ngFyr3QN9A\n\t\t\t\t\t\tKk8nU8PPOAJ3DAPRpFnAAiUaAKHyNlZLqWONr+5jVQAJGlnWc7Z3ian57YLKcG6Z\n\t\t\t\t\t\tPmnqt9n9gfBUmk6Oh1mxvN2mf+bStCXNjSmIV6X39Xl1RWNnl6SIIEB8ibrAZqpE\n\t\t\t\t\t\tGbb40d+/Ki3Whzh1wS4Mr/V/Yxo6Klqr4VqQoIfDq6J5CVa8GwsCAwEAAaOBrzCB\n\t\t\t\t\t\trDAdBgNVHQ4EFgQUA0geA/VQ7QAYL0gI5OnhkuUEgPIwfQYDVR0jBHYwdIAUA0ge\n\t\t\t\t\t\tA/VQ7QAYL0gI5OnhkuUEgPKhUaRPME0xIjAgBgNVBAoTGUV1cm9tb25pdG9yIElu\n\t\t\t\t\t\tdGVybmF0aW9uYWwxJzAlBgNVBAMTHnN0YWdpbmcucG9ydGFsLmV1cm9tb25pdG9y\n\t\t\t\t\t\tLmNvbYIJAKY1zcaXHG70MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcNAQEFBQADggEB\n\t\t\t\t\t\tAJAi5ZB4lhOmbmzFuLUCyELol15fQA/iRfQqDmuCx2pcZhKrcU2d3suWYaBKu5eT\n\t\t\t\t\t\tVX8MMHAHeO/7hdFbbjmTRcXJNnLMfRs5V5pnOj3F8GZtetDt0oU808w7fGESWifs\n\t\t\t\t\t\tRljP0mxWzKQoiBxZXU9XJLJa64Nkfpr5Ohb95YhLr3i+K/HnHsYZw2wGonekCqFB\n\t\t\t\t\t\tWMAzY3lJ/UoRe6MIMFGB/LX/uXkVXtjTldrauOik4NiDX1Z8AwYfU8f0T4iWUzrh\n\t\t\t\t\t\trlPlWyGoSgT23vdw9IKNL7msMOA8dOfzIClDtBbcOYlDpGI5gEMTiSbBhKLwuMT5\n\t\t\t\t\t\tzcL17P70Sn+9n3DUm+MpLWw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Passport is Euromonitor International's gateway to global strategic intelligence."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Passport (Staging) - Euromonitor International"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://sp.silverchair.com/bates/production/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ShibbolethAdmin@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Admin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hirst"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:khirst@silverchair.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kevin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.silverchair.com/bates/production/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-02-27T11:52:49Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Silverchair Production: Wolters Kluwer Bates Visual Guide"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://batesvisualguide.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Silverchair Science + Communications, LLC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://batesvisualguide.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://batesvisualguide.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://batesvisualguide.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://batesvisualguide.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://batesvisualguide.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://batesvisualguide.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDBjCCAe6gAwIBAgIJAOFo9MBRXeFRMA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\n\t\t\t\t\t\tBAMTFXNjbS1wcm9kd2ViMDEuc2lzLmxhbjAeFw0xNTAyMjYxNjIyMzZaFw0yNTAy\n\t\t\t\t\t\tMjMxNjIyMzZaMCAxHjAcBgNVBAMTFXNjbS1wcm9kd2ViMDEuc2lzLmxhbjCCASIw\n\t\t\t\t\t\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL4rrdOYTdOOx3hU6sLw5SuLnoMY\n\t\t\t\t\t\tNl7zueILpPdpy/aix1CqJ9evkwFNwy9lST7MbJe5Dj6Llg+jnu4Czp0+FeGUUwFU\n\t\t\t\t\t\t2osBP9fFBvU+0s7G0ixT6FoKSMak2mq8IF1QHCTa0h9Fxj+dWvGTsr5LwjuGoqAz\n\t\t\t\t\t\toPSm5wXFw2Wf/qCVDGrYpuwFrnI9C5tboukUQNLcoVxKUzUc74MKOSQ/yDnw+5gJ\n\t\t\t\t\t\td17oTEMXrId/snTfdz2Vt9g8St0nfL003+N45ZrksoZjLKyhAzZFk6nUPuUuqhOU\n\t\t\t\t\t\thCYkLhjlouMZass2IUJLY4YHBQ+YRnayoO14rOZ41n0dmKAOx/ji+l03yNkCAwEA\n\t\t\t\t\t\tAaNDMEEwIAYDVR0RBBkwF4IVc2NtLXByb2R3ZWIwMS5zaXMubGFuMB0GA1UdDgQW\n\t\t\t\t\t\tBBT41sXyIBF6ETN3en6hOQZ+sfvkMzANBgkqhkiG9w0BAQUFAAOCAQEAuBRCom7N\n\t\t\t\t\t\tl2KrRgCABtXj+EEpCAVmn/TU/Y1bNqmZIj7YB23w+YpbDS3o3d9euouHhcLeDRUg\n\t\t\t\t\t\tL4guMR3sLMlEYzyJPNwuWXwbC/uctW1/djMHJbVh9VHF4Iq0u0WhsadwwMbKM+nH\n\t\t\t\t\t\tJCLIoF3gnHM/zOyNSl9CiZH44SUjeF/Pi4BTugS7BIaeHNEL6INBheXWE24kDpil\n\t\t\t\t\t\td8SAOHfOQsqvYRLlnl61ESpAuh1vRvcG7MOQ9YRsDOLoK7O/wa4QpmHRnvBxk670\n\t\t\t\t\t\ttaO2s6UldkU0aSnJaTrk/q+F6LGyyA2cpVEhjSNQrUdd0o7JHDzo1/62wILbORpj\n\t\t\t\t\t\t+0cK6G714oAgXg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://batesvisualguide.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://batesvisualguide.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://batesvisualguide.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://batesvisualguide.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://batesvisualguide.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://batesvisualguide.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://disposer.c3se.chalmers.se",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://disposer.c3se.chalmers.se",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://disposer.c3se.chalmers.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://disposer.c3se.chalmers.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://disposer.c3se.chalmers.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://disposer.c3se.chalmers.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://disposer.c3se.chalmers.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://disposer.c3se.chalmers.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://disposer.c3se.chalmers.se/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Testserver (Disposer) f\u00f6r SNIC User and Project Repository (SUPR)."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Test server (Disposer) for the SNIC User and Project Repository (SUPR)."
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SUPR testserver Disposer"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SUPR test server Disposer"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "disposer"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3zCCAcegAwIBAgIJAJpQNd54W1WpMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\nBAMTCGRpc3Bvc2VyMB4XDTE0MTExMzA5NTI0MVoXDTI0MTExMDA5NTI0MVowEzER\nMA8GA1UEAxMIZGlzcG9zZXIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQC+y5uIuslZ8w+FzuKwwmmkbpGkQVeryBrlb01ZhxRLlI/uB/H5/SYuSkWOIwmh\nbXBmd1wE8qlgx50PC+XZOdDNMY1vV/gva6MUQagU9rztDcpAQcm/sIoO+ocvdLiC\n5x/JfAPSwbA/5OyCRYIYR+LjFgZNC0q3sMtxAtsdQjP7dOK0D8JRRNGpCTJHgCPa\ndLjhau0NRmvUhEfaHS05zbKETZUte3ZTmPxKrrc8GwOEMyGu4TWOQyRT02SHEOjL\ngSMrek+gsjXxKz6jrxUVW1spz+F2eArUXrStQlvJT9gOjmFEep0jGCoXcq10QG+h\n+WvvuamBes8B8QpsdIkYXOLHAgMBAAGjNjA0MBMGA1UdEQQMMAqCCGRpc3Bvc2Vy\nMB0GA1UdDgQWBBSzVONP+mikveeZyi4aTBJzi6aqFDANBgkqhkiG9w0BAQUFAAOC\nAQEAHsiX3kB2IDsp15WOq7nWLPhLOJvTMQoKi3mEJ5gKkCzuUHHoulw8HoJFKKYJ\nCq5sf8d5WG6AJCLuofs87/qtu9AdLjWuQXfhIgdTKrW951sXTIg605dmucR1N//Z\n9WESsxzk9PVQwbEU6SKhLJKRXx4/EmfPHKYTnWEwWr3mzr93a0Xk9Hr7UJsViK1q\nJiXD3ClfD1XQBL7fH9QglS8Wmxkj4KhLZY6ski0dOGF6LeZY/FDMrXiExOgLK9uH\nH9JEriBZP+KVDFZ1U6rKdISQcDUMZLSZmEiVLmqBeWY6XNYGy6SbLM23iyjIe2FH\no/agI+HB5oEGJQGKjPQGnNTpng=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=disposer"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://disposer.c3se.chalmers.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://disposer.c3se.chalmers.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://disposer.c3se.chalmers.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://disposer.c3se.chalmers.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://disposer.c3se.chalmers.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://disposer.c3se.chalmers.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://disposer.c3se.chalmers.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://disposer.c3se.chalmers.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://disposer.c3se.chalmers.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.shh.fi/idp/shibboleth",
    {
      "entity_id": "https://idp.shh.fi/idp/shibboleth",
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "true",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.shh.fi/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hanken.fi"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hanken School of Economics"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hanken Svenska handelsh\u00f6gskolan"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hanken Svenska handelsh\u00f6gskolan"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "kalmar"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "finland"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "tags",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEYTCCA0mgAwIBAgIQR1F2IKk/FGfCBPi7E7Lr9DANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMTAxODAwMDAwMFoXDTE2MTExMjIzNTk1OVowODEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRMwEQYDVQQDEwppZHAuc2hoLmZp\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0tjmJ1ERx/Za5uVfPURB\n8eTAKK0QEXJD/++dCZcVSrIpau8jiLkmi+kzweI531JVBDrpT24jFGXn2cKnzUIB\nxpOWEUKLQSkYdA3LoKD1gJjjFxF8Y3J237Zlg3QL/dmNnfCLxs8SsXbCsjxpuPAP\nwYRR1ZEL2SjdU3zEDc4iqMqkk5wS4lzjB1SMNFaaKRRsW97BAKATyHRwp4a01nB4\no0MDNn4iGcIoE3kO9X83H7smurBXGqVzc4dnfH3yLOXF+NMpRbH9upSrSBe2EoZU\njc+Vi4/fsEXRmr/u+8IOb1ERpYNLCd6L+mD9ppbA3ZeRJe/LRaq7MFQX3VzMR5mn\nxwIDAQABo4IBZzCCAWMwHwYDVR0jBBgwFoAUDL2TaAzz3qujSWsrN1dH6pDjue0w\nHQYDVR0OBBYEFH9BqIu5UIBGpznMYuQP3dJQ6f7zMA4GA1UdDwEB/wQEAwIFoDAM\nBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNV\nHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAxMC+gLaAr\nhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNybDBtBggr\nBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5v\ncmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8vb2NzcC50Y3Mu\ndGVyZW5hLm9yZzAVBgNVHREEDjAMggppZHAuc2hoLmZpMA0GCSqGSIb3DQEBBQUA\nA4IBAQBk7DXTXfwZCTrFUVB73h4TzHF2zrIUm83SFCNcn5BBA9qKRL/TfozD4ZwK\n1zfaVtcc8gpS4tUE+T3dOa2zKvUgYSuDScC7cInBht1wLUrukBhQCDIU+0lKaBJv\nA17KXHxowqua95sMKkN3tDUB7lbLCuPxhJyWzE2E9TrJ2oTYQ35C3cGd5FbnLEWk\n9ceS4WR5+t1lpvC4uwWrc0DYgb0ADv9TDW52/qssZKNLbVu5BwRKI6ToAZTgnNbf\naeNbuslxAJn11gg6nMy8yRVZMTOMZoLK5j4vNXhp8YngrWxdGBDIaEtLvLWfIs99\nnAiHebdvpVCIMaM703zAuuDVImHf"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ohrman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboservice@hanken.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kuno"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Isaksson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboservice@hanken.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Johan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:help@hanken.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Hanken"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hanken Svenska handelsh\u00f6gskolan"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hanken School of Economics"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hanken Svenska handelsh\u00f6gskolan"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hanken.fi"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hanken.fi"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hanken.fi"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hanken Svenska handelsh\u00f6gskolan"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hanken School of Economics"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hanken Svenska handelsh\u00f6gskolan"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor"
    }
  ],
  [
    "https://idp.wooster.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vdiscipio@wooster.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Vince DiScipio"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rdills@wooster.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roger Dills"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mnaylor@wooster.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael Naylor"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.wooster.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.wooster.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.wooster.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.wooster.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.wooster.edu:8444/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.wooster.edu:8444/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wooster.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The College of Wooster"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAI2Lui1vSO8MHNMubyKBhAnnj/14MA0GCSqGSIb3DQEB\nBQUAMBoxGDAWBgNVBAMTD2lkcC53b29zdGVyLmVkdTAeFw0xMTExMDMxODM4NTFa\nFw0zMTExMDMxOTM4NTFaMBoxGDAWBgNVBAMTD2lkcC53b29zdGVyLmVkdTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKnu2Gw6Irx4NZldkeGBLetETpCy\nuVS8wUHPhzodyjLhksa5NeT6SBG4BBt2JSnuI4dRwY7k1igxe8km1qXgUnn/j1Ho\n5W6zAwzHASsuIyYFyYrQ0sdnLes6sEeZDPADU5LDQT7vvWJm3WgvZJmM45NcsXr4\n6mN+wYKpgQbiUfBytkbYjTV1tYHPTYFNz8HDlBuYDwifx0pdZ3MhxT3tt30RMZ5Y\nF3Jo8VlMiLMIdS0wYKGOdXMSykKyi0+Gix1kv+DmLRpuMcid0CBBfh7uPnUO7MUy\nsJHoC397p2F4bidrnAEV1CFmetxaZB3irPGhUnL81ud8BapgOfhPp4OWbx8CAwEA\nAaNlMGMwQgYDVR0RBDswOYIPaWRwLndvb3N0ZXIuZWR1hiZodHRwczovL2lkcC53\nb29zdGVyLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU2clCh8A4cBYUuLvs\nqGX5zdpFUc4wDQYJKoZIhvcNAQEFBQADggEBAJ2Eap2ziunllauY/qhBEWrhSnVH\nSUGBCLvyylg5kbpoNdcl1CPXW/pfWNn4UEy8AtNwHiQZG4CPy89ik0ZcIf146Tn2\nYQcoJn0XAszpvKzYDVxlEE0T1UrtlKDy0V9jFDnVw9UFw+5w3Ix3vBDT/TZwjyAj\n+ksknyRMcGWCi5ia9U0ZgHKvOE/B/QgF3vT8Dzzb5G772LWytudXutQJmQC9Ch8K\nW5aggtvAOm9Z5a398jL21emZAgI3HBKcByqHpKB6Ci5rUmTQklhZ6szqU1+IM9+a\nruOBR00Y3KW+OWjgg06N026JaWDbMENv4J8oyrehK5NqlLF/mZKGEk0UwRI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The College of Wooster"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wooster.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The College of Wooster"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dadotsdev02.essex.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Noble"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Susan.Noble@manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Susan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Syrotiuk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nicholas.syrotiuk@jisc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nick"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dadotsdev02.essex.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-03-06T10:05:46Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UK Data Service Dotstat Development Server 02"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://ukdataservice.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Essex"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dadotsdev02.essex.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dadotsdev02.essex.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dadotsdev02.essex.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dadotsdev02.essex.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dadotsdev02.essex.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dadotsdev02.essex.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDDCCAfSgAwIBAgIJAILDhwjr7ZN4MA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\n\t\t\t\t\t\tBAMTF2RhZG90c2RldjAyLmVzc2V4LmFjLnVrMB4XDTE1MDIyNTE2MTUwM1oXDTI1\n\t\t\t\t\t\tMDIyMjE2MTUwM1owIjEgMB4GA1UEAxMXZGFkb3RzZGV2MDIuZXNzZXguYWMudWsw\n\t\t\t\t\t\tggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDlsK18Tb2IK838pdwwylTu\n\t\t\t\t\t\tHiF86/nYePu9WhXOBNHq+2LGaA73+j+RVMQnZIvLOWEFDmUtPUZQCALEAy9cVWEy\n\t\t\t\t\t\tv+clmkXG+yrRB2u2rxMRydNZvPWRyAyceYJtnHUtd6WGqh5P5YzK/h7z8aedHsOe\n\t\t\t\t\t\t/pINhgmqQowunjXpKPRcVGvd3H5WVzILM9mqROfIJ6sV8I7a0eBBJN2lDLgeUzMO\n\t\t\t\t\t\tbIYITWKnnVYnzouQU1UDRDCrO3hhuhX21fLE6Lt4BrQJrNMrkSCxDAYuYaHZP2n7\n\t\t\t\t\t\tc7K4q1A5haGXN9H32eIqCqUcYp/mtf2mQ0Mqm88eDc2IItbs36kUQG9gfUHJp5p9\n\t\t\t\t\t\tAgMBAAGjRTBDMCIGA1UdEQQbMBmCF2RhZG90c2RldjAyLmVzc2V4LmFjLnVrMB0G\n\t\t\t\t\t\tA1UdDgQWBBS7fh8aeRB64R+kY5/JJpy41IP9WjANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tFmsAVt9WPTgZ1bHRZcs9q4CqtIGGRJiRsWbSXIi9rOvt3ZeRYoP/rIF023z9vpEe\n\t\t\t\t\t\tqEIJZNmXuGwYc9VDL+6qwPdLSNKqb3Zz5M9x7qYAB7VjqLf8lhkzv9HJJ1Cmpwlm\n\t\t\t\t\t\tq5rJlWCPvdViJ44hMFwB6QEsvDHH34CDQgPegG2EY7Xkm7ugwnniTBqZYcyFU2SH\n\t\t\t\t\t\tGO+cggiW6+7by2FTk33qTZaSTVMwKK5ZbesGjIriSgQVdHt4FWbE5pKhnNPTaPXH\n\t\t\t\t\t\tQcjOIA/E0+h92TKhws2T4jj2gyoLE2+f3ah6zfItTKwJgB1yuTSpkVo2Hpnq8lak\n\t\t\t\t\t\tc3GH0A8MBMfaHeUkrOsmgA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dadotsdev02.essex.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dadotsdev02.essex.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dadotsdev02.essex.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dadotsdev02.essex.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dadotsdev02.essex.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dadotsdev02.essex.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://pubs.aeaweb.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso-support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "sso-support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso-tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "sso-tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://pubs.aeaweb.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-10-10T08:56:45Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "American Economic Association"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aeaweb.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJAKoOWJDw6RetMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\n\t\t\t\t\t\tBAMTD3B1YnMuYWVhd2ViLm9yZzAeFw0xMzEyMTIwMTI3NDRaFw0yMzEyMTAwMTI3\n\t\t\t\t\t\tNDRaMBoxGDAWBgNVBAMTD3B1YnMuYWVhd2ViLm9yZzCCASIwDQYJKoZIhvcNAQEB\n\t\t\t\t\t\tBQADggEPADCCAQoCggEBALhJgZeh9u4wYjh6peTaimer1DET8rqQSpXrOzF4O8Fx\n\t\t\t\t\t\tXbNq98Fl+jcptXhLqBFB92SludwbeI0WEV935EPXZ778ujoum5BeomZa5ovc6CpL\n\t\t\t\t\t\tB+1ETN3oDS30R/vMQuF5WT7mSd8vXNZdXcvlPbNjO59Xctib/BzaVVjzkkc5SWVO\n\t\t\t\t\t\trz5q/0JVCOata4vzqv1oSJ0O6rNl7icY5zkeZq9x8tFmZZSgayPIw1aTWjf92EE2\n\t\t\t\t\t\txJl8G34vhK+1Lcn641Aih7lyXGiRS+GvcgSqVUaicWjJ3yDhaaiwQVFP09mC4eTr\n\t\t\t\t\t\tjRR7BYAk1PzR+ScsSSmI4AXQp3wi0S/Yc0tYIDQxoFECAwEAAaNhMF8wPgYDVR0R\n\t\t\t\t\t\tBDcwNYIPcHVicy5hZWF3ZWIub3JnhiJodHRwczovL3B1YnMuYWVhd2ViLm9yZy9z\n\t\t\t\t\t\taGliYm9sZXRoMB0GA1UdDgQWBBSMePkpVX6JEvtEmetRdkNOgvAt/zANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAfVr2rxL8fNCBjE981MAhaSCPznvdN5v7vFSUMSQTDB+X8WoL\n\t\t\t\t\t\tB45kfM/nRSJjzdZVmDlUOdTJed+dNZIbHGCOHS/keALrgeL1HTPNtP/4mqgvJ+0G\n\t\t\t\t\t\tBKFoKN0CQ6sLZkXBrQ1v6AfLeGU+W0UPD9rfjjRCYu805v3II7TdN3evfnbtLmjS\n\t\t\t\t\t\tpnNdZgNqGVODh7jJgoM3dVPNXnKjGq60l7Fbxa0hjUTA9XaNZg4BeTvFQN7qi5M9\n\t\t\t\t\t\txNk/TOrio1K7mK7NE1OuwZ82cUSrPzEyriT0LQOmUCSEOotGLpCk5h8DiC0c8BtU\n\t\t\t\t\t\txHfGWdly2G2H86vOxMCeEJ+lpsW/zPvNTHJ4SQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://pubs.aeaweb.org/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pubs.aeaweb.org/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://pubs.aeaweb.org/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.ate.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.ate.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ate.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.ate.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ate.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ate.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ate.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.ate.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.ate.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.ate.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.ate.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.ate.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.ate.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.ate.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJAM9A/EFvH3nnMA0GCSqGSIb3DQEBCwUAMBsxGTAXBgNV\nBAMTEHd3dy5hdGUubGFkb2suc2UwHhcNMTYwMzE0MTMwMjUyWhcNMjYwMzEyMTMw\nMjUyWjAbMRkwFwYDVQQDExB3d3cuYXRlLmxhZG9rLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAxxDoG4YR72KYS1/uPqADYdCHQotCJ7x9cTxV0As1\nCdkVlaTKUdmy/p+ahzn043P19KYCPz7G9EMHWw3qhr0fqZMrGrewg07akree3zfI\nbaQJD7phHiwQ8UGo2Q2lorInth3Ave4IlaC+rUBtvoa3LsqRCKxqwYuesNcmsO98\n3RxXY29DW5oCtE03rd8OdKtSrItmJ8mxvEH+hGtSb9oMgrhyXYgjGRGySlR0LnbP\nt7UpjQGjLp6TLbXoLHiDu4t2jxS/IcR85q532k1Qjhy+WjEwxcMg2Gn74NnpARl4\nN10huJFnopx8DDpVf9F6aacz8nF/5M9oZAZuZKJdBc+UOwIDAQABo18wXTA8BgNV\nHREENTAzghB3d3cuYXRlLmxhZG9rLnNlhh9odHRwczovL3d3dy5hdGUubGFkb2su\nc2UvZ3VpLXNwMB0GA1UdDgQWBBRPAFHovGUtyQwEvziKRmqJ8cbg3jANBgkqhkiG\n9w0BAQsFAAOCAQEAAUMLZd5+2AyiJL0mNgAt0hC+XR+8fnI91gUly8Q2uMtSdTMT\nvfIsygTpKkSgwm86DWRVLzHRXOGFhu+mAgVsQ0QE5p85ERoB58iGvRI4rcYtv0ie\npuPskX/E5j7gMRHaanBnP6X+vNQ08HEH3/m+Y7nolZkMtmKPlGuiGaHbghywy4WA\nzR3LAF9VtFJWm9tdt1FlP7R4goQAKJQpiV2PcYxyrzYd59SWE/Sa4ZNw04qh+HAv\nfbjk0oejOLjZ6uoEUjf9LLl6ie5zcFBQjXiTb+mXZUTbsy1FYNqYtXJmYNlxgZc3\nIS8RGYGqahuV0paHCbi4AHBtoYA6waPXxJVmKA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.ate.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ate.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.ate.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ate.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ate.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ate.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ate.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.ate.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.ate.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.ate.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.gre.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Edwards"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:n.c.edwards@gre.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nadine"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hunter"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:g.j.hunter@gre.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Geoff"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.gre.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-08-01T09:20:51Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.gre.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.gre.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gre.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRjCCAi6gAwIBAgIIZQXHbuQMihkwDQYJKoZIhvcNAQEFBQAwOjEgMB4GA1UE\n\t\t\t\t\t\tCgwXVW5pdmVyc2l0eSBvZiBHcmVlbndpY2gxFjAUBgNVBAMMDWlkcC5ncmUuYWMu\n\t\t\t\t\t\tdWswHhcNMTMwNjA2MTIzMDE5WhcNMjMwNjA2MTIzMDE5WjA6MSAwHgYDVQQKDBdV\n\t\t\t\t\t\tbml2ZXJzaXR5IG9mIEdyZWVud2ljaDEWMBQGA1UEAwwNaWRwLmdyZS5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIvRxjI34duzh2spZJCamd9E\n\t\t\t\t\t\t8OwnYWdLNS9ZEdorE9x9ZXQA/ejG4x10O1Ljr0N6+0T9YEEa/1JiNp2tUvX3UT7b\n\t\t\t\t\t\t34EKrE5WcYJVZxmPptfge6NakSRBgA5lptbP4mUa4nF52mcovhIWpuk/UYlBKIlJ\n\t\t\t\t\t\tkyodxPGsC4t2cQpvmbSs0RksyIbw7LVBV4MQ6lJtUr1z8KSgyykl2nYfvtWVFmjM\n\t\t\t\t\t\tsmHYt5hXI0Wnmb7mzaRpum1jCWDOfM7frUeA/LR82Vht5QwLBofN1foBy+epycoQ\n\t\t\t\t\t\tmWhalR5RO9O4fcKpdDivesBRr2Azv1yqYAWHFHSuWZIBVu0tJFIOENNAnfdG0PkC\n\t\t\t\t\t\tAwEAAaNQME4wHQYDVR0OBBYEFHyc5wEg+klCOqiJqFE473Ty1/YnMB8GA1UdIwQY\n\t\t\t\t\t\tMBaAFHyc5wEg+klCOqiJqFE473Ty1/YnMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAC6aG56JBmxTiBDNatEhacitubAc+4g/4fKMY/dAVd9SR/Qc8BN4\n\t\t\t\t\t\tYGaM5lR5hhjITyDD/HRI90EEhVXL/TrVmHECXL2SSXRaKJElUIWBtZggFDcyWBC+\n\t\t\t\t\t\tjQPsf/QvfYTheFklroidGqhKUtATdsWtL5iYKjUSYySWQXeujpmNXNjUKJDXsPPX\n\t\t\t\t\t\tiUSrx58Jl1ywPSdJfbDBb8jcb/8TTSq5xEl37TkXp86zvOUrmYFn+RexScPt+kHG\n\t\t\t\t\t\ti4v7/IIqQEnbyG6PZ5CmgZLw5kz1RaQHxfeDomry3wDksX3X3fJUszF3NFBuuPyU\n\t\t\t\t\t\t+w4TA7Ns7GKZQL7rjKJD7Q35wrF/KnjuwCo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRjCCAi6gAwIBAgIIZQXHbuQMihkwDQYJKoZIhvcNAQEFBQAwOjEgMB4GA1UE\n\t\t\t\t\t\tCgwXVW5pdmVyc2l0eSBvZiBHcmVlbndpY2gxFjAUBgNVBAMMDWlkcC5ncmUuYWMu\n\t\t\t\t\t\tdWswHhcNMTMwNjA2MTIzMDE5WhcNMjMwNjA2MTIzMDE5WjA6MSAwHgYDVQQKDBdV\n\t\t\t\t\t\tbml2ZXJzaXR5IG9mIEdyZWVud2ljaDEWMBQGA1UEAwwNaWRwLmdyZS5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIvRxjI34duzh2spZJCamd9E\n\t\t\t\t\t\t8OwnYWdLNS9ZEdorE9x9ZXQA/ejG4x10O1Ljr0N6+0T9YEEa/1JiNp2tUvX3UT7b\n\t\t\t\t\t\t34EKrE5WcYJVZxmPptfge6NakSRBgA5lptbP4mUa4nF52mcovhIWpuk/UYlBKIlJ\n\t\t\t\t\t\tkyodxPGsC4t2cQpvmbSs0RksyIbw7LVBV4MQ6lJtUr1z8KSgyykl2nYfvtWVFmjM\n\t\t\t\t\t\tsmHYt5hXI0Wnmb7mzaRpum1jCWDOfM7frUeA/LR82Vht5QwLBofN1foBy+epycoQ\n\t\t\t\t\t\tmWhalR5RO9O4fcKpdDivesBRr2Azv1yqYAWHFHSuWZIBVu0tJFIOENNAnfdG0PkC\n\t\t\t\t\t\tAwEAAaNQME4wHQYDVR0OBBYEFHyc5wEg+klCOqiJqFE473Ty1/YnMB8GA1UdIwQY\n\t\t\t\t\t\tMBaAFHyc5wEg+klCOqiJqFE473Ty1/YnMAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAC6aG56JBmxTiBDNatEhacitubAc+4g/4fKMY/dAVd9SR/Qc8BN4\n\t\t\t\t\t\tYGaM5lR5hhjITyDD/HRI90EEhVXL/TrVmHECXL2SSXRaKJElUIWBtZggFDcyWBC+\n\t\t\t\t\t\tjQPsf/QvfYTheFklroidGqhKUtATdsWtL5iYKjUSYySWQXeujpmNXNjUKJDXsPPX\n\t\t\t\t\t\tiUSrx58Jl1ywPSdJfbDBb8jcb/8TTSq5xEl37TkXp86zvOUrmYFn+RexScPt+kHG\n\t\t\t\t\t\ti4v7/IIqQEnbyG6PZ5CmgZLw5kz1RaQHxfeDomry3wDksX3X3fJUszF3NFBuuPyU\n\t\t\t\t\t\t+w4TA7Ns7GKZQL7rjKJD7Q35wrF/KnjuwCo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Greenwich - OpenAthens"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gre.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Greenwich"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.univ-corse.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "VAREILLE"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vareille@univ-corse.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.univ-corse.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2010-06-24T18:11:52Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.univ-corse.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.univ-corse.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.univ-corse.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-corse.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-corse.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Corse"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Corse"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSzCCAjOgAwIBAgIUMl8XYihMN+c1fr7Z/kwhIqchZ14wDQYJKoZIhvcNAQEF\nBQAwIzEhMB8GA1UEAxMYc2hpYmJvbGV0aC51bml2LWNvcnNlLmZyMB4XDTEwMDUy\nMDA4MjIyOFoXDTMwMDUyMDA4MjIyOFowIzEhMB8GA1UEAxMYc2hpYmJvbGV0aC51\nbml2LWNvcnNlLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmBAW\nWcnpElNR57uUh2Eb7CEy5InpGkloYXu6jUpiZGV/vIM+dB0n2n/gWLLy5G2ME0Om\nclCBmVWG3uDMNZZyC6EBiEoBWbyj6Af93eEOscjfXXSMWgg0Atmyh84/HZWemhM3\nod2NXDRgHRpJ8ZjZ0VcQE4YNjh7kk5yDaFIoHPqpVK5ItNpZfk1nQ6gYHTsuAe9z\n6UDYE/fXOqF2+TO3Q+XG8+aRjcf0g+y2PaZnv8eSJGRYG3412oJEG4MggFmsAWkc\nlCLEiyMk325+7/8tKY5n/Rnd7jCuLEAqZMo2R/PlwbUO7kf5tcRoWaoKeBtjeweP\nLoIqXeXDkYQB93Q+MQIDAQABo3cwdTBUBgNVHREETTBLghhzaGliYm9sZXRoLnVu\naXYtY29yc2UuZnKGL2h0dHBzOi8vc2hpYmJvbGV0aC51bml2LWNvcnNlLmZyL2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBStZw7/ALbTOYIUU68SwgUXNM+5LTANBgkq\nhkiG9w0BAQUFAAOCAQEAjzOt2lHyqGXgYtxbu8D4aCdJfCgT9dKcN3zfZLJKUUBk\nw5QRiOoz4AKj/QWqYucmWu4KElu6J8GDKsAblw5IGkMto1Pf+hIogTgqSXaFd9/O\ntu/fwQ4sWsVZIl8MeC735h6C+NK4d3cCB+0fHRJFZ4mriZG9tGHmUHFB4rqn27JK\nnrsOwXXTta43x7OixVk4T30ALeIRWw9GjwssjHOBI6BvXI36tEM4mjdV6TBP13Qv\najnfP3xyXWF0/SRe0vvOEqDioR1lKpoeqvINaa5O4u60VsqOFPoZPmNxASoOnnz8\nT9heLa0GVnNgDEgGzmeVmC1UCkmkhz0s325gEEfxAg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Corse"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-corse.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Corse"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso-demo.proofidcloud.co.uk/idp/pingfederate",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@proofid.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@proofid.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso-demo.proofidcloud.co.uk/idp/pingfederate",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-04-17T14:25:26Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso-demo.proofidcloud.co.uk:8443/idp/attrsvc.ssaml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso-demo.proofidcloud.co.uk:8443/idp/soap.ssaml1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCDCCAfCgAwIBAgIGAUwSdXIfMA0GCSqGSIb3DQEBCwUAMEUxCzAJBgNVBAYT\n\t\t\t\t\t\tAkdCMRAwDgYDVQQKEwdQcm9vZklEMSQwIgYDVQQDExtzc28tZGVtby5wcm9vZmlk\n\t\t\t\t\t\tY2xvdWQuY28udWswHhcNMTUwMzEzMDkyNzA5WhcNMjUwMzEwMDkyNzA5WjBFMQsw\n\t\t\t\t\t\tCQYDVQQGEwJHQjEQMA4GA1UEChMHUHJvb2ZJRDEkMCIGA1UEAxMbc3NvLWRlbW8u\n\t\t\t\t\t\tcHJvb2ZpZGNsb3VkLmNvLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\n\t\t\t\t\t\tAQEA1a9N/0Jzf+SLunGwsQlsZ6eCw0v/P4JsYnkiM1+hspj28Dvk3DZ6T7FzW9Wb\n\t\t\t\t\t\tAcpnMqesvvYWukrvSYWF7cJ4gtGaaqUOvrIHWCFHs4wZgD7dpas3QCg33ehdomIl\n\t\t\t\t\t\t4kev30P+vjRVF3v59riCK+1sKES00oL3fAI1oa7iKEkVewd8UleDGw4FepL2VaNm\n\t\t\t\t\t\tikN+gF5Fqod7Ga/Uw8RVj9BC79aRzWTpfhyp8B/fXBnW0wSrSnrCQC7OB96XFlxU\n\t\t\t\t\t\t9yn++rbHAZLv48eA2kA3fO/fZtudMsQZMc1d8qHkGkchdUDIbOLllsr3CyLxG9kD\n\t\t\t\t\t\tONkv4+Ht1Lcdfp6Y0LjBLfBGTwIDAQABMA0GCSqGSIb3DQEBCwUAA4IBAQB/1Mec\n\t\t\t\t\t\ty2q86P1bZD4Pspeaw/MaBKA+Im8GsrpGdQ3IUkwrknqeLw+ZC9JgcG35ImU7bhnj\n\t\t\t\t\t\tGKajNLS2veuODfgN1U20mPdSrWOBIq//QGfrg9QDWhNnntb1e2WTECtpHr+I//7o\n\t\t\t\t\t\t/mBRNFDFzCiBpTJh+uSCn31fxxcRdjXMSgotDZ9ss8o3cnfvX6tx0byL/r2xoLFT\n\t\t\t\t\t\teCIaR1fjrQMwcZ3Yo7tgiRdPrTUMqmV9R94XRX8VsjcMgXHP/3nJRe0SJo6CEahj\n\t\t\t\t\t\tStVbzLE1Wc+P/kNGPRD3U1+Mzwa7Y7fZenkuR4xVKGFHJS6NyozJG37FwaWM775s\n\t\t\t\t\t\tdgZDvrnXtrH7Soum"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "proofidcloud.co.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso-demo.proofidcloud.co.uk/idp/isx.saml1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso-demo.proofidcloud.co.uk/idp/SSO.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso-demo.proofidcloud.co.uk/idp/SSO.saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso-demo.proofidcloud.co.uk:8443/idp/soap.ssaml1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "proofidcloud.co.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCDCCAfCgAwIBAgIGAUwSdXIfMA0GCSqGSIb3DQEBCwUAMEUxCzAJBgNVBAYT\n\t\t\t\t\t\tAkdCMRAwDgYDVQQKEwdQcm9vZklEMSQwIgYDVQQDExtzc28tZGVtby5wcm9vZmlk\n\t\t\t\t\t\tY2xvdWQuY28udWswHhcNMTUwMzEzMDkyNzA5WhcNMjUwMzEwMDkyNzA5WjBFMQsw\n\t\t\t\t\t\tCQYDVQQGEwJHQjEQMA4GA1UEChMHUHJvb2ZJRDEkMCIGA1UEAxMbc3NvLWRlbW8u\n\t\t\t\t\t\tcHJvb2ZpZGNsb3VkLmNvLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\n\t\t\t\t\t\tAQEA1a9N/0Jzf+SLunGwsQlsZ6eCw0v/P4JsYnkiM1+hspj28Dvk3DZ6T7FzW9Wb\n\t\t\t\t\t\tAcpnMqesvvYWukrvSYWF7cJ4gtGaaqUOvrIHWCFHs4wZgD7dpas3QCg33ehdomIl\n\t\t\t\t\t\t4kev30P+vjRVF3v59riCK+1sKES00oL3fAI1oa7iKEkVewd8UleDGw4FepL2VaNm\n\t\t\t\t\t\tikN+gF5Fqod7Ga/Uw8RVj9BC79aRzWTpfhyp8B/fXBnW0wSrSnrCQC7OB96XFlxU\n\t\t\t\t\t\t9yn++rbHAZLv48eA2kA3fO/fZtudMsQZMc1d8qHkGkchdUDIbOLllsr3CyLxG9kD\n\t\t\t\t\t\tONkv4+Ht1Lcdfp6Y0LjBLfBGTwIDAQABMA0GCSqGSIb3DQEBCwUAA4IBAQB/1Mec\n\t\t\t\t\t\ty2q86P1bZD4Pspeaw/MaBKA+Im8GsrpGdQ3IUkwrknqeLw+ZC9JgcG35ImU7bhnj\n\t\t\t\t\t\tGKajNLS2veuODfgN1U20mPdSrWOBIq//QGfrg9QDWhNnntb1e2WTECtpHr+I//7o\n\t\t\t\t\t\t/mBRNFDFzCiBpTJh+uSCn31fxxcRdjXMSgotDZ9ss8o3cnfvX6tx0byL/r2xoLFT\n\t\t\t\t\t\teCIaR1fjrQMwcZ3Yo7tgiRdPrTUMqmV9R94XRX8VsjcMgXHP/3nJRe0SJo6CEahj\n\t\t\t\t\t\tStVbzLE1Wc+P/kNGPRD3U1+Mzwa7Y7fZenkuR4xVKGFHJS6NyozJG37FwaWM775s\n\t\t\t\t\t\tdgZDvrnXtrH7Soum"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ProofID PingFederate IdP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.proofid.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ProofID Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://eka-idp.lanet.lv",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ITserviss"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "itserviss@lu.lv"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://eka-idp.lanet.lv",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://laife.lanet.lv/wiki/Latvian-Academic-Identity-Federation-Policy.pdf"
              }
            ],
            "registration_instant": "2013-10-10T10:10:10Z",
            "registration_authority": "http://laife.lanet.lv/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://eka-idp.lanet.lv/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://eka-idp.lanet.lv/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:56.950974,24.116292"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The University College of Economics and Culture"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The University College of Economics and Culture- EKA IDP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://laife.lanet.lv/"
          },
          {
            "lang": "lv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://eka.edu.lv/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LAIFE - EKA"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/det.kristne-gym.dk/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/det.kristne-gym.dk/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2011-10-25T12:46:26Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/det.kristne-gym.dk/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kristne-gym.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Det Kristne Gymnasium"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The Christian Gymnasium"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "kristne-gym.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAjCCAeoCAQcwDQYJKoZIhvcNAQELBQAwRzFFMEMGA1UEAww8aHR0cHM6Ly9k\nZXQua3Jpc3RuZS1neW0uZGsvc2ltcGxlc2FtbC9zYW1sMi9pZHAvbWV0YWRhdGEu\ncGhwMB4XDTE1MDEwMTAwMDAwMFoXDTI1MTIzMTIzNTk1OVowRzFFMEMGA1UEAww8\naHR0cHM6Ly9kZXQua3Jpc3RuZS1neW0uZGsvc2ltcGxlc2FtbC9zYW1sMi9pZHAv\nbWV0YWRhdGEucGhwMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAx4gM\nCmoQU7iOGfiCda4DnhIggst20fUCHtwaQrHoxQlOa0s5FgDalbnNTw36dCXSGYaz\n17JgyUDJonTwhjyA0CqPm5Pmn9/hFBUvyP/t+bEgV9r3/odQx72VfY7M55qUlY6e\nx2f1qD1gcpFgSTtADlZswec5WqpEt+ie+vsMXq8HabhMVZ2EjXe90vgMk/xGfrVw\nDvupUPBS/2DJSZ1JEmkqi0hxctNQ9qgTZmEcAaQkuv3VGcsYtLeY/IISlA+ARzmV\nWr5+uSetnCXV4jnDEclACKeexl0Ky+tyra4yHF3Xavgmcmebd+xHVDiM+No6BXMu\n9zBTp7cp5ShLzsNQSQIDAQABMA0GCSqGSIb3DQEBCwUAA4IBAQCoUBE3jK8ztvya\nKQuU9cbWt39ew+Thn05TXGTLY+uoTqE/CIgnG9b1UUJGFsuh/21Iy8U1GaskTg9J\n5ePAf5X8r0gunshVgzsYIUkjyFh29g59FOr/VJezhzudoBYXKa9hygheEWYvPB15\nJskdU00YEbp0ql+FHgCAYxgORQY3o6HgUqLUdwNK5ySALZLXb8gx83J/tUBQWjXa\n7PlnX2NZ0LViHI7dgX1TTJWG4smT88Jl5Xelo99XaarlIsCNkeyl6fl+c7xNR3Sg\na49V4RspOhcJ7AR2/E11J0DcbrLtX1CQtQGC1ACyzP3ZaXrnS3K22LNdJNLar9nk\nbNSPxoYF"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Det Kristne Gymnasium"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Christian Gymnasium"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kristne-gym.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kristne-gym.dk"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Det Kristne Gymnasium"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Christian Gymnasium"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://unmpidp.unm.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "chuckp@unm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chuck Phillips"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ehenry@unm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Libby Henry"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jagalb@unm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jared Galbraith"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jagalb@unm.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jared Galbraith"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://unmpidp.unm.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://unmpidp.unm.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://unmpidp.unm.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://unmpidp.unm.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://unmpidp.unm.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://unmpidp.unm.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unm.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Primary IDP for the University of New Mexico"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of New Mexico"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJzCCAg+gAwIBAgIUHkqghRUEAkZxZ/0df+bxNNL7T9AwDQYJKoZIhvcNAQEF\nBQAwGjEYMBYGA1UEAxMPdW5tcGlkcC51bm0uZWR1MB4XDTEyMDExMTE4NTU1NloX\nDTMyMDExMTE4NTU1NlowGjEYMBYGA1UEAxMPdW5tcGlkcC51bm0uZWR1MIIBIjAN\nBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmROfmboGYsxF4ku4WuME7OETL99Z\n5Yx4ZvBd2YFDHwMuuEn3NoKcoQVd26ey+8Ae/Y9bvBS667g87+tKW3xAXAWvsvnT\n0eNh27YXtNkm8TZWs2rmRYM9k1QsF45O2NurMxj/P9TBF5F4BvSbT4/lxd5ZNpJC\nS96rVSfM1hgUXhCdDNOQEg6ZG4Kakhkmiki+1LlfWwM4EBXySWiKuFrPruz/tUTm\np+kXJ7NI8vrDCTsWwD8f4CA4XoySkAsSXKYOtL/Vqmo6T4IoQmsNnkfNApn0AFLM\nApS4Svgds/F8nm6+14/UV7Ol7P1Iy9M4o01Fc2HtUxm9/tPSPLRGj7O2PQIDAQAB\no2UwYzBCBgNVHREEOzA5gg91bm1waWRwLnVubS5lZHWGJmh0dHBzOi8vdW5tcGlk\ncC51bm0uZWR1L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTZrZ1dPGWgZ9RxQDBp\nTtzO9iPGVzANBgkqhkiG9w0BAQUFAAOCAQEAMHPssz1ZNLmk4zm7ocuQY1CqlQxb\nplnjNRYxSznr1PQ2ZF6I6H/KQCsfyhY/gU0UGtnfh9bj60p5d50h9eCuHTi0KL54\ncCw9ijyKK0v/4EdYBk6ib9koDzwwX/BmGJxPuDPkoboWqmb0mCKM4TFkWmEivAw3\nTMXYK7ycdYBfsqaH9w7lG7esXXThYRiktRq5mzCxQx93x7H5LCF4o+OFvSx0mCX2\nIoYdDX58vQSM0wh4b8pjNSWyPhyyt7Ogee4EVq17sJLMLlFzggjbJCE6YkBvwxce\nmtW4BfJL5R5xn6jGVmGkCJ/H3Qn4XW26dFRbTtpoKVeYnogS4bPdvoc4qQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of New Mexico"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unm.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of New Mexico"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.sweclarin.se/sp/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Millet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pablo.millet@gu.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pablo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.sweclarin.se/sp/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.sweclarin.se/sp/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.sweclarin.se/sp/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.sweclarin.se/sp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp.sweclarin.se/sp/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.sweclarin.se/sp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp.sweclarin.se/sp/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://login.ki.se/idp/shibboleth",
    {
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.ki.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.ki.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.ki.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.ki.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.ki.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ki.se"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r Karolinska Institutet."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Karolinska Institutet."
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.ki.se/images/ki_logo_292x146.png",
                    "height": "146",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "292"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Karolinska Institutet (endast nya Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Karolinska Institutet (only new Ladok)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "ki.se"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:59.3475753,18.0279382"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:59.219589,17.940939"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.229.0.0/18"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.237.96.0/19"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.237.128.0/20"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.237.204.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.237.207.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.16.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.140.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "194.14.96.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:06B0:0022::/48"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "136.155.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "159.38.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.63.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.10.76.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUSr91KhOWgx1LLaoQAw69hE2zxN8wDQYJKoZIhvcNAQEL\nBQAwFjEUMBIGA1UEAwwLbG9naW4ua2kuc2UwHhcNMTUxMTEwMTMyNjU0WhcNMzUx\nMTEwMTMyNjU0WjAWMRQwEgYDVQQDDAtsb2dpbi5raS5zZTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAJ+xNQGjVs6rbJym13yai5iPGLhcXcDFhs2dcckk\n9SnhS0oEhHEPdwn9iwtkXbDaQCdlPzKw1lAQ4PFeqeynh3bM/GNz5RLQp3Fiac1b\nn2MiUEK6Xj2T+5XZklJHwsXnAP5FrPfsXLJ8kbDU7cS7aQ9b+8xqs+YNjIzZzEAx\nOGQp7/zwHTFejWc0GfxrARc+L5xwlXyQGRFjGQAs8Ka+WlV5MhyZFnHV81+/O4Xu\ngztzKuC2i0QKt46S1hep2Za8KxmWfN1pzWG8hnJHFWYOtRuKmTs4tF6ln03c72zF\n0wZ0zv5VKsplRd7ZGozJ275i0gntt233X9RoBM9rGYVBkaMCAwEAAaNdMFswHQYD\nVR0OBBYEFBqgkKxTUPlSShbr1NxOyLvrWkljMDoGA1UdEQQzMDGCC2xvZ2luLmtp\nLnNlhiJodHRwczovL2xvZ2luLmtpLnNlL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3\nDQEBCwUAA4IBAQAB7enC9iTTTfKZXUFtdXPEEJte/x3VembkSftwr+sK1EtDezIB\nR8LUsMqovpC771JmJbhkEVNtErfG9cwyKC3g0oWRY5U02jGxuxcq7yEh6/bTIZ0R\nnx88SX0+V9jMDfQKBFhljKCuozq70dGtApXm8bmuvBPe5gQ9+NaSKWkniOPv+zOS\nwOUUvi/8r6AE7PtCXn6uydqUcEo/oh8OMZOVx0siApLrG6NwZpGUz6l8mqH00zd5\nLslkb6jUsVBP2o/ORnwRlgY0I4491wMALYaplSMa1LUZPyB7Iv5IuHkybBEYy+mY\nGzAYjGQSD2+4EUgB8f7vuxJSjRnfmVUmh6cB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUQnJmXS4G/tbR42ca8QG480l3MMEwDQYJKoZIhvcNAQEL\nBQAwFjEUMBIGA1UEAwwLbG9naW4ua2kuc2UwHhcNMTUxMTEwMTMyNjU0WhcNMzUx\nMTEwMTMyNjU0WjAWMRQwEgYDVQQDDAtsb2dpbi5raS5zZTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAJA5FGj3sWcneuNuMoqgT9nQ07FAXKdSnDtfASMq\n0ZyaxyLJbOlKyRRzy8okbWTAhuI98JvuvGsSjg2dXCvRFKI/fF5pXn70enux0Svk\nNUvZdnr38noCyEVpTUpSMjDrHF9V1FDAloJ65zbRepdHU4Sv9di5Vy9ppAo4VrLw\niR2AXS7EFQ39aIm37xPIQz2M0HXBERVCQHOg51LrwNnMCVE1I70s28qYzI3wo/0p\nHfD9qWqnqIz8Fr1UHCDGArJN1YhQJZbWlN2KBndl3Ike4obeDxQFnS707l8B1Hnh\nceV8ohgtK82bASKSVCJ1Z7w+CAGAhABqc8DCJ599mTDzm78CAwEAAaNdMFswHQYD\nVR0OBBYEFDrrD9A+XOKI8btkdBaO8hvc/vyMMDoGA1UdEQQzMDGCC2xvZ2luLmtp\nLnNlhiJodHRwczovL2xvZ2luLmtpLnNlL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3\nDQEBCwUAA4IBAQBhpdosfvuPTuvAoK0jokVl7gqDW53KrRTD+BrJRoOGPBQ2DXVF\nTvQdmS/zymbrFghQr0XOzYLRa+fP6lfoNusBWKfL0Fyto8skicSNswYDG1zgF6HI\n03eHqhB5ma6u4rh3gAMwVcpyYCcrrJ2hbTI8BWXzZFaxXM9JaK7u2J8k5tGAccK1\n247NSR8LEai46HkZpovuKPjD9zwunV6mQeOXQeo3WtoPW0twB9h01sfqV0iMvaXg\nTu4iUPkcwpIeauNAjJ4KXpl5OxehsBnz9rrb6smtz2bfWBBNiPHaHhT6XIqon5X1\nkEJEO2P16fM/dhzKIPEqH52zd3J8O6Hs1Cil"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUEEr81svYHmizs6DjzN0FCQ1IlLkwDQYJKoZIhvcNAQEL\nBQAwFjEUMBIGA1UEAwwLbG9naW4ua2kuc2UwHhcNMTUxMTEwMTMyNjU0WhcNMzUx\nMTEwMTMyNjU0WjAWMRQwEgYDVQQDDAtsb2dpbi5raS5zZTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAMIJsWHFr/fc/26Dfv0WOBhspXfyRVGSHMu5IeRs\nreQGRKbrdW4KOOrKQkqZnyQVe8eZt/GZKSzy+9VnAJo3ypaUt2y0LsTqibcg7oNO\nRcC2yDKlEN8CCSX3OQrQ1kWRxHpMSaHx1TeWAPI9kB0CykeG6FmVYXG9arY9u9pn\nZvdPCXg7SkFbTCa1zJdbxBCumq/nAKGiEct6GQHMeYOb9YBI+WYYByfseLdf5dNC\ni1fXuRYbxK9dcFIVlGuZRea99TklSZZR3BxFLHgcECjp1ZtoT0Byl2yxmm0nGJE2\nHKh+LsxAUz3ouG3qItUJPYzBS1RHQVWYz8N4T8z+w+1jEY0CAwEAAaNdMFswHQYD\nVR0OBBYEFKf0zzGixtPS531/l3z2Vc04g1seMDoGA1UdEQQzMDGCC2xvZ2luLmtp\nLnNlhiJodHRwczovL2xvZ2luLmtpLnNlL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3\nDQEBCwUAA4IBAQA4PPWZd96F0l40muNxqPzVNzTq/D+ndRhEcPOxk8SraEXaFlkm\nxqELKuLnuj7MAx+y/SJssIs9acDm8CBxp60z9hSTkokVjVAfyWiTU+KuTGvwWWnP\nT25PheKwMPl+W45PhXfbK0F1nDXvNf2L59gxuBIJEcqojx6BHlLfz1tbQUCsezV4\nfv98gre6OoWeN5TSiWgtl7Gsb1cjFRcfiYNwDo9pWqNnLOioncMs4SOyEKrTxrU7\nrmABcIrDyPLSecdGrJBUBiYy1tTm72SEGK9npcZ8QPuXkkSf7zskTenf4tFszUnq\nBazoaLKp7SoAtN5cqOcYTgOJY89fkO6T8gqd"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Karolinska Institutet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ki.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "KI"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "entity_id": "https://login.ki.se/idp/shibboleth"
    }
  ],
  [
    "https://shibboleth.highwire.org/entity/oxfordservices",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.highwire.org/entity/oxfordservices",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-09-14T15:23:45Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Oxford Online"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oxfordonline.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HighWire Press, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.highwire.org/applications/oxfordservices/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.highwire.org/applications/oxfordservices/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIJAMTRVlqTJ11lMA0GCSqGSIb3DQEBBQUAMIG+MQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBD\n\t\t\t\t\t\taXR5MRcwFQYDVQQKEw5IaWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUx\n\t\t\t\t\t\tIDAeBgNVBAMTF3NoaWJib2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkB\n\t\t\t\t\t\tFiZzaGliYm9sZXRoLWFkbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTAeFw0xNDA0\n\t\t\t\t\t\tMTUxOTQzMDNaFw0yNDA0MTIxOTQzMDNaMIG+MQswCQYDVQQGEwJVUzETMBEGA1UE\n\t\t\t\t\t\tCBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBDaXR5MRcwFQYDVQQKEw5I\n\t\t\t\t\t\taWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUxIDAeBgNVBAMTF3NoaWJi\n\t\t\t\t\t\tb2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkBFiZzaGliYm9sZXRoLWFk\n\t\t\t\t\t\tbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALPB99M9iWjentrddY/rLgzKn1X0j4Ao191iyiowBBt/r/pmn2oz\n\t\t\t\t\t\tfrbONkkTVBB++mNtiufK6jyKnBM5mffPOkXHRo+K1DQec7TvpQ1PmLv/BpBgPrr9\n\t\t\t\t\t\tldViOSUnYJuB0IgJVV8oylgeH2Ay0XRkNPlBUjBA2fUPWVpXcvFe+aD2tLdVR9uO\n\t\t\t\t\t\tXvfTMxAEGqzxTU+OxO6pW2sBXNBmGvZQ0TRyovQh5+pTURY/lm0V/iWvRmRe51WE\n\t\t\t\t\t\tO/nhYyvRuMmNj8EL38o10S9TXuCkVzY00hK5cclaFge7gz/tfjmadVVcbe8xCVxc\n\t\t\t\t\t\tnb1lhmt1kH2XtKvU5hyZMTO+VUfXQvqcQyECAwEAAaN7MHkwCQYDVR0TBAIwADAs\n\t\t\t\t\t\tBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYD\n\t\t\t\t\t\tVR0OBBYEFJpUZq/XaW9/bPvjffkxX0IDvuPiMB8GA1UdIwQYMBaAFJpUZq/XaW9/\n\t\t\t\t\t\tbPvjffkxX0IDvuPiMA0GCSqGSIb3DQEBBQUAA4IBAQCq/FF56ZB1cL3KbniEJP99\n\t\t\t\t\t\tU9wTD6KpOrWxvqNbUSV1cefLf5cYHonOjy6oAJSSBSNuP7U5Q//0tXtkvlJoqGUY\n\t\t\t\t\t\tvqngmeg9wLZ/Fla3tXcDdTj0n1F+NZOx9vBDacIk0Ua4aHXDA4bdytzkV1QyZDRq\n\t\t\t\t\t\tQ8vq7RoQ8E5IF7Cll+kt2dZXQk8o6Qp3w2ppoMRtYdKOQassqn+V1MYcMPgdxZkS\n\t\t\t\t\t\tDrcgzktR/JMb5OmPrp4mSy1OWDGrFvUIigsLBPZV9tw1f7y42lnbmQas3RCS30yr\n\t\t\t\t\t\tCtUPT/PQDkCdBRViGmmMkYwjdaOTiHOJveWtrVXu8vLvO36pqFF4Kft0pgqlfvAE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.highwire.org/applications/oxfordservices/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.highwire.org/applications/oxfordservices/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.highwire.org/applications/oxfordservices/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.highwire.org/applications/oxfordservices/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.nptc.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lewis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chris.lewis@nptcgroup.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Lewis"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chris.lewis@nptcgroup.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.nptc.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-07-01T09:00:48Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVAOuMhJPh+PUsyjWCDIkMwY77mV8nMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCAxHjAcBgNVBAMTFXNoaWJib2xldGgubnB0Yy5hYy51azAeFw0xNDA3MzEx\n\t\t\t\t\t\tMzM4MTRaFw0zNDA3MzExMzM4MTRaMCAxHjAcBgNVBAMTFXNoaWJib2xldGgubnB0\n\t\t\t\t\t\tYy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIxTzrChL9Ud\n\t\t\t\t\t\tALbMY1tQii/tKJb010drODV9hTRwm9p5kGPiviV9kMqaWkuBLihzZtaXnOa0RfBj\n\t\t\t\t\t\tb+wrJxGx1JGzSUXSvZaI3LMUKM+P8+ewhAfd4z+85uxdBtS7Foy5HD5xNZfCAQap\n\t\t\t\t\t\tODUsT0nG/N7eMBv4v0CatmygS6WRRjE89UVQQcc69j+/hjfMvO+oBHlMXgfqMc2a\n\t\t\t\t\t\tjq/A3TUy/fHUosYdAZiQ5Cu2uJS2qwvxE59vkI1/x70k+PKuG2CB7UKmN5iGoYQ7\n\t\t\t\t\t\tkThjQJMyjL2W7V4f9/9Y3oe6Co6stCF+4v+RuVBXM8GzITGP1lpdPk0qFSxFMdS6\n\t\t\t\t\t\tXghrbldDD5cCAwEAAaNxMG8wTgYDVR0RBEcwRYIVc2hpYmJvbGV0aC5ucHRjLmFj\n\t\t\t\t\t\tLnVrhixodHRwczovL3NoaWJib2xldGgubnB0Yy5hYy51ay9pZHAvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQULe2KsIkQADxw5Ty0+mY6dQuclkYwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAHFeFNvxnYZS4C36tCWddIbqhy28j02wq9BNa1Z81rgFW4X/7bLYMCWVogz8\n\t\t\t\t\t\tIx0XDTqYoYabDygGk5KNXMufaBg6or5Yc95YyVWYEfDMYZvttprXeY7wLtXqiZdq\n\t\t\t\t\t\t4swR+ZPGF5Dahmn+fG+2bqL3E7PdCDkQNzpIlc57a1faLMnh8qeZyN62mxYrFEKJ\n\t\t\t\t\t\tRv5fXenQI9vwy9STCfHzgu7F9Lo3O3C3+VLsp128RL7RvAAt8ylswYPw5c1OhLVF\n\t\t\t\t\t\t1tPtzpQSWBjOGsjeFOI5IK0TbyX3e6GK8NjypAX0gjSqO70v6o2ZFm5svXDHyUl/\n\t\t\t\t\t\trhxiSLK1U13f5Z1zFhi15dJ7tLE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nptc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.nptc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.nptc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.nptc.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.nptc.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.nptc.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.nptc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.nptc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.nptc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.nptc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.nptc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.nptc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nptc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVAOuMhJPh+PUsyjWCDIkMwY77mV8nMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCAxHjAcBgNVBAMTFXNoaWJib2xldGgubnB0Yy5hYy51azAeFw0xNDA3MzEx\n\t\t\t\t\t\tMzM4MTRaFw0zNDA3MzExMzM4MTRaMCAxHjAcBgNVBAMTFXNoaWJib2xldGgubnB0\n\t\t\t\t\t\tYy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIxTzrChL9Ud\n\t\t\t\t\t\tALbMY1tQii/tKJb010drODV9hTRwm9p5kGPiviV9kMqaWkuBLihzZtaXnOa0RfBj\n\t\t\t\t\t\tb+wrJxGx1JGzSUXSvZaI3LMUKM+P8+ewhAfd4z+85uxdBtS7Foy5HD5xNZfCAQap\n\t\t\t\t\t\tODUsT0nG/N7eMBv4v0CatmygS6WRRjE89UVQQcc69j+/hjfMvO+oBHlMXgfqMc2a\n\t\t\t\t\t\tjq/A3TUy/fHUosYdAZiQ5Cu2uJS2qwvxE59vkI1/x70k+PKuG2CB7UKmN5iGoYQ7\n\t\t\t\t\t\tkThjQJMyjL2W7V4f9/9Y3oe6Co6stCF+4v+RuVBXM8GzITGP1lpdPk0qFSxFMdS6\n\t\t\t\t\t\tXghrbldDD5cCAwEAAaNxMG8wTgYDVR0RBEcwRYIVc2hpYmJvbGV0aC5ucHRjLmFj\n\t\t\t\t\t\tLnVrhixodHRwczovL3NoaWJib2xldGgubnB0Yy5hYy51ay9pZHAvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQULe2KsIkQADxw5Ty0+mY6dQuclkYwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAHFeFNvxnYZS4C36tCWddIbqhy28j02wq9BNa1Z81rgFW4X/7bLYMCWVogz8\n\t\t\t\t\t\tIx0XDTqYoYabDygGk5KNXMufaBg6or5Yc95YyVWYEfDMYZvttprXeY7wLtXqiZdq\n\t\t\t\t\t\t4swR+ZPGF5Dahmn+fG+2bqL3E7PdCDkQNzpIlc57a1faLMnh8qeZyN62mxYrFEKJ\n\t\t\t\t\t\tRv5fXenQI9vwy9STCfHzgu7F9Lo3O3C3+VLsp128RL7RvAAt8ylswYPw5c1OhLVF\n\t\t\t\t\t\t1tPtzpQSWBjOGsjeFOI5IK0TbyX3e6GK8NjypAX0gjSqO70v6o2ZFm5svXDHyUl/\n\t\t\t\t\t\trhxiSLK1U13f5Z1zFhi15dJ7tLE="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NPTC Group"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nptc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Neath Port Talbot College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://wp.nordu.net/shibboleth",
    {
      "entity_id": "http://wp.nordu.net/shibboleth",
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "http://wp.nordu.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "http://wp.nordu.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://wp.nordu.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "http://wp.nordu.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "http://wp.nordu.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "http://wp.nordu.net/Shibboleth.sso/DS/test-ds.nordu.net",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "http://wp.nordu.net/Shibboleth.sso/DS/test-ds.nordu.net-dj",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "http://wp.nordu.net/Shibboleth.sso/DS/skolfederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "http://wp.nordu.net/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "4"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "http://wp.nordu.net/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "5"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "leifj.nordu.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAPoZZSAmc/l2MA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2xlaWZqLm5vcmR1Lm5ldDAeFw0xMjAyMjkxMzAzNDZaFw0yMjAyMjYxMzAz\nNDZaMBoxGDAWBgNVBAMTD2xlaWZqLm5vcmR1Lm5ldDCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAMIHbbT3m/6fI3EcEYK0wfEDMmb4AmLBjf1kko+a0d1s\nzdhIgeLDbBwi5v9aqS3504nAS5W25MlyYha87xghSDXLXrXHi7HLCIRUYStEiyDr\n6Isl+1ZujXEW+yaipdkTBTmg10vP3VjLgv/KNEgwwgohqsKj8Pr4NGrrdlXVgW5U\nSj3haVm0skx2jD+8PWnF/dREOqejHeWjRvbKD6gtmoIMPM/qbl1cy6VEsRLiIifo\niNP/fm0MlWPsEiJ9Qmp04QUD66iJ2xVrPv3nM1IKoUifRXaWdPFI4cz8Wlkm/JV9\nqNRfgVB3q7zvNmu4vJgTwzPxvmuB0fgz0o/cNmS+vKMCAwEAAaM9MDswGgYDVR0R\nBBMwEYIPbGVpZmoubm9yZHUubmV0MB0GA1UdDgQWBBTf64pGyxTkQRMjVQT2ra0N\nEyjvWjANBgkqhkiG9w0BAQUFAAOCAQEAAcmKI4qEPi+EYp6xZMNgCH5d8r8Bk1Lf\n9KgtFOV05+M4NpMKGVkDMZJbdF7fILfeI5iZoW2JzQlUkUIF9pbaicfrpAemcPET\ny8GYXkpnKS5AX+H7fyzfyt1EDStBwI4rlNw5Gfgu6LIiE7+t6+jzBYBC7xyx2dwH\n4XsJdtJuBFbz70NfV9XA84D6frNl+XXsC1ZHnwnwJXhtNIfWgLnQj0i1FMs7+bFP\nZ0TqyXKdwviYeLZbhkRQLxf82H0g5p2IY1+iR2aWOQFJwhm6sDAGBTSup0fmGxFk\n6P0RaIYawNNB2VMNAsVvyEwop4exElQK7WF/20xXETiUKWFOA8PD6Q=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=leifj.nordu.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "leifj.nordu.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAPoZZSAmc/l2MA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2xlaWZqLm5vcmR1Lm5ldDAeFw0xMjAyMjkxMzAzNDZaFw0yMjAyMjYxMzAz\nNDZaMBoxGDAWBgNVBAMTD2xlaWZqLm5vcmR1Lm5ldDCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAMIHbbT3m/6fI3EcEYK0wfEDMmb4AmLBjf1kko+a0d1s\nzdhIgeLDbBwi5v9aqS3504nAS5W25MlyYha87xghSDXLXrXHi7HLCIRUYStEiyDr\n6Isl+1ZujXEW+yaipdkTBTmg10vP3VjLgv/KNEgwwgohqsKj8Pr4NGrrdlXVgW5U\nSj3haVm0skx2jD+8PWnF/dREOqejHeWjRvbKD6gtmoIMPM/qbl1cy6VEsRLiIifo\niNP/fm0MlWPsEiJ9Qmp04QUD66iJ2xVrPv3nM1IKoUifRXaWdPFI4cz8Wlkm/JV9\nqNRfgVB3q7zvNmu4vJgTwzPxvmuB0fgz0o/cNmS+vKMCAwEAAaM9MDswGgYDVR0R\nBBMwEYIPbGVpZmoubm9yZHUubmV0MB0GA1UdDgQWBBTf64pGyxTkQRMjVQT2ra0N\nEyjvWjANBgkqhkiG9w0BAQUFAAOCAQEAAcmKI4qEPi+EYp6xZMNgCH5d8r8Bk1Lf\n9KgtFOV05+M4NpMKGVkDMZJbdF7fILfeI5iZoW2JzQlUkUIF9pbaicfrpAemcPET\ny8GYXkpnKS5AX+H7fyzfyt1EDStBwI4rlNw5Gfgu6LIiE7+t6+jzBYBC7xyx2dwH\n4XsJdtJuBFbz70NfV9XA84D6frNl+XXsC1ZHnwnwJXhtNIfWgLnQj0i1FMs7+bFP\nZ0TqyXKdwviYeLZbhkRQLxf82H0g5p2IY1+iR2aWOQFJwhm6sDAGBTSup0fmGxFk\n6P0RaIYawNNB2VMNAsVvyEwop4exElQK7WF/20xXETiUKWFOA8PD6Q=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=leifj.nordu.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "http://wp.nordu.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "http://wp.nordu.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://wp.nordu.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "http://wp.nordu.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "http://wp.nordu.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "http://wp.nordu.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "http://wp.nordu.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "http://wp.nordu.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "http://wp.nordu.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "http://wp.nordu.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-demo-01.its.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-demo-01.its.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-01.its.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-01.its.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-01.its.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-01.its.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-01.its.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-demo-01.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-demo-01.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;demo-01"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;demo-01"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-demo-01.its.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-demo-01.its.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIJAOeH1y234BADMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\nBAMTGWxhZG9rMy1kZW1vLTAxLml0cy51bXUuc2UwHhcNMTIxMjA3MDcyODExWhcN\nMjIxMjA1MDcyODExWjAkMSIwIAYDVQQDExlsYWRvazMtZGVtby0wMS5pdHMudW11\nLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA5w0tDtWTb1i7oEXr\ncmgSbQN2+INDlywnQRJXaGDyjypZ66LtKafw0E2g7WXCfYupkGGIf9UhpYY2tbMh\nd0yztJiKtvWTbEb8E8Z7D1kG5FuoXQkjmG2w/FKzSAFH0MLiGyfvr9oBab3F7yZQ\nzZ7t9XPc1RFe2qAYmu3iH383RmRb9fje/WXQVk4cMybqhCZTUoiHBWo9dZhwdxfL\n/UeN8BqIY+NwcmcaIdyPQKH2NGB5/3bJr0doap127tyokoyfLDo8meJnBc4zwSt4\nXCLFmC4g/1JsIe6T2RsieYtpVY0teWB+LH0emFTlyuhoNMM1bTtVfUk4mjq/R1B8\nmjxKhwIDAQABo3EwbzBOBgNVHREERzBFghlsYWRvazMtZGVtby0wMS5pdHMudW11\nLnNlhihodHRwczovL2xhZG9rMy1kZW1vLTAxLml0cy51bXUuc2UvZ3VpLXNwMB0G\nA1UdDgQWBBQgFTqtvplztjIK/Tf1iTAdLHAEwzANBgkqhkiG9w0BAQUFAAOCAQEA\nOecNgHiP0PD31hbHg8QxsL6IHqpOIrvXRyj+U9gnG/S1ivj79y+lyO6HLrqsycOJ\nUiWyXm1zkG9otie1FBOVIQeZ5GKf3qEgfphkTBcigBCHKMxrDFOEjr9WlZEX7UAw\n3wpgakdItEHPLbvx/v0x2aLvEgf7FrV9cYrv0HpVI+rZrETTDxWulmS1WE3jr4mm\n+Xbwm5CdJMFxtdHoADDUxbYpb7HMu8XLPN0/nVKEs/87xGCVQbHO8uRNQmeDAQhn\n0ev1AvjK9iWoPASSWa05+hcK6gULU5zjl0B4zuECMj9Q5k4Y/0rEcKN828D+JXHq\n9eyXLV8+BdsY6n7mcEsoOg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-demo-01.its.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-01.its.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-01.its.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-01.its.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-01.its.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-01.its.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-01.its.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-demo-01.its.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-demo-01.its.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-demo-01.its.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ezproxy.rgu.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cunningham"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.cunningham@rgu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Milne"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:r.milne@rgu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ezproxy.rgu.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-07-01T10:29:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Robert Gordon University: EZproxy Service"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rgu.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Robert Gordon University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ezproxy.rgu.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ezproxy.rgu.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "3",
              "location": "https://ezproxy.rgu.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ezproxy.rgu.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEpDCCA4ygAwIBAgIJAJgUTeTAeKehMA0GCSqGSIb3DQEBBQUAMIGSMQswCQYD\n\t\t\t\t\t\tVQQGEwJHQjEWMBQGA1UECBMNQWJlcmRlZW5zaGlyZTERMA8GA1UEBxMIQWJlcmRl\n\t\t\t\t\t\tZW4xITAfBgNVBAoTGFJvYmVydCBHb3Jkb24gVW5pdmVyc2l0eTEZMBcGA1UECxMQ\n\t\t\t\t\t\tTGlicmFyeSBTZXJ2aWNlczEaMBgGA1UEAxMRZXpwcm94eS5yZ3UuYWMudWswHhcN\n\t\t\t\t\t\tMTQwNTA2MTQ1NTA1WhcNMjQwNTAzMTQ1NTA1WjCBkjELMAkGA1UEBhMCR0IxFjAU\n\t\t\t\t\t\tBgNVBAgTDUFiZXJkZWVuc2hpcmUxETAPBgNVBAcTCEFiZXJkZWVuMSEwHwYDVQQK\n\t\t\t\t\t\tExhSb2JlcnQgR29yZG9uIFVuaXZlcnNpdHkxGTAXBgNVBAsTEExpYnJhcnkgU2Vy\n\t\t\t\t\t\tdmljZXMxGjAYBgNVBAMTEWV6cHJveHkucmd1LmFjLnVrMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEA2Tzm0+NmopoXeqyx5SHaQ9UMNC5vb4EXAQ9JSSY/\n\t\t\t\t\t\tDuLy/LjQDjJBSFB3oDpOIb5Sm9OG9GOPB5Z5U37tQvV5iZQuNq7YXr3b1CPN/thw\n\t\t\t\t\t\tjESnCHBHvdUXCPGRldDA/g0lrAyiniLwkYGyyzDWUZFwhNOy+WYPlYSr+gQy6Wjz\n\t\t\t\t\t\tcEySDW5Pad8KvMKraaXugNLpwM/+ZjoBuDY9XESZzga4OQ2SdAZAeeAU4nt/k9Gx\n\t\t\t\t\t\tTmwb73+Z3lSMQHRgyOmMadk+zCftSAOFWyvLQrawv87qaeCwG4vBhpCTQ/NxS9C3\n\t\t\t\t\t\tmryv/uf3HMYqhjFF8OogmG8rcCwlu3AFbEF9OPF4gS17twIDAQABo4H6MIH3MB0G\n\t\t\t\t\t\tA1UdDgQWBBREOo8/1pVkYbj7YXLrtyZGOv2gRDCBxwYDVR0jBIG/MIG8gBREOo8/\n\t\t\t\t\t\t1pVkYbj7YXLrtyZGOv2gRKGBmKSBlTCBkjELMAkGA1UEBhMCR0IxFjAUBgNVBAgT\n\t\t\t\t\t\tDUFiZXJkZWVuc2hpcmUxETAPBgNVBAcTCEFiZXJkZWVuMSEwHwYDVQQKExhSb2Jl\n\t\t\t\t\t\tcnQgR29yZG9uIFVuaXZlcnNpdHkxGTAXBgNVBAsTEExpYnJhcnkgU2VydmljZXMx\n\t\t\t\t\t\tGjAYBgNVBAMTEWV6cHJveHkucmd1LmFjLnVrggkAmBRN5MB4p6EwDAYDVR0TBAUw\n\t\t\t\t\t\tAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAXgyDbrL+z46zzEuYEPIQSq6zVjQb8SDM\n\t\t\t\t\t\tg7UrEgIEJbM+3H7HXde8A7ZAxlKy76/qDDPm7/ICd763e8wWA8NSlZRwQ+ZTD8ea\n\t\t\t\t\t\td/b0Mt0DWAPz7TilJLLV2fgqlzn+jKJaOrl766XomUI1j/MnTdRGQKoDEg3Q+iox\n\t\t\t\t\t\tTZ1cyu6zsXR4vtq0M7r/9SIqblFYq12Ma9mnR4DgECY+UUP6DeBYjv16SQ2R4NMN\n\t\t\t\t\t\tEK298jRhTkhZLszADzTcL/ARxSV//GCmgUnKd4RCybWtA7uRP71/3qflHFpkVjoU\n\t\t\t\t\t\tgA28CO1KdN7ReDk2vPP0F+SahxgArJHT62ZbKptfiRR7I+m3nsR/+A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ezproxy.rgu.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://idp.gssk.si/idp/20141130",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kam\u0161ek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:meta.kamsek@guest.arnes.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Meta"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@gssk.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Miheli\u010d"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:toni.mihelic@guest.arnes.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Toni"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mihelic"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:toni.mihelic@guest.arnes.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Anton"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ferbe\u017ear"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tomaz.ferbezar@sc-nm.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Toma\u017e"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mihelic"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:toni.mihelic@guest.arnes.si"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Anton"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.gssk.si/idp/20141130",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_general.pdf"
              },
              {
                "lang": "sl",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://aai.arnes.si/static/doc/ArnesAAI_splosni_pogoji.pdf"
              }
            ],
            "registration_instant": "2014-12-02T11:12:08Z",
            "registration_authority": "http://aai.arnes.si",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.gssk.si/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.gssk.si/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gssk.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "student.gssk.si"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dijak.gssk.si"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.gssk.si"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.gssk.si"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for Gimnazija in srednja \u0161ola Ko\u010devje"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ponudnik identitet Gimnazija in srednja \u0161ola Ko\u010devje"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "115",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "120"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Gimnazija in srednja \u0161ola Ko\u010devje"
                  },
                  {
                    "lang": "sl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Gimnazija in srednja \u0161ola Ko\u010devje"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GIMNAZIJA IN SREDNJA \u0160OLA KO\u010cEVJE - Gimnazija"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "GIMNAZIJA IN SREDNJA \u0160OLA KO\u010cEVJE - Gimnazija"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gssk.si"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gssk.si"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GIMNAZIJA IN SREDNJA \u0160OLA KO\u010cEVJE - Gimnazija"
          },
          {
            "lang": "sl",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "GIMNAZIJA IN SREDNJA \u0160OLA KO\u010cEVJE - Gimnazija"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://fed-interop-wg.ligo.org/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "scott.koranda@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Scott Koranda"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "warren.anderson@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Warren Anderson"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "scott.koranda@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Scott Koranda"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "lsc-seccomm@ligo.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "LIGO Security Committee"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://fed-interop-wg.ligo.org/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "LIGO Scientific Collaboration"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ligo.caltech.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "LIGO Scientific Collaboration"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://fed-interop-wg.ligo.org/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://fed-interop-wg.ligo.org/spinfo.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "GitLab for I2 Fed Op WG hosted by LIGO"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "GitLab service for the Internet2 Federation Interoperability Working Group hosted by LIGO"
                  }
                ],
                "logo": [
                  {
                    "text": "https://fed-interop-wg.ligo.org/img/ligologo80x60.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://fed-interop-wg.ligo.org/spprivacy.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIJAO4GMlBzog5QMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2ZlZC1pbnRlcm9wLXdnLmxpZ28ub3JnMB4XDTE1MDgyOTE4NTYzOFoXDTE4\nMDgyODE4NTYzOFowIjEgMB4GA1UEAxMXZmVkLWludGVyb3Atd2cubGlnby5vcmcw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDAnD0Eot/XtlRZv1dgabn5\n1suiIcnCJyli3NF6Lnm8pm+QxuRfJxGQTyJcmaSuUixU3K9OorRVGVo0+La0liSK\n3yncmHZQ0SC7PKsuavwupM7QoEHuJXq2dj+cfz2+r7KtfUprE1GsdoYQe1lG0Q78\nmIFfZEoz+PPyIWJQbMk3P3W45mnYvYNWcxOFfoEGG3sEFJMnV8rI2cpLLbDRmY2l\nywwF9pvgP5ndDGaDwC+mEVW2+LLGc+g1MZfzuTUM/1jdduGgBrbH2VkunFDpaE7q\nJmKmeNEipvu46jQRqB+k5OAC++rJ0U3GtdGh6kF+6wleNwmKB98RBZZnrkwTTbbr\nAgMBAAGjcTBvME4GA1UdEQRHMEWCF2ZlZC1pbnRlcm9wLXdnLmxpZ28ub3Jnhipo\ndHRwczovL2ZlZC1pbnRlcm9wLXdnLmxpZ28ub3JnL3NoaWJib2xldGgwHQYDVR0O\nBBYEFBQ8hmlK6r1tTukMs96IGob5xMl+MA0GCSqGSIb3DQEBBQUAA4IBAQBCfGPD\n1SEjl3E/XtQ/9tv1NrCCOHib29BoFDIIjTejcyehwX0/lDW9Ryra6t+qlkofAuV9\nPUVL3dBQQFka0adUPonvs5Q9chisVj1hT4mhUz1C72m9wIDsIP9QQkuOqgK/3SFg\nJ0wsttMzP2uirZRnkg9DHKfym64D8sCpI8qWtHJbf40qxH9Zk90BKQWNR6e3qnLC\nncePo7O6V1anNgFJD78E+bNjd9KlY/YJkzOyL/M52HhM6IjDvBRgfhwUxf9HkdEb\nAPc4VR5gYD4DBiUTINX+Ex3yinxQ4AHx09FlvKXu2MKGmiCH3AozhjvR4vNFivqi\ndD7nKurLpav8RpR+"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://fed-interop-wg.ligo.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://fed-interop-wg.ligo.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://fed-interop-wg.ligo.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://fed-interop-wg.ligo.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "GitLab for I2 Fed Op WG hosted by LIGO"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "GitLab service for the Internet2 Federation Interoperability Working Group hosted by LIGO"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:displayName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonPrincipalName",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:mail",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://devsp.sweclarin.se/sp/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Millet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pablo.millet@gu.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pablo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://devsp.sweclarin.se/sp/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://devsp.sweclarin.se/sp/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://devsp.sweclarin.se/sp/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://devsp.sweclarin.se/sp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://devsp.sweclarin.se/sp/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://devsp.sweclarin.se/sp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://devsp.sweclarin.se/sp/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://uoe-shib.hosted.exlibrisgroup.com/shib",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ginestet"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:benoit.ginestet@exlibrisgroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Benoit"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://uoe-shib.hosted.exlibrisgroup.com/shib",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-03-12T13:57:14Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "This is a Shibboleth SP for the University of Edinburgh"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://exlibrisgroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ex Libris (UK) Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uoe-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://uoe-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uoe-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uoe-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uoe-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "This is an Ex Libris Primo Hosted SP on behalf of the University of Edinburgh"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Edinburgh - Primo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://uoe-shib.hosted.exlibrisgroup.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAIHsfkq6pSPaMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB2FpbzAwMjEwHhcNMTUwMjIwMjE1MzA1WhcNMjUwMjE3MjE1MzA1WjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdhaW8wMDIxMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\t+GqQ/e7BZpmfvaNUUPVyPQvF5kOAqzguqY/YKlYj6AqUwZiT7UI2sNmnhBMWfqp3\n\t\t\t\t\t\txQDm4obQqL+dKN8IO1NqtB3mDSk9I2xffDIzWXipBou+kgbrBKdI7jjRy5Jyogjh\n\t\t\t\t\t\tiCWwDob/pjSVG6ymk+6W99+we3kwasOIdL4l72pp4HpOmAXg0YtliBB4pdPn7j/a\n\t\t\t\t\t\t4l5uV1itS7e126hXv7gk2gegsmkgcvHs18CjpATjKCouOm+pWrbAAW92ZyDp9Kfd\n\t\t\t\t\t\tTXLkjiJzZWZOKD2aoHPx8FdQhIgxnJSdY80mH0oyJSdAMVH5Y5eWzuuaPKXAjzeB\n\t\t\t\t\t\tSeCzO/GJpQ7QIXTmc4QE/wIDAQABozUwMzASBgNVHREECzAJggdhaW8wMDIxMB0G\n\t\t\t\t\t\tA1UdDgQWBBQF2D5zrvZSq4lY1Ww/1qFpUKj6MzANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tS+GqgtoiVnYgzYx5+q+uHPeaFvX2oeEg3t4qrrd+02dhLTnRNB1fkg3RpNfISsnK\n\t\t\t\t\t\t4yUr17grT3pzOxDCm13iSw2sDfsVUrbJORQslKMemJ7dZDm1irzbPnqRpE8cwIFz\n\t\t\t\t\t\tqUrf+p4iUqvjnhMZ/8jW4SKtlo7GwkxFZ1xFznyLGQM7W47ZvqX1qdlEoWD+CkUD\n\t\t\t\t\t\tZ4M6UFXxC3sjOF1G0AF3K2YNfSWHwrqWdrUXXnsS1yNAutb/jv5zhhDcKb6YXPuU\n\t\t\t\t\t\ttcaxY6g7Qf6hKDePS/E1Za597QsmpfLNMhllU3JjTATGBBwHP3Ke/TSicuDYU/cu\n\t\t\t\t\t\t2uFODAwEKXXlTXol08EA3w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uoe-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://uoe-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uoe-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://uoe-shib.hosted.exlibrisgroup.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://fed.nusextra.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:enquiries@nusextra.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Enquiries"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:enquiries@nusextra.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Enquiries"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://fed.nusextra.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-14T10:18:20Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NUS extra Student Discount card"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nus.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NUS Services Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://fed.nusextra.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://fed.nusextra.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://fed.nusextra.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://fed.nusextra.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://fed.nusextra.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://fed.nusextra.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "To be eligible for the NUS extra student discount card, you need to be over 16 years of age, and in full or part time education"
                  }
                ],
                "logo": [
                  {
                    "text": "https://cards.nusextra.co.uk/media/images/nhs-rb-extra-logo-blue.png",
                    "height": "61",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "143"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NUS extra Student Discount card"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6zCCAdOgAwIBAgIJAJgeZ2sQotvlMA0GCSqGSIb3DQEBBQUAMBcxFTATBgNV\n\t\t\t\t\t\tBAMTDG51c2V4dHJhd2ViMzAeFw0xNDA3MjIxMTI1MTJaFw0yNDA3MTkxMTI1MTJa\n\t\t\t\t\t\tMBcxFTATBgNVBAMTDG51c2V4dHJhd2ViMzCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBAKsOIQgV+O4ecSpfdT4Xo4wosGJAPFe5Rq7NMw+qdvsNShKwaZAb\n\t\t\t\t\t\tkPIGk1GsQMsg732uHiWvWGjGV254NV4gSBWMZ/qe4itSegoFCZCYEyJ8BNy8Itoa\n\t\t\t\t\t\tbRLoiqj5K1H98I//nSC9Og7xFENAqSES0aeh6Ye23W64ljo02iJiwnbDqerpv6Ju\n\t\t\t\t\t\tB61vGT7U7ftQoJr31b+uz2Ia43mG+py/GJAE9T7QEtMhwB4z+D/LuM4hVDR0dYrf\n\t\t\t\t\t\tTCfwi3TholspuWPXy67deJebRUMoAX0aUEqjFQzTDBicND7xVMkFXiQBdzApfmwA\n\t\t\t\t\t\t6E8aV798URhz6BNUSnBpx93zbLmsI/jQsy0CAwEAAaM6MDgwFwYDVR0RBBAwDoIM\n\t\t\t\t\t\tbnVzZXh0cmF3ZWIzMB0GA1UdDgQWBBRpBgrh5ihM16MMSNdIVA9LKq3gUDANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAjVHxwsL4OW9jcgmCu7z7AecgF4pbCiA5wwGIXTvbqM2Q\n\t\t\t\t\t\tcIFzgeqUjlxK+1XKEcH8vKItpqC5qFYXy4/Xe8Btl0RrTWI50sY5ZktGmqeuzHB1\n\t\t\t\t\t\txRgKkAgGmo49wm7z+ZpJdZBPnx3Ho9mw1OAuN60oZoy6yCD6qFAOblABIMKBVi1f\n\t\t\t\t\t\trjdUIVWJX8EboD0TrdwH22QWSnmdWe6WLcs0do27ul5AfkVPaf7qpoWa8viGtCCL\n\t\t\t\t\t\tPyALH2n1WIsOiM+UnXC5JKaR6QMpRTFJkkV4aONwk9eQN0GcSHo89jQmUaU7w/wZ\n\t\t\t\t\t\txud/pMpwowhvQB7YgVq2uJQzBeJDKgnv9Kr6HfE0qw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://fed.nusextra.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://fed.nusextra.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://fed.nusextra.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://fed.nusextra.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://fed.nusextra.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://fed.nusextra.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.boltoncc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Knott"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:railton.knott@boltoncc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Railton"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Baggaley"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Dean.Baggaley@boltoncc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dean"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.boltoncc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-07-15T18:01:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRjCCAi4CCQCsi3PM6isCkjANBgkqhkiG9w0BAQUFADBlMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEPMA0GA1UECBMGQm9sdG9uMQ8wDQYDVQQHEwZCb2x0b24xFzAVBgNVBAoTDkJv\n\t\t\t\t\t\tbHRvbiBDb2xsZWdlMRswGQYDVQQDExJpZHAuYm9sdG9uY2MuYWMudWswHhcNMTMx\n\t\t\t\t\t\tMjA5MDk1NjEyWhcNMzMxMjA0MDk1NjEyWjBlMQswCQYDVQQGEwJHQjEPMA0GA1UE\n\t\t\t\t\t\tCBMGQm9sdG9uMQ8wDQYDVQQHEwZCb2x0b24xFzAVBgNVBAoTDkJvbHRvbiBDb2xs\n\t\t\t\t\t\tZWdlMRswGQYDVQQDExJpZHAuYm9sdG9uY2MuYWMudWswggEiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tAQUAA4IBDwAwggEKAoIBAQDt/7etyusEoPkmBjb+vlI5qWaSK/nunnDDfKji4Rf1\n\t\t\t\t\t\tJ2LcJ0AQBE7EZ9a3uaFLe3sHLIxav/VwuOGlLEFA+bIlpfuIUI00Pkv5lWpoSv3Q\n\t\t\t\t\t\tqDHKniLxLgOxeO3WKO0ziALCM9gKor0iZkPwESKjp8PkM4Kn9CgpM8BlYBdvedBA\n\t\t\t\t\t\tfxF3+OHy+RtsRRw1ObfG7U3mS8msLKjV8ziVK50XiM60EOvoK9Bb2QzLVxzL/Z3C\n\t\t\t\t\t\tKwv8EpTSZMD0OFTBI/+vZ7evhPT96qYGvMomPZ2WjkcdfkmXRc8+IY7vfL1m5jp3\n\t\t\t\t\t\t3C2DkOHgEny4lQd/qJucf9jnhUkT69YoEsEXf0JE29NjAgMBAAEwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAEjerzNXlUF0L/dYMpidDZmVpQpHSEjBhbcR3wravACGkwJcL2ek\n\t\t\t\t\t\tYUD5Jee1Kd7D/H2MmmBKtK8u7j7FbLIxxA/lnXMbAOecD1apzeG2jEz88PGnJswl\n\t\t\t\t\t\tg9XnRu/DvUggQs626CbJ3a9QkFrHel3VrL/WMnHn0aVEiBZphoiFSBZUpb8QuNyy\n\t\t\t\t\t\tFGkWWWeUJO9f7TG5qbW6TGKeOx6IlxmVmbui8gYrZ8rur5zKhAzd640zbtCgYh6O\n\t\t\t\t\t\tQUfQMXNSt4yna9Dh4QT6SaMcD4tKhA1nqlghNPBFFGgZo3hCyWzwCXVEIpCJmNqR\n\t\t\t\t\t\tK9mlz3r6b+Vka51fYE5nKPrUGT60d4hOe+s="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bolton-community-college.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.boltoncc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.boltoncc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.boltoncc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.boltoncc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.boltoncc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.boltoncc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.boltoncc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.boltoncc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bolton-community-college.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRjCCAi4CCQCsi3PM6isCkjANBgkqhkiG9w0BAQUFADBlMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEPMA0GA1UECBMGQm9sdG9uMQ8wDQYDVQQHEwZCb2x0b24xFzAVBgNVBAoTDkJv\n\t\t\t\t\t\tbHRvbiBDb2xsZWdlMRswGQYDVQQDExJpZHAuYm9sdG9uY2MuYWMudWswHhcNMTMx\n\t\t\t\t\t\tMjA5MDk1NjEyWhcNMzMxMjA0MDk1NjEyWjBlMQswCQYDVQQGEwJHQjEPMA0GA1UE\n\t\t\t\t\t\tCBMGQm9sdG9uMQ8wDQYDVQQHEwZCb2x0b24xFzAVBgNVBAoTDkJvbHRvbiBDb2xs\n\t\t\t\t\t\tZWdlMRswGQYDVQQDExJpZHAuYm9sdG9uY2MuYWMudWswggEiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tAQUAA4IBDwAwggEKAoIBAQDt/7etyusEoPkmBjb+vlI5qWaSK/nunnDDfKji4Rf1\n\t\t\t\t\t\tJ2LcJ0AQBE7EZ9a3uaFLe3sHLIxav/VwuOGlLEFA+bIlpfuIUI00Pkv5lWpoSv3Q\n\t\t\t\t\t\tqDHKniLxLgOxeO3WKO0ziALCM9gKor0iZkPwESKjp8PkM4Kn9CgpM8BlYBdvedBA\n\t\t\t\t\t\tfxF3+OHy+RtsRRw1ObfG7U3mS8msLKjV8ziVK50XiM60EOvoK9Bb2QzLVxzL/Z3C\n\t\t\t\t\t\tKwv8EpTSZMD0OFTBI/+vZ7evhPT96qYGvMomPZ2WjkcdfkmXRc8+IY7vfL1m5jp3\n\t\t\t\t\t\t3C2DkOHgEny4lQd/qJucf9jnhUkT69YoEsEXf0JE29NjAgMBAAEwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAEjerzNXlUF0L/dYMpidDZmVpQpHSEjBhbcR3wravACGkwJcL2ek\n\t\t\t\t\t\tYUD5Jee1Kd7D/H2MmmBKtK8u7j7FbLIxxA/lnXMbAOecD1apzeG2jEz88PGnJswl\n\t\t\t\t\t\tg9XnRu/DvUggQs626CbJ3a9QkFrHel3VrL/WMnHn0aVEiBZphoiFSBZUpb8QuNyy\n\t\t\t\t\t\tFGkWWWeUJO9f7TG5qbW6TGKeOx6IlxmVmbui8gYrZ8rur5zKhAzd640zbtCgYh6O\n\t\t\t\t\t\tQUfQMXNSt4yna9Dh4QT6SaMcD4tKhA1nqlghNPBFFGgZo3hCyWzwCXVEIpCJmNqR\n\t\t\t\t\t\tK9mlz3r6b+Vka51fYE5nKPrUGT60d4hOe+s="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bolton College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bolton-community-college.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Bolton College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://contentstore.cla.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dev@cloudspringtech.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dev Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dev@cloudspringtech.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dev Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://contentstore.cla.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-08-21T10:58:30Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Digital Content Store"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://cla.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Copyright Licensing Agency Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://contentstore.cla.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://contentstore.cla.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://contentstore.cla.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://contentstore.cla.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://contentstore.cla.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://contentstore.cla.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://contentstore.cla.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3zCCAcegAwIBAgIJANN7j8TZENUbMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\n\t\t\t\t\t\tBAMTCG5zMzczMTUzMB4XDTE1MDQyNzEzNDMzOVoXDTI1MDQyNDEzNDMzOVowEzER\n\t\t\t\t\t\tMA8GA1UEAxMIbnMzNzMxNTMwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDe0s9fwQ9v4NajnGwDJkesWo7Py4ufH/5qJsYUPcForz10FATKQtlGZZvb1Gzq\n\t\t\t\t\t\t1TaenINx4QqSjUjdyVUN3N25LWCVXW7IKmL+cxJPXx0R8Nng86ZCtYmA1epphESy\n\t\t\t\t\t\tPTXHLDOst7B4LdtxdlfqMaSr7xRo+1tBvY4G3Lqpt2l085R13XSvVfpbevQZSD4p\n\t\t\t\t\t\tnqi9vAiFUM4NDvycm0Yil/dPk4fGWlpMNT01JR50rpFnntJJVfab7I9Qf5cxboBw\n\t\t\t\t\t\t5mOPwqA8w4BI4o1gFqeH/vBXwrbA8zX9Ehgkfn1Rl8Aa0ZSMgoNjhzzwwLvjAuxT\n\t\t\t\t\t\tbWxPlVUwr7soX+RK9JRRgEMbAgMBAAGjNjA0MBMGA1UdEQQMMAqCCG5zMzczMTUz\n\t\t\t\t\t\tMB0GA1UdDgQWBBSp4HYFPmzOFP8q8RG2pBi0PerD3TANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAU9s2EhAdQudGpXpw6Ozw4tmEvg1IKDbUxUNEKkfUMOnlqPIeYvYhk5LN5ttD\n\t\t\t\t\t\tYTBcGaA8tIh5UIlQpNUh2Eb89FgZ2UqNgyx9OGMaiP7nl5ZV8HHckiTcrFKOnG6X\n\t\t\t\t\t\t+nuyOTeIYjgvpldbLZxRMlCt5fSQzqwwYX6SyK6PWsqQTZhvzpwdpbGrUj4mKEcV\n\t\t\t\t\t\tvs9mlOgKFkqvzXLr+I4D8XVYbIxBCeh7X82ooPv4r6d7kzJJo9pRf+qi0RNKJmWZ\n\t\t\t\t\t\tvI2el1erTkBgTf/qHvtskD/N1KTxz9oZV/bTpkype7gRaya8jguEmXqz0fyt9ohB\n\t\t\t\t\t\tkep+2TUr/H4eYqGM0KNkWWD8FA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://contentstore.cla.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://contentstore.cla.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://contentstore.cla.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://contentstore.cla.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://contentstore.cla.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://contentstore.cla.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.ete.grayzone.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.ete.grayzone.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ete.grayzone.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.ete.grayzone.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ete.grayzone.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ete.grayzone.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ete.grayzone.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.ete.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.ete.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.ete.grayzone.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.ete.grayzone.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.ete.grayzone.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.ete.grayzone.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.ete.grayzone.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIJAOWFYTqhNVvCMA0GCSqGSIb3DQEBCwUAMCQxIjAgBgNV\nBAMTGXd3dy5ldGUuZ3JheXpvbmUubGFkb2suc2UwHhcNMTYwMzE0MTIxODQ0WhcN\nMjYwMzEyMTIxODQ0WjAkMSIwIAYDVQQDExl3d3cuZXRlLmdyYXl6b25lLmxhZG9r\nLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArVBzGuFoS+tskR5h\nj5riw+TYtVOEoRzhhYadhWtDdHcVXzDhlCRjxUJh5ZaGMs2HQoU4fsuDOtc1FSx4\n5zfvXPlxrp1dAR6gIyzw/S3c7O++Y/eFcnEHeIp6Qj19ewe1IA0O01sGOKMFavjn\nHMSNqYr2jph0C/LxJxOz3aGzyJf7QdEzL9P6kqT3P5ZvmQwhTG5USlW/MBHvHkPl\nCEU3q7f5iJAgwCFrx2B+kcj/rqOgF09qoBPRx6P+UPpDZAwQ2GRZr4oTxugJD/7x\nEkSq/Ih+CuysSvj49kvuPtnyv3NzQtHr0v6OztvJGJrIvdYp5y9/8tOfZk67zze8\n+VXX9wIDAQABo3EwbzBOBgNVHREERzBFghl3d3cuZXRlLmdyYXl6b25lLmxhZG9r\nLnNlhihodHRwczovL3d3dy5ldGUuZ3JheXpvbmUubGFkb2suc2UvZ3VpLXNwMB0G\nA1UdDgQWBBSLSbmYVzYDUUSx6oMPSF6CSX8TujANBgkqhkiG9w0BAQsFAAOCAQEA\nV1eergR3PJpB8MDSKi1yO4WWf3elAcpn/OcLc58hoem1dqnfc64sPVpRfKcfYSiR\nFAjTvJm1tSkXpYvKwMAPdfguBHODF1abm6BTTHBXnDG5Be8HvLf/apMKcWhBRwMh\nxLjcVBsD2JROhF8RpT6hs10RLPblWk2uyI79bBTgKdt9gfHaf9zk2SwDT26ll5WI\nCrdOV1fuoBg7Y7hejnuxzA/HS+B0l+Dxp19N4gKRZa2bp5X1CK7ZUGXW5sW6VhYW\nN2btwps3PZrInQGW94xgXB5upuxNEzoWLHhRdzGOaeO2Za3FefwH5Lkc7wD0Nez1\nxOLd3/SRsYXlsa7ueYeKiw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.ete.grayzone.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ete.grayzone.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.ete.grayzone.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ete.grayzone.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ete.grayzone.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ete.grayzone.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.ete.grayzone.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.ete.grayzone.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.ete.grayzone.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.ete.grayzone.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-demo-04.its.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-demo-04.its.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-04.its.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-04.its.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-04.its.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-04.its.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-04.its.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-demo-04.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-demo-04.its.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;demo-04"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;demo-04"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-demo-04.its.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-demo-04.its.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIJANlFzsY2FA6AMA0GCSqGSIb3DQEBBQUAMCQxIjAgBgNV\nBAMTGWxhZG9rMy1kZW1vLTA0Lml0cy51bXUuc2UwHhcNMTIxMjA3MDcyODE4WhcN\nMjIxMjA1MDcyODE4WjAkMSIwIAYDVQQDExlsYWRvazMtZGVtby0wNC5pdHMudW11\nLnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvlVP4OWFWzxFY0/I\nt4PYP1o9FZ445Ny8LR7lvQA6Po9V18dwgd6gcyaN566m+vRbmSph478N5aVqjypk\n83dOD+oGBvFaRz4BpHZIcvxRQReR8QKl7jFmTuDbd/wLp1kaMpirwkaxL6RhO3e5\ncE02mey1QqluMAyH43WSOUMDT6QFwVbl5NPn2otduFdQYJQFX5Lyxs23ds11l2RU\nn9lnBOFhd2Q+gLffoXM1oS1eb5/LbZ0axsau+cURyHlmklnt4mvx+Ab93tIGQGVh\nPnGK8oEVVmdqt8rbmvrb2MEASIDAmQ+l5yE45o9NoikcvCzI8Y7zvbvUWMo2d2d7\n1sigzwIDAQABo3EwbzBOBgNVHREERzBFghlsYWRvazMtZGVtby0wNC5pdHMudW11\nLnNlhihodHRwczovL2xhZG9rMy1kZW1vLTA0Lml0cy51bXUuc2UvZ3VpLXNwMB0G\nA1UdDgQWBBQ3gGPs2hRPUPD9E7Gak6TZdV1t3TANBgkqhkiG9w0BAQUFAAOCAQEA\nCxCGvf3tc5IFIffk9SumXZEVZWx5anaH3cJt7cQ4BXLxVGEIsM0j+CC/o4nnFFd0\nKjtU8MN9dIip5mI95QFVY8EcGKoVfu83ZRou6rqo//z34sg6c5ybvI85LDj4Kqem\n0TVxhloov+Bgjj+TCXKDk04cIMmgXbRoLyqn3RcBYhjyEPcK14QTHLPf9dk7mx5x\n//bToL69WMAfERaGj0/394W0pMWL4WhmvV+3DeC8sLjlHNqRrPfSl1jn5FgYMOcd\nyvyUqYJ7h2Q0KgjSQw+DteUNpYqTfQtUYQgCc13+BbVnfUW6Rw6AsFawtbEKTLpa\nP6m+IbDWFLo61vhr/Nkcmw=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-demo-04.its.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-demo-04.its.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-demo-04.its.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-04.its.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-04.its.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-demo-04.its.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-demo-04.its.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-demo-04.its.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-demo-04.its.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-demo-04.its.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://lmet.aiwip.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Khazarchiev"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ruslan@aiwip.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ruslan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Khazarchiev"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ruslan@aiwip.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ruslan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://lmet.aiwip.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-09-29T11:32:39Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Aiwip for London Metropolitan"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://lmet.aiwip.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Aiwip Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lmet.aiwip.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lmet.aiwip.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lmet.aiwip.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lmet.aiwip.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://lmet.aiwip.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://lmet.aiwip.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Free printing for London Metropolitan students"
                  }
                ],
                "logo": [
                  {
                    "text": "https://lmet.aiwip.com/static/images/logo2-dark.png",
                    "height": "135",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "90"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Aiwip for London Metropolitan"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDlDCCAnygAwIBAgIJAN9ls5zbDz+1MA0GCSqGSIb3DQEBCwUAMEsxCzAJBgNV\n\t\t\t\t\t\tBAYTAkdCMQ8wDQYDVQQIDAZMb25kb24xEjAQBgNVBAoMCUFpd2lwIEx0ZDEXMBUG\n\t\t\t\t\t\tA1UEAwwObG1ldC5haXdpcC5jb20wHhcNMTUwOTE0MTExMTA3WhcNMjUwOTExMTEx\n\t\t\t\t\t\tMTA3WjBLMQswCQYDVQQGEwJHQjEPMA0GA1UECAwGTG9uZG9uMRIwEAYDVQQKDAlB\n\t\t\t\t\t\taXdpcCBMdGQxFzAVBgNVBAMMDmxtZXQuYWl3aXAuY29tMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAv0/WfygzXE9eiyKLZZD0SuqJS6fI5oh/kkWXdqhN\n\t\t\t\t\t\t/tyOkGz9DsjsZRt9lrVHwU0bEGRECaFqQyXgpmEGjHrhfhfzWo8ryJBrSORX4c9A\n\t\t\t\t\t\tAo+Oq2imyooxxzGUPgRmiAsjOmBVOWXLhiMGSzjg0SGN4b3ybU/EKBQFVOHNIPbK\n\t\t\t\t\t\tWxXA4ZlvoS/3vcmkWDWs4LGML2XF/AE7K8Q3sQ+KoZf/NYlFLMTT+csiIxNmALcf\n\t\t\t\t\t\tyxoY2lPisp/v1BiMi/qUlcmmRcY0XkODFmk/pwZ7sQnBWex5Br3BdC6MZ4sdB0N7\n\t\t\t\t\t\tvbSz1OgqOrcsHiPqKuvzP6nOBODBudVMgNQ/vxzgo3EvVwIDAQABo3sweTAJBgNV\n\t\t\t\t\t\tHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZp\n\t\t\t\t\t\tY2F0ZTAdBgNVHQ4EFgQUV9pkYjyXATU71LnpAHCworPziswwHwYDVR0jBBgwFoAU\n\t\t\t\t\t\tV9pkYjyXATU71LnpAHCworPziswwDQYJKoZIhvcNAQELBQADggEBAI48vWrZzALl\n\t\t\t\t\t\tBIifkeifljOBBS/BYtPQenkkLpqiNQ6mIbSJrf/vzW6vifTup+1ppJax+htrsh1d\n\t\t\t\t\t\tiUQieasACKFX5kGOcvG5uDp7cvAn23yeTwIRu8Kf2nMOL2zjn6hV8dDDj0M/cVnK\n\t\t\t\t\t\tbm1yYeKAMAZmPNhw2C4xRIDJDqawapwxRvQh2b+rTBTJ9JCQNbzfN8cb4NPqaFCO\n\t\t\t\t\t\tpjUM7Hl6CnKKiMUfRbMGzvxrxN7yZo1Jvf9+PL7Cly8DYvDczN22Y4UDEEtJ5Stf\n\t\t\t\t\t\tcEduhkrPF1g42Vc36GGScFGwHwqUHWsp3a7i5ziGsBy0nnPOVDJ0jRJA6m903JDa\n\t\t\t\t\t\tmFPqGq9ZnxI="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lmet.aiwip.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://lmet.aiwip.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://lmet.aiwip.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://lmet.aiwip.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://lmet.aiwip.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://lmet.aiwip.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://betawww.itslearning.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Akhtar"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Waseem.Akhtar@itslearning.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Waseem"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Akhtar"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Waseem.Akhtar@itslearning.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Waseem"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://betawww.itslearning.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "it's learning UK Limited: beta"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.itslearning.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "it's learning UK Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://betawww.itslearning.com/elogin/logout.aspx",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIJAIpqSMSevorFMA0GCSqGSIb3DQEBBQUAMCkxJzAlBgNV\n\t\t\t\t\t\tBAMTHmJldGF3d3cuZWxvZ2luLml0c2xlYXJuaW5nLmNvbTAeFw0xMTAyMTgxMzA4\n\t\t\t\t\t\tNDJaFw0yMTAyMTUxMzA4NDJaMCkxJzAlBgNVBAMTHmJldGF3d3cuZWxvZ2luLml0\n\t\t\t\t\t\tc2xlYXJuaW5nLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAPTk\n\t\t\t\t\t\tKu1qar6Ni1aG1x1JwjJUvGbSJOP7N0b7yw9ybzzOiq3vEnZXtIgAsb01YlC3nzqW\n\t\t\t\t\t\t6qJ5iE/lKKg289oySLPrwGAIecPWMyD3n8ADy5fc/hn18rD7rmcsY/zBHaj1xSbl\n\t\t\t\t\t\tLg8YtD7hKCQ8KtyicEFR35CwGPEMosDm5eoih9uxkjlDGqvpIPsaCxLEu3QaGDut\n\t\t\t\t\t\t7otZLtgmfDrYx7L0bUFfk4vXI3ylvN3FZCy2f3RvPizDGPKTYiDCtq7KWTrmy3r8\n\t\t\t\t\t\tQupk3loopZ77VQ9zwyawvrJaRn/k0OwENWRQpH02qrC/uAwwmCK0sPp0Lsw5CAbV\n\t\t\t\t\t\tbTWb777CvWdZaLQE1LcCAwEAAaN7MHkwCQYDVR0TBAIwADAsBglghkgBhvhCAQ0E\n\t\t\t\t\t\tHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFHUyplId\n\t\t\t\t\t\t19IQi+iRVHhSm3VWjucpMB8GA1UdIwQYMBaAFHUyplId19IQi+iRVHhSm3VWjucp\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQCUTWhvAerxQ33duwkc6iRNTgTrD/ftSKF6IL9F\n\t\t\t\t\t\t+gGK7SQT8K/cuq5qgGd21zld3qb6KDBB3YAxIXqaOTMWYQF42IbpXufXUwiquUlZ\n\t\t\t\t\t\twEgTIBQkNTmnw7MxxG/5RZ85Os1PafXeXj1G4CFCxS8uSxO7q3VR8H4gA4RU/g/6\n\t\t\t\t\t\tICTS8fAaNnZguQiZKyJyiNLPUiMdWuPvQLwodRa1HqzdJHYGhvtjTnoS3MCmTxAb\n\t\t\t\t\t\t/YTTrd+fRL4ZchK28dRbofcdGPgDbrN0ZeUh0ywt2/EUW3s3J29rBakXU53pPn+F\n\t\t\t\t\t\tCksvz2qqJnZqqE98f/5ecjEUxWxkZ7Kgs1t+yGDOkmvRK3+p"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://betawww.itslearning.com/elogin/default.aspx",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://aai-idp.uzh.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "ZI Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@id.uzh.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UZH"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "AAI Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aaiadm@id.uzh.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UZH"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://aai-idp.uzh.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2016-04-04T08:58:24Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGyTCCBbGgAwIBAgIUaP2onvcn8JF3V2Rgtd4Y3DPdls0wDQYJKoZIhvcNAQEL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\nM5r00gwrZAVynl2Imw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uzh.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-idp.uzh.ch/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aai-idp.uzh.ch/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai-idp.uzh.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai-idp.uzh.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aai-idp.uzh.ch/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-idp.uzh.ch/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uzh.ch"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uzh.ch/index_en.html"
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uzh.ch/index.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e4t Z\u00fcrich"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Zurich"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Universit\u00e4t Z\u00fcrich"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Zurich"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.id.uzh.ch/dl/mobil/AAI/Nutzungsbedingungen.html"
                  },
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.id.uzh.ch/dl/mobil/AAI/Nutzungsbedingungen.html"
                  }
                ]
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "uzh.ch"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "unizh.ch"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "unizh.edu"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "uzh.edu"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.374571,8.548659"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.397194,8.548950"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.410914,8.540683"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.41.135.192/27"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.41.132.0/22"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.0.64/27"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.41.136.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:620:10::/48"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:620:13::/48"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "160.85.2.16/28"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "160.85.2.128/27"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "160.85.3.24/29"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "160.85.3.128/25"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.12.247.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "89.206.64.0/18"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.60.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.60.10.0/25"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.60.128.64/26"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.138.69.0/24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "error_url": "http://www.id.uzh.ch/support.html",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGyTCCBbGgAwIBAgIUaP2onvcn8JF3V2Rgtd4Y3DPdls0wDQYJKoZIhvcNAQEL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\nM5r00gwrZAVynl2Imw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e4t Z\u00fcrich"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Zurich"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uzh.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uzh.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "uzh.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ed.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:IS.Helpline@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "shibboleth@ed.ac.uk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ed.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-04-10T09:51:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUaNzLeqDgCpvqZ+xdntpj4UryL9AwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwFzEVMBMGA1UEAxMMaWRwLmVkLmFjLnVrMB4XDTEwMDYyMzE0MTIzNFoXDTMw\n\t\t\t\t\t\tMDYyMzE0MTIzNFowFzEVMBMGA1UEAxMMaWRwLmVkLmFjLnVrMIIBIjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQEFAAOCAQ8AMIIBCgKCAQEA8RXQWoMfry/rRwfXVCxnRdkS05zIfHerw0/c\n\t\t\t\t\t\tObSFOORK8zOShk1QKuv+TevSZFJgD+iu96A1s55q6k0ZtbpW1iKzTAbHLXikt0yT\n\t\t\t\t\t\tGYg5th2Gp3PqBFdzChse1Sdk8exRou10yOGZaqCyfG61u+BRgdEzefdG6to7PpG4\n\t\t\t\t\t\tBNWD1njtO6zDl/zzsX9DiV3Kc7Fuo6P7ak+XPHGxztXVNwDRSoKZYiM5K11dpGvG\n\t\t\t\t\t\tnhyhL2gbIO98AzGMELdkurTf4EYXuELGPY836NNdzhBEZ0Mo+g9EUqvPQ8inFOT4\n\t\t\t\t\t\tTloSEUtxUzLr530YPOezm55QCDjH7JIS4rc+G4rN1B7b1zTybwIDAQABo18wXTA8\n\t\t\t\t\t\tBgNVHREENTAzggxpZHAuZWQuYWMudWuGI2h0dHBzOi8vaWRwLmVkLmFjLnVrL2lk\n\t\t\t\t\t\tcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQmHZOct2bza0v07qT/d1ATgFYrajANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAEgOOXyutNIWNlWoDj3VKfkZFDpw/2qvrP09EaYGBCwZ+\n\t\t\t\t\t\tNAmPHWtN+3jlDxfnYBwhTAaCWlZBqfhk4JObVH2Q3xu08zWEHBqo4fr/YGYYWAGp\n\t\t\t\t\t\tnZ29epYGOJAYbuJcWwwMJ4onFHyygRgmec4xPnz53noB8h6VEMmfP77y0JzZIF86\n\t\t\t\t\t\t+1icvTyJg4ydkh8iPir4WwZzuP7wj+cPb3uyNTGSusxhghVoREkGIG2YBwgp3cyv\n\t\t\t\t\t\tzqrzhKEksLsrrxs4mtHKDUDPSS1iArA4OJHFoIqEBMg8UOQFY4FA/FV4BDd6L5Z/\n\t\t\t\t\t\tu0zH2B9Z0UeGRg5ivQYSOQ9HLX2IeDCQWhcJC33ibQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ed.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ed.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ed.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ed.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ed.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ed.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ed.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ed.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ed.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ed.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://idp.ed.ac.uk/university.gif",
                    "height": "70",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "315"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Edinburgh"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:55.9213,-3.1726"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUaNzLeqDgCpvqZ+xdntpj4UryL9AwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwFzEVMBMGA1UEAxMMaWRwLmVkLmFjLnVrMB4XDTEwMDYyMzE0MTIzNFoXDTMw\n\t\t\t\t\t\tMDYyMzE0MTIzNFowFzEVMBMGA1UEAxMMaWRwLmVkLmFjLnVrMIIBIjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQEFAAOCAQ8AMIIBCgKCAQEA8RXQWoMfry/rRwfXVCxnRdkS05zIfHerw0/c\n\t\t\t\t\t\tObSFOORK8zOShk1QKuv+TevSZFJgD+iu96A1s55q6k0ZtbpW1iKzTAbHLXikt0yT\n\t\t\t\t\t\tGYg5th2Gp3PqBFdzChse1Sdk8exRou10yOGZaqCyfG61u+BRgdEzefdG6to7PpG4\n\t\t\t\t\t\tBNWD1njtO6zDl/zzsX9DiV3Kc7Fuo6P7ak+XPHGxztXVNwDRSoKZYiM5K11dpGvG\n\t\t\t\t\t\tnhyhL2gbIO98AzGMELdkurTf4EYXuELGPY836NNdzhBEZ0Mo+g9EUqvPQ8inFOT4\n\t\t\t\t\t\tTloSEUtxUzLr530YPOezm55QCDjH7JIS4rc+G4rN1B7b1zTybwIDAQABo18wXTA8\n\t\t\t\t\t\tBgNVHREENTAzggxpZHAuZWQuYWMudWuGI2h0dHBzOi8vaWRwLmVkLmFjLnVrL2lk\n\t\t\t\t\t\tcC9zaGliYm9sZXRoMB0GA1UdDgQWBBQmHZOct2bza0v07qT/d1ATgFYrajANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAEgOOXyutNIWNlWoDj3VKfkZFDpw/2qvrP09EaYGBCwZ+\n\t\t\t\t\t\tNAmPHWtN+3jlDxfnYBwhTAaCWlZBqfhk4JObVH2Q3xu08zWEHBqo4fr/YGYYWAGp\n\t\t\t\t\t\tnZ29epYGOJAYbuJcWwwMJ4onFHyygRgmec4xPnz53noB8h6VEMmfP77y0JzZIF86\n\t\t\t\t\t\t+1icvTyJg4ydkh8iPir4WwZzuP7wj+cPb3uyNTGSusxhghVoREkGIG2YBwgp3cyv\n\t\t\t\t\t\tzqrzhKEksLsrrxs4mtHKDUDPSS1iArA4OJHFoIqEBMg8UOQFY4FA/FV4BDd6L5Z/\n\t\t\t\t\t\tu0zH2B9Z0UeGRg5ivQYSOQ9HLX2IeDCQWhcJC33ibQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Edinburgh"
          },
          {
            "lang": "gd",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Oilthigh Dh\u00f9n \u00c8ideann"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.unmc.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ltrant@unmc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lee Trant"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mscallaway@unmc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matt Callaway"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ggloeb@unmc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Geoff Gloeb"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.unmc.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/assurance/bronze"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oasis:names:tc:SAML:attribute:assurance-certification",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.unmc.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unmc.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unmc.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.unmc.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unmc.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unmc.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unmc.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.unmc.edu"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Nebraska Medical Center"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The University of Nebraska Medical Center IdP enables standards-based federation for the UNMC community."
                  }
                ],
                "logo": [
                  {
                    "text": "https://net.unmc.edu/standards/assets/unmcicon.png",
                    "lang": "en",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "171"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.unmc.edu/its/privacystatement.htm"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIUbN18eVJXDqBOyNPdN7TXDGBcPlQwDQYJKoZIhvcNAQEF\nBQAwFzEVMBMGA1UEAxMMaWRwLnVubWMuZWR1MB4XDTEyMTAwNTE2NDIzOVoXDTMy\nMTAwNTE2NDIzOVowFzEVMBMGA1UEAxMMaWRwLnVubWMuZWR1MIIBIjANBgkqhkiG\n9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsEhWme7SDrh3YstHdYhXSi7rrnXyZUV5j3a9\n5qDqetFS6/3V1mLAvQXDtegryo+F7dO2KTj8e3WDued9bDQOLwde8K8oc2CI1d3w\ntL1e//IODz+mrIOVrKvs36/dZxYvGDsZhx37prj30aiH+SkfTJ/Q0wMMX/CS+fw1\nJfK3vhr/1w26gMRxsIyEqUtr5QC13nW09Ykkl6E7Z4Wn6JacNiM4kA4uT8MtAE3+\nmDn7Z3RSvsrh6+KXU/Wpfxwfl6brAVwdp/tW9aGXUxikYcOChfyAltbNChaxTGiZ\nPdJu1gw3cyOGUXXouvhgcVjbC4cpZjfzj+RDsz2xrK+TYhENxwIDAQABo18wXTA8\nBgNVHREENTAzggxpZHAudW5tYy5lZHWGI2h0dHBzOi8vaWRwLnVubWMuZWR1L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBSpJp3uhInvxqYjNltL7NbVkusJyjANBgkq\nhkiG9w0BAQUFAAOCAQEAbUrXe0hFkFVlADXlupQhW2YjdY5mcVBiVNAUTub+sZpL\nEw2QXSIcQEW+iGamt95vaC2pjY1VkU+DYnxkrfz2JWcCvzFiMMwPoFljATwyEB6O\nmDLBXNfg09v8WIBhXEaumT5mfdZ5o1MNa3TUtgf2dEEdHmd46Y/JaF3sU0GiTHt5\nFLc13nOcn8B4oa7KsqlIQabF7wn3jLKCmZV22VSSNTU2TfraOnobKf+dU3WdyArT\nqldJfiveQ3S4tzsv9PykD/AUf2DsYKUolzcS/HEPYp0NrIvlIKMRVZMrNoHmJo4B\nfdpZQ2TIsfzV+ci/L9l5y9IOnEqQTn66a9yUVWxNaQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Nebraska Medical Center"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unmc.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Nebraska Medical Center"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.cds.stfc.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Miller"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:cdsbb@stfc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Akkas"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ali.akkas@stfc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ali"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.cds.stfc.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-01-20T11:39:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Chemical Database Service, Daresbury"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.scitech.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Science and Technology Facilities Council"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cds.dl.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cds.dl.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cds.dl.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cds.dl.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://cds.dl.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALfgUSfF89pnMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDWNkczYuZGwuYWMudWswHhcNMTAwMjE2MTMzNDI2WhcNMjAwMjE0MTMzNDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1jZHM2LmRsLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEA7oViYpAbYqdi+QInwb//yT2pCJ+lMpq1ST4TgOsu8A+NJ8V7\n\t\t\t\t\t\t8zE4TzIDsXKOlXhWQ51JhvbpqGQeYHWO/ipGC/GJIxfb/ZMsRH9NOubO2A9JQsSu\n\t\t\t\t\t\t4pFhSjoEq2OyQYQQYbf5+06vWxr2MAhCyBhH3UvC1yIbhwGJYFgZZg05pBGIBoR2\n\t\t\t\t\t\tGxcfEXNQLhhdgdYUUDLUmF3s79U10I8ZJikvzKGLlXmWWaMD53M8M4Rom8r13kEB\n\t\t\t\t\t\t0xr13CWhd/H9xKwVImG62qCCMakF2O6+8HZziZmfPuiJD/G6HSVL3hTz9hdz9unP\n\t\t\t\t\t\tpOTFmcGxjnRU1k79TEPbbHvsTJXoYInGFiqyOQIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1jZHM2LmRsLmFjLnVrMB0GA1UdDgQWBBSpcwVd1js90ymqIUzIeiUp1K8BHzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEASYhQmAbVn4Yt+5+xcqsE25rCn9Etx3ZVqNLfoZ3G\n\t\t\t\t\t\t9Xc7QCggfVTltVFKKvxeIZ9QUOb1HH/27V1okJoH6uRoD+AnK1UGVP/+ufv0Ev2H\n\t\t\t\t\t\tvkPSyG+oVhDFYuMrTmUE3bwBiNSfHAOsflR44GEQZ5RqWTdztS4PhWF2g3s3sMY4\n\t\t\t\t\t\tJr9dD/8WUXZhV60ZQJC0hTV0RzKjdqCrKuTgMbmwCmEVQTrkj5JkrOafI7/SnfHf\n\t\t\t\t\t\tFWLAMzDMWQMdKGY6yndSdSf+RVCNka03NbDNOWkRf5pUfmsbTnr2Jn0StH2tOPBu\n\t\t\t\t\t\tSR5rJW8JbCAeIO/ydDoOl43joSNAAzoOPF0HFf5WHJDZCw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALfgUSfF89pnMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDWNkczYuZGwuYWMudWswHhcNMTAwMjE2MTMzNDI2WhcNMjAwMjE0MTMzNDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1jZHM2LmRsLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEA7oViYpAbYqdi+QInwb//yT2pCJ+lMpq1ST4TgOsu8A+NJ8V7\n\t\t\t\t\t\t8zE4TzIDsXKOlXhWQ51JhvbpqGQeYHWO/ipGC/GJIxfb/ZMsRH9NOubO2A9JQsSu\n\t\t\t\t\t\t4pFhSjoEq2OyQYQQYbf5+06vWxr2MAhCyBhH3UvC1yIbhwGJYFgZZg05pBGIBoR2\n\t\t\t\t\t\tGxcfEXNQLhhdgdYUUDLUmF3s79U10I8ZJikvzKGLlXmWWaMD53M8M4Rom8r13kEB\n\t\t\t\t\t\t0xr13CWhd/H9xKwVImG62qCCMakF2O6+8HZziZmfPuiJD/G6HSVL3hTz9hdz9unP\n\t\t\t\t\t\tpOTFmcGxjnRU1k79TEPbbHvsTJXoYInGFiqyOQIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1jZHM2LmRsLmFjLnVrMB0GA1UdDgQWBBSpcwVd1js90ymqIUzIeiUp1K8BHzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEASYhQmAbVn4Yt+5+xcqsE25rCn9Etx3ZVqNLfoZ3G\n\t\t\t\t\t\t9Xc7QCggfVTltVFKKvxeIZ9QUOb1HH/27V1okJoH6uRoD+AnK1UGVP/+ufv0Ev2H\n\t\t\t\t\t\tvkPSyG+oVhDFYuMrTmUE3bwBiNSfHAOsflR44GEQZ5RqWTdztS4PhWF2g3s3sMY4\n\t\t\t\t\t\tJr9dD/8WUXZhV60ZQJC0hTV0RzKjdqCrKuTgMbmwCmEVQTrkj5JkrOafI7/SnfHf\n\t\t\t\t\t\tFWLAMzDMWQMdKGY6yndSdSf+RVCNka03NbDNOWkRf5pUfmsbTnr2Jn0StH2tOPBu\n\t\t\t\t\t\tSR5rJW8JbCAeIO/ydDoOl43joSNAAzoOPF0HFf5WHJDZCw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cds.dl.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cds.dl.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cds.dl.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cds.dl.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cds.dl.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cds.dl.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://cds.dl.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://cds.dl.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://cds.dl.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://cds.dl.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.efc.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Laryea"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:RLARYEA@efc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rehman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nrehman@efc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Naeem"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Laryea"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:RLARYEA@efc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rehman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nrehman@efc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Naeem"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.efc.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-11T12:54:58Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.efc.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.efc.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.efc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.efc.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.efc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.efc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.efc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.efc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.efc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.efc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "efc.ac.uk"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Epping Forest College Shibboleth IdP"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Epping Forest College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAJFRmkgwhw52LYLRaMPn4753oNLdMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMBgxFjAUBgNVBAMMDWlkcC5lZmMuYWMudWswHhcNMTYwMzE3MTE0MzM5WhcN\n\t\t\t\t\t\tMzYwMzE3MTE0MzM5WjAYMRYwFAYDVQQDDA1pZHAuZWZjLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApNTw5TLO9Ge/T8f0r55g3oYeWEIcsunU\n\t\t\t\t\t\t7e0Mqn3f5Bx+9Jq2gPKKoKJwGAbM44ZHp9kT2lv9fbgLoqV4wsN5kAaUyQ0V1I2T\n\t\t\t\t\t\tR2HQ1WGYaYyB0NQFZB30SVZ/NA446OO7/JQjvC6UrgDjLlh+tHKfvtr9M7p/t5aA\n\t\t\t\t\t\tOiJK78plnV/YyRkAmGMNjqtqC5UYaknQsRyd5FaKJkmxA/LDtn50yZUDrtmSVCco\n\t\t\t\t\t\twGPPAvSjtrtKMXvIOleR7IUd8RTGcLm9FRe0PSMwlq5Wni0E7/VNVD2cbVQ/N4JL\n\t\t\t\t\t\tcFZkRL6k3hNj8LZvwz8RVm3ihPuPhs9N72ML5+LK2POCZ1zjceC9VwIDAQABo2Ew\n\t\t\t\t\t\tXzAdBgNVHQ4EFgQUCueTLaZVrYTMUiuPwdJTc4lvcNkwPgYDVR0RBDcwNYINaWRw\n\t\t\t\t\t\tLmVmYy5hYy51a4YkaHR0cHM6Ly9pZHAuZWZjLmFjLnVrL2lkcC9zaGliYm9sZXRo\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBCwUAA4IBAQCAGITy3H8BKF/HwonbKtRsEG1nAlU5I+rTp4/m\n\t\t\t\t\t\tSW2Hm76+w4xicHWvHiDOOfvOU/xiTJgWRiubpY6Lu2+m4yrArcYGvOdUrw5tB7bQ\n\t\t\t\t\t\tmZBl/xr6JQAjbqKypBO+W95x3KWFWTtq3vNTRPsW8skCArzhLnJJNg4/nwr2IE4X\n\t\t\t\t\t\taEi2HUCZ6uy3OFf9gUAXuUIQIEtWzEfYcu5IXlWYk7H1Jh2qyBVLfdYE4J5zEt/6\n\t\t\t\t\t\ttxchHGxkg1bMiMIjEv+sfkrQm1Vvk5p71nqcBdb+i0/u1zBDQR6fPtn7dzqGR5jx\n\t\t\t\t\t\tFESrzA5BMELrUJnQ3KIkLgFEGDGnWM9gSQwnfMhMRvuLMqy6"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUOXBO8f5f0h/99rHsjUGvuzOOJCwwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwGDEWMBQGA1UEAwwNaWRwLmVmYy5hYy51azAeFw0xNjAzMTcxMTQzMzdaFw0z\n\t\t\t\t\t\tNjAzMTcxMTQzMzdaMBgxFjAUBgNVBAMMDWlkcC5lZmMuYWMudWswggEiMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCQoowAbiQx7g+RBCwYkM3QolXf8opzpjWr\n\t\t\t\t\t\tX5kD6C+lc9FyRbPBWUsewQlcKOuNy46ernfLi+K49WKD0bdjffK42Y4c0jhi7XMf\n\t\t\t\t\t\tGg2PfD5xSQy3v6A+P6lpbYbxTQlqenUFRb5djFsot8gsKaLdfTGNizE8lPYaMJPw\n\t\t\t\t\t\t8ELTmgBdeXkhFFXJCRxEeFTjBstc0HcyVAgnYr8nZEZzpFIUxpi1A81Qcq5OCk7+\n\t\t\t\t\t\typh8Gp2Ossneh4L0ZzHKvbCMjxHBhF6zrdneJfTKed9JzYKLm4L0QPvIE46CiAnD\n\t\t\t\t\t\toUAz5weBBvdqox6rh3E4Q6mH5+eguiDeLy5jIubyOAq6ai8SelCNAgMBAAGjYTBf\n\t\t\t\t\t\tMB0GA1UdDgQWBBR/+c7vffPYnB1eNa6B2zavd7rzJDA+BgNVHREENzA1gg1pZHAu\n\t\t\t\t\t\tZWZjLmFjLnVrhiRodHRwczovL2lkcC5lZmMuYWMudWsvaWRwL3NoaWJib2xldGgw\n\t\t\t\t\t\tDQYJKoZIhvcNAQELBQADggEBABepHt+qyj0kAJRbJOo/r85+JGibsxsz6bgezVHx\n\t\t\t\t\t\t/maSj3XFDgVzC9LjuHG3y8Hd1se4hIWg92RjoC3fBI2x1GjwOdGga7oQHiREv4+V\n\t\t\t\t\t\t3wBimcmqztPK8G0U3rGDMeDVy+kyUYMgpdf5MxTFDjLx91FdACMaNTTMigAGWVbw\n\t\t\t\t\t\tC3srGBGXk0RsEgZD4JkP9LUW91oXuqhxki6kZO+Isyw4PlgazdB4y4Uc+VlCh6y6\n\t\t\t\t\t\tP9e8ihxbhKaN/zpepysWoPpTh8GjPnz6Z4OOVtvZNvFaPk5uQcotBVdW3B3IvGe3\n\t\t\t\t\t\tk5Yp5NSOAwlFfg9z/Xil7SQY8qxGi3ubkN5uRIoo0aay6/Y="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAP6ohCGvdEG1dnh4PrjWIjzXKARGMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMBgxFjAUBgNVBAMMDWlkcC5lZmMuYWMudWswHhcNMTYwMzE3MTE0MzM5WhcN\n\t\t\t\t\t\tMzYwMzE3MTE0MzM5WjAYMRYwFAYDVQQDDA1pZHAuZWZjLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAg5NOOh728m29wPobTiOHr6UuEnHccxZR\n\t\t\t\t\t\trJ6cCVxWkJMdyb9FVJ53pMWbCmLrMpPl63uxs1LsJN+y+ksmoFEkBledGMhCsBlh\n\t\t\t\t\t\tINwjraPHgtYdX5tvlOWtPBDvadI7yAjTohmzC18Y4HicGyf+N8wd7o2ZIf8Emkoy\n\t\t\t\t\t\txemehjPHPrydJMMYpFjKkh5SJovAiTIIfBXpg/5zUJ8hi8Mm5kSW+5AQVoGensvp\n\t\t\t\t\t\tpG91nLp+jcaKGawlg0d/pvca0Qrw4eJTFukAKT6U2O7TrC1qpK0GcC/oMmHSC0C8\n\t\t\t\t\t\tdGAvgwEYWyg5w5WIAQVntzqgWfGlm0RGR0rDStQ7oyhtlOz1lHmMcwIDAQABo2Ew\n\t\t\t\t\t\tXzAdBgNVHQ4EFgQUEGCQsUv3Uai6wzZ7Hwq7hfU3bpMwPgYDVR0RBDcwNYINaWRw\n\t\t\t\t\t\tLmVmYy5hYy51a4YkaHR0cHM6Ly9pZHAuZWZjLmFjLnVrL2lkcC9zaGliYm9sZXRo\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBCwUAA4IBAQBtbPSWiXrw62ZbVJHSaouA2rV6wtwlbPmuLAhc\n\t\t\t\t\t\tZ5F6LEtTdyXGkzK/5arRzqXmOjZe/ym4Y25MNf2kgtcL5XDjH0CtryNxJRZEnnRQ\n\t\t\t\t\t\tSt9xyxZjBl41QGNE//h4hiNyFSBERQ8rMgPn/eZ6/C0fD2MYcUjQqY2K0eINHWFK\n\t\t\t\t\t\ttwO/Qhc+Ap85rvUlnxkHJuhOqjQrD0VkENe1Z47Rnx1pyr4RgRt/K8dWHXOpQGBt\n\t\t\t\t\t\tHQSlmxxBb+6hFpDrrOq7cW+mG/niWbp0vh118CM21W8xUWeU+7Is2JuHhic5oImZ\n\t\t\t\t\t\tfme2bStBabIJQ5C7qVD0H+E6Hoa3Qe80s5fsVerqwK0KaW7s"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Epping Forest College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.efc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Epping Forest College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.rva.ar.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.rva.ar.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.rva.ar.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.rva.ar.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.rva.ar.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.rva.ar.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.rva.ar.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.rva.ar.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.rva.ar.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.rva.ar.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.rva.ar.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.rva.ar.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.rva.ar.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.rva.ar.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIJAJIr0U/MQN78MA0GCSqGSIb3DQEBBQUAMB4xHDAaBgNV\nBAMTE3d3dy5ydmEuYXIubGFkb2suc2UwHhcNMTUwMzExMTMxMzEwWhcNMjUwMzA4\nMTMxMzEwWjAeMRwwGgYDVQQDExN3d3cucnZhLmFyLmxhZG9rLnNlMIIBIjANBgkq\nhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAytR6BGgkGEtgmXxx7uz+nYH/j80wurdZ\nu8/61pinsFz6m2wNmyVgosqtmXO/ohZjhOBY7U7rAlDyproNTc7mgIPPr0IKoHSV\nOxHxQ3zrjg+uME9qKQFuAc3R6XkN6ChtPYTTaZAdF8MJYP/7qOFrucaeth2ZDGXH\nisHFwJ/sfeM1m218ULVqM9VMi3Ray8Du8x66k8TU2NEw3H/ZKMsbVvmT5YkJ2Pf4\nq7/0trLZkQWB1+1th1Jvpo8Mg/dN9/xz7U+dCxjVnZKGcrG5rIr+glV0AmcYMoSF\nxcQNHP3HIzhq2gNzJObJSBeCj/sQlX7pG+xyQLsox0kxAB/uUxxoBwIDAQABo2Uw\nYzBCBgNVHREEOzA5ghN3d3cucnZhLmFyLmxhZG9rLnNlhiJodHRwczovL3d3dy5y\ndmEuYXIubGFkb2suc2UvZ3VpLXNwMB0GA1UdDgQWBBQApfQjdtUWLQ8Nmt63z4Q4\nsJnu0TANBgkqhkiG9w0BAQUFAAOCAQEAbw+HYfL/EwKyIwXmuolH7nrXM1fewAPQ\nkl/hx8sdL+EO1UGcSXKNtLPfwjQ0PUkl4XohUeSeVETPhrt9tZFKOMSDHDpklDoS\nTu6axvlJ0JQyr8DYpskTd9R1ZEtT+hEenA5O7NR3WkTIPxfZVxPeNkBrdcoQmxHy\n4+lfU6QOZpVW0q058Kcp/uQBWZ89S8kR4OK6sLNNkOweTyAMRCuuk3vUWFHGVXh7\n0mE6kKIoI9JhvnzrFPTGqEx4p3f/AppCTKoEdIVFkHar1DPBJDiXHgSEDwXv3fuT\nPKmLjRJGNEV+OLIHc1VJRz2wkF76UJgdbH91DqdttDwGTuiaU4XAsQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.rva.ar.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.rva.ar.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.rva.ar.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.rva.ar.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.rva.ar.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.rva.ar.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.rva.ar.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.rva.ar.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.rva.ar.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.rva.ar.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://judge.wcu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jbright@wcu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Joshua Bright"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jbright@wcu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Joshua Bright"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mckenzie@wcu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Joel McKenzie"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shammer@wcu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stan Hammer"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://judge.wcu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://judge.wcu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://judge.wcu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://judge.wcu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://judge.wcu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://judge.wcu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wcu.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.wcu.edu"
                  }
                ],
                "logo": [
                  {
                    "text": "https://judge.wcu.edu/idp/images/wculogo.png",
                    "lang": "en",
                    "height": "70",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "171"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Western Carolina University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAMwcokVuvUtTMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMMDWp1ZGdlLndjdS5lZHUwHhcNMTMwMzAxMjAyMzA0WhcNMjMwMzAyMjAyMzA0\nWjAYMRYwFAYDVQQDDA1qdWRnZS53Y3UuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAsVhnO72sN9OTCnD4ZomHvGlMmZ/dzryb5eabvKvYanwuNfcy\nw39B8IuWyEbXZeR3OjDwlGkkmVb4slU7pzt5m/LificVrGEmYFsiM8IBTJMIn7h/\n2mS030ZCKS6YGgOMpSctaGUj+Ss/42Sdtgv/NW1bvXDLkB+3gpjJ7ypp+JFSt2c3\nkfhgP/vKqQhJfYWA7Hmiv1PJW0tIbWr3KfbLD8c93L3ogZLlRUvhj4NBwD4JlqDR\n0x3PhNfFqVZ96rCJnL+CA51y7c6SnXhQ0UV0ogIqmsUQXeoyLJBdXDuZRX1RBt00\nMfvprphVHYcEviANqDqc3QWp5Q9iCWAlxzTpuwIDAQABo1AwTjAdBgNVHQ4EFgQU\n9Q4zcYCEnOTK0NfRPbhlTNroUu0wHwYDVR0jBBgwFoAU9Q4zcYCEnOTK0NfRPbhl\nTNroUu0wDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAqoLlA+7iun5/\noKIAoRa+7KsxhqOj+Tma0YGqUiE4c26Hrq5HQeIKth7Bdy7yYFFpihEZdRdL0R2z\nVw15xUTHkzMRbXYzLTLCejM8PIXuBymAapKRTcOgc0hhIR3taMnzqrRr9yGI0q8I\n4tN4D5XLJOOWALcCyA4cZTFtcPRzMiPa7NN0gBdT0GovdtKzg+0L0VjkaQRgWj85\nnu9QYDv3QLT3bKbbVxlHgmcF375m4y6ztSn9NTVI9vbQ1DwP8kbOGyfHZ4mIr+jb\nxOXJMBYALX0MFAdPtoE+V5+8GhV4syXPQmL4HFrK/Ywdx+4ER+/Ld7ovoZCxI1eb\nu+Vt6r08yQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Western Carolina University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wcu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Western Carolina University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://federation-identite.univ-paris13.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "fed-contact@univ-paris13.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federation-identite.univ-paris13.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2010-10-27T17:00:46Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation-identite.univ-paris13.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federation-identite.univ-paris13.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://federation-identite.univ-paris13.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-paris13.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-paris13.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Members of University Paris 13 (Students, Teaching staff, Researchers and Administrative and Technical staff)"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Personnes membres de l'Universit\u00e9 Paris 13 (Etudiants, Personnels, Enseignants, Enseignants-Chercheurs, Chercheurs)."
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAAAAAA6mKC9AAAACXBIWXMAAABIAAAASABGyWs+AAAACXZwQWcAAAAQAAAAEABcxq3DAAAAXElEQVQY02P4DwTnf/+HAwYQseI/mkA7ukASuoD1FzQB+bNoAqq9aAIhVmgCcxkuoQq84E5CFfhfyXAOVeCdoiuqwP/THJ2oAv93C61CFfh/yX0NqsD/T3N2gigAi3XtGsHbROAAAAAldEVYdGRhdGU6Y3JlYXRlADIwMTUtMDctMjBUMTA6NDk6NDgrMDI6MDBjnYKrAAAAJXRFWHRkYXRlOm1vZGlmeQAyMDE1LTA3LTIwVDEwOjQ5OjQ4KzAyOjAwEsA6FwAAAABJRU5ErkJggg==",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University Paris 13"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 Paris 13"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDejCCAmKgAwIBAgIVAK7XWBt0cfWGEv/HUzJRJYhKWFD6MA0GCSqGSIb3DQEB\nBQUAMC4xLDAqBgNVBAMTI2ZlZGVyYXRpb24taWRlbnRpdGUudW5pdi1wYXJpczEz\nLmZyMB4XDTEwMTAyMzEyMTExNFoXDTMwMTAyMzEyMTExNFowLjEsMCoGA1UEAxMj\nZmVkZXJhdGlvbi1pZGVudGl0ZS51bml2LXBhcmlzMTMuZnIwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQCc/y6YY56o8yN7kpm+WTki591jEzoyfZhI883X\nRMP54gc9B/YlMvhOX0c3yKxsAA9DGZqhC3IpzhNIwEqZdznaDtLyb8qfExgP37zU\nsKJlqU3fmiZ3PLB1H3MKMu850bQpxcY9mQnboBSfwybTkiggCei2uVls8dgDhr6O\nM/JkWo2JzAnBKYP8B1nEG3Ynabbk1ncktx1XlUb5Ar7L33GXSBHZmZjQczgifXbl\neuOjVRlBJodDaQS0dZMKVvEWxPIU2n0Kd7leiWrVe9UJgIOlc9XPCX0EXfNb90fx\nz5anJggWlCClzAI2BNPM1BlTk+Sf0B4j0Df250uvsqM+6dUjAgMBAAGjgY4wgYsw\nagYDVR0RBGMwYYIjZmVkZXJhdGlvbi1pZGVudGl0ZS51bml2LXBhcmlzMTMuZnKG\nOmh0dHBzOi8vZmVkZXJhdGlvbi1pZGVudGl0ZS51bml2LXBhcmlzMTMuZnIvaWRw\nL3NoaWJib2xldGgwHQYDVR0OBBYEFPPj9MEZxWRXVouk6e4gI+J1lfjsMA0GCSqG\nSIb3DQEBBQUAA4IBAQAIvX5H/FQEOM68IPlr/uhjuDKEhngLhPp/oJB2rewP6ryS\nPtgXpCpFVF2LKK5WJGtoXtpAxHg5DFz1UVvcCG2ELivEtZa0L15DxQNQRCkx9ot2\nz4FPpojZ5AfAzJixC8QxXL6Em97K5iJic1cin5oRNaX5TJBki5VVGpy1HGJuw2jT\nrk2djX0eDw4AXkvCk9v20rg2f/JQtCu7Ai1rlRzHzq1bAhaepZmdXOBedBSiPTlX\nHtqWfXo71mMZC74xUh+ctHhBLqZJ8oKWIif43XpoA5ZXUsgSKKQ11d+l8l9UEFDQ\n0pZI2DZg+vSvz1Lncsgyiuy4FDU0VFXEc+gRL3aZ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 Paris 13"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-paris13.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 Paris 13"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://wakshib1.wakefield.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Richardson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:s.richardson@wakefield.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simon"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Watts"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:a.watts@wakefield.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://wakshib1.wakefield.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-01-16T16:45:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDbjCCAlYCCQChpNcFSrUPmTANBgkqhkiG9w0BAQsFADB5MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEXMBUGA1UECBMOV2VzdCBZb3Jrc2hpcmUxEjAQBgNVBAcTCVdha2VmaWVsZDEa\n\t\t\t\t\t\tMBgGA1UEChMRV2FrZWZpZWxkIENvbGxlZ2UxITAfBgNVBAMTGHdha3NoaWIxLndh\n\t\t\t\t\t\ta2VmaWVsZC5hYy51azAeFw0xNDExMDYxMDQxMTlaFw0zNDExMDExMDQxMTlaMHkx\n\t\t\t\t\t\tCzAJBgNVBAYTAkdCMRcwFQYDVQQIEw5XZXN0IFlvcmtzaGlyZTESMBAGA1UEBxMJ\n\t\t\t\t\t\tV2FrZWZpZWxkMRowGAYDVQQKExFXYWtlZmllbGQgQ29sbGVnZTEhMB8GA1UEAxMY\n\t\t\t\t\t\td2Frc2hpYjEud2FrZWZpZWxkLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\n\t\t\t\t\t\tMIIBCgKCAQEA3w1GYtKzy9tPP8ZwCI11qZP5GX3Cm578CywOe7gb9ZhpQN7ZnozN\n\t\t\t\t\t\tHH5d/O+jLLL7Mib0PxKKYZptBIl0uIVvwOQPIXLtBI+XENBlVOiMMIimOt+pCr12\n\t\t\t\t\t\tAl5LdBNwuKB4ZFMSsgg5LwM7Z64GnP9npOOjYMBKK2qsiNDC7KcBiGPVMKgEM0N7\n\t\t\t\t\t\tyguPdcy6DgHRMY0H+ZeT44Vhp2LkEfUOkVGwmfyTEBD8/5SgNjV+xmsvPBrTfNp3\n\t\t\t\t\t\tjeCHHXVw+gFsOSRElE/Ah0DOZiJBJYhriBg+sK8BWIcbsbc5xs9Q1w44ws5YDues\n\t\t\t\t\t\t8oYr6b5B/8fCfFv2rURIZUFMOqTw3YprkwIDAQABMA0GCSqGSIb3DQEBCwUAA4IB\n\t\t\t\t\t\tAQA4EiC3dzyiJIYTKQhtWoV2BQ1AnHAwJPJAXf4jW7cpvCFMEvfN8ZOK/Lacfz5p\n\t\t\t\t\t\tvITgJoBs2eBy0xO1eBQlKfe1kCWnxpOd918odQ9zf5VZhHocklY1ZimrF+n3nVCL\n\t\t\t\t\t\tKdojs4VmrEi0PLEtazYNBAig9dOJcHKY3qIIpFi2PKesdf9AuNt+Q04UqKKpRa7y\n\t\t\t\t\t\th92+bH74geOC/hOWBxH+3C8jIkfn/+K2K4NhqGlp8qOLkpgR3X87m0kSsBT9nbDc\n\t\t\t\t\t\t2mduGi9SFFVrYv8N7aLs8QqdjP3nAVlZxB0Ts1r21TCeun+6Ns8/4tMvwLTDjzat\n\t\t\t\t\t\tB0jkCgiVDEKc3OFBaVsdSQPX"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wakefield.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://wakshib1.wakefield.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://wakshib1.wakefield.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://wakshib1.wakefield.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://wakshib1.wakefield.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://wakshib1.wakefield.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://wakshib1.wakefield.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://wakshib1.wakefield.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://wakshib1.wakefield.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "wakefield.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDbjCCAlYCCQChpNcFSrUPmTANBgkqhkiG9w0BAQsFADB5MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEXMBUGA1UECBMOV2VzdCBZb3Jrc2hpcmUxEjAQBgNVBAcTCVdha2VmaWVsZDEa\n\t\t\t\t\t\tMBgGA1UEChMRV2FrZWZpZWxkIENvbGxlZ2UxITAfBgNVBAMTGHdha3NoaWIxLndh\n\t\t\t\t\t\ta2VmaWVsZC5hYy51azAeFw0xNDExMDYxMDQxMTlaFw0zNDExMDExMDQxMTlaMHkx\n\t\t\t\t\t\tCzAJBgNVBAYTAkdCMRcwFQYDVQQIEw5XZXN0IFlvcmtzaGlyZTESMBAGA1UEBxMJ\n\t\t\t\t\t\tV2FrZWZpZWxkMRowGAYDVQQKExFXYWtlZmllbGQgQ29sbGVnZTEhMB8GA1UEAxMY\n\t\t\t\t\t\td2Frc2hpYjEud2FrZWZpZWxkLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\n\t\t\t\t\t\tMIIBCgKCAQEA3w1GYtKzy9tPP8ZwCI11qZP5GX3Cm578CywOe7gb9ZhpQN7ZnozN\n\t\t\t\t\t\tHH5d/O+jLLL7Mib0PxKKYZptBIl0uIVvwOQPIXLtBI+XENBlVOiMMIimOt+pCr12\n\t\t\t\t\t\tAl5LdBNwuKB4ZFMSsgg5LwM7Z64GnP9npOOjYMBKK2qsiNDC7KcBiGPVMKgEM0N7\n\t\t\t\t\t\tyguPdcy6DgHRMY0H+ZeT44Vhp2LkEfUOkVGwmfyTEBD8/5SgNjV+xmsvPBrTfNp3\n\t\t\t\t\t\tjeCHHXVw+gFsOSRElE/Ah0DOZiJBJYhriBg+sK8BWIcbsbc5xs9Q1w44ws5YDues\n\t\t\t\t\t\t8oYr6b5B/8fCfFv2rURIZUFMOqTw3YprkwIDAQABMA0GCSqGSIb3DQEBCwUAA4IB\n\t\t\t\t\t\tAQA4EiC3dzyiJIYTKQhtWoV2BQ1AnHAwJPJAXf4jW7cpvCFMEvfN8ZOK/Lacfz5p\n\t\t\t\t\t\tvITgJoBs2eBy0xO1eBQlKfe1kCWnxpOd918odQ9zf5VZhHocklY1ZimrF+n3nVCL\n\t\t\t\t\t\tKdojs4VmrEi0PLEtazYNBAig9dOJcHKY3qIIpFi2PKesdf9AuNt+Q04UqKKpRa7y\n\t\t\t\t\t\th92+bH74geOC/hOWBxH+3C8jIkfn/+K2K4NhqGlp8qOLkpgR3X87m0kSsBT9nbDc\n\t\t\t\t\t\t2mduGi9SFFVrYv8N7aLs8QqdjP3nAVlZxB0Ts1r21TCeun+6Ns8/4tMvwLTDjzat\n\t\t\t\t\t\tB0jkCgiVDEKc3OFBaVsdSQPX"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Wakefield College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.wakefield.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Wakefield College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.univ-tours.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Patrice Garnier"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "patrice.garnier@univ-tours.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.univ-tours.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-06-24T18:00:31Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univ-tours.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univ-tours.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.univ-tours.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-tours.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-tours.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Tours"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Tours"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIUVH5OPXLEAtiW4UVmoDzKej0fR7wwDQYJKoZIhvcNAQEF\nBQAwHDEaMBgGA1UEAxMRaWRwLnVuaXYtdG91cnMuZnIwHhcNMDkwNjA5MTI0NTIx\nWhcNMjkwNjA5MTI0NTIxWjAcMRowGAYDVQQDExFpZHAudW5pdi10b3Vycy5mcjCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJV+FLOks9NmLB17N7XlmI+E\nr7NgQKavtPYd75TgOu5ubqe2YYD7DoLrQQzalOs7dw7Q2b1Pd+DSbqKjthjdD/wm\nIrvbA3bddVtU0hurW+wOfcP/aqvODxOL2PjYgRucGu82UfocIxbjDQyKvAhS1wsR\ntz2p0rLdCGKevDJqeJsSC7JAGolSYmnpZHRRY/86qKuvO/5XxBFUxqAuplOD2Cyk\n+SgMsyd1eRNgfNf18peOPuK/s7midkIoSNfmffQri/gqlxXrZujj7sYQawU1bAt6\nIGxxDfKsyzinTxSj/8wXUfO1YaaSZpoOzQI6s42CvqZf5fnLBAu5G7QmGVPSQL8C\nAwEAAaNpMGcwRgYDVR0RBD8wPYIRaWRwLnVuaXYtdG91cnMuZnKGKGh0dHBzOi8v\naWRwLnVuaXYtdG91cnMuZnIvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFCJdjIn0\nY6lWGricZa673uc04sZuMA0GCSqGSIb3DQEBBQUAA4IBAQAGMS23ntdqT1WC7zXy\nKvER9CkWn8VHr3/j8FgHxJ/Ny5+eAAp348PPgk4FIl5W3JAyg5ZwqZYUET34xXBd\nC66AZjpoQvuyXEtWWlhama0FFW4UMRKjYxGSFf8BJFmyMk4fRtwolbm9s+MWD4bz\nZpQtX9RZhBibLqx6BROOvyVFDsXxT/SbR7sHIlZE4Vd9bis6QE2SAefj6qyehYPL\nNm452WAqt1hsasELZYoMp3q/jUFuLwIqk4HaoyP0ugbGZS5S+uf6vrodMvoVwf84\nSf1I3HGOP6+0iyh+HO8fJM+1VZRsIxCJy69Z4uWDSacQOJo7cvj6sXSDRdv2Ecm8\nDW4K"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Tours"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-tours.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Tours"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp-emedea.irccs.garr.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idpcloud-service@garr.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-emedea.irccs.garr.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2015-06-12T08:30:34Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSzCCAjOgAwIBAgIUJ4fNWGX5+08debnn/nkHiEjdar8wDQYJKoZIhvcNAQEF\nBQAwIzEhMB8GA1UEAxMYaWRwLWVtZWRlYS5pcmNjcy5nYXJyLml0MB4XDTE0MTIw\nMzE0NTI1MFoXDTM0MTIwMzE0NTI1MFowIzEhMB8GA1UEAxMYaWRwLWVtZWRlYS5p\ncmNjcy5nYXJyLml0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAgSTZ\nerZWMbKpBbRjuYs/cV3i+w+VxlEX/vBCeZNGm0GuA/83OSaBPgybFy++HadFeGwv\nCHJ0ezfzKBcChCrmc8fDEeGAGGPTCDf/fwUcHfDkNXVADV0gc9ArOf/c+n27gpeP\ndQjR8PEe5LjAmPxSu3FaYHaDCDolp6+fCF/kO/iRAkovLhkciWvZ6UByp7za187b\nQ9+oAywSZ+YRU8R7FA1r2DcYEL1bYm0BVGgieQViDXIQ1IxoFONXPkqh5hIWWafZ\nPkpD93sGtasppKmZJgBnoLbxqJr1yM6+G1lWoAl86jJcrYcbhSz3s1JooJU/ixm8\nD/TiBLNuWQXBvmBjdQIDAQABo3cwdTBUBgNVHREETTBLghhpZHAtZW1lZGVhLmly\nY2NzLmdhcnIuaXSGL2h0dHBzOi8vaWRwLWVtZWRlYS5pcmNjcy5nYXJyLml0L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBRGrPEKhYrWASXXduqff7O6vmNl3TANBgkq\nhkiG9w0BAQUFAAOCAQEAdMxKPZHKW7KPpNiNKKPCqB6IN8v0kG1y2MseXKZK4zvG\nDGpRO1Ct25Y5AryzXi7yUmtXfU2xDywgrf8met+OrlYBnEStx2iEmRLqWy9uno36\nRYu7oCdQ/IA4glu6fFOaXrxqy+oph/popolaYZukfFZpxtMz+K8vDiZHC9MG2aed\npuDKQAij1jLb7WuFJDThpxZoqlh/5K9pC8zvupkflSB3ryDiD238MEG0XeJP4lrd\n71LUNetzMHi2RIWXjBtFyQrtWHEhkZRDLy5tTVgnRWbj7fW5LsUDSg7IXhTXlvGd\nK9UQVp9FsBNJgDA7bdiWsS8s4kOuhwB7w52dprEQ+w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "emedea.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-emedea.irccs.garr.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-emedea.irccs.garr.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-emedea.irccs.garr.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-emedea.irccs.garr.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-emedea.irccs.garr.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-emedea.irccs.garr.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-emedea.irccs.garr.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-emedea.irccs.garr.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "emedea.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.emedea.it/ricerca/idem-garr-en.php"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.emedea.it/ricerca/idem-garr.php"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IRCCS Eugenio Medea"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IRCCS Eugenio Medea"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for IRCCS \"Eugenio Medea\" users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider per gli utenti dell'IRCCS \"Eugenio Medea\""
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp-emedea.irccs.garr.it/idp/images/institutionLogo-160x120_en.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idp-emedea.irccs.garr.it/idp/images/institutionLogo-32x32_en.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idp-emedea.irccs.garr.it/idp/images/institutionLogo-160x120_it.png",
                    "lang": "it",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idp-emedea.irccs.garr.it/idp/images/institutionLogo-32x32_it.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.emedea.it/ricerca/idem-garr-en.php"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.emedea.it/ricerca/idem-garr.php"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSzCCAjOgAwIBAgIUJ4fNWGX5+08debnn/nkHiEjdar8wDQYJKoZIhvcNAQEF\nBQAwIzEhMB8GA1UEAxMYaWRwLWVtZWRlYS5pcmNjcy5nYXJyLml0MB4XDTE0MTIw\nMzE0NTI1MFoXDTM0MTIwMzE0NTI1MFowIzEhMB8GA1UEAxMYaWRwLWVtZWRlYS5p\ncmNjcy5nYXJyLml0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAgSTZ\nerZWMbKpBbRjuYs/cV3i+w+VxlEX/vBCeZNGm0GuA/83OSaBPgybFy++HadFeGwv\nCHJ0ezfzKBcChCrmc8fDEeGAGGPTCDf/fwUcHfDkNXVADV0gc9ArOf/c+n27gpeP\ndQjR8PEe5LjAmPxSu3FaYHaDCDolp6+fCF/kO/iRAkovLhkciWvZ6UByp7za187b\nQ9+oAywSZ+YRU8R7FA1r2DcYEL1bYm0BVGgieQViDXIQ1IxoFONXPkqh5hIWWafZ\nPkpD93sGtasppKmZJgBnoLbxqJr1yM6+G1lWoAl86jJcrYcbhSz3s1JooJU/ixm8\nD/TiBLNuWQXBvmBjdQIDAQABo3cwdTBUBgNVHREETTBLghhpZHAtZW1lZGVhLmly\nY2NzLmdhcnIuaXSGL2h0dHBzOi8vaWRwLWVtZWRlYS5pcmNjcy5nYXJyLml0L2lk\ncC9zaGliYm9sZXRoMB0GA1UdDgQWBBRGrPEKhYrWASXXduqff7O6vmNl3TANBgkq\nhkiG9w0BAQUFAAOCAQEAdMxKPZHKW7KPpNiNKKPCqB6IN8v0kG1y2MseXKZK4zvG\nDGpRO1Ct25Y5AryzXi7yUmtXfU2xDywgrf8met+OrlYBnEStx2iEmRLqWy9uno36\nRYu7oCdQ/IA4glu6fFOaXrxqy+oph/popolaYZukfFZpxtMz+K8vDiZHC9MG2aed\npuDKQAij1jLb7WuFJDThpxZoqlh/5K9pC8zvupkflSB3ryDiD238MEG0XeJP4lrd\n71LUNetzMHi2RIWXjBtFyQrtWHEhkZRDLy5tTVgnRWbj7fW5LsUDSg7IXhTXlvGd\nK9UQVp9FsBNJgDA7bdiWsS8s4kOuhwB7w52dprEQ+w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IRCCS Eugenio Medea"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IRCCS Eugenio Medea"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.emedea.it/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.emedea.it/english_medea/index.php"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IRCCS Eugenio Medea"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IRCCS Eugenio Medea"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ross.impa.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ricardo Gomes"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "netadm@impa.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ross.impa.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDijCCAnICAQAwDQYJKoZIhvcNAQEFBQAwgYoxDTALBgNVBAoTBElNUEExDDAK\nBgNVBAsTA0NJTjEdMBsGCSqGSIb3DQEJARYObmV0YWRtQGltcGEuYnIxFzAVBgNV\nBAcTDlJpbyBkZSBKYW5laXJvMRcwFQYDVQQIEw5SaW8gZGUgSmFuZWlybzELMAkG\nA1UEBhMCQlIxDTALBgNVBAMTBHJvc3MwHhcNMTQwOTMwMTg0MjE1WhcNMTcwOTI5\nMTg0MjE1WjCBijENMAsGA1UEChMESU1QQTEMMAoGA1UECxMDQ0lOMR0wGwYJKoZI\nhvcNAQkBFg5uZXRhZG1AaW1wYS5icjEXMBUGA1UEBxMOUmlvIGRlIEphbmVpcm8x\nFzAVBgNVBAgTDlJpbyBkZSBKYW5laXJvMQswCQYDVQQGEwJCUjENMAsGA1UEAxME\ncm9zczCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALZqzra9igATlWYM\nnWpR0mCkXBwbB1mMRmr7vJF9A9ZfKeF4ztOmG+6YRmCLZk8rbd+mhp4bPJ504hL5\nrSjixTm2IXf9XJHcFIQKZLkq77ZquBcdeYKGjkkRqlyFv4YdptJEgViamXqyL9Oj\nU3lbO5I7QLL5l255KUdsiYRxlAAdXJGv+7tglOXkcSf3c7+M3bgM151LruzoHRqM\nx8i5m5PL0Ve8hvUvPiuaPUxKEDRzqgxTCcyeoFTbgXV/P6vt+/LaNNFQia8mrmVV\n2w0LwoLF1NkFbbrSfFuxiMpPCV7voI0F8BLAjHZgZYCgj+e490QfdUCUscVR5xZc\nSssOYGUCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAQYIyUBaYYa+BI7KF3xLb2C6K\nJ4PY4GkCxtWEYnaBZYRSsef85OgMT7r1F4finTBY3KfoCOt5Yti5TIkXtwxvoCTN\nnF68zBR55rLFO67LJWJ+B/aAazptn17X53wky+x7pdKASE54GcWhTxW9QEWVLaWD\nxu2Y7bPNIthUtiW9wmbWB+4fY4LhTVhcuh+/4xaFx/MVoTRhf2tFS6hBFeaUcsWT\nm/XJf5kBpLpV1G983akqJtH2D2IMJckYSQ67tUwWVpdXq3B1b8fwpnsl9H075UAD\nqwTl09UClG9hVUE5fDKSwyKE6DCq8Whg3Zb1EdVjTOncky3d7DkzttgD8YDqmA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "impa.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ross.impa.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://ross.impa.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ross.impa.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ross.impa.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://ross.impa.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ross.impa.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ross.impa.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://ross.impa.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "impa.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.impa.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.impa.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IMPA - Associacao Instituto Nacional de Matematica Pura e Aplicada"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IMPA - Associacao Instituto Nacional de Matematica Pura e Aplicada"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IMPA - Associacao Instituto Nacional de Matematica Pura e Aplicada"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IMPA - Associacao Instituto Nacional de Matematica Pura e Aplicada"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDijCCAnICAQAwDQYJKoZIhvcNAQEFBQAwgYoxDTALBgNVBAoTBElNUEExDDAK\nBgNVBAsTA0NJTjEdMBsGCSqGSIb3DQEJARYObmV0YWRtQGltcGEuYnIxFzAVBgNV\nBAcTDlJpbyBkZSBKYW5laXJvMRcwFQYDVQQIEw5SaW8gZGUgSmFuZWlybzELMAkG\nA1UEBhMCQlIxDTALBgNVBAMTBHJvc3MwHhcNMTQwOTMwMTg0MjE1WhcNMTcwOTI5\nMTg0MjE1WjCBijENMAsGA1UEChMESU1QQTEMMAoGA1UECxMDQ0lOMR0wGwYJKoZI\nhvcNAQkBFg5uZXRhZG1AaW1wYS5icjEXMBUGA1UEBxMOUmlvIGRlIEphbmVpcm8x\nFzAVBgNVBAgTDlJpbyBkZSBKYW5laXJvMQswCQYDVQQGEwJCUjENMAsGA1UEAxME\ncm9zczCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALZqzra9igATlWYM\nnWpR0mCkXBwbB1mMRmr7vJF9A9ZfKeF4ztOmG+6YRmCLZk8rbd+mhp4bPJ504hL5\nrSjixTm2IXf9XJHcFIQKZLkq77ZquBcdeYKGjkkRqlyFv4YdptJEgViamXqyL9Oj\nU3lbO5I7QLL5l255KUdsiYRxlAAdXJGv+7tglOXkcSf3c7+M3bgM151LruzoHRqM\nx8i5m5PL0Ve8hvUvPiuaPUxKEDRzqgxTCcyeoFTbgXV/P6vt+/LaNNFQia8mrmVV\n2w0LwoLF1NkFbbrSfFuxiMpPCV7voI0F8BLAjHZgZYCgj+e490QfdUCUscVR5xZc\nSssOYGUCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAQYIyUBaYYa+BI7KF3xLb2C6K\nJ4PY4GkCxtWEYnaBZYRSsef85OgMT7r1F4finTBY3KfoCOt5Yti5TIkXtwxvoCTN\nnF68zBR55rLFO67LJWJ+B/aAazptn17X53wky+x7pdKASE54GcWhTxW9QEWVLaWD\nxu2Y7bPNIthUtiW9wmbWB+4fY4LhTVhcuh+/4xaFx/MVoTRhf2tFS6hBFeaUcsWT\nm/XJf5kBpLpV1G983akqJtH2D2IMJckYSQ67tUwWVpdXq3B1b8fwpnsl9H075UAD\nqwTl09UClG9hVUE5fDKSwyKE6DCq8Whg3Zb1EdVjTOncky3d7DkzttgD8YDqmA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IMPA - Associacao Instituto Nacional de Matematica Pura e Aplicada"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IMPA - Associacao Instituto Nacional de Matematica Pura e Aplicada"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.impa.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.impa.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IMPA - Associacao Instituto Nacional de Matematica Pura e Aplicada"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IMPA - Associacao Instituto Nacional de Matematica Pura e Aplicada"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://adfs1.oba.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs1.oba.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-05-18T13:37:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/effd01c35b2da13885151fd82ac263a2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Openbare Bibliotheek Amsterdam (OBA)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Openbare Bibliotheek Amsterdam (OBA)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/oba.png",
                    "height": "48",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "48"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Openbare Bibliotheek Amsterdam (OBA)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Openbare Bibliotheek Amsterdam (OBA)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Openbare Bibliotheek Amsterdam (OBA)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oba.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Openbare Bibliotheek Amsterdam (OBA)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.studentsupermarket.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gray"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:robert@studentsupermarket.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Onder"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ali@studentsupermarket.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ali"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.studentsupermarket.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-03-17T10:12:25Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Student Supermarket"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.studentsupermarket.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Student Supermarket Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.studentsupermarket.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.studentsupermarket.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.studentsupermarket.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.studentsupermarket.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.studentsupermarket.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.studentsupermarket.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "A global online platform to provide services for students everyday lives"
                  }
                ],
                "logo": [
                  {
                    "text": "https://studentsupermarket.com/images/logos/studentlogo.png",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Student Supermarket"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAM+NtIG/0ge4MA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEGlwLTE3Mi0zMS0xOS0yNDIwHhcNMTUwMzEwMTYzNTEyWhcNMjUwMzA3MTYz\n\t\t\t\t\t\tNTEyWjAbMRkwFwYDVQQDExBpcC0xNzItMzEtMTktMjQyMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEAm6LJQRhFMzXL9LCIqw44/wgw2VDefNZwS5/FE8co\n\t\t\t\t\t\tcHA6DMdopRpaTFg7W0OvjMPbLlUZmvGB4GAvMFbNKXWQ4qccbNptDXcD4kN7gTP7\n\t\t\t\t\t\t8Stzd6TXOPdhejQ0U2Q2/zNX9B5klAS51NhlzLfW6MLWK6qV9eFCnum9gxTcx2/c\n\t\t\t\t\t\t79xiYI+lEMYKkXKFUnls6JjhQgm4/a0NEiGkWEjzoIVOXQDKMyz7p1JJ6OcQ65y6\n\t\t\t\t\t\tBGdXT/4oG6a6yhgGHbgaV6ZJWAax53Ffv+P4p1gC129Zc/s6oOWro6Mo8jh9mC8u\n\t\t\t\t\t\toH7eHSgcpxJUWzwAUl4RDPpfvSHCUy83y6p+lqWTuOYvKQIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghBpcC0xNzItMzEtMTktMjQyMB0GA1UdDgQWBBRWTq9V0PVO5YKVXNur\n\t\t\t\t\t\tY2dQoYWknzANBgkqhkiG9w0BAQUFAAOCAQEAjJJq1iIQ5cc+4YhaPlng3/Lol/Mg\n\t\t\t\t\t\tUNxGCDigM2IDSaCEH9SvAoyMvNqHeUpuYpHn8Do1oifyHS8xZH41aDyhh3Vl4TkG\n\t\t\t\t\t\t5KfqOxoH18vwa66IRz3Mn6E20qXuYIQAGIFufW/l3KWFWBe9l1GRxRItIwVolEd5\n\t\t\t\t\t\tGtU8Tri/ftwndN8aifYEhPrpMJl1lWYUU2cHnQ7lM1/E9pzeJaCq7wkU+Il3471I\n\t\t\t\t\t\t3ewD2JCEJ+ORBj1AL+QF5TqJghWyH6a3IKkMVkIHk+7NHq4L6QZvFW7togFp+0Oa\n\t\t\t\t\t\tW/4oy5wJRf4niwyvkV8gDlo/H5cIxc7nt0nwpotbejw3/FNEu8WkrKzrXQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.studentsupermarket.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.studentsupermarket.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.studentsupermarket.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.studentsupermarket.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.studentsupermarket.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.studentsupermarket.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://brain.lab.vvc.niif.hu/simplesamlphp/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Meszaros"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:misi@niif.hu"
            }
          ],
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Meszaros"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:misi@niif.hu"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Meszaros"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:misi@niif.hu"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://brain.lab.vvc.niif.hu/simplesamlphp/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "niifi"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "href-edugain"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:geant:niif.hu:eduid.hu:entity-attributes:processing-info",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "hu",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://metadata.eduid.hu/registration_policy_1_0.txt"
              }
            ],
            "registration_instant": "2013-08-01T07:17:19.807Z",
            "registration_authority": "http://eduid.hu",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NIIF - Nemzeti Inform\u00e1ci\u00f3s Infrastrukt\u00fara Fejleszt\u00e9si Int\u00e9zet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NIIF Institute - National Information Infrastructure Development"
          }
        ],
        "organization_url": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.niif.hu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.niif.hu/en"
          }
        ],
        "organization_name": [
          {
            "lang": "hu",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NIIF - Nemzeti Inform\u00e1ci\u00f3s Infrastrukt\u00fara Fejleszt\u00e9si Int\u00e9zet"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NIIF Institute - National Information Infrastructure Development"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://brain.lab.vvc.niif.hu/simplesamlphp/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://brain.lab.vvc.niif.hu"
                  }
                ],
                "description": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "NIIF & G\u00c9ANT4 SA8T2 STUN/TURN pilot service"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "NIIF & G\u00c9ANT4 SA8T2 STUN/TURN pilot service"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://brain.lab.vvc.niif.hu/privacy.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "hu",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SA8T2 STUN/TURN pilot service"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SA8T2 STUN/TURN pilot service"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "brain.lab.vvc.niif.hu"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://brain.lab.vvc.niif.hu/simplesamlphp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://brain.lab.vvc.niif.hu/simplesamlphp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "hu",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SA8T2 STUN/TURN pilot service"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "SA8T2 STUN/TURN pilot service"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.gkunions.co.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.gkunions.co.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-09-03T11:31:14Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Greenwich and Kent Unions Together"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gkunions.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.gkunions.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.gkunions.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.gkunions.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.gkunions.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.gkunions.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.gkunions.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.gkunions.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.gkunions.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.gkunions.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.gkunions.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.gkunions.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.gkunions.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.gkunions.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shib.med.cornell.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tom2010@med.cornell.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tom McMahon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Support@med.cornell.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ITS Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.med.cornell.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.med.cornell.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.med.cornell.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.med.cornell.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.med.cornell.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.med.cornell.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "med.cornell.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://shib.med.cornell.edu/idp/images/wcmc.jpg",
                    "lang": "en",
                    "height": "87",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "360"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Weill Cornell Medical College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVALf2UjTulHPvT1Tql4y9F07IaKUoMA0GCSqGSIb3DQEB\nBQUAMB8xHTAbBgNVBAMTFHNoaWIubWVkLmNvcm5lbGwuZWR1MB4XDTExMTIxMjIz\nNDMwMVoXDTMxMTIxMjIzNDMwMVowHzEdMBsGA1UEAxMUc2hpYi5tZWQuY29ybmVs\nbC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCpSX+ljW9kBT8o\nWr6dWDSTO3Xt4YUVW2D4f0HRGappmxcRL0eTj+5xMem5toiHuHmrnyyS3fByVmWZ\nDUm4aiTzbhxktRiL2VlIB1j+ggLq4g+y6R8w4xAwC1Kgi8iHPrp164mh+/7pmbd1\nUP2qjdOJLjg3NqVjZa/YhFBVdF22qc3tjOddqMvay5wh3smGvr7gygQy1oZnAbOq\nm9cX0nHB71C0ITa65v8QojU3+ivj3b8c8HW+OAeMWe2sd65BgkwBAZ29Ms7bc/N4\nSGaJOuRPvDd556afu64/p/s0AW0vXePwlxyY6puFZcHCREOLqImODGiaC0j9q+qf\na9UNeIgjAgMBAAGjbzBtMEwGA1UdEQRFMEOCFHNoaWIubWVkLmNvcm5lbGwuZWR1\nhitodHRwczovL3NoaWIubWVkLmNvcm5lbGwuZWR1L2lkcC9zaGliYm9sZXRoMB0G\nA1UdDgQWBBTLuL7YYyGqqqyNrM1VTvMM31GBOjANBgkqhkiG9w0BAQUFAAOCAQEA\nZOuFvp/wh93CGfs0VP7VpVsX/Nfy/6xqYYPFywUeBdLmiP00rk7dbmFftQxil82u\nhsENb1L/quzerzHQPZPjzhMY1lMuLr9vIBZkfyFgyE96LlYrpsWqWT86gJeKEgWu\nkKKOa1rzD75EjjAQCogb6nK7FHKOhfFle5bYdVnRW+1RkZRXb0sJYwqsVttXuBes\nNbQ++tq32Y01h5+LgfGaK0QJ1nkUthT09OtyT/1Zs1X5plOvUvCHpfCcq9exE/G9\n8AZTYkxqWSzEVVXNh2dglaskxIfxRaKfTsznYfuqu+sDLNWPDiP7TCJ5pBHUSqO/\nMkcicsifJ9hvJTUFVS7mSg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://shib.med.cornell.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Weill Cornell Medical College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.med.cornell.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Weill Cornell Medical College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://cafe1.ufes.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Renan Manola"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "renan.manola@ufes.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe1.ufes.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDoDCCAogCAQAwDQYJKoZIhvcNAQEFBQAwgZUxDTALBgNVBAoTBFVGRVMxDDAK\nBgNVBAsTA05USTEmMCQGCSqGSIb3DQEJARYXYW50b25pby5tLnJvY2hhQHVmZXMu\nYnIxEDAOBgNVBAcTB1ZpdG9yaWExFzAVBgNVBAgTDkVzcGlyaXRvIFNhbnRvMQsw\nCQYDVQQGEwJCUjEWMBQGA1UEAxMNY2FmZTEudWZlcy5icjAeFw0xNTAxMDcxNzU0\nNTJaFw0xODAxMDYxNzU0NTJaMIGVMQ0wCwYDVQQKEwRVRkVTMQwwCgYDVQQLEwNO\nVEkxJjAkBgkqhkiG9w0BCQEWF2FudG9uaW8ubS5yb2NoYUB1ZmVzLmJyMRAwDgYD\nVQQHEwdWaXRvcmlhMRcwFQYDVQQIEw5Fc3Bpcml0byBTYW50bzELMAkGA1UEBhMC\nQlIxFjAUBgNVBAMTDWNhZmUxLnVmZXMuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQDLb0G4Z/B9GlxpGjL/b6HMukcpJZY4V5hInFe2jRELMHaOjC/H\na8rkkGE+BF328i+j3TbadC2PztQLcIliu4RnchXFbHnf4rPcEslivY61ScD7Gr5A\nYyVZjy7IFTyujMt0xTxpCCa2ALafqz0wP+0h8vnDIuirI2sbZvMRVTZlEkGxLqiN\nP8E9eXrHeBF0Mqn5Y3ALtmxK/3EhJZGPFb3mpAKA8VVWBbCxcwEMTlBbD2khbxEQ\n4JuBr+c53Mw/Vw+nKwc3TnGC5JIpubdARd/zvBx2ITEw40snOBjVS9eQ2oJb7fQ2\nQUmZSeBOiyT7upWtr5iIRs+pgGx6aRiM7J8jAgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBAFaMTOaqN0tOvO4r9vNAE5jS9U06yyidIRvCS68Tvx7nbk2H6ij3fX8YxkcM\npU7Tf5xRjM/4KKCiKn/paBWgiEykCHL49F4ncspsQPqkzV5HM6j/TdbSQXKSnzhT\nhC+UUBcEqAO7VKNIB61EmoYWEYLhb/nRwG3e6SwyqcyxuyslzLdlXTTWJTCFIL4e\n/lcdxU4qaDe9OVFviLm7VUSc5cKdsZ6D/L8y4rs++JDAHcY+AOALUg1f5OtFFn3S\nk0J2vt+xpANqnDVC4sBQlal4XvU3os8bHCVjktGc9TXnJ4ncKQYCX/f00JpRCM0/\n3zZYkTltfRJxIQam1OGU4pKCZlc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufes.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe1.ufes.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe1.ufes.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe1.ufes.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe1.ufes.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe1.ufes.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe1.ufes.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe1.ufes.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe1.ufes.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufes.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufes.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ufes.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFES - Universidade Federal do Espirito Santo"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFES - Universidade Federal do Espirito Santo"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFES - Universidade Federal do Espirito Santo"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFES - Universidade Federal do Espirito Santo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDoDCCAogCAQAwDQYJKoZIhvcNAQEFBQAwgZUxDTALBgNVBAoTBFVGRVMxDDAK\nBgNVBAsTA05USTEmMCQGCSqGSIb3DQEJARYXYW50b25pby5tLnJvY2hhQHVmZXMu\nYnIxEDAOBgNVBAcTB1ZpdG9yaWExFzAVBgNVBAgTDkVzcGlyaXRvIFNhbnRvMQsw\nCQYDVQQGEwJCUjEWMBQGA1UEAxMNY2FmZTEudWZlcy5icjAeFw0xNTAxMDcxNzU0\nNTJaFw0xODAxMDYxNzU0NTJaMIGVMQ0wCwYDVQQKEwRVRkVTMQwwCgYDVQQLEwNO\nVEkxJjAkBgkqhkiG9w0BCQEWF2FudG9uaW8ubS5yb2NoYUB1ZmVzLmJyMRAwDgYD\nVQQHEwdWaXRvcmlhMRcwFQYDVQQIEw5Fc3Bpcml0byBTYW50bzELMAkGA1UEBhMC\nQlIxFjAUBgNVBAMTDWNhZmUxLnVmZXMuYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IB\nDwAwggEKAoIBAQDLb0G4Z/B9GlxpGjL/b6HMukcpJZY4V5hInFe2jRELMHaOjC/H\na8rkkGE+BF328i+j3TbadC2PztQLcIliu4RnchXFbHnf4rPcEslivY61ScD7Gr5A\nYyVZjy7IFTyujMt0xTxpCCa2ALafqz0wP+0h8vnDIuirI2sbZvMRVTZlEkGxLqiN\nP8E9eXrHeBF0Mqn5Y3ALtmxK/3EhJZGPFb3mpAKA8VVWBbCxcwEMTlBbD2khbxEQ\n4JuBr+c53Mw/Vw+nKwc3TnGC5JIpubdARd/zvBx2ITEw40snOBjVS9eQ2oJb7fQ2\nQUmZSeBOiyT7upWtr5iIRs+pgGx6aRiM7J8jAgMBAAEwDQYJKoZIhvcNAQEFBQAD\nggEBAFaMTOaqN0tOvO4r9vNAE5jS9U06yyidIRvCS68Tvx7nbk2H6ij3fX8YxkcM\npU7Tf5xRjM/4KKCiKn/paBWgiEykCHL49F4ncspsQPqkzV5HM6j/TdbSQXKSnzhT\nhC+UUBcEqAO7VKNIB61EmoYWEYLhb/nRwG3e6SwyqcyxuyslzLdlXTTWJTCFIL4e\n/lcdxU4qaDe9OVFviLm7VUSc5cKdsZ6D/L8y4rs++JDAHcY+AOALUg1f5OtFFn3S\nk0J2vt+xpANqnDVC4sBQlal4XvU3os8bHCVjktGc9TXnJ4ncKQYCX/f00JpRCM0/\n3zZYkTltfRJxIQam1OGU4pKCZlc="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFES - Universidade Federal do Espirito Santo"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFES - Universidade Federal do Espirito Santo"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufes.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ufes.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFES - Universidade Federal do Espirito Santo"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFES - Universidade Federal do Espirito Santo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.huddnewcoll.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Andre"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:candre@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Andre"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:candre@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.huddnewcoll.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-07-12T13:35:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID1jCCAr4CCQDipzubEmV65TANBgkqhkiG9w0BAQUFADCBrDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFTATBgNVBAgTDEh1ZGRlcnNmaWVsZDEVMBMGA1UEBxMMTmV3IEhleSBSb2Fk\n\t\t\t\t\t\tMSEwHwYDVQQKExhIdWRkZXJzZmllbGQgTmV3IENvbGxlZ2UxJTAjBgNVBAsTHHNo\n\t\t\t\t\t\taWJib2xldGguaHVkZG5ld2NvbGwuYWMudWsxJTAjBgNVBAMTHHNoaWJib2xldGgu\n\t\t\t\t\t\taHVkZG5ld2NvbGwuYWMudWswHhcNMTMwNTIwMDg1NDM5WhcNMzMwNTE1MDg1NDM5\n\t\t\t\t\t\tWjCBrDELMAkGA1UEBhMCR0IxFTATBgNVBAgTDEh1ZGRlcnNmaWVsZDEVMBMGA1UE\n\t\t\t\t\t\tBxMMTmV3IEhleSBSb2FkMSEwHwYDVQQKExhIdWRkZXJzZmllbGQgTmV3IENvbGxl\n\t\t\t\t\t\tZ2UxJTAjBgNVBAsTHHNoaWJib2xldGguaHVkZG5ld2NvbGwuYWMudWsxJTAjBgNV\n\t\t\t\t\t\tBAMTHHNoaWJib2xldGguaHVkZG5ld2NvbGwuYWMudWswggEiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tAQUAA4IBDwAwggEKAoIBAQDITxYchqgwkjzeMznQ3pAKZcssEogz3vkQpZhnuABl\n\t\t\t\t\t\tPiVWBj/mBI2HuVXXKIi5hf5vxwtU5vrxGyWnQobKl8GioNDH0ijbZE2XSiB6xDWP\n\t\t\t\t\t\tNVnvWOwQF60Rmblu/nGlbyKY3iRsTs3cJSMxGb0if6eBb2Z+vYtfhvcxU7omCCNU\n\t\t\t\t\t\t6QjV0klmu0fLOP/qoVFkyPRKPvYgkZMtajvXt4yc6gigwsNmVJF7VczqjJNi9yN2\n\t\t\t\t\t\tk2GkGUXcMg7Vaqgg61kGhDOO7zqHNRrMnbBjQte+99OkuOLDPdHgreFlP3MV7Jbc\n\t\t\t\t\t\tZEzpFuoFYk3qdGbAVhM1965Kgoqy6ch4AOgmFSFy0KxpAgMBAAEwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAK9RrkLse5uPKVnAsFhGFEnSgcaf/4kejl2cy/+2kTkUXYPJegf+\n\t\t\t\t\t\t5bluOqZJfjsYcguTtOIhRli4JnNrPd5b1evrXnBAZFDztvqSiBaZkT7pGwuecrjF\n\t\t\t\t\t\tKfykj21LxZrPCfIdmfTyacDCWJamUblQG5B/fpIzRlUps5ueI5uyIBKYqtg8rpdz\n\t\t\t\t\t\tS5Tv7kpjdFCJnO8nyD95EiGc36pV+C6Q91k7Zq08mIxJEgDlnFEGjkPpN5QFUI1B\n\t\t\t\t\t\tEku18ndqAe3yyTTtYjzBC8yz03J49x8OcJoBmjF1TldyfjE25y/23juUoT7o3UT0\n\t\t\t\t\t\t6KDdLZLQpW7ZoCPDM22iFArIEPpajNu8tVU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "huddnewcoll.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.huddnewcoll.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.huddnewcoll.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.huddnewcoll.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.huddnewcoll.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.huddnewcoll.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.huddnewcoll.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.huddnewcoll.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.huddnewcoll.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "huddnewcoll.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID1jCCAr4CCQDipzubEmV65TANBgkqhkiG9w0BAQUFADCBrDELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFTATBgNVBAgTDEh1ZGRlcnNmaWVsZDEVMBMGA1UEBxMMTmV3IEhleSBSb2Fk\n\t\t\t\t\t\tMSEwHwYDVQQKExhIdWRkZXJzZmllbGQgTmV3IENvbGxlZ2UxJTAjBgNVBAsTHHNo\n\t\t\t\t\t\taWJib2xldGguaHVkZG5ld2NvbGwuYWMudWsxJTAjBgNVBAMTHHNoaWJib2xldGgu\n\t\t\t\t\t\taHVkZG5ld2NvbGwuYWMudWswHhcNMTMwNTIwMDg1NDM5WhcNMzMwNTE1MDg1NDM5\n\t\t\t\t\t\tWjCBrDELMAkGA1UEBhMCR0IxFTATBgNVBAgTDEh1ZGRlcnNmaWVsZDEVMBMGA1UE\n\t\t\t\t\t\tBxMMTmV3IEhleSBSb2FkMSEwHwYDVQQKExhIdWRkZXJzZmllbGQgTmV3IENvbGxl\n\t\t\t\t\t\tZ2UxJTAjBgNVBAsTHHNoaWJib2xldGguaHVkZG5ld2NvbGwuYWMudWsxJTAjBgNV\n\t\t\t\t\t\tBAMTHHNoaWJib2xldGguaHVkZG5ld2NvbGwuYWMudWswggEiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tAQUAA4IBDwAwggEKAoIBAQDITxYchqgwkjzeMznQ3pAKZcssEogz3vkQpZhnuABl\n\t\t\t\t\t\tPiVWBj/mBI2HuVXXKIi5hf5vxwtU5vrxGyWnQobKl8GioNDH0ijbZE2XSiB6xDWP\n\t\t\t\t\t\tNVnvWOwQF60Rmblu/nGlbyKY3iRsTs3cJSMxGb0if6eBb2Z+vYtfhvcxU7omCCNU\n\t\t\t\t\t\t6QjV0klmu0fLOP/qoVFkyPRKPvYgkZMtajvXt4yc6gigwsNmVJF7VczqjJNi9yN2\n\t\t\t\t\t\tk2GkGUXcMg7Vaqgg61kGhDOO7zqHNRrMnbBjQte+99OkuOLDPdHgreFlP3MV7Jbc\n\t\t\t\t\t\tZEzpFuoFYk3qdGbAVhM1965Kgoqy6ch4AOgmFSFy0KxpAgMBAAEwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBAK9RrkLse5uPKVnAsFhGFEnSgcaf/4kejl2cy/+2kTkUXYPJegf+\n\t\t\t\t\t\t5bluOqZJfjsYcguTtOIhRli4JnNrPd5b1evrXnBAZFDztvqSiBaZkT7pGwuecrjF\n\t\t\t\t\t\tKfykj21LxZrPCfIdmfTyacDCWJamUblQG5B/fpIzRlUps5ueI5uyIBKYqtg8rpdz\n\t\t\t\t\t\tS5Tv7kpjdFCJnO8nyD95EiGc36pV+C6Q91k7Zq08mIxJEgDlnFEGjkPpN5QFUI1B\n\t\t\t\t\t\tEku18ndqAe3yyTTtYjzBC8yz03J49x8OcJoBmjF1TldyfjE25y/23juUoT7o3UT0\n\t\t\t\t\t\t6KDdLZLQpW7ZoCPDM22iFArIEPpajNu8tVU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Huddersfield New College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.huddnewcoll.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Huddersfield New College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.infectiousdisease.cam.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:falcon-support@ucs.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Falcon Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:falcon-support@ucs.cam.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Falcon Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.infectiousdisease.cam.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-05-06T12:47:56Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Cambridge: Infectious Diseases"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.infectiousdisease.cam.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Cambridge"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.infectiousdisease.cam.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.infectiousdisease.cam.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.infectiousdisease.cam.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.infectiousdisease.cam.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.infectiousdisease.cam.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www-cvdc.eng.cam.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDDzCCAfegAwIBAgIJAOB8D/FajzX8MA0GCSqGSIb3DQEBBQUAMCMxITAfBgNV\n\t\t\t\t\t\tBAMTGHd3dy1mYWxjb24uY3N4LmNhbS5hYy51azAeFw0xMDAxMTgxMTAwMDdaFw0y\n\t\t\t\t\t\tMDAxMTYxMTAwMDdaMCMxITAfBgNVBAMTGHd3dy1mYWxjb24uY3N4LmNhbS5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKpU2AuemKJSIeDmgjkZ\n\t\t\t\t\t\ttPgKaPPkM5CKu3QUHm5JzmtnG3UFMxbOumt6sxWWF72ceXQNPgBNGqFI/sFdaCIo\n\t\t\t\t\t\tHxZj+Z2i+k7/IVXhc4wjs72YUfrjvTMDhHHzndm3KkJS8imsIYQ8/bBnJEF93zVJ\n\t\t\t\t\t\tgPYTrX1C8JxqF/wfY/XCGbEqHgJtqDrSEvK+vLF7LaYI4oTotZOg/vhN7uwaEa7n\n\t\t\t\t\t\tGU2+bKuhcAL+rolEM6sbdrQAj3KarTafacfh9IiAclzyOQTA6pfjFWrucNIuWXc4\n\t\t\t\t\t\tYhaEPyOMubMsp+0eXZAwEPTJ61x+nQZd3UAf7Rm5v7agrzRAdqdwpnqb4yyprJlI\n\t\t\t\t\t\t+lkCAwEAAaNGMEQwIwYDVR0RBBwwGoIYd3d3LWZhbGNvbi5jc3guY2FtLmFjLnVr\n\t\t\t\t\t\tMB0GA1UdDgQWBBTz/ES/EvNaSsqqXUxLuIFc9YHi/TANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAAvFTJS2L6StZuqKA935AD3bBOHe5pg+LCF6ydHdTuyWEJYIWBRJ1WXsKMyaG\n\t\t\t\t\t\tyvdlX60XziJARq2UiYxt4yRjuGLAjQl9kNdrlqeb2AJFnA5E1Mt56FtzPiwu2zrC\n\t\t\t\t\t\tTQlklC4Xfie1Yaw2kEVO2vAoRfg9bgSBfyvFC4oR3vCery3Z687oCeQqDp7LPRcn\n\t\t\t\t\t\t+k5qQD8pout57IYzwyo7GPeVkYEPb3GO2KYmoENlDR/xah2VcsTZF7aIsMBFxaPv\n\t\t\t\t\t\tO+oqrQcnQXTviY9yWLbAlSrPPqGNYDxayVHn+zDSO4scLlOoqZJ8iC5NboNKqFyB\n\t\t\t\t\t\tRsenNm/aXp0wIU+jHVmi/GAPCQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.infectiousdisease.cam.ac.uk/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.infectiousdisease.cam.ac.uk/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.infectiousdisease.cam.ac.uk/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.infectiousdisease.cam.ac.uk/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.infectiousdisease.cam.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.infectiousdisease.cam.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.infectiousdisease.cam.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.infectiousdisease.cam.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.infectiousdisease.cam.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.infectiousdisease.cam.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idpv3.essingtoncc.co.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Morris"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:andy@essingtoncc.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andy"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Morris"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:andy@essingtoncc.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andy"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idpv3.essingtoncc.co.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-11-06T12:07:22Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idpv3.essingtoncc.co.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idpv3.essingtoncc.co.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idpv3.essingtoncc.co.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idpv3.essingtoncc.co.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idpv3.essingtoncc.co.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idpv3.essingtoncc.co.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "essingtoncc.co.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVANxdvblrHmOwk0K/rl10Sda/mMrFMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMCIxIDAeBgNVBAMMF2lkcHYzLmVzc2luZ3RvbmNjLmNvLnVrMB4XDTE1MTAx\n\t\t\t\t\t\tNDE1NTYxNFoXDTM1MTAxNDE1NTYxNFowIjEgMB4GA1UEAwwXaWRwdjMuZXNzaW5n\n\t\t\t\t\t\tdG9uY2MuY28udWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCcprpG\n\t\t\t\t\t\tG0NVw74J4JKdvg7fGAdrBVniHTIkljKuTl9h8JnseVsrTdBq+8QVH+g9eoF6HgYq\n\t\t\t\t\t\tLgS3ejgk4lX6OmTS8welpfyvX6Rml3vU4fvFb8JPiSB6zzzlp6KmGrWBt0vNRrQ2\n\t\t\t\t\t\tjG0TeByBHTX+4TXI9/hC+WCHv5urgC3m+i8KcLzGRhj+ULq66wzqlkiFgCTgCpfz\n\t\t\t\t\t\tvV6cu4CFkTW+8TR8vjcjqU16f/jzafqJKOWYY4nzutoudmytSatAHym8Doosxv3d\n\t\t\t\t\t\tieCCGxb6O9FNHbbAY7ycB5Mm2jTmqlNU2iJsYBDqixXyIfOAscJ21RCxTjpZt9Ce\n\t\t\t\t\t\t5UCicxpLDLvF5rr/AgMBAAGjdTBzMB0GA1UdDgQWBBT6YZEW8mN2VfFAMqscacoG\n\t\t\t\t\t\tui/n5DBSBgNVHREESzBJghdpZHB2My5lc3Npbmd0b25jYy5jby51a4YuaHR0cHM6\n\t\t\t\t\t\tLy9pZHB2My5lc3Npbmd0b25jYy5jby51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG\n\t\t\t\t\t\t9w0BAQsFAAOCAQEAOsSFIttIYMwgmXQD22mKCFobO4SMXYRn+1yjGc5nEP/Mz+8s\n\t\t\t\t\t\tW23exjfS80yiLnn435T/Iq+UMd4zkITo45tiNO01G/FnN+cGpHl8RB/P2NgQcZRP\n\t\t\t\t\t\tQID3rle+Ufzr7APC1+ACZzxVk2GtT9QuWf7JYRLUQCeQOfIptgntDeIhX4uOTfdt\n\t\t\t\t\t\tdl0Kmt0J9yOXgBoxvFQsNT+RCKScdTO+frwyKKpjBlR7sOngO8R8JJ/YHSYzJOXc\n\t\t\t\t\t\tDshYuafoNMzlhChAmEjZgwbU+bMtjQv6A0J49uebhyyIbd5k3UGtuafv1XQXERL+\n\t\t\t\t\t\tLmiAYOW7xsIlMcU3oGuPig1k5E9I4mtPxgqfQw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRzCCAi+gAwIBAgIUQ+2SQEeM841I+Pr+e1Rf1G2mWtYwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwIjEgMB4GA1UEAwwXaWRwdjMuZXNzaW5ndG9uY2MuY28udWswHhcNMTUxMDE0\n\t\t\t\t\t\tMTU1NjA5WhcNMzUxMDE0MTU1NjA5WjAiMSAwHgYDVQQDDBdpZHB2My5lc3Npbmd0\n\t\t\t\t\t\tb25jYy5jby51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALQaBR9n\n\t\t\t\t\t\tAPsTg0QtFRtSAn/vnJ8EWRVpml3/4BdsrNtZslJ9WMX2wRiVCKqyVAUzVvB+fZW6\n\t\t\t\t\t\tc0G4Om9OLcMHn9NqYOVNktxmApNj5yjAe1on1Jb9vpzzfz042brEQahSMH8dP2WK\n\t\t\t\t\t\tBNl0zsEl6B+O5LGv9R6zWRpjcWpP/Hhdv1Mt2UCubk1j0YB0yigDCSJsKtlt4ADW\n\t\t\t\t\t\t0zcI8e+yltSWf2m5PJ2lOVfsE9lGMw2K9HnCo4wto2cMboXgZwTUbPz/opcZ6PWr\n\t\t\t\t\t\tzN6OgX0MteSUrjoMkzKsLUKv3cs0Xn/+JRNEAtyWQvm6/DH2Z+EV0rDSQVbXPEmw\n\t\t\t\t\t\tG7n3UM8PrSm5HVkCAwEAAaN1MHMwHQYDVR0OBBYEFIRy38M9ievXUaGPVTs7o70A\n\t\t\t\t\t\tnYPBMFIGA1UdEQRLMEmCF2lkcHYzLmVzc2luZ3RvbmNjLmNvLnVrhi5odHRwczov\n\t\t\t\t\t\tL2lkcHYzLmVzc2luZ3RvbmNjLmNvLnVrL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBCwUAA4IBAQCy6r+ejtGEvl96u4RndrDZLZ9OYtga+axs3/4YjQV0tRIKa8En\n\t\t\t\t\t\tTJnPdRGhxp1hskOmPtmYZQ3dLH3feLjb+ux8L2QDRYa0q4ghNIiHD75DYwnme1bc\n\t\t\t\t\t\t3VeO0rMIvOfjZnyQVfFTdVQmhcpYdeqrnZZOXBiuTXWVFvwChaCfEmHdUV93j7Gg\n\t\t\t\t\t\twuv77Rq2ZfASy8bfsYvCkkOlYV4lEAcZJLg+UgYzbdUf3lg9YUGsp0IdrFozQnL5\n\t\t\t\t\t\tSc5v7jqZOGcVPtR9xiewWBb5p9LjWLezZPYyM2nz6bJktSea75YDiJpFYIsGX1EA\n\t\t\t\t\t\tgtlBzrAHoC/fd8GGCq5HZ0mQyNzrF70sEXN7"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAPzpG2xrtqp1K0RSsJJUezfEZvB1MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tCwUAMCIxIDAeBgNVBAMMF2lkcHYzLmVzc2luZ3RvbmNjLmNvLnVrMB4XDTE1MTAx\n\t\t\t\t\t\tNDE1NTYxM1oXDTM1MTAxNDE1NTYxM1owIjEgMB4GA1UEAwwXaWRwdjMuZXNzaW5n\n\t\t\t\t\t\tdG9uY2MuY28udWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCj9KaC\n\t\t\t\t\t\tpr5xfua5HRef7zqgmclBmTQMwduUp4KEO91NB+YGlmyyfgNm9K8xZ+72dHbLMqyJ\n\t\t\t\t\t\tK9YqQTuJLHBi4mVH2fmqYUGhTnOfLMP1cvSGdQyhl3Yp6YpyHa0L4ZIx1YRhVP7m\n\t\t\t\t\t\t+uh0o6XTL8KGZQf5E+O6tP5CEqyTRLPPqFJCZZyGk5g/P848zmS5y//SgWs9irSz\n\t\t\t\t\t\tTKf1xsgiaCa1j4BKOuk/0cYwc5Vr8UJw3iQVQNyY22IkbXcwgqoAejXl1a50k1ca\n\t\t\t\t\t\tZdv1sJbfMMxNRaJvSgJQazE4rhluCNmmPrd5pFizMZD8Rdci1325eKs9WPR8Q2UE\n\t\t\t\t\t\t3Q1BcAYk/UwrhU/HAgMBAAGjdTBzMB0GA1UdDgQWBBTpb8nD6p3duvAL1ovP5W1D\n\t\t\t\t\t\tKtOVOTBSBgNVHREESzBJghdpZHB2My5lc3Npbmd0b25jYy5jby51a4YuaHR0cHM6\n\t\t\t\t\t\tLy9pZHB2My5lc3Npbmd0b25jYy5jby51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG\n\t\t\t\t\t\t9w0BAQsFAAOCAQEAdgEszQ9bhu0UXACuvCpFkIsc0+2IyhlqYYO2sNRPiM+YgLIA\n\t\t\t\t\t\t1YrwPxlcmHomTf+VU7q+/s4ZNfYITbRcfNP4CFiiZR5AbkWDnMLQ281guKHLN6bq\n\t\t\t\t\t\t5VVqsyS4YBF0nv0NFf6Jk/BuqGJJV2zmWxUKIKxRnyiWnIzEMIn4nIOFAx9M7Gse\n\t\t\t\t\t\t/AzjpZWOIrHPQVtCWLpq8+5bzXP66/9iuzgYv517JUjZo+AfBFInuqUCHXgazl4N\n\t\t\t\t\t\tq1Jv3WZ9N9b7LT17+KzD30WQMYlRRO++T+j7McCQB2I32ymF8xo8NkpUjKA43m+z\n\t\t\t\t\t\t1oHqE+W7b2W2PL9JJ7zQEP5c4qax7abevAa5yw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Essington Computer Consultancy Ltd"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.essingtoncc.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Essington Computer Consultancy Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp-couperin.renater.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "chabli Anass"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "anass.chabli@renater.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-couperin.renater.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-06-01T17:29:32Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-couperin.renater.fr/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-couperin.renater.fr/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-couperin.renater.fr/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-couperin.renater.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-couperin.renater.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-couperin.renater.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "couperin.org"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.renater.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Service d'authentification de Couperin"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Service d'authentification de Couperin"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAIAAACQkWg2AAAAA3NCSVQICAjb4U/gAAABKUlEQVQokWM0Nk5jIAWwoPFl1L6pGX/m4v0L4V44IPDkFheyAka4DZw8fzJ776obf0Ez4sIB/gUNCt+/QI1mlpIyhrAq5t9Q0v327TPz0na5Vb2ye5eLvXnOpqT7VVb9u6Lu1+NbRFCcpGb8WVb9OwMDw4IGhYsHBSCC+5aLP7nFVTzzlrrxF2HJn2+fs2PxA1w1BNw6y3vzLA8DAwMn71+G59g8jQn60tWRuUwENaCBAdfAyfNn5pmzM8+cVTP+jKLh7TM2CMMp8iWyBueoVwwMDN8+M986ywsRgYbS2+fsxzYLW/m+DS9+YuDwASKtZvwZEvGremXgRjAiJz6nyJe+ac/hCYmBgeHNM7ZVvbLIkcOImVpl1L5B9Hz7zIyW8hiwRhymImQAABoAaLnD7wajAAAAAElFTkSuQmCC",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "COUPERIN"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "COUPERIN"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAMULo4bCEwXQpVzPDquvwEPmzkVrMA0GCSqGSIb3DQEB\nCwUAMCIxIDAeBgNVBAMMF2lkcC1jb3VwZXJpbi5yZW5hdGVyLmZyMB4XDTE1MDYw\nMjEzMjc1M1oXDTM1MDYwMjEzMjc1M1owIjEgMB4GA1UEAwwXaWRwLWNvdXBlcmlu\nLnJlbmF0ZXIuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCtjxsz\nBuG1iCzsTXkK+6koRh28hxJqOIlitP3hawDeXx+m73jNm9nYxvbXi4wNVLIfXMGk\nien8yhwC7jn5daBz1/DpwJHxi9qC3/c5IrN3MmfcSYsS6pVW1+bLssOBdRusu8CN\ncltECD/F8NsTNubx0Dp3iQzOj+2ePiDZT7hF2qKneOl6VQAT5m6+CC9SlrhZKlAo\nj2Y71cSmnulzOpx/791duI1fFhOG+uB01iimekPTzCAs34g8nA3g7t776Pvf4lL6\nHyQdgg/5ty+lFT4Z01gpqO+3E3m0AVZx44RtU1+e8tpJtwHNksDwRh4hFlV5EVHC\nR8+Pqqm915QZNP13AgMBAAGjdTBzMB0GA1UdDgQWBBTM5/T7q4JJ5LhIHRNnTA3g\ns4qhWjBSBgNVHREESzBJghdpZHAtY291cGVyaW4ucmVuYXRlci5mcoYuaHR0cHM6\nLy9pZHAtY291cGVyaW4ucmVuYXRlci5mci9pZHAvc2hpYmJvbGV0aDANBgkqhkiG\n9w0BAQsFAAOCAQEAhtPzNITQtpPpLLzDo1ihtgDcUOpdM0DAQ0vvLjaPNBRWqwGA\nSTfAd9a90JZmO862Q8BMTdHHF4Buy+eROTL1w0VXkuP423sJvqlpQ2PhiZAf0Eyf\n50SyQnzXQQ2+VUoMws+oe+qyZWsi6eGV10lmVs+su982pJnH730B+CzMCPK7WHtt\n22tF63XjAZwBWK9iYx3+H7uAHf09PA8cE2Tvf8VotrrZP4JA9zThj/oXt+eKYR4d\n9uO1aL0aX8uJvW1pBzHLduUpoGEKoaTf4JxRereiuuKCCiMcI3ETSpq7QpmChzt9\nt07R76998/yfPxz/Dakn82YII+tPFsgpgJXT4g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "COUPERIN"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.renater.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "COUPERIN"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.listening-books.org.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jens"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jjens@gallerypartnership.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Joost"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jens"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jjens@gallerypartnership.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Joost"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.listening-books.org.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-09-24T15:02:27Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Listening Books"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.listening-books.org.uk/what-we-do.aspx"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Gallery Partnership Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.listening-books.org.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.listening-books.org.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.listening-books.org.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.listening-books.org.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.listening-books.org.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.listening-books.org.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "logo": [
                  {
                    "text": "https://www.listening-books.org.uk/images/logotop1.gif",
                    "height": "147",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "264"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Listening Books"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFTCCAf2gAwIBAgIJAKDYQGOVxDtoMA0GCSqGSIb3DQEBBQUAMCUxIzAhBgNV\n\t\t\t\t\t\tBAMTGnRncGx3ZWIwMS50Z3BsaG9zdGVkLmxvY2FsMB4XDTExMTAyMDEwMjUxN1oX\n\t\t\t\t\t\tDTIxMTAxNzEwMjUxN1owJTEjMCEGA1UEAxMadGdwbHdlYjAxLnRncGxob3N0ZWQu\n\t\t\t\t\t\tbG9jYWwwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDN2HILHmtyg26I\n\t\t\t\t\t\tknBnnJ0C/MGIYoDGyYvy+ECjDj2QeEYJKx7ew9shXOkeHgrwBbxyDvsSf1dY2fnI\n\t\t\t\t\t\t6WF9iVtzIw0imhxPNvNqrQT21zMNK/UsPd2jj8rgBpG8BAnPviKFACgvOcV/jwWn\n\t\t\t\t\t\tkMlYtcBVMivFomIvwCG907vVth/az8X26jRhQJ2stWJkST5VJ6hY2ynhjuqrveMC\n\t\t\t\t\t\ttUN9nOVp2gh5tx1DgIKQS4k9FMlNL0CdS0jNqt5L+pmn67oBrPrJm8T643BYgvl6\n\t\t\t\t\t\tUhoR2+M7BfyNy+y5GsmNysgKBQ7AY7kMBgQTOBecgfsN9rilljpB/ajMq3shGXYG\n\t\t\t\t\t\tu3xpXxy7AgMBAAGjSDBGMCUGA1UdEQQeMByCGnRncGx3ZWIwMS50Z3BsaG9zdGVk\n\t\t\t\t\t\tLmxvY2FsMB0GA1UdDgQWBBRktKsDD89ocGlu6WacWrHMS/q5WjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQUFAAOCAQEAq7ISl1XdEGVH72x0o9PqdeWv8e6w9iyyXlc7no1ugkM7qcXrzfEn\n\t\t\t\t\t\tEuRn+vd7FVYw0WQDa+YbdMiY0iT/Mt094WUTFU+tUcfgbJLskLqsHrJhdwpI6GVX\n\t\t\t\t\t\tlKICBk4ck20Hb9a6DAMHCOlMl5jyVTbtfDmsDE45QnRzwKmyItGPulup/WsRN6cw\n\t\t\t\t\t\tljVoBNnM64z/4Espp7Hqh9MT3elQnzCOYZH+qIwmLWvulpeLICokPW0SqIRzPx14\n\t\t\t\t\t\txCgNUc6/n0jjZM/Y2EOq1yjqLVkMp3pWmvkSrPfnymIdLeGqJj7ItmTcGXrtXF0q\n\t\t\t\t\t\tH7URozYYVkfDdLe3tdeszum1dhpLBArFfg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.listening-books.org.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.listening-books.org.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.listening-books.org.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.listening-books.org.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.listening-books.org.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.listening-books.org.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:cru.fr:federation:univ-lemans.fr",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "fed-tech@univ-lemans.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:cru.fr:federation:univ-lemans.fr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-03-16T12:04:57Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp2.univ-lemans.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp2.univ-lemans.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp2.univ-lemans.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-lemans.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-lemans.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 du Maine - Le Mans"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 du Maine - Le Mans"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEBzCCAu+gAwIBAgIJAPJkjMeKwz+TMA0GCSqGSIb3DQEBBQUAMIGZMQswCQYD\nVQQGEwJmcjEUMBIGA1UECAwLdW5pdi1sZW1hbnMxEDAOBgNVBAcMB0xFIE1BTlMx\nHDAaBgNVBAoME1VOSVZFUlNJVEUgRFUgTUFJTkUxHDAaBgNVBAMME2lkcDIudW5p\ndi1sZW1hbnMuZnIxJjAkBgkqhkiG9w0BCQEWF2ZlZC10ZWNoQHVuaXYtbGVtYW5z\nLmZyMB4XDTE0MDQxNDEwMDkzNFoXDTM0MDQxNDEwMDkzNFowgZkxCzAJBgNVBAYT\nAmZyMRQwEgYDVQQIDAt1bml2LWxlbWFuczEQMA4GA1UEBwwHTEUgTUFOUzEcMBoG\nA1UECgwTVU5JVkVSU0lURSBEVSBNQUlORTEcMBoGA1UEAwwTaWRwMi51bml2LWxl\nbWFucy5mcjEmMCQGCSqGSIb3DQEJARYXZmVkLXRlY2hAdW5pdi1sZW1hbnMuZnIw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDBgciAAr1+6sMGIFgYHYju\nl57S7ReTKO8qbyJ6QfVfrzQHSspk+Hfx8FxLTlP1yR59mO0PmTL3zxJr9rXvIBzw\nG1HyzZw3K6QLL02u4SAFcQRET8CmlXKM18JbmyF+WyQ1xBGfzpHXQGszHVQ/TihW\neEQat8D2ALVscAxxKpyFZsJWB9StyDPc/gYsqSU77GnXwun5p5SO10F2Ag+hWpzP\nGj5hHn2KVQdqP/rdDryi6WNN3Nk1niyecbxpPkomGg8n3ZAojulNYsn8bVkMB9I0\n1+1OCGcr1IMDiZVADDQ9tdO6c/ftFZMUNsOayYXsQsDnaW7LbvSIABBPQvGuBLDx\nAgMBAAGjUDBOMB0GA1UdDgQWBBRt0PUs8HKbUTeuD+959t8js76s5jAfBgNVHSME\nGDAWgBRt0PUs8HKbUTeuD+959t8js76s5jAMBgNVHRMEBTADAQH/MA0GCSqGSIb3\nDQEBBQUAA4IBAQArAai8yD7FfetenGqoPKTUt9fWdBN4tArGV++NydXdBjCC5E8S\nIML/iFVPuuCWC2kWI7b39UjnvrSCtzvkCjjcSA7ThkW9+0CdT6ohD8lh0TE34VQo\nUH4OnFMgI9iwhYEzJbcqDl3oGCtSLg482SU9YgdSLbSWQCYmJOWKtrnE5VGtHKba\nVAgkzA5irhs1FL1lhLrN0VP0Zl41cckZtAamNcc4xJ+HXPk0jCRtEIRdoBCF+4fL\n0Kczl19r1JsQ1/qYuSzYFoSeMonfQMzNswe2JMhVtem/X76sSLk9sXf/DGLBdxO5\npsTKLRse8C18pocxxBm/KWroiZrNIExoq6GB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAOfG5aIZ6Aohb63NMTtvPZ3HLBWfMA0GCSqGSIb3DQEB\nBQUAMB4xHDAaBgNVBAMTE2lkcDIudW5pdi1sZW1hbnMuZnIwHhcNMTAwNDEyMTE1\nODExWhcNMzAwNDEyMTE1ODExWjAeMRwwGgYDVQQDExNpZHAyLnVuaXYtbGVtYW5z\nLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmmABnRWyz2lm0ged\nF4Prv9GO+Z914ed7yVYJJi3jlCLejmkcDWpfTVm7rRalLX/3sO5KdE7dnXEBxdYf\nAluI409b9yNcDi8iTcRgQA233FnJxSkYf7yEKFVc5ZWhCvpbvda4NfxPHAi7E3LD\n1Rzji0PT+KYzElb/eTPmVl85LCeKK5aM9ILv8b5ziFC70t3JdaNsoXR0esC+5r8o\nnI80ICke0tibfbHrwlyldiJb/po9m9tSEB3i8NkEOgFXwz7X/fdGHur5gfJwvEXS\nMXzgSoq9DbpjWKR6/g46hABdmv8+C/+N+mxp4KehoyDcFPbED8pH9cqw9QtLKLgE\nSXy8uQIDAQABo20wazBKBgNVHREEQzBBghNpZHAyLnVuaXYtbGVtYW5zLmZyhipo\ndHRwczovL2lkcDIudW5pdi1sZW1hbnMuZnIvaWRwL3NoaWJib2xldGgwHQYDVR0O\nBBYEFMjVlzAX+5XMpiXoz2pkh/xv8xpAMA0GCSqGSIb3DQEBBQUAA4IBAQB+5SH/\nygI70ba2rP2hmL3klQ1md/zIaK7p3MOOkDy5lkIH31oI6lIFTrKyZg7ML19gMVeA\nuZhIO9ZWJDrFtBxgDGYeishp1zEctX+ExWuVU9rtWzgCQ7GlqpnJLDAjxCVotdTG\noEa3NbsjuPm4R3FaHiEAcVWGun8edQztZ9PRGxk7KDsT7+omuABB80mrvtYHGNCZ\nlKgdL3SFqkTQMbBvs4ouAnxw++YMfvcqUtxZJZKIKF7QTPeDOPLHLwHEZl6yL/kl\ndkydWQ+SmHuq9+cAfmW7kzferGnkRoHvIPVNtgGNo7kvQieeLbnGrLYpRWeMFt3f\n4weH5Ji9r7v8/chk"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 du Maine - Le Mans"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-lemans.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 du Maine - Le Mans"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://umdac-strike.ad.umu.se/shibboleth",
    {
      "entity_id": "https://umdac-strike.ad.umu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.example.org/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.example.org/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.example.org/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.example.org/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.example.org/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sp.example.org/Shibboleth.sso/DS/ds.swamid.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "sp.strike.ad.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE1jCCA76gAwIBAgIJANgp9G5gZX/7MA0GCSqGSIb3DQEBBQUAMIGiMQswCQYD\nVQQGEwJTRTEVMBMGA1UECBMMVmFzdGVyYm90dGVuMQ0wCwYDVQQHEwRVbWVhMRkw\nFwYDVQQKExBVbWVhIHVuaXZlcnNpdGV0MQwwCgYDVQQLEwNJVFMxHDAaBgNVBAMT\nE3NwLnN0cmlrZS5hZC51bXUuc2UxJjAkBgkqhkiG9w0BCQEWF2RhdG9yZHJpZnRA\ndW1kYWMudW11LnNlMB4XDTExMDIxMDEzMjI0MVoXDTEzMTIyNDEzMjI0MVowgaIx\nCzAJBgNVBAYTAlNFMRUwEwYDVQQIEwxWYXN0ZXJib3R0ZW4xDTALBgNVBAcTBFVt\nZWExGTAXBgNVBAoTEFVtZWEgdW5pdmVyc2l0ZXQxDDAKBgNVBAsTA0lUUzEcMBoG\nA1UEAxMTc3Auc3RyaWtlLmFkLnVtdS5zZTEmMCQGCSqGSIb3DQEJARYXZGF0b3Jk\ncmlmdEB1bWRhYy51bXUuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQD3cDW3/Z5H0wDknkiHATmn5+pSap07JCNKUrwBQZquE2Nfr3Idw83A3qMUwY7Z\nEW1jQU69j363dqGv9Ypc8ViQ9jSR5+O9iTaMYIpJHJSiFju3wFHbwZMJckFdsRjt\njsWCdh1EGU/oJP0HdijvDtr1eM6VjeB3a3oEOlN9ECPkGAR03m+O8CPviRSSwXJD\nyvtJKgBNy6U3t2o13L1i7xgvNNcywRu4vtdkt5K+NI/P7C0H/j1DzAbZzqfyJhBO\nKPW1X2Wetk6nubsw49k2XnRUFkqamvSe6shL4492cwRYpxmKTX+e/RUde0+Ve7VS\n0VaD9+9utUzO/kG/cOeXtzsDAgMBAAGjggELMIIBBzAdBgNVHQ4EFgQUbDEDfqkU\nfWcjQC7Y53yHYNEgGLQwgdcGA1UdIwSBzzCBzIAUbDEDfqkUfWcjQC7Y53yHYNEg\nGLShgaikgaUwgaIxCzAJBgNVBAYTAlNFMRUwEwYDVQQIEwxWYXN0ZXJib3R0ZW4x\nDTALBgNVBAcTBFVtZWExGTAXBgNVBAoTEFVtZWEgdW5pdmVyc2l0ZXQxDDAKBgNV\nBAsTA0lUUzEcMBoGA1UEAxMTc3Auc3RyaWtlLmFkLnVtdS5zZTEmMCQGCSqGSIb3\nDQEJARYXZGF0b3JkcmlmdEB1bWRhYy51bXUuc2WCCQDYKfRuYGV/+zAMBgNVHRME\nBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAVvAHw6N0vq1/WK6Xgu63vgI3Y6E62\nioR3z4ysf0RMFCO1X3t3ZV119uINUKcV8IOsQL4yaSSPk25kAd+WELjX03pRfbzx\npr07qZjmDGQ4+NXeEfQzHNS1ONmWB5ehb07q+BQ3NBO9fNecboLqhKXO4aY6DGd8\n6sUsvhBBTHjDBoIe7VuIA53XdUCLFfvS/SwDBJOPfQeSg+16uzMWF7wpF+xFhvWn\nPyekLl4nWhrS6lKYrMdR4u5gQI8nzSycLqHiWrC3ftlFEYpEau1MskWdOAAd3r8q\nlI1794b9Dm6mV7L0EhmDNsX6gIy5lHdW5rfaW9gTZdImBpGECbBQlehm"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=datordrift@umdac.umu.se,CN=sp.strike.ad.umu.se,OU=ITS,O=Umea universitet,L=Umea,ST=Vasterbotten,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "sp.strike.ad.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE1jCCA76gAwIBAgIJANgp9G5gZX/7MA0GCSqGSIb3DQEBBQUAMIGiMQswCQYD\nVQQGEwJTRTEVMBMGA1UECBMMVmFzdGVyYm90dGVuMQ0wCwYDVQQHEwRVbWVhMRkw\nFwYDVQQKExBVbWVhIHVuaXZlcnNpdGV0MQwwCgYDVQQLEwNJVFMxHDAaBgNVBAMT\nE3NwLnN0cmlrZS5hZC51bXUuc2UxJjAkBgkqhkiG9w0BCQEWF2RhdG9yZHJpZnRA\ndW1kYWMudW11LnNlMB4XDTExMDIxMDEzMjI0MVoXDTEzMTIyNDEzMjI0MVowgaIx\nCzAJBgNVBAYTAlNFMRUwEwYDVQQIEwxWYXN0ZXJib3R0ZW4xDTALBgNVBAcTBFVt\nZWExGTAXBgNVBAoTEFVtZWEgdW5pdmVyc2l0ZXQxDDAKBgNVBAsTA0lUUzEcMBoG\nA1UEAxMTc3Auc3RyaWtlLmFkLnVtdS5zZTEmMCQGCSqGSIb3DQEJARYXZGF0b3Jk\ncmlmdEB1bWRhYy51bXUuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQD3cDW3/Z5H0wDknkiHATmn5+pSap07JCNKUrwBQZquE2Nfr3Idw83A3qMUwY7Z\nEW1jQU69j363dqGv9Ypc8ViQ9jSR5+O9iTaMYIpJHJSiFju3wFHbwZMJckFdsRjt\njsWCdh1EGU/oJP0HdijvDtr1eM6VjeB3a3oEOlN9ECPkGAR03m+O8CPviRSSwXJD\nyvtJKgBNy6U3t2o13L1i7xgvNNcywRu4vtdkt5K+NI/P7C0H/j1DzAbZzqfyJhBO\nKPW1X2Wetk6nubsw49k2XnRUFkqamvSe6shL4492cwRYpxmKTX+e/RUde0+Ve7VS\n0VaD9+9utUzO/kG/cOeXtzsDAgMBAAGjggELMIIBBzAdBgNVHQ4EFgQUbDEDfqkU\nfWcjQC7Y53yHYNEgGLQwgdcGA1UdIwSBzzCBzIAUbDEDfqkUfWcjQC7Y53yHYNEg\nGLShgaikgaUwgaIxCzAJBgNVBAYTAlNFMRUwEwYDVQQIEwxWYXN0ZXJib3R0ZW4x\nDTALBgNVBAcTBFVtZWExGTAXBgNVBAoTEFVtZWEgdW5pdmVyc2l0ZXQxDDAKBgNV\nBAsTA0lUUzEcMBoGA1UEAxMTc3Auc3RyaWtlLmFkLnVtdS5zZTEmMCQGCSqGSIb3\nDQEJARYXZGF0b3JkcmlmdEB1bWRhYy51bXUuc2WCCQDYKfRuYGV/+zAMBgNVHRME\nBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAVvAHw6N0vq1/WK6Xgu63vgI3Y6E62\nioR3z4ysf0RMFCO1X3t3ZV119uINUKcV8IOsQL4yaSSPk25kAd+WELjX03pRfbzx\npr07qZjmDGQ4+NXeEfQzHNS1ONmWB5ehb07q+BQ3NBO9fNecboLqhKXO4aY6DGd8\n6sUsvhBBTHjDBoIe7VuIA53XdUCLFfvS/SwDBJOPfQeSg+16uzMWF7wpF+xFhvWn\nPyekLl4nWhrS6lKYrMdR4u5gQI8nzSycLqHiWrC3ftlFEYpEau1MskWdOAAd3r8q\nlI1794b9Dm6mV7L0EhmDNsX6gIy5lHdW5rfaW9gTZdImBpGECbBQlehm"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=datordrift@umdac.umu.se,CN=sp.strike.ad.umu.se,OU=ITS,O=Umea universitet,L=Umea,ST=Vasterbotten,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.example.org/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.example.org/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.example.org/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.example.org/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.example.org/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp.example.org/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.example.org/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp.example.org/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp.example.org/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp.example.org/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-p12.ladok.umu.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-p12.ladok.umu.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p12.ladok.umu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p12.ladok.umu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p12.ladok.umu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p12.ladok.umu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p12.ladok.umu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-p12.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-p12.ladok.umu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem ladok3#x2011;p12"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite ladok3#x2011;p12"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-p12.ladok.umu.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-p12.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIJAIwqpqrS/3KqMA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2xhZG9rMy1wMTIubGFkb2sudW11LnNlMB4XDTE1MDIwOTEwNDE0NFoXDTI1\nMDIwNjEwNDE0NFowIjEgMB4GA1UEAxMXbGFkb2szLXAxMi5sYWRvay51bXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDTjX8ROOs9AYI7Id93/jMB\nMjSy3sJ0SkoU+xFYZMCwgEO87sbsHLCqWNyf/0jCYTHsJz3PSwD5jRfh0s54mGIP\nrx1DD1YyennMWU/ipJE3jNv7BTgsF00GnJMpAqVuKAh0hRhHsggdh1fg4va17QdN\n8GZr1kIhloV8NDH0z7PkpnEZgq9PvQdE0IwC7x4Mh36hpwF6yLLr06YlldbY2ym+\nfI/aq8ByM09YxgKKOshat22lcPD1Qp4hhCtvkUgNhPe1rasRZXkGM8C9idSEKQLe\n+K84hbsexa2XV0NbN/U0YEgbM/WBRf14GJ4hURmIqbDnI5uwvhmxHb8oVwTX6pS3\nAgMBAAGjbTBrMEoGA1UdEQRDMEGCF2xhZG9rMy1wMTIubGFkb2sudW11LnNlhiZo\ndHRwczovL2xhZG9rMy1wMTIubGFkb2sudW11LnNlL2d1aS1zcDAdBgNVHQ4EFgQU\niBjBC45eIXnO2+70Uuag5jO5z9wwDQYJKoZIhvcNAQEFBQADggEBAChVgBB3wewy\nSULV85zs/mbAVo4kjUhB1EKiKGqT1RXtrzSU16JGoXmqOSJYS0A05FdTv999l5Dt\nv0YueU/iPRi7dEfNeaVYotSDhRhZP+rsUr1mMoNlXMqTU90vwifp38XLyB35NpcJ\njS1+OY/qw50nx/wgtjObE5fUTahgD+bIayH1yiPqJ/oV70o/mbFNzKlQfKZUycPZ\nNT+5a1QA5NljIzDleDAasFdAIQsp5MaNReM/anzT2jVyJi1ck1AhjQ0aSvmMnoAf\n8vY2VZYR47AClkyOv+lyxqUscUTCfm4zELzhn9LqxMGp+c2h9ATk3JOXzFXWMWUh\nmG1iR8k9mTI="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-p12.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p12.ladok.umu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p12.ladok.umu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p12.ladok.umu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p12.ladok.umu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p12.ladok.umu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p12.ladok.umu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-p12.ladok.umu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-p12.ladok.umu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-p12.ladok.umu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cardshibidp.cardonald.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "MacCormick"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:gmaccormick@glasgowclyde.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Graeme"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@glasgowclyde.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Cardonald College Service Desk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cardshibidp.cardonald.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDajCCAlICCQDmyaTj/dnWQTANBgkqhkiG9w0BAQUFADB3MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEQMA4GA1UECBMHR2xhc2dvdzEQMA4GA1UEBxMHR2xhc2dvdzEeMBwGA1UEChMV\n\t\t\t\t\t\tR2xhc2dvdyBDbHlkZSBDb2xsZWdlMSQwIgYDVQQDExtjYXJkc2hpYmlkcC5jYXJk\n\t\t\t\t\t\tb25hbGQuYWMudWswHhcNMTQwNDA5MDkxNzA3WhcNMzQwNDA0MDkxNzA3WjB3MQsw\n\t\t\t\t\t\tCQYDVQQGEwJHQjEQMA4GA1UECBMHR2xhc2dvdzEQMA4GA1UEBxMHR2xhc2dvdzEe\n\t\t\t\t\t\tMBwGA1UEChMVR2xhc2dvdyBDbHlkZSBDb2xsZWdlMSQwIgYDVQQDExtjYXJkc2hp\n\t\t\t\t\t\tYmlkcC5jYXJkb25hbGQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\n\t\t\t\t\t\tAoIBAQDUBR0+1loJ3T9kkKMKAs/KLAO8pXDtAeNpjNTFGwFRGQOI//gLgeNi3eGn\n\t\t\t\t\t\tt6nBLcaqAZqVIjsnCkPsIZH5I8L9WXcg3Xrg1+X1PRdBWWicGyizbqqOqeufH2Jz\n\t\t\t\t\t\twuhXwEK6DQk2seKkduZtNkxwDELyQGs8U0muyb3/OnJ3KhvBfDIHtm7M0yVFtG2G\n\t\t\t\t\t\trE9D4AR6WY4bS2vQwK0dhiGKmPdhL1PpMhbK5spFiCHC9RLpbkKuhAC8ZmUHeCFT\n\t\t\t\t\t\t5M3Y0SqckKXu1n1nzhIOIlcRFP+P1FBWDFZ5hPm+3el/I12jm129H8VVeWjTOhr6\n\t\t\t\t\t\tOabPJQiJcOZ7s1iDg+BezNU5v/KzAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBALQN\n\t\t\t\t\t\tt30jSUt1DO6lkHtPVJUX3lnMUurAOX2ko9P2zwk3kKIiu4hgyjNiKJFRm4vmHNWB\n\t\t\t\t\t\tqpv/zK0dGUFToqHcEU79sCQ3YUKNC3b+s8jE8NQe+lUmxsF4KqYo1SUamwLO9SbF\n\t\t\t\t\t\tHiLXKmL+8/laltXrjKszX97RBFQakC5IuzrO6k2nzrU7i2E+NkwxqdFkQrwilmq3\n\t\t\t\t\t\tK2Ieb7y2Bke7GLZHE6F64clptrsVkgXXjcX3mmzkG03i8aSVUqEUJgy1z8NcpH/m\n\t\t\t\t\t\t54/ncBcKbY9hfoeAr4T4jkFePzJA1+UcnXTBR+SyYGLsjh1u/VG76kwAnwKR+Zyd\n\t\t\t\t\t\t0qFR8jsJAPaduHvbjU8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cardonald.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cardshibidp.cardonald.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cardshibidp.cardonald.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cardshibidp.cardonald.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cardshibidp.cardonald.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cardshibidp.cardonald.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cardshibidp.cardonald.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cardshibidp.cardonald.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cardshibidp.cardonald.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cardonald.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDajCCAlICCQDmyaTj/dnWQTANBgkqhkiG9w0BAQUFADB3MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEQMA4GA1UECBMHR2xhc2dvdzEQMA4GA1UEBxMHR2xhc2dvdzEeMBwGA1UEChMV\n\t\t\t\t\t\tR2xhc2dvdyBDbHlkZSBDb2xsZWdlMSQwIgYDVQQDExtjYXJkc2hpYmlkcC5jYXJk\n\t\t\t\t\t\tb25hbGQuYWMudWswHhcNMTQwNDA5MDkxNzA3WhcNMzQwNDA0MDkxNzA3WjB3MQsw\n\t\t\t\t\t\tCQYDVQQGEwJHQjEQMA4GA1UECBMHR2xhc2dvdzEQMA4GA1UEBxMHR2xhc2dvdzEe\n\t\t\t\t\t\tMBwGA1UEChMVR2xhc2dvdyBDbHlkZSBDb2xsZWdlMSQwIgYDVQQDExtjYXJkc2hp\n\t\t\t\t\t\tYmlkcC5jYXJkb25hbGQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\n\t\t\t\t\t\tAoIBAQDUBR0+1loJ3T9kkKMKAs/KLAO8pXDtAeNpjNTFGwFRGQOI//gLgeNi3eGn\n\t\t\t\t\t\tt6nBLcaqAZqVIjsnCkPsIZH5I8L9WXcg3Xrg1+X1PRdBWWicGyizbqqOqeufH2Jz\n\t\t\t\t\t\twuhXwEK6DQk2seKkduZtNkxwDELyQGs8U0muyb3/OnJ3KhvBfDIHtm7M0yVFtG2G\n\t\t\t\t\t\trE9D4AR6WY4bS2vQwK0dhiGKmPdhL1PpMhbK5spFiCHC9RLpbkKuhAC8ZmUHeCFT\n\t\t\t\t\t\t5M3Y0SqckKXu1n1nzhIOIlcRFP+P1FBWDFZ5hPm+3el/I12jm129H8VVeWjTOhr6\n\t\t\t\t\t\tOabPJQiJcOZ7s1iDg+BezNU5v/KzAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBALQN\n\t\t\t\t\t\tt30jSUt1DO6lkHtPVJUX3lnMUurAOX2ko9P2zwk3kKIiu4hgyjNiKJFRm4vmHNWB\n\t\t\t\t\t\tqpv/zK0dGUFToqHcEU79sCQ3YUKNC3b+s8jE8NQe+lUmxsF4KqYo1SUamwLO9SbF\n\t\t\t\t\t\tHiLXKmL+8/laltXrjKszX97RBFQakC5IuzrO6k2nzrU7i2E+NkwxqdFkQrwilmq3\n\t\t\t\t\t\tK2Ieb7y2Bke7GLZHE6F64clptrsVkgXXjcX3mmzkG03i8aSVUqEUJgy1z8NcpH/m\n\t\t\t\t\t\t54/ncBcKbY9hfoeAr4T4jkFePzJA1+UcnXTBR+SyYGLsjh1u/VG76kwAnwKR+Zyd\n\t\t\t\t\t\t0qFR8jsJAPaduHvbjU8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Glasgow Clyde College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cardonald.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Glasgow Clyde College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.st-andrews.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Brannen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dbb@st-andrews.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Duncan"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Brannen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dbb@st-andrews.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Duncan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.st-andrews.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-01-16T14:59:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFTDCCBDSgAwIBAgICEKgwDQYJKoZIhvcNAQEFBQAwgbsxCzAJBgNVBAYTAlVL\n\t\t\t\t\t\tMQ0wCwYDVQQIEwRGaWZlMRMwEQYDVQQHEwpTdCBBbmRyZXdzMSEwHwYDVQQKExhV\n\t\t\t\t\t\tbml2ZXJzaXR5IG9mIFN0IEFuZHJld3MxFjAUBgNVBAsTDUkuVC4gU2VydmljZXMx\n\t\t\t\t\t\tIzAhBgNVBAMTGk1hc3RlciBTaWduaW5nIENlcnRpZmljYXRlMSgwJgYJKoZIhvcN\n\t\t\t\t\t\tAQkBFhloZWxwZGVza0BzdC1hbmRyZXdzLmFjLnVrMB4XDTE0MDUyODEwMjI0OVoX\n\t\t\t\t\t\tDTM0MDUyMzEwMjI0OVowgYsxCzAJBgNVBAYTAkdCMQ0wCwYDVQQIEwRGaWZlMRMw\n\t\t\t\t\t\tEQYDVQQHEwpTdCBBbmRyZXdzMSEwHwYDVQQKExhVbml2ZXJzaXR5IG9mIFN0IEFu\n\t\t\t\t\t\tZHJld3MxFDASBgNVBAsTC0lUIFNlcnZpY2VzMR8wHQYDVQQDExZsb2dpbi5zdC1h\n\t\t\t\t\t\tbmRyZXdzLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtrVW\n\t\t\t\t\t\tAoC2c9E11GatKp3M8sFYhgsnPX1rdZ8bToP6y9uzQlKn7CSbzgY/MFTT1ol/dIpw\n\t\t\t\t\t\tQFXqGBdNomQtaE3S2v81k30E2/nR294xEeT/PjP9GcPxYJjBq/ngoTzmBC6TJtsj\n\t\t\t\t\t\tDWYWQEPUoMhgQ1Rqlhm2+rEJWY/AbdzZWjZiCS1P6W6uxw9/lPLLSAkSQSLGiavu\n\t\t\t\t\t\tuyRmogqgH/HOzVFlF/DwKFZJDZ/bWGv1WHc6rii8nl8K9I1zZoM0sIPBnfrdWZzN\n\t\t\t\t\t\tSAhX9zMSv1EXTJ0VFD3nrElU/Xx8WO4ZosnDwL7R+w6TZ1b+yOmc/A4ZsKQECxd/\n\t\t\t\t\t\tLYcLPfbhgK2hhrApPQIDAQABo4IBhjCCAYIwCQYDVR0TBAIwADAsBglghkgBhvhC\n\t\t\t\t\t\tAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFIKd\n\t\t\t\t\t\tmF6wLnFmysL7I3lf1Z5UI+KIMIHwBgNVHSMEgegwgeWAFEVZKa2Kkeq6fIItSmOm\n\t\t\t\t\t\t9juqqJOToYHBpIG+MIG7MQswCQYDVQQGEwJVSzENMAsGA1UECBMERmlmZTETMBEG\n\t\t\t\t\t\tA1UEBxMKU3QgQW5kcmV3czEhMB8GA1UEChMYVW5pdmVyc2l0eSBvZiBTdCBBbmRy\n\t\t\t\t\t\tZXdzMRYwFAYDVQQLEw1JLlQuIFNlcnZpY2VzMSMwIQYDVQQDExpNYXN0ZXIgU2ln\n\t\t\t\t\t\tbmluZyBDZXJ0aWZpY2F0ZTEoMCYGCSqGSIb3DQEJARYZaGVscGRlc2tAc3QtYW5k\n\t\t\t\t\t\tcmV3cy5hYy51a4IJALjpP8s3OebbMDUGCWCGSAGG+EIBBAQoFiZodHRwOi8vd3d3\n\t\t\t\t\t\tLnN0LWFuZHJld3MuYWMudWsvY2EtY3JsLnBlbTANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tj9HmQMvf9ZWP0RSRvxvPG9esUh/D3QpsVw4Q0NmH0iH3CO+KEAuskwRi4Oy0P7kG\n\t\t\t\t\t\tgYIdgRp9upn2lqn70mNU6B040YG7gB8cCckNFcTguwBjgiwahzXuF8xbpHCbDQRh\n\t\t\t\t\t\t/Npkb4niRx8bk0HrR4qH0E9xNNcts0mIwwvPZeSyfgh28y2b5lE1O7pr417xevjN\n\t\t\t\t\t\tpx1V63hOos/k1jZwLjGX7mf4uNqY2X27muoWxncx5bdljRrI+7KueS6vIaGvvy+O\n\t\t\t\t\t\tahQL5K+/ebdMh89ffv7SK9aDp/RPJu77ggTRXK0+fKkoy9JJYX/mh99r5cClGhGs\n\t\t\t\t\t\t3nwOT+n5Ge0J+NSey+6Otg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "st-andrews.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.st-andrews.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.st-andrews.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.st-andrews.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.st-andrews.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.st-andrews.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.st-andrews.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://login.st-andrews.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.st-andrews.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "st-andrews.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFTDCCBDSgAwIBAgICEKgwDQYJKoZIhvcNAQEFBQAwgbsxCzAJBgNVBAYTAlVL\n\t\t\t\t\t\tMQ0wCwYDVQQIEwRGaWZlMRMwEQYDVQQHEwpTdCBBbmRyZXdzMSEwHwYDVQQKExhV\n\t\t\t\t\t\tbml2ZXJzaXR5IG9mIFN0IEFuZHJld3MxFjAUBgNVBAsTDUkuVC4gU2VydmljZXMx\n\t\t\t\t\t\tIzAhBgNVBAMTGk1hc3RlciBTaWduaW5nIENlcnRpZmljYXRlMSgwJgYJKoZIhvcN\n\t\t\t\t\t\tAQkBFhloZWxwZGVza0BzdC1hbmRyZXdzLmFjLnVrMB4XDTE0MDUyODEwMjI0OVoX\n\t\t\t\t\t\tDTM0MDUyMzEwMjI0OVowgYsxCzAJBgNVBAYTAkdCMQ0wCwYDVQQIEwRGaWZlMRMw\n\t\t\t\t\t\tEQYDVQQHEwpTdCBBbmRyZXdzMSEwHwYDVQQKExhVbml2ZXJzaXR5IG9mIFN0IEFu\n\t\t\t\t\t\tZHJld3MxFDASBgNVBAsTC0lUIFNlcnZpY2VzMR8wHQYDVQQDExZsb2dpbi5zdC1h\n\t\t\t\t\t\tbmRyZXdzLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtrVW\n\t\t\t\t\t\tAoC2c9E11GatKp3M8sFYhgsnPX1rdZ8bToP6y9uzQlKn7CSbzgY/MFTT1ol/dIpw\n\t\t\t\t\t\tQFXqGBdNomQtaE3S2v81k30E2/nR294xEeT/PjP9GcPxYJjBq/ngoTzmBC6TJtsj\n\t\t\t\t\t\tDWYWQEPUoMhgQ1Rqlhm2+rEJWY/AbdzZWjZiCS1P6W6uxw9/lPLLSAkSQSLGiavu\n\t\t\t\t\t\tuyRmogqgH/HOzVFlF/DwKFZJDZ/bWGv1WHc6rii8nl8K9I1zZoM0sIPBnfrdWZzN\n\t\t\t\t\t\tSAhX9zMSv1EXTJ0VFD3nrElU/Xx8WO4ZosnDwL7R+w6TZ1b+yOmc/A4ZsKQECxd/\n\t\t\t\t\t\tLYcLPfbhgK2hhrApPQIDAQABo4IBhjCCAYIwCQYDVR0TBAIwADAsBglghkgBhvhC\n\t\t\t\t\t\tAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYDVR0OBBYEFIKd\n\t\t\t\t\t\tmF6wLnFmysL7I3lf1Z5UI+KIMIHwBgNVHSMEgegwgeWAFEVZKa2Kkeq6fIItSmOm\n\t\t\t\t\t\t9juqqJOToYHBpIG+MIG7MQswCQYDVQQGEwJVSzENMAsGA1UECBMERmlmZTETMBEG\n\t\t\t\t\t\tA1UEBxMKU3QgQW5kcmV3czEhMB8GA1UEChMYVW5pdmVyc2l0eSBvZiBTdCBBbmRy\n\t\t\t\t\t\tZXdzMRYwFAYDVQQLEw1JLlQuIFNlcnZpY2VzMSMwIQYDVQQDExpNYXN0ZXIgU2ln\n\t\t\t\t\t\tbmluZyBDZXJ0aWZpY2F0ZTEoMCYGCSqGSIb3DQEJARYZaGVscGRlc2tAc3QtYW5k\n\t\t\t\t\t\tcmV3cy5hYy51a4IJALjpP8s3OebbMDUGCWCGSAGG+EIBBAQoFiZodHRwOi8vd3d3\n\t\t\t\t\t\tLnN0LWFuZHJld3MuYWMudWsvY2EtY3JsLnBlbTANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tj9HmQMvf9ZWP0RSRvxvPG9esUh/D3QpsVw4Q0NmH0iH3CO+KEAuskwRi4Oy0P7kG\n\t\t\t\t\t\tgYIdgRp9upn2lqn70mNU6B040YG7gB8cCckNFcTguwBjgiwahzXuF8xbpHCbDQRh\n\t\t\t\t\t\t/Npkb4niRx8bk0HrR4qH0E9xNNcts0mIwwvPZeSyfgh28y2b5lE1O7pr417xevjN\n\t\t\t\t\t\tpx1V63hOos/k1jZwLjGX7mf4uNqY2X27muoWxncx5bdljRrI+7KueS6vIaGvvy+O\n\t\t\t\t\t\tahQL5K+/ebdMh89ffv7SK9aDp/RPJu77ggTRXK0+fKkoy9JJYX/mh99r5cClGhGs\n\t\t\t\t\t\t3nwOT+n5Ge0J+NSey+6Otg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of St Andrews"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.st-andrews.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of St Andrews"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibbsrv1.gsa.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Meldrum"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:s.meldrum@gsa.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sid"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Meldrum"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:s.meldrum@gsa.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sid"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibbsrv1.gsa.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWjCCAkICCQCivWPQEvRbljANBgkqhkiG9w0BAQUFADBvMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEQMA4GA1UECBMHR2xhc2dvdzEXMBUGA1UEBxMOUmVuZnJldyBTdHJlZXQxFzAV\n\t\t\t\t\t\tBgNVBAoTDlJlbmZyZXcgU3RyZWV0MRwwGgYDVQQDExNzaGliYnNydjEuZ3NhLmFj\n\t\t\t\t\t\tLnVrMB4XDTEzMDQxMDE0Mjc1MloXDTMzMDQwNTE0Mjc1MlowbzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEDAOBgNVBAgTB0dsYXNnb3cxFzAVBgNVBAcTDlJlbmZyZXcgU3RyZWV0MRcw\n\t\t\t\t\t\tFQYDVQQKEw5SZW5mcmV3IFN0cmVldDEcMBoGA1UEAxMTc2hpYmJzcnYxLmdzYS5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMyvtXXL1ZjqGV45\n\t\t\t\t\t\tQRqdOrqXaX+trM2srXsh74k8UfivA5QxDAho548YVlcdmnm/d1kSTYSIHzD1IZu0\n\t\t\t\t\t\t1HD2X3RehRORQTiejQQl+KfZa3HNwVc96PqkQ3UDmsTLwkzCnKToto3SVqEmflGG\n\t\t\t\t\t\tibj1SUA8kr/4kYmO/EZEIyhDq0dWYlx4iMQGHoUUHUp1FBDFRfOffBjUVyoDGzbM\n\t\t\t\t\t\tcZesKVyJLIMuwZdWYm8diYnQggNHw17N0t/FsgKbUnPA1Wj2w5bE2sObR/eGCRv1\n\t\t\t\t\t\t/QgiPvuW0qawibwgfdNYr+u6x8ZB9D1CA5xwSAmLhxDxAG8Vn34e/j51doS1ET5U\n\t\t\t\t\t\trR071ccCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAzBfS3T2zWUe+nCXopLOASUxv\n\t\t\t\t\t\tJzx4WHXsLbuR5I9dA/l1GXdQkgswDwMvSBh+eP6bLe2qncKOys/2QLx2R1g/ata2\n\t\t\t\t\t\tdxACjh5t68Aca5xKfxD4Axnyzu2j0aW3CojrR0SlzIAiXEWzQAOwUM9FtEYfrcDc\n\t\t\t\t\t\tSauS3ziuUbHzzLufHrnuKOvzyTv/6acMNnlL4JZQPTUtMluzdNxApbsndvYuOty+\n\t\t\t\t\t\tyhnJqONwsMlgVqghAmHILD54ZgEsBUX+drhMVu7+Vk0tocvfr5SDmp5yfB2zl2RV\n\t\t\t\t\t\tZAsbj5IQmyAuMRF3AnM7837HCnvjO/89bCjODt286HBAvPgyRFbHiUpruf3F+A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gsa.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibbsrv1.gsa.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibbsrv1.gsa.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibbsrv1.gsa.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibbsrv1.gsa.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibbsrv1.gsa.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibbsrv1.gsa.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibbsrv1.gsa.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibbsrv1.gsa.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "gsa.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDWjCCAkICCQCivWPQEvRbljANBgkqhkiG9w0BAQUFADBvMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEQMA4GA1UECBMHR2xhc2dvdzEXMBUGA1UEBxMOUmVuZnJldyBTdHJlZXQxFzAV\n\t\t\t\t\t\tBgNVBAoTDlJlbmZyZXcgU3RyZWV0MRwwGgYDVQQDExNzaGliYnNydjEuZ3NhLmFj\n\t\t\t\t\t\tLnVrMB4XDTEzMDQxMDE0Mjc1MloXDTMzMDQwNTE0Mjc1MlowbzELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEDAOBgNVBAgTB0dsYXNnb3cxFzAVBgNVBAcTDlJlbmZyZXcgU3RyZWV0MRcw\n\t\t\t\t\t\tFQYDVQQKEw5SZW5mcmV3IFN0cmVldDEcMBoGA1UEAxMTc2hpYmJzcnYxLmdzYS5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMyvtXXL1ZjqGV45\n\t\t\t\t\t\tQRqdOrqXaX+trM2srXsh74k8UfivA5QxDAho548YVlcdmnm/d1kSTYSIHzD1IZu0\n\t\t\t\t\t\t1HD2X3RehRORQTiejQQl+KfZa3HNwVc96PqkQ3UDmsTLwkzCnKToto3SVqEmflGG\n\t\t\t\t\t\tibj1SUA8kr/4kYmO/EZEIyhDq0dWYlx4iMQGHoUUHUp1FBDFRfOffBjUVyoDGzbM\n\t\t\t\t\t\tcZesKVyJLIMuwZdWYm8diYnQggNHw17N0t/FsgKbUnPA1Wj2w5bE2sObR/eGCRv1\n\t\t\t\t\t\t/QgiPvuW0qawibwgfdNYr+u6x8ZB9D1CA5xwSAmLhxDxAG8Vn34e/j51doS1ET5U\n\t\t\t\t\t\trR071ccCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAzBfS3T2zWUe+nCXopLOASUxv\n\t\t\t\t\t\tJzx4WHXsLbuR5I9dA/l1GXdQkgswDwMvSBh+eP6bLe2qncKOys/2QLx2R1g/ata2\n\t\t\t\t\t\tdxACjh5t68Aca5xKfxD4Axnyzu2j0aW3CojrR0SlzIAiXEWzQAOwUM9FtEYfrcDc\n\t\t\t\t\t\tSauS3ziuUbHzzLufHrnuKOvzyTv/6acMNnlL4JZQPTUtMluzdNxApbsndvYuOty+\n\t\t\t\t\t\tyhnJqONwsMlgVqghAmHILD54ZgEsBUX+drhMVu7+Vk0tocvfr5SDmp5yfB2zl2RV\n\t\t\t\t\t\tZAsbj5IQmyAuMRF3AnM7837HCnvjO/89bCjODt286HBAvPgyRFbHiUpruf3F+A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Glasgow School of Art (MyGSA)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.gsa.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Glasgow School of Art"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ekrksso.keeleressursid.ee/simplesaml/module.php/saml/sp/metadata.php/ekrk-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jesmin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lauri.jesmin@ut.ee"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Lauri"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ekrksso.keeleressursid.ee/simplesaml/module.php/saml/sp/metadata.php/ekrk-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-05-15T09:54:53Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://clarin.eu/category/clarin-member"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ekrksso.keeleressursid.ee/simplesaml/module.php/saml/sp/saml2-logout.php/ekrk-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://keeleressursid.ee/en/"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CELR Dienste"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CELR services"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://193.40.5.27/display/keeleressursid/Privacy+Policy+of+Center+of+Estonian+Language+Resources"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CELR Dienste"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CELR services"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ekrksso.keeleressursid.ee"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfzCCA2egAwIBAgIQEHEZOlxMPA1OJ+5lCLnyNTANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMTIwNjAwMDAwMFoXDTE2MTIwNTIzNTk1OVowRzEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMSIwIAYDVQQDExlla3Jrc3NvLmtl\nZWxlcmVzc3Vyc2lkLmVlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\nwDXZTjKFPgzC8w22Bfp7cvTj3cRFBACW4i5yhCG+oK+sT69WDhlMq1chr2tOUhgX\nu9ASJvS2ZZ2qKp+vX28GqQFQbyLARF4Lr93tA0if8NYPm5oi9ZLB9iPUvRHrdiEA\nA3jjMZ2TNqHEIsxJdJUWg4mtuaorwqjZn8qZ3mT8ia3qgIRJsAXzcO2MimvGmbWI\nl0l1u8bDD316+r3YZH6UkgASjAsv6iOsUE1VNU8Qd4cOG60BseupUFAAwK20zj8i\nupV4gXr8F+n+CFiLFui8pFXPrVND5SHPltWjlTprOaUv7aNaSUMMtetFsjvHQXQZ\nln43JTlb12uZes+Oe9524wIDAQABo4IBdjCCAXIwHwYDVR0jBBgwFoAUDL2TaAzz\n3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFJqexvFu3FAXf3v9yEN07/a3hEbdMA4G\nA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMB\nBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6\nBgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVO\nQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9j\ncnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpo\ndHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAkBgNVHREEHTAbghlla3Jrc3NvLmtl\nZWxlcmVzc3Vyc2lkLmVlMA0GCSqGSIb3DQEBBQUAA4IBAQCuuAWKbmr7yefGwYa1\nMvN/4O8L40d8SD5AF9GcRjjh7Azgf76xwG4wDtU41NFnBd+glWBUEYwM/YLzODwQ\nWx46wW1FTRRwvmhId84J4AY+lFN/8Nv+iqQtS3PrdJu80wO9Lv8E7vWoi8yvL3bP\nmqBGjE3i4Pu03DisLwOZkGsrc8ngz5y/MWTLyZTkkBfalnaeusTzOeD36BV9xdtb\nnbjONxJYVASTlEUjqsj+Q2duXJw/ORjMlQ4bSi7fFNp0aM6RLXRNIMUNevkzz/Sv\n93XHII/BZkp4Tc6bqqZc8oQzV737EHHj49GvG6xVjQ2gY0E6K++MhI+3H31o24ib\n+w26"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ekrksso.keeleressursid.ee,OU=Domain Control Validated"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ekrksso.keeleressursid.ee/simplesaml/module.php/saml/sp/saml2-acs.php/ekrk-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ekrksso.keeleressursid.ee/simplesaml/module.php/saml/sp/saml1-acs.php/ekrk-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ekrksso.keeleressursid.ee/simplesaml/module.php/saml/sp/saml2-acs.php/ekrk-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ekrksso.keeleressursid.ee/simplesaml/module.php/saml/sp/saml1-acs.php/ekrk-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CELR Dienste"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "CELR services"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "CELR Dienste"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "CELR services"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "cn",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "o",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.nhl.nl/",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.nhl.nl/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-05-01T16:00:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/956bebc4302f328ea5722d84005d17ef",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "NHL Hogeschool"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "NHL Hogeschool"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/nhl.png",
                    "height": "47",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "68"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NHL Hogeschool"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "NHL Hogeschool"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NHL Hogeschool"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nhl.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NHL Hogeschool"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-05.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-05.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-05.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-05.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-05.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-05.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-05.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-05.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-05.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;05"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;05"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-05.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-05.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAOtHsdcqv/rDMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wNS5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTQzOTM2WhcNMjQx\nMDA0MTQzOTM2WjAhMR8wHQYDVQQDExZsYWRvazMtMDUubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA8+pPNqjRUNAPWYZ0S8+nNEem\nOzveLIubT9EsqBx6xV8mWv3th3Uk/Vi8AGQhsaKH83yNUQYnaBHEPwyBexeqTRPl\neQd0d660dheQacDxOHrp8z8QMkCCXAXA/xsnJ0+P2W8A0sbyAn6dAEH3cQNnCH+W\n9gDdHOrgztt8uLeIjGkUFpU0oeL5sHh9LWShcMT1lSnbEAQ97ArN60hFHzFVpebJ\nABiY+2jHo+74yOrpU6sE0WWpPAFKQhDEDNNOMeaSrV/cOxp+q7U2x2mTU8F1pWVT\nVg2zzgyv3OW0U+ohb5DGTWEA5M0h6flIP2iZzhlZeeppkPFPxPyeBkLm1aAdyQID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMDUubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0wNS5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQU8ZmWu90VLpnQ9ljpSueBe5a1WpkwDQYJKoZIhvcNAQEFBQADggEB\nAA3+A4hEH+KGBrY6XhgJpKBTfhtTrkkpniEIeUzycPg2bExIypb1WNNY2XdGB3eM\nTcTrmIUPwjJQDrd+5xU/oH+cxUlYco7bSP5isFzJO9GP48dDA+Mwh+tVkBti9A9f\nADXVB0/0ulpv0LMw1efxkhLUWYrNcvkFhcbdCuXI5a7VQ1bAs8YK3oPiHamfAJhs\nVW54fH2lNhf9+FZTZjJ44HRiVrmvG9qzMQkprABKehZAdXOU30A7M1SMheujqfRM\nC6PyjKalJKJ5+Dozdnw9O8O8AahzAOfS6rgV2cN5cJek56UEEufuFFpYhsI+2R98\n+FU9YfjsJUnp69MHPt1J/fI="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-05.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-05.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-05.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-05.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-05.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-05.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-05.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-05.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-05.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-05.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibb.stockport.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bahrt"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:nichole.bahrt@stockport.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Nichole"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Smith"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:michael.smith@stockport.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mike"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Doherty"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Patrick.Doherty@Stockport.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Patrick"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Comer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Robert.Comer@Stockport.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Robert"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibb.stockport.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-05-20T11:53:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUM+WxIbWXv2I74/FnfG6jjwU+Ri0wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwIDEeMBwGA1UEAxMVc2hpYmIuc3RvY2twb3J0LmFjLnVrMB4XDTExMDUwNjE0\n\t\t\t\t\t\tMDAyM1oXDTMxMDUwNjE0MDAyM1owIDEeMBwGA1UEAxMVc2hpYmIuc3RvY2twb3J0\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAifpJBo9UYsko\n\t\t\t\t\t\tkMULJTlBmVICnEZWWnlX3XFNf3aUtkOYW5EgGgwro1jR0irV252k/WIThep4ozjI\n\t\t\t\t\t\tC31suuhrKVUtPggMVaP7LxXcEvO7FP2fc++yqvpUYs8h4kJylmy5J4UX6MlSqM7W\n\t\t\t\t\t\tLcyH3SOPeQkh/XEGdsNcxphhaXHMhyCEsB5xESYyp0tMFh7bjX9+YjBMxnoWu7iz\n\t\t\t\t\t\tZk/+bxP2lgaQA1DayxgvhSEsvdSJkxCerjPnPrGv6f0pVN2exDCOpwsFPPQWsCIC\n\t\t\t\t\t\t0BQnqbxqf/ONpBUCi2fJHFEqNHIh+YBfLBqSOpPqIkhAlXnAlYVfP3/oJ/zaIHoG\n\t\t\t\t\t\tTKp2AP62pQIDAQABo3EwbzBOBgNVHREERzBFghVzaGliYi5zdG9ja3BvcnQuYWMu\n\t\t\t\t\t\tdWuGLGh0dHBzOi8vc2hpYmIuc3RvY2twb3J0LmFjLnVrL2lkcC9zaGliYm9sZXRo\n\t\t\t\t\t\tMB0GA1UdDgQWBBTNA3WQ8zvZbogwr3KVdrj2DAZLlTANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEATxljwm7uXHGMCNLIFyJlpTx/TLCW7m4kP+FMhDa67Odpv3rNyu33fgtxP5lN\n\t\t\t\t\t\t14RioV5jXaPruxMjdVw8L2v3Q4mBAOOB1qfJyIAmn+QpGvouXvh/rIOywlz9S9Ng\n\t\t\t\t\t\ta0vc5R47wfL6Zyb548WnO6QqVgSgg8ZbsBZalcvrDLHLX+xFlltXo3x+rrfWLgf6\n\t\t\t\t\t\thfWNaS4qX4wFjS02bb6BaYt8dExP/MjJ93F/NnsaatHc6ez2OQSQAaHDWWBUXB/P\n\t\t\t\t\t\tDY9eQDYcEDia9hZgAs3FnwK2Cmwk6aqOIW3WlUMmVPCat764FOLrOMiAVtq4kFJq\n\t\t\t\t\t\tba0bpVtpnDdaJXtivnztmKRWPw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stockport.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibb.stockport.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibb.stockport.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibb.stockport.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibb.stockport.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibb.stockport.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibb.stockport.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibb.stockport.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibb.stockport.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "stockport.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUM+WxIbWXv2I74/FnfG6jjwU+Ri0wDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwIDEeMBwGA1UEAxMVc2hpYmIuc3RvY2twb3J0LmFjLnVrMB4XDTExMDUwNjE0\n\t\t\t\t\t\tMDAyM1oXDTMxMDUwNjE0MDAyM1owIDEeMBwGA1UEAxMVc2hpYmIuc3RvY2twb3J0\n\t\t\t\t\t\tLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAifpJBo9UYsko\n\t\t\t\t\t\tkMULJTlBmVICnEZWWnlX3XFNf3aUtkOYW5EgGgwro1jR0irV252k/WIThep4ozjI\n\t\t\t\t\t\tC31suuhrKVUtPggMVaP7LxXcEvO7FP2fc++yqvpUYs8h4kJylmy5J4UX6MlSqM7W\n\t\t\t\t\t\tLcyH3SOPeQkh/XEGdsNcxphhaXHMhyCEsB5xESYyp0tMFh7bjX9+YjBMxnoWu7iz\n\t\t\t\t\t\tZk/+bxP2lgaQA1DayxgvhSEsvdSJkxCerjPnPrGv6f0pVN2exDCOpwsFPPQWsCIC\n\t\t\t\t\t\t0BQnqbxqf/ONpBUCi2fJHFEqNHIh+YBfLBqSOpPqIkhAlXnAlYVfP3/oJ/zaIHoG\n\t\t\t\t\t\tTKp2AP62pQIDAQABo3EwbzBOBgNVHREERzBFghVzaGliYi5zdG9ja3BvcnQuYWMu\n\t\t\t\t\t\tdWuGLGh0dHBzOi8vc2hpYmIuc3RvY2twb3J0LmFjLnVrL2lkcC9zaGliYm9sZXRo\n\t\t\t\t\t\tMB0GA1UdDgQWBBTNA3WQ8zvZbogwr3KVdrj2DAZLlTANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEATxljwm7uXHGMCNLIFyJlpTx/TLCW7m4kP+FMhDa67Odpv3rNyu33fgtxP5lN\n\t\t\t\t\t\t14RioV5jXaPruxMjdVw8L2v3Q4mBAOOB1qfJyIAmn+QpGvouXvh/rIOywlz9S9Ng\n\t\t\t\t\t\ta0vc5R47wfL6Zyb548WnO6QqVgSgg8ZbsBZalcvrDLHLX+xFlltXo3x+rrfWLgf6\n\t\t\t\t\t\thfWNaS4qX4wFjS02bb6BaYt8dExP/MjJ93F/NnsaatHc6ez2OQSQAaHDWWBUXB/P\n\t\t\t\t\t\tDY9eQDYcEDia9hZgAs3FnwK2Cmwk6aqOIW3WlUMmVPCat764FOLrOMiAVtq4kFJq\n\t\t\t\t\t\tba0bpVtpnDdaJXtivnztmKRWPw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Stockport College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.stockport.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Stockport College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:cru.fr:federation:univ-lyon1.fr",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@univ-lyon1.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:cru.fr:federation:univ-lyon1.fr",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-10-26T16:20:23Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univ-lyon1.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univ-lyon1.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.univ-lyon1.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-lyon1.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-lyon1.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Lyon 1 - Claude Bernard"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Lyon 1 - Claude Bernard"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE3zCCA8egAwIBAgIJAIz0IVyFIDO8MA0GCSqGSIb3DQEBCwUAMIGlMQswCQYD\nVQQGEwJGUjEPMA0GA1UECBMGRlJBTkNFMRUwEwYDVQQHEwxWSUxMRVVSQkFOTkUx\nKTAnBgNVBAoTIFVOSVZFUlNJVEUgQ0xBVURFIEJFUk5BUkQgTFlPTiAxMRowGAYD\nVQQDExFpZHAudW5pdi1seW9uMS5mcjEnMCUGCSqGSIb3DQEJARYYc2hpYmJvbGV0\naEB1bml2LWx5b24xLmZyMB4XDTE1MDkyMjExNTIzMFoXDTI1MDkxOTExNTIzMFow\ngaUxCzAJBgNVBAYTAkZSMQ8wDQYDVQQIEwZGUkFOQ0UxFTATBgNVBAcTDFZJTExF\nVVJCQU5ORTEpMCcGA1UEChMgVU5JVkVSU0lURSBDTEFVREUgQkVSTkFSRCBMWU9O\nIDExGjAYBgNVBAMTEWlkcC51bml2LWx5b24xLmZyMScwJQYJKoZIhvcNAQkBFhhz\naGliYm9sZXRoQHVuaXYtbHlvbjEuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQC58VIw+tigGlowMge/475AvTFgSNUsA4jM4zZwBU/hxGTrf7MQovEW\nXyMZcPNcE0+LK53IcgAipHEJ5/dj2ZRT9EtjlabTca6d7xyil5c155fExkb//Vq6\nXsBojJ7O26BLhHx0/Pl8HSYq6sqZA2J+QgzYQ2SDZRS6EowSJokKI7ATDX3gmyKp\ns82p9paStfM0xQD8XaZIirbdue9eY0fAEavTGNA0D5jYgfgQ99D/0wMUgUumh86g\nn7ux+fc8kjUIwYG4cXM4laNS+4nbUQLTuXxlpuLNmkSkCmBl9q0fKJM+a013Dhe7\nAtk+E51GJGmz3Q5EKBkOoTsq//4qrUojAgMBAAGjggEOMIIBCjAdBgNVHQ4EFgQU\n4tUM0e5oVHam+Ui4mw7eyrJlWrMwgdoGA1UdIwSB0jCBz4AU4tUM0e5oVHam+Ui4\nmw7eyrJlWrOhgaukgagwgaUxCzAJBgNVBAYTAkZSMQ8wDQYDVQQIEwZGUkFOQ0Ux\nFTATBgNVBAcTDFZJTExFVVJCQU5ORTEpMCcGA1UEChMgVU5JVkVSU0lURSBDTEFV\nREUgQkVSTkFSRCBMWU9OIDExGjAYBgNVBAMTEWlkcC51bml2LWx5b24xLmZyMScw\nJQYJKoZIhvcNAQkBFhhzaGliYm9sZXRoQHVuaXYtbHlvbjEuZnKCCQCM9CFchSAz\nvDAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQCXQyUIW7tNLd3vKNg6\n1JF7KwTHe+f1FO7J21cozLf/OuiSCuz1naKPB4VqLfYoBK03yEme8CHOaxCPjkSB\nixV1vqA0Uovka6VrzuM7OhtLEReF3VajJD4+MExwLeCKJnjpFJEDQdDracNFfi1n\n6HpsX95vX11466ig8O4JTyXJ77LaIHItTBhrQozrY3woFr6kt6cs2IYMxqDj9M2K\nc9cUTNP0EeRAYh7jQtNMJirphI8U43QDGdeOSytypmpQpe002c44CczDa9tkx+sT\nTFbUmmvfu3TPJmE3CXuFrt8C9wh19uNNm9uAhqU3jHjRa5n/OqQJVddhgZ8WkCsd\ndYpv"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Lyon 1 - Claude Bernard"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-lyon1.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Lyon 1 - Claude Bernard"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso.memphis.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "pchood@memphis.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Patrick Hood"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "wassa@memphis.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Walter Hoehn"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.memphis.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.memphis.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.memphis.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAMRzm6r0KEI0aMxpj+07KHii/Em0MA0GCSqGSIb3DQEB\nBQUAMBoxGDAWBgNVBAMTD3Nzby5tZW1waGlzLmVkdTAeFw0xMDA1MDQxNjQzMjla\nFw0zMDA1MDQxNjQzMjlaMBoxGDAWBgNVBAMTD3Nzby5tZW1waGlzLmVkdTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIfoWBM++Q+1MvUNrhdyCxsRG/1b\n9x+Zydzbgfk13b5NDH4kwW0pdQaejJD4Lyjv51wFGRu46Nujs5BZVXg2/TTxEef4\nqP1UATWeGc05bYv+G1wrGyjDGtuePMjXTXKNcizGf6ixKmwDlBhBaOa9XCBD7Mfb\nrwaVNKq/oVUm3KUazKk5PKNDPQbMWieIR3xdUgOm9MZYoFD5HF+zg2XIJr7nUvNe\nBvqrhOmCw1b4LBz+3Do3yAi4SaF2d6Vz1IIkAgzJFlLvkBCFZib793CUFMd/tEz6\n9rHISb0DQHc0fxchJNY65TsTWDf7eaSmfVNq24N95zFjTB1LpsZq41HqiSECAwEA\nAaNlMGMwQgYDVR0RBDswOYIPc3NvLm1lbXBoaXMuZWR1hiZodHRwczovL3Nzby5t\nZW1waGlzLmVkdS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUPT6dRHJJjkrdBtxY\n8h56JhBLM3gwDQYJKoZIhvcNAQEFBQADggEBAINm/g8hIwxTA+Qyl1mOJJmraDJ/\nBbzXRA57magxwGUdGV5vknlTh0P9Tvp7yqiRUrZzD3RjomI6bmvu2E5p5JMXqTuz\nFUgkk3DR6kT8SLg+Jc0vyAM11M0hMhmZYjzgwbL/3ArpxJnUAt6XTzMtn2ylv++p\nzs2YddbosZ2kbcEmAUoIuuiBRf37fQDj7b84ri6XusWphMBuQdMG2hRFXAVKXMas\nMNVw3x0YwNgpXojdR/YaOD7FVhMSdU5dpafnBngseJgY0bWb0RFIFaa8TFwaxze4\n+UQ7IWMgsQsCScGpJnaOU2KXOQrF5zPSxsKLS07rJlGUEszyfaRblzJEwNU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "memphis.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://sso.memphis.edu/idp/images/uofmlogo.png",
                    "lang": "en",
                    "height": "118",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The University of Memphis"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The University of Memphis"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.memphis.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Memphis"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://serviceadmin.company.ja.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jtag@ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "JANET TAG"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jtag@ja.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "JANET TAG"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://serviceadmin.company.ja.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2012-12-17T14:09:03Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Service Admin"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ja.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "JISC Collections and Janet Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://serviceadmin.company.ja.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://serviceadmin.company.ja.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://serviceadmin.company.ja.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://serviceadmin.company.ja.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://serviceadmin.company.ja.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://serviceadmin.company.ja.net/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://serviceadmin.company.ja.net/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC4jCCAcqgAwIBAgIJAKyF+vahRReuMA0GCSqGSIb3DQEBBQUAMBQxEjAQBgNV\n\t\t\t\t\t\tBAMTCWhhcjAwMzkxODAeFw0wOTExMjAwODM4MTVaFw0xOTExMTgwODM4MTVaMBQx\n\t\t\t\t\t\tEjAQBgNVBAMTCWhhcjAwMzkxODCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAKyGnAXQpTnriKaVLhBxB2V01KEV7JFljb6JyCUgmPzhjozQV78Lt6wnrlVE\n\t\t\t\t\t\tPMJUFzx6MhVOOFdmoud9f4uEt3eLeNNBkXy6F1hLsK93MmEq7NycC9f+RTGkXuI9\n\t\t\t\t\t\tZZ6bHpCQg4cgLlo+e+oSmyFrqdwHkKXRxhx7sLDpmrBRt4WS1Yom/sf1roaj/HYJ\n\t\t\t\t\t\tI09jwKfl5mlFhWqHoprT6zHYZ/q4HIgo8CYFzRPTBYP2WoakD87P3UPpVZj6uLAz\n\t\t\t\t\t\td8LCuv1ZX2HJTHYrUyEM4tbqA2cv/CN8W6cgTkm5puZAMvPmFeNnoQlkBnUpH/oc\n\t\t\t\t\t\toGDmT026FyBGQ6yXva1uZVOX0xMCAwEAAaM3MDUwFAYDVR0RBA0wC4IJaGFyMDAz\n\t\t\t\t\t\tOTE4MB0GA1UdDgQWBBQST9Pog/haMAhYi8W9rY0cKz3XfjANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAERDcKAB+oNKMF14ys3MjR7NgPZzAnxNjyDizDMsPug9ZqfXKTfU1NFZx\n\t\t\t\t\t\tnx1ihIXHOBZgLU4RKLJSopHZ57V+HlOebXCckx/je1y4a30B0sIg3yk9ZZlMNcVI\n\t\t\t\t\t\tJWEIEGc6kkIhgQBMAtTaae+Yd1gqk4MQBQG08iDy9M3E4jp3BmgZbJL2lBYwCoRc\n\t\t\t\t\t\tU2soIdQNoQS5WDuqwDVXqOljUfijVZU9YRpjPDsXqDQDVO+7v/EbPxVtRThQChxY\n\t\t\t\t\t\tLwXeoQe6wBNtmeBEdm16Ik+PCxkgQlTCLythjkwmB+AjmqoW6Kp9bNfh7/Tlv/lM\n\t\t\t\t\t\tbYW9q2/JzwJW2LhAXTV1ev8D9e3peg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://serviceadmin.company.ja.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://serviceadmin.company.ja.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://serviceadmin.company.ja.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://serviceadmin.company.ja.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://serviceadmin.company.ja.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://serviceadmin.company.ja.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://serviceadmin.company.ja.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://serviceadmin.company.ja.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://serviceadmin.company.ja.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://serviceadmin.company.ja.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ladok3-p09.ladok.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-p09.ladok.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;p09"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;p09"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-p09.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-p09.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQTCCAimgAwIBAgIJAJDMEf13vqm0MA0GCSqGSIb3DQEBBQUAMCIxIDAeBgNV\nBAMTF2xhZG9rMy1wMDkubGFkb2sudW11LnNlMB4XDTE1MDIwOTEwNDExOVoXDTI1\nMDIwNjEwNDExOVowIjEgMB4GA1UEAxMXbGFkb2szLXAwOS5sYWRvay51bXUuc2Uw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCgU1uWIVhW231AIUHyZneh\nDWU+Ugltcvv53ihgCwRaXRI9QvLhExPGDLYniweFv6PGRX8fom3u/OGT7cTy+QnF\n8mZ5VgJb6Mtkv0ZgIuuFsasCQX7Hg/4UnECz6ZPdLZnjNV/AC38v9ZQnLvrx7SJU\neBcqCQRmudcz3Qlo+9+I1vUB3LH3IBdLGcRVEtOOnS7J0pb0mWPT6FIpVEa+g7cm\nI3QDrFZjAYeix6scDVIqYgnPwwSJral64tUqIRtuRsTZC3FsCzB8h6J9rszi1dPW\nEGy/I9RTG14rGCuLtXaZQALBm1Mo/7dVD6J7E+E+ChxMHPnykHAl4lY4gjc5FdLx\nAgMBAAGjejB4MFcGA1UdEQRQME6CF2xhZG9rMy1wMDkubGFkb2sudW11LnNlhjNo\ndHRwczovL2xhZG9rMy1wMDkubGFkb2sudW11LnNlL3N0dWRlbnQtZnJvbnRlbmQt\nc3AwHQYDVR0OBBYEFLwAiGxbc8cqytq7LRCVyVBmfs/uMA0GCSqGSIb3DQEBBQUA\nA4IBAQBj4wqdwkNWasllr/4ov3YfHCzDEzk5oRRD0mvK+n4EPqjOe0U0DSEsALFh\nBq3jL6ETaGDCBVFWnzVInGGo8Q+iEWtDi0IbBG3nKFXH3CzYPGzGRb1jxjOKs9wm\ndaqZwPSI+4E6hgz7SGMZUpEXcaIkqUw+Ha2JHIvT3qzmPVNeNHzqv2klAwPQSMKA\niGOXogu4t0iBxIrWwIJSawO3FaWlNa9s8WvVHpdml+4hFF61dkQ4Z1rYwUcv1MGj\nncrI0Cpb8E0yZl4rItbZkZat1Xr7ZabhVno2hgVeuSpEgB42dxmfrg2ohLByjMbs\nKrLP2rhVcVzanxwt02kjYwaqb4YH"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-p09.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-p09.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://srv00847.soton.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Serviceline@soton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Serviceline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Peters"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:C.L.Peters@soton.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Clayton"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://srv00847.soton.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-05-14T09:37:39Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Southampton Test Service"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.southampton.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Southampton"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://srv00847.soton.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://srv00847.soton.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://srv00847.soton.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://srv00847.soton.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://srv00847.soton.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://srv00847.soton.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://srv00847.soton.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3zCCAcegAwIBAgIJAIAbqup9yKKMMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\n\t\t\t\t\t\tBAMTCHNydjAwODQ3MB4XDTE0MDUwNjExNTY1MFoXDTI0MDUwMzExNTY1MFowEzER\n\t\t\t\t\t\tMA8GA1UEAxMIc3J2MDA4NDcwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\n\t\t\t\t\t\tAQDfhFR+xjj1/R3UX0UDL9wX1Yo1lMCA9gCjvzE6j6i6b2rLfTwlc9cgaBkN2Cpe\n\t\t\t\t\t\tSLkFUxkJq4D1jtAE1slBTEos29o+7LGgpxr4CTbiKwAbcPIfezYGnjaCECBqCDVj\n\t\t\t\t\t\tKMmYt0mP8K1n7Lh7lHpg55K6ldVtDS7v2UWEH/604fwxeRDEwvf2BvvKoD8aztkE\n\t\t\t\t\t\taZubA9KEWit+m0xPIpMKZ0xOc96upMsz0NZwByNe47NKt1UiR1qoba/54/w9hATQ\n\t\t\t\t\t\tICW7zdFN9eRFkC4kDOFU+8JPJ1PJwIIIwmZsL/h30uN3ZRr6P3Su57e4Be6Kse2u\n\t\t\t\t\t\tw7lgpRDbBx4mec+wPZ8GD+oFAgMBAAGjNjA0MBMGA1UdEQQMMAqCCHNydjAwODQ3\n\t\t\t\t\t\tMB0GA1UdDgQWBBTBlMHnSTXBUylCdM2mqIb7TdtTIDANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAhl9srCrHEXFRQhO7Q5tsSPYXwr/nWqgaPR/nPTjE43elXKNy57P0uDXdEAQU\n\t\t\t\t\t\t3ax6OQIO5xMy4bBA4qRF50N2JzmKVz96GANDguvWQBtn3LDu0g8SRxgaogm0WYCv\n\t\t\t\t\t\t6IhB/6HJ4XIeVeIwlQbwvp69lRV9z2O851yRJL1Rtqk5vnxmikSNQk7RH4Dd4PCw\n\t\t\t\t\t\t7KH0cfGW3vA8sngRHX2JtjDpjgunpVKzmXffdt1WZIHJJ4LcNVXd8moFGQetL+H7\n\t\t\t\t\t\tkUs4VoXiMXI702q9rXK7OH9Qg07bFB20jdoYpw3UfBBPSPylb/SQR9kCRL78JCqY\n\t\t\t\t\t\tnxbGI9WQz4LJ5w9S87j8jiPEzg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://srv00847.soton.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://srv00847.soton.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://srv00847.soton.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://srv00847.soton.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://srv00847.soton.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://srv00847.soton.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://services.oxfordjournals.org/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://services.oxfordjournals.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2014-01-16T18:05:53Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Oxford Journals"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.oxfordjournals.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HighWire Press, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.highwire.org/applications/oupjournals/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.highwire.org/applications/oupjournals/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIJAMTRVlqTJ11lMA0GCSqGSIb3DQEBBQUAMIG+MQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBD\n\t\t\t\t\t\taXR5MRcwFQYDVQQKEw5IaWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUx\n\t\t\t\t\t\tIDAeBgNVBAMTF3NoaWJib2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkB\n\t\t\t\t\t\tFiZzaGliYm9sZXRoLWFkbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTAeFw0xNDA0\n\t\t\t\t\t\tMTUxOTQzMDNaFw0yNDA0MTIxOTQzMDNaMIG+MQswCQYDVQQGEwJVUzETMBEGA1UE\n\t\t\t\t\t\tCBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBDaXR5MRcwFQYDVQQKEw5I\n\t\t\t\t\t\taWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUxIDAeBgNVBAMTF3NoaWJi\n\t\t\t\t\t\tb2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkBFiZzaGliYm9sZXRoLWFk\n\t\t\t\t\t\tbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALPB99M9iWjentrddY/rLgzKn1X0j4Ao191iyiowBBt/r/pmn2oz\n\t\t\t\t\t\tfrbONkkTVBB++mNtiufK6jyKnBM5mffPOkXHRo+K1DQec7TvpQ1PmLv/BpBgPrr9\n\t\t\t\t\t\tldViOSUnYJuB0IgJVV8oylgeH2Ay0XRkNPlBUjBA2fUPWVpXcvFe+aD2tLdVR9uO\n\t\t\t\t\t\tXvfTMxAEGqzxTU+OxO6pW2sBXNBmGvZQ0TRyovQh5+pTURY/lm0V/iWvRmRe51WE\n\t\t\t\t\t\tO/nhYyvRuMmNj8EL38o10S9TXuCkVzY00hK5cclaFge7gz/tfjmadVVcbe8xCVxc\n\t\t\t\t\t\tnb1lhmt1kH2XtKvU5hyZMTO+VUfXQvqcQyECAwEAAaN7MHkwCQYDVR0TBAIwADAs\n\t\t\t\t\t\tBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYD\n\t\t\t\t\t\tVR0OBBYEFJpUZq/XaW9/bPvjffkxX0IDvuPiMB8GA1UdIwQYMBaAFJpUZq/XaW9/\n\t\t\t\t\t\tbPvjffkxX0IDvuPiMA0GCSqGSIb3DQEBBQUAA4IBAQCq/FF56ZB1cL3KbniEJP99\n\t\t\t\t\t\tU9wTD6KpOrWxvqNbUSV1cefLf5cYHonOjy6oAJSSBSNuP7U5Q//0tXtkvlJoqGUY\n\t\t\t\t\t\tvqngmeg9wLZ/Fla3tXcDdTj0n1F+NZOx9vBDacIk0Ua4aHXDA4bdytzkV1QyZDRq\n\t\t\t\t\t\tQ8vq7RoQ8E5IF7Cll+kt2dZXQk8o6Qp3w2ppoMRtYdKOQassqn+V1MYcMPgdxZkS\n\t\t\t\t\t\tDrcgzktR/JMb5OmPrp4mSy1OWDGrFvUIigsLBPZV9tw1f7y42lnbmQas3RCS30yr\n\t\t\t\t\t\tCtUPT/PQDkCdBRViGmmMkYwjdaOTiHOJveWtrVXu8vLvO36pqFF4Kft0pgqlfvAE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.highwire.org/applications/oupjournals/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.highwire.org/applications/oupjournals/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.highwire.org/applications/oupjournals/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.highwire.org/applications/oupjournals/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.test.resultat.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.test.resultat.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.test.resultat.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.test.resultat.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.test.resultat.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.test.resultat.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.test.resultat.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.test.resultat.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.test.resultat.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.test.resultat.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.test.resultat.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.test.resultat.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.test.resultat.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.test.resultat.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIJAKTiHAGw6WrZMA0GCSqGSIb3DQEBBQUAMCUxIzAhBgNV\nBAMTGnd3dy50ZXN0LnJlc3VsdGF0LmxhZG9rLnNlMB4XDTE1MDUyODEzNTkxOVoX\nDTI1MDUyNTEzNTkxOVowJTEjMCEGA1UEAxMad3d3LnRlc3QucmVzdWx0YXQubGFk\nb2suc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCcZc5294v0tIZ0\n9R7Aa5liI+XckA03D6JSnNXyPO/WYjrKQy5FBWMFYo1UHLLLGyXlsi+uoGhjMqnI\n7s9L6DtNOg3qbh5qg+bqg36QE3P1OfUBvNvfpeBsAn5jaymvdD37gs9ltRS89WGV\nDedyGGblJ/xXmuBZEr2v5AXblFfaS+Hq7RTCP99Y0G3pZnGLqe0GPlrb1wiYCYII\neNMGc+zB2nAKddsf8OZzNoK+EW3YoFbhoEt9JwsCSqcOy2iNCBOQ/JKeRzN1TqIe\nsvzf4FpmZfOcbHgQzBsHeCAQ14wcauMNWNDrKnLGmZu1VnYZx7nRem4iqfNCehjM\nrLTPVn1PAgMBAAGjczBxMFAGA1UdEQRJMEeCGnd3dy50ZXN0LnJlc3VsdGF0Lmxh\nZG9rLnNlhilodHRwczovL3d3dy50ZXN0LnJlc3VsdGF0LmxhZG9rLnNlL2d1aS1z\ncDAdBgNVHQ4EFgQUR4xhLIkCvWmfQcZGqgRaijKmtAswDQYJKoZIhvcNAQEFBQAD\nggEBAIM/jI8Lx3C1uKt7Yd3RfxtUcmfjMRd9qJS7AROgnJEHnS3R/J/b4pjcSL5T\n5WcCBSsWwVtw/yOZYjO2YIL7JmpITnrty+cvbIM9gP8B+f7yaXLMXyPMRLTmXRdA\n7jgSYjAW4kvW03bYwAmTXZTYVMa3RdEPQVm4ExeGm2mKuPmxU+DKtUN9P4/y3vk1\nB5cpxHLB3GirJnh7YeqjJrZDqykFNxrd3rl+ZltPKHDnrg/Ed7KZQsLZwxukya5h\nzUw6DXac6BTHP4Cc2+YgqM9RrIvcuuKbXPVpmgpbbblEqeJou8FkL60Dm+zHHSMz\nS2liOjKSQVs/JKjCYEiaEdD+x0U="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.test.resultat.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.test.resultat.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.test.resultat.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.test.resultat.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.test.resultat.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.test.resultat.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.test.resultat.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.test.resultat.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.test.resultat.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.test.resultat.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.chichester.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@chichester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Heaume"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Owen.Heaume@chichester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Owen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.chichester.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAJjvxUK9DXhdlH/EkMId7VAbUERjMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB8xHTAbBgNVBAMTFGlkcC5jaGljaGVzdGVyLmFjLnVrMB4XDTEzMDcwMzE1\n\t\t\t\t\t\tMjUxNloXDTMzMDcwMzE1MjUxNlowHzEdMBsGA1UEAxMUaWRwLmNoaWNoZXN0ZXIu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCPypPq8ApF4OPt\n\t\t\t\t\t\tENNcoWFIOnyJtNDbGoaRRlMTg7CDf1HkQb6Y9+zeK3gg1HC4PdI4Hxw+gqyhdeLE\n\t\t\t\t\t\tOp9uKvu9Mc2vx3ekfzQ5gbt9m0XgmnBAo+Pp21nOIwwQHRM3bLmld1A9jW3hcgA6\n\t\t\t\t\t\tMIjuJ6SeETWpbuFx00KNUXO7BuxBtvnhPesp1NRK03yHSI9T+pevq1Im1U0aplHP\n\t\t\t\t\t\t747tAS7/lGZBk/f3Xa0iCkriO6/9fEuXianylagIyJnvLBTImwMHPFYU1hrcpBez\n\t\t\t\t\t\tnfHYpHmUEQ26ol83ZrwT+oDgY6mBsZKcMp4pn9aBVxqXSIP9wB3C0kMYzTPvj6vI\n\t\t\t\t\t\t3tAIJ0krAgMBAAGjbzBtMEwGA1UdEQRFMEOCFGlkcC5jaGljaGVzdGVyLmFjLnVr\n\t\t\t\t\t\thitodHRwczovL2lkcC5jaGljaGVzdGVyLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0G\n\t\t\t\t\t\tA1UdDgQWBBQVTtCrfHJjvTZ+wDTp5oNJlTJRRjANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tO3KMZhp4iLbEGamacfT0kOrh9IDuhcjHlwRbATf7VBW2IuHZbBPNO11Z8Km6a2g0\n\t\t\t\t\t\tNDIHuc8jPYxY6rt//kjQwf4UEGxjiYwuplGsiN9FJfHcbXUkt9+8HUJpCX2C/jcg\n\t\t\t\t\t\tyEX9NGRp+4VGnqLV5ddJcFa7hH2g08bj6hfNBKQcmSdeuWAKR/XBM6xCW9yNskpb\n\t\t\t\t\t\tGMvVNbPQiLbkXCaEqgu3qOHuUXExez+BYT3WL7XL4yencFGtbZccgDMjS5zk3gYL\n\t\t\t\t\t\t11qYKdO9e8zZ1qufcZmIXPh4pVeM9WuRPq378hTwCMgBCEKM+/UMqcfagwLe+180\n\t\t\t\t\t\tn9abLyFHDmPsq3igTHKAkQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "chichester.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.chichester.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.chichester.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.chichester.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.chichester.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.chichester.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.chichester.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.chichester.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.chichester.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "chichester.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAJjvxUK9DXhdlH/EkMId7VAbUERjMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB8xHTAbBgNVBAMTFGlkcC5jaGljaGVzdGVyLmFjLnVrMB4XDTEzMDcwMzE1\n\t\t\t\t\t\tMjUxNloXDTMzMDcwMzE1MjUxNlowHzEdMBsGA1UEAxMUaWRwLmNoaWNoZXN0ZXIu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCPypPq8ApF4OPt\n\t\t\t\t\t\tENNcoWFIOnyJtNDbGoaRRlMTg7CDf1HkQb6Y9+zeK3gg1HC4PdI4Hxw+gqyhdeLE\n\t\t\t\t\t\tOp9uKvu9Mc2vx3ekfzQ5gbt9m0XgmnBAo+Pp21nOIwwQHRM3bLmld1A9jW3hcgA6\n\t\t\t\t\t\tMIjuJ6SeETWpbuFx00KNUXO7BuxBtvnhPesp1NRK03yHSI9T+pevq1Im1U0aplHP\n\t\t\t\t\t\t747tAS7/lGZBk/f3Xa0iCkriO6/9fEuXianylagIyJnvLBTImwMHPFYU1hrcpBez\n\t\t\t\t\t\tnfHYpHmUEQ26ol83ZrwT+oDgY6mBsZKcMp4pn9aBVxqXSIP9wB3C0kMYzTPvj6vI\n\t\t\t\t\t\t3tAIJ0krAgMBAAGjbzBtMEwGA1UdEQRFMEOCFGlkcC5jaGljaGVzdGVyLmFjLnVr\n\t\t\t\t\t\thitodHRwczovL2lkcC5jaGljaGVzdGVyLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0G\n\t\t\t\t\t\tA1UdDgQWBBQVTtCrfHJjvTZ+wDTp5oNJlTJRRjANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tO3KMZhp4iLbEGamacfT0kOrh9IDuhcjHlwRbATf7VBW2IuHZbBPNO11Z8Km6a2g0\n\t\t\t\t\t\tNDIHuc8jPYxY6rt//kjQwf4UEGxjiYwuplGsiN9FJfHcbXUkt9+8HUJpCX2C/jcg\n\t\t\t\t\t\tyEX9NGRp+4VGnqLV5ddJcFa7hH2g08bj6hfNBKQcmSdeuWAKR/XBM6xCW9yNskpb\n\t\t\t\t\t\tGMvVNbPQiLbkXCaEqgu3qOHuUXExez+BYT3WL7XL4yencFGtbZccgDMjS5zk3gYL\n\t\t\t\t\t\t11qYKdO9e8zZ1qufcZmIXPh4pVeM9WuRPq378hTwCMgBCEKM+/UMqcfagwLe+180\n\t\t\t\t\t\tn9abLyFHDmPsq3igTHKAkQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Chichester College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.chichester.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Chichester College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp-test.essex.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wolton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:awolton@essex.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alexis"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wolton"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:awolton@essex.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alexis"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-test.essex.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-06-03T15:04:21Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-test.essex.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-test.essex.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-test.essex.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-test.essex.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-test.essex.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-test.essex.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "essex.ac.uk"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Essex test IdP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUc2qae097+pkdjp+uUEKBZzGqiSQwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAwwUaWRwLXRlc3QuZXNzZXguYWMudWswHhcNMTUwNTE1MTAw\n\t\t\t\t\t\tMzA3WhcNMzUwNTE1MTAwMzA3WjAfMR0wGwYDVQQDDBRpZHAtdGVzdC5lc3NleC5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIyLl/oc4Xy4HOcG\n\t\t\t\t\t\teHwsRcgGzWFj9NK3V72WgWazSbE4AiLDqt02vaOBhclR8R1SegCrObOFj0b82sJN\n\t\t\t\t\t\t5vjndItF3CP9I8rEaHV5AXUNfzgbzbSbUGCCAm56PCGjZJAqnIbzXww2VZy8Hrfi\n\t\t\t\t\t\tigO1M7+6MJ+VlWSy8goKEjTTUxIP+lLKXBigLJ5TaEX7XjL82XwGP/dySlugbv+A\n\t\t\t\t\t\tGvKl60o19R91RLXnW4JJxqwTtbcXsmCBt8+Y7u2ydLd0npSqVsuU83J4QDobqNd9\n\t\t\t\t\t\tm63+dY8ZWIVT9dAhS/axohCnB1fLw6rAJVFv8dxUFwy9K1qmJNlmXeo8Wh5Ri1LC\n\t\t\t\t\t\tX9TQUiUCAwEAAaNvMG0wHQYDVR0OBBYEFBiAv2kRo1+4l0cY7QOfqGKVib4FMEwG\n\t\t\t\t\t\tA1UdEQRFMEOCFGlkcC10ZXN0LmVzc2V4LmFjLnVrhitodHRwczovL2lkcC10ZXN0\n\t\t\t\t\t\tLmVzc2V4LmFjLnVrL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQA0\n\t\t\t\t\t\tEQeoXFQ3WXuPikpsVSxUcQnUXSQq7vk189C5kLJaB6Cl1kBbBBhl0dshxTq6byGq\n\t\t\t\t\t\tiX0ERW7Yu3aNi1cJTODsPj8DT7Z5zGOqhqET+YjpNrjrG9c4DTq8MPioyjaaeFnW\n\t\t\t\t\t\t+yHoAfDCmD08B836EQ3FkoX6O7PwnERqacvTWlqkVVmrvIDQYkrgHMwIqC7qA7iW\n\t\t\t\t\t\tkkf29rslAhqUpnm3ivN7MLRkUxcYUZSgClbCOKU8vv/kRcKNhdHq2s9iQQMJrBzL\n\t\t\t\t\t\tXlioySiVaS8oqLO5edwzwVRYdnBcz0BLKLKmKIcIx06TBQ3mBp9rtmOGToAhS6X3\n\t\t\t\t\t\tyGMY1s5np9J/xHxJjwaE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIULJr1XXhT+S3ey6YboSWZXF4zcoYwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAwwUaWRwLXRlc3QuZXNzZXguYWMudWswHhcNMTUwNTE1MTAw\n\t\t\t\t\t\tMzA1WhcNMzUwNTE1MTAwMzA1WjAfMR0wGwYDVQQDDBRpZHAtdGVzdC5lc3NleC5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJEuHJm+QRG19FyF\n\t\t\t\t\t\tg5TWqE8KHXqOU7jWgTS3N83Pf0FyMGOvXsxBqNZumsYRbSgMX9IaI8N/uQZc8N1w\n\t\t\t\t\t\tWRefVBK4I5grCJGdVQVYfUa9ezNkV3CtbIkHavxcSYeSA+caWPDpTUliTmDhdDiP\n\t\t\t\t\t\tV0b74WdDrs0a1HaHm7M7b5TFizx+zVQde6XweF/mYuMaanZWi2DULmOOvOj1j0Ep\n\t\t\t\t\t\tLb4NzXR4Atci0UwH1lY4zqmEC2cUMOlKJ9D3ofEXU+eISRUQEGAPw74avPONdKTh\n\t\t\t\t\t\tipStt/v0UvAuFVYQMm8oTxiwAFQ7fhDt0wQrCcHfH5nInUUE4oJPa7Lap7x56FGi\n\t\t\t\t\t\tEyl89GsCAwEAAaNvMG0wHQYDVR0OBBYEFLnNt2t9J3W56iiW3JuCujd/TLRpMEwG\n\t\t\t\t\t\tA1UdEQRFMEOCFGlkcC10ZXN0LmVzc2V4LmFjLnVrhitodHRwczovL2lkcC10ZXN0\n\t\t\t\t\t\tLmVzc2V4LmFjLnVrL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQBV\n\t\t\t\t\t\tupSeT6edpnEJVB7ExAX3guINejlieUJJhiOGxaNzMKvII6znTDsRMauoVptgymGR\n\t\t\t\t\t\tYeGee42mLF0T3sbejYr8gFo9r3jVrGwjdL4ITMEGp3olTUuqDBfqsqZKFlKhZHZj\n\t\t\t\t\t\tgsci2Y24nD0Hv6YeZqVwitndQLtozwUSUyL2vU2xvF1L23sygV0FIoDT4lsRwNcI\n\t\t\t\t\t\tpZGKEorIgOTjx7Bc+MANEZoLDZraFm0TOH6qv4zEUIETMbcVOIphIUyrxx5jVrKF\n\t\t\t\t\t\t0VpLooL/mMU9VbJR6WT1+uX7uJ+3qLZhLYeV2Yjl4T2QkQUtziJfxdqXcu6fPycZ\n\t\t\t\t\t\tGFtAhBQHvhlmPU7wzNwn"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUZozs58pLdQvrhtNplOVI0oAY+cYwDQYJKoZIhvcNAQEL\n\t\t\t\t\t\tBQAwHzEdMBsGA1UEAwwUaWRwLXRlc3QuZXNzZXguYWMudWswHhcNMTUwNTE1MTAw\n\t\t\t\t\t\tMzA2WhcNMzUwNTE1MTAwMzA2WjAfMR0wGwYDVQQDDBRpZHAtdGVzdC5lc3NleC5h\n\t\t\t\t\t\tYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL1SMdXONgTIC6Xi\n\t\t\t\t\t\t+OMn34w2H4HdvT2py71AYE8J5HEgXSv3ummvnLPT/oXose66nkef9/CVpsgChSYv\n\t\t\t\t\t\tWvNc7zXpxcnAU9fHwqMxN+ztrmf3w1KvAQb6GTteXUR1lNljPubrV+95r5XbWl7C\n\t\t\t\t\t\tdttSLoYe1gvqew1iw/x6Onm1HerShUlofucfjp9M9pUSMgS1ASX3kt7lOhgMpvRf\n\t\t\t\t\t\t6HnMe3MpuPHms0F9fvJhJ0SC6c0a7XRCKa6lhC14Y8/mjVYSQBGKvtgZOHW7K4uB\n\t\t\t\t\t\tXDn7uJon4+YA12LyuEP4gPytZVvju2u2jry45tBdBUGk8rUn5edlWXXFUsCGVRJn\n\t\t\t\t\t\tr3xCnIkCAwEAAaNvMG0wHQYDVR0OBBYEFIVRQ4elcjZ6FYNL/Mvrq53zgdviMEwG\n\t\t\t\t\t\tA1UdEQRFMEOCFGlkcC10ZXN0LmVzc2V4LmFjLnVrhitodHRwczovL2lkcC10ZXN0\n\t\t\t\t\t\tLmVzc2V4LmFjLnVrL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEBCwUAA4IBAQBp\n\t\t\t\t\t\tCxluAdTD3wtu2ONWT8pQZHjW7XKLJadu3nVZ6+tpb0vBGUrIYoA2yw1a/qKaAa4Z\n\t\t\t\t\t\tJYnoMLPHFA6y8b8YQfGh8RqsJf0ElUMr05SE+qXyqVbH+lX1u24RQPQ9oeECW65I\n\t\t\t\t\t\tQu+C/eVSsoS3Necoc7bdMD0tZ5G4+hKZb1HtVwOZjT+4e2pSV8jPc2gdaSfwlyu6\n\t\t\t\t\t\tFQwQez6M2RAaQHCGGDUOU4ak6eDVAa0P1V1i8QWWBu14wVdDvVWle8+oFG6eDMP6\n\t\t\t\t\t\t1oRl6W8FAYaIrGHdwkMNRDBKnbPub6Qm6TYbEN6CNRNm9yn8PWLSLSPukxZO9Syd\n\t\t\t\t\t\tOHCALjxd0RBvEBzxEmDl"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Essex test IdP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.essex.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Essex"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.ifes.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Ramon Ramos"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ramon.ramos@ifes.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.ifes.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDpjCCAo4CAQAwDQYJKoZIhvcNAQEFBQAwgZgxDTALBgNVBAoTBElmZXMxDDAK\nBgNVBAsTA0RUSTEeMBwGCSqGSIb3DQEJARYPZHRpQGlmZXMuZWR1LmJyMREwDwYD\nVQQHFAhWaXTDs3JpYTEYMBYGA1UECBQPRXNww61yaXRvIFNhbnRvMQswCQYDVQQG\nEwJCUjEfMB0GA1UEAxMWc2hpYmJvbGV0aC5pZmVzLmVkdS5icjAeFw0xNTA1Mjcx\nNzIxMTRaFw0xODA1MjYxNzIxMTRaMIGYMQ0wCwYDVQQKEwRJZmVzMQwwCgYDVQQL\nEwNEVEkxHjAcBgkqhkiG9w0BCQEWD2R0aUBpZmVzLmVkdS5icjERMA8GA1UEBxQI\nVml0w7NyaWExGDAWBgNVBAgUD0VzcMOtcml0byBTYW50bzELMAkGA1UEBhMCQlIx\nHzAdBgNVBAMTFnNoaWJib2xldGguaWZlcy5lZHUuYnIwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQDDQKGUMB+kGYe4LbyZevimFzeFi2L6kLi2FnTLoip4\nYXeGBcSEz6sqJfaODq0NrRbfYH9dlP3SoxSHjN4j7G60Vhg0FlyKSA0tub76+FW9\nuu2CUpfOTfRdZUFcizwPh+Y8/7sSevPj5Xy0UqLlixETtR4uyyLBHssZSIpStRb2\nbKL+BtJjwCG5oRJbnIlK3/5MNwe4bGMor85TxAcQu2s2iDYzKfKRVBQ1fXkgHF1y\nW/zTqFNJt6HzEnIx3BkmkC+p+JrLThxiqsZauikOF9z3Xkm3RdwK0F9pFVwQZvAj\naTwO6+n9brX40409y6Y8DR6YJX2qsiKUHNeeIXcYtjNNAgMBAAEwDQYJKoZIhvcN\nAQEFBQADggEBAJZ1v506MKbGj2BLTlyWiO9rrtvAgUqkaSJnu0IONIcLkgGqLxVd\nLZYkgHY2BGblgk8q1by2TdcgvU97EJwWJfnJP3ssnVsppMSlNQj/PpEY8HdjdpcD\nuRJlSeLcIIaNjgtAcd1Gf6cPiCVlEpTbzuZaqTGMPph1saqOe2GqyK3w/T77c5Bg\nEaTESvRwpXEyKVBtEY2cgikp52pDD/KyH99GJ3XLU5rdrwpmmiCa9bGvABQH8hhd\nuhuDc4RigznHLvlxoiALH/EH1rglIPpdv8MG2FaUEAdtGgc4GIeBNpsEdKkR/7a4\nznp/YgyE1kJOxcCrcbaV9OaXAQvXe72je1g="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.ifes.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.ifes.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.ifes.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.ifes.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.ifes.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.ifes.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.ifes.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.ifes.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifes.edu.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifes.edu.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFES - Instituto Federal do Espirito Santo"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFES - Instituto Federal do Espirito Santo"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFES - Instituto Federal do Espirito Santo"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFES - Instituto Federal do Espirito Santo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDpjCCAo4CAQAwDQYJKoZIhvcNAQEFBQAwgZgxDTALBgNVBAoTBElmZXMxDDAK\nBgNVBAsTA0RUSTEeMBwGCSqGSIb3DQEJARYPZHRpQGlmZXMuZWR1LmJyMREwDwYD\nVQQHFAhWaXTDs3JpYTEYMBYGA1UECBQPRXNww61yaXRvIFNhbnRvMQswCQYDVQQG\nEwJCUjEfMB0GA1UEAxMWc2hpYmJvbGV0aC5pZmVzLmVkdS5icjAeFw0xNTA1Mjcx\nNzIxMTRaFw0xODA1MjYxNzIxMTRaMIGYMQ0wCwYDVQQKEwRJZmVzMQwwCgYDVQQL\nEwNEVEkxHjAcBgkqhkiG9w0BCQEWD2R0aUBpZmVzLmVkdS5icjERMA8GA1UEBxQI\nVml0w7NyaWExGDAWBgNVBAgUD0VzcMOtcml0byBTYW50bzELMAkGA1UEBhMCQlIx\nHzAdBgNVBAMTFnNoaWJib2xldGguaWZlcy5lZHUuYnIwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQDDQKGUMB+kGYe4LbyZevimFzeFi2L6kLi2FnTLoip4\nYXeGBcSEz6sqJfaODq0NrRbfYH9dlP3SoxSHjN4j7G60Vhg0FlyKSA0tub76+FW9\nuu2CUpfOTfRdZUFcizwPh+Y8/7sSevPj5Xy0UqLlixETtR4uyyLBHssZSIpStRb2\nbKL+BtJjwCG5oRJbnIlK3/5MNwe4bGMor85TxAcQu2s2iDYzKfKRVBQ1fXkgHF1y\nW/zTqFNJt6HzEnIx3BkmkC+p+JrLThxiqsZauikOF9z3Xkm3RdwK0F9pFVwQZvAj\naTwO6+n9brX40409y6Y8DR6YJX2qsiKUHNeeIXcYtjNNAgMBAAEwDQYJKoZIhvcN\nAQEFBQADggEBAJZ1v506MKbGj2BLTlyWiO9rrtvAgUqkaSJnu0IONIcLkgGqLxVd\nLZYkgHY2BGblgk8q1by2TdcgvU97EJwWJfnJP3ssnVsppMSlNQj/PpEY8HdjdpcD\nuRJlSeLcIIaNjgtAcd1Gf6cPiCVlEpTbzuZaqTGMPph1saqOe2GqyK3w/T77c5Bg\nEaTESvRwpXEyKVBtEY2cgikp52pDD/KyH99GJ3XLU5rdrwpmmiCa9bGvABQH8hhd\nuhuDc4RigznHLvlxoiALH/EH1rglIPpdv8MG2FaUEAdtGgc4GIeBNpsEdKkR/7a4\nznp/YgyE1kJOxcCrcbaV9OaXAQvXe72je1g="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFES - Instituto Federal do Espirito Santo"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFES - Instituto Federal do Espirito Santo"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifes.edu.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifes.edu.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFES - Instituto Federal do Espirito Santo"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFES - Instituto Federal do Espirito Santo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://federation.hdh.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://federation.hdh.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-05-13T13:44:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/8040fadd4eb10cff25d3bd0f04466c12",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hotelschool den Haag"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Hotelschool den Haag"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/hdh.gif",
                    "height": "35",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hotelschool den Haag"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Hotelschool den Haag"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Hotelschool den Haag"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hotelschool.nl/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Hotelschool den Haag"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.crous-dijon.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dsi@crous-dijon.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.crous-dijon.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2012-12-17T13:12:39Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.crous-dijon.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.crous-dijon.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.crous-dijon.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "crous-dijon.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.crous-dijon.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Dijon - Personnels"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Dijon - Personnels"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUXZf8djanPtL+INJI961K5kFsBf8wDQYJKoZIhvcNAQEF\nBQAwHTEbMBkGA1UEAwwSaWRwLmNyb3VzLWRpam9uLmZyMB4XDTE1MDgyNDE0NTU1\nNFoXDTM1MDgyNDE0NTU1NFowHTEbMBkGA1UEAwwSaWRwLmNyb3VzLWRpam9uLmZy\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArVfO+wFeSZeOHnc1JAYL\n4i3MQbeQkQElEuN1f+GikD8A9UWn39PHAv/3IivGLm27yngEasC74zQaPlk6BS2c\ngLksqzoBWMdjVkuPXiGEBSSDKaxRplzTsAPPVdkyBlEQFqoPAZS/+wg5g7yU3SuK\n0BKKGyP+Izfn+MBMBFRjMuwhzV2wLqFZsgZF1YZiCzlpuiFn09N2p182ha9zqian\n0RTH2Lsq/rNip0DzeaNG4gfuRBdOZwraw1uBfB0yvHd0oZRrzeQCByBBjdKrj2Qt\nsng4zx9gwU0ghHvQNgi8DY/Yne9u6LGrwWwuX2Qv461P/G8pj1ecQadoNGDJElSB\nWQIDAQABo2swaTAdBgNVHQ4EFgQU+keN+vwttrmrAqr4XoFcSMrJWKwwSAYDVR0R\nBEEwP4ISaWRwLmNyb3VzLWRpam9uLmZyhilodHRwczovL2lkcC5jcm91cy1kaWpv\nbi5mci9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEAeD2xGUMdtpXi\nf33R0MT8fLTpvjZx22SkqZpmgMPN1Mv36pevCqM3DQglu53mUcp7uowpNlxKINfV\nwKsLB31Uu3ADLKWWOU1Zhmqa8R2V05odXecAQgdcojS162TSkwzTeI43/Nc9zrtC\niO5xMR3wznB/kfmVpTvbEY8dsjZryxWnVsuFh23EbZc3r/W4JfE4cvfUNBVOJm0l\n55m1tP45kBigy5No2O7YC+TzGy+b2rABfPL6D0eYQhhvfBw5WbDCAtW+DaAV0AuB\nT+zF8GLFgOT6h68tIL0eLGprCAKV1x0RF2y2hYQMlxMfVQCobgHEtJoEudpNj0kN\nAWeDYzsI0g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIErzCCA5egAwIBAgIRAPce78VI0mZGzFqgRgussIEwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xMTAxMTIwMDAwMDBaFw0xNDAxMTEyMzU5NTlaMGAxCzAJBgNV\nBAYTAkZSMQ4wDAYDVQQHEwVEaWpvbjEXMBUGA1UEChMOQ1JPVVMgZGUgRElKT04x\nDDAKBgNVBAsTA0RTSTEaMBgGA1UEAxMRbnMuY3JvdXMtZGlqb24uZnIwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC4CnU/wibyinuaPI2EqcrvmaWCV9dz\nZ9zkKanUn0KVoPGaFayhJCI/H0c5D+FEJl/lsA0YKzghi8baSc8L+pmq+LV4DF0k\nk3Ke9Yfn9gDr5Y+IadmSo7nmxiE42LJrFZBSzPrqK7HClDKskkgHu6lIXX3vDwX9\nNTUWOITDsqh+iLziudBc4DLim1brrMVwdpZVwCGWixI+pnx+Mn1KaLkW2migteMW\nTvAj7uf37zucUa0RhHXI5IbsmRXsH04r7Xq2et74nQETmGS861kBfEtqNWs8oZNF\nGGT4y7VCq4XIN2ZFp7xZetyzEkrlaGxJyL+2H0PFy2PJkVgU0BRpEA//AgMBAAGj\nggGMMIIBiDAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJays3V0fqkOO57TAdBgNVHQ4E\nFgQUkCg4s3FgI7pzpdqRGT3IeDfAkSUwDgYDVR0PAQH/BAQDAgWgMAwGA1UdEwEB\n/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMBgGA1UdIAQRMA8w\nDQYLKwYBBAGyMQECAh0wOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3Mu\ndGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsG\nAQUFBzAChilodHRwOi8vY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNy\ndDAmBggrBgEFBQcwAYYaaHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwRAYDVR0R\nBD0wO4IRbnMuY3JvdXMtZGlqb24uZnKCEmNhcy5jcm91cy1kaWpvbi5mcoISaWRw\nLmNyb3VzLWRpam9uLmZyMA0GCSqGSIb3DQEBBQUAA4IBAQAIUjdnsILs5B0S4r30\n7X842J3m5zaE7xQ2kKKAa8FiF2TNZ+dzQQDbYrB8+nLD85ziWEwLzqGPHulDWbTI\nYxUX6Stt/KMW5frhCXX2i7hEp3gfKazu+jXou9ISXRuqKCU198d2Ic1Pqu8VoxwF\n7BgmqM7TDu+t8FTDF7rufbSKwCIR+yY+3oHtdNlZEdGCvCGOakfBEgqyZ4H6USuH\nWOVN0EpwAIdhLCQfwekeOM9ZulAKFYRB5tEKfmWS1aqo/7wNx71fJdjFV2mOkdcX\nB3ix6dIX1SsZx0ffnk3wPlrx6RGiItqiVD6gPDlUY/BRftSiyH/EEEM00YzHtqO/\niTNj"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS Dijon - Personnels"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.crous-dijon.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS Dijon - Personnels"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://tickets.sheffieldstudentsunion.com/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "MSL support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bonsall"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:james.bonsall@ukmsl.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "James"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://tickets.sheffieldstudentsunion.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-10-14T15:02:52Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Sheffield Students Union Tickets"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://tickets.sheffieldstudentsunion.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Membership Solutions Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://tickets.sheffieldstudentsunion.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://tickets.sheffieldstudentsunion.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://tickets.sheffieldstudentsunion.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://tickets.sheffieldstudentsunion.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://tickets.sheffieldstudentsunion.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://tickets.sheffieldstudentsunion.com/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC7jCCAdagAwIBAgIJALorwOxJ9felMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\n\t\t\t\t\t\tBAMTDXJlZC51a21zbC5uZXQwHhcNMTIwMTE2MTQyMDI2WhcNMjIwMTEzMTQyMDI2\n\t\t\t\t\t\tWjAYMRYwFAYDVQQDEw1yZWQudWttc2wubmV0MIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAt6/w1DLbf7yP1Ds/hbckh6UpvPP21vzMBxe6Lbf83wKx5FOq\n\t\t\t\t\t\tFxV138Riyr0lgjIjMaXjTq5LK/JV+6HDGq8jJjxYAaOU+R2ZtLC6C0rGT7tQrU1l\n\t\t\t\t\t\tZkg5pRz7mu+QNL1SzXxNu/62wpik3Htzk9eaf7v6MaXUqnvXz8QiGeVMcGrazjHG\n\t\t\t\t\t\tkzCDhme9/s01FVXBsryzFtTsKOMk08ynKVtqDdNYxL5sR4pnkfsd2dfFpFYYurT7\n\t\t\t\t\t\t0YWChpPt2hUZ3cG6oVuWPtExRfynR+DVhDMrQ8lZqTVYS+nkK9GaY48Z+kLelzPf\n\t\t\t\t\t\t5aJ5IOwIYGXXYmQxhqZK9BibifIavWcCoaz7HwIDAQABozswOTAYBgNVHREEETAP\n\t\t\t\t\t\tgg1yZWQudWttc2wubmV0MB0GA1UdDgQWBBTkJ2an+ISi623AA1DyKy+U/G2OdzAN\n\t\t\t\t\t\tBgkqhkiG9w0BAQUFAAOCAQEACEY1LH3ovYmB3S5+LSXWcA+J7L+s0GoWtwDALVEL\n\t\t\t\t\t\tEYLUyKUMkoyWzFA/kQ6fJoKVlYzftF6pAarqcF/EKAHP8B2205EMlnlwordaqJ5A\n\t\t\t\t\t\t70H/KTXpbec9awr/w/AEq9aDKQf0LbrrBCt5R2Eq+FsUwaYzdPb4NNOk2iwOuKRb\n\t\t\t\t\t\tQgGBOVxn/IHmkkF2nx/lmISlrTw3w/8t14OwRKtokdIkTCRYdJdPeXY4Lux8nDEC\n\t\t\t\t\t\tMVdMuxTmukTJxZ2jyg3jw03chH+na+7V14PgcxA5wmVkl2Dbk54rf4B8+lKZn9Qs\n\t\t\t\t\t\tRc5i1bGCRL38Kj86NSizDS+KVMrx3J48sPExehT3PUM8og=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://tickets.sheffieldstudentsunion.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://tickets.sheffieldstudentsunion.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://tickets.sheffieldstudentsunion.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://tickets.sheffieldstudentsunion.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://tickets.sheffieldstudentsunion.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://tickets.sheffieldstudentsunion.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://student.mit.ladok.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://student.mit.ladok.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://student.mit.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://student.mit.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3-projektets Migrations-, Integrations- och Testmilj\u00f6 (MIT-milj\u00f6n)"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 MIT Studentgr\u00e4nsnitt"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://student.mit.ladok.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "student.mit.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNTCCAh2gAwIBAgIJAJ3icKR+gNdqMA0GCSqGSIb3DQEBBQUAMB8xHTAbBgNV\nBAMTFHN0dWRlbnQubWl0LmxhZG9rLnNlMB4XDTE1MDIxMjA3MzEzOFoXDTI1MDIw\nOTA3MzEzOFowHzEdMBsGA1UEAxMUc3R1ZGVudC5taXQubGFkb2suc2UwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC3GvpMV8JsG+orqyQ1bx9vsley4AxO\nB7nDmfRwX63t22mpyBDer4ZMMwDxb8lNf0a9rzXyfacDh6UkbBghPB6w71onmt60\nrCozzqCUOYwyPwocEQZ9mxelc9dEyN1c8WhyIo6BnhQWPbPr7Y+EAihe4oOK16p1\nw+wyPlKxNRj1g0zOJHvvmg2vbXALyt1xJ60y7vSWKiZEMDpclnTwHCd2icU7AB5R\nEGBGxAV3rGVXQWzHZnDoP0NPr+OlzVbTowTAC7KoNlY0iBZwwtxyI1BolXgU4oN9\nXlpnu/FroqFAlsCuyZCc3/VLNwiNl7wH8ZOYRBoy+6rJMPVBLf1TEA+ZAgMBAAGj\ndDByMFEGA1UdEQRKMEiCFHN0dWRlbnQubWl0LmxhZG9rLnNlhjBodHRwczovL3N0\ndWRlbnQubWl0LmxhZG9rLnNlL3N0dWRlbnQtZnJvbnRlbmQtc3AwHQYDVR0OBBYE\nFGy8rVzZpS2hPPUQeQeK1LWAOhgZMA0GCSqGSIb3DQEBBQUAA4IBAQB2IVqSGbpJ\nqO1bh7aHHdnnmw2Wbc3jnyU8dhbJ4PuEii1m6rbu8b+pdpwYjqit1UZ2RVjzaL38\n4V8hCooWybOQ5phNj7pohwUqliPOX4rockK9nAhk0MT69KYArh+VfsvBmN9sb5uf\nCy4YS1P+vUWvWJqwmCwuKvBuCu3K8zI6QELhHFpafXTvkz+K+z3A22G1FigBqsMT\nua2Dzh2zE+wfcRwqZ+GwH0mN0iqxDJUKqgs9aEsl8Q9iHH1cmBYOMQnCaCIbnd6l\nXp4VZ3QgIMowFfU+rOyCR3jMz8kW9hLPuIGQXq65q14lETenxSds3d9Z6TGB6Xbc\naQxSEmvTJulB"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=student.mit.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://student.mit.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://ucl.epiclearninggroup.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bannister"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ABannister@epiclearninggroup.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Avey"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve.avey@leolearning.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steve"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://ucl.epiclearninggroup.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-02-13T17:04:02Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ExtendUCL"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://epiclearninggroup.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Epic Performance Improvement Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://extend.ucl.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://extend.ucl.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://extend.ucl.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://extend.ucl.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://extend.ucl.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://extend.ucl.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC0DCCAbigAwIBAgIJAKNyH/gxrpu9MA0GCSqGSIb3DQEBBQUAMA4xDDAKBgNV\n\t\t\t\t\t\tBAMTA3VjbDAeFw0xMjEyMTQwOTQ4NDBaFw0yMjEyMTIwOTQ4NDBaMA4xDDAKBgNV\n\t\t\t\t\t\tBAMTA3VjbDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL/YpbWoOORQ\n\t\t\t\t\t\teVEUuO5C+fue4B/lIw3d7J+oaeySdcld/BlHL1smwyQ51NkvZ3GCiQvRtWqcEDj1\n\t\t\t\t\t\twxHQeIOxCh8vJr1t7sdEI8McfTD9XS4sSGgNPehiynpcWlPB0HqtjAOwqaD5WDfN\n\t\t\t\t\t\txJDH73KhEg5rgnNKUuL9GCeuCwRUen3bbFk1pK4+s7CBxYr/JpjYKYZ4gBhsMmk9\n\t\t\t\t\t\thoDlh6Cyp2pgPgPJEdTUvKoWPzYi45dn7ih1JAxtsBQ/cDkd7apdK0IUjBSuXbYj\n\t\t\t\t\t\tjIPjhI522fXX6f3Vhwl/ftkmDQgTJ3tqd7hMajkF/me/j5UNOAU/NxaveDyQEiiO\n\t\t\t\t\t\tS2bGBBdURgsCAwEAAaMxMC8wDgYDVR0RBAcwBYIDdWNsMB0GA1UdDgQWBBS+K+xw\n\t\t\t\t\t\tEBCrHMQGnD8pYs3KlndVwzANBgkqhkiG9w0BAQUFAAOCAQEAhpRh7R7B45GEvxFI\n\t\t\t\t\t\trzT6QHsERtp00ZZmStaqAa5+E4DuFwX15G+igX4Bqqo5q67ClYrKKUExwElGYrWp\n\t\t\t\t\t\tFmL1U9LebLQLrfRqFiJxx670LTVVFBX1ElbWsPsDo5deASYIa6dYUd5k7jl74qSv\n\t\t\t\t\t\t0At3Ch8Jo71SfslPn9UXqwpLr4GeGK3xqYMZsEl09Mgfr/DQVpZ6LMr+2gc4o5pp\n\t\t\t\t\t\tBOGduhIs7GQjZAkugHE9UwZJiQYDVkhgoHz/1+3QfYPXerhunV3JM5VUbXXguRcd\n\t\t\t\t\t\t0bjeFxeLtcvlKpoHb4l1zh3bEr5kuP9LM830xgN0mAhqZN7tMdDURPdMuqCNOoyh \n\t\t\t\t\t\tgNNnjA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://extend.ucl.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://extend.ucl.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://extend.ucl.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://extend.ucl.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://extend.ucl.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://extend.ucl.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://dlib-skaill.ucs.ed.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hopkins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sara.hopkins@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sara"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hopkins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sara.hopkins@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sara"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dlib-skaill.ucs.ed.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-03-08T11:18:42Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRzCCAi+gAwIBAgIUSmTdfn763UNpnElLInB08fIfiOgwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwIjEgMB4GA1UEAxMXZGxpYi1za2FpbGwuZWRpbmEuYWMudWswHhcNMTQwNjE4\n\t\t\t\t\t\tMTIwMzIxWhcNMzQwNjE4MTIwMzIxWjAiMSAwHgYDVQQDExdkbGliLXNrYWlsbC5l\n\t\t\t\t\t\tZGluYS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJOx63EY\n\t\t\t\t\t\tJ4uh9FlNoNhB1KEi41z1uxuyWp3IOwX+EfUYXIshjnt1J4s0m36TFL7Ng6NfkHHs\n\t\t\t\t\t\tvWZ2GVX4p0qbK9sPQ/m9jNvA4PI55un/hRBn/KYu3/35Mf4ioiKkFRP/iEl/+YM1\n\t\t\t\t\t\tgURWxWd8bUyu0LbQRWbMRz9tU3dRruutxm47TNlZEfrEPaSAWb1otytGmw04vcjm\n\t\t\t\t\t\ty5nWIzPhBrpL1Zu+JekBcwvD3vrIgeA2h3r+8EuG0WghcLcWJtwUlOb5jSXmA/b6\n\t\t\t\t\t\t8l2F7Bbvy81x88NGBghZBhUnlLFwuUZ1zEDy5hqOVcGgoKlb216LzqRSPTxiiPQ9\n\t\t\t\t\t\t1PGvxffMLGTYCAMCAwEAAaN1MHMwUgYDVR0RBEswSYIXZGxpYi1za2FpbGwuZWRp\n\t\t\t\t\t\tbmEuYWMudWuGLmh0dHBzOi8vZGxpYi1za2FpbGwuZWRpbmEuYWMudWsvaWRwL3No\n\t\t\t\t\t\taWJib2xldGgwHQYDVR0OBBYEFOfvuXoBOS3z6kiFQNzznSPg5R1rMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBBQUAA4IBAQCQmnq2HC8MK+yGVLmKCr/wlDZKPwlUSvyNQXhgQYAtwUD9mb53\n\t\t\t\t\t\tWz+n7UXTYJQ/koVuJD+nDuQngkqAiEuW4NlMUQgtB5HQfIATQwkv7an029+4UL0m\n\t\t\t\t\t\tsWryJGjvGbbfZZ6+kt00Rrz3BEaU6fRV63/vrY0PYItvb36tjn0xfrI74MFIdQoj\n\t\t\t\t\t\ta3fa8kPIc1QYsCtNsV06GEpHpl0asgwNlCukFFyFUCuU/E/8Dadbwlw6o+ObNj3K\n\t\t\t\t\t\tb6ettwdPpzsvba7W2w/oERE2IJLP1fwJ5I3KE2nOGnlUYaXQFon/w7vDDYfpqCzO\n\t\t\t\t\t\tR313g/RR8Oq6ulpwKhbAPdoxFpyxxy3OS8K/"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dlib-skaill.ucs.ed.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://dlib-skaill.ucs.ed.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-skaill.ucs.ed.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://dlib-skaill.ucs.ed.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dlib-skaill.ucs.ed.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dlib-skaill.ucs.ed.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dlib-skaill.ucs.ed.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://dlib-skaill.ucs.ed.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-skaill.ucs.ed.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dlib-skaill.ucs.ed.ac.uk"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Skaill Test IdP"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRzCCAi+gAwIBAgIUSmTdfn763UNpnElLInB08fIfiOgwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwIjEgMB4GA1UEAxMXZGxpYi1za2FpbGwuZWRpbmEuYWMudWswHhcNMTQwNjE4\n\t\t\t\t\t\tMTIwMzIxWhcNMzQwNjE4MTIwMzIxWjAiMSAwHgYDVQQDExdkbGliLXNrYWlsbC5l\n\t\t\t\t\t\tZGluYS5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJOx63EY\n\t\t\t\t\t\tJ4uh9FlNoNhB1KEi41z1uxuyWp3IOwX+EfUYXIshjnt1J4s0m36TFL7Ng6NfkHHs\n\t\t\t\t\t\tvWZ2GVX4p0qbK9sPQ/m9jNvA4PI55un/hRBn/KYu3/35Mf4ioiKkFRP/iEl/+YM1\n\t\t\t\t\t\tgURWxWd8bUyu0LbQRWbMRz9tU3dRruutxm47TNlZEfrEPaSAWb1otytGmw04vcjm\n\t\t\t\t\t\ty5nWIzPhBrpL1Zu+JekBcwvD3vrIgeA2h3r+8EuG0WghcLcWJtwUlOb5jSXmA/b6\n\t\t\t\t\t\t8l2F7Bbvy81x88NGBghZBhUnlLFwuUZ1zEDy5hqOVcGgoKlb216LzqRSPTxiiPQ9\n\t\t\t\t\t\t1PGvxffMLGTYCAMCAwEAAaN1MHMwUgYDVR0RBEswSYIXZGxpYi1za2FpbGwuZWRp\n\t\t\t\t\t\tbmEuYWMudWuGLmh0dHBzOi8vZGxpYi1za2FpbGwuZWRpbmEuYWMudWsvaWRwL3No\n\t\t\t\t\t\taWJib2xldGgwHQYDVR0OBBYEFOfvuXoBOS3z6kiFQNzznSPg5R1rMA0GCSqGSIb3\n\t\t\t\t\t\tDQEBBQUAA4IBAQCQmnq2HC8MK+yGVLmKCr/wlDZKPwlUSvyNQXhgQYAtwUD9mb53\n\t\t\t\t\t\tWz+n7UXTYJQ/koVuJD+nDuQngkqAiEuW4NlMUQgtB5HQfIATQwkv7an029+4UL0m\n\t\t\t\t\t\tsWryJGjvGbbfZZ6+kt00Rrz3BEaU6fRV63/vrY0PYItvb36tjn0xfrI74MFIdQoj\n\t\t\t\t\t\ta3fa8kPIc1QYsCtNsV06GEpHpl0asgwNlCukFFyFUCuU/E/8Dadbwlw6o+ObNj3K\n\t\t\t\t\t\tb6ettwdPpzsvba7W2w/oERE2IJLP1fwJ5I3KE2nOGnlUYaXQFon/w7vDDYfpqCzO\n\t\t\t\t\t\tR313g/RR8Oq6ulpwKhbAPdoxFpyxxy3OS8K/"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Skaill Test IdP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://lbr.csc.fi/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Matthiesen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:martin.matthiesen@csc.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mustonen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rems@csc.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Timo"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Matthiesen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:martin.matthiesen@csc.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Martin"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://lbr.csc.fi/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2015-10-09T19:28:51Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://clarin.eu/category/clarin-member"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CLARIN ERIC"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://clarin.eu"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e459"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://lbr.csc.fi/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://lbr.csc.fi/home"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Service for applying for and managing access rights to language resources in the Language Bank of Finland."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Service for applying for and managing access rights to language resources in the Language Bank of Finland."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://lbr.csc.fi/en_GB/web/guest/privacy-policy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Language Bank Rights"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Language Bank Rights"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "lbr.csc.fi"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFYTCCBEmgAwIBAgIQWBOOp78lJI42EYlJleUqwDANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQwOTAwMDAwMFoXDTE3MDQwODIzNTk1OVowODEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRMwEQYDVQQDEwpsYnIuY3NjLmZp\nMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAqJDA0hb4cWa8XBfHbLrS\nQX1lRLMm9nFWH6n0Dv3KnTeyMKMuAewdAfmM+RfSqzehcOc6p4i8kfzf0akMGm1Q\nA/7JBCpjBFixlLE3L6+Fvxxha1To8RyHdUtaJI71jffmuBgHDucya8ypCAvmAJDT\nk3AW4RpnV8PEbf26KUsCkimMRdjvTkQyGz9R+yCM6rmyvs6DbdJz2oods7H43NJ6\nbZVKggLMeBY4n9pZuWIDUvgno6kJmXt971AeIBts3qO3yo3IxRLleZQibkxsCaK2\nGi+8GIWUaJ2hzLdBNkvGYb4Ij7/WtuuP4fUNLILwEkM+8EeVUsmf0VA8HKfrmrF3\niyPYTZFYYgzUptJZ+jNTkR/8XqMfnUj6VrM+GChmPEYslU9Dav1gkykob3phjgGm\nxkZY7sjTOLCfGoPivnUFywnJpcUs+FPV6/cbPsnxX9HA4n44w5B3JcwAgcHQ3IVb\nZL/pinLNDQ7hsN81+7zoqa2TGNkXjMH7rHgtlFw15rhdX8pTAMzuqyDjapnt9i/s\nkAIj8+KkXjd1JtbniTRKTH+3U4Hc9WZuclwNA4lhQjoGcvtoj71Lsn0hFTycGxzQ\nBIEKTSqsTnmI0AZklPCVpu12aVzNw79C69Qkrk7hYbq+HL2JmyC475lnvKCcT9Ob\nQHhbAM3EykBvOXcEByX1UwcCAwEAAaOCAWcwggFjMB8GA1UdIwQYMBaAFAy9k2gM\n896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBSYeFleYFefS0VfWjy/GIzy3JUMYTAO\nBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcD\nAQYIKwYBBQUHAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgEw\nOgYDVR0fBDMwMTAvoC2gK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJF\nTkFTU0xDQS5jcmwwbQYIKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8v\nY3J0LnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYa\naHR0cDovL29jc3AudGNzLnRlcmVuYS5vcmcwFQYDVR0RBA4wDIIKbGJyLmNzYy5m\naTANBgkqhkiG9w0BAQUFAAOCAQEADyIWRbAx7eFhuc6L/aaKZj7u8TPcq59YusJt\nMeHkFjj1AnSgzbdo/hd5AlHL01xFulXG8a5+xehfSWqTxGnQSFgcDXvdwNWx8JAV\n6JwDyq06ko2V4+6Y4OeR/vaW40J4hMhfuDO56/YITUxmMkSCo1Dk44hxtCPNDmTH\nqotUhjkJ+hNlRXZabFwp9LUSWiN0av0zpwMzxSHU1saTfgN0tB7KABKjYnriI7N+\n0k3tNgXiJfaZ3TCGNOPYWvv8Vqj9hqIzOvLFEPnPJ+TACiFBQUArI/2ges4bol7I\nInF/qlfqDoaoTI1ZSkpyr+97qTyFYFlbC5IFJCeCjcQAzscSUA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=lbr.csc.fi,OU=Domain Control Validated"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://lbr.csc.fi/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Language Bank Rights"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Language Bank Rights"
                }
              ],
              "service_description": [
                {
                  "lang": "de",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Service for applying for and managing access rights to language resources in the Language Bank of Finland."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Service for applying for and managing access rights to language resources in the Language Bank of Finland."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "cn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonAffiliation",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganizationType",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://play.umu.se",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "saml_admin@kaltura.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://play.umu.se",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ume\u00e5 universitet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://play.umu.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ume\u00e5 universitet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://play.umu.se/user/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UMU Play video portal vid Ume\u00e5 universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UMU Play video portal at Ume\u00e5 University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UMU Play, Ume\u00e5 universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UMU Play, Ume\u00e5 University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.umu.se/user/authenticate",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://test.ulster.unidesk.ac.uk/tas/secure/login/verify",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:is.helpline@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:apps-certs@mlist.is.ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IS Apps Technology Management"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://test.ulster.unidesk.ac.uk/tas/secure/login/verify",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-04-05T13:25:40Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Test Unidesk - Ulster"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ed.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID5jCCAs6gAwIBAgIJANq1yLjymVOIMA0GCSqGSIb3DQEBCwUAMFUxIjAgBgNV\n\t\t\t\t\t\tBAMTGXRlc3QudWxzdGVyLnVuaWRlc2suYWMudWsxIjAgBgNVBAoTGXRlc3QudWxz\n\t\t\t\t\t\tdGVyLnVuaWRlc2suYWMudWsxCzAJBgNVBAYTAlVLMB4XDTE2MDQwMTEyMzc1NFoX\n\t\t\t\t\t\tDTI2MDMzMDEyMzc1NFowVTEiMCAGA1UEAxMZdGVzdC51bHN0ZXIudW5pZGVzay5h\n\t\t\t\t\t\tYy51azEiMCAGA1UEChMZdGVzdC51bHN0ZXIudW5pZGVzay5hYy51azELMAkGA1UE\n\t\t\t\t\t\tBhMCVUswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDJI/GFDxsFAW+6\n\t\t\t\t\t\tOu5nagpAq1Qk5Fin2rFY9BB7RS6KLhJoSgMX7ssGNXP8HYzcISCVPNXzqbfoKvcv\n\t\t\t\t\t\t7grqXAA4iuhDWgAvIgxehnByEuj1TsxPb33b1ajNYDolxjJEmU51klO7NnaPRwR6\n\t\t\t\t\t\tJJvhvzd2FzDlF9JrycTM8XbPjsTfTPXwgKfUeuxdCqlpsOb8MFyM3izEzIZkx+6N\n\t\t\t\t\t\tbpIE+KLQZgOSchYFSaHhLqu/9TBza/J95VShgaPwQTK/yOtwTO3gX8oyOCOHzypy\n\t\t\t\t\t\tKK8FylnsXQCp4EO6pNuN4b4VSp6OsrKdGKRU9oUamnR7qPzj4v8M+B6XU4mzMR3e\n\t\t\t\t\t\tZ+ZbXFxPAgMBAAGjgbgwgbUwHQYDVR0OBBYEFEe6QHlpPV401yTQq07DeOkTcAw2\n\t\t\t\t\t\tMIGFBgNVHSMEfjB8gBRHukB5aT1eNNck0KtOw3jpE3AMNqFZpFcwVTEiMCAGA1UE\n\t\t\t\t\t\tAxMZdGVzdC51bHN0ZXIudW5pZGVzay5hYy51azEiMCAGA1UEChMZdGVzdC51bHN0\n\t\t\t\t\t\tZXIudW5pZGVzay5hYy51azELMAkGA1UEBhMCVUuCCQDatci48plTiDAMBgNVHRME\n\t\t\t\t\t\tBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQCG0pO2+nYPsZIECStWimLJK0InGvkE\n\t\t\t\t\t\t0AM+t6qX2+6A+eRyL6Uv6weUtM3XHXC/evNV7oy7/B8fBGHxBPpHohawBS+3EH9N\n\t\t\t\t\t\t+TbyynfcetgpdVQJbfi5NEigG8kcakpjAKRykwjul1UdfRATEKxdwlvcrSTUZvt9\n\t\t\t\t\t\tu21ITIDtIC6E/oRS+2PWP5XHwoebHcFvh1uAoWUscez4FFA2PK3rUpjDR7GhIQ80\n\t\t\t\t\t\t+aFxEUr85lO9e25/1WlMNlQQCkzOHRSBKR2GXeqrfTUqeI3Ez5kumWYrmxiyXCDU\n\t\t\t\t\t\t76p9XQ/DN7/gOwewXYHVMmZTvRGfEeicsqCUwVFEV705uNkc9jvhifo3"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID5jCCAs6gAwIBAgIJANq1yLjymVOIMA0GCSqGSIb3DQEBCwUAMFUxIjAgBgNV\n\t\t\t\t\t\tBAMTGXRlc3QudWxzdGVyLnVuaWRlc2suYWMudWsxIjAgBgNVBAoTGXRlc3QudWxz\n\t\t\t\t\t\tdGVyLnVuaWRlc2suYWMudWsxCzAJBgNVBAYTAlVLMB4XDTE2MDQwMTEyMzc1NFoX\n\t\t\t\t\t\tDTI2MDMzMDEyMzc1NFowVTEiMCAGA1UEAxMZdGVzdC51bHN0ZXIudW5pZGVzay5h\n\t\t\t\t\t\tYy51azEiMCAGA1UEChMZdGVzdC51bHN0ZXIudW5pZGVzay5hYy51azELMAkGA1UE\n\t\t\t\t\t\tBhMCVUswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDJI/GFDxsFAW+6\n\t\t\t\t\t\tOu5nagpAq1Qk5Fin2rFY9BB7RS6KLhJoSgMX7ssGNXP8HYzcISCVPNXzqbfoKvcv\n\t\t\t\t\t\t7grqXAA4iuhDWgAvIgxehnByEuj1TsxPb33b1ajNYDolxjJEmU51klO7NnaPRwR6\n\t\t\t\t\t\tJJvhvzd2FzDlF9JrycTM8XbPjsTfTPXwgKfUeuxdCqlpsOb8MFyM3izEzIZkx+6N\n\t\t\t\t\t\tbpIE+KLQZgOSchYFSaHhLqu/9TBza/J95VShgaPwQTK/yOtwTO3gX8oyOCOHzypy\n\t\t\t\t\t\tKK8FylnsXQCp4EO6pNuN4b4VSp6OsrKdGKRU9oUamnR7qPzj4v8M+B6XU4mzMR3e\n\t\t\t\t\t\tZ+ZbXFxPAgMBAAGjgbgwgbUwHQYDVR0OBBYEFEe6QHlpPV401yTQq07DeOkTcAw2\n\t\t\t\t\t\tMIGFBgNVHSMEfjB8gBRHukB5aT1eNNck0KtOw3jpE3AMNqFZpFcwVTEiMCAGA1UE\n\t\t\t\t\t\tAxMZdGVzdC51bHN0ZXIudW5pZGVzay5hYy51azEiMCAGA1UEChMZdGVzdC51bHN0\n\t\t\t\t\t\tZXIudW5pZGVzay5hYy51azELMAkGA1UEBhMCVUuCCQDatci48plTiDAMBgNVHRME\n\t\t\t\t\t\tBTADAQH/MA0GCSqGSIb3DQEBCwUAA4IBAQCG0pO2+nYPsZIECStWimLJK0InGvkE\n\t\t\t\t\t\t0AM+t6qX2+6A+eRyL6Uv6weUtM3XHXC/evNV7oy7/B8fBGHxBPpHohawBS+3EH9N\n\t\t\t\t\t\t+TbyynfcetgpdVQJbfi5NEigG8kcakpjAKRykwjul1UdfRATEKxdwlvcrSTUZvt9\n\t\t\t\t\t\tu21ITIDtIC6E/oRS+2PWP5XHwoebHcFvh1uAoWUscez4FFA2PK3rUpjDR7GhIQ80\n\t\t\t\t\t\t+aFxEUr85lO9e25/1WlMNlQQCkzOHRSBKR2GXeqrfTUqeI3Ez5kumWYrmxiyXCDU\n\t\t\t\t\t\t76p9XQ/DN7/gOwewXYHVMmZTvRGfEeicsqCUwVFEV705uNkc9jvhifo3"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://test.ulster.unidesk.ac.uk/tas/secure/login/verify",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://grouper-utv.its.uu.se/shibboleth",
    {
      "entity_id": "https://grouper-utv.its.uu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://grouper-utv.its.uu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://grouper-utv.its.uu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://grouper-utv.its.uu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://grouper-utv.its.uu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://grouper-utv.its.uu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "0"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://grouper-utv.its.uu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Uppsala universitets IT-avdelnings interna Grouper f\u00f6r utvecklning"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The internal development Grouper for the IT Department at Uppsala University"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UU UTV GROUPER"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UU DEV GROUPER"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "laeta.its.uu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9DCCAdygAwIBAgIJAPhqmNfCXoJdMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2xhZXRhLml0cy51dS5zZTAeFw0xMjAyMTQxMDI3MjFaFw0yMjAyMTExMDI3\nMjFaMBoxGDAWBgNVBAMTD2xhZXRhLml0cy51dS5zZTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAL4zBv8DXuK32BxPmgj1ecXRfZe35OwJprelf4tZ25IF\ngUw5wy6YJG1dwA0rRyZTvRDgGcSjCpUtO2AAqRASM3BzvnzMJdg8aIi70c33KvvL\n486fKpfc3oUfnZ4s1WBOFiqeYAmzz85YL6F830yRw7UdN9/ysJPCVC2qilAKM7RI\niOwcrZIb8prxvoVDRFsV2wGjRP/YIyVO41ObfdWkg+tB7X7DRz127S5Mqga/YlJk\nO0NLXv4DqSqAkv9tYpTJKE0UG6oh5B9dtbtEfLYMLGamDv7y82jvmjW4qaY+Gu2G\n2yYqkon3ILleH4mk3Vath9qRRqEQVRE61xtoH0ZpADUCAwEAAaM9MDswGgYDVR0R\nBBMwEYIPbGFldGEuaXRzLnV1LnNlMB0GA1UdDgQWBBSyozmFibzGVWSCCyw/Ek5+\nPFmlgTANBgkqhkiG9w0BAQUFAAOCAQEAJ9RJgL04YiZhJFVrPHzv4QPWtHN4BRoN\nMUQeXlzQ9iz9ksl/0eN0XKJuzo5HbG0067w1OUzpZUEM8GVtBCTpOlqAJJA6lb60\nr+3KbUEejZyPZeHh9xFh1tlPkZLmn7bj/ucfTdBACRbXYniWAOn98wV1wd4eGLVG\n/VyoVi5bUhq5tCOhp5eO/xWM0gBCeRt760hZWDQ5/sgd4nkrS1Se7zWejG7Ph+Cx\nOH5QMcOlj81+M7N3qUU//X8ypY42+QHc0gUQEB8BJAzatIdjIjipoT4fhk82E84q\np9ItgP+bXhVORPr8DiYsTGUr5vfs7Q4e7etZRBJC30LQiGaerGc80Q=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=laeta.its.uu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://grouper-utv.its.uu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://grouper-utv.its.uu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://grouper-utv.its.uu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://grouper-utv.its.uu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.kutztown.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idpadmin@kutztown.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard Miller"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idpadmin@kutztown.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mitch Freed"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.kutztown.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.kutztown.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.kutztown.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAJ3D3gijWRLD8z8jAWuBcPQG+wpvMA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEGlkcC5rdXR6dG93bi5lZHUwHhcNMTMwMjAxMjA1NTA2\nWhcNMzMwMjAxMjA1NTA2WjAbMRkwFwYDVQQDExBpZHAua3V0enRvd24uZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAiaF7/maNy94CecugFCeuOkeB\nQ4RxCLf+phdRdBvEMDFErMw5blnOvX9DJjkaRVO/YqHaVGanKzDUegVNrhBVoGrO\nXOAkVce8YoDzpH2PS5pabBuB4blKr7wrQg58wIKkslgTuBMFWfjq8R+SAnufY2zt\nRhdHvlpd7/1xNQ9//i1iAwBTEfJzCUnBHxLBYyocPSluTEkIWDINyeQDi/wo3/LV\n0tYK2FPdrz+vOokXeaWu31y4OnkiEnxQKVCttWSR2jDnbt0urekR2L3kaJSq0ZRq\nvbzQGOwfAkFjAdF5JG3/O5MZbDc4Ox744ptu8/uifZV7sH6IogE80v2wPV00ZQID\nAQABo2cwZTBEBgNVHREEPTA7ghBpZHAua3V0enRvd24uZWR1hidodHRwczovL2lk\ncC5rdXR6dG93bi5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFFLsLBZyW9Pj\nMfO/2/7kbDCaS2EOMA0GCSqGSIb3DQEBBQUAA4IBAQCG1OFDvggcXym/LGpxhlB9\nbu4hZOoMmtb0KrxXeYUqVRIs1vUKfotiaPP30BoYEZS2Sbf5HQWL5NBwazGHSgDA\nWhWvEZ0AYyzo3Fgk+iCst/tMb++3yebMxjhY2hDvQmHAHtMAS2NWrg5QuAcWKNUo\n0vez+5K+GHA16PrmwwU0R1hM1k/6H0ddlFoEDvL8q/JK5EYiWBOlrKTJnx8vdSwO\nreL8ewKmZ+HT8AB0pP0jS3Cln94bvncHDNtY/PxTYNFIvLmclhT0+wN/VlCUYzF4\nHKssl2bp1LTZPwNXt8hUArVYIypb1ChoiffijKBeaBT8NSHXKQkH6Kcs6hBiHq3v"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kutztown.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.kutztown.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.kutztown.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.kutztown.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.kutztown.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.kutztown.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kutztown.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Kutztown University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAJ3D3gijWRLD8z8jAWuBcPQG+wpvMA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEGlkcC5rdXR6dG93bi5lZHUwHhcNMTMwMjAxMjA1NTA2\nWhcNMzMwMjAxMjA1NTA2WjAbMRkwFwYDVQQDExBpZHAua3V0enRvd24uZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAiaF7/maNy94CecugFCeuOkeB\nQ4RxCLf+phdRdBvEMDFErMw5blnOvX9DJjkaRVO/YqHaVGanKzDUegVNrhBVoGrO\nXOAkVce8YoDzpH2PS5pabBuB4blKr7wrQg58wIKkslgTuBMFWfjq8R+SAnufY2zt\nRhdHvlpd7/1xNQ9//i1iAwBTEfJzCUnBHxLBYyocPSluTEkIWDINyeQDi/wo3/LV\n0tYK2FPdrz+vOokXeaWu31y4OnkiEnxQKVCttWSR2jDnbt0urekR2L3kaJSq0ZRq\nvbzQGOwfAkFjAdF5JG3/O5MZbDc4Ox744ptu8/uifZV7sH6IogE80v2wPV00ZQID\nAQABo2cwZTBEBgNVHREEPTA7ghBpZHAua3V0enRvd24uZWR1hidodHRwczovL2lk\ncC5rdXR6dG93bi5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFFLsLBZyW9Pj\nMfO/2/7kbDCaS2EOMA0GCSqGSIb3DQEBBQUAA4IBAQCG1OFDvggcXym/LGpxhlB9\nbu4hZOoMmtb0KrxXeYUqVRIs1vUKfotiaPP30BoYEZS2Sbf5HQWL5NBwazGHSgDA\nWhWvEZ0AYyzo3Fgk+iCst/tMb++3yebMxjhY2hDvQmHAHtMAS2NWrg5QuAcWKNUo\n0vez+5K+GHA16PrmwwU0R1hM1k/6H0ddlFoEDvL8q/JK5EYiWBOlrKTJnx8vdSwO\nreL8ewKmZ+HT8AB0pP0jS3Cln94bvncHDNtY/PxTYNFIvLmclhT0+wN/VlCUYzF4\nHKssl2bp1LTZPwNXt8hUArVYIypb1ChoiffijKBeaBT8NSHXKQkH6Kcs6hBiHq3v"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idp.kutztown.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Kutztown University of Pennsylvania"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kutztown.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Kutztown University of Pennsylvania"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://educonf-directory.geant.net/simplesaml/module.php/saml/sp/metadata.php/eduCONF",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@geant.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "eduCONF"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:educonf@geant.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "eduCONF VC Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://educonf-directory.geant.net/simplesaml/module.php/saml/sp/metadata.php/eduCONF",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-05-28T13:11:24Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "G\u00c9ANT Intranet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.geant.net/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "G\u00c9ANT Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://educonf-directory.geant.net/simplesaml/module.php/saml/sp/saml2-logout.php/eduCONF",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "eduCONF supports and facilitates the use and adoption of videoconferencing, simplifying the videoconference experience and reducing operational costs. It enables further integration of the NRENs\u2019 videoconferencing services within a coherent service, reduces travel costs, environmental impact and increases the awareness of Partners\u2019 videoconferencing services across Europe."
                  }
                ],
                "logo": [
                  {
                    "text": "https://educonf-directory.geant.net/pic/eduCONF_logo.png",
                    "lang": "en",
                    "height": "96",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "350"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://educonf-directory.geant.net/privacy_policy.php"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "eduCONF"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIECTCCAvGgAwIBAgIJAPAcrGLtMuPXMA0GCSqGSIb3DQEBBAUAMGAxCzAJBgNV\n\t\t\t\t\t\tBAYTAlBMMRUwEwYDVQQIEwxXaWVsa29wb2xza2ExDzANBgNVBAcTBlBvem5hbjEN\n\t\t\t\t\t\tMAsGA1UEChMEUFNOQzELMAkGA1UECxMCTkQxDTALBgNVBAMTBFBTTkMwHhcNMTQw\n\t\t\t\t\t\tMzI1MTI0MTI2WhcNMjQwMzI0MTI0MTI2WjBgMQswCQYDVQQGEwJQTDEVMBMGA1UE\n\t\t\t\t\t\tCBMMV2llbGtvcG9sc2thMQ8wDQYDVQQHEwZQb3puYW4xDTALBgNVBAoTBFBTTkMx\n\t\t\t\t\t\tCzAJBgNVBAsTAk5EMQ0wCwYDVQQDEwRQU05DMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAprLbGmrldyPqbXlk5Y2mE78VYdLbsn6/LtQEVO4UNuYU6kxK\n\t\t\t\t\t\thy38FDjZ20Zrsgjz4fspJxP08yjeyw2qGGVcZXJRZAlJ3IRhjLlq9cZi5t5XDA4A\n\t\t\t\t\t\tHfD+LSzUFmllZdNRS6oOceLXRkR7BYeHVeMYQHLTc6SABjCSs9oDpGwlxj8iHqbH\n\t\t\t\t\t\tP50zh7PxBNxRv8PlEgsWEgGZ5Vgk1U1sT0490t7VB7ksqO+ka0BLQORPmZj7JNiJ\n\t\t\t\t\t\tOn20X7w/fXeSTcOgRcoGhf9d5QaOU/k7yP4BPXx1fX6gPsPM63zJzvtKfD/3WCdj\n\t\t\t\t\t\ttqHHhEC1IP6eYzM3PJNa67N0HMiwzxpjjAPv+wIDAQABo4HFMIHCMB0GA1UdDgQW\n\t\t\t\t\t\tBBTzO8Ze8XJHf1jHWJ30yMxIB1BpXzCBkgYDVR0jBIGKMIGHgBTzO8Ze8XJHf1jH\n\t\t\t\t\t\tWJ30yMxIB1BpX6FkpGIwYDELMAkGA1UEBhMCUEwxFTATBgNVBAgTDFdpZWxrb3Bv\n\t\t\t\t\t\tbHNrYTEPMA0GA1UEBxMGUG96bmFuMQ0wCwYDVQQKEwRQU05DMQswCQYDVQQLEwJO\n\t\t\t\t\t\tRDENMAsGA1UEAxMEUFNOQ4IJAPAcrGLtMuPXMAwGA1UdEwQFMAMBAf8wDQYJKoZI\n\t\t\t\t\t\thvcNAQEEBQADggEBAEUL4IvCbJkcFE976QP/9k+zN5aXOXIIW7CSH1KJLjvCY0UJ\n\t\t\t\t\t\tKzz+hzdaYIQ08DYq++SI+P0tUX3joUkPCQPCKiddGtRCaQLtvkl4Jt8S+eqC9rX2\n\t\t\t\t\t\tl+A/wry/VIjxpntaz+A+Vwz1FEiuUAHrMAchJnuCEaGXOZ9NSLErOTD6d7e2j6+5\n\t\t\t\t\t\t1Jy2cd/WUFGtxlhkMPD4Zax1uKiJj3Ptw1Q4pBPFKNLsyObFWL2igel2fEVGxxBH\n\t\t\t\t\t\tAXaXuUUk8l+3BWmYoCbsZdnN36DqXqsK1NLhCCl+VIYEvr62U0B4AWlLcCfyt4Dy\n\t\t\t\t\t\t7eK+5ZFB6MaRVtCwdykxbQQXWNv60u8dwrbkTqk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIECTCCAvGgAwIBAgIJAPAcrGLtMuPXMA0GCSqGSIb3DQEBBAUAMGAxCzAJBgNV\n\t\t\t\t\t\tBAYTAlBMMRUwEwYDVQQIEwxXaWVsa29wb2xza2ExDzANBgNVBAcTBlBvem5hbjEN\n\t\t\t\t\t\tMAsGA1UEChMEUFNOQzELMAkGA1UECxMCTkQxDTALBgNVBAMTBFBTTkMwHhcNMTQw\n\t\t\t\t\t\tMzI1MTI0MTI2WhcNMjQwMzI0MTI0MTI2WjBgMQswCQYDVQQGEwJQTDEVMBMGA1UE\n\t\t\t\t\t\tCBMMV2llbGtvcG9sc2thMQ8wDQYDVQQHEwZQb3puYW4xDTALBgNVBAoTBFBTTkMx\n\t\t\t\t\t\tCzAJBgNVBAsTAk5EMQ0wCwYDVQQDEwRQU05DMIIBIjANBgkqhkiG9w0BAQEFAAOC\n\t\t\t\t\t\tAQ8AMIIBCgKCAQEAprLbGmrldyPqbXlk5Y2mE78VYdLbsn6/LtQEVO4UNuYU6kxK\n\t\t\t\t\t\thy38FDjZ20Zrsgjz4fspJxP08yjeyw2qGGVcZXJRZAlJ3IRhjLlq9cZi5t5XDA4A\n\t\t\t\t\t\tHfD+LSzUFmllZdNRS6oOceLXRkR7BYeHVeMYQHLTc6SABjCSs9oDpGwlxj8iHqbH\n\t\t\t\t\t\tP50zh7PxBNxRv8PlEgsWEgGZ5Vgk1U1sT0490t7VB7ksqO+ka0BLQORPmZj7JNiJ\n\t\t\t\t\t\tOn20X7w/fXeSTcOgRcoGhf9d5QaOU/k7yP4BPXx1fX6gPsPM63zJzvtKfD/3WCdj\n\t\t\t\t\t\ttqHHhEC1IP6eYzM3PJNa67N0HMiwzxpjjAPv+wIDAQABo4HFMIHCMB0GA1UdDgQW\n\t\t\t\t\t\tBBTzO8Ze8XJHf1jHWJ30yMxIB1BpXzCBkgYDVR0jBIGKMIGHgBTzO8Ze8XJHf1jH\n\t\t\t\t\t\tWJ30yMxIB1BpX6FkpGIwYDELMAkGA1UEBhMCUEwxFTATBgNVBAgTDFdpZWxrb3Bv\n\t\t\t\t\t\tbHNrYTEPMA0GA1UEBxMGUG96bmFuMQ0wCwYDVQQKEwRQU05DMQswCQYDVQQLEwJO\n\t\t\t\t\t\tRDENMAsGA1UEAxMEUFNOQ4IJAPAcrGLtMuPXMAwGA1UdEwQFMAMBAf8wDQYJKoZI\n\t\t\t\t\t\thvcNAQEEBQADggEBAEUL4IvCbJkcFE976QP/9k+zN5aXOXIIW7CSH1KJLjvCY0UJ\n\t\t\t\t\t\tKzz+hzdaYIQ08DYq++SI+P0tUX3joUkPCQPCKiddGtRCaQLtvkl4Jt8S+eqC9rX2\n\t\t\t\t\t\tl+A/wry/VIjxpntaz+A+Vwz1FEiuUAHrMAchJnuCEaGXOZ9NSLErOTD6d7e2j6+5\n\t\t\t\t\t\t1Jy2cd/WUFGtxlhkMPD4Zax1uKiJj3Ptw1Q4pBPFKNLsyObFWL2igel2fEVGxxBH\n\t\t\t\t\t\tAXaXuUUk8l+3BWmYoCbsZdnN36DqXqsK1NLhCCl+VIYEvr62U0B4AWlLcCfyt4Dy\n\t\t\t\t\t\t7eK+5ZFB6MaRVtCwdykxbQQXWNv60u8dwrbkTqk="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://educonf-directory.geant.net/simplesaml/module.php/saml/sp/saml2-acs.php/eduCONF",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://educonf-directory.geant.net/simplesaml/module.php/saml/sp/saml1-acs.php/eduCONF",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://educonf-directory.geant.net/simplesaml/module.php/saml/sp/saml2-acs.php/eduCONF",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://educonf-directory.geant.net/simplesaml/module.php/saml/sp/saml1-acs.php/eduCONF/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "eduCONF"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "eduCONF supports and facilitates the use and adoption of videoconferencing, simplifying the videoconference experience and reducing operational costs. It enables further integration of the NRENs\u2019 videoconferencing services within a coherent service, reduces travel costs, environmental impact and increases the awareness of Partners\u2019 videoconferencing services across Europe."
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "commonName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "surname",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.uniparthenope.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "N.Napolitano-A.Cioffi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@uniparthenope.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uniparthenope.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2011-01-11T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUaE6MYuJWXmKRLkOaoYJ7v4C0fFowDQYJKoZIhvcNAQEF\nBQAwHzEdMBsGA1UEAxMUaWRwLnVuaXBhcnRoZW5vcGUuaXQwHhcNMTAxMDExMTA1\nOTU2WhcNMzAxMDExMTA1OTU2WjAfMR0wGwYDVQQDExRpZHAudW5pcGFydGhlbm9w\nZS5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJkPb9xxWtT2CoJL\nteZJDfYsGC3ieLYzf3iE+Yb8tv/4YpEFfUlUK07FH+SBDC0gpmGyd6EhUnaQP9Lz\nHc8iIaiSCNwGy3iZyVQkbYHhiGCcgMvoIbnK2B4/DST1vRjNweCQiZsmk03O05dQ\n+JjcgEkFi+8EeSEpOu3IrACRix/FViPy8l0JOr1ftLiONl/7WdyNJorLfTym6+cY\nkwSJIOzu5+U0UTx1vQJa1RN67dydGPy68Hq9JiKrYZ9zm+n0w7rbkCe+F4oP4Pp/\nlXJhGdenDusAZpohA72CXqFMGpMoKf4ktnm1vg6o2awl6pUQTRFqjhIXdy8v6f7O\nn0W9s/sCAwEAAaNvMG0wTAYDVR0RBEUwQ4IUaWRwLnVuaXBhcnRoZW5vcGUuaXSG\nK2h0dHBzOi8vaWRwLnVuaXBhcnRoZW5vcGUuaXQvaWRwL3NoaWJib2xldGgwHQYD\nVR0OBBYEFBbCXm5gWz4H5pWLzyTs/P1rDgveMA0GCSqGSIb3DQEBBQUAA4IBAQBR\n4eYlPyqz4G+EwI5vRbPA+1MZ3C4NNowmgkzvZVYhyuHNvYXqk0AvfyCTbi9fpPjk\nK87fkCo6qmaQAHlUE0ZxPzCbR1tRGoOVGAszMesh1whopFxHlfh9/zIFHocE2VDz\nQ3X5Orpt5M7J0Q56cXquYh3EuIFmYByXzK9hTOAiDq55n1QQ2nvQHItC4Jkp7GeO\nc5D59ahcQWgbzHw5WbJqHuT2JvU+jF8w08RZbxQLCWEQHPKfwCBuKLQy8R4tWbDr\nNMFx4IIXL5k2bXFtVidG02j1Mw66zjER3tinreZdr4emOtqomO0kR0kpYkGeqJDU\ncReeVaTfudJyy/pCjfbP"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uniparthenope.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uniparthenope.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uniparthenope.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.uniparthenope.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.uniparthenope.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.uniparthenope.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uniparthenope.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.uniparthenope.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.uniparthenope.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uniparthenope.it"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for PARTHENOPE University member"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli afferenti alla Universita' PARTHENOPE"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 di Napoli Parthenope"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 di Napoli Parthenope"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDOzCCAiOgAwIBAgIUaE6MYuJWXmKRLkOaoYJ7v4C0fFowDQYJKoZIhvcNAQEF\nBQAwHzEdMBsGA1UEAxMUaWRwLnVuaXBhcnRoZW5vcGUuaXQwHhcNMTAxMDExMTA1\nOTU2WhcNMzAxMDExMTA1OTU2WjAfMR0wGwYDVQQDExRpZHAudW5pcGFydGhlbm9w\nZS5pdDCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJkPb9xxWtT2CoJL\nteZJDfYsGC3ieLYzf3iE+Yb8tv/4YpEFfUlUK07FH+SBDC0gpmGyd6EhUnaQP9Lz\nHc8iIaiSCNwGy3iZyVQkbYHhiGCcgMvoIbnK2B4/DST1vRjNweCQiZsmk03O05dQ\n+JjcgEkFi+8EeSEpOu3IrACRix/FViPy8l0JOr1ftLiONl/7WdyNJorLfTym6+cY\nkwSJIOzu5+U0UTx1vQJa1RN67dydGPy68Hq9JiKrYZ9zm+n0w7rbkCe+F4oP4Pp/\nlXJhGdenDusAZpohA72CXqFMGpMoKf4ktnm1vg6o2awl6pUQTRFqjhIXdy8v6f7O\nn0W9s/sCAwEAAaNvMG0wTAYDVR0RBEUwQ4IUaWRwLnVuaXBhcnRoZW5vcGUuaXSG\nK2h0dHBzOi8vaWRwLnVuaXBhcnRoZW5vcGUuaXQvaWRwL3NoaWJib2xldGgwHQYD\nVR0OBBYEFBbCXm5gWz4H5pWLzyTs/P1rDgveMA0GCSqGSIb3DQEBBQUAA4IBAQBR\n4eYlPyqz4G+EwI5vRbPA+1MZ3C4NNowmgkzvZVYhyuHNvYXqk0AvfyCTbi9fpPjk\nK87fkCo6qmaQAHlUE0ZxPzCbR1tRGoOVGAszMesh1whopFxHlfh9/zIFHocE2VDz\nQ3X5Orpt5M7J0Q56cXquYh3EuIFmYByXzK9hTOAiDq55n1QQ2nvQHItC4Jkp7GeO\nc5D59ahcQWgbzHw5WbJqHuT2JvU+jF8w08RZbxQLCWEQHPKfwCBuKLQy8R4tWbDr\nNMFx4IIXL5k2bXFtVidG02j1Mw66zjER3tinreZdr4emOtqomO0kR0kpYkGeqJDU\ncReeVaTfudJyy/pCjfbP"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 di Napoli Parthenope"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 di Napoli Parthenope"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uniparthenope.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uniparthenope.it"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 di Napoli Parthenope"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 di Napoli Parthenope"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://aai-logon.psi.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "support",
          "telephone_number": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&TelephoneNumber",
              "text": "+41 56 310 8400"
            }
          ],
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Helpdesk"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@psi.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "PSI"
          }
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aai-support@psi.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "AAI"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://aai-logon.psi.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2015-03-10T15:13:37Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIJALQ2EjQw+BiNMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGFhaS1sb2dvbi5wc2kuY2gwHhcNMTMxMTI2MDg1MjQ2WhcNMTYxMTI1MDg1\nMjQ2WjAbMRkwFwYDVQQDExBhYWktbG9nb24ucHNpLmNoMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA53/6MrJPHxt8oigLyUvYLR83hN2cu3GbPfjBB4VJ\nkpQisdb3jaGRiwJFjVuc1THr3Ov/cNmQ2ONQaIIvJ5d2BEmkvUj1tSnwR2CfDmGy\n0lEPxjD5Da++9P/S/sCdClR+1RwPAVH8ravfWYPEi6Jgzw5iSR5Jx3MD3cK7KHw2\nPliko6+ibmVf56nfHRTJpPjJ9EGiSH9GBrmpPH8r+a0gUm9Mb1Mdk+Df+nMxUo9H\nIY4YoLRgFpcWXdWLM0TxzXM8bdVDoel96FvMITgNIDktb6Ml5MCm/9rrxLcVUelx\n/xtNa88PYtRmsqsQUY4ZAKwANyKNeUHZBADLHaNLepKhiwIDAQABo2cwZTBEBgNV\nHREEPTA7ghBhYWktbG9nb24ucHNpLmNohidodHRwczovL2FhaS1sb2dvbi5wc2ku\nY2gvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFNazc1/qrmmqgEVueIN62F390Kni\nMA0GCSqGSIb3DQEBBQUAA4IBAQAAZuFgMpEZjoq8pxLjbQDtfw5NTG1Wggmefv4M\nomMi3arqsiYQTUuMKwj6T5B08lPUV0kGIhCNBANLBxw+2UxFo266dWD5g703RFdn\nEeMlJ6Uro2niBUSl/FqDJ2i5t9yOP8CS6lEBvWo3CwJye5uo1YFQFP7W/rnvjhSp\nkQL8Jo3n/ZJbIImhG9pYBDJFK1D4UA0zxfOZ0Vt3rG6hnGiMDZ6S8l34axecTT1o\naAOK+xJsXSM4wiULQuUiqaqUQkUqowD35dc8NuH1KZa4TgpLacCbKEN4d6XibSQf\n5ESwtfL8jg5PPnAfIXXSYewO0a7Unlt+BbpkQ7KCOkpPLzNB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "psi.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-logon.psi.ch:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-logon.psi.ch:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aai-logon.psi.ch/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai-logon.psi.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai-logon.psi.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aai-logon.psi.ch/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-logon.psi.ch:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-logon.psi.ch:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "psi.ch"
              },
              {
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Paul Scherrer Institut"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Paul Scherrer Institute"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PSI - Paul Scherrer Institut"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PSI - Paul Scherrer Institute"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "psi.ch"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "psilab.ch"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:47.537688,8.222623"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.0.32/28"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:620:170::/48"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "129.129.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.118.0/23"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.33.120.0/21"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "error_url": "http://ait.web.psi.ch/us/",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIJALQ2EjQw+BiNMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGFhaS1sb2dvbi5wc2kuY2gwHhcNMTMxMTI2MDg1MjQ2WhcNMTYxMTI1MDg1\nMjQ2WjAbMRkwFwYDVQQDExBhYWktbG9nb24ucHNpLmNoMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA53/6MrJPHxt8oigLyUvYLR83hN2cu3GbPfjBB4VJ\nkpQisdb3jaGRiwJFjVuc1THr3Ov/cNmQ2ONQaIIvJ5d2BEmkvUj1tSnwR2CfDmGy\n0lEPxjD5Da++9P/S/sCdClR+1RwPAVH8ravfWYPEi6Jgzw5iSR5Jx3MD3cK7KHw2\nPliko6+ibmVf56nfHRTJpPjJ9EGiSH9GBrmpPH8r+a0gUm9Mb1Mdk+Df+nMxUo9H\nIY4YoLRgFpcWXdWLM0TxzXM8bdVDoel96FvMITgNIDktb6Ml5MCm/9rrxLcVUelx\n/xtNa88PYtRmsqsQUY4ZAKwANyKNeUHZBADLHaNLepKhiwIDAQABo2cwZTBEBgNV\nHREEPTA7ghBhYWktbG9nb24ucHNpLmNohidodHRwczovL2FhaS1sb2dvbi5wc2ku\nY2gvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFNazc1/qrmmqgEVueIN62F390Kni\nMA0GCSqGSIb3DQEBBQUAA4IBAQAAZuFgMpEZjoq8pxLjbQDtfw5NTG1Wggmefv4M\nomMi3arqsiYQTUuMKwj6T5B08lPUV0kGIhCNBANLBxw+2UxFo266dWD5g703RFdn\nEeMlJ6Uro2niBUSl/FqDJ2i5t9yOP8CS6lEBvWo3CwJye5uo1YFQFP7W/rnvjhSp\nkQL8Jo3n/ZJbIImhG9pYBDJFK1D4UA0zxfOZ0Vt3rG6hnGiMDZ6S8l34axecTT1o\naAOK+xJsXSM4wiULQuUiqaqUQkUqowD35dc8NuH1KZa4TgpLacCbKEN4d6XibSQf\n5ESwtfL8jg5PPnAfIXXSYewO0a7Unlt+BbpkQ7KCOkpPLzNB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PSI - Paul Scherrer Institut"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PSI - Paul Scherrer Institute"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.psi.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.psi.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "psi.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.brandeis.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jwilson@brandeis.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Josh Wilson"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "irifkin@brandeis.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian Rifkin"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jlambert@brandeis.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jim Lambert"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "e-resources@brandeis.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Library Systems"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.brandeis.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.brandeis.edu/cgi-bin/logout",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.brandeis.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.brandeis.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.brandeis.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.brandeis.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.brandeis.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brandeis.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Brandeis University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSDCCAjCgAwIBAgIVAJ07ki+U+Q1jeqL9/EKoyRbWCMAyMA0GCSqGSIb3DQEB\nBQUAMCIxIDAeBgNVBAMTF3NoaWJib2xldGguYnJhbmRlaXMuZWR1MB4XDTEzMDMw\nODIwMTczOVoXDTMzMDMwODIwMTczOVowIjEgMB4GA1UEAxMXc2hpYmJvbGV0aC5i\ncmFuZGVpcy5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCKZIwW\nKwP8VTEQc8aR/fukHycUON1HPpq7LoIjINdzuzMR2C6ZdNRMzbR+4qkQRdeW6Ptp\n9L7C0HMEeIPRhEFh6gdAgl3VwyyDgz/fqMHpXNQn/7Tw+vl3I2Joha69iNQK3K6I\ngNI2E/x2b8YizudhSSCu3RAm7vPLN3gcyc2sRA3KkXvaEWO0jU7GJVTmaCgRpCH0\nBsv5vZ724UMuuPP1Feu4nhKtqRm0khEA9svRGfDVxhWnPpg8rLT9Yu03IChN8hdq\nNspAQCmDI2OFQB5frAuiQ9MQT7Q9jzBSJ3bcWQsYsdbWNG7Hpl2hBSlUtqR5tzat\niU1U1LsZAv/wQbgLAgMBAAGjdTBzMFIGA1UdEQRLMEmCF3NoaWJib2xldGguYnJh\nbmRlaXMuZWR1hi5odHRwczovL3NoaWJib2xldGguYnJhbmRlaXMuZWR1L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBQPTVgZcvtUxjYUCn8mj6n/ldo5zjANBgkqhkiG\n9w0BAQUFAAOCAQEAVGtWGwmb6iIG3sbWiBvuayHCmiWCl3rZN/CpFYxU5p9Xcuu6\nlcTq6wAY04Cs/v4rjStdsH1REnI6CUyOcLzVCK55bhpyvLCTxQYAaULVg95UmZF2\nKkr0LXmXHkOfG7nTwY8Qm13tfBAPwqNdHmstlMvw3LAgmy96heq+bHryqbTYKC/V\ndTdUuhV14vl7PJt9y3EqXISJjwNG7wEF9wM0qUIG51qlp4f4MiNaNxJI/cYUC1cw\n7d/XK0tGHAwQxu/IeOIxUYbsUbTSua3u/Xc6WaTwfWxSl96NcOuTnyazB4hkSIYa\nC30ze3MSAph0HLqEHTWk8Ldt2Y3QWku9g5WNlA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Brandeis University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.brandeis.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Brandeis University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib.uni-mainz.de/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Glatzer"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:glatzert@uni-mainz.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Thomas"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hotline"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:hotline@uni-mainz.de"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ZDV"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib.uni-mainz.de/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/en/join/"
              },
              {
                "lang": "de",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.aai.dfn.de/teilnahme/"
              }
            ],
            "registration_instant": "2011-05-17T15:01:00Z",
            "registration_authority": "https://www.aai.dfn.de",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shib.uni-mainz.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF2jCCBMKgAwIBAgIHFUXfZ4347jANBgkqhkiG9w0BAQUFADCBojELMAkGA1UE\nBhMCREUxGDAWBgNVBAgTD1JoZWlubGFuZC1QZmFsejEOMAwGA1UEBxMFTWFpbnox\nLjAsBgNVBAoTJUpvaGFubmVzIEd1dGVuYmVyZy1Vbml2ZXJzaXRhZXQgTWFpbnox\nFTATBgNVBAMTDEpHVSBDQSAtIEcwMTEiMCAGCSqGSIb3DQEJARYTamd1LWNhQHVu\naS1tYWluei5kZTAeFw0xMzAyMjExODA1MTFaFw0xODAyMjAxODA1MTFaMIGDMQsw\nCQYDVQQGEwJERTEYMBYGA1UECBMPUmhlaW5sYW5kLVBmYWx6MQ4wDAYDVQQHEwVN\nYWluejEuMCwGA1UEChMlSm9oYW5uZXMgR3V0ZW5iZXJnLVVuaXZlcnNpdGFldCBN\nYWluejEaMBgGA1UEAxMRc2hpYi51bmktbWFpbnouZGUwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQC5V0tZG9Ic9Nov70JfqfO4t9GcozAWBXJGMQMfbIfL\nZmt564t5+et+oOWgKtVFj2+RmqlBvbxU53XavGsBvA6jNLsjOxQWUQMY8KrkU9aI\naN2mNoOJ9ehD3yZ6F9Gbm0SF3QqwbeoRpjQcZeIO3o/PkII0kQm2mq+3eCSH+kAa\nc6PgaER/TjB3OvATmWrWMQ6zFvzjnmYpXJgbiC+a00gNrjRzwM2W9OWcXCzEy+vI\nKGxa3HPpoRuTWH+4ZX1kaexXr9qc5AFdh/mkfyPh7A6plSdNNz688jH40Ve9nmTe\nafnRWqrnQg8/+hKSq8eV+aR7ljJMgS5WxDn/THZL8p43AgMBAAGjggIwMIICLDA5\nBgNVHSAEMjAwMBEGDysGAQQBga0hgiwBAQQDADARBg8rBgEEAYGtIYIsAgEEAwAw\nCAYGZ4EMAQICMAkGA1UdEwQCMAAwCwYDVR0PBAQDAgXgMB0GA1UdJQQWMBQGCCsG\nAQUFBwMCBggrBgEFBQcDATAdBgNVHQ4EFgQUCThNUyURKm/PrBqSzVV5GNlLnfcw\nHwYDVR0jBBgwFoAUMxg5PVU0WHCjrK/wjPuaRyI9T80wHAYDVR0RBBUwE4IRc2hp\nYi51bmktbWFpbnouZGUwgYMGA1UdHwR8MHowO6A5oDeGNWh0dHA6Ly9jZHAxLnBj\nYS5kZm4uZGUvdW5pLW1haW56LWNhL3B1Yi9jcmwvY2FjcmwuY3JsMDugOaA3hjVo\ndHRwOi8vY2RwMi5wY2EuZGZuLmRlL3VuaS1tYWluei1jYS9wdWIvY3JsL2NhY3Js\nLmNybDCB0wYIKwYBBQUHAQEEgcYwgcMwMwYIKwYBBQUHMAGGJ2h0dHA6Ly9vY3Nw\nLnBjYS5kZm4uZGUvT0NTUC1TZXJ2ZXIvT0NTUDBFBggrBgEFBQcwAoY5aHR0cDov\nL2NkcDEucGNhLmRmbi5kZS91bmktbWFpbnotY2EvcHViL2NhY2VydC9jYWNlcnQu\nY3J0MEUGCCsGAQUFBzAChjlodHRwOi8vY2RwMi5wY2EuZGZuLmRlL3VuaS1tYWlu\nei1jYS9wdWIvY2FjZXJ0L2NhY2VydC5jcnQwDQYJKoZIhvcNAQEFBQADggEBAGX8\naJBr9XXcme9DVKbjX1ZxWxX6PfFYZ6LnwzTlCaVzoFyhn4TgjhDrD+nONfNnTaBg\n51dhMCb8pxO/EVJ9ARk0G7sXdn9RXmWpz3h2isf0GkqPQmmoNwcYzMLUdhzcbT9B\nbirS0hKIA90L8mDmUfq1xC+fubW5RVgM/WD5mwTamU0i/iJ7F5kkS3iPNtMz60A0\nZt2tbiyWnF28DXObhDp6tKRbnaEyX1/lTSNVHB20tvj4yPhfNgy6BINSpkPa3Otg\nrmPKXapBTUXw83z+IQnGkFBKypI3ceETkGaydx+aHwCyL9WBKRC87GfKFSvB620e\nQlWpyRQfOn6GOvmhDbM="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=shib.uni-mainz.de,O=Johannes Gutenberg-Universitaet Mainz,L=Mainz,ST=Rheinland-Pfalz,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uni-mainz.de"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.uni-mainz.de:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.uni-mainz.de:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.uni-mainz.de/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.uni-mainz.de/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.uni-mainz.de/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.uni-mainz.de/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.uni-mainz.de:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.uni-mainz.de:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uni-mainz.de"
              },
              {
                "information_url": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uni-mainz.de"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uni-mainz.de"
                  }
                ],
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Single-Sign-On der Johannes Gutenberg-Universit\u00e4t Mainz"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Single-Sign-On der Johannes Gutenberg-Universit\u00e4t Mainz"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e4t Mainz"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e4t Mainz"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shib.uni-mainz.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF2jCCBMKgAwIBAgIHFUXfZ4347jANBgkqhkiG9w0BAQUFADCBojELMAkGA1UE\nBhMCREUxGDAWBgNVBAgTD1JoZWlubGFuZC1QZmFsejEOMAwGA1UEBxMFTWFpbnox\nLjAsBgNVBAoTJUpvaGFubmVzIEd1dGVuYmVyZy1Vbml2ZXJzaXRhZXQgTWFpbnox\nFTATBgNVBAMTDEpHVSBDQSAtIEcwMTEiMCAGCSqGSIb3DQEJARYTamd1LWNhQHVu\naS1tYWluei5kZTAeFw0xMzAyMjExODA1MTFaFw0xODAyMjAxODA1MTFaMIGDMQsw\nCQYDVQQGEwJERTEYMBYGA1UECBMPUmhlaW5sYW5kLVBmYWx6MQ4wDAYDVQQHEwVN\nYWluejEuMCwGA1UEChMlSm9oYW5uZXMgR3V0ZW5iZXJnLVVuaXZlcnNpdGFldCBN\nYWluejEaMBgGA1UEAxMRc2hpYi51bmktbWFpbnouZGUwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQC5V0tZG9Ic9Nov70JfqfO4t9GcozAWBXJGMQMfbIfL\nZmt564t5+et+oOWgKtVFj2+RmqlBvbxU53XavGsBvA6jNLsjOxQWUQMY8KrkU9aI\naN2mNoOJ9ehD3yZ6F9Gbm0SF3QqwbeoRpjQcZeIO3o/PkII0kQm2mq+3eCSH+kAa\nc6PgaER/TjB3OvATmWrWMQ6zFvzjnmYpXJgbiC+a00gNrjRzwM2W9OWcXCzEy+vI\nKGxa3HPpoRuTWH+4ZX1kaexXr9qc5AFdh/mkfyPh7A6plSdNNz688jH40Ve9nmTe\nafnRWqrnQg8/+hKSq8eV+aR7ljJMgS5WxDn/THZL8p43AgMBAAGjggIwMIICLDA5\nBgNVHSAEMjAwMBEGDysGAQQBga0hgiwBAQQDADARBg8rBgEEAYGtIYIsAgEEAwAw\nCAYGZ4EMAQICMAkGA1UdEwQCMAAwCwYDVR0PBAQDAgXgMB0GA1UdJQQWMBQGCCsG\nAQUFBwMCBggrBgEFBQcDATAdBgNVHQ4EFgQUCThNUyURKm/PrBqSzVV5GNlLnfcw\nHwYDVR0jBBgwFoAUMxg5PVU0WHCjrK/wjPuaRyI9T80wHAYDVR0RBBUwE4IRc2hp\nYi51bmktbWFpbnouZGUwgYMGA1UdHwR8MHowO6A5oDeGNWh0dHA6Ly9jZHAxLnBj\nYS5kZm4uZGUvdW5pLW1haW56LWNhL3B1Yi9jcmwvY2FjcmwuY3JsMDugOaA3hjVo\ndHRwOi8vY2RwMi5wY2EuZGZuLmRlL3VuaS1tYWluei1jYS9wdWIvY3JsL2NhY3Js\nLmNybDCB0wYIKwYBBQUHAQEEgcYwgcMwMwYIKwYBBQUHMAGGJ2h0dHA6Ly9vY3Nw\nLnBjYS5kZm4uZGUvT0NTUC1TZXJ2ZXIvT0NTUDBFBggrBgEFBQcwAoY5aHR0cDov\nL2NkcDEucGNhLmRmbi5kZS91bmktbWFpbnotY2EvcHViL2NhY2VydC9jYWNlcnQu\nY3J0MEUGCCsGAQUFBzAChjlodHRwOi8vY2RwMi5wY2EuZGZuLmRlL3VuaS1tYWlu\nei1jYS9wdWIvY2FjZXJ0L2NhY2VydC5jcnQwDQYJKoZIhvcNAQEFBQADggEBAGX8\naJBr9XXcme9DVKbjX1ZxWxX6PfFYZ6LnwzTlCaVzoFyhn4TgjhDrD+nONfNnTaBg\n51dhMCb8pxO/EVJ9ARk0G7sXdn9RXmWpz3h2isf0GkqPQmmoNwcYzMLUdhzcbT9B\nbirS0hKIA90L8mDmUfq1xC+fubW5RVgM/WD5mwTamU0i/iJ7F5kkS3iPNtMz60A0\nZt2tbiyWnF28DXObhDp6tKRbnaEyX1/lTSNVHB20tvj4yPhfNgy6BINSpkPa3Otg\nrmPKXapBTUXw83z+IQnGkFBKypI3ceETkGaydx+aHwCyL9WBKRC87GfKFSvB620e\nQlWpyRQfOn6GOvmhDbM="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=shib.uni-mainz.de,O=Johannes Gutenberg-Universitaet Mainz,L=Mainz,ST=Rheinland-Pfalz,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "shib.uni-mainz.de"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIF8DCCBNigAwIBAgIHGlGNEMJrKTANBgkqhkiG9w0BAQsFADCBojELMAkGA1UE\nBhMCREUxGDAWBgNVBAgTD1JoZWlubGFuZC1QZmFsejEOMAwGA1UEBxMFTWFpbnox\nLjAsBgNVBAoTJUpvaGFubmVzIEd1dGVuYmVyZy1Vbml2ZXJzaXRhZXQgTWFpbnox\nFTATBgNVBAMTDEpHVSBDQSAtIEcwMTEiMCAGCSqGSIb3DQEJARYTamd1LWNhQHVu\naS1tYWluei5kZTAeFw0xNTEwMjkxMjIyMjVaFw0xOTAxMjUxMjIyMjVaMIGDMQsw\nCQYDVQQGEwJERTEYMBYGA1UECAwPUmhlaW5sYW5kLVBmYWx6MQ4wDAYDVQQHDAVN\nYWluejEuMCwGA1UECgwlSm9oYW5uZXMgR3V0ZW5iZXJnLVVuaXZlcnNpdGFldCBN\nYWluejEaMBgGA1UEAwwRc2hpYi51bmktbWFpbnouZGUwggEiMA0GCSqGSIb3DQEB\nAQUAA4IBDwAwggEKAoIBAQDcpVmR0l6m/MrnlyY/LgILDGUMLHf/m7X8NI5Lju0s\nRNQYdTk0jZ3SfW7hoIbeCOW1W8cDjPsyYl13cU1FYsQ/43W4qKLR1+0A/bZ05CDH\n5yDV3yGaFLWzzomQ6eHEpgFHOuNpySsXJ4MXsfObkL3yTD9CgiuS1XqpCQHx6TOM\nYVFrjoNLKukCp7flG+/OFueVN0uUwL7huomGKtIXPQFprT+q06EqbdNszcq2bt3l\nFWmEUwbAK66wTNJvkFEa3fgbsW1DuIK+oDeA6hr0dHb8tirA4ww97y3upNqKTSBd\nz7lr/xD1S6Hl7A8xKWTSORzpbsoptsT3dsvB/1tqPUMzAgMBAAGjggJGMIICQjBZ\nBgNVHSAEUjBQMBEGDysGAQQBga0hgiwBAQQDBDARBg8rBgEEAYGtIYIsAgEEAwEw\nDwYNKwYBBAGBrSGCLAEBBDANBgsrBgEEAYGtIYIsHjAIBgZngQwBAgIwCQYDVR0T\nBAIwADALBgNVHQ8EBAMCBPAwEwYDVR0lBAwwCgYIKwYBBQUHAwEwHQYDVR0OBBYE\nFM+hafRdjETrrKia7HYSPoPA4/XfMB8GA1UdIwQYMBaAFDMYOT1VNFhwo6yv8Iz7\nmkciPU/NMBwGA1UdEQQVMBOCEXNoaWIudW5pLW1haW56LmRlMIGDBgNVHR8EfDB6\nMDugOaA3hjVodHRwOi8vY2RwMS5wY2EuZGZuLmRlL3VuaS1tYWluei1jYS9wdWIv\nY3JsL2NhY3JsLmNybDA7oDmgN4Y1aHR0cDovL2NkcDIucGNhLmRmbi5kZS91bmkt\nbWFpbnotY2EvcHViL2NybC9jYWNybC5jcmwwgdMGCCsGAQUFBwEBBIHGMIHDMDMG\nCCsGAQUFBzABhidodHRwOi8vb2NzcC5wY2EuZGZuLmRlL09DU1AtU2VydmVyL09D\nU1AwRQYIKwYBBQUHMAKGOWh0dHA6Ly9jZHAxLnBjYS5kZm4uZGUvdW5pLW1haW56\nLWNhL3B1Yi9jYWNlcnQvY2FjZXJ0LmNydDBFBggrBgEFBQcwAoY5aHR0cDovL2Nk\ncDIucGNhLmRmbi5kZS91bmktbWFpbnotY2EvcHViL2NhY2VydC9jYWNlcnQuY3J0\nMA0GCSqGSIb3DQEBCwUAA4IBAQCQACHxVetQU3UZoPVLDeXWTl6SBU8MAKNw6z6Y\nVRts0YC7bPUy44M+JT8nyQtZ3i/iiv7LpsGlAXhAI8V33vdckcKVAfzKW72dLHqb\nuVfNgNg51oOc3GfnEZ/CiqMeb24IThvhL05d2ozo5Sp455cUU5WumLERYQyYqkrO\nM6VaDqej+QIgKFmUHqDy1MpFFr1cmTQa0G8aCccAHPzMDzpsy4ixjL+MeV/XQDr3\n4Wjha/zHnj7H5lVSNXdKuo8JwBERv5nf++6IiJs8R7agG7h9Lg9sc5oXyY+dv3pO\nKYeXaQluI5vCZTsL0vjTNZ1kphU4MWsXGXXtiP5p2G+cZw8s"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=shib.uni-mainz.de,O=Johannes Gutenberg-Universitaet Mainz,L=Mainz,ST=Rheinland-Pfalz,C=DE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Johannes Gutenberg-Universit\u00e4t Mainz"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Johannes Gutenberg-Universit\u00e4t Mainz"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-mainz.de"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uni-mainz.de"
          }
        ],
        "organization_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e265"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "e265"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://auth.aspirationtraining.com/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Overt Software Solutions Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@overtsoftware.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Overt Software Solutions Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://auth.aspirationtraining.com/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-01-09T17:13:45Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDejCCAmICCQDX1cojLXODTzANBgkqhkiG9w0BAQUFADB/MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEXMBUGA1UECAwOV29yY2VzdGVyc2hpcmUxEzARBgNVBAcMCkJyb21zZ3JvdmUx\n\t\t\t\t\t\tHDAaBgNVBAoME0FzcGlyYXRpb24gVHJhaW5pbmcxJDAiBgNVBAMMG2F1dGguYXNw\n\t\t\t\t\t\taXJhdGlvbnRyYWluaW5nLmNvbTAeFw0xMjEyMTgxMDA5NTNaFw0zMjEyMTMxMDA5\n\t\t\t\t\t\tNTNaMH8xCzAJBgNVBAYTAkdCMRcwFQYDVQQIDA5Xb3JjZXN0ZXJzaGlyZTETMBEG\n\t\t\t\t\t\tA1UEBwwKQnJvbXNncm92ZTEcMBoGA1UECgwTQXNwaXJhdGlvbiBUcmFpbmluZzEk\n\t\t\t\t\t\tMCIGA1UEAwwbYXV0aC5hc3BpcmF0aW9udHJhaW5pbmcuY29tMIIBIjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2NCaFs4yihlbWsPejTxurOzorKVniu++Hf64\n\t\t\t\t\t\t2EQmqAEkw9eaHITpI47h+kJKP/Cm1kkdd1BheCcCGm66nJubzpIxTZ+HQxRzdG0/\n\t\t\t\t\t\tEQ7ndwnvnun77iQ4FLI49i5NOYpqR26S5GBLwpPvuPSMPh1f4S09AkRDFlda1krb\n\t\t\t\t\t\tqIhSxFLRT2kahKjiKCkTf5SOxmSponEwpnk+I+niPNT5HslNCjItKjTX9ykHZrnN\n\t\t\t\t\t\t7+Rus9AlHV14jYrlZtLsN7wqvgXw+UC7RvbBTm/Wjsp06VUIBXs33bLTq0BfxCM/\n\t\t\t\t\t\tuzoAfeFQlY67ariROz+KRCZR3P84V7bVT3KhI9BQjF6NY9t83wIDAQABMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQAtVoxlBB777Ms2s5CGDSHFU4sSGih8KrLmnDly215yjrqv\n\t\t\t\t\t\tsdFcnmehXE2tWd8MDZz6T+XGU6NwTPh7MJmPhghZA2smNEzCnrAV2w/G2oMKnepR\n\t\t\t\t\t\tBdtDUBGPJ+ZCPoBRHBlFXlRcU4DO70eHDiEtSV/asAI4DTF358rjDMon2gmzM+dl\n\t\t\t\t\t\tI916AQ8YHsISrO6ftTmjReZhBt3Q+TpFcPp98rC86O35HwAdDSXsEwuyO22rHgE2\n\t\t\t\t\t\tNNvNPi4XVgdCvET15Z8/3sp6na0uWumk2S8Mvhzu4Sr65FbmUdUdXuabN+RO6teg\n\t\t\t\t\t\t7ofaWoIudaTkckRrLtBv0iW2PfAl/Lene6U/UtCu"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aspirationtraining.com"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://auth.aspirationtraining.com:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://auth.aspirationtraining.com:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://auth.aspirationtraining.com/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.aspirationtraining.com/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://auth.aspirationtraining.com/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.aspirationtraining.com/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://auth.aspirationtraining.com:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://auth.aspirationtraining.com:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aspirationtraining.com"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDejCCAmICCQDX1cojLXODTzANBgkqhkiG9w0BAQUFADB/MQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEXMBUGA1UECAwOV29yY2VzdGVyc2hpcmUxEzARBgNVBAcMCkJyb21zZ3JvdmUx\n\t\t\t\t\t\tHDAaBgNVBAoME0FzcGlyYXRpb24gVHJhaW5pbmcxJDAiBgNVBAMMG2F1dGguYXNw\n\t\t\t\t\t\taXJhdGlvbnRyYWluaW5nLmNvbTAeFw0xMjEyMTgxMDA5NTNaFw0zMjEyMTMxMDA5\n\t\t\t\t\t\tNTNaMH8xCzAJBgNVBAYTAkdCMRcwFQYDVQQIDA5Xb3JjZXN0ZXJzaGlyZTETMBEG\n\t\t\t\t\t\tA1UEBwwKQnJvbXNncm92ZTEcMBoGA1UECgwTQXNwaXJhdGlvbiBUcmFpbmluZzEk\n\t\t\t\t\t\tMCIGA1UEAwwbYXV0aC5hc3BpcmF0aW9udHJhaW5pbmcuY29tMIIBIjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQEFAAOCAQ8AMIIBCgKCAQEA2NCaFs4yihlbWsPejTxurOzorKVniu++Hf64\n\t\t\t\t\t\t2EQmqAEkw9eaHITpI47h+kJKP/Cm1kkdd1BheCcCGm66nJubzpIxTZ+HQxRzdG0/\n\t\t\t\t\t\tEQ7ndwnvnun77iQ4FLI49i5NOYpqR26S5GBLwpPvuPSMPh1f4S09AkRDFlda1krb\n\t\t\t\t\t\tqIhSxFLRT2kahKjiKCkTf5SOxmSponEwpnk+I+niPNT5HslNCjItKjTX9ykHZrnN\n\t\t\t\t\t\t7+Rus9AlHV14jYrlZtLsN7wqvgXw+UC7RvbBTm/Wjsp06VUIBXs33bLTq0BfxCM/\n\t\t\t\t\t\tuzoAfeFQlY67ariROz+KRCZR3P84V7bVT3KhI9BQjF6NY9t83wIDAQABMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBBQUAA4IBAQAtVoxlBB777Ms2s5CGDSHFU4sSGih8KrLmnDly215yjrqv\n\t\t\t\t\t\tsdFcnmehXE2tWd8MDZz6T+XGU6NwTPh7MJmPhghZA2smNEzCnrAV2w/G2oMKnepR\n\t\t\t\t\t\tBdtDUBGPJ+ZCPoBRHBlFXlRcU4DO70eHDiEtSV/asAI4DTF358rjDMon2gmzM+dl\n\t\t\t\t\t\tI916AQ8YHsISrO6ftTmjReZhBt3Q+TpFcPp98rC86O35HwAdDSXsEwuyO22rHgE2\n\t\t\t\t\t\tNNvNPi4XVgdCvET15Z8/3sp6na0uWumk2S8Mvhzu4Sr65FbmUdUdXuabN+RO6teg\n\t\t\t\t\t\t7ofaWoIudaTkckRrLtBv0iW2PfAl/Lene6U/UtCu"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Aspiration Training"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aspirationtraining.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Aspiration Training Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://adfs.geant.org/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it@geant.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "G\u00c9ANT IT"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:it@geant.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "G\u00c9ANT IT"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs.geant.org/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-01-08T14:43:52Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "G\u00c9ANT Ltd."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.geant.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "G\u00c9ANT Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://adfs.geant.org/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://adfs.geant.org/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Suite of websites and web applications for G\u00c9ANT Project."
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://adfs.geant.org/PrivacyPolicy/GEANTWebPrivacyPolicy.htm"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "G\u00c9ANT Web Presence"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDCjCCAfKgAwIBAgIQs5tPc9z706NO4mzHhrCV8TANBgkqhkiG9w0BAQsFADAZ\n\t\t\t\t\t\tMRcwFQYDVQQDEw5hZGZzLmdlYW50Lm9yZzAeFw0xNTExMzAyMzAwMDBaFw0yNTEy\n\t\t\t\t\t\tMzEyMzAwMDBaMBkxFzAVBgNVBAMTDmFkZnMuZ2VhbnQub3JnMIIBIjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmRspgLghse0p+atImNpxxYICpkNEGZ/KYsCT\n\t\t\t\t\t\twkDpje68srDJQYJoRGo2H8RJO0JRhLdtCKtHPSB5UffPVbC2rhHRyRKbAJ+Lcwpz\n\t\t\t\t\t\tfrPe82WsHm6oTIuL+QlmjWDjjdHJ6JmYDgIhNflPsoStZ5pF7vd2NpVzPysneAWX\n\t\t\t\t\t\tg9X8PZvvD+Vs0jA+eGFzm23t6Fq/Dd74Je+FL5avGWHGVfqDwn7gjpnV/DprC+y1\n\t\t\t\t\t\tAq/YE1ISsYlDbCoc9caghtdDFe+UyAZ3ftQICS2KGSw6N3JilTIlY4MB/WLlnPC1\n\t\t\t\t\t\tKDdSRWtxAphCFg0tVOArYFfy5uiI+8/TKAl8lNCc/sdD9URk+QIDAQABo04wTDBK\n\t\t\t\t\t\tBgNVHQEEQzBBgBDE00phQQHYraGrC4n0nrkmoRswGTEXMBUGA1UEAxMOYWRmcy5n\n\t\t\t\t\t\tZWFudC5vcmeCELObT3Pc+9OjTuJsx4awlfEwDQYJKoZIhvcNAQELBQADggEBAFto\n\t\t\t\t\t\t4jjSLViYHyICsyFsdCu3Gp3dbOcGkokEcR+EuDjuJX2ckDmXaVleyuEO73VIWFdn\n\t\t\t\t\t\tAeCckGMgzl5Kp+QQAVJrre75kTtc7DelHeu8q4/v4mJX5jbGIikg3FzaoPPp4aeN\n\t\t\t\t\t\tbCFADvM30dp6Tx2Jo70oaDBlmmt1IZ7/CSM8BHMYsouOvLbvexfuEhCVyjo4rlXf\n\t\t\t\t\t\tULZJqKXuExn8g6ACrSXxkWec0P40QJqeFmQpuW4An6KzFEvwKA8jogtEY4Vo6mJ1\n\t\t\t\t\t\tNyQCZybAQfgvDyviwbu2fgMwy3UyIaDV0y3jNrLqVIcxn2bdsUP35jI8PFpIv6T4\n\t\t\t\t\t\tWKQ3AllzMMauGECc7IU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://adfs.geant.org/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://adfs.geant.org/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "G\u00c9ANT Web Presence"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Suite of websites and web applications for G\u00c9ANT Project."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "email",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonScopedAffiliation",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://birk.wayf.dk/birk.php/saml.pharmakon.dk/adfs/services/trust",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Operations"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "operations@wayf.dk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "WAYF"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://birk.wayf.dk/birk.php/saml.pharmakon.dk/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2011-12-22T11:57:11Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://birk.wayf.dk/birk.php/saml.pharmakon.dk/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://birk.wayf.dk/birk.php/saml.pharmakon.dk/adfs/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "apoteket.dk"
              },
              {
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Pharmakon"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Pharmakon"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "apoteket.dk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC5DCCAcwCAQcwDQYJKoZIhvcNAQELBQAwODE2MDQGA1UEAwwtaHR0cHM6Ly9z\nYW1sLnBoYXJtYWtvbi5kay9hZGZzL3NlcnZpY2VzL3RydXN0MB4XDTE1MDEwMTAw\nMDAwMFoXDTI1MTIzMTIzNTk1OVowODE2MDQGA1UEAwwtaHR0cHM6Ly9zYW1sLnBo\nYXJtYWtvbi5kay9hZGZzL3NlcnZpY2VzL3RydXN0MIIBIjANBgkqhkiG9w0BAQEF\nAAOCAQ8AMIIBCgKCAQEAx4gMCmoQU7iOGfiCda4DnhIggst20fUCHtwaQrHoxQlO\na0s5FgDalbnNTw36dCXSGYaz17JgyUDJonTwhjyA0CqPm5Pmn9/hFBUvyP/t+bEg\nV9r3/odQx72VfY7M55qUlY6ex2f1qD1gcpFgSTtADlZswec5WqpEt+ie+vsMXq8H\nabhMVZ2EjXe90vgMk/xGfrVwDvupUPBS/2DJSZ1JEmkqi0hxctNQ9qgTZmEcAaQk\nuv3VGcsYtLeY/IISlA+ARzmVWr5+uSetnCXV4jnDEclACKeexl0Ky+tyra4yHF3X\navgmcmebd+xHVDiM+No6BXMu9zBTp7cp5ShLzsNQSQIDAQABMA0GCSqGSIb3DQEB\nCwUAA4IBAQB0m15bj3mKtEsAa2OuZDm3kNObF9EdWovAZX2UP2KL2DYiFTMq+ed0\nwcfWkL08mIbdQkqK4J50AGVY87tSZ6bWfHFYWUKsLjWtxq6Wv7gvLhrBbvPApVCf\nThzKXtYoYmQodgfwdPob9NErnQyRYCXQqTl8P/LL8fz8wH4nLr8nbSc3pOXLtU7p\nWpB3i8Kk2E3xW/txsFNgFxz42w9sKpEZ4Ks3KKWAJqu8mOD7QdG7dHD53e8Mo2En\nGLUoaz+5wbTnNxn+ld3iVk9oeGqm4glPuaLwZ0p0bTt5uPFCjMLRc6+C45LWb6F1\nHM6p9FnQoiWszraaknJsQ8E+fjjqZ1dY"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Pharmakon"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Pharmakon"
          }
        ],
        "organization_url": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://pharmakon.dk"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://pharmakon.dk/pages/International.aspx"
          }
        ],
        "organization_name": [
          {
            "lang": "da",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Pharmakon"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Pharmakon"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibtest.idp.mimas.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@mimas.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mimas helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:mimas-shib-tech@listserv.manchester.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mimas Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibtest.idp.mimas.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIVAN7ga1+uXpDOX1/droiJ39Pl1TLUMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCMxITAfBgNVBAMTGHNoaWJ0ZXN0LmlkcC5taW1hcy5hYy51azAeFw0xMDA3\n\t\t\t\t\t\tMTAxNDE4NTdaFw0zMDA3MTAxNDE4NTdaMCMxITAfBgNVBAMTGHNoaWJ0ZXN0Lmlk\n\t\t\t\t\t\tcC5taW1hcy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAI5a\n\t\t\t\t\t\ts9OeylQjgw9Ikt2LQ0PeyVpArU30QKiawZ0vTELSAYGmguMnDqONV6TpYeBA6ul1\n\t\t\t\t\t\t/Yk50Qc8VoSLbz6gXINVdAHykSsYj4hdiAbKZUcu4+5GLvQ2/WRdsAQ+SHoL3IoD\n\t\t\t\t\t\tV0u9rkSfuHH/TdVpF/Ub+FT2bRDqVWnxdePhKwyc6rFVu7fl4aJ9sPwaCykbF8YL\n\t\t\t\t\t\tRvDjm+yRbO2REUv2j1S5ALKpem5RsSlk8BO/7N2GC9BZ45OdUyNEs61O0HSnTr5I\n\t\t\t\t\t\tW8TIAyKkbHjPgDog26pFRBpIOXUGwX8iLTPd/A4t8OfivW+yQHhRly8DIJvEkmLQ\n\t\t\t\t\t\tuQmFFsJYiD0cgcHEvLcCAwEAAaN3MHUwVAYDVR0RBE0wS4IYc2hpYnRlc3QuaWRw\n\t\t\t\t\t\tLm1pbWFzLmFjLnVrhi9odHRwczovL3NoaWJ0ZXN0LmlkcC5taW1hcy5hYy51ay9p\n\t\t\t\t\t\tZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUF8HL505cOeu0WSjw1vYH0cpDUlUwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBADaxi5Bc/h9oaFU8tuD1V67gUlwPsNTU8lR3vlOGZqan\n\t\t\t\t\t\t3gxFnmOAkB+GOyqOSZ2TKyQkSMslpV4Vh1CVYl/tCzojfjd0vtu/BGyj+GwkwLBH\n\t\t\t\t\t\tv3xee+AZAE14ENQwNCakQmylSDk4Jrd+4L2LgaAj/HXO2LC2y4WpekFSo1LdBHIo\n\t\t\t\t\t\t64Ar2nuXGtzIuQ1xaQP/uzhkbTSRn67RYWfNXaoy8gAbSVC64YfQPQsGrutJZBxr\n\t\t\t\t\t\thnd57QZ3WTyqB0/30TrDkpPkL3GAjrdoUAMfG7wBYagR+soc+1URAr8oP+shK8M/\n\t\t\t\t\t\tuSohqKcoLLVvY0qjE+AzYlX6YdrpGbad1nCO6WOIm/0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mimas.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibtest.idp.mimas.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibtest.idp.mimas.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibtest.idp.mimas.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibtest.idp.mimas.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibtest.idp.mimas.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibtest.idp.mimas.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibtest.idp.mimas.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibtest.idp.mimas.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "mimas.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDTDCCAjSgAwIBAgIVAN7ga1+uXpDOX1/droiJ39Pl1TLUMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCMxITAfBgNVBAMTGHNoaWJ0ZXN0LmlkcC5taW1hcy5hYy51azAeFw0xMDA3\n\t\t\t\t\t\tMTAxNDE4NTdaFw0zMDA3MTAxNDE4NTdaMCMxITAfBgNVBAMTGHNoaWJ0ZXN0Lmlk\n\t\t\t\t\t\tcC5taW1hcy5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAI5a\n\t\t\t\t\t\ts9OeylQjgw9Ikt2LQ0PeyVpArU30QKiawZ0vTELSAYGmguMnDqONV6TpYeBA6ul1\n\t\t\t\t\t\t/Yk50Qc8VoSLbz6gXINVdAHykSsYj4hdiAbKZUcu4+5GLvQ2/WRdsAQ+SHoL3IoD\n\t\t\t\t\t\tV0u9rkSfuHH/TdVpF/Ub+FT2bRDqVWnxdePhKwyc6rFVu7fl4aJ9sPwaCykbF8YL\n\t\t\t\t\t\tRvDjm+yRbO2REUv2j1S5ALKpem5RsSlk8BO/7N2GC9BZ45OdUyNEs61O0HSnTr5I\n\t\t\t\t\t\tW8TIAyKkbHjPgDog26pFRBpIOXUGwX8iLTPd/A4t8OfivW+yQHhRly8DIJvEkmLQ\n\t\t\t\t\t\tuQmFFsJYiD0cgcHEvLcCAwEAAaN3MHUwVAYDVR0RBE0wS4IYc2hpYnRlc3QuaWRw\n\t\t\t\t\t\tLm1pbWFzLmFjLnVrhi9odHRwczovL3NoaWJ0ZXN0LmlkcC5taW1hcy5hYy51ay9p\n\t\t\t\t\t\tZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUF8HL505cOeu0WSjw1vYH0cpDUlUwDQYJ\n\t\t\t\t\t\tKoZIhvcNAQEFBQADggEBADaxi5Bc/h9oaFU8tuD1V67gUlwPsNTU8lR3vlOGZqan\n\t\t\t\t\t\t3gxFnmOAkB+GOyqOSZ2TKyQkSMslpV4Vh1CVYl/tCzojfjd0vtu/BGyj+GwkwLBH\n\t\t\t\t\t\tv3xee+AZAE14ENQwNCakQmylSDk4Jrd+4L2LgaAj/HXO2LC2y4WpekFSo1LdBHIo\n\t\t\t\t\t\t64Ar2nuXGtzIuQ1xaQP/uzhkbTSRn67RYWfNXaoy8gAbSVC64YfQPQsGrutJZBxr\n\t\t\t\t\t\thnd57QZ3WTyqB0/30TrDkpPkL3GAjrdoUAMfG7wBYagR+soc+1URAr8oP+shK8M/\n\t\t\t\t\t\tuSohqKcoLLVvY0qjE+AzYlX6YdrpGbad1nCO6WOIm/0="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Manchester: Mimas Development IdP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://mimas.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The University of Manchester"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.univ-fcomte.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "bernard.voisin@univ-fcomte.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.univ-fcomte.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-09-15T12:46:40Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univ-fcomte.fr/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univ-fcomte.fr/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.univ-fcomte.fr/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.univ-fcomte.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.univ-fcomte.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.univ-fcomte.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-fcomte.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://univ-fcomte.fr/"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Franche-Comte"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e9 de Franche-Comt\u00e9"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIECTCCAvGgAwIBAgIJAMpmbKzqwZS/MA0GCSqGSIb3DQEBCwUAMIGaMQswCQYD\nVQQGEwJGUjEWMBQGA1UECAwNRlJBTkNIRSBDT01URTERMA8GA1UEBwwIQmVzYW5j\nb24xDDAKBgNVBAoMA1VGQzEMMAoGA1UECwwDQ1JJMRswGQYDVQQDDBJpZHAudW5p\ndi1mY29tdGUuZnIxJzAlBgkqhkiG9w0BCQEWGGlkcG1hc3RlckB1bml2LWZjb210\nZS5mcjAeFw0xNTA3MTAwNzQ2MzNaFw0yNTA3MDcwNzQ2MzNaMIGaMQswCQYDVQQG\nEwJGUjEWMBQGA1UECAwNRlJBTkNIRSBDT01URTERMA8GA1UEBwwIQmVzYW5jb24x\nDDAKBgNVBAoMA1VGQzEMMAoGA1UECwwDQ1JJMRswGQYDVQQDDBJpZHAudW5pdi1m\nY29tdGUuZnIxJzAlBgkqhkiG9w0BCQEWGGlkcG1hc3RlckB1bml2LWZjb210ZS5m\ncjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJaIDFDxx9tCnqjzRE4g\n2v49CrDURG3Ve2tOnGkgj7t+5AkH+B7DHnbHC+cEde7OiJYo3GWB2qXA1+4C2CeN\nInC5i6R7Un+PjM3qnZ6C+jwUf9QgWV77G27ao50uIj/XB84Cf4jSSWMtJBrfzcgw\noFFVMUgVoAel6l8okarDEZdK+IoukX/TbFNj+X0+8wa/lv1LEzDTXAYFJH1KHunX\nGRCwl2ObiG8VSVkbUruQkY5IZjY9AudoFCPdTtjuLo1j1k49kYHggE2SBGqVyoAv\nCoChbNvHkryMXL5W+wQReIulWR28L2qqX+l43lIpCC+VSR1WDJ/j/FVOqleK950K\n1NkCAwEAAaNQME4wHQYDVR0OBBYEFCer9hrE+IBVKwn4FDhH6E3aW33CMB8GA1Ud\nIwQYMBaAFCer9hrE+IBVKwn4FDhH6E3aW33CMAwGA1UdEwQFMAMBAf8wDQYJKoZI\nhvcNAQELBQADggEBACXU4gUJOWe43QXQSApU/JtcTgAgKF6NcOVs/jZ++8KiGWgZ\n46qhDQbnjYSXl4/QsjlIqJliAmWGp89aJIlUs1oXZ7Ro4cIgfSoKTlbXQc+3L2QL\npa56dTmER/5Z4oamgeP9YPJd2teIMuh42lCD3GBDFE120F7zTSy5N7E0mwPOCWXN\npFXlNA+vzp+WEEWPO6TV29w1Hz66NFf7PeexEr4DDBg0vnvsEBAdiGA1x1CQbFit\nIif5onYKtZVZW68sY7wLOim3mCWb/QayOXJIycv0zc5EyziPGy+dIZT2LePsQPU3\nkL3y4I3hH+GeK5iK/w7esz+6VG04gBFYYeamic8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUW6mVllZscKchJexSqcEND0YtS8AwDQYJKoZIhvcNAQEF\nBQAwHTEbMBkGA1UEAxMSaWRwLnVuaXYtZmNvbXRlLmZyMB4XDTA5MDkyMjA5MjY0\nOFoXDTI5MDkyMjA5MjY0OFowHTEbMBkGA1UEAxMSaWRwLnVuaXYtZmNvbXRlLmZy\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAo5IZG9vjS65fZl4V7Rj0\n7m98ICKvOdEKifDECnogADu3DKKwTgNRFdluGjA97M/vLYGyDPIxp6WH5/Xn402n\ndBKoR7x4cCPxcbreXqstbObb6DKLQ9wno2kZGHhCGnSbP04GruIKoLjtZJ0HjkYY\n805ZEB+yR543hZoAKvYoL7yNfkbhw4pqiHocd7lDjeW30airDj26endmgxKMDdma\nQZc+SZQih2c4pwvFeY478VxvMC34U9r+bnljREDXNk6j342vIKTqSEhf2UgMcd6/\nox+ozGhstsDwRPecDyLm9t4VtcL7jAwC2mF/zhAkziDQ1ZSqszLOpM94kPW8rdvC\n7QIDAQABo2swaTBIBgNVHREEQTA/ghJpZHAudW5pdi1mY29tdGUuZnKGKWh0dHBz\nOi8vaWRwLnVuaXYtZmNvbXRlLmZyL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTr\nIVfDPghF09R0vhBjtKCIU7ibzjANBgkqhkiG9w0BAQUFAAOCAQEAjuMuu1Jhi1x6\n6ePM1bMbdyGTRAiWeQIBQsHkz6xbHOzAL86/bgIw2hgQqcjq1Tzy3OTFFsduAW1N\nwIfDITbZ1Bg2FecmYpdxzpwzzTgnPzpaztN013WlCkXURlbf4LP2OBpGe0gC488N\nv720Gk3YrUSZ4Qvfrr15kRsb92unQ87qT7JWGnp8+3/e8Cuw93bNZZY+rgAjLm8z\nXqW8svXuUo4q0dQH93j8YzV7Ehhri1crpeix9jNFHU9Nv1UNT4a1kFgbvtqvbJEK\nnN/RMfsKrrdgX8j3c+CoTxWr/whb+1TSruMB/J1PgNArpPGxNDJEoZloNEMAowoU\nIVPuFCeDJg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e9 de Franche-Comt\u00e9"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://univ-fcomte.fr/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e9 de Franche-Comt\u00e9"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.iceruganda.org/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-support@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Technical Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-admin@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Administrative Support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-support@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "icer-vro-support@list.nih.gov"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NIAID ICER VRO Technical Support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.iceruganda.org/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.iceruganda.org:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAMx+qfsrxTy3MA0GCSqGSIb3DQEBCwUAMB8xHTAbBgNV\nBAMMFGxvZ2luLmljZXJ1Z2FuZGEub3JnMB4XDTE1MDUwNzIwMDYzN1oXDTI1MDUw\nNDIwMDYzN1owHzEdMBsGA1UEAwwUbG9naW4uaWNlcnVnYW5kYS5vcmcwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDB5PvpRc9pdE99+SlCG07pmyLVUR9/\nDnCg7EJWDYvzC04NCZzGigRKlDU8BjX6eM227HaqsBpuFYT+WKHR58oqEnqhXlNB\nA4Tr9hfAvaaLLdoMGCR7qb7CLpwUAkcki7l+9difqEQ/wt7CN+B3QaqKpt3Q4JKM\ngeK6ybH7borIFwQ5CjHbKJvcz8S8FTItTVgIGGufBSBHYLN899QafdNRMNklyaQc\nh+FY81sh1MecaSxf3LbLH0vEgWZgEI+1VDXpNBVLs1PeOXzF3XRXUl4TVFMIbwXj\nbqbk4luqC2mgOumhFjt5l8GlWd6qaHH9skdAtTBVyZYAZCWsAuwpxSaVAgMBAAGj\nQjBAMB0GA1UdDgQWBBQVxLfBPzQonEfKhhr/XpHlJl3sOjAfBgNVHREEGDAWghRs\nb2dpbi5pY2VydWdhbmRhLm9yZzANBgkqhkiG9w0BAQsFAAOCAQEAkWQiuIfo/w0C\n33m2GZZM5/KBO8ndkfHQsaVhxqw+BADemU0lzHKMDnsNsYcIjRbQ0vhpGw3ioe2U\nFYEUpw8cz+kgOi0mTxpngwWQEFmNV5JLXVfYLNu/ZY2bwiTJHkT2M1EFpz4x96ou\ncAeLUlcMF23bgwTF+u0mS+JVMUbpUmr7/YoRF32F0nU1NorSEffdMtJGvdiAoIue\nUA2aWOI0QLY0u9SzjDfLu/izfY31SBGFezTKoTJjFvp0ix4xhx0uDrkAhXOx/Ji7\nBtg/mqYjzfnR35ziLKAB7wcG7ldYEp7NOy2dMUk21w6x0HVVXbPtwO6Dl+9jf4tW\nnWg+uFqEKQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAOV+XCm7XZ1cMA0GCSqGSIb3DQEBCwUAMB8xHTAbBgNV\nBAMMFGxvZ2luLmljZXJ1Z2FuZGEub3JnMB4XDTE1MDUwNzIwMTM0MVoXDTI1MDUw\nNDIwMTM0MVowHzEdMBsGA1UEAwwUbG9naW4uaWNlcnVnYW5kYS5vcmcwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDV4UwuEyE4qPYvWH53bd3cYGZQrN63\nkaCSFrxio9rJfB6PFCJKmZv+JuXhMyGzDoxXrr5iew/jguZZU3XW/MXE4243YdrM\nUoPuhEWkZgIvPQq4Qf+Q2WJFeap5/lgoAwksi0uwz5otU8034LLhCWhGKTIwbJc7\nUvW9iZXZrzdv/c/iFBgY2NMEzvNP8gZUqhBSOj9KMKNpRJmUOY7QFicpGxfefPEy\nehA3xJqUY34+5OQrUwAxuQdS4QQTPPHMCs/3lUBPKOSaxELSbfIQmPhLD4NwXLSw\nfNCYcWz8ZaqaZTEkyx4nGOOwyNCGhV/No9GZB7NbazcDbwFcR6BiHGSxAgMBAAGj\nQjBAMB0GA1UdDgQWBBTbgNwoTdyYFjL1vmL+8TOsz8a4TDAfBgNVHREEGDAWghRs\nb2dpbi5pY2VydWdhbmRhLm9yZzANBgkqhkiG9w0BAQsFAAOCAQEAhwlWcbzYH1Wv\nHkvT16CAk0XkB40tOGqRDIoiqNug2+xjn95uu7z+hj5Nu3lqLsdHmWzExSvz+ljF\nU4FHz2iKsJA2AfIBYweulrC6v87giPF/lpe7IliZh1xjzYwecfmG4Fy+uAqy3dOP\nKiQStmp3O75dFLttP1Ps8EvWpzeOybx7sM1Tbkq5B1OKvAkZzO6ZQ1Vk8pf2/AS/\nrv+/S1JWmYL0m2zX26MZIGzkdiEEQ+E979NF2tENKRFQ4/tVBWieMgwDXj8ueshs\nXFFuLjqh9cAsGDHv3B+Elm2QjpsbKtq4Pa8jG322UixM3w5Y3t1KhP73BiWjUCYf\nxX3P5EdlXw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iceruganda.org"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.iceruganda.org/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.iceruganda.org/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.iceruganda.org/idp/profile/SAML2/SOAP/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.iceruganda.org/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.iceruganda.org:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iceruganda.org"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://login.iceruganda.org/federation/info"
                  }
                ],
                "logo": [
                  {
                    "text": "https://login.iceruganda.org/federation/ui/logo/icerugandalogo80x60.png",
                    "lang": "en",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://login.iceruganda.org/federation/privacy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ICER - Uganda"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAMx+qfsrxTy3MA0GCSqGSIb3DQEBCwUAMB8xHTAbBgNV\nBAMMFGxvZ2luLmljZXJ1Z2FuZGEub3JnMB4XDTE1MDUwNzIwMDYzN1oXDTI1MDUw\nNDIwMDYzN1owHzEdMBsGA1UEAwwUbG9naW4uaWNlcnVnYW5kYS5vcmcwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDB5PvpRc9pdE99+SlCG07pmyLVUR9/\nDnCg7EJWDYvzC04NCZzGigRKlDU8BjX6eM227HaqsBpuFYT+WKHR58oqEnqhXlNB\nA4Tr9hfAvaaLLdoMGCR7qb7CLpwUAkcki7l+9difqEQ/wt7CN+B3QaqKpt3Q4JKM\ngeK6ybH7borIFwQ5CjHbKJvcz8S8FTItTVgIGGufBSBHYLN899QafdNRMNklyaQc\nh+FY81sh1MecaSxf3LbLH0vEgWZgEI+1VDXpNBVLs1PeOXzF3XRXUl4TVFMIbwXj\nbqbk4luqC2mgOumhFjt5l8GlWd6qaHH9skdAtTBVyZYAZCWsAuwpxSaVAgMBAAGj\nQjBAMB0GA1UdDgQWBBQVxLfBPzQonEfKhhr/XpHlJl3sOjAfBgNVHREEGDAWghRs\nb2dpbi5pY2VydWdhbmRhLm9yZzANBgkqhkiG9w0BAQsFAAOCAQEAkWQiuIfo/w0C\n33m2GZZM5/KBO8ndkfHQsaVhxqw+BADemU0lzHKMDnsNsYcIjRbQ0vhpGw3ioe2U\nFYEUpw8cz+kgOi0mTxpngwWQEFmNV5JLXVfYLNu/ZY2bwiTJHkT2M1EFpz4x96ou\ncAeLUlcMF23bgwTF+u0mS+JVMUbpUmr7/YoRF32F0nU1NorSEffdMtJGvdiAoIue\nUA2aWOI0QLY0u9SzjDfLu/izfY31SBGFezTKoTJjFvp0ix4xhx0uDrkAhXOx/Ji7\nBtg/mqYjzfnR35ziLKAB7wcG7ldYEp7NOy2dMUk21w6x0HVVXbPtwO6Dl+9jf4tW\nnWg+uFqEKQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDAzCCAeugAwIBAgIJAOV+XCm7XZ1cMA0GCSqGSIb3DQEBCwUAMB8xHTAbBgNV\nBAMMFGxvZ2luLmljZXJ1Z2FuZGEub3JnMB4XDTE1MDUwNzIwMTM0MVoXDTI1MDUw\nNDIwMTM0MVowHzEdMBsGA1UEAwwUbG9naW4uaWNlcnVnYW5kYS5vcmcwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDV4UwuEyE4qPYvWH53bd3cYGZQrN63\nkaCSFrxio9rJfB6PFCJKmZv+JuXhMyGzDoxXrr5iew/jguZZU3XW/MXE4243YdrM\nUoPuhEWkZgIvPQq4Qf+Q2WJFeap5/lgoAwksi0uwz5otU8034LLhCWhGKTIwbJc7\nUvW9iZXZrzdv/c/iFBgY2NMEzvNP8gZUqhBSOj9KMKNpRJmUOY7QFicpGxfefPEy\nehA3xJqUY34+5OQrUwAxuQdS4QQTPPHMCs/3lUBPKOSaxELSbfIQmPhLD4NwXLSw\nfNCYcWz8ZaqaZTEkyx4nGOOwyNCGhV/No9GZB7NbazcDbwFcR6BiHGSxAgMBAAGj\nQjBAMB0GA1UdDgQWBBTbgNwoTdyYFjL1vmL+8TOsz8a4TDAfBgNVHREEGDAWghRs\nb2dpbi5pY2VydWdhbmRhLm9yZzANBgkqhkiG9w0BAQsFAAOCAQEAhwlWcbzYH1Wv\nHkvT16CAk0XkB40tOGqRDIoiqNug2+xjn95uu7z+hj5Nu3lqLsdHmWzExSvz+ljF\nU4FHz2iKsJA2AfIBYweulrC6v87giPF/lpe7IliZh1xjzYwecfmG4Fy+uAqy3dOP\nKiQStmp3O75dFLttP1Ps8EvWpzeOybx7sM1Tbkq5B1OKvAkZzO6ZQ1Vk8pf2/AS/\nrv+/S1JWmYL0m2zX26MZIGzkdiEEQ+E979NF2tENKRFQ4/tVBWieMgwDXj8ueshs\nXFFuLjqh9cAsGDHv3B+Elm2QjpsbKtq4Pa8jG322UixM3w5Y3t1KhP73BiWjUCYf\nxX3P5EdlXw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://login.iceruganda.org/federation/error"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ICER - Uganda"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nih.gov/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "National Institutes of Health"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.cardiffmet.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ithelpdesk@cardiffmet.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Morris"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:amorris@cardiffmet.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andi"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cardiffmet.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-01-26T17:02:53Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAM/WrHuhoD12UZd9duSVXiTcAQKqMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB8xHTAbBgNVBAMMFGlkcC5jYXJkaWZmbWV0LmFjLnVrMB4XDTE0MTEyODE0\n\t\t\t\t\t\tNTA1OFoXDTM0MTEyODE0NTA1OFowHzEdMBsGA1UEAwwUaWRwLmNhcmRpZmZtZXQu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCibib8LKS+kWc/\n\t\t\t\t\t\t4jFZaF5lJlCYKGc2M3h7Dzx7En9rOaP/4BnyRXmIfX0XQQ43Zl/M3TZ1V3lfOMl0\n\t\t\t\t\t\tmS7qxiNP9tRR44Imj4tAlPGTL0/G6wKrRgZwT5Ya5Situ4uGSjRqlEXKp0WPX9DB\n\t\t\t\t\t\trV40f+n3amXbG6968QkBgMTVQoYSfPYPDeYvMkJgIBJ7fFEfoiUEMLbmApFvKAOF\n\t\t\t\t\t\tfh3AyRIgIvNZGuhCmOurAxrK83NQf8GxYCrxWVYBDxy2zM+ieqIQfXq7vKPwRj0i\n\t\t\t\t\t\tI93TqeH3tW+NNXxp3L2Vhqp6QjNwTJuQoq8CyeFAppZ3R7I76gS0a/G65BnDexXr\n\t\t\t\t\t\ts35piiX3AgMBAAGjbzBtMB0GA1UdDgQWBBRhlIKvVhsJq55eRmziUxsfKVzMkjBM\n\t\t\t\t\t\tBgNVHREERTBDghRpZHAuY2FyZGlmZm1ldC5hYy51a4YraHR0cHM6Ly9pZHAuY2Fy\n\t\t\t\t\t\tZGlmZm1ldC5hYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tV2tNA0SAzHCAXhPCbT2SAMgB4bSGM51OLwKn+tJNC5gasFq62kERnXcRbl/Ii5VZ\n\t\t\t\t\t\tIu1t8ml0jTLBjiFYCFtq4uGEMeDPPxKNUNEPkWfIqCq693CrSHc1M5Lso4CmhiCK\n\t\t\t\t\t\tCAnz0V1oVkgyBW9e7WnDzRGvVN12hTGmS33ZINOamwmQErUbeEdRnlB7fa3BZHB9\n\t\t\t\t\t\tkdW3SZRhb7CynWQoB6byYyBBWKfTuD1qScRQlIFhOscGX3qxBYBIqwzsJkd4qXPK\n\t\t\t\t\t\t3qrSFwHAyC6nXz1MLyanluHTBD+41hABSHxu5pwWhD8xXbFS0dA+8qJwagPvuO8q\n\t\t\t\t\t\tJA5KMQm1uzCs13HbQj79Nw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cardiffmet.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cardiffmet.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cardiffmet.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cardiffmet.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cardiffmet.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cardiffmet.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.cardiffmet.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cardiffmet.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.cardiffmet.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cardiffmet.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cardiffmet.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cardiffmet.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cardiffmet.ac.uk"
              },
              {
                "logo": [
                  {
                    "text": "https://idplogos.cardiffmet.ac.uk/cmet80x60.gif",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  },
                  {
                    "text": "https://idplogos.cardiffmet.ac.uk/cmet_16x16_crest.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Cardiff Metropolitan University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAM/WrHuhoD12UZd9duSVXiTcAQKqMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB8xHTAbBgNVBAMMFGlkcC5jYXJkaWZmbWV0LmFjLnVrMB4XDTE0MTEyODE0\n\t\t\t\t\t\tNTA1OFoXDTM0MTEyODE0NTA1OFowHzEdMBsGA1UEAwwUaWRwLmNhcmRpZmZtZXQu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCibib8LKS+kWc/\n\t\t\t\t\t\t4jFZaF5lJlCYKGc2M3h7Dzx7En9rOaP/4BnyRXmIfX0XQQ43Zl/M3TZ1V3lfOMl0\n\t\t\t\t\t\tmS7qxiNP9tRR44Imj4tAlPGTL0/G6wKrRgZwT5Ya5Situ4uGSjRqlEXKp0WPX9DB\n\t\t\t\t\t\trV40f+n3amXbG6968QkBgMTVQoYSfPYPDeYvMkJgIBJ7fFEfoiUEMLbmApFvKAOF\n\t\t\t\t\t\tfh3AyRIgIvNZGuhCmOurAxrK83NQf8GxYCrxWVYBDxy2zM+ieqIQfXq7vKPwRj0i\n\t\t\t\t\t\tI93TqeH3tW+NNXxp3L2Vhqp6QjNwTJuQoq8CyeFAppZ3R7I76gS0a/G65BnDexXr\n\t\t\t\t\t\ts35piiX3AgMBAAGjbzBtMB0GA1UdDgQWBBRhlIKvVhsJq55eRmziUxsfKVzMkjBM\n\t\t\t\t\t\tBgNVHREERTBDghRpZHAuY2FyZGlmZm1ldC5hYy51a4YraHR0cHM6Ly9pZHAuY2Fy\n\t\t\t\t\t\tZGlmZm1ldC5hYy51ay9pZHAvc2hpYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tV2tNA0SAzHCAXhPCbT2SAMgB4bSGM51OLwKn+tJNC5gasFq62kERnXcRbl/Ii5VZ\n\t\t\t\t\t\tIu1t8ml0jTLBjiFYCFtq4uGEMeDPPxKNUNEPkWfIqCq693CrSHc1M5Lso4CmhiCK\n\t\t\t\t\t\tCAnz0V1oVkgyBW9e7WnDzRGvVN12hTGmS33ZINOamwmQErUbeEdRnlB7fa3BZHB9\n\t\t\t\t\t\tkdW3SZRhb7CynWQoB6byYyBBWKfTuD1qScRQlIFhOscGX3qxBYBIqwzsJkd4qXPK\n\t\t\t\t\t\t3qrSFwHAyC6nXz1MLyanluHTBD+41hABSHxu5pwWhD8xXbFS0dA+8qJwagPvuO8q\n\t\t\t\t\t\tJA5KMQm1uzCs13HbQj79Nw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cardiff Metropolitan University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cardiffmet.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cardiff Metropolitan University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.uef.fi/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Huuskonen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:haka-ilmoitukset@uef.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jarno"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hagman"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:markus.hagman@uef.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Markus"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Huuskonen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:haka-ilmoitukset@uef.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jarno"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Huuskonen"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:haka-ilmoitukset@uef.fi"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jarno"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.uef.fi/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.csc.fi/english/institutions/haka/instructions/join/eduGAINRegistrationStatement/"
              }
            ],
            "registration_authority": "http://www.csc.fi/haka",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.uef.fi/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uef.fi"
              },
              {
                "information_url": [
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uef.fi/fi/etusivu"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uef.fi/en/etusivu"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "University of Eastern Finland students, faculty and employees."
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "It\u00e4-Suomen yliopiston opiskelijoita, tutkijoita, opetushenkil\u00f6kuntaa ja ty\u00f6ntekij\u00f6it\u00e4."
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Eastern Finland"
                  },
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "\u00d6stra Finlands universitet"
                  },
                  {
                    "lang": "fi",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "It\u00e4-Suomen yliopisto"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDjDCCAnSgAwIBAgICBA8wDQYJKoZIhvcNAQEFBQAwgZAxCzAJBgNVBAYTAkZJ\nMQ8wDQYDVQQHDAZLdW9waW8xJjAkBgNVBAoMHVVuaXZlcnNpdHkgb2YgRWFzdGVy\nbiBGaW5sYW5kMRAwDgYDVQQLDAdTaGliIENBMRQwEgYDVQQDDAtVRUYgU2hpYiBD\nQTEgMB4GCSqGSIb3DQEJARYRaG9zdG1hc3RlckB1ZWYuZmkwHhcNMTQwNDA5MTQx\nMTIzWhcNMjkwNDA1MTQxMTIzWjBZMQswCQYDVQQGEwJGSTEmMCQGA1UECgwdVW5p\ndmVyc2l0eSBvZiBFYXN0ZXJuIEZpbmxhbmQxDTALBgNVBAsMBFRpa2UxEzARBgNV\nBAMMCmlkcC51ZWYuZmkwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDE\nJZ1AwVGJ2S7FOsjH/vsvo2SEsUwN9QFdz4Kf+QBR50NaOocbl6wV6spOt//d/Tbp\nM9qs4Z9EgfT8hvCjNLRhI4m8w6XhYlA/MmBcxgQBYn19xoUTJ3DcJJddLIQsMU2H\nqOKoiYWwLL1ZQgbFG5ilZ15ZWpUXRBdDt9Hn8eK2SF2dPNrUKuAOZyDkMSY9cfwR\npWrSUwX7Mm9+8TceZHWHaoPR2nbBABqBNuhXvZl6yK+bGXFvbPNGbMJTwXY/LJvc\n4x+sSDuR7HM5tGFcwFjVfj2yEva9BwG8jXWB/RSj7eleHLLM7+PvvR5axVaPbQ/9\nCIJjgPh1r8P8arKs140LAgMBAAGjJjAkMCIGA1UdEQQbMBmCCmlkcC51ZWYuZmmC\nC2lkcDIudWVmLmZpMA0GCSqGSIb3DQEBBQUAA4IBAQA9xGaMiAZM1Ivp3XcTeNn2\n2U/vcCD9fZ9FbrB9buJrECPFh31xJqCtY4gTqdJZl9Z9T3e3I8SqahRPdKX8QPed\nXpIjKfMDM9SBSzMFuSUWyVrbvNCrQScwX+qD5PlpsACQzAGC+Q2pF5lqVx9zERef\nfq7jOiSACuaC39ymek0Wok1k6Mes9krUmwJOdP4SjPmgzWCdeh9X/d3xHgUpg2x5\nSami+WFaMgXxZxJhK+roCmH3hkSh3r8U7xlrnfckSfQ2es9PGYnFI6UlZJqqtrTc\nWGsRO8eC1kCnCdgVhnerPYdvl76LeqVtkqSwepNbrncvnyGIOh+jhD2yrwRV7oqQ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "It\u00e4-Suomen yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Eastern Finland"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "\u00d6stra Finlands universitet"
          }
        ],
        "organization_url": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uef.fi"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uef.fi"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uef.fi"
          }
        ],
        "organization_name": [
          {
            "lang": "fi",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "It\u00e4-Suomen yliopisto"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Eastern Finland"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "\u00d6stra Finlands universitet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://dlib-lockssdev2.ucs.ed.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:edina@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "EDINA Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Rusbridge"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:a.rusbridge@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Adam"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://dlib-lockssdev2.ucs.ed.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2013-06-03T14:44:26Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "EDINA Demonstrator LOCKSS service"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://edina.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-lockssdev2.ucs.ed.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://dlib-lockssdev2.ucs.ed.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dlib-lockssdev2.ucs.ed.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dlib-lockssdev2.ucs.ed.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://dlib-lockssdev2.ucs.ed.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://dlib-lockssdev2.ucs.ed.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://dlib-lockssdev2.ucs.ed.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGzCCAgOgAwIBAgIJAIQtmbCJW/PuMA0GCSqGSIb3DQEBBQUAMCcxJTAjBgNV\n\t\t\t\t\t\tBAMTHGRsaWItbG9ja3NzZGV2Mi51Y3MuZWQuYWMudWswHhcNMTMwNTA3MDkyMTUy\n\t\t\t\t\t\tWhcNMjMwNTA1MDkyMTUyWjAnMSUwIwYDVQQDExxkbGliLWxvY2tzc2RldjIudWNz\n\t\t\t\t\t\tLmVkLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA34JSXcKK\n\t\t\t\t\t\tYdYQSYRfOoS6GfkSrQAVlHAXn4sFmHOt7ToOWqEZNcnNqE9rVUxh5XWXpZ5tFec3\n\t\t\t\t\t\tqrNdyUlIvZth+DR68wwZZYUwCjkwfs2GKQln6SVnVUne6k8QX93pXVgTSkzqc+RN\n\t\t\t\t\t\tbl1mt4JcT41rD2/GgAKj7xGMtQziBzrpkNXpNvoKozyJphXyGgKvZi+z1h+KufND\n\t\t\t\t\t\tkc0ZUSoRFJ5Gk3GZldgIHRhTQdh3tYrd+VCFb8Xold7asRvMzpIKMDuAWZ9Sps8o\n\t\t\t\t\t\tQzIRZoqUcwA7vqLGY/C5SRIkDeIs+0s0TYSJZXihnnvXt72rOhavZw2bHDz2bZYw\n\t\t\t\t\t\t8X+FdDwlNytgPQIDAQABo0owSDAnBgNVHREEIDAeghxkbGliLWxvY2tzc2RldjIu\n\t\t\t\t\t\tdWNzLmVkLmFjLnVrMB0GA1UdDgQWBBTVk7N8XLDIxSb9lfiOMNXJY1M1cDANBgkq\n\t\t\t\t\t\thkiG9w0BAQUFAAOCAQEAuDDx9SeeUT1fSoQ5pgQ1arfpOolwRsn+mp/QlmMDL3yn\n\t\t\t\t\t\tYLzoTBNdn6nVkx62vgSReb0zpI6MIeRmz0efJd4ulaRzSZmL228TCdajqc13wSxG\n\t\t\t\t\t\tTZrMn9IlrpAl+1KCZCVY6sqwKmeKWreXwBGno2R4scmEgTYlqJ8AgWMandVSV0I1\n\t\t\t\t\t\tps2I/PUbZ3kc3/2zIdOM2qMkpFReB0KUoEzy27eSRFbLf5rPiaWOroW+wti0PlDi\n\t\t\t\t\t\tV9+uuPyJCrE9JCuwsXge4oRLDXrG4ZozxXgGw6T7Ztv2sO7/Q777HZ5Cx198b30D\n\t\t\t\t\t\tPH5PkyAFdq5eTMTwRJI6WIXZ4pL3aDDMKjySSPfbaA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dlib-lockssdev2.ucs.ed.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://dlib-lockssdev2.ucs.ed.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://dlib-lockssdev2.ucs.ed.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://dlib-lockssdev2.ucs.ed.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://dlib-lockssdev2.ucs.ed.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://dlib-lockssdev2.ucs.ed.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cafe.ifb.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hugo Faria"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "hugo.faria@ifb.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.ifb.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID2DCCAsACAQAwDQYJKoZIhvcNAQEFBQAwgbExJjAkBgNVBAoTHUluc3RpdHV0\nbyBGZWRlcmFsIGRlIEJyYXNpbGlhMQwwCgYDVQQLEwNDUEQxJDAiBgkqhkiG9w0B\nCQEWFWh1Z28uZmFyaWFAaWZiLmVkdS5icjERMA8GA1UEBxMIQnJhc2lsaWExGTAX\nBgNVBAgTEERpc3RyaXRvIEZlZGVyYWwxCzAJBgNVBAYTAkJSMRgwFgYDVQQDEw9j\nYWZlLmlmYi5lZHUuYnIwHhcNMTQwNDMwMTIwNjMzWhcNMTkwNDI5MTIwNjMzWjCB\nsTEmMCQGA1UEChMdSW5zdGl0dXRvIEZlZGVyYWwgZGUgQnJhc2lsaWExDDAKBgNV\nBAsTA0NQRDEkMCIGCSqGSIb3DQEJARYVaHVnby5mYXJpYUBpZmIuZWR1LmJyMREw\nDwYDVQQHEwhCcmFzaWxpYTEZMBcGA1UECBMQRGlzdHJpdG8gRmVkZXJhbDELMAkG\nA1UEBhMCQlIxGDAWBgNVBAMTD2NhZmUuaWZiLmVkdS5icjCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAMl4NkWCkt4LPisjIniHMzV7ad52UPjkndK7dy2P\nPR4zZ4ssQ0em22DdCbv9g/UYtrUZkzbw1pVDuZkmrIEI6IpG235bYis1vdFV6Ezc\nsfqG6cVK07+ov7edKzSUAUL9JPCioRcbh+ol4MYGQ271tNpKI7paE1S3AWmpiiGE\nLKXLItn3SMncuQRjA8XLhYkZWLk76deWt43cKTeUQe4wMQgKjhV/sflk9Yisccnf\nfcqzJKlC7qH5yRm8yNQzUpp43V5sdkQ+yNFPZOJc0LndacUAoyDBle8s3n6rLkkQ\nPet095bxY+ahltMWtcCZM5NWDVbWd/2WGru5NTtTG5SojbECAwEAATANBgkqhkiG\n9w0BAQUFAAOCAQEAT/zrVbbQSdoaqk2/tut9i+nwzX3jVzbIdj4TFF0oFS9YmojK\n5Tu8s0wR3GdoyOPp367k9AFkrM5oVtdkN/wmzgiMYQzbh65t3bU/sx3/QNpvN1FF\n3ZrCo4vSxwMc0yEmdgT0eYUfyeWL/gqJ08nnsVoY8cmkoV37rjNhMLCz+WRdhoGI\nziTBHSHSfT19MUBPshQtI8InKtZxzjo9PEPIzfxLyj1GNWzhmNVeAoEwefVjm4Wi\nXuahCg66qDobt3XR77O74guAdjEtcrIFLdXDQpZb/yrA4dCH3l53A6k8PB7Gcqxn\nlfIkoNoppJp00hFJFgb7O6y36a0AO2jY7LDjHA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.ifb.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.ifb.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.ifb.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.ifb.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.ifb.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.ifb.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.ifb.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.ifb.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifb.edu.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifb.edu.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFB -Instituto Federal de Brasilia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFB -Instituto Federal de Brasilia"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFB -Instituto Federal de Brasilia"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFB -Instituto Federal de Brasilia"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID2DCCAsACAQAwDQYJKoZIhvcNAQEFBQAwgbExJjAkBgNVBAoTHUluc3RpdHV0\nbyBGZWRlcmFsIGRlIEJyYXNpbGlhMQwwCgYDVQQLEwNDUEQxJDAiBgkqhkiG9w0B\nCQEWFWh1Z28uZmFyaWFAaWZiLmVkdS5icjERMA8GA1UEBxMIQnJhc2lsaWExGTAX\nBgNVBAgTEERpc3RyaXRvIEZlZGVyYWwxCzAJBgNVBAYTAkJSMRgwFgYDVQQDEw9j\nYWZlLmlmYi5lZHUuYnIwHhcNMTQwNDMwMTIwNjMzWhcNMTkwNDI5MTIwNjMzWjCB\nsTEmMCQGA1UEChMdSW5zdGl0dXRvIEZlZGVyYWwgZGUgQnJhc2lsaWExDDAKBgNV\nBAsTA0NQRDEkMCIGCSqGSIb3DQEJARYVaHVnby5mYXJpYUBpZmIuZWR1LmJyMREw\nDwYDVQQHEwhCcmFzaWxpYTEZMBcGA1UECBMQRGlzdHJpdG8gRmVkZXJhbDELMAkG\nA1UEBhMCQlIxGDAWBgNVBAMTD2NhZmUuaWZiLmVkdS5icjCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAMl4NkWCkt4LPisjIniHMzV7ad52UPjkndK7dy2P\nPR4zZ4ssQ0em22DdCbv9g/UYtrUZkzbw1pVDuZkmrIEI6IpG235bYis1vdFV6Ezc\nsfqG6cVK07+ov7edKzSUAUL9JPCioRcbh+ol4MYGQ271tNpKI7paE1S3AWmpiiGE\nLKXLItn3SMncuQRjA8XLhYkZWLk76deWt43cKTeUQe4wMQgKjhV/sflk9Yisccnf\nfcqzJKlC7qH5yRm8yNQzUpp43V5sdkQ+yNFPZOJc0LndacUAoyDBle8s3n6rLkkQ\nPet095bxY+ahltMWtcCZM5NWDVbWd/2WGru5NTtTG5SojbECAwEAATANBgkqhkiG\n9w0BAQUFAAOCAQEAT/zrVbbQSdoaqk2/tut9i+nwzX3jVzbIdj4TFF0oFS9YmojK\n5Tu8s0wR3GdoyOPp367k9AFkrM5oVtdkN/wmzgiMYQzbh65t3bU/sx3/QNpvN1FF\n3ZrCo4vSxwMc0yEmdgT0eYUfyeWL/gqJ08nnsVoY8cmkoV37rjNhMLCz+WRdhoGI\nziTBHSHSfT19MUBPshQtI8InKtZxzjo9PEPIzfxLyj1GNWzhmNVeAoEwefVjm4Wi\nXuahCg66qDobt3XR77O74guAdjEtcrIFLdXDQpZb/yrA4dCH3l53A6k8PB7Gcqxn\nlfIkoNoppJp00hFJFgb7O6y36a0AO2jY7LDjHA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFB -Instituto Federal de Brasilia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFB -Instituto Federal de Brasilia"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifb.edu.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifb.edu.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFB -Instituto Federal de Brasilia"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFB -Instituto Federal de Brasilia"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.archer.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@archer.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Archer Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Booth"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:s.booth@ed.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Stephen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.archer.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-01-22T12:59:13Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ARCHER SAFE"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.archer.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Edinburgh"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.archer.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.archer.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.archer.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.archer.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.archer.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.archer.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.archer.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SAFE service administration for ARCHER"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.archer.ac.uk/assets/img/archer_logo_259.png",
                    "height": "83",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "259"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ARCHER SAFE"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAPNKT3NJhvy6MA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\n\t\t\t\t\t\tBAMTEHd3dy5hcmNoZXIuYWMudWswHhcNMTQwODI3MTUxNjExWhcNMjQwODI0MTUx\n\t\t\t\t\t\tNjExWjAbMRkwFwYDVQQDExB3d3cuYXJjaGVyLmFjLnVrMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEA2glxhYdtiCZ1hmouXkzW5UivP7rf/ro9gBIjJvcl\n\t\t\t\t\t\t08BWT5r3dluh+SL7qHsPN+ej8ygoS3iGVeSjFD3CizzqG4OtyUtPiB5TMOWrbrmj\n\t\t\t\t\t\tZzbixIKM4weAtSoJdHvboy6Qlt170ZaQoqz4rqAc66kJTI1ILzyE+uBCyfV2GUfm\n\t\t\t\t\t\tZ0/ZXe0syjKPo85N0779rCfYmnUTx6jojS1pT1neclayO/VEgj4RbW1hkoK+hgVU\n\t\t\t\t\t\tuZsQPD/Ei+LNykBFuKkRhZp1Sg27KOaS0wrYJjkqjKC5xlj7xnSX6ynVnjzaRb6V\n\t\t\t\t\t\tdPNx6XuHKAgFXxNhzzck844ILL1jlMjQerFqvdtlyJ2V3wIDAQABoz4wPDAbBgNV\n\t\t\t\t\t\tHREEFDASghB3d3cuYXJjaGVyLmFjLnVrMB0GA1UdDgQWBBTO2VNhV9Q2f2wqQuTG\n\t\t\t\t\t\tE8x16++mCDANBgkqhkiG9w0BAQUFAAOCAQEAiPBzjUdPLQeenN8ajRudraWnB2b5\n\t\t\t\t\t\t0gyPpNCbm10P/Xb58zRIrNdrnC6PoxIYqfpA2+/TErNx9PjUHaJq2h7mwhH5SVQf\n\t\t\t\t\t\tmoWQNrvsVq99g7oFrMre7/V5sne0kRe2cHK4bvLKAXGOhGxJcQAVoRkL//rHXzmz\n\t\t\t\t\t\tcjonxObbFuxU1sF3D6GdHdPgI2pGMaoeikyY6NX43AZ0xOFUEIYlWL6JlJdtZ/dC\n\t\t\t\t\t\tjhhNJTBgE5N2TUn+dyUgezjdNQ2hGrgUsFcvpEs0vPUufMbKYu+q904waWu0Ogul\n\t\t\t\t\t\tpbOFcMFgJJJ7jDa/ks8fgt6NX85BKIDwE0AZ3ce6AzEikZKWhGJTDnRYZQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.archer.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.archer.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.archer.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.archer.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.archer.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.archer.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "ARCHER SAFE"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "SAFE service administration for ARCHER"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:mace:dir:attribute-def:eduPersonTargetedID",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:mace:shibboleth:1.0:attributeNamespace:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.theacademiclibrary.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Coyne"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@theacademiclibrary.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pat"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Coyne"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@theacademiclibrary.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pat"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.theacademiclibrary.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2016-02-16T15:48:21Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "The Academic Library"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.theacademiclibrary.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Academic Library Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDpjCCAo6gAwIBAgIJAPs1pKAPoYV7MA0GCSqGSIb3DQEBBQUAMEAxGTAXBgNV\n\t\t\t\t\t\tBAoTEEFjYWRlbWljIExpYnJhcnkxIzAhBgNVBAMTGnd3dy50aGVhY2FkZW1pY2xp\n\t\t\t\t\t\tYnJhcnkuY29tMB4XDTE2MDIxMDE0MDk1MVoXDTI2MDIwNzE0MDk1MVowQDEZMBcG\n\t\t\t\t\t\tA1UEChMQQWNhZGVtaWMgTGlicmFyeTEjMCEGA1UEAxMad3d3LnRoZWFjYWRlbWlj\n\t\t\t\t\t\tbGlicmFyeS5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDyA/mV\n\t\t\t\t\t\tzffMFJwoTbPcyN9sQs3CdE2MVkBQbT8E3zX1apSGHfk+p8sLMaH+6nzjVI6+bTiP\n\t\t\t\t\t\tkdbroNLt8HDau5EnQVUlhSprDpMUfXCv1mLitLrFH7plto76nsOxwKjwIPjKInsF\n\t\t\t\t\t\tr4zFNUXscvgSvvt7BSCxjSbBk6j5MLNxBNydAVw6oEyCokRTQVmJGgc0ellCFWmZ\n\t\t\t\t\t\tU5XAhttN7Kcu+c8Crg4CQlJhqywEjEpG8U87AXmRhSCWgU6ca7nQ3nJFhE8e/cku\n\t\t\t\t\t\tnAPNg4/yAgXH+gH+cPMhHa7gLMd62oaiIsGwZ6j/AQSAAbxeWCdY0P25r+uHkp9y\n\t\t\t\t\t\t+QpD5bgLlzI32selAgMBAAGjgaIwgZ8wHQYDVR0OBBYEFLtmKFe+6mR/wmdBR3h5\n\t\t\t\t\t\t/a3jS5HwMHAGA1UdIwRpMGeAFLtmKFe+6mR/wmdBR3h5/a3jS5HwoUSkQjBAMRkw\n\t\t\t\t\t\tFwYDVQQKExBBY2FkZW1pYyBMaWJyYXJ5MSMwIQYDVQQDExp3d3cudGhlYWNhZGVt\n\t\t\t\t\t\taWNsaWJyYXJ5LmNvbYIJAPs1pKAPoYV7MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBALXivAHD87zmSGPoCCxbm9DoS3Slxdxf1FajIG5LvrskufYBOcHQ\n\t\t\t\t\t\tySeMNSLxm3PaOjhs/t4XVu2ruqh3ezOOU3X2r0gK19p8lViHEQduAd153McmjHek\n\t\t\t\t\t\tn4RcvIaqaX6GOrGqhKMUEM4H0usvomDJDMLVmRsXrzzN8X6nKxr1NIDPN+bK5CW1\n\t\t\t\t\t\tgGwbO1Ov27G4sS4Rphlcj6X9/tDxLSi3ymWQXU1k5DTQDSfjqylxhjqhmgfyhCPS\n\t\t\t\t\t\t59XCigD56OeJwGTf+dtUCq6D/MEPbEH/HbiNDwo8bFQo+vXWW69PsXh0Y28bPUKI\n\t\t\t\t\t\tldEPubpuegrPDcXT9xfexgy93PV17kmR7TU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDpjCCAo6gAwIBAgIJAPs1pKAPoYV7MA0GCSqGSIb3DQEBBQUAMEAxGTAXBgNV\n\t\t\t\t\t\tBAoTEEFjYWRlbWljIExpYnJhcnkxIzAhBgNVBAMTGnd3dy50aGVhY2FkZW1pY2xp\n\t\t\t\t\t\tYnJhcnkuY29tMB4XDTE2MDIxMDE0MDk1MVoXDTI2MDIwNzE0MDk1MVowQDEZMBcG\n\t\t\t\t\t\tA1UEChMQQWNhZGVtaWMgTGlicmFyeTEjMCEGA1UEAxMad3d3LnRoZWFjYWRlbWlj\n\t\t\t\t\t\tbGlicmFyeS5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDyA/mV\n\t\t\t\t\t\tzffMFJwoTbPcyN9sQs3CdE2MVkBQbT8E3zX1apSGHfk+p8sLMaH+6nzjVI6+bTiP\n\t\t\t\t\t\tkdbroNLt8HDau5EnQVUlhSprDpMUfXCv1mLitLrFH7plto76nsOxwKjwIPjKInsF\n\t\t\t\t\t\tr4zFNUXscvgSvvt7BSCxjSbBk6j5MLNxBNydAVw6oEyCokRTQVmJGgc0ellCFWmZ\n\t\t\t\t\t\tU5XAhttN7Kcu+c8Crg4CQlJhqywEjEpG8U87AXmRhSCWgU6ca7nQ3nJFhE8e/cku\n\t\t\t\t\t\tnAPNg4/yAgXH+gH+cPMhHa7gLMd62oaiIsGwZ6j/AQSAAbxeWCdY0P25r+uHkp9y\n\t\t\t\t\t\t+QpD5bgLlzI32selAgMBAAGjgaIwgZ8wHQYDVR0OBBYEFLtmKFe+6mR/wmdBR3h5\n\t\t\t\t\t\t/a3jS5HwMHAGA1UdIwRpMGeAFLtmKFe+6mR/wmdBR3h5/a3jS5HwoUSkQjBAMRkw\n\t\t\t\t\t\tFwYDVQQKExBBY2FkZW1pYyBMaWJyYXJ5MSMwIQYDVQQDExp3d3cudGhlYWNhZGVt\n\t\t\t\t\t\taWNsaWJyYXJ5LmNvbYIJAPs1pKAPoYV7MAwGA1UdEwQFMAMBAf8wDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBALXivAHD87zmSGPoCCxbm9DoS3Slxdxf1FajIG5LvrskufYBOcHQ\n\t\t\t\t\t\tySeMNSLxm3PaOjhs/t4XVu2ruqh3ezOOU3X2r0gK19p8lViHEQduAd153McmjHek\n\t\t\t\t\t\tn4RcvIaqaX6GOrGqhKMUEM4H0usvomDJDMLVmRsXrzzN8X6nKxr1NIDPN+bK5CW1\n\t\t\t\t\t\tgGwbO1Ov27G4sS4Rphlcj6X9/tDxLSi3ymWQXU1k5DTQDSfjqylxhjqhmgfyhCPS\n\t\t\t\t\t\t59XCigD56OeJwGTf+dtUCq6D/MEPbEH/HbiNDwo8bFQo+vXWW69PsXh0Y28bPUKI\n\t\t\t\t\t\tldEPubpuegrPDcXT9xfexgy93PV17kmR7TU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "want_assertions_signed": "false",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "index": "1",
              "location": "https://www.theacademiclibrary.com/oa/auth/rcv/shib/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.theacademiclibrary.com/oa/auth/rcv/saml2/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor"
        }
      ]
    }
  ],
  [
    "https://admin.webfiltering.ja.net/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibsupport@ifl.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Support Contact"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibtechcontact@ifl.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Shibboleth Technical Contact"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://admin.webfiltering.ja.net/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "RM Education plc: RM Safetynet JANET"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rm.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "RM Education plc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://admin.webfiltering.ja.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://admin.webfiltering.ja.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://admin.webfiltering.ja.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://admin.webfiltering.ja.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://admin.webfiltering.ja.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://admin.webfiltering.ja.net/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJAIDKIKpmE2tBMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\n\t\t\t\t\t\tBAMTG2FkbWluLnNhZmV0eW5ldC5ybXBsYy5jby51azAeFw0xMDA0MDgxNjE2MTha\n\t\t\t\t\t\tFw0yMDA0MDUxNjE2MThaMCYxJDAiBgNVBAMTG2FkbWluLnNhZmV0eW5ldC5ybXBs\n\t\t\t\t\t\tYy5jby51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALyO69kuQy4+\n\t\t\t\t\t\tR7W0KgA21wY7EnbY2qr8K1AKfX87jvsfDX5Jg+XwifaI/8f8sIju9jlgg0S2ju+M\n\t\t\t\t\t\tuWQyCYV6cCMp790MEXXaOR0PiAkrallrkYg/+FbP7+flmOrPhj6UWCAc80ZWJ8wx\n\t\t\t\t\t\tU6Un+UpDpmhRrQWjOn0sOW6PvkbZlRrEtW6XJ2PfhOCHHfAJIcB/r4frQFvmGBk1\n\t\t\t\t\t\t6e24W46xEPi2gznxM9MRm/MMBnFHBzHlpgu+QmL+gBI6OQ0Gr1nmZgcTJqEJCahk\n\t\t\t\t\t\tdp51SjegGKmXXWAdV7pGYkoRrwYH6TryXNaHUXQn0zoS+aa1kZIf0dVp0S508go6\n\t\t\t\t\t\taqwe92WWsAcCAwEAAaNJMEcwJgYDVR0RBB8wHYIbYWRtaW4uc2FmZXR5bmV0LnJt\n\t\t\t\t\t\tcGxjLmNvLnVrMB0GA1UdDgQWBBTiUv6qHBxNTHW11t8mP9SXPRvMmjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAhVafLlFnznxyNY5Zls8IiCN2kAqwUN5iBuVx2Q749LcVHlGy\n\t\t\t\t\t\tNtTZVpLWcrZsklTl2mBJuGI5XjqjuEu/UJtaRx0p6oC32Pg2R8/McMcJjLtbwA9X\n\t\t\t\t\t\tpIZsuOfARLq0AFS9ncrgZtVrua9YErJSWSCUkzZgJTu/1Aelc1Dlojdmp22GH4Rn\n\t\t\t\t\t\tFr1hRdDgtzpAwdBpxPdai7Pdaf47QVRSgfDjCuJ2zJopboYAbnk6UAuiLWDuLtcB\n\t\t\t\t\t\to8UiVcMPP/vvRio3IzTVoEKAmb8/EENkXRSR+we7CKNAQhZBvTvC2oWruki4UmMK\n\t\t\t\t\t\taFvLcsb+dVUZ5xAnv9teHQR18B9PVW+1Se6k3A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJAIDKIKpmE2tBMA0GCSqGSIb3DQEBBQUAMCYxJDAiBgNV\n\t\t\t\t\t\tBAMTG2FkbWluLnNhZmV0eW5ldC5ybXBsYy5jby51azAeFw0xMDA0MDgxNjE2MTha\n\t\t\t\t\t\tFw0yMDA0MDUxNjE2MThaMCYxJDAiBgNVBAMTG2FkbWluLnNhZmV0eW5ldC5ybXBs\n\t\t\t\t\t\tYy5jby51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALyO69kuQy4+\n\t\t\t\t\t\tR7W0KgA21wY7EnbY2qr8K1AKfX87jvsfDX5Jg+XwifaI/8f8sIju9jlgg0S2ju+M\n\t\t\t\t\t\tuWQyCYV6cCMp790MEXXaOR0PiAkrallrkYg/+FbP7+flmOrPhj6UWCAc80ZWJ8wx\n\t\t\t\t\t\tU6Un+UpDpmhRrQWjOn0sOW6PvkbZlRrEtW6XJ2PfhOCHHfAJIcB/r4frQFvmGBk1\n\t\t\t\t\t\t6e24W46xEPi2gznxM9MRm/MMBnFHBzHlpgu+QmL+gBI6OQ0Gr1nmZgcTJqEJCahk\n\t\t\t\t\t\tdp51SjegGKmXXWAdV7pGYkoRrwYH6TryXNaHUXQn0zoS+aa1kZIf0dVp0S508go6\n\t\t\t\t\t\taqwe92WWsAcCAwEAAaNJMEcwJgYDVR0RBB8wHYIbYWRtaW4uc2FmZXR5bmV0LnJt\n\t\t\t\t\t\tcGxjLmNvLnVrMB0GA1UdDgQWBBTiUv6qHBxNTHW11t8mP9SXPRvMmjANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAhVafLlFnznxyNY5Zls8IiCN2kAqwUN5iBuVx2Q749LcVHlGy\n\t\t\t\t\t\tNtTZVpLWcrZsklTl2mBJuGI5XjqjuEu/UJtaRx0p6oC32Pg2R8/McMcJjLtbwA9X\n\t\t\t\t\t\tpIZsuOfARLq0AFS9ncrgZtVrua9YErJSWSCUkzZgJTu/1Aelc1Dlojdmp22GH4Rn\n\t\t\t\t\t\tFr1hRdDgtzpAwdBpxPdai7Pdaf47QVRSgfDjCuJ2zJopboYAbnk6UAuiLWDuLtcB\n\t\t\t\t\t\to8UiVcMPP/vvRio3IzTVoEKAmb8/EENkXRSR+we7CKNAQhZBvTvC2oWruki4UmMK\n\t\t\t\t\t\taFvLcsb+dVUZ5xAnv9teHQR18B9PVW+1Se6k3A=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://admin.webfiltering.ja.net/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://admin.webfiltering.ja.net/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://admin.webfiltering.ja.net/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://admin.webfiltering.ja.net/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://admin.webfiltering.ja.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://admin.webfiltering.ja.net/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://admin.webfiltering.ja.net/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://admin.webfiltering.ja.net/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://admin.webfiltering.ja.net/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://admin.webfiltering.ja.net/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp-ensr.ens-rennes.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "postmaster@ens-rennes.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp-ensr.ens-rennes.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-02-25T13:55:28Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-ensr.ens-rennes.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-ensr.ens-rennes.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-ensr.ens-rennes.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ens-rennes.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ens-rennes.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ensemble des utilisateurs de l'ENS Rennes"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENS Rennes"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "ENS Rennes"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiygAwIBAgIVAMWqxLx7lYiNhlTPapEholL2ajx8MA0GCSqGSIb3DQEB\nBQUAMCExHzAdBgNVBAMTFmlkcC1lbnNyLmVucy1yZW5uZXMuZnIwHhcNMTQwMjI1\nMTgzNDE1WhcNMzQwMjI1MTgzNDE1WjAhMR8wHQYDVQQDExZpZHAtZW5zci5lbnMt\ncmVubmVzLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAmDxunK9B\nVB2RZVJ2YdtrKMLZpQ+7U9dDBnjD2xkwKFyEswtX/U2OK0nALFkJCgK+RSeU2A6e\nkmHZIcYKN4giqcXt0UyAVdXDQP8Ovs6KgL6vdcLofuYthL5mvQeBHG3AtGLffpZp\n7Xg/RpjBtQSC/5R4/O9IMRPYPGD9ZJpQMxl1lBiVw36e+/9zwysyhjpGAIm96h1f\nKkZaYNsMT8Y+aHNmcvYXB/EPKj9iLtFxOYmD19DbIFSVSOrc3N81xtYZSg3w+K9M\nJvBT+jJ8Tr7tXaVoNAUL50qfTR9V8Otftlxlrm+btFQANxOwfmAa6NtLqChTuErG\nZMZyvh7dvtDFDQIDAQABo3MwcTBQBgNVHREESTBHghZpZHAtZW5zci5lbnMtcmVu\nbmVzLmZyhi1odHRwczovL2lkcC1lbnNyLmVucy1yZW5uZXMuZnIvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFMWCwroMGof468uwDOVo9CmJtFCmMA0GCSqGSIb3DQEB\nBQUAA4IBAQBuJkugeq35RQ1eJVCFpQEF1cvz3HI2WNaYJVAzNKVHjQKLTgeEXTAw\n2n0U0wijhjNhLn0KU7RjF/YKq3byxsvmw2V/dkor6Uj/o24QRIS/rnGp0OOAm8md\nKuATxDlbfiUiLZ8P09LWfCj7kBofKAWpdSA3EqK3C1r1ABP3cfgy6bCEAKmImZ/g\nrU56Bc4TlmzKTAcgt6N/Wmwb7jubtPpeoZ3oQuuMjl5SD5kabufWGeLRR3blN2Fc\n067E4nErVpBw181gQpQMwpin/OjW+lbqa+ayBIRJfng4G2t5KcnvpJzfmlJS/Nus\nrfl6FRk/WmuNV0iaMjHeIz48Vet1SQLF"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ENS Rennes"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ens-rennes.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "ENS Rennes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.enc.sorbonne.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "informatique@enc.sorbonne.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.enc.sorbonne.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-02-02T14:31:53Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.enc.sorbonne.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.enc.sorbonne.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.enc.sorbonne.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "enc.sorbonne.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.enc.sorbonne.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Idp test \u00e9cole nationale des Chartes"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Idp test \u00e9cole nationale des Chartes"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Nationale des Chartes production"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ecole Nationale des Chartes production"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUHHNR9K1ZuuDTVcVyeRLx99mFDa8wDQYJKoZIhvcNAQEF\nBQAwJTEjMCEGA1UEAwwac2hpYmJvbGV0aC5lbmMuc29yYm9ubmUuZnIwHhcNMTQx\nMTE0MTUxMjMzWhcNMzQxMTE0MTUxMjMzWjAlMSMwIQYDVQQDDBpzaGliYm9sZXRo\nLmVuYy5zb3Jib25uZS5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\nANZSfCkacJ9hNSaYxgFaZojB+8jhgGCdm4UrACCnIEWe0nUmAXZxkAsP4qwBIoFQ\nVVU/MrgEUdC0IET7zMDoJTNVAWny/7RwBUS5hqk9UW8SWWk7G3UK3JYQNyQQz94H\nijjiBGWaul5Im+JmqIq53qQ0i6Eb6ME+PhtquaLHY7NbGADRBGl0FLxXculDirtr\nKagzWDL8WGem9pPK70VfA7NdoGK0mTQJ+sGtUpOMsnNzj9PdCh8Fy+zyc4mUWeE8\nihunnzwXgh4JBdVpVoadL+RFjjrchNVl0URUDc+hppaq7o1dceGz7WjNE+tDczVU\nHsehrjZBMyiOWELToCRixaECAwEAAaN7MHkwHQYDVR0OBBYEFNb7pKFV8CQpIfWw\n5yA4HECYK+RDMFgGA1UdEQRRME+CGnNoaWJib2xldGguZW5jLnNvcmJvbm5lLmZy\nhjFodHRwczovL3NoaWJib2xldGguZW5jLnNvcmJvbm5lLmZyL2lkcC9zaGliYm9s\nZXRoMA0GCSqGSIb3DQEBBQUAA4IBAQAU+8wCycc2Bi+7LEh80AgyarkG5P/NUtc+\ntkIZrrOz69LB6f8BFngBo/+gbUshNKRW7LE8KvCu2qLJJlCh3hUs6dHtYi8qt/xk\n0y2Y86WizmPpA4+72wDw6i+nbWfaTUvs+pwY9In2gXxegFVZldCmbIwEflmu1gfM\n8nZJMLLuD1HkmNPA0bJSK15W+m8nj7H+90L9o9vm+Tl8aqilcVk4llTZRibACZXM\nfJHF1BDZX2A5KV8UzZ4NO8HQrBdMW/tVBZvBCCqAzrZreQY+fBv8se9HkR5M83Rr\nK+rXM7jkNQmgfZEZYJwccXuA+Ugd0UMtXh6qTpXcf8hNrCZEj9jQ"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ecole Nationale des Chartes production"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.enc.sorbonne.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ecole Nationale des Chartes production"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso.bsfc.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Szkudlapski"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:johns@bsfc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Paul"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Szkudlapski"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:johns@bsfc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "John Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.bsfc.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2010-06-04T14:25:14Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAJQNNxLqLyuVe5PctJiOH67/djG+MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB0xGzAZBgNVBAMTEnNoaWJpZHAuYnNmYy5hYy51azAeFw0xNDA0MTgxMzEx\n\t\t\t\t\t\tMDNaFw0zNDA0MTgxMzExMDNaMB0xGzAZBgNVBAMTEnNoaWJpZHAuYnNmYy5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIsaf63mJRi9DTIIEOZX\n\t\t\t\t\t\toTUhdrTefTq6ZgKMyPtehzYJpItEgN/CV/1l6iUZe2U5R8D5RtGXMhzqaFz/ZadW\n\t\t\t\t\t\ttw+RB3W0s60YchtuSqDDC3QTK+TWZLDIHDlldik9zwts3819cU/sBdqwOzKu6WTb\n\t\t\t\t\t\tvwzvRrCwiAt4wnOqXcF3EjncKWfNEySUsmRZlEQPvvbx9U3sPh3tyWWGN3rB8fBu\n\t\t\t\t\t\tKXE6LKNuwopaBDjOAqm0auIpVxgqedDSwhT80UpV0ncAL8/A6D2WYdUZ5kwXE4SU\n\t\t\t\t\t\t818MMM7U4d54TVdqFjHow4GMuzIsQ4AqE2bFlBB2ABLUVmVMXOrxv0wFvZ3ULcwU\n\t\t\t\t\t\t/20CAwEAAaNrMGkwSAYDVR0RBEEwP4ISc2hpYmlkcC5ic2ZjLmFjLnVrhilodHRw\n\t\t\t\t\t\tczovL3NoaWJpZHAuYnNmYy5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n\t\t\t\t\t\tjLVWkxPeVPF+7dS8T+2Dc3vbEDMwDQYJKoZIhvcNAQEFBQADggEBAEcAtYMdqfwd\n\t\t\t\t\t\tuhf/ERsHz2fss7ROO6JFndGq19NXLlERMDf9qG6UHz1RKtzs/kNSS9Pr2JcERKBB\n\t\t\t\t\t\t4hJOTPQ1q8cU5//2RIGsWrO+7Wt/WS1kQlAu0Ez9ly9nC8KqeAkxnhaCSTx3csnr\n\t\t\t\t\t\tuSDKZSBupejCt+bDvXF1A1tMigvDhKbP35ELwx64900xSSfK+To51AdhAkzec4z0\n\t\t\t\t\t\tlfSqU/r6WiiM1a5KTAfVjU4JPrFYU0VjRWds6BpNBZIx8JRYHHFhR7hxmOweJcKH\n\t\t\t\t\t\tgCQVhaBRE1QFYK4NBInDyUqmQqreNJNWJHv2Ek89P0pS3cU9QueuoLVNYABQGMIy\n\t\t\t\t\t\tXbBdS/uPgFA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bsfc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.bsfc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.bsfc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibidp.bsfc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibidp.bsfc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibidp.bsfc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibidp.bsfc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibidp.bsfc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibidp.bsfc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "bsfc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNDCCAhygAwIBAgIVAJQNNxLqLyuVe5PctJiOH67/djG+MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB0xGzAZBgNVBAMTEnNoaWJpZHAuYnNmYy5hYy51azAeFw0xNDA0MTgxMzEx\n\t\t\t\t\t\tMDNaFw0zNDA0MTgxMzExMDNaMB0xGzAZBgNVBAMTEnNoaWJpZHAuYnNmYy5hYy51\n\t\t\t\t\t\tazCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAIsaf63mJRi9DTIIEOZX\n\t\t\t\t\t\toTUhdrTefTq6ZgKMyPtehzYJpItEgN/CV/1l6iUZe2U5R8D5RtGXMhzqaFz/ZadW\n\t\t\t\t\t\ttw+RB3W0s60YchtuSqDDC3QTK+TWZLDIHDlldik9zwts3819cU/sBdqwOzKu6WTb\n\t\t\t\t\t\tvwzvRrCwiAt4wnOqXcF3EjncKWfNEySUsmRZlEQPvvbx9U3sPh3tyWWGN3rB8fBu\n\t\t\t\t\t\tKXE6LKNuwopaBDjOAqm0auIpVxgqedDSwhT80UpV0ncAL8/A6D2WYdUZ5kwXE4SU\n\t\t\t\t\t\t818MMM7U4d54TVdqFjHow4GMuzIsQ4AqE2bFlBB2ABLUVmVMXOrxv0wFvZ3ULcwU\n\t\t\t\t\t\t/20CAwEAAaNrMGkwSAYDVR0RBEEwP4ISc2hpYmlkcC5ic2ZjLmFjLnVrhilodHRw\n\t\t\t\t\t\tczovL3NoaWJpZHAuYnNmYy5hYy51ay9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU\n\t\t\t\t\t\tjLVWkxPeVPF+7dS8T+2Dc3vbEDMwDQYJKoZIhvcNAQEFBQADggEBAEcAtYMdqfwd\n\t\t\t\t\t\tuhf/ERsHz2fss7ROO6JFndGq19NXLlERMDf9qG6UHz1RKtzs/kNSS9Pr2JcERKBB\n\t\t\t\t\t\t4hJOTPQ1q8cU5//2RIGsWrO+7Wt/WS1kQlAu0Ez9ly9nC8KqeAkxnhaCSTx3csnr\n\t\t\t\t\t\tuSDKZSBupejCt+bDvXF1A1tMigvDhKbP35ELwx64900xSSfK+To51AdhAkzec4z0\n\t\t\t\t\t\tlfSqU/r6WiiM1a5KTAfVjU4JPrFYU0VjRWds6BpNBZIx8JRYHHFhR7hxmOweJcKH\n\t\t\t\t\t\tgCQVhaBRE1QFYK4NBInDyUqmQqreNJNWJHv2Ek89P0pS3cU9QueuoLVNYABQGMIy\n\t\t\t\t\t\tXbBdS/uPgFA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Birkenhead Sixth Form College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bsfc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Birkenhead Sixth Form College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.dit.ie/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Duffy"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:liam.duffy@dit.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Liam"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "NOC"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:noc@dit.ie"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Roche"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:tracey.roche@dit.ie"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tracey"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.dit.ie/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2010-10-06T23:00:00Z",
            "registration_authority": "http://www.heanet.ie",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.dit.ie/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.dit.ie/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.dit.ie/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "dit.ie"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.dit.ie"
                  }
                ],
                "logo": [
                  {
                    "text": "https://edugate.heanet.ie/rr3/logos/dit.png",
                    "height": "124",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "124"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "lang": "en",
                    "height": "124",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "124"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Dublin Institute of Technology"
                  },
                  {
                    "lang": "ga",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institi\u00faid Teicneola\u00edochta Bhaile Atha Cliath"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "dit.ie"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:53.3386922370051,-6.266900897026062"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "147.252.0.0/16"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.1.28.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.186.8.0/29"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "193.1.186.8/29"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:0770:0068::/48"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAJ7TJcMtAwNtz/8vec1TyPtNeUveMA0GCSqGSIb3DQEB\nBQUAMBUxEzARBgNVBAMTCmlkcC5kaXQuaWUwHhcNMTAwNjIyMTExNTAwWhcNMzAw\nNjIyMTExNTAwWjAVMRMwEQYDVQQDEwppZHAuZGl0LmllMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAs8xgb2mE8WJaUYR0fVcH8dEAS7f7bGWpyzrT+SPa\nv5egAD27fcuhUP+QFILf6plDW6YqXBcbymxHE1yPExVYO84v8lfpULEMbii1wRg+\nz/ywHqZ1Bio+aq8OrcCdjrlR84n3fpR/6aaVr21JbwVPR6+sCuc4+q3opXzaGGFa\nLvTT3hcl5C/cGiJQra81rlv9Q1dWwZh6xvmR5wrqzxkKiyJ8mr1KjuePyJV3BOJJ\nzeaki3SYdkB+xM8gO6P19lXkvsVYnkUWVR79E61mFReUWPzr9Bjub0A/aE2Pwzuq\nZWPedEsVR4NfTZANVhewKCNFDadRDbRFDDRW9W2Lc2v3rwIDAQABo1swWTA4BgNV\nHREEMTAvggppZHAuZGl0LmllhiFodHRwczovL2lkcC5kaXQuaWUvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFF6EGb7A7x+2xLW/hEJHpulkdzkYMA0GCSqGSIb3DQEB\nBQUAA4IBAQA2kPu6oYpbBoldko99FX4ePbXa9ty11/I+EamddnzkAsLWsNd2JLQW\nR9wo+2vSkUzaxck11FMBS5hbqNsKdUjqTtscGP2MfmIiQJG+dgN7ThHKVvaxyTpc\n3JPQIvaew08s7L8ShjCuhkjmYmlOa4olGV1Z0aG7SjSI9b5w3MfDwN2lecAAUKVW\nN2vAFMBh3uxWVlSDbivRfNXflXOMYtDqAG1BPHff1UMArvYiSxxiVwM5tNBxmgZy\nN8bWLtABtkfUyrU6ay6E7h6qReHu30iU46r8xDyZkHjLa6iakvGjobWlTBTAF24P\nmANH8mJhMI+endx1YgUmOJJXylP/VAbC"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Dublin Institute of Technology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.dit.ie"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Dublin Institute of Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.brookehouse.ac.uk/openathens",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.brookehouse.ac.uk/openathens",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/brookehouse.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/brookehouse.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brookehouse.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bsix Brooke House Sixth Form College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.brookehouse.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sts.windows.net/a1bce70e-1f36-4e8c-b4f3-48980a5f78ee/",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "admin.infra.dsi@montpellier-bs.com"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sts.windows.net/a1bce70e-1f36-4e8c-b4f3-48980a5f78ee/",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-02-20T10:07:00Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.microsoftonline.com/a1bce70e-1f36-4e8c-b4f3-48980a5f78ee/saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://login.microsoftonline.com/a1bce70e-1f36-4e8c-b4f3-48980a5f78ee/saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.microsoftonline.com/a1bce70e-1f36-4e8c-b4f3-48980a5f78ee/saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.microsoftonline.com/a1bce70e-1f36-4e8c-b4f3-48980a5f78ee/saml2",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "montpellier-bs.com"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.montpellier-bs.com/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Montpellier Business School - IDP - Production"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Montpellier Business School - IDP - Production"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Montpellier Business School"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Montpellier Business School"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Montpellier Business School"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.montpellier-bs.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Montpellier Business School"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.nbi.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:computing.helpdesk@nbi.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Computing Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Imran"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Mohamed.imran@nbi.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mohamed"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.nbi.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2013-07-16T17:37:34Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAP8HG8Tqa3oYPeErtZhxjc1ROFKaMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBgxFjAUBgNVBAMTDWlkcC5uYmkuYWMudWswHhcNMTMwNzA5MTY0MDUwWhcN\n\t\t\t\t\t\tMzMwNzA5MTY0MDUwWjAYMRYwFAYDVQQDEw1pZHAubmJpLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApHOt3m/M81BDIw0lEc0SUUyTASbRsYEw\n\t\t\t\t\t\tNd7h6F1zL/kdr5b8pZswPinFm5nVQQ5CI9MdtrTs5ACPjqdbqFUPAMrkLq9A4qsI\n\t\t\t\t\t\tY6eWkQwiR8t5plmfAxw+WvEkJ89gE9FZ6MSIXDlg1NxWzn9En47tl0T7Q3CeWNde\n\t\t\t\t\t\tsjnQZN81AC0SLo/wcnxzE8dHftLIqPR1LLuAfuTc3w5GLZS/RZgDTrlhzrXFieho\n\t\t\t\t\t\tA2WHWfdPa6+RrxHyfWeqXn8ZE04ILIZu78h/BfkKmzLfRqV3ED7nWUujnOSb20Vr\n\t\t\t\t\t\tPiB0BaHb4iOglArkx4RsybZ/NyADpjNLXtjIWOllruxyznQqLGs3fwIDAQABo2Ew\n\t\t\t\t\t\tXzA+BgNVHREENzA1gg1pZHAubmJpLmFjLnVrhiRodHRwczovL2lkcC5uYmkuYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFOpCrmGHgYRnUdKyrHB0VPmKFpbs\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQAmcCqvZSGO2hUl5gxzXKaihOeHJCNe9KuC6Dnu\n\t\t\t\t\t\tcj/ujX//256AnC4TBzrmUgl3RULQE8zs6XGvW9UXEk/3wcKuIJFAt/L2/tS2vhj3\n\t\t\t\t\t\tx9Dpw3jtm7u2Npl1DUsy73PmlGcJDYepgyZdScl64KuZbfcqJeXEZsWiki2gNZc/\n\t\t\t\t\t\t44CQn7q7xAfpvyxmW+4MJ+YKAXCauhtR9A0XaSqDek59GREsFR49ELza8bfgNbP6\n\t\t\t\t\t\tp39TmmBquj3bNJibKeCeQIM3YEwP38H74axMyVSrKyLhAI3atsZdBvpwjJ2bwbMU\n\t\t\t\t\t\tvJg9GInLqz3AeBmDXF1Kze/Tqpmcsegii41FP5UoBUSMNhZV"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nbi.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.nbi.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nbi.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.nbi.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.nbi.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nbi.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.nbi.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.nbi.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.nbi.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.nbi.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.nbi.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.nbi.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "nbi.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIDCCAgigAwIBAgIVAP8HG8Tqa3oYPeErtZhxjc1ROFKaMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBgxFjAUBgNVBAMTDWlkcC5uYmkuYWMudWswHhcNMTMwNzA5MTY0MDUwWhcN\n\t\t\t\t\t\tMzMwNzA5MTY0MDUwWjAYMRYwFAYDVQQDEw1pZHAubmJpLmFjLnVrMIIBIjANBgkq\n\t\t\t\t\t\thkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApHOt3m/M81BDIw0lEc0SUUyTASbRsYEw\n\t\t\t\t\t\tNd7h6F1zL/kdr5b8pZswPinFm5nVQQ5CI9MdtrTs5ACPjqdbqFUPAMrkLq9A4qsI\n\t\t\t\t\t\tY6eWkQwiR8t5plmfAxw+WvEkJ89gE9FZ6MSIXDlg1NxWzn9En47tl0T7Q3CeWNde\n\t\t\t\t\t\tsjnQZN81AC0SLo/wcnxzE8dHftLIqPR1LLuAfuTc3w5GLZS/RZgDTrlhzrXFieho\n\t\t\t\t\t\tA2WHWfdPa6+RrxHyfWeqXn8ZE04ILIZu78h/BfkKmzLfRqV3ED7nWUujnOSb20Vr\n\t\t\t\t\t\tPiB0BaHb4iOglArkx4RsybZ/NyADpjNLXtjIWOllruxyznQqLGs3fwIDAQABo2Ew\n\t\t\t\t\t\tXzA+BgNVHREENzA1gg1pZHAubmJpLmFjLnVrhiRodHRwczovL2lkcC5uYmkuYWMu\n\t\t\t\t\t\tdWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFOpCrmGHgYRnUdKyrHB0VPmKFpbs\n\t\t\t\t\t\tMA0GCSqGSIb3DQEBBQUAA4IBAQAmcCqvZSGO2hUl5gxzXKaihOeHJCNe9KuC6Dnu\n\t\t\t\t\t\tcj/ujX//256AnC4TBzrmUgl3RULQE8zs6XGvW9UXEk/3wcKuIJFAt/L2/tS2vhj3\n\t\t\t\t\t\tx9Dpw3jtm7u2Npl1DUsy73PmlGcJDYepgyZdScl64KuZbfcqJeXEZsWiki2gNZc/\n\t\t\t\t\t\t44CQn7q7xAfpvyxmW+4MJ+YKAXCauhtR9A0XaSqDek59GREsFR49ELza8bfgNbP6\n\t\t\t\t\t\tp39TmmBquj3bNJibKeCeQIM3YEwP38H74axMyVSrKyLhAI3atsZdBvpwjJ2bwbMU\n\t\t\t\t\t\tvJg9GInLqz3AeBmDXF1Kze/Tqpmcsegii41FP5UoBUSMNhZV"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Norwich Bioscience Institutes"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nbi.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NBI Partnership Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shib2idp-2.rgu.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Milne"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:r.milne@rgu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Cunningham"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:m.cunningham@rgu.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Michael"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shib2idp-2.rgu.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-02-27T13:00:57Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEozCCA4ugAwIBAgIRAKWfpZdh7g9wz9mxzKXmeEMwDQYJKoZIhvcNAQELBQAw\n\t\t\t\t\t\tZDELMAkGA1UEBhMCTkwxFjAUBgNVBAgTDU5vb3JkLUhvbGxhbmQxEjAQBgNVBAcT\n\t\t\t\t\t\tCUFtc3RlcmRhbTEPMA0GA1UEChMGVEVSRU5BMRgwFgYDVQQDEw9URVJFTkEgU1NM\n\t\t\t\t\t\tIENBIDIwHhcNMTUwMjE4MDAwMDAwWhcNMTgwMjE3MjM1OTU5WjBCMSEwHwYDVQQL\n\t\t\t\t\t\tExhEb21haW4gQ29udHJvbCBWYWxpZGF0ZWQxHTAbBgNVBAMTFHNoaWIyaWRwLTIu\n\t\t\t\t\t\tcmd1LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0f5wqUju\n\t\t\t\t\t\taXytpxhUvEINWnjJknOJlQCjE5I3b6zLtA19wEjJwPaxfynT6RNyZ6SFB+YLhmY1\n\t\t\t\t\t\t/jwMQtInvaCvyNwlT12/dgllyCroi8pcHzNk2qIr4oeKuV3Ey+Gu4f6Q3O7r2jIA\n\t\t\t\t\t\t/ZLasZYEBssdZXibwiIzGMIptXgNpA32G0hZkf4CXOfyXf21YxWaEQUAmNF/kZzx\n\t\t\t\t\t\tnI/syf/lT3WofFf1Z44xpxY3hvqurxwp+y+pFp3ulJ52NL11BYcpxyucKSNqLvvf\n\t\t\t\t\t\taCFLPbhRPXC1l4ZZaNcYt37YRTb7uFzDn/DBZC/WvDaRugpxwAKcNtvlhtyHiXm4\n\t\t\t\t\t\tidSf1CbxT2C8IQIDAQABo4IBcDCCAWwwHwYDVR0jBBgwFoAUW9CKHJoyW+C13ZZU\n\t\t\t\t\t\tG+GGKLD9tr0wHQYDVR0OBBYEFIm+C+W8KETQHZjRFK0SNZLp4bTlMA4GA1UdDwEB\n\t\t\t\t\t\t/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEF\n\t\t\t\t\t\tBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8E\n\t\t\t\t\t\tMzAxMC+gLaArhilodHRwOi8vY3JsLnVzZXJ0cnVzdC5jb20vVEVSRU5BU1NMQ0Ey\n\t\t\t\t\t\tLmNybDBsBggrBgEFBQcBAQRgMF4wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudXNl\n\t\t\t\t\t\tcnRydXN0LmNvbS9URVJFTkFTU0xDQTIuY3J0MCUGCCsGAQUFBzABhhlodHRwOi8v\n\t\t\t\t\t\tb2NzcC51c2VydHJ1c3QuY29tMB8GA1UdEQQYMBaCFHNoaWIyaWRwLTIucmd1LmFj\n\t\t\t\t\t\tLnVrMA0GCSqGSIb3DQEBCwUAA4IBAQB58/SY7DvyV8owwALt0tzRGdeDQ/Mquplz\n\t\t\t\t\t\tUn9XXTbrFycawmt5bes3zKhCeeRaKk/ZDfM1PbKydYxJlJ+1C7KGxW6eLCNTiKCO\n\t\t\t\t\t\tyvbjvqG6DSZPq8PBf5V+Z28WTn5z5TPQlfjiqW7NJrDv8wQeDRImflWLNpW4/iu2\n\t\t\t\t\t\tUD9E6mx+MNBQB3V1ICH9GdlNtmcdBjEIdAqfYQ1XRhVezlsKreHw7U5osiJRutAX\n\t\t\t\t\t\tKTjfii2gfRVj3nY0/gfyOeGB2zuQbz+npQYHqVzALIrWbFqwvMErl+sww2vN3lcw\n\t\t\t\t\t\tQJ781d5laJnxYr9a1fWShNVgPZB2fQvl3DglKN/fnRBY6xb96bpV"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rgu.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib2idp-2.rgu.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib2idp-2.rgu.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib2idp-2.rgu.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib2idp-2.rgu.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib2idp-2.rgu.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib2idp-2.rgu.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib2idp-2.rgu.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib2idp-2.rgu.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rgu.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEozCCA4ugAwIBAgIRAKWfpZdh7g9wz9mxzKXmeEMwDQYJKoZIhvcNAQELBQAw\n\t\t\t\t\t\tZDELMAkGA1UEBhMCTkwxFjAUBgNVBAgTDU5vb3JkLUhvbGxhbmQxEjAQBgNVBAcT\n\t\t\t\t\t\tCUFtc3RlcmRhbTEPMA0GA1UEChMGVEVSRU5BMRgwFgYDVQQDEw9URVJFTkEgU1NM\n\t\t\t\t\t\tIENBIDIwHhcNMTUwMjE4MDAwMDAwWhcNMTgwMjE3MjM1OTU5WjBCMSEwHwYDVQQL\n\t\t\t\t\t\tExhEb21haW4gQ29udHJvbCBWYWxpZGF0ZWQxHTAbBgNVBAMTFHNoaWIyaWRwLTIu\n\t\t\t\t\t\tcmd1LmFjLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA0f5wqUju\n\t\t\t\t\t\taXytpxhUvEINWnjJknOJlQCjE5I3b6zLtA19wEjJwPaxfynT6RNyZ6SFB+YLhmY1\n\t\t\t\t\t\t/jwMQtInvaCvyNwlT12/dgllyCroi8pcHzNk2qIr4oeKuV3Ey+Gu4f6Q3O7r2jIA\n\t\t\t\t\t\t/ZLasZYEBssdZXibwiIzGMIptXgNpA32G0hZkf4CXOfyXf21YxWaEQUAmNF/kZzx\n\t\t\t\t\t\tnI/syf/lT3WofFf1Z44xpxY3hvqurxwp+y+pFp3ulJ52NL11BYcpxyucKSNqLvvf\n\t\t\t\t\t\taCFLPbhRPXC1l4ZZaNcYt37YRTb7uFzDn/DBZC/WvDaRugpxwAKcNtvlhtyHiXm4\n\t\t\t\t\t\tidSf1CbxT2C8IQIDAQABo4IBcDCCAWwwHwYDVR0jBBgwFoAUW9CKHJoyW+C13ZZU\n\t\t\t\t\t\tG+GGKLD9tr0wHQYDVR0OBBYEFIm+C+W8KETQHZjRFK0SNZLp4bTlMA4GA1UdDwEB\n\t\t\t\t\t\t/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEF\n\t\t\t\t\t\tBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8E\n\t\t\t\t\t\tMzAxMC+gLaArhilodHRwOi8vY3JsLnVzZXJ0cnVzdC5jb20vVEVSRU5BU1NMQ0Ey\n\t\t\t\t\t\tLmNybDBsBggrBgEFBQcBAQRgMF4wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudXNl\n\t\t\t\t\t\tcnRydXN0LmNvbS9URVJFTkFTU0xDQTIuY3J0MCUGCCsGAQUFBzABhhlodHRwOi8v\n\t\t\t\t\t\tb2NzcC51c2VydHJ1c3QuY29tMB8GA1UdEQQYMBaCFHNoaWIyaWRwLTIucmd1LmFj\n\t\t\t\t\t\tLnVrMA0GCSqGSIb3DQEBCwUAA4IBAQB58/SY7DvyV8owwALt0tzRGdeDQ/Mquplz\n\t\t\t\t\t\tUn9XXTbrFycawmt5bes3zKhCeeRaKk/ZDfM1PbKydYxJlJ+1C7KGxW6eLCNTiKCO\n\t\t\t\t\t\tyvbjvqG6DSZPq8PBf5V+Z28WTn5z5TPQlfjiqW7NJrDv8wQeDRImflWLNpW4/iu2\n\t\t\t\t\t\tUD9E6mx+MNBQB3V1ICH9GdlNtmcdBjEIdAqfYQ1XRhVezlsKreHw7U5osiJRutAX\n\t\t\t\t\t\tKTjfii2gfRVj3nY0/gfyOeGB2zuQbz+npQYHqVzALIrWbFqwvMErl+sww2vN3lcw\n\t\t\t\t\t\tQJ781d5laJnxYr9a1fWShNVgPZB2fQvl3DglKN/fnRBY6xb96bpV"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Robert Gordon University - TEST"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rgu.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "The Robert Gordon University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://uolics.sisoshibboleth.co.uk/entity",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:info@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Info"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Oates"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steve@siso.uk.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steven"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://uolics.sisoshibboleth.co.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-09-12T16:50:14Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SiSo University of Leeds ~ ICS, Online Resource Booking"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.siso.uk.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "TechEthika Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://uol.siso.co/ics/sso/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://uol.siso.co/ics/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://uol.siso.co/ics/sso/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SiSo University of Leeds ~ ICS, Online Resource Booking"
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth.siso.co/siso-logo60x60.jpg",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SiSo University of Leeds ~ ICS, Online Resource Booking"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3DCCAcSgAwIBAgIJAOSUhyDXVj7AMA0GCSqGSIb3DQEBBQUAMBIxEDAOBgNV\n\t\t\t\t\t\tBAMTB3Npc28uY28wHhcNMTMwMTA3MTYzMTIxWhcNMjMwMTA1MTYzMTIxWjASMRAw\n\t\t\t\t\t\tDgYDVQQDEwdzaXNvLmNvMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n\t\t\t\t\t\txDnj9YFJVXclawo/8rs1aWYAgk6rKi8A/Cyycq0mW5yOKLLh8MUIgDeOGL7bLl7p\n\t\t\t\t\t\tMBeZM4ILlNaeJhICWm1tuLB6SYzREnXwpO7+lvx13xsRHW2TjCPGV3yUgz55vRYj\n\t\t\t\t\t\tbseFrwFHJ8IrL24UTLcpX/R//9cMkZpSqM+77Hn22dxbYvGUOQCHOQzL78AO91qz\n\t\t\t\t\t\tdUaxKzYWyWM7w2U4APP41Zvd0flyUtRZXp8W+WwlUDffFoNndsjR4L/9wuXvOcrH\n\t\t\t\t\t\t+VZtMLy60+cB9bpvVlaQVlt+1stEABdMVvuGNkJ9wIjRjP2b9OLUI76QmgwIDtdE\n\t\t\t\t\t\t5BS0Bv0Puz66L96r2MunRQIDAQABozUwMzASBgNVHREECzAJggdzaXNvLmNvMB0G\n\t\t\t\t\t\tA1UdDgQWBBRRosxNbUQXXwtWDl/kYMScRImh5TANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tgrfjza9Btcz+9WvzcjDTZ+KSrWWvrthA3zc6Q+C/MIBG8CCuxMO+uwFBnXIopGlX\n\t\t\t\t\t\tbLa/QtVLjOugsnizFxjaEFTG4jGndtPJ8+9V8Eja5RlOazuM2LT738+Um8/1Frhr\n\t\t\t\t\t\tGXa0Hdv9ZWEbIhil65fFqZNOmOteja6xxAQ9NgGG/XUnTVTbr7msihEAYTTcS40/\n\t\t\t\t\t\tGSYpT9nQwiryfSWDNJ17Zyl44389kSw+FCUsu8Ns9VSDEDWr/R+97ZMcjN6hAfJL\n\t\t\t\t\t\tdji3X1aaAC/JbnJl/v+yR1TH/sdHyObVaM7FToUGKiyjX9VpfOe64d0hjogzEr0x\n\t\t\t\t\t\tfirJubLNu96jbGctasqcpQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://uol.siso.co/ics/sso/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://uol.siso.co/ics/sso/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://uol.siso.co/ics/sso/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://uol.siso.co/ics/sso/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://uol.siso.co/ics/sso/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://uol.siso.co/ics/sso/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:incommon:clemson.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "hbj@clemson.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Barry Johnson"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "hbj@clemson.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Barry Johnson"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kewrig@clemson.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Kathy E. Wright"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "SHIBBOLETHOPS@lists.clemson.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "CCIT Web Authentication"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:clemson.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.clemson.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.clemson.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMjCCAhqgAwIBAgIJAIWTbV26VuPeMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2lkcC5jbGVtc29uLmVkdTAeFw0xNDAxMjIxOTI0NTBaFw0yNDAxMjAxOTI0\nNTBaMBoxGDAWBgNVBAMTD2lkcC5jbGVtc29uLmVkdTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAKh970CMYkhnBWn4flEVBZxZyx6OjF9Y5TzcsAQPEqb+\nJ8e0f8+eoi/SjCH62J3wkycb637xVGcpOe8gxheqb/yAoO/1XkQcQqGGDFwe5i2C\nacfNy2GzEjXoTuwPZv1rBMeeTJ5GWeuO7kP0xJMUz6EwgnEPky/KO4jTLmQElD0O\nnr2LUe3r6RNh/iQdVuR7OU6aNIGoRB0TDoth7Gvb11Y/ztkVss9Be/9B7ILKVrF5\nEQqt6rXb1Uam0wNcFRt1UWnzwvWqTOD3ndsIP3/okWpKezk90gJmQ31jIUqPUWAB\n3Jq8rASoKBtm4v6m8/PVxqaiDVUP3pMoDn/kuC2tdgECAwEAAaN7MHkwHQYDVR0O\nBBYEFGRIag6EZ77qa33zp5/pHiGTYl15MEoGA1UdIwRDMEGAFGRIag6EZ77qa33z\np5/pHiGTYl15oR6kHDAaMRgwFgYDVQQDEw9pZHAuY2xlbXNvbi5lZHWCCQCFk21d\nulbj3jAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQB/PeqBB+qaogdv\n7IqcXrz7mgftKI8mUFae76rzVGnIPIYMyManRceCRfVnvPFrNKOjoUuqQRg3dQsE\nSzUMzFWD4IHcbUP1xI+o8o1FtyM6KYMQE1DIV0GbsZ5FAlGEhWjrYGhJ/SqIeakg\nMiLtXO/Y+b8Ys4mAtdJS3Bx/qM+hfYWc8oJMaJZeHcEzqC/MaBxvkxz5VTkq9hN4\nEGUdMHmqx12yrMmweKwJ2thh2DOEebiJeJ8DBvj44kmSGMoEWw7HCC3wQOUsTrjv\nKmFS8uC55wmP9wsWXa8g5S7eim10poro2UW5dSOGYhET3GVG7rywL//9eP9bH6nG\ngf9X1kGw"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMjCCAhqgAwIBAgIJAPsDZoExwhElMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2lkcC5jbGVtc29uLmVkdTAeFw0xMTAxMjQxOTMyMzdaFw0xNDAxMjMxOTMy\nMzdaMBoxGDAWBgNVBAMTD2lkcC5jbGVtc29uLmVkdTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAK5YIc776NBPnEjgRsVCNaQxK4Ea8sTBbD6f3v9bGnaH\nio+9fA1h89k7ojvX7csWUtGBL304AM7Kx0rMgCgi+OFF6e45mqAkwhqHSfCwmGvu\nF9rj79DS13WqKWZDMfU3+CotMgUzbFRKO5ouVPv0WaF8qbtZlOZztjJj5997oLXp\nTxCY4t3+nQyT6saGMmuL8o6nP08j98Bk+yfZmuJXa+Yhgwpmvi1GBCM17Kc8+1fW\nHZO1yUtDPjwPgB5lzhvur8eNSjAnWexSW8qxfZq+Nnz7gEXw9pTk2fIAEu7Jz6YC\nwUeaq7XHnYDqZPnZoQPF1R23tA6WtBDIUP3CIplBAZsCAwEAAaN7MHkwHQYDVR0O\nBBYEFE7t7i1ZDwXlPDO370w3RhyPPY28MEoGA1UdIwRDMEGAFE7t7i1ZDwXlPDO3\n70w3RhyPPY28oR6kHDAaMRgwFgYDVQQDEw9pZHAuY2xlbXNvbi5lZHWCCQD7A2aB\nMcIRJTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCtkW8qB2pVFIX0\nDCmp833kDMP9ySpN5MnM1camlHRCm9YfAPZVYrP5DL/FJDnWbNW4svhkW0jyzdrU\nDFrh29mZCRFNse9VuOs8f3isBavcnaPdriHBo88ciTuAEV93BgT/+Q14xPx1phXH\n1eSLXJewMPoq1zWOv93U/8IKbtcGL9lrXGHtnurCcd4EeMHGoc7jZpvZ101daDTx\nNNUqqKY9PkPijGeGztwogiwosxr6SCiwsQWc2OzcGslAVPCFkpQTlIlYN1xm19R/\ncRa+GNX9yfCwaDszTvIkvAfks4q+/J8F5Pu/OiWT1CQTL//bvVf0c38c9SLY9uVI\nW9jOpMFc"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "clemson.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.clemson.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.clemson.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.clemson.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.clemson.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.clemson.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.clemson.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "clemson.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.clemson.edu/ccit/help_support/safe_computing/resources/best_practices.html"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Clemson University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Identity Provider for Clemson University"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.clemson.edu/administration/public-affairs/toolbox/downloads/logos/logos/wordmark.png",
                    "lang": "en",
                    "height": "130",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "449"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.clemson.edu/ccit/about/policies/index.html"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMjCCAhqgAwIBAgIJAIWTbV26VuPeMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2lkcC5jbGVtc29uLmVkdTAeFw0xNDAxMjIxOTI0NTBaFw0yNDAxMjAxOTI0\nNTBaMBoxGDAWBgNVBAMTD2lkcC5jbGVtc29uLmVkdTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAKh970CMYkhnBWn4flEVBZxZyx6OjF9Y5TzcsAQPEqb+\nJ8e0f8+eoi/SjCH62J3wkycb637xVGcpOe8gxheqb/yAoO/1XkQcQqGGDFwe5i2C\nacfNy2GzEjXoTuwPZv1rBMeeTJ5GWeuO7kP0xJMUz6EwgnEPky/KO4jTLmQElD0O\nnr2LUe3r6RNh/iQdVuR7OU6aNIGoRB0TDoth7Gvb11Y/ztkVss9Be/9B7ILKVrF5\nEQqt6rXb1Uam0wNcFRt1UWnzwvWqTOD3ndsIP3/okWpKezk90gJmQ31jIUqPUWAB\n3Jq8rASoKBtm4v6m8/PVxqaiDVUP3pMoDn/kuC2tdgECAwEAAaN7MHkwHQYDVR0O\nBBYEFGRIag6EZ77qa33zp5/pHiGTYl15MEoGA1UdIwRDMEGAFGRIag6EZ77qa33z\np5/pHiGTYl15oR6kHDAaMRgwFgYDVQQDEw9pZHAuY2xlbXNvbi5lZHWCCQCFk21d\nulbj3jAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQB/PeqBB+qaogdv\n7IqcXrz7mgftKI8mUFae76rzVGnIPIYMyManRceCRfVnvPFrNKOjoUuqQRg3dQsE\nSzUMzFWD4IHcbUP1xI+o8o1FtyM6KYMQE1DIV0GbsZ5FAlGEhWjrYGhJ/SqIeakg\nMiLtXO/Y+b8Ys4mAtdJS3Bx/qM+hfYWc8oJMaJZeHcEzqC/MaBxvkxz5VTkq9hN4\nEGUdMHmqx12yrMmweKwJ2thh2DOEebiJeJ8DBvj44kmSGMoEWw7HCC3wQOUsTrjv\nKmFS8uC55wmP9wsWXa8g5S7eim10poro2UW5dSOGYhET3GVG7rywL//9eP9bH6nG\ngf9X1kGw"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMjCCAhqgAwIBAgIJAPsDZoExwhElMA0GCSqGSIb3DQEBBQUAMBoxGDAWBgNV\nBAMTD2lkcC5jbGVtc29uLmVkdTAeFw0xMTAxMjQxOTMyMzdaFw0xNDAxMjMxOTMy\nMzdaMBoxGDAWBgNVBAMTD2lkcC5jbGVtc29uLmVkdTCCASIwDQYJKoZIhvcNAQEB\nBQADggEPADCCAQoCggEBAK5YIc776NBPnEjgRsVCNaQxK4Ea8sTBbD6f3v9bGnaH\nio+9fA1h89k7ojvX7csWUtGBL304AM7Kx0rMgCgi+OFF6e45mqAkwhqHSfCwmGvu\nF9rj79DS13WqKWZDMfU3+CotMgUzbFRKO5ouVPv0WaF8qbtZlOZztjJj5997oLXp\nTxCY4t3+nQyT6saGMmuL8o6nP08j98Bk+yfZmuJXa+Yhgwpmvi1GBCM17Kc8+1fW\nHZO1yUtDPjwPgB5lzhvur8eNSjAnWexSW8qxfZq+Nnz7gEXw9pTk2fIAEu7Jz6YC\nwUeaq7XHnYDqZPnZoQPF1R23tA6WtBDIUP3CIplBAZsCAwEAAaN7MHkwHQYDVR0O\nBBYEFE7t7i1ZDwXlPDO370w3RhyPPY28MEoGA1UdIwRDMEGAFE7t7i1ZDwXlPDO3\n70w3RhyPPY28oR6kHDAaMRgwFgYDVQQDEw9pZHAuY2xlbXNvbi5lZHWCCQD7A2aB\nMcIRJTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCtkW8qB2pVFIX0\nDCmp833kDMP9ySpN5MnM1camlHRCm9YfAPZVYrP5DL/FJDnWbNW4svhkW0jyzdrU\nDFrh29mZCRFNse9VuOs8f3isBavcnaPdriHBo88ciTuAEV93BgT/+Q14xPx1phXH\n1eSLXJewMPoq1zWOv93U/8IKbtcGL9lrXGHtnurCcd4EeMHGoc7jZpvZ101daDTx\nNNUqqKY9PkPijGeGztwogiwosxr6SCiwsQWc2OzcGslAVPCFkpQTlIlYN1xm19R/\ncRa+GNX9yfCwaDszTvIkvAfks4q+/J8F5Pu/OiWT1CQTL//bvVf0c38c9SLY9uVI\nW9jOpMFc"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Clemson University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.clemson.edu"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Clemson University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.antagning.se/aws-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/policy/assurance/al2"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://www.swamid.se/assurance-requirement",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.antagning.se/aws-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.antagning.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.antagning.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.antagning.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.antagning.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.antagning.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.antagning.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Antagning.se \u00e4r sajten f\u00f6r anm\u00e4lan till universitet och h\u00f6gskolor."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Apply online to Swedish universities and university colleges."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.antagning.se/images/logo/antagning_se.png",
                    "lang": "sv",
                    "height": "52",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "195"
                  },
                  {
                    "text": "https://www.universityadmissions.se/images/logo/university-admisssions.png",
                    "lang": "en",
                    "height": "52",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "205"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Antagning.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universityadmissions.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.antagning.se/aws-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.antagning.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIJAM1gMiTqlkCLMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEHd3dy5hbnRhZ25pbmcuc2UwHhcNMTEwNTA5MTY1NTA0WhcNMjEwNTA2MTY1\nNTA0WjAbMRkwFwYDVQQDExB3d3cuYW50YWduaW5nLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA9M2iGNZWzqCU6FfPBz8z1LdBRKk9BLLc3aL1VRC9\n2VCL5vnGa/+kWRiWOa6liVbyPrVHbfTCfdj/V9P46dmdB34kzhgRNryc9I5Hmz+c\njMLQ+tjWOO9b1vRota5HeCsxD/qZS55qbFAaj0PaU65Twv+u9vIkB576tRypJOXY\nS+fJC89+F/0QR/DfhgfMh6lvSxMP+OXrUVra6926sHA7iZuSn7e3hCaIY3VEiYq6\nt1X9ROUoorUcUDk/kwI0eDkxz03/wP2z9SUT+qfHJ8cVLeB5JC1aHok0ScZS9ym5\nU9BAmKwOnOz+H9izisIDf1aOWwFptP4g1kgjNtZBt01McwIDAQABo18wXTA8BgNV\nHREENTAzghB3d3cuYW50YWduaW5nLnNlhh9odHRwczovL3d3dy5hbnRhZ25pbmcu\nc2UvYXdzLXNwMB0GA1UdDgQWBBQp9cf++1Fp9XL3b+XKAYdH8DhZmzANBgkqhkiG\n9w0BAQUFAAOCAQEAP/xtFa8pJk6ZZ+YHPY8wur100MlTZqcL0YFHXtp2xilQWKBs\nFhF4QdJd4GdZ79E1ihhk7mUg73nEt73AQPs6yoYxK0f6YYXHW1Y+tp4vwPQRHXmq\na0CyLppiBHmtjCNNE3fmDkg83drN3mb9htuqrXwwOAzjXTxAPvKR0G+qI8uAfXNi\nevaeM5M/9fH2lLQux6LaO7Y8lUKwS3R7ACy5a/2iHvmqf6AhcxS/BTFZX9fuATMQ\nRdmf3Z9lxeoKDHMXqmZEiaxZmTp0YVHrc7NbPrbQ78KXqabsq7A6cqq/bhSgJCsf\nwo1Z+XF5sAEJ3w30UnCsgh0Muvwlyb3cnRvYFA=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.antagning.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.antagning.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.antagning.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.antagning.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.antagning.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.antagning.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.antagning.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.antagning.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.antagning.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.antagning.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.antagning.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:incommon:humboldt.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mark.hendricks@humboldt.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark Hendricks"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "peter.johnson@humboldt.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Peter Johnson"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "sysadmin@humboldt.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Systems Group"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "josh.callahan@humboldt.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Josh Callahan"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "troy.butolph@humboldt.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Troy Butolph"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:humboldt.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.humboldt.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.humboldt.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFkTCCBHmgAwIBAgICAiUwDQYJKoZIhvcNAQEFBQAwVjELMAkGA1UEBhMCVVMx\nHDAaBgNVBAoTE0luQ29tbW9uIEZlZGVyYXRpb24xKTAnBgNVBAMTIEluQ29tbW9u\nIENlcnRpZmljYXRpb24gQXV0aG9yaXR5MB4XDTA5MDUyOTE4NDY0OFoXDTExMDUz\nMDE4NDY0OFowGzEZMBcGA1UEAxMQaWRwLmh1bWJvbGR0LmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAIobfOptbMRmZfxAr5j5iDpNzctKRRn+f105\nqejIvk2diU5AYo5pDNcbEBEixdV0ikWwqHh2PH2D2FvpQDikQU7CPcLHCcuSbviy\npIyJIuGM1cfnirzFSkCjhgKqIjgTEKkCJzZgNKFqikWnEGf3ptn27z3H0GRZCC+B\n5ahmBJSO17iBuyQ71Qp+3pH2Pq0ffoOpRuTutfQUpsM2Qw1t5AG7j1F/fvw3vzrc\nHxwlWpyuDtcOlSiCezrcIJdx7ejK+G0aoqihe8HuHrD2Wg7vmRFsC/N9/S+7A+sV\n+uAaxI1JSt0M+twXDiMuPvcdlh82kiEB56njXsDcJm5UrskYR5ECAwEAAaOCAqIw\nggKeMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsG\nAQUFBwMBBggrBgEFBQcDAjAdBgNVHQ4EFgQUKdif1++SY7RXkOHiEkduH4q/e/Yw\nfgYDVR0jBHcwdYAUky3IYRitY+ObZbOd3Y2TuufKY0WhWqRYMFYxCzAJBgNVBAYT\nAlVTMRwwGgYDVQQKExNJbkNvbW1vbiBGZWRlcmF0aW9uMSkwJwYDVQQDEyBJbkNv\nbW1vbiBDZXJ0aWZpY2F0aW9uIEF1dGhvcml0eYIBADCBsgYIKwYBBQUHAQEEgaUw\ngaIwTwYIKwYBBQUHMAKGQ2h0dHA6Ly9pbmNvbW1vbmNhMS5pbmNvbW1vbmZlZGVy\nYXRpb24ub3JnL2JyaWRnZS9jZXJ0cy9jYS1jZXJ0cy5wN2IwTwYIKwYBBQUHMAKG\nQ2h0dHA6Ly9pbmNvbW1vbmNhMi5pbmNvbW1vbmZlZGVyYXRpb24ub3JnL2JyaWRn\nZS9jZXJ0cy9jYS1jZXJ0cy5wN2IwgY0GA1UdHwSBhTCBgjA/oD2gO4Y5aHR0cDov\nL2luY29tbW9uY3JsMS5pbmNvbW1vbmZlZGVyYXRpb24ub3JnL2NybC9lZWNybHMu\nY3JsMD+gPaA7hjlodHRwOi8vaW5jb21tb25jcmwyLmluY29tbW9uZmVkZXJhdGlv\nbi5vcmcvY3JsL2VlY3Jscy5jcmwwXgYDVR0gBFcwVTBTBgsrBgEEAa4jAQQBATBE\nMEIGCCsGAQUFBwIBFjZodHRwOi8vaW5jb21tb25jYS5pbmNvbW1vbmZlZGVyYXRp\nb24ub3JnL3ByYWN0aWNlcy5wZGYwGwYDVR0RBBQwEoIQaWRwLmh1bWJvbGR0LmVk\ndTANBgkqhkiG9w0BAQUFAAOCAQEAOcwPpeqe61hu63uwC9PVYZNOyxzc2f2h0ii/\nSNLOlbbolZfxMKbuxLXcYCpy1IXxlzBx4hieTRYTksHehIHcDK2dM52F1AMumRo3\nEMSh1TTRn9Z6xK9ACypa3Ah42+qdvCXDT3je/DCQK4gkTlXd9KE2hv06IemHD9V+\nEo7yhlY9Nd2oOVWCLV6+hNqrR56gio6b0SWf97B1LAlkPTW0iLaldmLui1dW6EV0\n8pWQYq0T+m/F/Hzj730ntKD9AYN+VBCYxIPKXNPqBsKkBqNO8622mYNPcS5rbfUj\nMA1WuRhoHwRbAV7L/wak8BuONBWFl1zr3+/hOj3F1/Xpeomhag=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDyjCCArICCQDSIlwe73ERBTANBgkqhkiG9w0BAQUFADCBpjELMAkGA1UEBhMC\nVVMxEzARBgNVBAgTCkNhbGlmb3JuaWExDzANBgNVBAcTBkFyY2F0YTEiMCAGA1UE\nChMZSHVtYm9sZHQgU3RhdGUgVW5pdmVyc2l0eTEMMAoGA1UECxMDSVRTMRkwFwYD\nVQQDExBpZHAuaHVtYm9sZHQuZWR1MSQwIgYJKoZIhvcNAQkBFhVzeXNhZG1pbkBo\ndW1ib2xkdC5lZHUwHhcNMTEwNTEwMjIzNzA2WhcNMjEwNTA3MjIzNzA2WjCBpjEL\nMAkGA1UEBhMCVVMxEzARBgNVBAgTCkNhbGlmb3JuaWExDzANBgNVBAcTBkFyY2F0\nYTEiMCAGA1UEChMZSHVtYm9sZHQgU3RhdGUgVW5pdmVyc2l0eTEMMAoGA1UECxMD\nSVRTMRkwFwYDVQQDExBpZHAuaHVtYm9sZHQuZWR1MSQwIgYJKoZIhvcNAQkBFhVz\neXNhZG1pbkBodW1ib2xkdC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQDXea3ZM6XJ8f2CRd6bisEol8JsGCwXPwPYLWqbiSF7rBcrxztVRbUofTXe\n5/f3+KR4w4cpvqm2OGun9xpa357mzgW2aMc/AIE6fPErHDSI20K1P3DUIIHIbxOz\nZb12oaeMDUgqI0PQso32oRCT0hQ9dFegPQ6ICegk5e57Azctpn7ovdkNYurfRVx1\nsQoS0STHPW8b5xNSv6IGoEOjkVUpzKtv9VO+5KIesq/9y5r9nPXISSzHUei/7iAa\n7G3MpNgWHcdYjfE+ZTgtUu2Mb60OKq9oxhwzRF8RrG+R4/+0xkcCJX5Vk3hHrUMs\n9XTdGGo98dm5lwBfS2FFVByNKqRXAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAHNX\n1zbqSKjgwJa8Bt0Kx7bNBm9ukHfERqfrT1I4c+O0OshH0N0PVLF+m2/eH8NrNz52\nFOfgNBtJrFu9BxI8tc0yp1ptjYVgeCaFrIurNPKShMQSqJRg/BSYYykm26wrPmUs\nZVagnI+OIJPWNpqDt56xRgzpDrLKf7zHLSLyEmrfK8f2R+DExzGWUGN5StA1G+tg\nJfaZDtwYHOUR9XrHbx+czHTqGcEo1Jpfg8p/KiuacKMb8n99HG9p2bUggLQOangC\nKU/1My9HTkHF8T8QLLSlqA4jb0eXnz9lxfJl2i2Y+imP77X7sWoPoL32jcoAWYoZ\nAR85Z5Jw0RxR+tbYexg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "humboldt.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.humboldt.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.humboldt.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.humboldt.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.humboldt.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.humboldt.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "humboldt.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Humboldt State University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFkTCCBHmgAwIBAgICAiUwDQYJKoZIhvcNAQEFBQAwVjELMAkGA1UEBhMCVVMx\nHDAaBgNVBAoTE0luQ29tbW9uIEZlZGVyYXRpb24xKTAnBgNVBAMTIEluQ29tbW9u\nIENlcnRpZmljYXRpb24gQXV0aG9yaXR5MB4XDTA5MDUyOTE4NDY0OFoXDTExMDUz\nMDE4NDY0OFowGzEZMBcGA1UEAxMQaWRwLmh1bWJvbGR0LmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBAIobfOptbMRmZfxAr5j5iDpNzctKRRn+f105\nqejIvk2diU5AYo5pDNcbEBEixdV0ikWwqHh2PH2D2FvpQDikQU7CPcLHCcuSbviy\npIyJIuGM1cfnirzFSkCjhgKqIjgTEKkCJzZgNKFqikWnEGf3ptn27z3H0GRZCC+B\n5ahmBJSO17iBuyQ71Qp+3pH2Pq0ffoOpRuTutfQUpsM2Qw1t5AG7j1F/fvw3vzrc\nHxwlWpyuDtcOlSiCezrcIJdx7ejK+G0aoqihe8HuHrD2Wg7vmRFsC/N9/S+7A+sV\n+uAaxI1JSt0M+twXDiMuPvcdlh82kiEB56njXsDcJm5UrskYR5ECAwEAAaOCAqIw\nggKeMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsG\nAQUFBwMBBggrBgEFBQcDAjAdBgNVHQ4EFgQUKdif1++SY7RXkOHiEkduH4q/e/Yw\nfgYDVR0jBHcwdYAUky3IYRitY+ObZbOd3Y2TuufKY0WhWqRYMFYxCzAJBgNVBAYT\nAlVTMRwwGgYDVQQKExNJbkNvbW1vbiBGZWRlcmF0aW9uMSkwJwYDVQQDEyBJbkNv\nbW1vbiBDZXJ0aWZpY2F0aW9uIEF1dGhvcml0eYIBADCBsgYIKwYBBQUHAQEEgaUw\ngaIwTwYIKwYBBQUHMAKGQ2h0dHA6Ly9pbmNvbW1vbmNhMS5pbmNvbW1vbmZlZGVy\nYXRpb24ub3JnL2JyaWRnZS9jZXJ0cy9jYS1jZXJ0cy5wN2IwTwYIKwYBBQUHMAKG\nQ2h0dHA6Ly9pbmNvbW1vbmNhMi5pbmNvbW1vbmZlZGVyYXRpb24ub3JnL2JyaWRn\nZS9jZXJ0cy9jYS1jZXJ0cy5wN2IwgY0GA1UdHwSBhTCBgjA/oD2gO4Y5aHR0cDov\nL2luY29tbW9uY3JsMS5pbmNvbW1vbmZlZGVyYXRpb24ub3JnL2NybC9lZWNybHMu\nY3JsMD+gPaA7hjlodHRwOi8vaW5jb21tb25jcmwyLmluY29tbW9uZmVkZXJhdGlv\nbi5vcmcvY3JsL2VlY3Jscy5jcmwwXgYDVR0gBFcwVTBTBgsrBgEEAa4jAQQBATBE\nMEIGCCsGAQUFBwIBFjZodHRwOi8vaW5jb21tb25jYS5pbmNvbW1vbmZlZGVyYXRp\nb24ub3JnL3ByYWN0aWNlcy5wZGYwGwYDVR0RBBQwEoIQaWRwLmh1bWJvbGR0LmVk\ndTANBgkqhkiG9w0BAQUFAAOCAQEAOcwPpeqe61hu63uwC9PVYZNOyxzc2f2h0ii/\nSNLOlbbolZfxMKbuxLXcYCpy1IXxlzBx4hieTRYTksHehIHcDK2dM52F1AMumRo3\nEMSh1TTRn9Z6xK9ACypa3Ah42+qdvCXDT3je/DCQK4gkTlXd9KE2hv06IemHD9V+\nEo7yhlY9Nd2oOVWCLV6+hNqrR56gio6b0SWf97B1LAlkPTW0iLaldmLui1dW6EV0\n8pWQYq0T+m/F/Hzj730ntKD9AYN+VBCYxIPKXNPqBsKkBqNO8622mYNPcS5rbfUj\nMA1WuRhoHwRbAV7L/wak8BuONBWFl1zr3+/hOj3F1/Xpeomhag=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDyjCCArICCQDSIlwe73ERBTANBgkqhkiG9w0BAQUFADCBpjELMAkGA1UEBhMC\nVVMxEzARBgNVBAgTCkNhbGlmb3JuaWExDzANBgNVBAcTBkFyY2F0YTEiMCAGA1UE\nChMZSHVtYm9sZHQgU3RhdGUgVW5pdmVyc2l0eTEMMAoGA1UECxMDSVRTMRkwFwYD\nVQQDExBpZHAuaHVtYm9sZHQuZWR1MSQwIgYJKoZIhvcNAQkBFhVzeXNhZG1pbkBo\ndW1ib2xkdC5lZHUwHhcNMTEwNTEwMjIzNzA2WhcNMjEwNTA3MjIzNzA2WjCBpjEL\nMAkGA1UEBhMCVVMxEzARBgNVBAgTCkNhbGlmb3JuaWExDzANBgNVBAcTBkFyY2F0\nYTEiMCAGA1UEChMZSHVtYm9sZHQgU3RhdGUgVW5pdmVyc2l0eTEMMAoGA1UECxMD\nSVRTMRkwFwYDVQQDExBpZHAuaHVtYm9sZHQuZWR1MSQwIgYJKoZIhvcNAQkBFhVz\neXNhZG1pbkBodW1ib2xkdC5lZHUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\nAoIBAQDXea3ZM6XJ8f2CRd6bisEol8JsGCwXPwPYLWqbiSF7rBcrxztVRbUofTXe\n5/f3+KR4w4cpvqm2OGun9xpa357mzgW2aMc/AIE6fPErHDSI20K1P3DUIIHIbxOz\nZb12oaeMDUgqI0PQso32oRCT0hQ9dFegPQ6ICegk5e57Azctpn7ovdkNYurfRVx1\nsQoS0STHPW8b5xNSv6IGoEOjkVUpzKtv9VO+5KIesq/9y5r9nPXISSzHUei/7iAa\n7G3MpNgWHcdYjfE+ZTgtUu2Mb60OKq9oxhwzRF8RrG+R4/+0xkcCJX5Vk3hHrUMs\n9XTdGGo98dm5lwBfS2FFVByNKqRXAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAHNX\n1zbqSKjgwJa8Bt0Kx7bNBm9ukHfERqfrT1I4c+O0OshH0N0PVLF+m2/eH8NrNz52\nFOfgNBtJrFu9BxI8tc0yp1ptjYVgeCaFrIurNPKShMQSqJRg/BSYYykm26wrPmUs\nZVagnI+OIJPWNpqDt56xRgzpDrLKf7zHLSLyEmrfK8f2R+DExzGWUGN5StA1G+tg\nJfaZDtwYHOUR9XrHbx+czHTqGcEo1Jpfg8p/KiuacKMb8n99HG9p2bUggLQOangC\nKU/1My9HTkHF8T8QLLSlqA4jb0eXnz9lxfJl2i2Y+imP77X7sWoPoL32jcoAWYoZ\nAR85Z5Jw0RxR+tbYexg="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Humboldt State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.humboldt.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Humboldt State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://keybucket.app.nordu.net/saml2/sp/metadata",
    {
      "entity_id": "https://keybucket.app.nordu.net/saml2/sp/metadata",
      "contact_person": [
        {
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "contact_type": "technical",
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Johansson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:leifj@nordu.net"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "NORDUnet"
          },
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Leif"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUNet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://keybucket.app.nordu.net/saml2/sp/ls/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEujCCA6KgAwIBAgIQLINqZJFs8l1wYd2J2IBMTjANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEyMDIyOTAwMDAwMFoXDTE1MDIyODIzNTk1OVowgZUxCzAJBgNV\nBAYTAkRLMQowCAYDVQQREwEuMQowCAYDVQQIEwEuMQswCQYDVQQHEwIuLjEZMBcG\nA1UECRMQREsgMjk3MCBIb3JzaG9sbTEVMBMGA1UECRMMQWdlcm4gQWxsZSAzMRUw\nEwYDVQQKEwxOT1JEVW5ldCBBL1MxGDAWBgNVBAMUDyouYXBwLm5vcmR1Lm5ldDCC\nASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJkBbj0ZJsjuirO6tN9rbRhE\n5PfQKfjrwMf5lp1a05DHlJcxsv2JZGPszkOA260D8gouWfjk3DJQIIJJgELfn5yP\nL4zwKArBDpsttTXW+DFmhfECbkemWV571ErDHMVC9JUD39uLhE1bAoYFxAeJGr14\nmg/N5YdnsuSTGOfVfC+XuhA3CgylcGBIWoXHPbPlUJk3VWVeNnYjO+nLlKPjhSSq\nmRVhmVhEwREiRPgbKyMEEoFpdmSzuNWcBMtVKt4FTLa0cjx3/rIn77imztcXRDSN\nT6GwXaG5pjy+7E602epC4t5hbj6pxzrC7mpyIQXdYjKboPgaKQ+E7bv+OqJNG3sC\nAwEAAaOCAWIwggFeMB8GA1UdIwQYMBaAFAy9k2gM896ro0lrKzdXR+qQ47ntMB0G\nA1UdDgQWBBT0F6Szj83YxTlMGIIIf3I9jdTedjAOBgNVHQ8BAf8EBAMCBaAwDAYD\nVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwGAYDVR0g\nBBEwDzANBgsrBgEEAbIxAQICHTA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3Js\nLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8w\nNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NM\nQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAa\nBgNVHREEEzARgg8qLmFwcC5ub3JkdS5uZXQwDQYJKoZIhvcNAQEFBQADggEBADMQ\nbc0dPVC1SlyOxDf90hN9sDKw92YdVtsUNFfs9MYivZK7KI5+qEQStpAvXkrBUNfd\ngM9wqL9ea9BDDmBcn5lYyjPBgGJBeLLkcyBbZ56JbcBAxIncKKFw6r5M3j7tMcth\nf06K4cm7ngUg80ZEYK00ioAyFle56qPfZ5UM25QFzV38DGvusLl5H1bTtpz1ijh7\nkO/ehJVo4K64KVCbjOr1bavp665TtcIQX2qoPsnTZY30gQ/X/K2UJQSUE5Qc+o19\nBkvvVT5jNYdeLZHXbC6X4kXYNhFKZaz9nURgfaFQIeIEu/zmsIM8tcwLjZyF1veH\nwXXiBDXS3PNHXQnnpys="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://keybucket.app.nordu.net/saml2/sp/acs/",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "The KeyBucket"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.sgi.cefetmg.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Clever de O. Junior"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "clever@dri.cefetmg.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.sgi.cefetmg.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDzjCCArYCAQAwDQYJKoZIhvcNAQEFBQAwgawxETAPBgNVBAoTCENFRkVULU1H\nMQ4wDAYDVQQLEwVESVRJQzEhMB8GCSqGSIb3DQEJARYSZHJpQGRyaS5jZWZldG1n\nLmJyMRcwFQYDVQQHEw5CZWxvIEhvcml6b250ZTEVMBMGA1UECBMMTWluYXMgR2Vy\nYWlzMQswCQYDVQQGEwJCUjEnMCUGA1UEAxMedm0taWRwLTAxLmRpdGljLnNnaS5j\nZWZldG1nLmJyMB4XDTE0MDMyNTIzNDk0N1oXDTE3MDMyNDIzNDk0N1owgawxETAP\nBgNVBAoTCENFRkVULU1HMQ4wDAYDVQQLEwVESVRJQzEhMB8GCSqGSIb3DQEJARYS\nZHJpQGRyaS5jZWZldG1nLmJyMRcwFQYDVQQHEw5CZWxvIEhvcml6b250ZTEVMBMG\nA1UECBMMTWluYXMgR2VyYWlzMQswCQYDVQQGEwJCUjEnMCUGA1UEAxMedm0taWRw\nLTAxLmRpdGljLnNnaS5jZWZldG1nLmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEAtjvu8RATCClfOz5ybFBuDzvJsg8O5duGMG19Iabw50a8CkDHfY9A\nfxks+v7f0pZdu+vQ65NsWtOaesFxIX6XXKnfjn/rLBtwoZ9j1EL3sbHxHJbKPydn\nalC12MEzOaaqWcSV2GmV3541oo03MiscRJtrdIrceIjUmVBw6nputht/XSwXUPHP\nj2vQncW5ora9WSwCSW2Ey4IRNxEsQ8JcW3YM8+ISuhIaRjyLzeHSBZ6OtjcD91+m\n/PKpuQL7eXwAmQ8QxzIdKoY+UnL7SEvofzvPSNTn3N2+39ZHu9Wb09o+Y/JhZwC/\nQoO8awGk11AcF4dbo5ReHHtPvQR+LwXfWwIDAQABMA0GCSqGSIb3DQEBBQUAA4IB\nAQB5IP7x25abYH9B0dJaQ6O2+EqavE+GMCjESrNTYgjboe4fPssr21EPe0Ye0O8F\nkbSVlULVwIU8jYpYSb6atr8J/eFeJCbVOeSjRSPByxLbuxgTgWuqhVEFgxeHbL6n\nhcmxB+ghnILB19VvRA2f2qGT3WVdL25D0lZW+APn0XmooTqUaxJHstr9uxgfMUmA\nYCq8RxeRlzv+nC8jsKRLX0f/MkoViUs8SqSUVwbFd/9m2aWfwm083pQCjHMxPJ6R\nAmQ7M4Sp8I/jlW+U3rinliikdU8/OtJfK5ul3VJJwDdiZSSKBTpgMK7I0ErMdGge\nygq02Y9TwNW87ZDtaYEO9eei"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cefetmg.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sgi.cefetmg.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sgi.cefetmg.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.sgi.cefetmg.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sgi.cefetmg.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.sgi.cefetmg.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sgi.cefetmg.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sgi.cefetmg.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sgi.cefetmg.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cefetmg.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.cefetmg.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.cefetmg.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CEFET-MG - Centro Federal de Educacao Tecnologica de Minas Gerais"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "CEFET-MG - Centro Federal de Educacao Tecnologica de Minas Gerais"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CEFET-MG - Centro Federal de Educacao Tecnologica de Minas Gerais"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CEFET-MG - Centro Federal de Educacao Tecnologica de Minas Gerais"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDzjCCArYCAQAwDQYJKoZIhvcNAQEFBQAwgawxETAPBgNVBAoTCENFRkVULU1H\nMQ4wDAYDVQQLEwVESVRJQzEhMB8GCSqGSIb3DQEJARYSZHJpQGRyaS5jZWZldG1n\nLmJyMRcwFQYDVQQHEw5CZWxvIEhvcml6b250ZTEVMBMGA1UECBMMTWluYXMgR2Vy\nYWlzMQswCQYDVQQGEwJCUjEnMCUGA1UEAxMedm0taWRwLTAxLmRpdGljLnNnaS5j\nZWZldG1nLmJyMB4XDTE0MDMyNTIzNDk0N1oXDTE3MDMyNDIzNDk0N1owgawxETAP\nBgNVBAoTCENFRkVULU1HMQ4wDAYDVQQLEwVESVRJQzEhMB8GCSqGSIb3DQEJARYS\nZHJpQGRyaS5jZWZldG1nLmJyMRcwFQYDVQQHEw5CZWxvIEhvcml6b250ZTEVMBMG\nA1UECBMMTWluYXMgR2VyYWlzMQswCQYDVQQGEwJCUjEnMCUGA1UEAxMedm0taWRw\nLTAxLmRpdGljLnNnaS5jZWZldG1nLmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEAtjvu8RATCClfOz5ybFBuDzvJsg8O5duGMG19Iabw50a8CkDHfY9A\nfxks+v7f0pZdu+vQ65NsWtOaesFxIX6XXKnfjn/rLBtwoZ9j1EL3sbHxHJbKPydn\nalC12MEzOaaqWcSV2GmV3541oo03MiscRJtrdIrceIjUmVBw6nputht/XSwXUPHP\nj2vQncW5ora9WSwCSW2Ey4IRNxEsQ8JcW3YM8+ISuhIaRjyLzeHSBZ6OtjcD91+m\n/PKpuQL7eXwAmQ8QxzIdKoY+UnL7SEvofzvPSNTn3N2+39ZHu9Wb09o+Y/JhZwC/\nQoO8awGk11AcF4dbo5ReHHtPvQR+LwXfWwIDAQABMA0GCSqGSIb3DQEBBQUAA4IB\nAQB5IP7x25abYH9B0dJaQ6O2+EqavE+GMCjESrNTYgjboe4fPssr21EPe0Ye0O8F\nkbSVlULVwIU8jYpYSb6atr8J/eFeJCbVOeSjRSPByxLbuxgTgWuqhVEFgxeHbL6n\nhcmxB+ghnILB19VvRA2f2qGT3WVdL25D0lZW+APn0XmooTqUaxJHstr9uxgfMUmA\nYCq8RxeRlzv+nC8jsKRLX0f/MkoViUs8SqSUVwbFd/9m2aWfwm083pQCjHMxPJ6R\nAmQ7M4Sp8I/jlW+U3rinliikdU8/OtJfK5ul3VJJwDdiZSSKBTpgMK7I0ErMdGge\nygq02Y9TwNW87ZDtaYEO9eei"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CEFET-MG - Centro Federal de Educacao Tecnologica de Minas Gerais"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CEFET-MG - Centro Federal de Educacao Tecnologica de Minas Gerais"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cefetmg.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.cefetmg.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CEFET-MG - Centro Federal de Educacao Tecnologica de Minas Gerais"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CEFET-MG - Centro Federal de Educacao Tecnologica de Minas Gerais"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://oala.leedsbeckett.ac.uk/oala",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ITServiceDesk@leedsbeckett.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "IT Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Taylor"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:d.v.taylor@leedsbeckett.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://oala.leedsbeckett.ac.uk/oala",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-11-03T09:51:22Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://oala.leedsbeckett.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://oala.leedsbeckett.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "leedsbeckett.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDXDCCAkSgAwIBAgIIY3NQ4sTPsKQwDQYJKoZIhvcNAQEFBQAwRTEhMB8GA1UE\n\t\t\t\t\t\tCgwYTGVlZHMgQmVja2V0dCBVbml2ZXJzaXR5MSAwHgYDVQQDDBdvYWxhLmxlZWRz\n\t\t\t\t\t\tYmVja2V0dC5hYy51azAeFw0xNTEwMjcxNzA1MzBaFw0yNTEwMjcxNzA1MzBaMEUx\n\t\t\t\t\t\tITAfBgNVBAoMGExlZWRzIEJlY2tldHQgVW5pdmVyc2l0eTEgMB4GA1UEAwwXb2Fs\n\t\t\t\t\t\tYS5sZWVkc2JlY2tldHQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\n\t\t\t\t\t\tAoIBAQCVFC46kUWSe1tcRlZUevYSOtQkNz9u3WMwwRE5tOtegpEQB8bVen1mLosc\n\t\t\t\t\t\tvs9xuot9/VZlK6I9dTB0zSfM4KqIyEgcjEbsvprxXAKFRR6pPNVxOofjVSfbJlHD\n\t\t\t\t\t\tPZwT2xPsm3tZNhhTxRaKmRYSSXAyg9YMHytFeR4RebgBrbbNsmLeOucvzOiyaRhQ\n\t\t\t\t\t\tf3k9yRIhWsawlgbId47GHl0AyaxBLoHISijYpVeU6AztbKFeQue4IQLpnOL5wbfR\n\t\t\t\t\t\teP365fhVoCA52A+9Ad8RBJam51LvKBEtXQwT1N1aff//qN6Xt9ka1/gZItf2puJz\n\t\t\t\t\t\tMijPqUOkiC/C43TzHM3o+GtOV/j/AgMBAAGjUDBOMB0GA1UdDgQWBBRslIEX55jy\n\t\t\t\t\t\t2+BX3F7pC3w3QQmyZTAfBgNVHSMEGDAWgBRslIEX55jy2+BX3F7pC3w3QQmyZTAM\n\t\t\t\t\t\tBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAVLJ7unff9MIjkJcDlLEax\n\t\t\t\t\t\t+izPFMJvCic7VptKLhffLm4m6MZaG+U1vtjIfSlZ+mzFonOjugiyW41aP1/0CXBo\n\t\t\t\t\t\tDIl64e4VgIDkpD7rBThmH2G1zNxJzQzmeUJ9TZJs9s7V8KhqfIBioBNVbht2ySOK\n\t\t\t\t\t\tDzmRleXBM2MNuwPjWDtKoaaX7av404JdSBZ0wUAoP5j015F8EIqQuHkrV0z8c+ba\n\t\t\t\t\t\teYX1IgrdpIyr2KogrjxVzojw1sfFR+z4YTm2vt9G1wkQAaXb7GJIWbJDmEtmowWx\n\t\t\t\t\t\toJOY4tpZB0ZjsOTUNnvwopX3H3B8ZSvgjmh3YMVvVrUEi+hcmpa3pmK3ZyNcojea"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDXDCCAkSgAwIBAgIIY3NQ4sTPsKQwDQYJKoZIhvcNAQEFBQAwRTEhMB8GA1UE\n\t\t\t\t\t\tCgwYTGVlZHMgQmVja2V0dCBVbml2ZXJzaXR5MSAwHgYDVQQDDBdvYWxhLmxlZWRz\n\t\t\t\t\t\tYmVja2V0dC5hYy51azAeFw0xNTEwMjcxNzA1MzBaFw0yNTEwMjcxNzA1MzBaMEUx\n\t\t\t\t\t\tITAfBgNVBAoMGExlZWRzIEJlY2tldHQgVW5pdmVyc2l0eTEgMB4GA1UEAwwXb2Fs\n\t\t\t\t\t\tYS5sZWVkc2JlY2tldHQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK\n\t\t\t\t\t\tAoIBAQCVFC46kUWSe1tcRlZUevYSOtQkNz9u3WMwwRE5tOtegpEQB8bVen1mLosc\n\t\t\t\t\t\tvs9xuot9/VZlK6I9dTB0zSfM4KqIyEgcjEbsvprxXAKFRR6pPNVxOofjVSfbJlHD\n\t\t\t\t\t\tPZwT2xPsm3tZNhhTxRaKmRYSSXAyg9YMHytFeR4RebgBrbbNsmLeOucvzOiyaRhQ\n\t\t\t\t\t\tf3k9yRIhWsawlgbId47GHl0AyaxBLoHISijYpVeU6AztbKFeQue4IQLpnOL5wbfR\n\t\t\t\t\t\teP365fhVoCA52A+9Ad8RBJam51LvKBEtXQwT1N1aff//qN6Xt9ka1/gZItf2puJz\n\t\t\t\t\t\tMijPqUOkiC/C43TzHM3o+GtOV/j/AgMBAAGjUDBOMB0GA1UdDgQWBBRslIEX55jy\n\t\t\t\t\t\t2+BX3F7pC3w3QQmyZTAfBgNVHSMEGDAWgBRslIEX55jy2+BX3F7pC3w3QQmyZTAM\n\t\t\t\t\t\tBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQAVLJ7unff9MIjkJcDlLEax\n\t\t\t\t\t\t+izPFMJvCic7VptKLhffLm4m6MZaG+U1vtjIfSlZ+mzFonOjugiyW41aP1/0CXBo\n\t\t\t\t\t\tDIl64e4VgIDkpD7rBThmH2G1zNxJzQzmeUJ9TZJs9s7V8KhqfIBioBNVbht2ySOK\n\t\t\t\t\t\tDzmRleXBM2MNuwPjWDtKoaaX7av404JdSBZ0wUAoP5j015F8EIqQuHkrV0z8c+ba\n\t\t\t\t\t\teYX1IgrdpIyr2KogrjxVzojw1sfFR+z4YTm2vt9G1wkQAaXb7GJIWbJDmEtmowWx\n\t\t\t\t\t\toJOY4tpZB0ZjsOTUNnvwopX3H3B8ZSvgjmh3YMVvVrUEi+hcmpa3pmK3ZyNcojea"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Leeds Beckett University (New)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.leedsbeckett.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Leeds Beckett University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:ibistic:prod:dk.ibistic.net",
    {
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://wayf.dk/images/stories/WAYF-filer/metadataregistrationpracticestatementwayf.pdf"
              }
            ],
            "registration_instant": "2011-09-19T08:55:21Z",
            "registration_authority": "https://www.wayf.dk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute_value": [
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "kalmar"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "denmark"
              },
              {
                "extension_attributes": {
                  "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                },
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                "text": "iceland"
              }
            ],
            "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
            "name": "tags",
            "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "urn:ibistic:prod:dk.ibistic.net",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Form\u00e5let er at h\u00e5ndtere og godkende leverand\u00f8rfakturaer i en webbaseret l\u00f8sning."
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The purpose is to handle and approve supplier invoices in a web-based solution."
                  }
                ],
                "display_name": [
                  {
                    "lang": "da",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ibistic"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ibistic"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://dk.ibistic.net/redirector/saml/post/ac",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "attribute_consuming_service": [
            {
              "service_description": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Form\u00e5let er at h\u00e5ndtere og godkende leverand\u00f8rfakturaer i en webbaseret l\u00f8sning."
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "The purpose is to handle and approve supplier invoices in a web-based solution."
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true",
              "service_name": [
                {
                  "lang": "da",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Ibistic"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Ibistic"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "gn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "schacHomeOrganization",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.25178.1.2.9",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cafe.uscs.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Eduardo dos Santos"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "eduardo@uscs.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.uscs.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDzjCCArYCAQAwDQYJKoZIhvcNAQEFBQAwgawxPTA7BgNVBAoUNFVTQ1MgLSBV\nbml2ZXJzaWRhZGUgTXVuaWNpcGFsIGRlIFPDo28gQ2FldGFubyBkbyBTdWwxHDAa\nBgNVBAsTE0RlcGFydGFtZW50byBkZSBUSUMxHDAaBgNVBAcUE1PDo28gQ2FldGFu\nbyBkbyBTdWwxEzARBgNVBAgUClPDo28gUGF1bG8xCzAJBgNVBAYTAkJSMQ0wCwYD\nVQQDEwRjYWZlMB4XDTE0MDQyMzEyMjkwOVoXDTE5MDQyMjEyMjkwOVowgawxPTA7\nBgNVBAoUNFVTQ1MgLSBVbml2ZXJzaWRhZGUgTXVuaWNpcGFsIGRlIFPDo28gQ2Fl\ndGFubyBkbyBTdWwxHDAaBgNVBAsTE0RlcGFydGFtZW50byBkZSBUSUMxHDAaBgNV\nBAcUE1PDo28gQ2FldGFubyBkbyBTdWwxEzARBgNVBAgUClPDo28gUGF1bG8xCzAJ\nBgNVBAYTAkJSMQ0wCwYDVQQDEwRjYWZlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEAnMgoOOS1q469sjuekkG6hOjIo0N0JLw+RFj20LasNRbdxpGNmlUu\nEO7/tXNMWs78BTtONVF9buyTZMOKUB2+Tw5qiZQ5w2y6B4quFS1zDv+jb361ZRhw\n/YHr17DZqYevPZfoIsMyr8PeXxGvpZvXIRxRWixFYXK6cSzxjZabK/HalaChWsok\nabWJvmtk3RUaNFDUg7m5fdysgCmMu1tXTIUqcCigHKvjIAi9VvUoTqs1sCFT916M\nPcORbfc+FpbNYbM+wW8nIJcwXTI94GhWiR1jJ4P8JfNRusbF6oaCOZe6WHIaysRN\nnuUwed10kYrBjIeh0+gH6WrvGi09VCbvFwIDAQABMA0GCSqGSIb3DQEBBQUAA4IB\nAQBEI/TESsgFK6AN0nrNrdcnqoGCf0P3yS1THvE0Q48I0RRCows+U07LTj+W4sm6\nsN9bM16I1nIwZPWSbBB49L0+JkJHkmUAId8vamN1qHG5hjU13HaIY6g2PSZNYM61\n4nL8Hf18QK/WD5etufceyiqTWImfFPq3/6bUEeZCCIcW9gnY2GjOC9a8hhWu9GV0\n9id1ZjXEhJYRnD4N42qPDTc6I9QtnbDJo5QN7+BEB7dFZ9x/WsZWk5B9Na5r69d5\nDsvS7Z5Hdoz1fHcgr6M82y0DzBOCJYFv37NBx/o8iQ/0AeWPGP75Al9b3qzAzQmS\nQEjzHAKqUpXAKTtGQ1Gp7AIE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uscs.edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.uscs.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.uscs.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.uscs.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.uscs.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.uscs.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.uscs.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.uscs.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.uscs.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uscs.edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uscs.edu.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.uscs.edu.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "USCS - Universidade Municipal de Sao Caetano do Sul"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "USCS - Universidade Municipal de Sao Caetano do Sul"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "USCS - Universidade Municipal de Sao Caetano do Sul"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "USCS - Universidade Municipal de Sao Caetano do Sul"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDzjCCArYCAQAwDQYJKoZIhvcNAQEFBQAwgawxPTA7BgNVBAoUNFVTQ1MgLSBV\nbml2ZXJzaWRhZGUgTXVuaWNpcGFsIGRlIFPDo28gQ2FldGFubyBkbyBTdWwxHDAa\nBgNVBAsTE0RlcGFydGFtZW50byBkZSBUSUMxHDAaBgNVBAcUE1PDo28gQ2FldGFu\nbyBkbyBTdWwxEzARBgNVBAgUClPDo28gUGF1bG8xCzAJBgNVBAYTAkJSMQ0wCwYD\nVQQDEwRjYWZlMB4XDTE0MDQyMzEyMjkwOVoXDTE5MDQyMjEyMjkwOVowgawxPTA7\nBgNVBAoUNFVTQ1MgLSBVbml2ZXJzaWRhZGUgTXVuaWNpcGFsIGRlIFPDo28gQ2Fl\ndGFubyBkbyBTdWwxHDAaBgNVBAsTE0RlcGFydGFtZW50byBkZSBUSUMxHDAaBgNV\nBAcUE1PDo28gQ2FldGFubyBkbyBTdWwxEzARBgNVBAgUClPDo28gUGF1bG8xCzAJ\nBgNVBAYTAkJSMQ0wCwYDVQQDEwRjYWZlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A\nMIIBCgKCAQEAnMgoOOS1q469sjuekkG6hOjIo0N0JLw+RFj20LasNRbdxpGNmlUu\nEO7/tXNMWs78BTtONVF9buyTZMOKUB2+Tw5qiZQ5w2y6B4quFS1zDv+jb361ZRhw\n/YHr17DZqYevPZfoIsMyr8PeXxGvpZvXIRxRWixFYXK6cSzxjZabK/HalaChWsok\nabWJvmtk3RUaNFDUg7m5fdysgCmMu1tXTIUqcCigHKvjIAi9VvUoTqs1sCFT916M\nPcORbfc+FpbNYbM+wW8nIJcwXTI94GhWiR1jJ4P8JfNRusbF6oaCOZe6WHIaysRN\nnuUwed10kYrBjIeh0+gH6WrvGi09VCbvFwIDAQABMA0GCSqGSIb3DQEBBQUAA4IB\nAQBEI/TESsgFK6AN0nrNrdcnqoGCf0P3yS1THvE0Q48I0RRCows+U07LTj+W4sm6\nsN9bM16I1nIwZPWSbBB49L0+JkJHkmUAId8vamN1qHG5hjU13HaIY6g2PSZNYM61\n4nL8Hf18QK/WD5etufceyiqTWImfFPq3/6bUEeZCCIcW9gnY2GjOC9a8hhWu9GV0\n9id1ZjXEhJYRnD4N42qPDTc6I9QtnbDJo5QN7+BEB7dFZ9x/WsZWk5B9Na5r69d5\nDsvS7Z5Hdoz1fHcgr6M82y0DzBOCJYFv37NBx/o8iQ/0AeWPGP75Al9b3qzAzQmS\nQEjzHAKqUpXAKTtGQ1Gp7AIE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "USCS - Universidade Municipal de Sao Caetano do Sul"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "USCS - Universidade Municipal de Sao Caetano do Sul"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uscs.edu.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uscs.edu.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "USCS - Universidade Municipal de Sao Caetano do Sul"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "USCS - Universidade Municipal de Sao Caetano do Sul"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.birpublications.org/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso-support@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "sso-support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:sso-tech@atypon.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "sso-tech"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.birpublications.org/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-02-24T17:34:33Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "BIR Publications"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.birpublications.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Atypon Systems, Inc"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID+jCCAuKgAwIBAgIJAPs6J7wBa9+AMA0GCSqGSIb3DQEBBQUAMFExIDAeBgNV\n\t\t\t\t\t\tBAMTF3d3dy5iaXJwdWJsaWNhdGlvbnMub3JnMS0wKwYDVQQDEyRiaXJwdWJzLmJp\n\t\t\t\t\t\tci1wcm9kLmxpdGVyYXR1bW9ubGluZS5jb20wHhcNMTQwMTI0MTEyNzAzWhcNMjQw\n\t\t\t\t\t\tMTIyMTEyNzAzWjBRMSAwHgYDVQQDExd3d3cuYmlycHVibGljYXRpb25zLm9yZzEt\n\t\t\t\t\t\tMCsGA1UEAxMkYmlycHVicy5iaXItcHJvZC5saXRlcmF0dW1vbmxpbmUuY29tMIIB\n\t\t\t\t\t\tIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1jmEDJ8jXi2v5lHPaFJlwecK\n\t\t\t\t\t\t1QrpkwvX0LBTH79TVTHx2pi8anBUJzCwB0igLIH2sGZab5YZuUX95rUUkbigbK2Z\n\t\t\t\t\t\tj+29kMamegKNa5P04i2g+M898/4ylemYsiuQPUSHvvnR4xN/wesNyEhNvGXkBU0n\n\t\t\t\t\t\tmA5MrHIfJb7XHlhsQHNzk88+MMUylkuxIxLHZKdCAV7otSAz/J85gw1kbxwfOnh9\n\t\t\t\t\t\t0DhRkDh6hXaxIbX1zMk+D8yAeiG3nuHYRYbjfeqt/dmZVSOSQT6zPxPfOdfMe7d/\n\t\t\t\t\t\tmEPf+RLf88ItXhsWSHrby5Dd3sLNRHccfM6eG04zCs88lrinzyteNrQnviD5qwID\n\t\t\t\t\t\tAQABo4HUMIHRMIGvBgNVHREEgacwgaSCF3d3dy5iaXJwdWJsaWNhdGlvbnMub3Jn\n\t\t\t\t\t\thipodHRwczovL3d3dy5iaXJwdWJsaWNhdGlvbnMub3JnL3NoaWJib2xldGiCJGJp\n\t\t\t\t\t\tcnB1YnMuYmlyLXByb2QubGl0ZXJhdHVtb25saW5lLmNvbYY3aHR0cHM6Ly9iaXJw\n\t\t\t\t\t\tdWJzLmJpci1wcm9kLmxpdGVyYXR1bW9ubGluZS5jb20vc2hpYmJvbGV0aDAdBgNV\n\t\t\t\t\t\tHQ4EFgQUKbT4MojJhlu+5CjDCYfsbGBg5lAwDQYJKoZIhvcNAQEFBQADggEBAI3E\n\t\t\t\t\t\t8w2mbN8mc+2ynACKQ0b+fzSzuSYmwkzCNrPlxpZfgqtKzPfy+Z3N1qGBLpLEArnS\n\t\t\t\t\t\tlTWJO2pOzI9sPAlPROl5ovpUky8SRneOeclpzzLFQJau9FJuG/x/tfLj7RQkkewK\n\t\t\t\t\t\td5I4e6B2H+q3KF8n6KnvJr4uh4SGfFu5EXAbIg0HpBEh5sFTFmSY/RNWLg45Quo4\n\t\t\t\t\t\td+1by3NzthGQKaQQB1vB8OevylY9O4elEPcTocDAGblsownCzcHhueScH+7uNMKB\n\t\t\t\t\t\tnTfnIQ4baN5Zgm+QRbEVn7mRA7b2HYA+SQyh8B9wmYbWZ9Aerfg5hXAw5POHIZzS\n\t\t\t\t\t\ttvSA3VPNsgDJZ/VDCPw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.birpublications.org/action/samlACS",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.birpublications.org/action/saml2post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.birpublications.org/action/saml2artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://iif.iucc.ac.il/idp/module.php/saml/sp/metadata.php/default-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@iif.iucc.ac.il"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Administrator"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "info@iif.iucc.ac.il"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://iif.iucc.ac.il/idp/module.php/saml/sp/metadata.php/default-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://iif.iucc.ac.il/wordpress/wp-content/uploads/2014/06/IIF-Policy.pdf"
              }
            ],
            "registration_instant": "2014-11-20T10:35:34Z",
            "registration_authority": "http://iif.iucc.ac.il",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IUCC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iucc.ac.il"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IUCC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://iif.iucc.ac.il/idp/module.php/saml/sp/saml2-logout.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Inter University Computation Center"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://iif.iucc.ac.il/idp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://iif.iucc.ac.il/idp/module.php/saml/sp/saml1-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://iif.iucc.ac.il/idp/module.php/saml/sp/saml2-acs.php/default-sp",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://iif.iucc.ac.il/idp/module.php/saml/sp/saml1-acs.php/default-sp/artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "IUCC"
                }
              ],
              "service_description": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "Inter University Computational Center"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "cn",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://play.lu.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://play.lu.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://play.lu.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://play.lu.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.lu.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://play.lu.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://play.lu.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://play.lu.se/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://play.lu.se/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "play.lu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC8TCCAdmgAwIBAgIJANdIt1sPlxZtMA0GCSqGSIb3DQEBBQUAMBUxEzARBgNV\nBAMTCnBsYXkubHUuc2UwHhcNMTIwOTIxMDg1ODQzWhcNMjIwOTE5MDg1ODQzWjAV\nMRMwEQYDVQQDEwpwbGF5Lmx1LnNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\nCgKCAQEAm52BjRAJpGfNZHRAES67hnyp1n9XiPmdZxQGGacgB+ME1zUS+s0+R4B4\nTQjJv3dzkkAa4Lhd3f3eRsTeJ1pnEJ2esqbK2bk5qX/GNC7lpdSnbRg+vBfvaZgD\n6643daq++Qt2gMvzbp7jn8BTqJUZQUH31RJwnoqjgrVj19GBOZOJmtBGmktBlPOb\n/MIWmk4p4epjgA9Fpg94WiJ8hjEl15SV+CtktRzQeRG3ph6uKFpMoXsda50LcmtW\nNrlnG/wkhGgT3BVyrqtUVi/0Fv0kVXhArhmDbN7f3foWpLfZhH+lhZYLfoxjtsgv\n16LqZVmWscFUI/oBmOjnwpZwvz7m8QIDAQABo0QwQjAhBgNVHREEGjAYggpwbGF5\nLmx1LnNlhgpwbGF5Lmx1LnNlMB0GA1UdDgQWBBQogVFbpaWP1X0OCpOzt3bysyYD\nQDANBgkqhkiG9w0BAQUFAAOCAQEAdP4K4e/MS3Fpxbx7oDaIaFAEWXDzgUDimGdF\n2jzgtcbkZJBj9TpgMSNbY6ThcLOpahFMheogxZX9f+y/bi/kGbuv134PdlMAv6tn\nJnLtx0r+rgbciWJjdu49SrkuNx35nkVhHbVGg7K8F2ov5sL8qt5UlzHyhQZkzPjB\nF2+m5EhhpnrRKwSlgv5ZDpgSjcberEOdvpUFfUhvst1zWfJ0sT/F7V8WcfTVUEu0\nfZtv5Htmbw0VP2Hrh/PPYXiC2pce8i/5mGCVUhHfH8KUGxO+6VHhgtRnFBNYiI1l\ntG3wt4eOb5yI3XF8IM76la4ykRFQSukvkZv1Wj5YiCx5UDm+Xg=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=play.lu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://play.lu.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://play.lu.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.lu.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://play.lu.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.lu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://play.lu.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://play.lu.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://play.lu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://play.lu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://play.lu.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://oala.aaschool.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Marine"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:simine.marine@aaschool.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Simine"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hopkins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itdept@aaschool.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "David"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Bielecki"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:itdept@aaschool.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mathew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://oala.aaschool.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-03-19T11:56:39Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://oala.aaschool.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://oala.aaschool.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aaschool.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVjCCAj6gAwIBAgIIU8+cSxqyjekwDQYJKoZIhvcNAQEFBQAwQjEiMCAGA1UE\n\t\t\t\t\t\tCgwZQXJjaGl0ZWN0dXJhbCBBc3NvY2lhdGlvbjEcMBoGA1UEAwwTb2FsYS5hYXNj\n\t\t\t\t\t\taG9vbC5hYy51azAeFw0xNDAyMDUxMjU0MjFaFw0yNDAyMDUxMjU0MjFaMEIxIjAg\n\t\t\t\t\t\tBgNVBAoMGUFyY2hpdGVjdHVyYWwgQXNzb2NpYXRpb24xHDAaBgNVBAMME29hbGEu\n\t\t\t\t\t\tYWFzY2hvb2wuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCN\n\t\t\t\t\t\t6u0fQexpAbYeL/juhqSYF3kRc6sf9w3ycYdDTx5r8k/3OwklSYshGn6qwJDS7aS4\n\t\t\t\t\t\tQJy2dkFzAaSCycdoEPTRfkcpIQ9nfT9ABzngbDIjYIvCMT7xMyZZCelO6NDuK5F4\n\t\t\t\t\t\tNFWN0vB357o3rce6gzmKY6tvIJ4C61yn2SArKo3VXTJSiLWtjVTTWWMuxK+DMmdD\n\t\t\t\t\t\twxgzB1tiQhGq2aNZHHSMuqri1wCegVB8awO8vn8sVrpd+OxubDS3Me5y4WlY4grs\n\t\t\t\t\t\tXqfrpFtHuQon30WhFgLqXjm5M2Htth44J2aRWvNwQ9UbcUAPDu8zn1EEWjGoeT4U\n\t\t\t\t\t\tKBo2hLbd5xckdJqLhBtvAgMBAAGjUDBOMB0GA1UdDgQWBBTfbelHaYpCBZW2wcu5\n\t\t\t\t\t\tR3SX1LLrejAfBgNVHSMEGDAWgBTfbelHaYpCBZW2wcu5R3SX1LLrejAMBgNVHRME\n\t\t\t\t\t\tBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBNPyhqpXFNU8s9HuXtFRXCraLXUYqW\n\t\t\t\t\t\tCg6Qq9ArXhdGBaPDLI33B5MFfxrK207ZszoC8NsBRU2TGhUs2TcYQYBnCEBjpVNs\n\t\t\t\t\t\tT9Pl+HT+1RAqFDXJfz8vnva16QFyohJQcOXgwbKcasy3v4TFOBLlQSYUN6gJyPDz\n\t\t\t\t\t\tRbuvCdEwIL74sLpZmHbGtF88nINKnPkRlQXIqCnnQg3nfL/qBd67lt6Ih4wyPCkX\n\t\t\t\t\t\tN+Fr1zIKaChdHOdfBVIuG8o9SL5GeLuHOSUwKtYngivsmk73rRvQxJHYwuRstWlV\n\t\t\t\t\t\tO6NtqBZn2l5WgFXs6cNoPTwZCFrlNTiQIVXgZnWaTdXzei52kRX/5v/X"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVjCCAj6gAwIBAgIIU8+cSxqyjekwDQYJKoZIhvcNAQEFBQAwQjEiMCAGA1UE\n\t\t\t\t\t\tCgwZQXJjaGl0ZWN0dXJhbCBBc3NvY2lhdGlvbjEcMBoGA1UEAwwTb2FsYS5hYXNj\n\t\t\t\t\t\taG9vbC5hYy51azAeFw0xNDAyMDUxMjU0MjFaFw0yNDAyMDUxMjU0MjFaMEIxIjAg\n\t\t\t\t\t\tBgNVBAoMGUFyY2hpdGVjdHVyYWwgQXNzb2NpYXRpb24xHDAaBgNVBAMME29hbGEu\n\t\t\t\t\t\tYWFzY2hvb2wuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCN\n\t\t\t\t\t\t6u0fQexpAbYeL/juhqSYF3kRc6sf9w3ycYdDTx5r8k/3OwklSYshGn6qwJDS7aS4\n\t\t\t\t\t\tQJy2dkFzAaSCycdoEPTRfkcpIQ9nfT9ABzngbDIjYIvCMT7xMyZZCelO6NDuK5F4\n\t\t\t\t\t\tNFWN0vB357o3rce6gzmKY6tvIJ4C61yn2SArKo3VXTJSiLWtjVTTWWMuxK+DMmdD\n\t\t\t\t\t\twxgzB1tiQhGq2aNZHHSMuqri1wCegVB8awO8vn8sVrpd+OxubDS3Me5y4WlY4grs\n\t\t\t\t\t\tXqfrpFtHuQon30WhFgLqXjm5M2Htth44J2aRWvNwQ9UbcUAPDu8zn1EEWjGoeT4U\n\t\t\t\t\t\tKBo2hLbd5xckdJqLhBtvAgMBAAGjUDBOMB0GA1UdDgQWBBTfbelHaYpCBZW2wcu5\n\t\t\t\t\t\tR3SX1LLrejAfBgNVHSMEGDAWgBTfbelHaYpCBZW2wcu5R3SX1LLrejAMBgNVHRME\n\t\t\t\t\t\tBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQBNPyhqpXFNU8s9HuXtFRXCraLXUYqW\n\t\t\t\t\t\tCg6Qq9ArXhdGBaPDLI33B5MFfxrK207ZszoC8NsBRU2TGhUs2TcYQYBnCEBjpVNs\n\t\t\t\t\t\tT9Pl+HT+1RAqFDXJfz8vnva16QFyohJQcOXgwbKcasy3v4TFOBLlQSYUN6gJyPDz\n\t\t\t\t\t\tRbuvCdEwIL74sLpZmHbGtF88nINKnPkRlQXIqCnnQg3nfL/qBd67lt6Ih4wyPCkX\n\t\t\t\t\t\tN+Fr1zIKaChdHOdfBVIuG8o9SL5GeLuHOSUwKtYngivsmk73rRvQxJHYwuRstWlV\n\t\t\t\t\t\tO6NtqBZn2l5WgFXs6cNoPTwZCFrlNTiQIVXgZnWaTdXzei52kRX/5v/X"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Architectural Association"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aaschool.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Architectural Association (Incorporated)"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "http://adfs.surfmarket.nl/adfs/services/trust",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@surfconext.nl"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "SURFconext support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "http://adfs.surfmarket.nl/adfs/services/trust",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://wiki.surfnet.nl/display/eduGAIN/EduGAIN"
              }
            ],
            "registration_instant": "2015-05-08T16:45:00Z",
            "registration_authority": "http://www.surfconext.nl/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://engine.surfconext.nl/authentication/idp/single-sign-on/dd8a661ec02c530266ecb8b41dcbb9cb",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SURFmarket"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "SURFmarket"
                  }
                ],
                "logo": [
                  {
                    "text": "https://static.surfconext.nl/logos/idp/surfmarket.png",
                    "height": "34",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "108"
                  }
                ],
                "display_name": [
                  {
                    "lang": "nl",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SURFmarket"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "SURFmarket"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": " "
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SURFmarket"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.surfmarket.nl"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SURFmarket"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://seminar.nordu.net/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:noc@nordu.net"
            }
          ],
          "company": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Company",
            "text": "NORDUnet NOC"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://seminar.nordu.net/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/eu-adequate-protection"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "NORDUnet A/S"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.nordu.net"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "NORDUnet"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://seminar.nordu.net/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://seminar.nordu.net/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://seminar.nordu.net/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://seminar.nordu.net/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://seminar.nordu.net/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://seminar.nordu.net/Shibboleth.sso/DS/nordu.net",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://seminar.nordu.net/Shibboleth.sso/DS/nordu.net",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://seminar.nordu.net/Shibboleth.sso/DS/nordu.net",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://seminar.nordu.net/Shibboleth.sso/DS/nordu.net",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://seminar.nordu.net/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://seminar.nordu.net/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://seminar.nordu.net/Shibboleth.sso/DS/kalmar2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://seminar.nordu.net/Shibboleth.sso/DS/kalmar2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "4"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://seminar.nordu.net/Shibboleth.sso/Login/feide",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://seminar.nordu.net/Shibboleth.sso/DS/haka.funet.fi",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://seminar.nordu.net/Shibboleth.sso/DS/haka.funet.fi",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "5"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://seminar.nordu.net/Shibboleth.sso/Login/idp.funet.fi",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ac-w01.nordu.net"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9zCCAd+gAwIBAgIJAK6IEFZqeYNkMA0GCSqGSIb3DQEBBQUAMBsxGTAXBgNV\nBAMTEGFjLXcwMS5ub3JkdS5uZXQwHhcNMTUxMTI1MTQzMTMxWhcNMjUxMTIyMTQz\nMTMxWjAbMRkwFwYDVQQDExBhYy13MDEubm9yZHUubmV0MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAm5n/c1jQxsE6ZLDCaLkxAzMkYAveKeF0uMosuZAm\nLbKK88nSMRvrM4XZWUxw4Y7Hhuy4CaI2ief6DEIeCvp1zL1akcRARLKR2dcZwhaI\nXk5ZmSk0nZFmfCx/Q1/1QkWRtlTWZN5QWjKYhMf8v6NWQUkPkzcnTn5JsFRC53XB\nZGm4PDxbsj4iHoR+fL78gqcZ/lNlWkico8dF1Gb5ECT7RoFLwYg3j9mJegEueZCd\nzI9xK4J8D1gCv98JhMFDnUuzOsUetKI+ztzgk2kvA4UUXSg5jNQmw4CXXvR4On9F\nzuyrlB7fxfHIUW4+msGDlSIcG4D9fkpgJVggYYfogslzTQIDAQABoz4wPDAbBgNV\nHREEFDASghBhYy13MDEubm9yZHUubmV0MB0GA1UdDgQWBBTSzNfSHtoiM3DkR1ki\nUjaoX4s3KzANBgkqhkiG9w0BAQUFAAOCAQEAkKma/1Q8c9Bfhya5ZjZeVoTD/q0m\nrM+K4C7a88+bEHyIAVi5iKXrGRqcYRxiOFJ90Bqrif5Lu1kXk//WfAoijVVO7LHR\nDstraFrFHnAk+Tqz4hgN7ttzgM63hR9uEe9M5euw00UQ1MTDX2EjUtB22T9m1IPn\nA9ToIGUpGX3izWzTLU+7h2do56ZxbVwH5c+NtQAGEIqDCEbtLvAaWu4XVor8Shj7\npdi0ryFf9fQWwe8aUhmC8BNl5KNnDMgo3ka39txGyo9bxjJHEHJDwiZNasMgHoCa\no53aOf7QIMq0SMHnBJXRznGwibXlXP0Wtbl2hpcO5QxiZHziD434b0eYqQ=="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ac-w01.nordu.net"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://seminar.nordu.net/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:kuleuven.be:kulassoc:khleuven.be",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Technical Support"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@khleuven.be"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:kuleuven.be:kulassoc:khleuven.be",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://federation.belnet.be/files/Belnet-metadata-registration-practice-statement.txt"
              }
            ],
            "registration_instant": "2012-03-27T12:00:00Z",
            "registration_authority": "http://federation.belnet.be/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.khleuven.be"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAIEBQgacYZ+Obt/8LGcNE9xCxtg1MA0GCSqGSIb3DQEB\n\tBQUAMBoxGDAWBgNVBAMTD2lkcC5raGxldXZlbi5iZTAeFw0wOTEyMTUwOTI5Mjla\n\tFw0yOTEyMTUwOTI5MjlaMBoxGDAWBgNVBAMTD2lkcC5raGxldXZlbi5iZTCCASIw\n\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJo7I1DRJ2ulw9KOgJGEX3Yo+Oi1\n\taxnNmLMaJQGWHIuKOih7ePjvm2MuGaFHZZLHsa3yI6JMsi6OWoh4FnUTfU8t+lSc\n\ti9Mn4zjQBIGQK6HAQiFjouUuMAKGD0hvXuqtIbw7cNK6dABRuZx6xbJ7HveUAb2W\n\tiLshYnfJ5smDY44UN68eOZfRS941NE+hY2EESWfRtHj3bF8K1eClv9DKaxB7A6zA\n\t3A0kZrum6K2DiyiN4gj9pUpC0w86jdXmPq+/8XXHLnX2RTBJE55KNzNe82n0DomT\n\tqVXGZ5bxBNuSuS+IGKQpxNDO6py7wKxUVMdIRHoy2xUqU62JunMyfExCgwcCAwEA\n\tAaNlMGMwQgYDVR0RBDswOYIPaWRwLmtobGV1dmVuLmJlhiZodHRwczovL2lkcC5r\n\taGxldXZlbi5iZS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU6LNVU7ay63LW4qY9\n\tgmQd70bUxXQwDQYJKoZIhvcNAQEFBQADggEBABGQdtkb/TncVxlIi0ejI3AHUYmG\n\tRT05mU0Cmt1SEKybN6/VvwamKPWc9bmJu+uxJo3bxRVzOfUdXExZCe9KoLugj7KJ\n\tECH1yRDSb+s9TV2djqGEQO104Ol6fhDRH1YV7FWGjQ79Roddu6IwEawek4VEY4om\n\trQmBOTjKUb10v9xTTX28PsTM7e8Avbu9BujIgeX4KcsUWqDDsX8r9P8hK7aOS7Ym\n\tXPLrSitrNNrQYr9FzuRm995nQ20lVTjh83TiPADSXUXDkebI9GcKqDA662HTNpNp\n\t5Dpn+ZM2hbJN+AbA9QdpVSb+MJCzpRyh2AlN8simVEiciy1+p5tWR3iLwv8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "associatie.kuleuven.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "khleuven.be"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.khleuven.be:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.khleuven.be:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.khleuven.be/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.khleuven.be/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.khleuven.be/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.khleuven.be/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.khleuven.be:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.khleuven.be:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "associatie.kuleuven.be"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "khleuven.be"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Katholieke Hogeschool Leuven"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "KHLeuven"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "idp.khleuven.be"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAIEBQgacYZ+Obt/8LGcNE9xCxtg1MA0GCSqGSIb3DQEB\n\tBQUAMBoxGDAWBgNVBAMTD2lkcC5raGxldXZlbi5iZTAeFw0wOTEyMTUwOTI5Mjla\n\tFw0yOTEyMTUwOTI5MjlaMBoxGDAWBgNVBAMTD2lkcC5raGxldXZlbi5iZTCCASIw\n\tDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJo7I1DRJ2ulw9KOgJGEX3Yo+Oi1\n\taxnNmLMaJQGWHIuKOih7ePjvm2MuGaFHZZLHsa3yI6JMsi6OWoh4FnUTfU8t+lSc\n\ti9Mn4zjQBIGQK6HAQiFjouUuMAKGD0hvXuqtIbw7cNK6dABRuZx6xbJ7HveUAb2W\n\tiLshYnfJ5smDY44UN68eOZfRS941NE+hY2EESWfRtHj3bF8K1eClv9DKaxB7A6zA\n\t3A0kZrum6K2DiyiN4gj9pUpC0w86jdXmPq+/8XXHLnX2RTBJE55KNzNe82n0DomT\n\tqVXGZ5bxBNuSuS+IGKQpxNDO6py7wKxUVMdIRHoy2xUqU62JunMyfExCgwcCAwEA\n\tAaNlMGMwQgYDVR0RBDswOYIPaWRwLmtobGV1dmVuLmJlhiZodHRwczovL2lkcC5r\n\taGxldXZlbi5iZS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU6LNVU7ay63LW4qY9\n\tgmQd70bUxXQwDQYJKoZIhvcNAQEFBQADggEBABGQdtkb/TncVxlIi0ejI3AHUYmG\n\tRT05mU0Cmt1SEKybN6/VvwamKPWc9bmJu+uxJo3bxRVzOfUdXExZCe9KoLugj7KJ\n\tECH1yRDSb+s9TV2djqGEQO104Ol6fhDRH1YV7FWGjQ79Roddu6IwEawek4VEY4om\n\trQmBOTjKUb10v9xTTX28PsTM7e8Avbu9BujIgeX4KcsUWqDDsX8r9P8hK7aOS7Ym\n\tXPLrSitrNNrQYr9FzuRm995nQ20lVTjh83TiPADSXUXDkebI9GcKqDA662HTNpNp\n\t5Dpn+ZM2hbJN+AbA9QdpVSb+MJCzpRyh2AlN8simVEiciy1+p5tWR3iLwv8="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "KHLeuven"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.khleuven.be/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Katholieke Hogeschool Leuven"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://shibboleth.highwire.org/entity/asnjnls",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Biasotti"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:shibboleth-admin@highwire.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Olga"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.highwire.org/entity/asnjnls",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-01-16T18:42:13Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Stanford University: Journals of the American Society of Nephrology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://asnjournals.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "HighWire Press, Inc."
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.highwire.org/applications/asnjnls/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://shibboleth.highwire.org/applications/asnjnls/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEfDCCA2SgAwIBAgIJAMTRVlqTJ11lMA0GCSqGSIb3DQEBBQUAMIG+MQswCQYD\n\t\t\t\t\t\tVQQGEwJVUzETMBEGA1UECBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBD\n\t\t\t\t\t\taXR5MRcwFQYDVQQKEw5IaWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUx\n\t\t\t\t\t\tIDAeBgNVBAMTF3NoaWJib2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkB\n\t\t\t\t\t\tFiZzaGliYm9sZXRoLWFkbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTAeFw0xNDA0\n\t\t\t\t\t\tMTUxOTQzMDNaFw0yNDA0MTIxOTQzMDNaMIG+MQswCQYDVQQGEwJVUzETMBEGA1UE\n\t\t\t\t\t\tCBMKQ2FsaWZvcm5pYTEVMBMGA1UEBxMMUmVkd29vZCBDaXR5MRcwFQYDVQQKEw5I\n\t\t\t\t\t\taWdoV2lyZSBQcmVzczERMA8GA1UECxMISGlnaFdpcmUxIDAeBgNVBAMTF3NoaWJi\n\t\t\t\t\t\tb2xldGguaGlnaHdpcmUub3JnMTUwMwYJKoZIhvcNAQkBFiZzaGliYm9sZXRoLWFk\n\t\t\t\t\t\tbWluQGhpZ2h3aXJlLnN0YW5mb3JkLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEP\n\t\t\t\t\t\tADCCAQoCggEBALPB99M9iWjentrddY/rLgzKn1X0j4Ao191iyiowBBt/r/pmn2oz\n\t\t\t\t\t\tfrbONkkTVBB++mNtiufK6jyKnBM5mffPOkXHRo+K1DQec7TvpQ1PmLv/BpBgPrr9\n\t\t\t\t\t\tldViOSUnYJuB0IgJVV8oylgeH2Ay0XRkNPlBUjBA2fUPWVpXcvFe+aD2tLdVR9uO\n\t\t\t\t\t\tXvfTMxAEGqzxTU+OxO6pW2sBXNBmGvZQ0TRyovQh5+pTURY/lm0V/iWvRmRe51WE\n\t\t\t\t\t\tO/nhYyvRuMmNj8EL38o10S9TXuCkVzY00hK5cclaFge7gz/tfjmadVVcbe8xCVxc\n\t\t\t\t\t\tnb1lhmt1kH2XtKvU5hyZMTO+VUfXQvqcQyECAwEAAaN7MHkwCQYDVR0TBAIwADAs\n\t\t\t\t\t\tBglghkgBhvhCAQ0EHxYdT3BlblNTTCBHZW5lcmF0ZWQgQ2VydGlmaWNhdGUwHQYD\n\t\t\t\t\t\tVR0OBBYEFJpUZq/XaW9/bPvjffkxX0IDvuPiMB8GA1UdIwQYMBaAFJpUZq/XaW9/\n\t\t\t\t\t\tbPvjffkxX0IDvuPiMA0GCSqGSIb3DQEBBQUAA4IBAQCq/FF56ZB1cL3KbniEJP99\n\t\t\t\t\t\tU9wTD6KpOrWxvqNbUSV1cefLf5cYHonOjy6oAJSSBSNuP7U5Q//0tXtkvlJoqGUY\n\t\t\t\t\t\tvqngmeg9wLZ/Fla3tXcDdTj0n1F+NZOx9vBDacIk0Ua4aHXDA4bdytzkV1QyZDRq\n\t\t\t\t\t\tQ8vq7RoQ8E5IF7Cll+kt2dZXQk8o6Qp3w2ppoMRtYdKOQassqn+V1MYcMPgdxZkS\n\t\t\t\t\t\tDrcgzktR/JMb5OmPrp4mSy1OWDGrFvUIigsLBPZV9tw1f7y42lnbmQas3RCS30yr\n\t\t\t\t\t\tCtUPT/PQDkCdBRViGmmMkYwjdaOTiHOJveWtrVXu8vLvO36pqFF4Kft0pgqlfvAE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://shibboleth.highwire.org/applications/asnjnls/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://shibboleth.highwire.org/applications/asnjnls/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://shibboleth.highwire.org/applications/asnjnls/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.highwire.org/applications/asnjnls/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://identities.univ-jfc.fr/idp/prod",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "J.-M. Kubek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jean-marie.kubek@univ-jfc.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://identities.univ-jfc.fr/idp/prod",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2011-02-10T15:01:12Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cabrel.univ-jfc.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cabrel.univ-jfc.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cabrel.univ-jfc.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "univ-jfc.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.univ-jfc.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CUFR Jean-Fran\u00e7ois Champollion"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CUFR Jean-Fran\u00e7ois Champollion"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEnjCCA4agAwIBAgIQKfC7PoBqgitD7hgMJJZhtzANBgkqhkiG9w0BAQsFADBk\nMQswCQYDVQQGEwJOTDEWMBQGA1UECBMNTm9vcmQtSG9sbGFuZDESMBAGA1UEBxMJ\nQW1zdGVyZGFtMQ8wDQYDVQQKEwZURVJFTkExGDAWBgNVBAMTD1RFUkVOQSBTU0wg\nQ0EgMjAeFw0xNDEyMTUwMDAwMDBaFw0xNzEyMTQyMzU5NTlaMEAxITAfBgNVBAsT\nGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEbMBkGA1UEAxMSY2FicmVsLnVuaXYt\namZjLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEApTfvTrYBl56c\niIbkgBbvhrgC1LViU8mt0cqFUEsumOqCnpM21XfZTeE60cK35tl00bU9rvAvOsS6\ngVEnTIW1JfjE4j+dyODlCETWExkbfEVpRlhzSDO1hClOobWOS9top0Z9LfpRaUk2\nBf0Nnf0IWrvH+fM/N+LquRzVLTMBZl3pm5CiQM4TofMVNadgVR66E8HllM/kFnPB\nLSsJD9Fa/66QgIxeRsN7Yos2tTjMTbnwQ4sYa5Q/B12/5c3SG1ImcJWHOYe/+scZ\ntiNUuOXKXucZsj7nKEOmaAqupbOCey/dPxDi4F5/QsJR0O+KlY4cfIOFHJeIgcpx\nZhFPxUpz0wIDAQABo4IBbjCCAWowHwYDVR0jBBgwFoAUW9CKHJoyW+C13ZZUG+GG\nKLD9tr0wHQYDVR0OBBYEFCKA92H/uYHKIR4GxXHdlujIJvc7MA4GA1UdDwEB/wQE\nAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQGCCsGAQUFBwMBBggrBgEFBQcD\nAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgGBmeBDAECATA6BgNVHR8EMzAx\nMC+gLaArhilodHRwOi8vY3JsLnVzZXJ0cnVzdC5jb20vVEVSRU5BU1NMQ0EyLmNy\nbDBsBggrBgEFBQcBAQRgMF4wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQudXNlcnRy\ndXN0LmNvbS9URVJFTkFTU0xDQTIuY3J0MCUGCCsGAQUFBzABhhlodHRwOi8vb2Nz\ncC51c2VydHJ1c3QuY29tMB0GA1UdEQQWMBSCEmNhYnJlbC51bml2LWpmYy5mcjAN\nBgkqhkiG9w0BAQsFAAOCAQEAdZc1KklhQc9qUvXfLL8pSRDf1YAr3TiazYRgs11d\nVT49T+XjywaEwt/EuO37kjgWEdDaUIixW+GbeOFmiOVL1SEzMfKFY8I3kOpvDObD\n3jsmc+bgInT2XR30NXpZqEZ/SR4E8Arhx1x88INL/vkZ8kc6fJ3Jd7JP90nTt9WV\ntmdx8n8rj2sNTl89FnNemEJYWQwF0nKuywnhLip82VqJCkWfL7lp9bdC+WU03DzF\nzr2zHMbf8Bks0RPLRRjYiGdyfU2+4JqdaCDsJqVRfSYWN0MLNazWWnmuUZ8aXNCm\nrZ7HQsIozzk8IpYy1UKXZtaGL3Rr/EyYfKsSeYGTGTX6Zw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEmjCCA4KgAwIBAgIRAJUDuJkaRvWHyWeev34/8hgwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xMTExMjkwMDAwMDBaFw0xNDExMjgyMzU5NTlaMHIxCzAJBgNV\nBAYTAkZSMUYwRAYDVQQKEz1DRU5UUkUgVU5JVkVSU0lUQUlSRSBERSBGT1JNQVRJ\nT04gRVQgUkVDSEVSQ0hFIEpGIENIQU1QT0xMSU9OMRswGQYDVQQDExJjYWJyZWwu\ndW5pdi1qZmMuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC3d+Rm\nUDXoUgVRpi6/M8k3JLM+icOPc+m2rVaVzaJ1r1YUtOI9IbQx5WWAJBQiaaOqbZl1\n9dQNaPBgirUCYs6fzEmiN+68Ea+Hl+V9na60PrCtE7f/iNREMsPdr0hyxkxbO5Rq\nXEvTcS4iBFW03z5iaAyPCVRckVFMLQ2wKo6AchS9kAMrkMDVnpe4fbp/viRytHZ0\n8JAzN9xh/XGdIQomMk7XCPBxmvRjaKhTuCaHfhnpQ2WVpxDL4bh+pR6FNm7cyM5q\nRyivGSxzfZzL1UhDyM2mp1JsJPpbMMNIIR73BurbBProSyNbNg0L3W7Y5SqmoziN\ncLxkrPjM/ALj6+o5AgMBAAGjggFlMIIBYTAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJ\nays3V0fqkOO57TAdBgNVHQ4EFgQUPwIsj+FMgUkCQS2yepLOs8XFoTIwDgYDVR0P\nAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsG\nAQUFBwMCMBgGA1UdIAQRMA8wDQYLKwYBBAGyMQECAh0wOgYDVR0fBDMwMTAvoC2g\nK4YpaHR0cDovL2NybC50Y3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcmwwbQYI\nKwYBBQUHAQEEYTBfMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnRjcy50ZXJlbmEu\nb3JnL1RFUkVOQVNTTENBLmNydDAmBggrBgEFBQcwAYYaaHR0cDovL29jc3AudGNz\nLnRlcmVuYS5vcmcwHQYDVR0RBBYwFIISY2FicmVsLnVuaXYtamZjLmZyMA0GCSqG\nSIb3DQEBBQUAA4IBAQBELDfgRtQGFFnCqUo2VOmdlMXrb+9jTvBcv3Uf5cyv9JDk\nlC5y4qKcUpdofmaBvTJ89CX+vRVwmwdSnCs0SmY7MgopBQKSelC6ioPSdo9NpVLG\n8SlCQ0p/bynWt0jAdav2bvOVGtHSkC0xw4Pa+KNkhQxIr+Q4lFEL+lR8glB0MjpI\nNL+Wg4nuXkz1Uk/2f7r0BvSfkVisZMPlTTEpeuAtrosSd6B2RiCR0qiCPQ0SoaqS\n+jyx9pIRcGIlOqogM0g4sPTu7HMo0YnTQMOBEnbsW28spqIS2YwFqhy1g5Ym0f9s\nhCYLgINEWub/bwGC6PX0gJc70qPAaHGV7JYa/Dgd"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CUFR Jean-Fran\u00e7ois Champollion"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.univ-jfc.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CUFR Jean-Fran\u00e7ois Champollion"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://crowdskills.ncl.ac.uk/shibboleth/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Franks"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chris.franks@ncl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Franks"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chris.franks@ncl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://crowdskills.ncl.ac.uk/shibboleth/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-08-07T14:44:05Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Newcastle University Crowd Skills SP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ncl.ac.uk/itservice/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Newcastle upon Tyne"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://crowdskills.ncl.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://crowdskills.ncl.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://crowdskills.ncl.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://crowdskills.ncl.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://crowdskills.ncl.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://crowdskills.ncl.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC6DCCAdCgAwIBAgIJAOU4R08iVl1iMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\n\t\t\t\t\t\tBAMTC2Nyb3dkc2tpbGxzMB4XDTE1MDgwNjExMDQ1MloXDTI1MDgwMzExMDQ1Mlow\n\t\t\t\t\t\tFjEUMBIGA1UEAxMLY3Jvd2Rza2lsbHMwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQDRen50bMBraKjUTLL/OfCaiv8RcrlkDPSOfPGYWkzp3FPQPA1EURF7\n\t\t\t\t\t\tcKQYIl+0zmaYM5n14cHIS9IvRAcHEEpdnQBqO94kNRE1DFVaCQw/2dSSafgbunEx\n\t\t\t\t\t\tTx0v3dHJv/0X6zacstIYSRj+lyEjuAmoe1PgwDVitlLoN0Qk1jbr8viNlXHgYStG\n\t\t\t\t\t\tbMjDSxpZg14OqtbYh8GaRpMYoUqVzQrwp08hmDKpIbELTIa+F9idRSRK6CJTN78D\n\t\t\t\t\t\tOtNpEJuv6i8He5LPSXKcqPJu1n+3sIZi25qistgxc26BF2OgKe5B63PWNCXCWMxr\n\t\t\t\t\t\tlsgfTzCCXcXl+yP0ysUk7pV0CLH/1FCHAgMBAAGjOTA3MBYGA1UdEQQPMA2CC2Ny\n\t\t\t\t\t\tb3dkc2tpbGxzMB0GA1UdDgQWBBQXuGLwu08yHj34HFP2woB/Wnaa0TANBgkqhkiG\n\t\t\t\t\t\t9w0BAQUFAAOCAQEAFLTlZ6Ltm1R3NUmxX2pp+xle22B7STeOq3H/gUW7pkJPi2Pi\n\t\t\t\t\t\tFJEjS1HnOtoR8dSh/eXWUf6YZsoH1wpSCx+XObNv5iwtcY/JU9CKqMoT6+EXnoWv\n\t\t\t\t\t\tYLRJF16S500AFuaYRY6VQ1DtpoUhcI62NhzkXc7m8tKgEd/ZOLXQqpyAwho9PKUt\n\t\t\t\t\t\tC953PAo4fjcv64SRbOFZF4+cW+oRFlbdiLQatPjlYaiHi1W4mVxfVdHpE0XkLm3h\n\t\t\t\t\t\t5+qM3/iIDrMFGj8+DITylrq5GN0+Gr9ucyHd8eaaDrQtNoGFqJH2YIiH7nvqLpMo\n\t\t\t\t\t\tggaP5VjpxxW0mUDliBDYf/hIcOV9P2sOtxqxrg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://crowdskills.ncl.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://crowdskills.ncl.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://crowdskills.ncl.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://crowdskills.ncl.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://crowdskills.ncl.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://crowdskills.ncl.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "urn:mace:incommon:umbc.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jcgriego@umbc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jason Griego"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "paulr@umbc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul Riddle"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "paulr@umbc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul Riddle"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "incommon-help@umbc.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Technology Support Center"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:umbc.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/assurance/bronze"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "urn:oasis:names:tc:SAML:attribute:assurance-certification",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://webauth.umbc.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://webauth.umbc.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNTCCAh2gAwIBAgIJAMBfbssnE/opMA0GCSqGSIb3DQEBBAUAMBsxGTAXBgNV\nBAMTEHdlYmF1dGgudW1iYy5lZHUwHhcNMTExMTIxMjEwOTAyWhcNMjExMTE4MjEw\nOTAyWjAbMRkwFwYDVQQDExB3ZWJhdXRoLnVtYmMuZWR1MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA8pneHoaFwkaenWXUuoP/Cp2Mf+KNdy7TegsTiC18\nyHMcGQ3sdzztAGicjqNf4N8wqSH9Ysqug72eHpopJbN+Rz9rmqUCujh8fzUgDb6G\ncyH0YpCt2sXDbjHxEzDyq/Acr7J0Q65DJUuqQPEm8WLyZhtT/trGLTM/UYFGIi16\nuYsM+N/GloqhznjcEQ1hEa9Vg5fZ3jl+VbEtzxMsCmou0LkFC+0xaMukPzAkhbeP\nKJG15OhuFFMdIS8oKBop45s7iOAc7CaDGE+1kkULCQzH/kB4K2bjDfyyE9TEMqy7\nWtIjyYUKGil3F1F85kzbQZSG+sVS5QDlGlvLhBnP3WTJIwIDAQABo3wwejAdBgNV\nHQ4EFgQUtGEIa05oxIWEnljb5yVlRL+GkMcwSwYDVR0jBEQwQoAUtGEIa05oxIWE\nnljb5yVlRL+GkMehH6QdMBsxGTAXBgNVBAMTEHdlYmF1dGgudW1iYy5lZHWCCQDA\nX27LJxP6KTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBAUAA4IBAQAjPscifXwc\nOms0MgBdgCdf6MtIELBoB2tmcpJ6ugVELMbOJZsvzF4w+PXzpCoEzitA5sK3455R\n/C0u94+QDxnejLnxRVz6I3Tg+hfcwE5/px+l53hJHblj/m7SeRj8oRku94Jqgpdd\nNsdP7zLepbr/1T4QnTaYSD+GcGbD+k26Dykq7g7lPcQrJMilaQbV3ojjuu5GBsk4\nutTwI71lUwiib56EZek95qUHDvAA9IbReMn+/El6OrtT2uvp2XrqMCyw+2mSEt5E\nZtXClyNP5VtdFaH5a+ghepre+P3T66MP8VoDKAdFlAQ8ZvLWLKd4kqzUy0i76tSW\nTyINBRx/UZdk"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "umbc.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://webauth.umbc.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://webauth.umbc.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://webauth.umbc.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://webauth.umbc.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://webauth.umbc.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://webauth.umbc.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "umbc.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://wiki.umbc.edu/display/MW/Shibboleth+Identity+Provider"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Maryland Baltimore County"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The University of Maryland Baltimore County IdP enables standards-based federation for the UMBC community."
                  }
                ],
                "logo": [
                  {
                    "text": "https://webauth.umbc.edu/umbclogo.png",
                    "lang": "en",
                    "height": "133",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "345"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.umbc.edu/policies/pdfs/x-1.00.06%20web%20site%20privacy%20statement.pdf"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDNTCCAh2gAwIBAgIJAMBfbssnE/opMA0GCSqGSIb3DQEBBAUAMBsxGTAXBgNV\nBAMTEHdlYmF1dGgudW1iYy5lZHUwHhcNMTExMTIxMjEwOTAyWhcNMjExMTE4MjEw\nOTAyWjAbMRkwFwYDVQQDExB3ZWJhdXRoLnVtYmMuZWR1MIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEA8pneHoaFwkaenWXUuoP/Cp2Mf+KNdy7TegsTiC18\nyHMcGQ3sdzztAGicjqNf4N8wqSH9Ysqug72eHpopJbN+Rz9rmqUCujh8fzUgDb6G\ncyH0YpCt2sXDbjHxEzDyq/Acr7J0Q65DJUuqQPEm8WLyZhtT/trGLTM/UYFGIi16\nuYsM+N/GloqhznjcEQ1hEa9Vg5fZ3jl+VbEtzxMsCmou0LkFC+0xaMukPzAkhbeP\nKJG15OhuFFMdIS8oKBop45s7iOAc7CaDGE+1kkULCQzH/kB4K2bjDfyyE9TEMqy7\nWtIjyYUKGil3F1F85kzbQZSG+sVS5QDlGlvLhBnP3WTJIwIDAQABo3wwejAdBgNV\nHQ4EFgQUtGEIa05oxIWEnljb5yVlRL+GkMcwSwYDVR0jBEQwQoAUtGEIa05oxIWE\nnljb5yVlRL+GkMehH6QdMBsxGTAXBgNVBAMTEHdlYmF1dGgudW1iYy5lZHWCCQDA\nX27LJxP6KTAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBAUAA4IBAQAjPscifXwc\nOms0MgBdgCdf6MtIELBoB2tmcpJ6ugVELMbOJZsvzF4w+PXzpCoEzitA5sK3455R\n/C0u94+QDxnejLnxRVz6I3Tg+hfcwE5/px+l53hJHblj/m7SeRj8oRku94Jqgpdd\nNsdP7zLepbr/1T4QnTaYSD+GcGbD+k26Dykq7g7lPcQrJMilaQbV3ojjuu5GBsk4\nutTwI71lUwiib56EZek95qUHDvAA9IbReMn+/El6OrtT2uvp2XrqMCyw+2mSEt5E\nZtXClyNP5VtdFaH5a+ghepre+P3T66MP8VoDKAdFlAQ8ZvLWLKd4kqzUy0i76tSW\nTyINBRx/UZdk"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://webauth.umbc.edu:443/shib_error_page.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Maryland Baltimore County"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.umbc.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Maryland Baltimore County"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.oar.net/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mbeadles@oar.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Mark Beadles"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "support@oar.net"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "OARnet Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "edmonds@oh-tech.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Alan Edmonds"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "msoter@oh-tech.org"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Matthew Soter"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.oar.net/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.oar.net:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.oar.net:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAMDIykk/faIk0RTovrokYZYWeLfSMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2lkcC5vYXIubmV0MB4XDTExMDkxNTE2MTYwOVoXDTMx\nMDkxNTE2MTYwOVowFjEUMBIGA1UEAxMLaWRwLm9hci5uZXQwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDPevvM8XlI02Ts4elPWfp9oE/16BQR+YfcoX1n\nqbWOu2D3NCVNhz/AyqFWo/hKA9LewgXdwBcf9xKVsG+KvMtdVEPu1UAOL/wXFztC\nITMGup3ZIAYzDNYz1UIVUJtdVy8fL6bfsGJxS4Fj6SJKdZi+KWH6kkmrTQOD9/3R\nvTbXtBV5T/lY+5iD9vdP3CN+mfcYe9NSTY1VpYfUPsF/4Rvz7AcuO+zJO4VxTnpj\nqjfREamPozYGF1vR5PXqMU0OWZ8i41fk75h80CtIomEj0pyBIdkg0IYDvTQFDgUh\nLtJJeo+2CtiuNvVGo+62xhktFzcSV3ecyhdDW7g5NswxxNYtAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2lkcC5vYXIubmV0hiJodHRwczovL2lkcC5vYXIubmV0L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBQ21xrbK7nRgX3S+6TWCpKWdI0LLDANBgkqhkiG\n9w0BAQUFAAOCAQEArAa7xs5klJmi4D5iMxj0qEU6kh8Kdk+FtYaAfsOAlzJXOoko\n5rECg6LB4BLT0n1f5EJTg9OafVXdcY0kRDFC2T5CBi/+HiZKf9zTdNJD+/x934/I\nnJdLaoxls9bDv79KxBPtZv1ThiWshGKRD69EZAG9gPTBzV50GMk1JwpYhKBLrsOb\nxm5skvrLDBVtpf7/G/S4oSHtdN1hnXOW6WGmaqnlzPpoF6bGMXMRbW0JsZXH07HO\n2z9hWgIOvL9bjEeEct7yOgbzwWZrHSvPDVHYoSyk+G1+RyL+yokUWMRaZ9YXG8ts\nnsG1QgdEewDOGQVbtLzDHtk+EBCJu03zYZHgoQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oar.net"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.oar.net/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.oar.net/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.oar.net/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.oar.net/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.oar.net:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.oar.net:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "oar.net"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://iamohio.net/content/oh_tech_web_identity_services"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ohio Technology Consortium (OH-TECH)"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "InCommon Federation Identity Provider for the Ohio Technology Consortium, an activity of the Ohio Board of Regents."
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.oar.net/images/full_logo.png",
                    "lang": "en",
                    "height": "149",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "353"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://ohio.gov/policies/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDGDCCAgCgAwIBAgIVAMDIykk/faIk0RTovrokYZYWeLfSMA0GCSqGSIb3DQEB\nBQUAMBYxFDASBgNVBAMTC2lkcC5vYXIubmV0MB4XDTExMDkxNTE2MTYwOVoXDTMx\nMDkxNTE2MTYwOVowFjEUMBIGA1UEAxMLaWRwLm9hci5uZXQwggEiMA0GCSqGSIb3\nDQEBAQUAA4IBDwAwggEKAoIBAQDPevvM8XlI02Ts4elPWfp9oE/16BQR+YfcoX1n\nqbWOu2D3NCVNhz/AyqFWo/hKA9LewgXdwBcf9xKVsG+KvMtdVEPu1UAOL/wXFztC\nITMGup3ZIAYzDNYz1UIVUJtdVy8fL6bfsGJxS4Fj6SJKdZi+KWH6kkmrTQOD9/3R\nvTbXtBV5T/lY+5iD9vdP3CN+mfcYe9NSTY1VpYfUPsF/4Rvz7AcuO+zJO4VxTnpj\nqjfREamPozYGF1vR5PXqMU0OWZ8i41fk75h80CtIomEj0pyBIdkg0IYDvTQFDgUh\nLtJJeo+2CtiuNvVGo+62xhktFzcSV3ecyhdDW7g5NswxxNYtAgMBAAGjXTBbMDoG\nA1UdEQQzMDGCC2lkcC5vYXIubmV0hiJodHRwczovL2lkcC5vYXIubmV0L2lkcC9z\naGliYm9sZXRoMB0GA1UdDgQWBBQ21xrbK7nRgX3S+6TWCpKWdI0LLDANBgkqhkiG\n9w0BAQUFAAOCAQEArAa7xs5klJmi4D5iMxj0qEU6kh8Kdk+FtYaAfsOAlzJXOoko\n5rECg6LB4BLT0n1f5EJTg9OafVXdcY0kRDFC2T5CBi/+HiZKf9zTdNJD+/x934/I\nnJdLaoxls9bDv79KxBPtZv1ThiWshGKRD69EZAG9gPTBzV50GMk1JwpYhKBLrsOb\nxm5skvrLDBVtpf7/G/S4oSHtdN1hnXOW6WGmaqnlzPpoF6bGMXMRbW0JsZXH07HO\n2z9hWgIOvL9bjEeEct7yOgbzwWZrHSvPDVHYoSyk+G1+RyL+yokUWMRaZ9YXG8ts\nnsG1QgdEewDOGQVbtLzDHtk+EBCJu03zYZHgoQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://idp.oar.net/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ohio Technology Consortium (OH-TECH)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://oh-tech.org/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ohio Technology Consortium (\"OH-TECH\")"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://federation.sciences-po.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "prs@sciences-po.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federation.sciences-po.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2009-06-26T17:55:00Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.sciences-po.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federation.sciences-po.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://federation.sciences-po.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sciences-po.fr"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sciences-po.org"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sciencespo.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.sciences-po.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sciences Po Paris"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Sciences Po Paris"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVAPSayRf4eNPJKhqMWVppnJInJ6XeMA0GCSqGSIb3DQEB\nBQUAMCQxIjAgBgNVBAMTGWZlZGVyYXRpb24uc2NpZW5jZXMtcG8uZnIwHhcNMDkx\nMTA5MTcwMjM1WhcNMjkxMTA5MTcwMjM1WjAkMSIwIAYDVQQDExlmZWRlcmF0aW9u\nLnNjaWVuY2VzLXBvLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\n3uIR9QwANsZZFf0MAGhbhYdMLZRGMijmIN2T/s/dxsQyYDybx7cfQMctEvsWP1NR\ndMEZ6rNR0wD3uyLI3DZUCoezeHkyY/s1vPqeJFIlzoaQvzR5uVm2Is37gqGEDTKs\n/M0tCLiXiTZQkxaOxq+HXypNrhUTw2EkXuhomk8LD6sRdAzaKpxGatqkfwByGUXS\nSkTJqeV0eX5BmC32WPG/vtWqaKUM7H+OjJ/QRQrbfir2znW3Wf4aAAkppJtnvtYY\nZkUiOjvziKNlbvwI4GyDiDfl5oGvP5JHIzy4vPBCdLW1JBZhnnOnLv7+nca/g9Ke\nRlmoOOR2VGqwkAzmwm+83wIDAQABo3kwdzBWBgNVHREETzBNghlmZWRlcmF0aW9u\nLnNjaWVuY2VzLXBvLmZyhjBodHRwczovL2ZlZGVyYXRpb24uc2NpZW5jZXMtcG8u\nZnIvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFAFHMcFjXGUqoshwWJhBzgyBC4zL\nMA0GCSqGSIb3DQEBBQUAA4IBAQDKpWas1Dj9IjKV3yYvTDsxGeZ2uFa1WGo5iKdV\n+1US2VwADvq7896oRvLDWCpQmh04X6wNee1T6HgHBLsvnFv9PlAjqRmC0likrtet\nmEf2+tD06zwxnJFj8EwwPTRGXKU5z6vq5QUQtKckCfZTf7W+LhBOd3Oi7/GFHyea\np8xY8/Xkx+nxiEJk5IPN1oboKWe0b7Liy7ZowGCXqRsWcFf41APBmzxvqiXGuTem\nYLbweS7USGQdYgrw8ZYIBgH59pVjdPORwc8c0tCr9jwAavYehWEDd1Hs8S/rma+Q\njuXUI4qWzUOgFDOh1MiSBezPFp1576XseU8Hiw1T7QZIAhgK"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUDCCAjigAwIBAgIVALYXRzpnlr2ss74It/kPDT1kzxV4MA0GCSqGSIb3DQEB\nBQUAMCQxIjAgBgNVBAMTGWZlZGVyYXRpb24uc2NpZW5jZXMtcG8uZnIwHhcNMDkw\nNjE5MDk1MTM3WhcNMjkwNjE5MDk1MTM3WjAkMSIwIAYDVQQDExlmZWRlcmF0aW9u\nLnNjaWVuY2VzLXBvLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA\ns1g13BW6C5N7THGGpG7yk4HoX1kjbFjPYihbslRlGYSm2zccvivUkf5dENcIqfE6\nqPT3D7uYqvrkeYcELXJ38BiHrtAmuzW3ss9gO/01g+uBjZDaXRguDG3qPz4fgxDl\nSbuahErVw5m7U7l388P/7veoBeaWzFx/eJeTX/hfIHvHa9I0kvnVUfS+D74WQ5vJ\nRjcF4nTL2g2vBQb+aytlC9PHid90ptvG2R9/WPCqz4vwUJVgIgemeJiUsQfOrnj2\n6LkYCg4hd0WAV+fAaH25fE9ggu6iBqJcUfeyQ/mP3pJB00pE6dNjc5QfpXmFA/j7\njBC9mfHbBQ7KXIjdepwehQIDAQABo3kwdzBWBgNVHREETzBNghlmZWRlcmF0aW9u\nLnNjaWVuY2VzLXBvLmZyhjBodHRwczovL2ZlZGVyYXRpb24uc2NpZW5jZXMtcG8u\nZnIvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFNuAcsGNTTS7GMoor6NWV6kgG2ys\nMA0GCSqGSIb3DQEBBQUAA4IBAQBJcsldsyHR5MGPmkwziCuf3sM2PwzCa40/Mu3H\nNBbieS8YpQQQNaXsdct1xTCFjkS/gqNRsfd/ngelulZ4xD66h3oVbP1p03t0y3It\nD+x9X+p9S3TCld38H14x51zV3xPRf/fPDQen6bJ5VH7nqg9d7nnuyC1FLDkW6Eql\nHTcgCpmWplZnMsMkTqnvi5davtUgK2IxXvhzhN+pLdPxHELoMN4y4oyxnpRxs3A7\ntKczTo9NPfV3G9zLwdktz35HRkF7mBfBGdZbJYHJZibHALTxeqXtFzkC+FK0R0hM\nRCOmYdr+xspPrnyaTVp1P2oNrHXtLHlWmLvtyoKzr0lGAMA8"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Sciences Po Paris"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sciences-po.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Sciences Po Paris"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.emeraldinsight.com/entity",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wood"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rwood@emeraldinsight.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rob"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Parkin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lparkin@emeraldinsight.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Laurence"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.emeraldinsight.com/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2009-05-28T12:31:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Emerald Live Site"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.emeraldinsight.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Emerald Group Publishing Ltd"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.emeraldinsight.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.emeraldinsight.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.emeraldinsight.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.emeraldinsight.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "1",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/DS/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/DS/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/DS/Kalmar2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/DS/Kalmar2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "2"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/DS/Wayf",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/DS/Wayf",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "3"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/WAYF/UKFederation",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/WAYF/dfn",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/WAYF/dfn",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "4"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/TestShib",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/wayf-test",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/dfn-test",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/dfn-test2",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/WAYF/dfn-test",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/WAYF/dfn-test",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "5"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/abu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/asc",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/aru",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/asu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/bsu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/bmu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/blc",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/bfc",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/brc",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/bru",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/bnu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/cac",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/chc",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/cmj",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/cru",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/dmu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/doc",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/enu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/icl",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/kiu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/lsbu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/mmu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/nec",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/ncn",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/nrc",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/nou",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/ntu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/qmu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/qmul",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/rgu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/rou",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/shu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/ssu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/shu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/tvu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/uls",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/umi",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/urhb",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/uab",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/uad",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/ube",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/ubi",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/ubr",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/ubri",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/uco",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/ucu",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/ugl",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/uglo",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/ulo",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/uma",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/unut",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/uno",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/upo",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/ure",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/uso",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/usa",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/ust",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/ustr",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/ute",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/ual",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/uwi",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/uwne",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/uwtsd",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/uwa",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/uwe",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/uyo",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/wac",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/wel",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.emeraldinsight.com/Shibboleth.sso/auth/wcc",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.emeraldinsight.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUTCCAjmgAwIBAgIJANuHp/m5TCXsMA0GCSqGSIb3DQEBBQUAMCwxKjAoBgNV\n\t\t\t\t\t\tBAMTIWVtLWwxLXJoLXN2cjAxLmVtZXJhbGRpbnNpZ2h0LmNvbTAeFw0xMTA4MTEw\n\t\t\t\t\t\tODM1MTJaFw0yMTA4MDgwODM1MTJaMCwxKjAoBgNVBAMTIWVtLWwxLXJoLXN2cjAx\n\t\t\t\t\t\tLmVtZXJhbGRpbnNpZ2h0LmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC\n\t\t\t\t\t\tggEBAL7nJHjWMmZxHtjdwAYdXKCZwObQn8nDKWS71kULyYRgcxkVxULE+Q8sazuA\n\t\t\t\t\t\t0bsX3Q4PQUeP6C+xuyBXzHi9XZy6Ef4hoIHo6p9qI7EboB7Qu1MebGROWca0Dtd9\n\t\t\t\t\t\tzyadDe4y61J8BlE5euVCvbpGkHSSuFVvz0ThhTdC61vAPzvl71R5sqWxUm8xIPDT\n\t\t\t\t\t\t0TryzRgOA0LsOH3tXsaxQ5Jb5d6G+X6+6K2flFCY8QKbrnxcMKXvTbPpMprTIa1N\n\t\t\t\t\t\tbUT+XFONWmplOvyjHQH1GdIDQCPKc4aT3WyIA3MxnWfzpPsP8Sdi7Z+QyhXGEgOP\n\t\t\t\t\t\tobM+cagbqe/E/Om1gUgI3a6F/z0CAwEAAaN2MHQwUwYDVR0RBEwwSoIhZW0tbDEt\n\t\t\t\t\t\tcmgtc3ZyMDEuZW1lcmFsZGluc2lnaHQuY29thiVodHRwczovL3d3dy5lbWVyYWxk\n\t\t\t\t\t\taW5zaWdodC5jb20vZW50aXR5MB0GA1UdDgQWBBT8iPZbLVpj12PDMabI7c5IEAQ0\n\t\t\t\t\t\t+zANBgkqhkiG9w0BAQUFAAOCAQEAVMg4wyJ1FHeFYIuJ/zBzqPgZRD/dRQ/P64Bg\n\t\t\t\t\t\tlkM/XKtTEkDL5nizTdMcm5qUB8sSLUpZIyuPUSy8AmYZ+FgvU6SqjW1WIhRzlnYG\n\t\t\t\t\t\tyl3bKyl0Ji8r7We5lAhLgLnr1FTo3r9ROVd+S/BC3J7CZVE8Jcqo6AS66gTtGBja\n\t\t\t\t\t\txwoQYnowMJKcoCFqPkRlPL25ystxifcSpgaaRnVJMik/JHO2IwLLti+WAUj6kwCM\n\t\t\t\t\t\tuCbrLPgzpR6W8YOkDzUH3rvANVZ5GKgqWNA/u8NfC6WRcA1Sktx2nLnK8Mw3d14g\n\t\t\t\t\t\tMvgwMr/rwl/SPLLZ0KDGqJ8iSYjIZQKsJ/JXP9xmaeEQW6v35w=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.emeraldinsight.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.emeraldinsight.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.emeraldinsight.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.emeraldinsight.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.emeraldinsight.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://www.emeraldinsight.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.emeraldinsight.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.emeraldinsight.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.emeraldinsight.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.emeraldinsight.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://cafe.ufal.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Diogo Cabral de Almeida"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "diogo@nti.ufal.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://cafe.ufal.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDyDCCArACAQAwDQYJKoZIhvcNAQEFBQAwgakxLzAtBgNVBAoTJlVGQUwgLSBV\nbml2ZXJzaWRhZGUgRmVkZXJhbCBkZSBBbGFnb2FzMQwwCgYDVQQLEwNOVEkxIDAe\nBgkqhkiG9w0BCQEWEWRpb2dvQG50aS51ZmFsLmJyMRAwDgYDVQQHFAdNYWNlacOz\nMRAwDgYDVQQIEwdBbGFnb2FzMQswCQYDVQQGEwJCUjEVMBMGA1UEAxMMY2FmZS51\nZmFsLmJyMB4XDTE0MTAwNjIwNTEzOVoXDTE3MTAwNTIwNTEzOVowgakxLzAtBgNV\nBAoTJlVGQUwgLSBVbml2ZXJzaWRhZGUgRmVkZXJhbCBkZSBBbGFnb2FzMQwwCgYD\nVQQLEwNOVEkxIDAeBgkqhkiG9w0BCQEWEWRpb2dvQG50aS51ZmFsLmJyMRAwDgYD\nVQQHFAdNYWNlacOzMRAwDgYDVQQIEwdBbGFnb2FzMQswCQYDVQQGEwJCUjEVMBMG\nA1UEAxMMY2FmZS51ZmFsLmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAvwzH1otQwbdbx7uHECItOI3sAiO9DWNc9mzRRyNrY0t7Xx7xoiblHagjDM/9\nI+pxiJ33ETOdGyr0PGgbZCPccUdUz6Zif5j6g9ioTIg2GUBaH8xU0rJdZF2A3eLn\nZ3s8CzCtYK7gHJhiFfhKWUAyWVCV6wZS46+Iu1Y2g4j3/WnSJA4/65UEtQ40UDFT\nYJclb8X4RHcBXlE39T6RcSUDQWFdEsxunpc3twR5M7adK2oZ4ekQr3zIA64bEahy\nT2XuKNTOuEKtkFG1oRFG1dkhfO5IcYDOCAjd6IPaq0l4r3pqBDSxilriVsb2hLUW\ndKtsnDDdpvhWasb7oqMQTW8/NQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQB0poIt\nL7OtIong6o5UdfsFQ/+Pw3LnIPsRXL39191AsSs8PMuVyDd32ngRLjij5fbeWNl6\nWxFh/OfVJJEzLlWylm8NhTQvxQZVLHKni1szVOYOMM7yFVzOoWrTB3eMD8ujJFs1\n1gG6NFum+liNs8R5b2HVgD4eUzK3Z1E1GPTztbA3MzApmmgZ4egDP+BGVZVcmGZv\nBWhIsbMNn/8HHvCtuhefamMfhoqm128bRzWvOcFvXVvv12Bd8hQqvKvI8ukvbfyq\nFqecVU8Rc3XGPdRjnSmC57zvq4iLH4ZJJFJNW2I06mnu2PdBzGe0GcrhsgjijQOI\nPvRE/EdtraBT9cvB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufal.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.ufal.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.ufal.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://cafe.ufal.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://cafe.ufal.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://cafe.ufal.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://cafe.ufal.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://cafe.ufal.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://cafe.ufal.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ufal.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ufal.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ufal.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFAL - Universidade Federal de Alagoas"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UFAL - Universidade Federal de Alagoas"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFAL - Universidade Federal de Alagoas"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UFAL - Universidade Federal de Alagoas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDyDCCArACAQAwDQYJKoZIhvcNAQEFBQAwgakxLzAtBgNVBAoTJlVGQUwgLSBV\nbml2ZXJzaWRhZGUgRmVkZXJhbCBkZSBBbGFnb2FzMQwwCgYDVQQLEwNOVEkxIDAe\nBgkqhkiG9w0BCQEWEWRpb2dvQG50aS51ZmFsLmJyMRAwDgYDVQQHFAdNYWNlacOz\nMRAwDgYDVQQIEwdBbGFnb2FzMQswCQYDVQQGEwJCUjEVMBMGA1UEAxMMY2FmZS51\nZmFsLmJyMB4XDTE0MTAwNjIwNTEzOVoXDTE3MTAwNTIwNTEzOVowgakxLzAtBgNV\nBAoTJlVGQUwgLSBVbml2ZXJzaWRhZGUgRmVkZXJhbCBkZSBBbGFnb2FzMQwwCgYD\nVQQLEwNOVEkxIDAeBgkqhkiG9w0BCQEWEWRpb2dvQG50aS51ZmFsLmJyMRAwDgYD\nVQQHFAdNYWNlacOzMRAwDgYDVQQIEwdBbGFnb2FzMQswCQYDVQQGEwJCUjEVMBMG\nA1UEAxMMY2FmZS51ZmFsLmJyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAvwzH1otQwbdbx7uHECItOI3sAiO9DWNc9mzRRyNrY0t7Xx7xoiblHagjDM/9\nI+pxiJ33ETOdGyr0PGgbZCPccUdUz6Zif5j6g9ioTIg2GUBaH8xU0rJdZF2A3eLn\nZ3s8CzCtYK7gHJhiFfhKWUAyWVCV6wZS46+Iu1Y2g4j3/WnSJA4/65UEtQ40UDFT\nYJclb8X4RHcBXlE39T6RcSUDQWFdEsxunpc3twR5M7adK2oZ4ekQr3zIA64bEahy\nT2XuKNTOuEKtkFG1oRFG1dkhfO5IcYDOCAjd6IPaq0l4r3pqBDSxilriVsb2hLUW\ndKtsnDDdpvhWasb7oqMQTW8/NQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQB0poIt\nL7OtIong6o5UdfsFQ/+Pw3LnIPsRXL39191AsSs8PMuVyDd32ngRLjij5fbeWNl6\nWxFh/OfVJJEzLlWylm8NhTQvxQZVLHKni1szVOYOMM7yFVzOoWrTB3eMD8ujJFs1\n1gG6NFum+liNs8R5b2HVgD4eUzK3Z1E1GPTztbA3MzApmmgZ4egDP+BGVZVcmGZv\nBWhIsbMNn/8HHvCtuhefamMfhoqm128bRzWvOcFvXVvv12Bd8hQqvKvI8ukvbfyq\nFqecVU8Rc3XGPdRjnSmC57zvq4iLH4ZJJFJNW2I06mnu2PdBzGe0GcrhsgjijQOI\nPvRE/EdtraBT9cvB"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFAL - Universidade Federal de Alagoas"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UFAL - Universidade Federal de Alagoas"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.ufal.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://www.ufal.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFAL - Universidade Federal de Alagoas"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UFAL - Universidade Federal de Alagoas"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://federation.ac-strasbourg.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Equipe Infrastructures"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "idp@ac-strasbourg.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://federation.ac-strasbourg.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2015-05-19T17:24:01Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://federation.ac-strasbourg.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://federation.ac-strasbourg.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://federation.ac-strasbourg.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ac-strasbourg.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ac-strasbourg.fr"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Rectorat de Strasbourg - federation.ac-strasbourg.fr"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Rectorat de Strasbourg - federation.ac-strasbourg.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rectorat de Strasbourg"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Rectorat de Strasbourg"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDVzCCAj+gAwIBAgIULlCyoAcZI1HxSV9f9eQvrbmdBYswDQYJKoZIhvcNAQEF\nBQAwJjEkMCIGA1UEAwwbZmVkZXJhdGlvbi5hYy1zdHJhc2JvdXJnLmZyMB4XDTE1\nMDUyMDA5MjA1MloXDTM1MDUyMDA5MjA1MlowJjEkMCIGA1UEAwwbZmVkZXJhdGlv\nbi5hYy1zdHJhc2JvdXJnLmZyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC\nAQEAhcao293f12SLrge+tM0jp4KWGfpR8PpGFcqgtyIO+o14cmrvCzXaCnMxIZrW\nXELpU6cg0NVYSkW3ECab3TQwCOLjRe/rQjFy/DrOXSMTZv1gv+H5f6bItEfsQXLF\n60gG/P+xvQVZeUMONq96DZdiUO5q81vQQE9li7Vc/DB11aTUFFcc8IVWe4MAmtBw\nboVb24xv/J9T9N5rsXHLfvUwqIKB87ULl4LEja6eNnKBCi1VR/kD1asZCip7r6SJ\nRFYDUni3NNJB6Lt+eGjxQxmXTR8CiEW80UyrvfkNI+mkuza1RzGugDD6yuRE9Sxc\nN6WkBC72JO2o6L0FK2p4Xmg97wIDAQABo30wezAdBgNVHQ4EFgQUrFJ5ZGA8dmDW\nBM9QyEUPnSFehaowWgYDVR0RBFMwUYIbZmVkZXJhdGlvbi5hYy1zdHJhc2JvdXJn\nLmZyhjJodHRwczovL2ZlZGVyYXRpb24uYWMtc3RyYXNib3VyZy5mci9pZHAvc2hp\nYmJvbGV0aDANBgkqhkiG9w0BAQUFAAOCAQEANKeYwcZkLwQdMoI+N1HGbjaveP3e\nc125LM3ld8vBUvLOjFEz2g+MbF+jMWAWY5DXoppOc0at6/TZYgfGvee3bPh2yp9j\ncNeHOhnl5DbC7R2cmnKmNkjWHQQzTMWPNWk6aTkHvAnkNK1CzznG8E2mYxcvFIMC\nDWZztDybb/yrC7h+ZnOueklkpS++ukQ4aRmZn+4ubt0JsykFC4HEwJIXCunR1+Dn\nt+li2DFtfZBGRZT0sHiadFDVzKX6Cau/wbgJpqg1nVj0pzaYjm2aeagbgTOq7Huf\nIPwBlW0WM1jfpoYm5KZjJgGBEzQL19k+CM8uBkdlCzgbjvMx+aNDdnMmvA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Rectorat de Strasbourg"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ac-strasbourg.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Rectorat de Strasbourg"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.resultat.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.resultat.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.resultat.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.resultat.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.resultat.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.resultat.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.resultat.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.resultat.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.resultat.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.resultat.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.resultat.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.resultat.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.resultat.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.resultat.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIJAPni8OuyG190MA0GCSqGSIb3DQEBBQUAMCAxHjAcBgNV\nBAMTFXd3dy5yZXN1bHRhdC5sYWRvay5zZTAeFw0xNTA5MzAxMjA3MzRaFw0yNTA5\nMjcxMjA3MzRaMCAxHjAcBgNVBAMTFXd3dy5yZXN1bHRhdC5sYWRvay5zZTCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKVFj8gNqkrF6BA42AiDa6JxAWeB\nDj/RRp2ZzKzYBYoF+ynjnoeAyoZ5UUg/UdK6IHwzAATgVawEDrldO+3aOZHxj6Rp\n4ToXP0HR3wAihuVNEw5Vcak5scMnuL27NxfMjyNcd5rgD5p9IQVXb+yyv8iVJELD\nEHczCIcySG7HQawS4aWulQ1VZ4nBm6AGZKMJeowkMlDm5aefMVYIMMHvzCtubJvA\nfbxL+FJl2eBIftO5Q8P+Jp9aEdKaQBJdPXCBsUX6jz+evgJNGm+bk96ULF5cqqU/\nLyEIhrqR/JCyN9u8QWFBFoPCeI0LblC5z7pxUeRnb3jzI7WNg1KC7hp8I/UCAwEA\nAaNpMGcwRgYDVR0RBD8wPYIVd3d3LnJlc3VsdGF0LmxhZG9rLnNlhiRodHRwczov\nL3d3dy5yZXN1bHRhdC5sYWRvay5zZS9ndWktc3AwHQYDVR0OBBYEFHVLPL17MicY\nU8hBzr8VKSAjfJ8EMA0GCSqGSIb3DQEBBQUAA4IBAQAWoXwGDt0yz/UUrddHaZAY\nMb2Ofk4nM1bEfa+NreWqfjFpNNzyXjRQ4kYjtUd3Qfn73UNyTjVHKsoKlIqtGMwG\nNOPqv4r3fDH8w5CyhgInQZ5bei8jmzXrC/8PlbhvDD4Ds1U1v2wZ2Xljm+30qORy\nxtBRtC+nbbUoPiy/xDonEizxBo6ho29lprWmvD1aIz5aPXwEQx5CD6wQu296e/XV\nXCjg7IKlblggNW0tW2WjGTj4zqlOfbY02mKFaZqhsKujYv8bq98sKyPc8Da8MiVj\n5SMJ5hbFdZJP1u+yYTEXUuQm/M3GKq12Sayx3xspzGln2ecQJ+pMpYCfrU+zBOyn"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.resultat.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.resultat.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.resultat.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.resultat.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.resultat.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.resultat.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.resultat.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.resultat.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.resultat.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.resultat.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.essingtoncc.co.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Morris"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:andy@essingtoncc.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Morris"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:andy@essingtoncc.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.essingtoncc.co.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_instant": "2012-05-21T15:59:21Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0jCCAroCCQCGyNfhukfamTANBgkqhkiG9w0BAQUFADCBqjELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFjAUBgNVBAgMDVN0YWZmb3Jkc2hpcmUxEjAQBgNVBAcMCUVzc2luZ3RvbjEr\n\t\t\t\t\t\tMCkGA1UECgwiRXNzaW5ndG9uIENvbXB1dGVyIENvbnN1bHRhbmN5IEx0ZDEeMBwG\n\t\t\t\t\t\tA1UEAwwVaWRwLmVzc2luZ3RvbmNjLmNvLnVrMSIwIAYJKoZIhvcNAQkBFhNzdXBw\n\t\t\t\t\t\tb3J0QGFnbTE5NjAuY29tMB4XDTE0MDUwMjEzNDk0N1oXDTI0MDQyOTEzNDk0N1ow\n\t\t\t\t\t\tgaoxCzAJBgNVBAYTAkdCMRYwFAYDVQQIDA1TdGFmZm9yZHNoaXJlMRIwEAYDVQQH\n\t\t\t\t\t\tDAlFc3Npbmd0b24xKzApBgNVBAoMIkVzc2luZ3RvbiBDb21wdXRlciBDb25zdWx0\n\t\t\t\t\t\tYW5jeSBMdGQxHjAcBgNVBAMMFWlkcC5lc3Npbmd0b25jYy5jby51azEiMCAGCSqG\n\t\t\t\t\t\tSIb3DQEJARYTc3VwcG9ydEBhZ20xOTYwLmNvbTCCASIwDQYJKoZIhvcNAQEBBQAD\n\t\t\t\t\t\tggEPADCCAQoCggEBAMsPBbmhQnhaUeaTfJcOioEIyFDMOEvnKf1bAiFqa3CRw8mX\n\t\t\t\t\t\tQSFLhOofkLQppkdBgPN+i9kDqc+noa4QXw2gZxzePLiipjJ1oA50FNVhEUd86/cL\n\t\t\t\t\t\t8gGfrY0Xt0l9JtU7XWGQPAjVv0oAa5FDbEyWBsGkWekD1wxNd3jGDyGDn6/0sxm6\n\t\t\t\t\t\tjxVExyDp3mzX/v17xsAW+t9+hhvSh8yxSQj+IH9Un5AXq2sPOrya7JgSsHbJl6Ql\n\t\t\t\t\t\tmnCO12+bHz59F/GTdGtAvz2lQQ/QqVRG8QGqL6Q5xyM1AYq4RxJVRBza1t+LD4u0\n\t\t\t\t\t\t2yJSstGOWdC4O/T8yiNDQyQt3wOPTrMuBiGiDMcCAwEAATANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAPsofQ9oo0zDYNV8Yxo+S2xyRV5LqfpamWqclIZs3Mu1Yt4RkopnoiCfv\n\t\t\t\t\t\tRP/bb6h/hM+5LbCtcl/6HzYuPcJvs3kqKMbOXhVtqR6ad9PYH6gLr3wzaDDioYcC\n\t\t\t\t\t\t0LMvvhhUUfPFqbkNV7cH1+qRq1SHi9GXWeBeUISrm+gHXsu7CuoY5Cynv5u2ugv1\n\t\t\t\t\t\tGiv+wxW8FWn4kVV5g77tP/FphuHqeKEAesjOMS2b4MU8DB2ptzj5NfGEmcWpf3cU\n\t\t\t\t\t\tZKkmrie5td8TdkKkn8UyJbGsbLcv6fFbFTCh9V/n8uBUCJTT+CQpKDNmPKNuRxSW\n\t\t\t\t\t\tx1EIfHvBWWZhPjOeFVoyVrdxsAdnIA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "essingtoncc.co.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.essingtoncc.co.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.essingtoncc.co.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.essingtoncc.co.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.essingtoncc.co.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.essingtoncc.co.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.essingtoncc.co.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.essingtoncc.co.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.essingtoncc.co.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "essingtoncc.co.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID0jCCAroCCQCGyNfhukfamTANBgkqhkiG9w0BAQUFADCBqjELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxFjAUBgNVBAgMDVN0YWZmb3Jkc2hpcmUxEjAQBgNVBAcMCUVzc2luZ3RvbjEr\n\t\t\t\t\t\tMCkGA1UECgwiRXNzaW5ndG9uIENvbXB1dGVyIENvbnN1bHRhbmN5IEx0ZDEeMBwG\n\t\t\t\t\t\tA1UEAwwVaWRwLmVzc2luZ3RvbmNjLmNvLnVrMSIwIAYJKoZIhvcNAQkBFhNzdXBw\n\t\t\t\t\t\tb3J0QGFnbTE5NjAuY29tMB4XDTE0MDUwMjEzNDk0N1oXDTI0MDQyOTEzNDk0N1ow\n\t\t\t\t\t\tgaoxCzAJBgNVBAYTAkdCMRYwFAYDVQQIDA1TdGFmZm9yZHNoaXJlMRIwEAYDVQQH\n\t\t\t\t\t\tDAlFc3Npbmd0b24xKzApBgNVBAoMIkVzc2luZ3RvbiBDb21wdXRlciBDb25zdWx0\n\t\t\t\t\t\tYW5jeSBMdGQxHjAcBgNVBAMMFWlkcC5lc3Npbmd0b25jYy5jby51azEiMCAGCSqG\n\t\t\t\t\t\tSIb3DQEJARYTc3VwcG9ydEBhZ20xOTYwLmNvbTCCASIwDQYJKoZIhvcNAQEBBQAD\n\t\t\t\t\t\tggEPADCCAQoCggEBAMsPBbmhQnhaUeaTfJcOioEIyFDMOEvnKf1bAiFqa3CRw8mX\n\t\t\t\t\t\tQSFLhOofkLQppkdBgPN+i9kDqc+noa4QXw2gZxzePLiipjJ1oA50FNVhEUd86/cL\n\t\t\t\t\t\t8gGfrY0Xt0l9JtU7XWGQPAjVv0oAa5FDbEyWBsGkWekD1wxNd3jGDyGDn6/0sxm6\n\t\t\t\t\t\tjxVExyDp3mzX/v17xsAW+t9+hhvSh8yxSQj+IH9Un5AXq2sPOrya7JgSsHbJl6Ql\n\t\t\t\t\t\tmnCO12+bHz59F/GTdGtAvz2lQQ/QqVRG8QGqL6Q5xyM1AYq4RxJVRBza1t+LD4u0\n\t\t\t\t\t\t2yJSstGOWdC4O/T8yiNDQyQt3wOPTrMuBiGiDMcCAwEAATANBgkqhkiG9w0BAQUF\n\t\t\t\t\t\tAAOCAQEAPsofQ9oo0zDYNV8Yxo+S2xyRV5LqfpamWqclIZs3Mu1Yt4RkopnoiCfv\n\t\t\t\t\t\tRP/bb6h/hM+5LbCtcl/6HzYuPcJvs3kqKMbOXhVtqR6ad9PYH6gLr3wzaDDioYcC\n\t\t\t\t\t\t0LMvvhhUUfPFqbkNV7cH1+qRq1SHi9GXWeBeUISrm+gHXsu7CuoY5Cynv5u2ugv1\n\t\t\t\t\t\tGiv+wxW8FWn4kVV5g77tP/FphuHqeKEAesjOMS2b4MU8DB2ptzj5NfGEmcWpf3cU\n\t\t\t\t\t\tZKkmrie5td8TdkKkn8UyJbGsbLcv6fFbFTCh9V/n8uBUCJTT+CQpKDNmPKNuRxSW\n\t\t\t\t\t\tx1EIfHvBWWZhPjOeFVoyVrdxsAdnIA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Essington Computer Consultancy Test IdP"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.essingtoncc.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Essington Computer Consultancy Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.math.cas.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Van\u00ed\u010dek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vanicekp@utia.cas.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.math.cas.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2014-11-10T13:39:01Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/avcr"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAMI6h1I2Ucbuc9TH2mQ3pJfm1qhGMA0GCSqGSIb3DQEB\nBQUAMBoxGDAWBgNVBAMTD2lkcC5tYXRoLmNhcy5jejAeFw0xNDExMDcwOTE0MzRa\nFw0zNDExMDcwOTE0MzRaMBoxGDAWBgNVBAMTD2lkcC5tYXRoLmNhcy5jejCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL162cnXK9D8343uG82KuAbzVz1p\nsVYb++2LmIjoTV/zyG08zV+uFwcoZbRogE4FUTqCnQjRM0CVmQ83JGuuKy1WoVJ0\nfrmAdAPKK2JhF/K6BRVYDMbxl7hfA2UWN1j7lwBivxywaG4yG1yvinevWz/vkLKo\ny3V1k3xMDk41103KYjnZ7zJzREgtpBY9zfiw7MhbeM+I3HHVSo76dQPjdcfJALco\ny3vG7OlsCaS4qovEPu5JbmStjscmNNCCOv89hPah3DZsxGLfZ3olikCGO+rGXPwe\nkzAGKoKVVuxRGCSCf1ppZYVPD5c6I82aFCVuRLDM8O4qQ6Fab6mJ6/rY6ksCAwEA\nAaNlMGMwQgYDVR0RBDswOYIPaWRwLm1hdGguY2FzLmN6hiZodHRwczovL2lkcC5t\nYXRoLmNhcy5jei9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU8puHnxuPvVxmZuQq\n3xOdeo0vxjgwDQYJKoZIhvcNAQEFBQADggEBAJmSwgJ/MOxvBI9NK65zMHYp2tHi\nCyCxtPnGxL3+9A/2Lx0AuxLCYVKDgU0GNaDkIERIQeMm5DyModRgrkhyEplo1Yxw\naVw3qypUgmWyFx1gZb4zmp79E4AYGhCwWaRpczQsQMgs7w8QLHi9h+LZNo6hCR8w\nCP0e18qET2/sk6jb5d8xNV/KForfL7xWVDFhr4CGYZSfsaBtfmNDYf92XkAbxUrv\nSoTahRu2eTDuvcQSrsIy13GhlWj9D5fTUjeIx9y83wFfR5c1G2u9jWYyjHCP3BPV\n9BY8Bxf+cas1FfM8Ajg8fddlhBG/1/KJwXbjUWw9MNE3hdZQZ0WQ37yhIJs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "math.cas.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.math.cas.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.math.cas.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.math.cas.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.math.cas.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.math.cas.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.math.cas.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.math.cas.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.math.cas.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.math.cas.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.math.cas.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.math.cas.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "math.cas.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.math.cas.cz/index.php?lang=1"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.math.cas.cz/index.php?lang=0"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider MU AV CR employees."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance M\u00da AV \u010cR"
                  }
                ],
                "logo": [
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-math-44.png",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "44"
                  },
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-math-100.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of Mathematics AS CR"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Matematick\u00fd \u00fastav AV \u010cR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDKDCCAhCgAwIBAgIVAMI6h1I2Ucbuc9TH2mQ3pJfm1qhGMA0GCSqGSIb3DQEB\nBQUAMBoxGDAWBgNVBAMTD2lkcC5tYXRoLmNhcy5jejAeFw0xNDExMDcwOTE0MzRa\nFw0zNDExMDcwOTE0MzRaMBoxGDAWBgNVBAMTD2lkcC5tYXRoLmNhcy5jejCCASIw\nDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL162cnXK9D8343uG82KuAbzVz1p\nsVYb++2LmIjoTV/zyG08zV+uFwcoZbRogE4FUTqCnQjRM0CVmQ83JGuuKy1WoVJ0\nfrmAdAPKK2JhF/K6BRVYDMbxl7hfA2UWN1j7lwBivxywaG4yG1yvinevWz/vkLKo\ny3V1k3xMDk41103KYjnZ7zJzREgtpBY9zfiw7MhbeM+I3HHVSo76dQPjdcfJALco\ny3vG7OlsCaS4qovEPu5JbmStjscmNNCCOv89hPah3DZsxGLfZ3olikCGO+rGXPwe\nkzAGKoKVVuxRGCSCf1ppZYVPD5c6I82aFCVuRLDM8O4qQ6Fab6mJ6/rY6ksCAwEA\nAaNlMGMwQgYDVR0RBDswOYIPaWRwLm1hdGguY2FzLmN6hiZodHRwczovL2lkcC5t\nYXRoLmNhcy5jei9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU8puHnxuPvVxmZuQq\n3xOdeo0vxjgwDQYJKoZIhvcNAQEFBQADggEBAJmSwgJ/MOxvBI9NK65zMHYp2tHi\nCyCxtPnGxL3+9A/2Lx0AuxLCYVKDgU0GNaDkIERIQeMm5DyModRgrkhyEplo1Yxw\naVw3qypUgmWyFx1gZb4zmp79E4AYGhCwWaRpczQsQMgs7w8QLHi9h+LZNo6hCR8w\nCP0e18qET2/sk6jb5d8xNV/KForfL7xWVDFhr4CGYZSfsaBtfmNDYf92XkAbxUrv\nSoTahRu2eTDuvcQSrsIy13GhlWj9D5fTUjeIx9y83wFfR5c1G2u9jWYyjHCP3BPV\n9BY8Bxf+cas1FfM8Ajg8fddlhBG/1/KJwXbjUWw9MNE3hdZQZ0WQ37yhIJs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of Mathematics AS CR"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Matematick\u00fd \u00fastav AV \u010cR, v.v.i."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.math.cas.cz/index.php?lang=0"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.math.cas.cz/index.php?lang=1"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of Mathematics"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Matematick\u00fd \u00fastav"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idpuniba.uniba.it/simplesaml/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Administrator"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:staff@uniba.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idpuniba.uniba.it/simplesaml/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2014-10-20T22:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idpuniba.uniba.it/simplesaml/saml2/idp/SingleLogoutService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idpuniba.uniba.it/simplesaml/saml2/idp/SSOService.php",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uniba.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://idpuniba.uniba.it/info/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 degli Studi di Bari Aldo Moro"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Bari Aldo Moro"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo",
                "description": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti dell'Universit\u00e0 degli Studi di Bari Aldo Moro"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for the users of University of Bari Aldo Moro"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idpuniba.uniba.it/info/unibalogo.png",
                    "lang": "en",
                    "height": "80",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  },
                  {
                    "text": "https://idpuniba.uniba.it/info/unibalogo.png",
                    "lang": "it",
                    "height": "80",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "60"
                  },
                  {
                    "text": "https://idpuniba.uniba.it/info/unibalogo16x16.png",
                    "lang": "en",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "https://idpuniba.uniba.it/info/unibalogo16x16.png",
                    "lang": "it",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "https://idpuniba.uniba.it/info/"
                  }
                ]
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID7TCCAtWgAwIBAgIJANj5CumEPPiKMA0GCSqGSIb3DQEBBQUAMIGMMQswCQYD\nVQQGEwJJVDEOMAwGA1UECAwFSXRhbHkxDTALBgNVBAcMBEJhcmkxDjAMBgNVBAoM\nBVVuaUJhMRMwEQYDVQQLDApDU0ktQ2FtcHVzMRowGAYDVQQDDBFpZHB1bmliYS51\nbmliYS5pdDEdMBsGCSqGSIb3DQEJARYOc3RhZmZAdW5pYmEuaXQwHhcNMTQwNDAz\nMTQzMjQwWhcNNDQwMzI2MTQzMjQwWjCBjDELMAkGA1UEBhMCSVQxDjAMBgNVBAgM\nBUl0YWx5MQ0wCwYDVQQHDARCYXJpMQ4wDAYDVQQKDAVVbmlCYTETMBEGA1UECwwK\nQ1NJLUNhbXB1czEaMBgGA1UEAwwRaWRwdW5pYmEudW5pYmEuaXQxHTAbBgkqhkiG\n9w0BCQEWDnN0YWZmQHVuaWJhLml0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\nCgKCAQEA2ybitm1sRZ5QF6IXsrh1V1EnuRT5fp3MZdev4WVv5hE/5q/XbRSGSY/v\neKuQCv2a1yNGd6fwK5lkG0kD8tFoSxfMTz9farfWPpNywhTgvXeMp8nRvzXIJKrw\nT/z34a8CgcXRU19pv6Sd4YgD7Wc/2MP7Uaxp7CCtzYHQ3SOdcWj486spHHdwbMo4\nOjw9bdZTxkB4XyBVcZ3y5S5P+j/4lsOSSAzKisSCoXm16T+YqZDSZFhwQMdtZTEx\nr2q26MKIqpPzLJMkt0cl/4pHu5olwQ3eTw7ZN/QkpuoXdIRSY5EeeQJyxq67A2ga\nP4KT3ksUKNHobBrPOkaODpnKtiSnJwIDAQABo1AwTjAdBgNVHQ4EFgQU1kgTrmPx\naF3ULu8QcLg8kF82PXAwHwYDVR0jBBgwFoAU1kgTrmPxaF3ULu8QcLg8kF82PXAw\nDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAcDLZs+MHK89MVM7964gc\nmK1Rr/7CiKc/ZQ7Swr8+j0kxASSTDO4kJ/+p1VfXx2f2SymbPsJgRnJSE8OxRlbn\nVwD2vciIZhyxYyUGVE17drPvUFBJriNCYvS1Rj+wjO3TvHRrDuSm+ss/ygj0L9FG\n2lDz549x+WGCw3DAEiQHyGMf9i/zksTv5BPlxA/7UqQZIa/BFlqEp/EW3YgVu0+W\n9RBoub2eFvPOcllFQoB28Z5gPQRPBWZhA+Zc1UEvfwcXCo6g61WJgiqAGUYT1ov4\ncCuJJOAZD3rKrhRFexgmfSOP68YWTF0vVcsxPccDmYw5wtYiEV7ziUVV9QuMgM58\nkA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID7TCCAtWgAwIBAgIJANj5CumEPPiKMA0GCSqGSIb3DQEBBQUAMIGMMQswCQYD\nVQQGEwJJVDEOMAwGA1UECAwFSXRhbHkxDTALBgNVBAcMBEJhcmkxDjAMBgNVBAoM\nBVVuaUJhMRMwEQYDVQQLDApDU0ktQ2FtcHVzMRowGAYDVQQDDBFpZHB1bmliYS51\nbmliYS5pdDEdMBsGCSqGSIb3DQEJARYOc3RhZmZAdW5pYmEuaXQwHhcNMTQwNDAz\nMTQzMjQwWhcNNDQwMzI2MTQzMjQwWjCBjDELMAkGA1UEBhMCSVQxDjAMBgNVBAgM\nBUl0YWx5MQ0wCwYDVQQHDARCYXJpMQ4wDAYDVQQKDAVVbmlCYTETMBEGA1UECwwK\nQ1NJLUNhbXB1czEaMBgGA1UEAwwRaWRwdW5pYmEudW5pYmEuaXQxHTAbBgkqhkiG\n9w0BCQEWDnN0YWZmQHVuaWJhLml0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\nCgKCAQEA2ybitm1sRZ5QF6IXsrh1V1EnuRT5fp3MZdev4WVv5hE/5q/XbRSGSY/v\neKuQCv2a1yNGd6fwK5lkG0kD8tFoSxfMTz9farfWPpNywhTgvXeMp8nRvzXIJKrw\nT/z34a8CgcXRU19pv6Sd4YgD7Wc/2MP7Uaxp7CCtzYHQ3SOdcWj486spHHdwbMo4\nOjw9bdZTxkB4XyBVcZ3y5S5P+j/4lsOSSAzKisSCoXm16T+YqZDSZFhwQMdtZTEx\nr2q26MKIqpPzLJMkt0cl/4pHu5olwQ3eTw7ZN/QkpuoXdIRSY5EeeQJyxq67A2ga\nP4KT3ksUKNHobBrPOkaODpnKtiSnJwIDAQABo1AwTjAdBgNVHQ4EFgQU1kgTrmPx\naF3ULu8QcLg8kF82PXAwHwYDVR0jBBgwFoAU1kgTrmPxaF3ULu8QcLg8kF82PXAw\nDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQUFAAOCAQEAcDLZs+MHK89MVM7964gc\nmK1Rr/7CiKc/ZQ7Swr8+j0kxASSTDO4kJ/+p1VfXx2f2SymbPsJgRnJSE8OxRlbn\nVwD2vciIZhyxYyUGVE17drPvUFBJriNCYvS1Rj+wjO3TvHRrDuSm+ss/ygj0L9FG\n2lDz549x+WGCw3DAEiQHyGMf9i/zksTv5BPlxA/7UqQZIa/BFlqEp/EW3YgVu0+W\n9RBoub2eFvPOcllFQoB28Z5gPQRPBWZhA+Zc1UEvfwcXCo6g61WJgiqAGUYT1ov4\ncCuJJOAZD3rKrhRFexgmfSOP68YWTF0vVcsxPccDmYw5wtYiEV7ziUVV9QuMgM58\nkA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 degli Studi di Bari Aldo Moro"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Bari Aldo Moro"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uniba.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uniba.it/english-version"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 degli Studi di Bari Aldo Moro"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Bari Aldo Moro"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://www.ohsu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "hyded@ohsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Denny Hyde"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vanderhe@ohsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Sean Vanderheiden"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.ohsu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ohsu.edu/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://www.ohsu.edu/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAKiKGs+N1BpUHsMJYEAJU0TUP6QMMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDHd3dy5vaHN1LmVkdTAeFw0wOTExMTcyMjUwNTJaFw0y\nOTExMTcyMjUwNTJaMBcxFTATBgNVBAMTDHd3dy5vaHN1LmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALghy62gm5RH9WP/KL0b+haTbG1H6sSYngn5\nBAFt3N/ETXm0FXf43XG3aCCuhAQQeHumEkebZZkJJxRDy7VBLiYDCrodTwZjG3Ux\nTMrErx+yrfgPcp4GyOFXcsdGUmlK7q+Z9VT9nFFgxoXkCwJ+E9kccmvREnWnuFxZ\ncyU7TU2KO9YbNkgmo6wOUOCStGfUKWgVNZdyuOpZPtY5RIxQM60mCd1XgwhReSAH\n3nU75XVrONn5vrYzCxFtandaJDfggrN2KTZE3t5UGNtFVK8WTR/hjCIaI8ibfpZn\nwcQtcrNjzGib3gS5mQlOGtKXYesb4sLbOTFky3gKrWM0nNoDq70CAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMd3d3Lm9oc3UuZWR1hiNodHRwczovL3d3dy5vaHN1LmVkdS9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUb/kidTpnbE/d8egtfWTwn3CVKAIwDQYJ\nKoZIhvcNAQEFBQADggEBAIYzjl2+3amoiguDweqoRwmfxnmd0rNijcOcvp0FJCUw\n3vn/0UbsbeXOxKz6cncAY/tmJOUZ1MSK/7s7NVECWjtNwmx5Im7N/FXdNcEYEcMl\nW/6gWu6ZwUAgXaV/8klbrTGX3NWJ5jJsWQwHqA1yY9wba58okkWOjoIjI070IsHj\nudBseAs0D9Q9aL0OofrcQLcNdaGsJzLilDVM/UU7cSCwKATWuuLJGKgNlepjyq5Q\nz2lDp/HktHga9plFDjee7YRsH4N/9e1Z+3mKzs9QRANCAfDeTz9iFo8lJqo4sRdp\nSHajk3KEnqZKbsvlZC70uJpwvS9dn3E0G9esB/ps3tM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ohsu.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://www.ohsu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.ohsu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.ohsu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://www.ohsu.edu/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.ohsu.edu/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ohsu.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Oregon Health & Science University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHDCCAgSgAwIBAgIVAKiKGs+N1BpUHsMJYEAJU0TUP6QMMA0GCSqGSIb3DQEB\nBQUAMBcxFTATBgNVBAMTDHd3dy5vaHN1LmVkdTAeFw0wOTExMTcyMjUwNTJaFw0y\nOTExMTcyMjUwNTJaMBcxFTATBgNVBAMTDHd3dy5vaHN1LmVkdTCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALghy62gm5RH9WP/KL0b+haTbG1H6sSYngn5\nBAFt3N/ETXm0FXf43XG3aCCuhAQQeHumEkebZZkJJxRDy7VBLiYDCrodTwZjG3Ux\nTMrErx+yrfgPcp4GyOFXcsdGUmlK7q+Z9VT9nFFgxoXkCwJ+E9kccmvREnWnuFxZ\ncyU7TU2KO9YbNkgmo6wOUOCStGfUKWgVNZdyuOpZPtY5RIxQM60mCd1XgwhReSAH\n3nU75XVrONn5vrYzCxFtandaJDfggrN2KTZE3t5UGNtFVK8WTR/hjCIaI8ibfpZn\nwcQtcrNjzGib3gS5mQlOGtKXYesb4sLbOTFky3gKrWM0nNoDq70CAwEAAaNfMF0w\nPAYDVR0RBDUwM4IMd3d3Lm9oc3UuZWR1hiNodHRwczovL3d3dy5vaHN1LmVkdS9p\nZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQUb/kidTpnbE/d8egtfWTwn3CVKAIwDQYJ\nKoZIhvcNAQEFBQADggEBAIYzjl2+3amoiguDweqoRwmfxnmd0rNijcOcvp0FJCUw\n3vn/0UbsbeXOxKz6cncAY/tmJOUZ1MSK/7s7NVECWjtNwmx5Im7N/FXdNcEYEcMl\nW/6gWu6ZwUAgXaV/8klbrTGX3NWJ5jJsWQwHqA1yY9wba58okkWOjoIjI070IsHj\nudBseAs0D9Q9aL0OofrcQLcNdaGsJzLilDVM/UU7cSCwKATWuuLJGKgNlepjyq5Q\nz2lDp/HktHga9plFDjee7YRsH4N/9e1Z+3mKzs9QRANCAfDeTz9iFo8lJqo4sRdp\nSHajk3KEnqZKbsvlZC70uJpwvS9dn3E0G9esB/ps3tM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://www.ohsu.edu/idp/error.jsp"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Oregon Health & Science University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ohsu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Oregon Health & Science University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-24.ladok.umu.se/student-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-24.ladok.umu.se/student-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-24.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-24.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-24.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-24.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-24.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-24.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-24.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;24"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;24"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-24.ladok.umu.se/student-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-24.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAM9GWy3OuQ/iMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0yNC5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTQ0NDM3WhcNMjQx\nMDA0MTQ0NDM3WjAhMR8wHQYDVQQDExZsYWRvazMtMjQubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA05MWDop8dPQZhrGXHpbJoUfN\nOWH9xOQBd7DYjVs336VaygNWQ51+GJhqG37T5ow3U9Pbo16xxgWKm3j1fbovoEGP\nTcehDJ3aHcnffF3GGWyQ5ALLnEl6sBeIsnDntJezXExouYgYRxcUYNDeN142dQcO\n1/erSOGpY5vaN1HTr1mcKwSG+cj0Zf04fwUw1XtJTNrXNMr4320WyjSgLrvFmqYg\nd8DBRQgJAwBefT7SzE4x9bddnfwdkolT0p2ZL/ruLS2DRk7Td8G4j+l9K8rwt9B1\nvzXvgqAR2Zga8lo/Cqy/JpMl/uW45JIKimcS4Nu4yeLuhZ/wf8a1opZEQzumCwID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMjQubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0yNC5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUjvmvCf1UdJmoBI3qlCoBOU1ohCIwDQYJKoZIhvcNAQEFBQADggEB\nAKEQjSN0Swj2r2+CyDe+/0zA4sQ4iUBlcge2Bba8Q5PIziByByJx95gRMGsTSxwJ\nq6Jy890QU4p3gqhjjX/J1GLUYutQ3hmL8Phemkq8oasP9L7B687mh6CIQtCDXK1R\nvcJCZtIaOuJh0Muuref7YKk9AEiNnKN8srbNEVxc7kPHKd2gorqshJc2kCgoX5Z/\nIg2kEKGOW3Pu7T6ay98J/YdwNKw6Qi+6mozddDCE6tS4yEZ1z6ets9smZacd+NTo\niV6PB1oIkO06lmDDHxUNloyeK5kBcCtk1gnBtvBCzBumj/Sq/p6Upr6QM7MV+fiM\nQU3oSUW5d9AK8EGOvHPJ30g="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-24.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-24.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-24.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-24.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-24.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-24.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-24.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-24.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-24.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-24.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://qa.esds.ac.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:helpdesk@ukdataservice.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Moradi"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:amoradi@essex.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Amir"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://qa.esds.ac.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-07-23T11:54:20Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "ESDS QA"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://ukdataservice.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Essex"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://qa.esds.ac.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://qa.esds.ac.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://qa.esds.ac.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://qa.esds.ac.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://qa.esds.ac.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://qa.esds.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://qa.esds.ac.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDxDCCAqygAwIBAgIJAIFv979CtniPMA0GCSqGSIb3DQEBBQUAMGMxCzAJBgNV\n\t\t\t\t\t\tBAYTAkFVMRMwEQYDVQQIDApTb21lLVN0YXRlMSEwHwYDVQQKDBhJbnRlcm5ldCBX\n\t\t\t\t\t\taWRnaXRzIFB0eSBMdGQxHDAaBgNVBAMME2RhcGxhdDIuZXNzZXguYWMudWswHhcN\n\t\t\t\t\t\tMTMwOTA2MDgzOTI5WhcNMjMwOTA0MDgzOTI5WjBjMQswCQYDVQQGEwJBVTETMBEG\n\t\t\t\t\t\tA1UECAwKU29tZS1TdGF0ZTEhMB8GA1UECgwYSW50ZXJuZXQgV2lkZ2l0cyBQdHkg\n\t\t\t\t\t\tTHRkMRwwGgYDVQQDDBNkYXBsYXQyLmVzc2V4LmFjLnVrMIIBIjANBgkqhkiG9w0B\n\t\t\t\t\t\tAQEFAAOCAQ8AMIIBCgKCAQEA3ler7LUUd+O4SzG18ZOt3hnXvqPnF35l+uCoAP4U\n\t\t\t\t\t\t/8UIglUqK7VPmQNjSIQUqqW04LtLpqJ6wCF4zzZx4yOzn5B7q3Ytu7awlYDDOoeT\n\t\t\t\t\t\tS+E/9AaHbHIzgwSu64yHqIaGsiOfntVLVJVTVby5gnjtZk7BsLvEBbmRj/xQit2i\n\t\t\t\t\t\ta4qoBbEfu2CV3JoikgEQ29ysaWL26BPGkPiMH4AJ8rbmkcuhsrrV4utjF6Y4XB7s\n\t\t\t\t\t\tc5dSiCOmsiVk8qWvmvyRndUv+FqfFWKNTvhwjKUH6YPLT8fR3kya05PqP6MsfpME\n\t\t\t\t\t\trAK2prPIoCAq3O/5H3G8Uyv4qNXOKTlvWMeGSSrKXHne6wIDAQABo3sweTAJBgNV\n\t\t\t\t\t\tHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NMIEdlbmVyYXRlZCBDZXJ0aWZp\n\t\t\t\t\t\tY2F0ZTAdBgNVHQ4EFgQUpCtjhsAZDcsg55nyc8m6G+rqmVkwHwYDVR0jBBgwFoAU\n\t\t\t\t\t\tpCtjhsAZDcsg55nyc8m6G+rqmVkwDQYJKoZIhvcNAQEFBQADggEBAD27KL4LkToX\n\t\t\t\t\t\tHnK4Ajmkn31e7OeB1IkDXbVU8yQmRBxQ/OVcHbf2r3dKUyVJh8kcC45eLX6CIa2S\n\t\t\t\t\t\tYClmSnaixPYjpiu20jFV1SpglaQg3KM59qc7BvN/2a7jg7wDG6LU2d42uXPHFrtj\n\t\t\t\t\t\thi+kURBEMRtEPVDMjDslROkNZPEmQw8kI9cA/WWz5yW4NLqsRL2cc2rQZAUA/NUm\n\t\t\t\t\t\tgG/+uv5UwFNZiXZVphq1ITLqgYzj4mxy9pPDT5DRu41/7tpeFgqQ1XA8gSzWh0zW\n\t\t\t\t\t\tLD49UT6gUswxL81WggC8WDMvi5sq6xnHtq1JPxCeTWDeeafn0vCR4WAV2B2y6Iwj\n\t\t\t\t\t\tipl34THDqR4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://qa.esds.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://qa.esds.ac.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://qa.esds.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://qa.esds.ac.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://qa.esds.ac.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://qa.esds.ac.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://mayumba.msh-paris.fr/shibauth.php",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Laurent Henry"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "laurent.henry@ehess.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://mayumba.msh-paris.fr/shibauth.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2014-06-06T15:31:17Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/category/wifi"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "https://federation.renater.fr/scope/national"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Ecole des Hautes Etudes en Sciences Sociales Paris"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ehess.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Ecole des Hautes Etudes en Sciences Sociales Paris"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://mayumba.msh-paris.fr/shibauth.php"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "EHESS - FMSH - Eduspot site France"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "EHESS - FMSH - Eduspot site France"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EHESS - FMSH - Eduspot France site"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "EHESS - FMSH - Eduspot site France"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEdjCCA16gAwIBAgIRAJLT9rWH2+hZg6OeczPW/SMwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDAzMTcwMDAwMDBaFw0xNzAzMTYyMzU5NTlaMEIxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEdMBsGA1UEAxMUbWF5dW1iYS5t\nc2gtcGFyaXMuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC+2Evn\nEJ4196BzLBm5zH056JWxzlbBm/WSBOeLNNImAqDs12N7+b3hUd6xtp1m3A2vCCMO\nn/XVB3ud7bIP7kKOmSzfM4/CXjiO6SkrFEhaGz1DfDAwAloHi3Yfj2ec/U9QDAy6\nYrAG4ylizSnFy/01RAyztNjPNAMrOl2TYYJrqRCg+fU3HacNejKcCf+RDGpbdTL6\n6AHfeenebVRjDpv3eLb6pkRy4u8dbDJ70G9Iq+JOs/CxD0mD5kuj0M+uQ807o9D6\n5QZlrDAaqb+RS0oczHXwitgJ0bFPc+IRyxwzM4S2chebQpoVbB2x5HNVarfDTzC1\nc1vFGYsJssOgzCS3AgMBAAGjggFxMIIBbTAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJ\nays3V0fqkOO57TAdBgNVHQ4EFgQUIvVHzc7309TyAJFX8xxYFgp3K+0wDgYDVR0P\nAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsG\nAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1Ud\nHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NM\nQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50\nY3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6\nLy9vY3NwLnRjcy50ZXJlbmEub3JnMB8GA1UdEQQYMBaCFG1heXVtYmEubXNoLXBh\ncmlzLmZyMA0GCSqGSIb3DQEBBQUAA4IBAQBxCtuXfhTlAFKYiPQFeKaJvL6wAwM7\nDYM9EpC8jzoaqk+K31QAH7+tDSWOMxIL8ovb21/L9Ol863cYl9wve3oXZIYLKmXf\nfU8vBZ6jaEzn7A5o2G0+jcH6ufWmgfgzhq482oCMGca+GVcPvwwRhuEA85k0/hYf\ncVqbNIBZdu0wxYugtmy1GSK0DCp69G277EX+67jjIwLfUhFfFOxk6URmwj4VLDVO\noBsYkAumOdtWk+4OHxczuEfrFW2QK5HJn8lpHWduwxNdYfgSl2ibdLwLSOQf+LT9\nOr49ZS1V+M3QMurHd0GkuHUbNeScR/FOOF4Nj4MCVfOgl31SfR0MDp5i"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEdjCCA16gAwIBAgIRAJLT9rWH2+hZg6OeczPW/SMwDQYJKoZIhvcNAQEFBQAw\nNjELMAkGA1UEBhMCTkwxDzANBgNVBAoTBlRFUkVOQTEWMBQGA1UEAxMNVEVSRU5B\nIFNTTCBDQTAeFw0xNDAzMTcwMDAwMDBaFw0xNzAzMTYyMzU5NTlaMEIxITAfBgNV\nBAsTGERvbWFpbiBDb250cm9sIFZhbGlkYXRlZDEdMBsGA1UEAxMUbWF5dW1iYS5t\nc2gtcGFyaXMuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC+2Evn\nEJ4196BzLBm5zH056JWxzlbBm/WSBOeLNNImAqDs12N7+b3hUd6xtp1m3A2vCCMO\nn/XVB3ud7bIP7kKOmSzfM4/CXjiO6SkrFEhaGz1DfDAwAloHi3Yfj2ec/U9QDAy6\nYrAG4ylizSnFy/01RAyztNjPNAMrOl2TYYJrqRCg+fU3HacNejKcCf+RDGpbdTL6\n6AHfeenebVRjDpv3eLb6pkRy4u8dbDJ70G9Iq+JOs/CxD0mD5kuj0M+uQ807o9D6\n5QZlrDAaqb+RS0oczHXwitgJ0bFPc+IRyxwzM4S2chebQpoVbB2x5HNVarfDTzC1\nc1vFGYsJssOgzCS3AgMBAAGjggFxMIIBbTAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJ\nays3V0fqkOO57TAdBgNVHQ4EFgQUIvVHzc7309TyAJFX8xxYFgp3K+0wDgYDVR0P\nAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsG\nAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1Ud\nHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NM\nQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50\nY3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6\nLy9vY3NwLnRjcy50ZXJlbmEub3JnMB8GA1UdEQQYMBaCFG1heXVtYmEubXNoLXBh\ncmlzLmZyMA0GCSqGSIb3DQEBBQUAA4IBAQBxCtuXfhTlAFKYiPQFeKaJvL6wAwM7\nDYM9EpC8jzoaqk+K31QAH7+tDSWOMxIL8ovb21/L9Ol863cYl9wve3oXZIYLKmXf\nfU8vBZ6jaEzn7A5o2G0+jcH6ufWmgfgzhq482oCMGca+GVcPvwwRhuEA85k0/hYf\ncVqbNIBZdu0wxYugtmy1GSK0DCp69G277EX+67jjIwLfUhFfFOxk6URmwj4VLDVO\noBsYkAumOdtWk+4OHxczuEfrFW2QK5HJn8lpHWduwxNdYfgSl2ibdLwLSOQf+LT9\nOr49ZS1V+M3QMurHd0GkuHUbNeScR/FOOF4Nj4MCVfOgl31SfR0MDp5i"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC5TCCAc2gAwIBAgIJAPzxQDl/0G/mMA0GCSqGSIb3DQEBBQUAMBUxEzARBgNV\nBAMTCnVjb3BpYS5jb20wHhcNMTQwNjA2MTMwMTAyWhcNMjQwNjAzMTMwMTAyWjAV\nMRMwEQYDVQQDEwp1Y29waWEuY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\nCgKCAQEA1awiqcSL2EvF9eWa8XJ7RerWu2Ol4rKdx4hEltu48MCuL/i1C4Yg7I7I\nJkAl2ZKcQHIGCyUVpfotn5m7Owy78jsotpbzY8PN54LVN816FHa2KKCfBgJ7/5uh\nGtYisUKez6O/UafnM4Uc6U/Ol5e/MmlUvE6v12MJbvwAIrYhVUp5aSKOX0Gp3hO+\nXVlFsEfHCDFCdulXSPkUNGhqYftMOvlP10miPE2CzoqcxP5iQIctfzfAyK387KDe\n/oFzT/OicnRHMIQRaOpDht3nKGNs7JKjxVpcLDdNqDCAfkRNfUxg7QFQ3/9gPILi\nn3Lskv9dvcmMjXBVoPUe01aUCIiDmwIDAQABozgwNjAVBgNVHREEDjAMggp1Y29w\naWEuY29tMB0GA1UdDgQWBBRbFXLSHc4k19XNE68D/izAhYDEBTANBgkqhkiG9w0B\nAQUFAAOCAQEAYyDBOUun2YgaT0jndrx9mjcimVIDr71YtGvyF3eSL5fc6DeTH3Ur\nktOsqDP0MwPZmm5qfQLsD1q/+nLdzdRKStpwOozjUPYSEx/Ebe7JpzsEyC2yOD6w\nvWDCm38KJUKvAS7ekRK9Z8pFYlhaW7N+qSzrK3gbvJkx1txdnKvHTV7W51p4n1jS\necFyneuv9tuhQrjCrFufI+fjFijTmN8gBK2SyiHERlP3IDrrwz033mQRRLasjazA\nZUhgs9OPjysee18xEBIstkff54Mlz6IKUzpjhorRIR335+M63Qk7WkwGFt3CAW5C\n89fZI6z4GQLZqtZNECfC4/uTQNXzZ3L1Hg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://mayumba.msh-paris.fr/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mayumba.msh-paris.fr/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "0"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "EHESS - FMSH - Eduspot site France"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "EHESS - FMSH - Eduspot France site"
                }
              ],
              "service_description": [
                {
                  "lang": "fr",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "EHESS - FMSH - Eduspot site France"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceDescription",
                  "text": "EHESS - FMSH - Eduspot site France"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "requested_attribute": [
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonTargetedID",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ]
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.morleycollege.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:athenshelp@eduserv.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Athens Helpdesk"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.morleycollege.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.openathens.net/saml/2/sso/morleycollege.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.openathens.net/saml/1/sso/morleycollege.ac.uk/c/ukfed",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDvjCCAqagAwIBAgIEVOxCIjANBgkqhkiG9w0BAQsFADCBoDEoMCYGCSqGSIb3\n\t\t\t\t\t\tDQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0IxETAP\n\t\t\t\t\t\tBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVzZXJ2\n\t\t\t\t\t\tMRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVuc2Ft\n\t\t\t\t\t\tcy5uZXQwHhcNMTUwMjI0MDkyMDA2WhcNMjUwMjI0MDkyMDA2WjCBoDEoMCYGCSqG\n\t\t\t\t\t\tSIb3DQEJARYZYXRoZW5zaGVscEBlZHVzZXJ2Lm9yZy51azELMAkGA1UEBhMCR0Ix\n\t\t\t\t\t\tETAPBgNVBAgMCFNvbWVyc2V0MQ0wCwYDVQQHDARCYXRoMRAwDgYDVQQKDAdFZHVz\n\t\t\t\t\t\tZXJ2MRMwEQYDVQQLDApPcGVuQXRoZW5zMR4wHAYDVQQDDBVnYXRld2F5LmF0aGVu\n\t\t\t\t\t\tc2Ftcy5uZXQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCandpa4o0N\n\t\t\t\t\t\tjtw1DqbrrNTfOVe1PqyXIIVmDrJ6VUR/mokXXu+m5Gm+1f+3lyN5IA2YMn9Z8Yo3\n\t\t\t\t\t\t7JQjIHs+xVS3q4nT1ewS7S3en1pdXKsH1WnUnVWUmpl9WJZrUwi5i8X80LNyr7Pm\n\t\t\t\t\t\tudhuKNEATGUXkA/xWCkk2d8jf91hy7Qu+HA8LOKtdbbNigErh2IY/YuNWUVUqgGb\n\t\t\t\t\t\tMH5BGr7ZEhPrz+Vwcf9lhPW+tKpKpZEzJfQiq8EoPaeMXEpKWBEErm67gkWFCA5V\n\t\t\t\t\t\thfcJLqFjQEC3pWOxt5rZVS8gl/Z33VSJZVzY5jWcQzmGaLXPHXyiKPmixl6+DjGl\n\t\t\t\t\t\tUM0ylNF7GvtDAgMBAAEwDQYJKoZIhvcNAQELBQADggEBAFhmhujLZueiJ6F7mQCp\n\t\t\t\t\t\tfB0Hj4Y8FyFUUc8NMAt5Set7H4DKSSl4shcqisZBa5yTdyenYwkmBszvCWs6Yeep\n\t\t\t\t\t\t+zJmCR62cb/f1M32oMzLm02OlznWMkE8/IajGmdxTnB6Z/XcdMMIiCeok4kqe5KM\n\t\t\t\t\t\td5oRAyNskHYZ+8kzhs2zTveR+rqCtYxa/AYpwf7n0VQR9clBSNCIT4BCRi10aPE5\n\t\t\t\t\t\t31VIxl4ljY3CwNoZ4lQTU/0aj8O4j68V2neiQb8lewAii0b2xoyOGYP4okd7T2tl\n\t\t\t\t\t\t4gl2noVbCvYNjd6GYze/w4lgwiemkby7wu5sN1lEudgKDV+H54wU29ZIyDEFM6DD\n\t\t\t\t\t\tNE4="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "morleycollege.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Morley College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.morleycollege.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Eduserv"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso.brown.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "CIS-EAS-IdMgmt@brown.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brown University Shibboleth Administrator"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "CIS-EAS-IdMgmt@brown.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brown University Identity Management"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "cis-helpdesk@brown.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Brown University Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.brown.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso.brown.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.brown.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.brown.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.brown.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.brown.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "brown.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Brown University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDHzCCAgegAwIBAgIUHPSdb4ae0QA3fyeEIe7wKXi2oT0wDQYJKoZIhvcNAQEF\nBQAwGDEWMBQGA1UEAxMNc3NvLmJyb3duLmVkdTAeFw0xMDA1MjEyMTAyMzFaFw0z\nMDA1MjEyMTAyMzFaMBgxFjAUBgNVBAMTDXNzby5icm93bi5lZHUwggEiMA0GCSqG\nSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCxabgPhLgyIOyoG87T41EXwUOyXKNJ4XvF\na5moC3y8J9JzWBeVRQ8L7zxEiLcsZ4qHYdOCVZNSD5SYeI8rtjwz/lHlJsF7dfLX\npeQSm5HggcgWEEbvgp+qHRsbu6ZLKUmD0qLnWLZ5pG+ihm0n10G6h9op9NKJqJOg\nkyk3PQbe1biAjjpnkVL5CxL4h1E0XADZogZBh3pY04kNzbMvaWsB9ToDI8i6JqTf\nyEZZcQr4ShgIdstAHzbHcGoRqSOuI3BDeYDj0lp7/X/v/lvQMWWnKFJD6E7xKypo\nVO2czCswZ9i390YkI9+eoBbIMunuE/JjPZwwknnWqaI5LBDkGbnJAgMBAAGjYTBf\nMD4GA1UdEQQ3MDWCDXNzby5icm93bi5lZHWGJGh0dHBzOi8vc3NvLmJyb3duLmVk\ndS9pZHAvc2hpYmJvbGV0aDAdBgNVHQ4EFgQU1EgYrxblcWF0RP8BxGEPTM4SkIow\nDQYJKoZIhvcNAQEFBQADggEBAG1o9TLKHLDMlW+fRtyWXeGI1Dpnvw505nmWOQEP\nzXnT3oMRsmFYUrynl6amaay0IlEZ86g8KALM0AsKA9x2hYz/Kvs99ZLJJ+3mcHDs\nwWWC9NYme6HEzs+mXRXD2wxOWUYNKc2xAs3QPOpYmX2g6sZiDPkyQ4KOZT/Vh9BZ\n970k7vtJ0lIOUFSDTQnlfGOtdEBE6QehIzHF6SpFakYYFyAK1MO4G/vdYYoe4lF5\nFTUg9UjnEWqwcmCX02ay5ma5YMkNkyXeetU6HmLRBnpwPcuCgIkzuXP64h+6nVWp\nbLEJHeHIom+fbTMoCnUDbZ0FcmiGxk9Cg6RPORcGztgLcVw="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "error_url": "https://wiki.brown.edu/confluence/x/b4D_AQ"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Brown University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.brown.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Brown University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:carleton.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "clelm@carleton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Candyce Lelm"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "rgraves@carleton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Rich Graves"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "llacroix@carleton.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Les LaCroix"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:carleton.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://login.carleton.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://login.carleton.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://login.carleton.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://login.carleton.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "carleton.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Carleton College"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.carleton.edu/departments/ITS/Images/CarletonLogoSmall.png",
                    "lang": "en",
                    "height": "53",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "321"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Carleton College"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDIjCCAgqgAwIBAgICBDswDQYJKoZIhvcNAQEFBQAwKzEMMAoGA1UECwwDU1NP\nMRswGQYDVQQDDBJsb2dpbi5jYXJsZXRvbi5lZHUwHhcNMTQwNDExMDI0MjAxWhcN\nMjQwNDA4MDI0MjAxWjArMQwwCgYDVQQLDANTU08xGzAZBgNVBAMMEmxvZ2luLmNh\ncmxldG9uLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL9/N77y\nFrpOKThUptD//RTM5yjPeE24ao3RNZ9NQWeEn8Lv/PVNgf9cvOvOzS2dUxraqthV\nP9QYwMgRogvs2K4/Jq+dsIm5zVnVLw9610T6b6rZycsXoqwVhNlD3V107jF1QwZz\n6wg42KWhic2mOQ3/Cg6764kUagACOmDhGvvNKqK/bKymCgpAmJoTCc9T6UCYPbgo\nEa4+CSQ1CL+oCmzVXLt5mj+qWTk7SZpLQajh3DiEPzRhmg7sX0/z3RH4brs5Qewr\nvgr9A05MjOyoIrrFm2CRhLeIzSoSwRdl8EY4Mw6xmISQ9UHKTAWCNOX2EC1Olcw4\nhFAYkqa1nMdbjzkCAwEAAaNQME4wHQYDVR0OBBYEFA/D4JnMpUbqUfqw4R3n9585\nJj2iMB8GA1UdIwQYMBaAFA/D4JnMpUbqUfqw4R3n9585Jj2iMAwGA1UdEwQFMAMB\nAf8wDQYJKoZIhvcNAQEFBQADggEBACyhKczVUBsf/7OH+Q6+JyggcnL8wPiZOfdi\nO6LBmsBu5gKOKRPX3T8AhOwErOU3bilw6JX3oZ9PZpon3F3DBxPi+oAAsKfbJ0lr\n88DJfPMNrB5LG6EdRWr+a7z1Ch3E5pLRStIw0L/+YdNwyg3bisv0jbz+xWN4LvX6\nRL8eo9ATYSSwl5JJM0D89XovPl534kPjGcp/l3PRp8tEiP6pNBrPWI+KgV0ksqkZ\nbllJv8s7/Np5XwEEQ1KkqCNLI/cvW9u7OIhII7/F0QoKyAvNtdut8e61oQJyyAJq\nEdda89AEn3ZZeCBK6d2ALE01aEjJmH2MElHQbR/a387IpYbztYM="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDujCCAqICCQCPaJ8ioTbhuDANBgkqhkiG9w0BAQUFADCBnjELMAkGA1UEBhMC\nVVMxEjAQBgNVBAgTCU1pbm5lc290YTETMBEGA1UEBxMKTm9ydGhmaWVsZDEZMBcG\nA1UEChMQQ2FybGV0b24gQ29sbGVnZTEMMAoGA1UECxMDSVRTMRswGQYDVQQDExJs\nb2dpbi5jYXJsZXRvbi5lZHUxIDAeBgkqhkiG9w0BCQEWEXdsZWVAY2FybGV0b24u\nZWR1MB4XDTEzMDIyMTIxNTEyMloXDTIzMDIxOTIxNTEyMlowgZ4xCzAJBgNVBAYT\nAlVTMRIwEAYDVQQIEwlNaW5uZXNvdGExEzARBgNVBAcTCk5vcnRoZmllbGQxGTAX\nBgNVBAoTEENhcmxldG9uIENvbGxlZ2UxDDAKBgNVBAsTA0lUUzEbMBkGA1UEAxMS\nbG9naW4uY2FybGV0b24uZWR1MSAwHgYJKoZIhvcNAQkBFhF3bGVlQGNhcmxldG9u\nLmVkdTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJJR4aGU0T4Rs+ra\niaCBqBp75XUZ+W0rnXVuP4oainijV8oepLVo0trGRjYgIHhNKufhtuFtvxkgsq/Q\nqaSR6mmCgKU8YH32gGggjwLBRbMn7aNiJu2PNi03g+NxFW+k3iz/qcuyrkb9CGO5\nQcqMlWznphotRXXXscm94+SBmJ9aeTL4XIUXfEIOdeDdNqZRjjvuKck83Mbqn/4t\n69uZcrOM0BFQFhJOE5vgJ9kOEBnsS+3dYbEndfK1dXnxp88gLaWY/4GvvOUwQTub\nsuvy9/hlyLUpNz/sZFNM7KekQUjKv2/qu3hi+gvl4Dl5LuEbug38XKZDQ75pZOm5\nPROnhKMCAwEAATANBgkqhkiG9w0BAQUFAAOCAQEAdTupllJ0sDvllI+4Jgn+DwPT\nlzOM5I7Y2MVkHtodZCyrT6qRaP4oX369LVG0S3vQbChVi1gW0CljeUl9e616nkaN\nJ89UhUhN3r9t5412qQ8/Lyq+LX1912yUyCuW8JMQXFbVlMS0b/FvJmXPYlLpFIf1\nDGbJW/HYJ07x+5V7hONXUmEvh8SZo+JXmTO37hLOBGSyteXbWJv7VptIm/fD6411\ncYLejujXijfbVj38Ijcucjrel7dJ2Zl8nnmkn3VlRFdEuRScuWudI+7rS6Ux+Dwc\n25Ls34lI9+W9mXyA7ix0qDjNmpRccdkzLcvfTgYC7q5VGzyToU4S2u7AZvcxeA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "error_url": "https://login.carleton.edu/error.html"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Carleton College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.carleton.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Carleton College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://oala.uws.ac.uk/oala/metadata",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jiracek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pavel.jiracek@uws.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pavel"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jiracek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:pavel.jiracek@uws.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Pavel"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://oala.uws.ac.uk/oala/metadata",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_instant": "2012-12-20T18:17:50Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "want_authn_requests_signed": "false",
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://oala.uws.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://oala.uws.ac.uk/oala/sso",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "uws.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIIbQnNE5dUfa4wDQYJKoZIhvcNAQEFBQAwMzEYMBYGA1UE\n\t\t\t\t\t\tCgwPVVdTX0RldmVsb3BtZW50MRcwFQYDVQQDDA5vYWxhLnV3cy5hYy51azAeFw0x\n\t\t\t\t\t\tMjEyMTgxNTE5MDZaFw0yMjEyMTgxNTE5MDZaMDMxGDAWBgNVBAoMD1VXU19EZXZl\n\t\t\t\t\t\tbG9wbWVudDEXMBUGA1UEAwwOb2FsYS51d3MuYWMudWswggEiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tAQUAA4IBDwAwggEKAoIBAQDiqewakPZodoX19+9+qPMOcxYrTZqEt/ljYtVrSkFb\n\t\t\t\t\t\tfo7QBQ8i7cI3gmLDR6OudWF7rc8Mg8Nhjdsv/qijBXWXK5pzmbczwKA2hYVg148M\n\t\t\t\t\t\t+GyIlOcIUD/OJ2xixpkXiaa11Z9m4SdOh50AgXyfOvo1WFMgJqC5Xg9dQtNWrP7r\n\t\t\t\t\t\tR91dVGaF4dY+PlEfgQ2HQp4N4YK8C2MhNppUyfgOrt8iczCNYBX1kqyOdny8/bDR\n\t\t\t\t\t\tcvzqAg9oIf910rGS5RvetpLxnIiG9bLnUoiXCiGytNntKZjj/3qKb4x4iTvrCFe8\n\t\t\t\t\t\t/2NRGe47rTzOKfyVDo0YnXDkEGhEuAjMu4FGQeo8muBLAgMBAAGjUDBOMB0GA1Ud\n\t\t\t\t\t\tDgQWBBTY1w4Mn4Xy3KHsgxVO5XFrEFf1ezAfBgNVHSMEGDAWgBTY1w4Mn4Xy3KHs\n\t\t\t\t\t\tgxVO5XFrEFf1ezAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQDFaE6E\n\t\t\t\t\t\t87PXIBb66PY1c75fSj1QItA8RkQLh/AqAbiV2+xonO44rxiNqMbUX8Cd3Sow0X/6\n\t\t\t\t\t\tUj59jtAhKHEslOaDIPNsig377yt9ppgGGgFeruK6yZ/TV86Jq6s2xxOYgJYjZv0f\n\t\t\t\t\t\tFOgbdMm1EtUk72qmcDL4+MQbCJrC4QZYlRglm2X+0uuiaoyamkJC32Z6Nfy5iqot\n\t\t\t\t\t\tHd5rN37WdO15lqq/9oJ7ceZcIfGUr4mn0u73iT2AJ0YwTl85Ra6iu/IdiCvPbNE8\n\t\t\t\t\t\tSg4ZQsDNqOTbhHKbYdD2iJq03fcfH3AySZLSXrbgfpqlOEwTiX/nAQT7jJjVJ3Wk\n\t\t\t\t\t\tkhuKC+d+27DnjjLI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIIbQnNE5dUfa4wDQYJKoZIhvcNAQEFBQAwMzEYMBYGA1UE\n\t\t\t\t\t\tCgwPVVdTX0RldmVsb3BtZW50MRcwFQYDVQQDDA5vYWxhLnV3cy5hYy51azAeFw0x\n\t\t\t\t\t\tMjEyMTgxNTE5MDZaFw0yMjEyMTgxNTE5MDZaMDMxGDAWBgNVBAoMD1VXU19EZXZl\n\t\t\t\t\t\tbG9wbWVudDEXMBUGA1UEAwwOb2FsYS51d3MuYWMudWswggEiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tAQUAA4IBDwAwggEKAoIBAQDiqewakPZodoX19+9+qPMOcxYrTZqEt/ljYtVrSkFb\n\t\t\t\t\t\tfo7QBQ8i7cI3gmLDR6OudWF7rc8Mg8Nhjdsv/qijBXWXK5pzmbczwKA2hYVg148M\n\t\t\t\t\t\t+GyIlOcIUD/OJ2xixpkXiaa11Z9m4SdOh50AgXyfOvo1WFMgJqC5Xg9dQtNWrP7r\n\t\t\t\t\t\tR91dVGaF4dY+PlEfgQ2HQp4N4YK8C2MhNppUyfgOrt8iczCNYBX1kqyOdny8/bDR\n\t\t\t\t\t\tcvzqAg9oIf910rGS5RvetpLxnIiG9bLnUoiXCiGytNntKZjj/3qKb4x4iTvrCFe8\n\t\t\t\t\t\t/2NRGe47rTzOKfyVDo0YnXDkEGhEuAjMu4FGQeo8muBLAgMBAAGjUDBOMB0GA1Ud\n\t\t\t\t\t\tDgQWBBTY1w4Mn4Xy3KHsgxVO5XFrEFf1ezAfBgNVHSMEGDAWgBTY1w4Mn4Xy3KHs\n\t\t\t\t\t\tgxVO5XFrEFf1ezAMBgNVHRMEBTADAQH/MA0GCSqGSIb3DQEBBQUAA4IBAQDFaE6E\n\t\t\t\t\t\t87PXIBb66PY1c75fSj1QItA8RkQLh/AqAbiV2+xonO44rxiNqMbUX8Cd3Sow0X/6\n\t\t\t\t\t\tUj59jtAhKHEslOaDIPNsig377yt9ppgGGgFeruK6yZ/TV86Jq6s2xxOYgJYjZv0f\n\t\t\t\t\t\tFOgbdMm1EtUk72qmcDL4+MQbCJrC4QZYlRglm2X+0uuiaoyamkJC32Z6Nfy5iqot\n\t\t\t\t\t\tHd5rN37WdO15lqq/9oJ7ceZcIfGUr4mn0u73iT2AJ0YwTl85Ra6iu/IdiCvPbNE8\n\t\t\t\t\t\tSg4ZQsDNqOTbhHKbYdD2iJq03fcfH3AySZLSXrbgfpqlOEwTiX/nAQT7jJjVJ3Wk\n\t\t\t\t\t\tkhuKC+d+27DnjjLI"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of the West of Scotland - ICT Development"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.uws.ac.uk/ictservices/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of the West of Scotland"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idf.pucsp.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Victor Emmanuel J.S. Vicente"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "dti@pucsp.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idf.pucsp.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGqDCCBZCgAwIBAgIQBvjTK3/wFt3MCgKdqTU41DANBgkqhkiG9w0BAQUFADBm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\nAY+3V4U1qNrpwyazvjVrqVVzY2LjNW9gbC+zzg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pucsp.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idf.pucsp.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idf.pucsp.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idf.pucsp.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idf.pucsp.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idf.pucsp.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idf.pucsp.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idf.pucsp.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idf.pucsp.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "pucsp.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.pucsp.br/"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.pucsp.br/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "PUC-SP - Pontificia Universidade Catolica de Sao Paulo"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "PUC-SP - Pontificia Universidade Catolica de Sao Paulo"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PUC-SP - Pontificia Universidade Catolica de Sao Paulo"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "PUC-SP - Pontificia Universidade Catolica de Sao Paulo"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIGqDCCBZCgAwIBAgIQBvjtk3/wFt3MCgKdqTU41DANBgkqhkiG9w0BAQUFADBm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\nAY+3V4U1qNrpwyazvjVrqVVzY2LjNW9gbC+zzg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PUC-SP - Pontificia Universidade Catolica de Sao Paulo"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "PUC-SP - Pontificia Universidade Catolica de Sao Paulo"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.pucsp.br/"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.pucsp.br/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "PUC-SP- Pontificia Universidade Catolica de Sao Paulo"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "PUC-SP- Pontificia Universidade Catolica de Sao Paulo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:ucop.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ucopdatacenter.helpdesk@ucop.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "UCOP DataCenter HelpDesk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "aig@ucop.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Munish Malik"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "Paul.Weiss@ucop.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul Weiss"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "urn:mace:incommon:ucop.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ucopidp.ucop.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://ucopidp.ucop.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAMQjUagrFAAc3mU/MM8Y89753FJsMA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEHVjb3BpZHAudWNvcC5lZHUwHhcNMTEwNDE1MjE0NDQy\nWhcNMzEwNDE1MjE0NDQyWjAbMRkwFwYDVQQDExB1Y29waWRwLnVjb3AuZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA5yWRcAVFF4lApTgaJ6Wiq4HQ\ncnHxfdZwqWwEeyKGcjhzS3mbaNZAjR37wsnK19npCIunzb966PK8BAXhATX5L7x9\n0+F8qTDL9NWGB2usN4ftkxDjCbHSzQP8/C1+nLdj0EuyxXxbn5etiVn5ScQ+xMHc\nMyo+u2+7crKloeUERtgXV9d8wbMZ+5dNeSjIVBq/EldB1xpo1oSQz5LSZoWppjqR\nj+HDHQNY2rGdyJchd6M5QjtV5/yWZsjhd++9AiD+avAcNkWrF+3Yg5mcRzgHhMtb\nYHZXtb69hJfO+vwQ655wlgN25pw4H0wLB5/GehMAi82hnL3PGnwvgFDrt2uTIwID\nAQABo2cwZTBEBgNVHREEPTA7ghB1Y29waWRwLnVjb3AuZWR1hidodHRwczovL3Vj\nb3BpZHAudWNvcC5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFOM/H8+UOT/R\nDmr2WHQCXELzAZztMA0GCSqGSIb3DQEBBQUAA4IBAQBVzHO+GyiTfvkhMqz29wl5\n6wLckOvYuilJqru9jXZOCzBzpjnK2YbAKmbmDs2BDT3cJfJDDAxM7bZG69mFf+0h\n2qIcgCoZd6054kAEe/T9WloBVRWa2AnQlbtkd3YIkmlCpB6jLNUpkgX6PAVPOpBa\nvEMn/hMWxQb10qaOsGyzp3uXz2aYJgZoEv2qAdVtKpuDSOcPt11A7rwZE4XhVwhb\nhdYDgZJ0gVCbr3oNhiccN7cf790QxrUdTjDq2qSl47S/SpOOLSLH0vflygsdASlb\nr5yHRx2chce62RYQtpM9sBEJjMZ9seBMN3J+y29vdvayfD1mo9Ma56VSHLitFJ9N"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucop.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ucopidp.ucop.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://ucopidp.ucop.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://ucopidp.ucop.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ucopidp.ucop.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ucopidp.ucop.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://ucopidp.ucop.edu/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucop.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of California - Office of the President"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLDCCAhSgAwIBAgIVAMQjUagrFAAc3mU/MM8Y89753FJsMA0GCSqGSIb3DQEB\nBQUAMBsxGTAXBgNVBAMTEHVjb3BpZHAudWNvcC5lZHUwHhcNMTEwNDE1MjE0NDQy\nWhcNMzEwNDE1MjE0NDQyWjAbMRkwFwYDVQQDExB1Y29waWRwLnVjb3AuZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA5yWRcAVFF4lApTgaJ6Wiq4HQ\ncnHxfdZwqWwEeyKGcjhzS3mbaNZAjR37wsnK19npCIunzb966PK8BAXhATX5L7x9\n0+F8qTDL9NWGB2usN4ftkxDjCbHSzQP8/C1+nLdj0EuyxXxbn5etiVn5ScQ+xMHc\nMyo+u2+7crKloeUERtgXV9d8wbMZ+5dNeSjIVBq/EldB1xpo1oSQz5LSZoWppjqR\nj+HDHQNY2rGdyJchd6M5QjtV5/yWZsjhd++9AiD+avAcNkWrF+3Yg5mcRzgHhMtb\nYHZXtb69hJfO+vwQ655wlgN25pw4H0wLB5/GehMAi82hnL3PGnwvgFDrt2uTIwID\nAQABo2cwZTBEBgNVHREEPTA7ghB1Y29waWRwLnVjb3AuZWR1hidodHRwczovL3Vj\nb3BpZHAudWNvcC5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFOM/H8+UOT/R\nDmr2WHQCXELzAZztMA0GCSqGSIb3DQEBBQUAA4IBAQBVzHO+GyiTfvkhMqz29wl5\n6wLckOvYuilJqru9jXZOCzBzpjnK2YbAKmbmDs2BDT3cJfJDDAxM7bZG69mFf+0h\n2qIcgCoZd6054kAEe/T9WloBVRWa2AnQlbtkd3YIkmlCpB6jLNUpkgX6PAVPOpBa\nvEMn/hMWxQb10qaOsGyzp3uXz2aYJgZoEv2qAdVtKpuDSOcPt11A7rwZE4XhVwhb\nhdYDgZJ0gVCbr3oNhiccN7cf790QxrUdTjDq2qSl47S/SpOOLSLH0vflygsdASlb\nr5yHRx2chce62RYQtpM9sBEJjMZ9seBMN3J+y29vdvayfD1mo9Ma56VSHLitFJ9N"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of California - Office of the President"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ucop.edu/welcome.html"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of California - Office of the President"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "urn:mace:incommon:ncsu.edu",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth-help@ncsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NC State Shibboleth Support Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth-help@ncsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NC State Shibboleth Support Team"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "help@ncsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NC State Help Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "security@ncsu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "NC State Security Team"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "urn:mace:incommon:ncsu.edu",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.ncsu.edu:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.ncsu.edu:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIJAKcwwnWxi6ZCMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDXNoaWIubmNzdS5lZHUwHhcNMTQwNDI1MTUxNDUyWhcNMTkwNDI1MTUxNDUy\nWjAYMRYwFAYDVQQDEw1zaGliLm5jc3UuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAoTTorB5iXx/tC50NPBwDBn0Zy2l6J1x0cTo/81bYgsU1BjlH\nXR/C5/A5mNciH0lpeYKqy/Ij23t+6X+p+3O4RYlTw1AsecLk28/k9sNnjZkvHAzM\nr3TBGQ0gqY50gEU4WPYN9SC7ElxHuSl2S2bv8bWqz99s6xFuKwS9zyRr75BWwZ31\ndEYX6VmFYuUvj72TFKconF79sQgCtpmeDFk3Hu6EVgzhBjLW+yLvYcj+2+bH0PU2\nLESx1nq6f/LFyViMO4TqefyA1wsuowie6X8RPk8obby0I8czdoix4aeohdGaDSyk\neVtDl8FvmSBEm7Sn434YT8po5QuHUEq90tBhpQIDAQABo2EwXzA+BgNVHREENzA1\ngg1zaGliLm5jc3UuZWR1hiRodHRwczovL3NoaWIubmNzdS5lZHUvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFFLakuecqjfP1r3rY4Ix1r9eSqZMMA0GCSqGSIb3DQEB\nBQUAA4IBAQB6ohqcjxrbXeT5GflMWx4cMRhM91xSSxz26GKYOhmhCqZSQkW82PaZ\ncRpmAoiUL21XtrVeZK2eKXRP1GuAoqKOEYCgskwbFk5CM2MeccboRZYMuKn8Myx9\nz9qjNRgbDua/pyprYKHklZiIfQ0shxobzyraSGU7eGQoboY28sy0CTAvNo94kjzY\nlt5/Noa2Z0beNonPwErtEVMHY5ozKVsDAj71VpJYVno9Rh4sJA40M9X90Z8VumZF\nsTmYvvoBIotU2pYCM8LJKGaV14EeDOvKUinr7NwLJtRvrpYhdJLtdoweOC/CriGE\nQG14KYZRu8ILWwLE2Vtr8Zl9dQOZvVuq"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ncsu.edu"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shib.ncsu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shib.ncsu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shib.ncsu.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shib.ncsu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shib.ncsu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shib.ncsu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ncsu.edu"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://oit.ncsu.edu/campus-it/identity-management/shibboleth/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Sign in with your NC State UnityID credentials"
                  }
                ],
                "logo": [
                  {
                    "text": "https://docs.shib.ncsu.edu/inc/fed_logo.gif",
                    "lang": "en",
                    "height": "33",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "195"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "North Carolina State University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIJAKcwwnWxi6ZCMA0GCSqGSIb3DQEBBQUAMBgxFjAUBgNV\nBAMTDXNoaWIubmNzdS5lZHUwHhcNMTQwNDI1MTUxNDUyWhcNMTkwNDI1MTUxNDUy\nWjAYMRYwFAYDVQQDEw1zaGliLm5jc3UuZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOC\nAQ8AMIIBCgKCAQEAoTTorB5iXx/tC50NPBwDBn0Zy2l6J1x0cTo/81bYgsU1BjlH\nXR/C5/A5mNciH0lpeYKqy/Ij23t+6X+p+3O4RYlTw1AsecLk28/k9sNnjZkvHAzM\nr3TBGQ0gqY50gEU4WPYN9SC7ElxHuSl2S2bv8bWqz99s6xFuKwS9zyRr75BWwZ31\ndEYX6VmFYuUvj72TFKconF79sQgCtpmeDFk3Hu6EVgzhBjLW+yLvYcj+2+bH0PU2\nLESx1nq6f/LFyViMO4TqefyA1wsuowie6X8RPk8obby0I8czdoix4aeohdGaDSyk\neVtDl8FvmSBEm7Sn434YT8po5QuHUEq90tBhpQIDAQABo2EwXzA+BgNVHREENzA1\ngg1zaGliLm5jc3UuZWR1hiRodHRwczovL3NoaWIubmNzdS5lZHUvaWRwL3NoaWJi\nb2xldGgwHQYDVR0OBBYEFFLakuecqjfP1r3rY4Ix1r9eSqZMMA0GCSqGSIb3DQEB\nBQUAA4IBAQB6ohqcjxrbXeT5GflMWx4cMRhM91xSSxz26GKYOhmhCqZSQkW82PaZ\ncRpmAoiUL21XtrVeZK2eKXRP1GuAoqKOEYCgskwbFk5CM2MeccboRZYMuKn8Myx9\nz9qjNRgbDua/pyprYKHklZiIfQ0shxobzyraSGU7eGQoboY28sy0CTAvNo94kjzY\nlt5/Noa2Z0beNonPwErtEVMHY5ozKVsDAj71VpJYVno9Rh4sJA40M9X90Z8VumZF\nsTmYvvoBIotU2pYCM8LJKGaV14EeDOvKUinr7NwLJtRvrpYhdJLtdoweOC/CriGE\nQG14KYZRu8ILWwLE2Vtr8Zl9dQOZvVuq"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "North Carolina State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ncsu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "North Carolina State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://publications.ki.se/shibboleth",
    {
      "entity_id": "https://publications.ki.se/shibboleth",
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Karolinska Institutet"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ki.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "KI"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://publications.ki.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://publications.ki.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://publications.ki.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://publications.ki.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "publications.ki.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE+jCCA+KgAwIBAgIJAOQykWZUCZpqMA0GCSqGSIb3DQEBBQUAMIGuMQswCQYD\nVQQGEwJTRTETMBEGA1UECBMKU29tZS1TdGF0ZTEOMAwGA1UEBxMFU29sbmExHjAc\nBgNVBAoTFUthcm9saW5za2EgSW5zdGl0dXRldDEbMBkGA1UECxMSVU5JVkVSU0lU\nWSBMSUJSQVJZMRswGQYDVQQDExJwdWJsaWNhdGlvbnMua2kuc2UxIDAeBgkqhkiG\n9w0BCQEWEXViaXRkb3NAa2liLmtpLnNlMB4XDTEwMDMyMzE1MzQ0OFoXDTIwMDMy\nMDE1MzQ0OFowga4xCzAJBgNVBAYTAlNFMRMwEQYDVQQIEwpTb21lLVN0YXRlMQ4w\nDAYDVQQHEwVTb2xuYTEeMBwGA1UEChMVS2Fyb2xpbnNrYSBJbnN0aXR1dGV0MRsw\nGQYDVQQLExJVTklWRVJTSVRZIExJQlJBUlkxGzAZBgNVBAMTEnB1YmxpY2F0aW9u\ncy5raS5zZTEgMB4GCSqGSIb3DQEJARYRdWJpdGRvc0BraWIua2kuc2UwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC11ax7K5PjR3GFpvzT37OKa1ycH3Rt\nz0GNApRMQtS7x9q1wgRjA3dqdTSIIJettkBgyEUOfB0f1MgcaMtaNIPhDJfMCqdr\nQ6dPKp+F0b7P7jWezyWNt8gVKXSOaeJYjze56zURO+MK8CA4sTpttqgcOOv5pnhN\nwyEuYmQBYtKGvcH13jJPStsQ+s5LZ9NX/5gV64DrRI4s64d9r0FH78lHzkM2TqHI\n0ce2KeZdn3AgXy1tOW58nUKVlUNgsFZyg/GH0ICZ08tOo1YHWBu1iuZQrzfKI655\nj8R4gElSbT+Sp770OoC9qgoBsQQdh3N/Pj+/RvgSTMG3cOmtIlNu/YjpAgMBAAGj\nggEXMIIBEzAdBgNVHQ4EFgQUjs01iDGc22yXqpCThMLfgM12WCAwgeMGA1UdIwSB\n2zCB2IAUjs01iDGc22yXqpCThMLfgM12WCChgbSkgbEwga4xCzAJBgNVBAYTAlNF\nMRMwEQYDVQQIEwpTb21lLVN0YXRlMQ4wDAYDVQQHEwVTb2xuYTEeMBwGA1UEChMV\nS2Fyb2xpbnNrYSBJbnN0aXR1dGV0MRswGQYDVQQLExJVTklWRVJTSVRZIExJQlJB\nUlkxGzAZBgNVBAMTEnB1YmxpY2F0aW9ucy5raS5zZTEgMB4GCSqGSIb3DQEJARYR\ndWJpdGRvc0BraWIua2kuc2WCCQDkMpFmVAmaajAMBgNVHRMEBTADAQH/MA0GCSqG\nSIb3DQEBBQUAA4IBAQBcI4P5JLCJuTCKie7Ze/NucF3tBgcXllnSYo7z4NSafr0i\nCrsoBPoxg1Sr7cFXSCRWLUr7Di2WfdQLrn3ZY1sPTYKWlgEmWVYFiSph2HYv04L9\nI72Jn8DLvaNCqew7KYgCODkSFRUFxzGDlWho0cXHMwP31/dEVEa2mUwmMEzG+ScQ\nDII+Op9QBwqJ7VgT7RLwhH6txbcicwNdfQYktXy/C7ysmUAS6XW1vE3H3LDd6Oc5\n98OMIxMcebzCxLN0jT93KgoWEq2eaGQi0h4TPZ7ZGmCkVQICVvSNjEKguACD/j9o\nryntMn54coBlF2Vqrm4Fa2XUyUIkurCv3FZtdN5W"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=ubitdos@kib.ki.se,CN=publications.ki.se,OU=UNIVERSITY LIBRARY,O=Karolinska Institutet,L=Solna,ST=Some-State,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "publications.ki.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIE+jCCA+KgAwIBAgIJAOQykWZUCZpqMA0GCSqGSIb3DQEBBQUAMIGuMQswCQYD\nVQQGEwJTRTETMBEGA1UECBMKU29tZS1TdGF0ZTEOMAwGA1UEBxMFU29sbmExHjAc\nBgNVBAoTFUthcm9saW5za2EgSW5zdGl0dXRldDEbMBkGA1UECxMSVU5JVkVSU0lU\nWSBMSUJSQVJZMRswGQYDVQQDExJwdWJsaWNhdGlvbnMua2kuc2UxIDAeBgkqhkiG\n9w0BCQEWEXViaXRkb3NAa2liLmtpLnNlMB4XDTEwMDMyMzE1MzQ0OFoXDTIwMDMy\nMDE1MzQ0OFowga4xCzAJBgNVBAYTAlNFMRMwEQYDVQQIEwpTb21lLVN0YXRlMQ4w\nDAYDVQQHEwVTb2xuYTEeMBwGA1UEChMVS2Fyb2xpbnNrYSBJbnN0aXR1dGV0MRsw\nGQYDVQQLExJVTklWRVJTSVRZIExJQlJBUlkxGzAZBgNVBAMTEnB1YmxpY2F0aW9u\ncy5raS5zZTEgMB4GCSqGSIb3DQEJARYRdWJpdGRvc0BraWIua2kuc2UwggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC11ax7K5PjR3GFpvzT37OKa1ycH3Rt\nz0GNApRMQtS7x9q1wgRjA3dqdTSIIJettkBgyEUOfB0f1MgcaMtaNIPhDJfMCqdr\nQ6dPKp+F0b7P7jWezyWNt8gVKXSOaeJYjze56zURO+MK8CA4sTpttqgcOOv5pnhN\nwyEuYmQBYtKGvcH13jJPStsQ+s5LZ9NX/5gV64DrRI4s64d9r0FH78lHzkM2TqHI\n0ce2KeZdn3AgXy1tOW58nUKVlUNgsFZyg/GH0ICZ08tOo1YHWBu1iuZQrzfKI655\nj8R4gElSbT+Sp770OoC9qgoBsQQdh3N/Pj+/RvgSTMG3cOmtIlNu/YjpAgMBAAGj\nggEXMIIBEzAdBgNVHQ4EFgQUjs01iDGc22yXqpCThMLfgM12WCAwgeMGA1UdIwSB\n2zCB2IAUjs01iDGc22yXqpCThMLfgM12WCChgbSkgbEwga4xCzAJBgNVBAYTAlNF\nMRMwEQYDVQQIEwpTb21lLVN0YXRlMQ4wDAYDVQQHEwVTb2xuYTEeMBwGA1UEChMV\nS2Fyb2xpbnNrYSBJbnN0aXR1dGV0MRswGQYDVQQLExJVTklWRVJTSVRZIExJQlJB\nUlkxGzAZBgNVBAMTEnB1YmxpY2F0aW9ucy5raS5zZTEgMB4GCSqGSIb3DQEJARYR\ndWJpdGRvc0BraWIua2kuc2WCCQDkMpFmVAmaajAMBgNVHRMEBTADAQH/MA0GCSqG\nSIb3DQEBBQUAA4IBAQBcI4P5JLCJuTCKie7Ze/NucF3tBgcXllnSYo7z4NSafr0i\nCrsoBPoxg1Sr7cFXSCRWLUr7Di2WfdQLrn3ZY1sPTYKWlgEmWVYFiSph2HYv04L9\nI72Jn8DLvaNCqew7KYgCODkSFRUFxzGDlWho0cXHMwP31/dEVEa2mUwmMEzG+ScQ\nDII+Op9QBwqJ7VgT7RLwhH6txbcicwNdfQYktXy/C7ysmUAS6XW1vE3H3LDd6Oc5\n98OMIxMcebzCxLN0jT93KgoWEq2eaGQi0h4TPZ7ZGmCkVQICVvSNjEKguACD/j9o\nryntMn54coBlF2Vqrm4Fa2XUyUIkurCv3FZtdN5W"
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "emailAddress=ubitdos@kib.ki.se,CN=publications.ki.se,OU=UNIVERSITY LIBRARY,O=Karolinska Institutet,L=Solna,ST=Some-State,C=SE"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://publications.ki.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://publications.ki.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://publications.ki.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://publications.ki.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://publications.ki.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://publications.ki.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://publications.ki.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://publications.ki.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://publications.ki.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://publications.ki.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://samltest.swamid.se/nren/sp.xml",
    {
      "entity_id": "https://samltest.swamid.se/nren/sp.xml",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Swedish Academic Identity Federation (SWAMID)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.swamid.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SWAMID"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "false",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://samltest.swamid.se/disco",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFcTCCBFmgAwIBAgIQIu7k1beHBKgWb27d90Ad9jANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQwODAwMDAwMFoXDTE3MDQwNzIzNTk1OVowQDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRswGQYDVQQDExJzYW1sdGVzdC5z\nd2FtaWQuc2UwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCcJfNqCJmM\nCWZ9+h9MAT9WbT/e+eRpGE9H8eucnnq4weTeFbT+2Ma15hY8hI6gP4GsDIZsaxTu\nDGgIYXctfnl9MTz+9rlANOo8Wjuz6CJ2trJ6BdhPvkoITuSqmIWkFbmP7/0NGkoG\n167CGp/Eq5yZnUOdiKXquH2S5OCw3mB4HGpjUk7T13cN0jOOPiK2cQhUTuUUMaVO\nei0QblIfK/+9fusfYOjd5uzNg1QZ9FvvbB/wTw4Z11eGcZWKpAprIrbx6iw119eL\nU7dvJhgA96VJmesDQejf96Xtpn7bCbxdyBqw2AtooamyrVjnAeQ8NDXW7td9MUuM\n4/yhN9H+fHTVJNs8dCX5FKayw5YoxF8eTMjRk0ObICMrLl8M/EiOG9Eqfc3TPGTF\ndn81sOGc3WzifRyG5fXUx/Xw9vXVkRAkVO6T4n6OUQxn2be9hwXR7yFw9tTplPIl\ndabhc7iWU7NgEBcBI3RWCcRNv0OVsXIMDeGZ64SOm4mpKbXMVebsnSLXxV69T1l4\nM8EegMpraRWHrbtF27FkKZPZgCbNaQbfW4vtJoN9rN07Flz8GLr200WXAepXT14L\ndGwXqjx6Cu2oilkl2OoNWQbRg3dvn1j6XqnRLbio4bvuiCYYEPpjuWcHOs/GwMnz\npml7EL51yz9PTwNZTQXsLH/xKlzWf1BuBQIDAQABo4IBbzCCAWswHwYDVR0jBBgw\nFoAUDL2TaAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFG40O0IHvLK2kXS6s4hN\nCq0DTtPLMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQG\nCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgG\nBmeBDAECATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEu\nb3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKG\nKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsG\nAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJz\nYW1sdGVzdC5zd2FtaWQuc2UwDQYJKoZIhvcNAQEFBQADggEBAHnWOLDwhrYWfd7q\n2fwTaiRP/x/tVPocNgi/wgwo6oZzC1Ru/HPjfUmnj11zkOOHeF8cf2BT2diRptPi\nqDc+7HN8GrM87+Deqvjj4pw7j4hwMpcfNd2AzqW4nPmw4LgiRehITtUtMxL9mkDh\neN0pgldD544xQRUdxYmD9nUWiIaTmuxNqusKkqUTD/kO41i+BxIeaWiXsw6IC7o6\nkPPUQHr1h2na805Kjoy5ML8K2EO+kcvFqfo42gtwa7mN38hKB+jbKF5VqqmoSb4m\nln/3lobOqcV8rrFKjvnjC6iNTbdpQ65o8CoOcfzhWmb/7RxkZ4a9fyzxVS8fMAi6\nu3Qzm3Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFcTCCBFmgAwIBAgIQIu7k1beHBKgWb27d90Ad9jANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTE0MDQwODAwMDAwMFoXDTE3MDQwNzIzNTk1OVowQDEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMRswGQYDVQQDExJzYW1sdGVzdC5z\nd2FtaWQuc2UwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCcJfNqCJmM\nCWZ9+h9MAT9WbT/e+eRpGE9H8eucnnq4weTeFbT+2Ma15hY8hI6gP4GsDIZsaxTu\nDGgIYXctfnl9MTz+9rlANOo8Wjuz6CJ2trJ6BdhPvkoITuSqmIWkFbmP7/0NGkoG\n167CGp/Eq5yZnUOdiKXquH2S5OCw3mB4HGpjUk7T13cN0jOOPiK2cQhUTuUUMaVO\nei0QblIfK/+9fusfYOjd5uzNg1QZ9FvvbB/wTw4Z11eGcZWKpAprIrbx6iw119eL\nU7dvJhgA96VJmesDQejf96Xtpn7bCbxdyBqw2AtooamyrVjnAeQ8NDXW7td9MUuM\n4/yhN9H+fHTVJNs8dCX5FKayw5YoxF8eTMjRk0ObICMrLl8M/EiOG9Eqfc3TPGTF\ndn81sOGc3WzifRyG5fXUx/Xw9vXVkRAkVO6T4n6OUQxn2be9hwXR7yFw9tTplPIl\ndabhc7iWU7NgEBcBI3RWCcRNv0OVsXIMDeGZ64SOm4mpKbXMVebsnSLXxV69T1l4\nM8EegMpraRWHrbtF27FkKZPZgCbNaQbfW4vtJoN9rN07Flz8GLr200WXAepXT14L\ndGwXqjx6Cu2oilkl2OoNWQbRg3dvn1j6XqnRLbio4bvuiCYYEPpjuWcHOs/GwMnz\npml7EL51yz9PTwNZTQXsLH/xKlzWf1BuBQIDAQABo4IBbzCCAWswHwYDVR0jBBgw\nFoAUDL2TaAzz3qujSWsrN1dH6pDjue0wHQYDVR0OBBYEFG40O0IHvLK2kXS6s4hN\nCq0DTtPLMA4GA1UdDwEB/wQEAwIFoDAMBgNVHRMBAf8EAjAAMB0GA1UdJQQWMBQG\nCCsGAQUFBwMBBggrBgEFBQcDAjAiBgNVHSAEGzAZMA0GCysGAQQBsjEBAgIdMAgG\nBmeBDAECATA6BgNVHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEu\nb3JnL1RFUkVOQVNTTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKG\nKWh0dHA6Ly9jcnQudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsG\nAQUFBzABhhpodHRwOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAdBgNVHREEFjAUghJz\nYW1sdGVzdC5zd2FtaWQuc2UwDQYJKoZIhvcNAQEFBQADggEBAHnWOLDwhrYWfd7q\n2fwTaiRP/x/tVPocNgi/wgwo6oZzC1Ru/HPjfUmnj11zkOOHeF8cf2BT2diRptPi\nqDc+7HN8GrM87+Deqvjj4pw7j4hwMpcfNd2AzqW4nPmw4LgiRehITtUtMxL9mkDh\neN0pgldD544xQRUdxYmD9nUWiIaTmuxNqusKkqUTD/kO41i+BxIeaWiXsw6IC7o6\nkPPUQHr1h2na805Kjoy5ML8K2EO+kcvFqfo42gtwa7mN38hKB+jbKF5VqqmoSb4m\nln/3lobOqcV8rrFKjvnjC6iNTbdpQ65o8CoOcfzhWmb/7RxkZ4a9fyzxVS8fMAi6\nu3Qzm3Q="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://samltest.swamid.se/acs/nren/redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://samltest.swamid.se/acs/nren/post",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp-prod.cc.ucf.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tim@ucf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim Larson"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "jim@ucf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jim Ennis"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "ls@ucf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Laurence Siew"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tim@ucf.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tim Larson"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        }
      ],
      "entity_id": "https://idp-prod.cc.ucf.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp-prod.cc.ucf.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp-prod.cc.ucf.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp-prod.cc.ucf.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp-prod.cc.ucf.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp-prod.cc.ucf.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp-prod.cc.ucf.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ucf.edu"
              },
              {
                "logo": [
                  {
                    "text": "https://idp-prod.cc.ucf.edu/idp/ucflogo.gif",
                    "lang": "en",
                    "height": "75",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "150"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Central Florida"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDODCCAiCgAwIBAgIVAMvE2hm/0pdXtouxqrRuMPJtXmUzMA0GCSqGSIb3DQEB\nBQUAMB4xHDAaBgNVBAMTE2lkcC1wcm9kLmNjLnVjZi5lZHUwHhcNMTEwNTE5MjEx\nMDQzWhcNMzEwNTE5MjExMDQzWjAeMRwwGgYDVQQDExNpZHAtcHJvZC5jYy51Y2Yu\nZWR1MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAghk3G4M/Iyq50iUv\nsL+m5QT24JkJOSJWEAXm1eEMeYoSsmHWxZhLeHDjUlP8THadLCn4+KO1tMdCuhw4\n5bC/jOqVPzXig10+KY79TuasbF9Dwa3EtW88Gt7FqrjXtQMZPfqJ/97EGZMPJF3f\nZXDX06BQMypHFYBzuO234+w4IJzy97wnyTz0qpjq9Vc0MK1vX9D+3JyU2Vg7MPQ8\n/gMnoNM/prapBiUeG4Fi4tPwSwKCqgrrxWvHYA7CWS/y7hq8IvGf+vM6kYuEc1fa\nVuKOP7X+B2wlL8nx0VchLaLkGyu9HG69zL5RJlUGhwIu/+tXBBZvqhzisyir7Rvh\nT+FUPwIDAQABo20wazBKBgNVHREEQzBBghNpZHAtcHJvZC5jYy51Y2YuZWR1hipo\ndHRwczovL2lkcC1wcm9kLmNjLnVjZi5lZHUvaWRwL3NoaWJib2xldGgwHQYDVR0O\nBBYEFOKN9QfppJIne49jBCn+VTA6JxN0MA0GCSqGSIb3DQEBBQUAA4IBAQAerM6c\nebboDhXRxJNQyrcrQT8ACDDdRTX3l+inDZZ7AdsywW/IKGLznA8756oGbG1vKhlw\nB31Mu6TmsMtpuC6ThikTzoqTqaoFIvEhEfeQgzXwkOrnXyx1TL1/I04JBHsPo2iO\nEfayKCmafksmUTzr1voSFmM9Bp2/S79jOX7zD+RsxLc/sc82b5B1Hx9VFSnVVZlp\ngQFQHIvnPTccKgoZts0CMVqPD2rzOuK2excw5D1s5hxIiZ5Bi6pG9FfYWybR2SQ8\nu9ZyOOyULacfY5dN4/BJ293av9Xmq7skS0DcikqAJ/ZQlEV/NDexFGpABUmfQo37\n0q3VVc70nXU1d7cV"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFMjCCBBqgAwIBAgIQXAU976ByHakHmxGdYsAfRzANBgkqhkiG9w0BAQUFADBR\nMQswCQYDVQQGEwJVUzESMBAGA1UEChMJSW50ZXJuZXQyMREwDwYDVQQLEwhJbkNv\nbW1vbjEbMBkGA1UEAxMSSW5Db21tb24gU2VydmVyIENBMB4XDTExMDUwOTAwMDAw\nMFoXDTEyMDUwODIzNTk1OVowgaQxCzAJBgNVBAYTAlVTMQswCQYDVQQIEwJGTDEQ\nMA4GA1UEBxMHT3JsYW5kbzEmMCQGA1UEChMdVW5pdmVyc2l0eSBvZiBDZW50cmFs\nIEZsb3JpZGExGjAYBgNVBAsTEUNvbXB1dGVyIFNlcnZpY2VzMRQwEgYDVQQLEwtQ\nbGF0aW51bVNTTDEcMBoGA1UEAxMTaWRwLXByb2QuY2MudWNmLmVkdTCCASIwDQYJ\nKoZIhvcNAQEBBQADggEPADCCAQoCggEBAMysvlrvbtoZic5wpQSW2Er1CJivM4nA\nzRoKkRC4q/cGlfMTTCTF8b/yTT1ExlnN+cDhR9dyuDfMv+ghEE3K8RyoLokp0u76\n9SJyPSbRIlBiWgjzn3HweY+/Q8H0cNcnH+XvwlnhPAdJhcZAan5qq1/5mJqxLwYd\nsSbB4O8ZfY9jLSAY1s7eQJi33jR2Oge3onqSzAGRWH5YBrlMgZWXN31TnP8ZGwXq\nwy2iJjjCu97mzF0voxO48OkVfca2Bvvv/q+RPs4ZCfLqw8zQuBhiGzdaLiKT/PiU\n46Lf2RGZPAuqUjCVPVOfIoMDLk4SmmeNXHCBCrtlCt6zqOD5hcKG+WkCAwEAAaOC\nAbAwggGsMB8GA1UdIwQYMBaAFEhPWvovSppe4FDza3tVpd71vjRdMB0GA1UdDgQW\nBBSGN0T+h5IO7pQRbBcw/BnsGpYmazAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/\nBAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUHAwIwXQYDVR0gBFYwVDBS\nBgwrBgEEAa4jAQQDAQEwQjBABggrBgEFBQcCARY0aHR0cHM6Ly93d3cuaW5jb21t\nb24ub3JnL2NlcnQvcmVwb3NpdG9yeS9jcHNfc3NsLnBkZjA9BgNVHR8ENjA0MDKg\nMKAuhixodHRwOi8vY3JsLmluY29tbW9uLm9yZy9JbkNvbW1vblNlcnZlckNBLmNy\nbDBvBggrBgEFBQcBAQRjMGEwOQYIKwYBBQUHMAKGLWh0dHA6Ly9jZXJ0LmluY29t\nbW9uLm9yZy9JbkNvbW1vblNlcnZlckNBLmNydDAkBggrBgEFBQcwAYYYaHR0cDov\nL29jc3AuaW5jb21tb24ub3JnMB4GA1UdEQQXMBWCE2lkcC1wcm9kLmNjLnVjZi5l\nZHUwDQYJKoZIhvcNAQEFBQADggEBADWsx84TkGK7p30UE7XJWuabbu+A0XIuBy/l\nkq3BfZ2tIQwiUmITq6DwPcI88JEA3HwHnxaS/fDs1rnl/SNR4VhdPibTCvhPZk7m\nIJ1r1GPZG4PoUvwZFOar+mPKw2SkeO9zOXNt0291HW/oRpt5EQ/iQZpnINmmsS1q\ntQ2H8SS7hUbzmD/NTO6cEsYjU1nxz28ibqYXxarPm52u4JsM6BTpoNT/Oghfs3gZ\niQtMxythgcIG+srpD7je26DK05H3d4qgjOzNogepc0Z1rCUxc1xOP/5QdoJ7dOhK\niVr4j+vsHmoBJB+J5VAC8/SAzG/s4VDMBZ2yqMvzeEXkmaOTrso="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Central Florida"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ucf.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Central Florida"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.tcat.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Flanders"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Paul.Flanders@tcat.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Flanders"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Paul.Flanders@tcat.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.tcat.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2011-09-05T15:44:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEADCCAugCCQCwjoaBYKCfJzANBgkqhkiG9w0BAQUFADCBwTELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEzARBgNVBAgTClNocm9wc2hpcmUxEDAOBgNVBAcTB1RlbGZvcmQxLTArBgNV\n\t\t\t\t\t\tBAoMJFRlbGZvcmQgQ29sbGVnZSBvZiBBcnRzICYgVGVjaG5vbG9neTEaMBgGA1UE\n\t\t\t\t\t\tCxMRQ29tcHV0ZXIgU2VydmljZXMxFzAVBgNVBAMTDmlkcC50Y2F0LmFjLnVrMScw\n\t\t\t\t\t\tJQYJKoZIhvcNAQkBFhhwYXVsLmZsYW5kZXJzQHRjYXQuYWMudWswHhcNMTQwNzE1\n\t\t\t\t\t\tMTUxMzE1WhcNMjQwNzEyMTUxMzE1WjCBwTELMAkGA1UEBhMCR0IxEzARBgNVBAgT\n\t\t\t\t\t\tClNocm9wc2hpcmUxEDAOBgNVBAcTB1RlbGZvcmQxLTArBgNVBAoMJFRlbGZvcmQg\n\t\t\t\t\t\tQ29sbGVnZSBvZiBBcnRzICYgVGVjaG5vbG9neTEaMBgGA1UECxMRQ29tcHV0ZXIg\n\t\t\t\t\t\tU2VydmljZXMxFzAVBgNVBAMTDmlkcC50Y2F0LmFjLnVrMScwJQYJKoZIhvcNAQkB\n\t\t\t\t\t\tFhhwYXVsLmZsYW5kZXJzQHRjYXQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IB\n\t\t\t\t\t\tDwAwggEKAoIBAQDwEPad4kYnJdollfR+J9PakClAmKbQKKHQt5gTIotM/5YWnQKv\n\t\t\t\t\t\tMuNgZmBlgP4u5j7HcI2x3GHt6SD8PDrhACRnHUlVAOsH7AtkHpzX0k5Lawes8DBV\n\t\t\t\t\t\tJmCMwUOSoboO3Kf4Niu0fzMJ2ou+Cwz7JXrV6KjJP4GgkakZIgG6ntpRsY7X3zPU\n\t\t\t\t\t\tb5GaSsC2boxY3snewwnFQ/yg5EleBo3hvAr0WzN+pu2UsG0kRd1GdMIPf32XWl8o\n\t\t\t\t\t\tV9+ZzDqxVjzJNHGfaelo6+1oOVubEg4TFUVLC0QyMhMx94tz2Yi7sKItonzrzrVq\n\t\t\t\t\t\tHcHtKA41ZpCYlgV5wxXJ7QVVgGene/ietIbVAgMBAAEwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAAHHT1eun1pip4eal05s9EaRBXrSAhE9+qrUNpw26FwTqMdVuwHzadYD1OAy\n\t\t\t\t\t\tNIj9Kvzb0Beg5cDbvKZwVZGJq2ggEN2OBe8jEfOpDdAySaPFPGqtjpK+prpN5Tos\n\t\t\t\t\t\ty5FK+4RzszXAi4gw4Nt/q90FN3tjWOkCzqGohCY2MSfSoLWig6kpJg0Hew7OAIKP\n\t\t\t\t\t\tncwOyF72tR6YpC2b0ME1yCVQfZ8u/lYtK+CiYQJmtVews1EVylbh6tAJukMyaaCv\n\t\t\t\t\t\tSmmiXVquChnW/ZIR4PTlFYkt+rJ7DklXcka6iAj9JimdVhvtejcsnLufxA3tcvwN\n\t\t\t\t\t\tSpAzJUepxnhluW2OGgk/PxNhR+c="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tcat.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.tcat.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.tcat.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.tcat.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.tcat.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.tcat.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.tcat.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.tcat.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.tcat.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "tcat.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEADCCAugCCQCwjoaBYKCfJzANBgkqhkiG9w0BAQUFADCBwTELMAkGA1UEBhMC\n\t\t\t\t\t\tR0IxEzARBgNVBAgTClNocm9wc2hpcmUxEDAOBgNVBAcTB1RlbGZvcmQxLTArBgNV\n\t\t\t\t\t\tBAoMJFRlbGZvcmQgQ29sbGVnZSBvZiBBcnRzICYgVGVjaG5vbG9neTEaMBgGA1UE\n\t\t\t\t\t\tCxMRQ29tcHV0ZXIgU2VydmljZXMxFzAVBgNVBAMTDmlkcC50Y2F0LmFjLnVrMScw\n\t\t\t\t\t\tJQYJKoZIhvcNAQkBFhhwYXVsLmZsYW5kZXJzQHRjYXQuYWMudWswHhcNMTQwNzE1\n\t\t\t\t\t\tMTUxMzE1WhcNMjQwNzEyMTUxMzE1WjCBwTELMAkGA1UEBhMCR0IxEzARBgNVBAgT\n\t\t\t\t\t\tClNocm9wc2hpcmUxEDAOBgNVBAcTB1RlbGZvcmQxLTArBgNVBAoMJFRlbGZvcmQg\n\t\t\t\t\t\tQ29sbGVnZSBvZiBBcnRzICYgVGVjaG5vbG9neTEaMBgGA1UECxMRQ29tcHV0ZXIg\n\t\t\t\t\t\tU2VydmljZXMxFzAVBgNVBAMTDmlkcC50Y2F0LmFjLnVrMScwJQYJKoZIhvcNAQkB\n\t\t\t\t\t\tFhhwYXVsLmZsYW5kZXJzQHRjYXQuYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IB\n\t\t\t\t\t\tDwAwggEKAoIBAQDwEPad4kYnJdollfR+J9PakClAmKbQKKHQt5gTIotM/5YWnQKv\n\t\t\t\t\t\tMuNgZmBlgP4u5j7HcI2x3GHt6SD8PDrhACRnHUlVAOsH7AtkHpzX0k5Lawes8DBV\n\t\t\t\t\t\tJmCMwUOSoboO3Kf4Niu0fzMJ2ou+Cwz7JXrV6KjJP4GgkakZIgG6ntpRsY7X3zPU\n\t\t\t\t\t\tb5GaSsC2boxY3snewwnFQ/yg5EleBo3hvAr0WzN+pu2UsG0kRd1GdMIPf32XWl8o\n\t\t\t\t\t\tV9+ZzDqxVjzJNHGfaelo6+1oOVubEg4TFUVLC0QyMhMx94tz2Yi7sKItonzrzrVq\n\t\t\t\t\t\tHcHtKA41ZpCYlgV5wxXJ7QVVgGene/ietIbVAgMBAAEwDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAAHHT1eun1pip4eal05s9EaRBXrSAhE9+qrUNpw26FwTqMdVuwHzadYD1OAy\n\t\t\t\t\t\tNIj9Kvzb0Beg5cDbvKZwVZGJq2ggEN2OBe8jEfOpDdAySaPFPGqtjpK+prpN5Tos\n\t\t\t\t\t\ty5FK+4RzszXAi4gw4Nt/q90FN3tjWOkCzqGohCY2MSfSoLWig6kpJg0Hew7OAIKP\n\t\t\t\t\t\tncwOyF72tR6YpC2b0ME1yCVQfZ8u/lYtK+CiYQJmtVews1EVylbh6tAJukMyaaCv\n\t\t\t\t\t\tSmmiXVquChnW/ZIR4PTlFYkt+rJ7DklXcka6iAj9JimdVhvtejcsnLufxA3tcvwN\n\t\t\t\t\t\tSpAzJUepxnhluW2OGgk/PxNhR+c="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Telford College of Arts & Technology (old)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.tcat.ac.uk"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Telford College of Arts and Technology"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.hiu.cas.cz/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Van\u00ed\u010dek"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "vanicekp@utia.cas.cz"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Petr"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.hiu.cas.cz/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/en/eduid/policy/policy_eduid_en-1_1.pdf"
              },
              {
                "lang": "cs",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.eduid.cz/wiki/_media/eduid/policy/policy_eduid_cz-1_1-3.pdf"
              }
            ],
            "registration_instant": "2015-01-20T09:24:02Z",
            "registration_authority": "http://www.eduid.cz/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://eduid.cz/uri/idp-group/avcr"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAI8MkDWeW/BNLq24Uo6mRe3luCklMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC5oaXUuY2FzLmN6MB4XDTE0MDgxNDA2MjM1OFoX\nDTM0MDgxNDA2MjM1OFowGTEXMBUGA1UEAxMOaWRwLmhpdS5jYXMuY3owggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDDEcc4ZXcQ0TjPrmWaiSqowRV0gC2J\n0AEg5vdr9g/IAaiSkL4/pCuA5JkCkVLZ3sICR/lVEoznIKIIy8HODWzOPqk4lms0\nMCmpVybV/KuVbzv0zLoR41tgipMKwcYNc0yya7rqSOf1go/JSbaNvNqsAYwgz645\npqtA0zx1hj8OXHijdpTTszA/QYdL/XquoqYTwrnYQqqnfZSSrW1bw7Q5Ay5mIBKc\ncHfgsiXJ3DR0qoPEI8tylEANxdGtAyAX/Ee1CJDgezaLE3KgxKSOB25t8Qr4ykUK\n6JA7n8+L9sBbg+5yeka1sHVNmBfDzWDMIdx6Vq6DyaVUslv6kU8suXK/AgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC5oaXUuY2FzLmN6hiVodHRwczovL2lkcC5oaXUu\nY2FzLmN6L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBS2DVKyehrtvGJR51jA6tCk\nv2zM6zANBgkqhkiG9w0BAQUFAAOCAQEASHg7C6a1JzNmeuEgsZuAeJ0DhtkyNdk9\nzKrMrDwr9vDVhjec5sPk6nYxyWm28sh37WfdvU29z14OGpmOoiV8c5CDxg0e71ay\nG0yWQt10zhLs9gcYCktnwOdx7cxhzGvAXAHpxRAqXLwgKdttK1Nzxc3KIIdUu0R4\nDGmTEE/ebAYi1pQegaFhlVENHtmGGs+WU05qygclhp3XGJou+5chOIZu5lBwEqUh\nOrR2dRjjHPiKAaxqQ8S7GY25pTYIn0Fz/3MlEV86VP7ez+9WT5sV8+teCDiFcQLj\nInEf51JhjceyxF/6DmYwakFJHeZ4IPBQMBAy2Z02wwmKDQ/ESYAWig=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hiu.cas.cz"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.hiu.cas.cz:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.hiu.cas.cz:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.hiu.cas.cz/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.hiu.cas.cz/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.hiu.cas.cz:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.hiu.cas.cz/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.hiu.cas.cz/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.hiu.cas.cz/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.hiu.cas.cz/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.hiu.cas.cz:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.hiu.cas.cz:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "hiu.cas.cz"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.hiu.cas.cz/"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.hiu.cas.cz/cs/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider IH AV CR employees."
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider pro zam\u011bstnance H\u00da AV \u010cR"
                  }
                ],
                "logo": [
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-hiu-44.png",
                    "height": "44",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "61"
                  },
                  {
                    "text": "https://jiftach.cas.cz/loga/logo-hiu-530.png",
                    "height": "530",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "740"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Institute of History of the ASCR"
                  },
                  {
                    "lang": "cs",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Historick\u00fd \u00fastav AV \u010cR"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAI8MkDWeW/BNLq24Uo6mRe3luCklMA0GCSqGSIb3DQEB\nBQUAMBkxFzAVBgNVBAMTDmlkcC5oaXUuY2FzLmN6MB4XDTE0MDgxNDA2MjM1OFoX\nDTM0MDgxNDA2MjM1OFowGTEXMBUGA1UEAxMOaWRwLmhpdS5jYXMuY3owggEiMA0G\nCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDDEcc4ZXcQ0TjPrmWaiSqowRV0gC2J\n0AEg5vdr9g/IAaiSkL4/pCuA5JkCkVLZ3sICR/lVEoznIKIIy8HODWzOPqk4lms0\nMCmpVybV/KuVbzv0zLoR41tgipMKwcYNc0yya7rqSOf1go/JSbaNvNqsAYwgz645\npqtA0zx1hj8OXHijdpTTszA/QYdL/XquoqYTwrnYQqqnfZSSrW1bw7Q5Ay5mIBKc\ncHfgsiXJ3DR0qoPEI8tylEANxdGtAyAX/Ee1CJDgezaLE3KgxKSOB25t8Qr4ykUK\n6JA7n8+L9sBbg+5yeka1sHVNmBfDzWDMIdx6Vq6DyaVUslv6kU8suXK/AgMBAAGj\nYzBhMEAGA1UdEQQ5MDeCDmlkcC5oaXUuY2FzLmN6hiVodHRwczovL2lkcC5oaXUu\nY2FzLmN6L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBS2DVKyehrtvGJR51jA6tCk\nv2zM6zANBgkqhkiG9w0BAQUFAAOCAQEASHg7C6a1JzNmeuEgsZuAeJ0DhtkyNdk9\nzKrMrDwr9vDVhjec5sPk6nYxyWm28sh37WfdvU29z14OGpmOoiV8c5CDxg0e71ay\nG0yWQt10zhLs9gcYCktnwOdx7cxhzGvAXAHpxRAqXLwgKdttK1Nzxc3KIIdUu0R4\nDGmTEE/ebAYi1pQegaFhlVENHtmGGs+WU05qygclhp3XGJou+5chOIZu5lBwEqUh\nOrR2dRjjHPiKAaxqQ8S7GY25pTYIn0Fz/3MlEV86VP7ez+9WT5sV8+teCDiFcQLj\nInEf51JhjceyxF/6DmYwakFJHeZ4IPBQMBAy2Z02wwmKDQ/ESYAWig=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Institute of History of the ASCR, Public Research Institution"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Historick\u00fd \u00fastav AV \u010cR, v.v.i."
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hiu.cas.cz/"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.hiu.cas.cz/cs/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Institute of History of the ASCR"
          },
          {
            "lang": "cs",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Historick\u00fd \u00fastav AV \u010cR"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idem.unisalento.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Antonio Campa"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:dorsale@unisalento.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idem.unisalento.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2011-09-05T15:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUA+PvTTuv3pJPbxuuJd/3LE3JtcEwDQYJKoZIhvcNAQEF\nBQAwHTEbMBkGA1UEAxMSaWRlbS51bmlzYWxlbnRvLml0MB4XDTEwMDcxMzEyMTg1\nNloXDTMwMDcxMzEyMTg1NlowHTEbMBkGA1UEAxMSaWRlbS51bmlzYWxlbnRvLml0\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAgla3juJH8iD+hOUKUgES\nhp9QqZOEuEPDSaS9SpYZHxscsgz0RXljN2yMw8fS7ih4LCZT98okH+lBG4wKndMg\n0X2gDQfpMpA9ly/Ei5htxtBQGcuIVtmfI1BPwMTGqlvxnO3HCRNdzbb/UivCtvZt\ng0cr0P6qYr11ExntVQInEq2S18S1xRLAZOL5SId8AcGUugVqZM1Q4L8anJclCww5\nHmnl27QQSrVTgoPjPt2KI7ALVEsTbY54gEti6YRX6VmXYtCiFOkLFK0A/Q5hcy7Z\nXDuZnhqYGh11iwh2xGRu8ZXYPKtEhKf+Y3+BqOB9j7+kSHRHbVqegREOm/Ude+WC\nlwIDAQABo2swaTBIBgNVHREEQTA/ghJpZGVtLnVuaXNhbGVudG8uaXSGKWh0dHBz\nOi8vaWRlbS51bmlzYWxlbnRvLml0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSD\nvtPQz4E2/RAEnZwWLaMi6MgpXzANBgkqhkiG9w0BAQUFAAOCAQEALqmALOf4h9Q+\nOT27WFz2eBzr8X39M3MZ60b2xXxGn36VRlkfrBS2sCSZz/8JZrFsDr650I0v5ZHV\n8I0pMfTzUyylxch4T8Y92779JifANL1ypLKLzsgXtO0zKut6AvxRG+6AnECQtFMg\ni3JWjW8VY7HVpvCSRpIZtLEBoYfSsGEB8vkdhbJvz15cmwwtBX9bHGyiqGdG8NSi\nt8hsGA3CsRPAhEgvzTX5bXdp9P2SZYcc/+jbsOLy2i5ECApA/BAUFkWVxo3zpdQc\nTuRSdi628uP4JhrF+naNDmjtypIhcFWxTb9nS0Q7pNztRk8WeKJWRJOPpmUcOti9\ncwGgvFbTug=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unisalento.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idem.unisalento.it:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idem.unisalento.it:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idem.unisalento.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idem.unisalento.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idem.unisalento.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idem.unisalento.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idem.unisalento.it:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idem.unisalento.it:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unisalento.it"
              },
              {
                "information_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://idem-idp.unisalento.it/info"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://idem-idp.unisalento.it/infoeng/"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for the users of University of Salento"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider per gli utenti dell'Universit\u00e0 del Salento"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://idem-idp.unisalento.it/info"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://idem-idp.unisalento.it/infoeng/"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "University of Salento"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e0 del Salento"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMzCCAhugAwIBAgIUA+PvTTuv3pJPbxuuJd/3LE3JtcEwDQYJKoZIhvcNAQEF\nBQAwHTEbMBkGA1UEAxMSaWRlbS51bmlzYWxlbnRvLml0MB4XDTEwMDcxMzEyMTg1\nNloXDTMwMDcxMzEyMTg1NlowHTEbMBkGA1UEAxMSaWRlbS51bmlzYWxlbnRvLml0\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAgla3juJH8iD+hOUKUgES\nhp9QqZOEuEPDSaS9SpYZHxscsgz0RXljN2yMw8fS7ih4LCZT98okH+lBG4wKndMg\n0X2gDQfpMpA9ly/Ei5htxtBQGcuIVtmfI1BPwMTGqlvxnO3HCRNdzbb/UivCtvZt\ng0cr0P6qYr11ExntVQInEq2S18S1xRLAZOL5SId8AcGUugVqZM1Q4L8anJclCww5\nHmnl27QQSrVTgoPjPt2KI7ALVEsTbY54gEti6YRX6VmXYtCiFOkLFK0A/Q5hcy7Z\nXDuZnhqYGh11iwh2xGRu8ZXYPKtEhKf+Y3+BqOB9j7+kSHRHbVqegREOm/Ude+WC\nlwIDAQABo2swaTBIBgNVHREEQTA/ghJpZGVtLnVuaXNhbGVudG8uaXSGKWh0dHBz\nOi8vaWRlbS51bmlzYWxlbnRvLml0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSD\nvtPQz4E2/RAEnZwWLaMi6MgpXzANBgkqhkiG9w0BAQUFAAOCAQEALqmALOf4h9Q+\nOT27WFz2eBzr8X39M3MZ60b2xXxGn36VRlkfrBS2sCSZz/8JZrFsDr650I0v5ZHV\n8I0pMfTzUyylxch4T8Y92779JifANL1ypLKLzsgXtO0zKut6AvxRG+6AnECQtFMg\ni3JWjW8VY7HVpvCSRpIZtLEBoYfSsGEB8vkdhbJvz15cmwwtBX9bHGyiqGdG8NSi\nt8hsGA3CsRPAhEgvzTX5bXdp9P2SZYcc/+jbsOLy2i5ECApA/BAUFkWVxo3zpdQc\nTuRSdi628uP4JhrF+naNDmjtypIhcFWxTb9nS0Q7pNztRk8WeKJWRJOPpmUcOti9\ncwGgvFbTug=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e0 del Salento"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "University of Salento"
          }
        ],
        "organization_url": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unisalento.it"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "https://international.unisalento.it/about"
          }
        ],
        "organization_name": [
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universit\u00e0 del Salento"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Salento"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://mp.uu.se/Shibboleth.sso",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:servicedesk@uu.se"
            }
          ],
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:liferay-datordrift@its.uu.se"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://mp.uu.se/Shibboleth.sso",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://mp.uu.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://mp.uu.se/web/support/om-mp"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://mp.uu.se/web/support/om-mp"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Medarbetarportalen \u00e4r ett intran\u00e4t f\u00f6r anst\u00e4llda vid Uppsala universitet, men \u00e4r \u00e4ven \u00e5tkomlig f\u00f6r studenter och externa anv\u00e4ndare"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Staff Portal (Medarbetarportalen) is an intranet for employees at Uppsala University, but it's also available for students and external users"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Medarbetarportalen vid Uppsala universitet"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "The Staff Portal (Medarbetarportalen) at Uppsala university"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC3zCCAcegAwIBAgIJAKpDmQ/flLdVMA0GCSqGSIb3DQEBBQUAMBMxETAPBgNV\nBAMTCG1wLnV1LnNlMB4XDTEyMTAxMTE0NTAyOFoXDTIyMTAwOTE0NTAyOFowEzER\nMA8GA1UEAxMIbXAudXUuc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB\nAQCvr+kBJ2UuNB0YitaXHig2ksWqvlio4e3zfQpQUVM97ING6GwaLtHFBVuOyKgI\nUD5VbxE0f3ex33z1v4tOZrDzsHN+btVImK6hRs08jl1iWsvPgrxM5sT0l0HHdP11\nNnksCj3/P6FwApPMu/hPGsMiDUuzUGIsKer2gZkcuR5VudY6D3xjEzxqcNu77rjg\noXLFr8Khl6W1qSC2/6DofcyAzdukK/Pj28xmZ9iWMVGAiDC1G5EMDa71CaOhAAlF\npKBOeo85ctSHdWJxZcx37EdJ7YB7W0E5bMeHpUAMcgsCsaqrYhXopMqo2CySol9i\nwUqTzgHB0yM6ZrqyKoZ/O7SnAgMBAAGjNjA0MBMGA1UdEQQMMAqCCG1wLnV1LnNl\nMB0GA1UdDgQWBBR3asu+pkmaby5q/Gu+oVaWIzRoWDANBgkqhkiG9w0BAQUFAAOC\nAQEAC7DqIlOLe7BHTLteri038WO0MqGgQ1RHXhginDAEx+UekwD1P5UIxZaqnkQf\nisCyOw10y5ZhSoc5FCNYA1EDRUKHAabivcRBbrL6GXi14KUTOORnUmMLzUgeuAlq\nw7f1NHlFokb1v7FvN/WKxf37z8Cy49Sfg9Hg6lv+jNobb5lSBjwnTICfCl+ffdFu\nxHXT67mQsDSoiBiExsGPjtqxbrVy2v9WV1Oup6UjXIgOacpaDNErD1XzAkQP6LD4\nt9uEzq8Qiu8ImRG9SyPDd76umF5tLtg53EHaK1o2LnSU4CyjsnUX5Np1l13rMKaR\nOhr8KLKt6tC/JZ059e8ENxrN7g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://mp.uu.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://mp.uu.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://mp.uu.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "sv",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "Medarbetarportalen vid Uppsala universitet"
                },
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "The Staff Portal (Medarbetarportalen) at Uppsala university"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "displayName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "givenName",
                  "is_required": "false",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.42",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "1",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.ths.se/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Kennerberg"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:owe.kennerberg@ths.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Owe"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "S\u00e4ll"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:peter@jhsupport.se"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Peter"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ths.se/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ths.se/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ths.se/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ths.se/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ths.se:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ths.se:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ths.se"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider f\u00f6r Teologiska h\u00f6gskolan Stockholm"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity Provider for Stockholm School of Theology"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.ths.se/idp/images/ths.png",
                    "height": "100",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "100"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Teologiska h\u00f6gskolan Stockholm"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Stockholm School of Theology"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAOoBGXpQZ8B+9yfZGw0M8PEB20fJMA0GCSqGSIb3DQEB\nCwUAMBUxEzARBgNVBAMMCmlkcC50aHMuc2UwHhcNMTUxMTExMDkxOTA0WhcNMzUx\nMTExMDkxOTA0WjAVMRMwEQYDVQQDDAppZHAudGhzLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAgneCxYbvQuIbSwkBuEHEAGJrWOe5usqevjBxnRIY\nIB3uR0AvVvJokrTWosSuzqRpbEUsgpG0sXH+D/BuvCCciLkzXOr6cog0q68ymz4d\nQegUSEAuU0CBzGK7qzb5UgQYuo7gopIAAfk+870o4FlaiZtkP9Ap/EjqvnrULL8p\nVJi69skI5gz/ua/boDXOpbsmWuzCAqD9Kzz9sYnwz14mfJX5hb1M5M2H5kDFaYiM\nzKT1dClICSlBUO59ijtBHKTGZKqR+VNn5Ik4LheDRUgTeiEmW+nrW3VNVR0ejayP\niqSoKvumaAaCVh1dwXNAKTYigMVQj5RN1xxrey6JHDtKTQIDAQABo1swWTAdBgNV\nHQ4EFgQUcqxMRNMBh6u+I+kuztUyzRv031AwOAYDVR0RBDEwL4IKaWRwLnRocy5z\nZYYhaHR0cHM6Ly9pZHAudGhzLnNlL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\nCwUAA4IBAQANq+u3kuueZ3Lrcy9fjpyvIQznBuINMD6nQmb3NEDOLu8klJewV5QF\nS2pMebzvzTmsEpe9Ru9JprMcAp7i3izSLYjOqJ9tVzGsGNBmtPQe5uUwrIlbNZue\nGtNimkNWHvS+uUcx2ACLcR3jt/bZ0DSU3YE5+zGFZKPZlO+5f9/YCa4xEhTl7OT/\nwO/kQ//XXJcoiwGR2aq5ap97qHaABMck78c+ABw4GCyovCmvlhPDoy8W4qILu1nh\nr8XPB8eZnOjSSAwbmJaLPThPRCbFVWtlPXpsUknV3QJccDKJe8+P/u+J2qDSziy/\nGPrwUbfYjDaDH2pZjUisQoVv15w0sWPt"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVAIwLUJoKnkoTdYnnhVC1hx97HazRMA0GCSqGSIb3DQEB\nCwUAMBUxEzARBgNVBAMMCmlkcC50aHMuc2UwHhcNMTUxMTExMDkxODUyWhcNMzUx\nMTExMDkxODUyWjAVMRMwEQYDVQQDDAppZHAudGhzLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAs+wFy6Bii4RxuP5xBGLV2ODTADmnAYjWdQ/SAaSF\nGkM1tHf/dH5+9nyIpz23PXSeO4X59arZC4eK71duqU7ajm2+LLKiLBguofbwlaK7\nIa46ReI9WkIQBSyRnCLC8dDEC/1G1gsh9up4jvSgJO/BwtchvO23iFnoWGa5BwxT\nHrieHSBIqixP8/Zd4v3eVoPTmetyRQVstC7tc8AK6AB47zha1nxd+sRqmsVbsaef\nDW8v5rBm++Dn+m8Im2cF9AAytz8PM7vSQSx6sTixTTHBddD16vBMnaTKHpEdrYb4\naK8sDS8ku2SXmsEGMmNSXo6CNFR8OZVpO4DHjZO94GwnFQIDAQABo1swWTAdBgNV\nHQ4EFgQUDd8LOI1MHYCc/x2uQ+F6edwmMJswOAYDVR0RBDEwL4IKaWRwLnRocy5z\nZYYhaHR0cHM6Ly9pZHAudGhzLnNlL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\nCwUAA4IBAQA5lFkOXXGkKwmKuAzA6ETKdvGfp8TloxdKrzQ9/2wwCZdLz/OVLhUe\nf00ILSO9SyDrkxTsnlUUkFqFR7zw/PwD/ZbRCH1zDPqz2fY8yg3uC9LM++r8ookt\nYx2kwRAnwS6N1fRC3/oiCoWuY7HS+7MYTrTqOHoWlzoLJW/0MXdfN1tFJdMrluWq\nWvXwtq5B+PQLjb42BmhBA59C06dCNyiJdYcGt6eqPFaGizjdLH/QTQkeD5v8ik2k\n0so3ocZPpR4cZKhTDoiQxDywpnP+ZJ/3UfwtzK4T9WTiip7alSqaOrs0aV2VHK54\n58VA8eiHnY+wTtxtm1m81aaHWm/CRe0g"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFDCCAfygAwIBAgIVALtpImI1/O45aUeC6eV2R+MYH/uvMA0GCSqGSIb3DQEB\nCwUAMBUxEzARBgNVBAMMCmlkcC50aHMuc2UwHhcNMTUxMTExMDkxODU4WhcNMzUx\nMTExMDkxODU4WjAVMRMwEQYDVQQDDAppZHAudGhzLnNlMIIBIjANBgkqhkiG9w0B\nAQEFAAOCAQ8AMIIBCgKCAQEAtUDQ13J3qxlTQ/bzLet+Y4xcjRkHeIWvQfUXIDDY\nTl2PAFdvfTE63A77c/EGE/fE3x3Gqd/pLoOXF9xxrYt1CEUWSgLuMP6JYK2q3ByI\nztL4AQRw6t313KRzsDH+qSnrA8m4o6w2ORx9Q8V6LSUfBXcqiUH8IdSJ2nkK4AEF\n/GDHtvYR0t3vxnARqa5bUtlBXc3lW8i4yet4lMnVVoDtvWQfVJ5i1AE3Uzys+RDK\ngoRoKfHlayqiDYyuVmgP1wEB5b3yb5htTIvlrVAv3IBStRlmeDHPqc1ovrldOZFW\nmfhH9PB0qPVf6dsRRBBKO1yJJc7A4gRXjHJdQ8wMcvAYcwIDAQABo1swWTAdBgNV\nHQ4EFgQUeHLwS/y7FmX87CIT3IpanavrYW8wOAYDVR0RBDEwL4IKaWRwLnRocy5z\nZYYhaHR0cHM6Ly9pZHAudGhzLnNlL2lkcC9zaGliYm9sZXRoMA0GCSqGSIb3DQEB\nCwUAA4IBAQCpSdEgMGI8XdHrUGfAAIqcYACudfOp80/rqpyOGPtO45qkBuYKrp3D\nyTts4EtDi3k5XCowH0TS9ODjgBCe/lOmDg05Ew/1dDc6pyxNUqMp1zRnmZ5DdzP8\nUxW2KAoh9mS3/6cbko76KQhxugnk0GDJa3OLGal3IKLg2aKh6iGQbdPgqPSqKeBV\n2SevIVPNCfKl9VGaxbkX9CGRLlB1YK3GBWUp4TvbsGC8+iM/+dXIQQy4Hh25vAzv\nSzSV1msy19QgIe/+OhBeq1VnedxuAXSKqpF+W7kTHhmq6f6bMUtlbkqJeeHiNQK6\nxAdB19mh1plahNrAaEfu6Ldetyz9iulY"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Teologiska h\u00f6gskolan Stockholm"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Stockholm School of Theology"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ths.se/english"
          },
          {
            "lang": "sv",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ths.se"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "THS"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.smu.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tdoan@smu.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Tommy Doan"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.smu.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.smu.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.smu.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.smu.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.smu.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.smu.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "smu.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Logon service for Southern Methodist University"
                  }
                ],
                "logo": [
                  {
                    "text": "https://idp.smu.edu/SMU-logo-1.png",
                    "lang": "en",
                    "height": "80",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "260"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Southern Methodist University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDFzCCAf+gAwIBAgIUMOoO5C0NUcKkug58h0G2G7wcwLswDQYJKoZIhvcNAQEF\nBQAwFjEUMBIGA1UEAxMLaWRwLnNtdS5lZHUwHhcNMTIwNTMwMDUyNDE2WhcNMzIw\nNTMwMDUyNDE2WjAWMRQwEgYDVQQDEwtpZHAuc211LmVkdTCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBALAqpkRq0LXHJ02/f2JBuFjLq4nC9q5OFaQB/iE3\nCPJJ1+C3JNp+i49vQZFlMq5baLE6h4w7kJ/3w7VH1VEsQqT5jcgmI+RdfJxGkb+n\nIJAOBdHQJKakZBnMbqwEnCj+E2UJrY65NkE42obLDr5ztJLC5G/4l+EEuGH2Haa1\ntshIn5eVxspiBSYgQvvbdCTNNpWiTtQj368OZU8dEHXUH7igKCtjFolnf0pp+hZY\n3QqCDDLVnnRLtu8e1/R/v8TXrmAPnzXtmG7oji3h7Ng9qmUi2z8wuhi6XjLmsL85\nbiPj8FWOpENBngX2/lYgiHJ/XAco62jg9r/vfbKpwvuF/UkCAwEAAaNdMFswOgYD\nVR0RBDMwMYILaWRwLnNtdS5lZHWGImh0dHBzOi8vaWRwLnNtdS5lZHUvaWRwL3No\naWJib2xldGgwHQYDVR0OBBYEFMqNi96ilJQDUjUXfzSFk6czjb5QMA0GCSqGSIb3\nDQEBBQUAA4IBAQAXNoWs60LcNsPtwO2QwdA3Hw/QbA09MUD43bUjyF9xBNfXH2G/\nCGnzcOGVgtACKAkLJwFLK4iHf9/GiXFGqVMtjaaft+B9SFh2kwK7cuE0GbhiUN/u\nHC1/dvaXVBzHTm9+CMsKPNbuv4W6tB45wK4d1DoYBq3rH+COwv/6xn+v320SbF79\nzq6H/1+gZBLHh4L/sUJLWXksJA+3axQt0YthytYVp2sDK4yx9LnPIkUt1nE7CxY7\nmRJSSLjES5YYMYZG1NFfLbBgSoJo5jv+aTCmFTFApialLSb7DgOij0DUH+HwYeD4\nIr3OTZqI0Gdw9VqbNRO6qHpf+GgkmMJN1mVW"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Southern Methodist University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.smu.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Southern Methodist University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.ifal.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Adriano da Silva Araujo"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "adriano.araujo@ifal.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.ifal.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID2DCCAsACAQAwDQYJKoZIhvcNAQEFBQAwgbExLDAqBgNVBAoTI0lGQUwgLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkZSBBbGFnb2FzMQwwCgYDVQQLEwNEVEkxKTAnBgkq\nhkiG9w0BCQEWGmFkcmlhbm8uYXJhdWpvQGlmYWwuZWR1LmJyMQ8wDQYDVQQHEwZN\nYWNlaW8xEDAOBgNVBAgTB0FsYWdvYXMxCzAJBgNVBAYTAkJSMRgwFgYDVQQDEw9p\nZHAuaWZhbC5lZHUuYnIwHhcNMTUwNTA2MTQyMjMxWhcNMTgwNTA1MTQyMjMxWjCB\nsTEsMCoGA1UEChMjSUZBTCAtIEluc3RpdHV0byBGZWRlcmFsIGRlIEFsYWdvYXMx\nDDAKBgNVBAsTA0RUSTEpMCcGCSqGSIb3DQEJARYaYWRyaWFuby5hcmF1am9AaWZh\nbC5lZHUuYnIxDzANBgNVBAcTBk1hY2VpbzEQMA4GA1UECBMHQWxhZ29hczELMAkG\nA1UEBhMCQlIxGDAWBgNVBAMTD2lkcC5pZmFsLmVkdS5icjCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAKlJSdX8bYPSSIWiiMIkOc/eKEu3Oa1FiyK56Qtr\nGq1v4nQ8gNaasT0f/US6S6uWxacNv6/+Y5Z9gR30pMXHr76UW1u6D+5aag86g6VM\nFSB+Nx7gqyr7BClrpTBtheDRZzCjeSe1CBDNfCZ9srEs6tnzxABBoeptyKK5O/WT\nf9c159eHzMatZ5yr3GIP3UeQhaZKyRUcDGdStWk8goZ/kNw+4CKbRhTSDARLDPvH\nLvh63Z+oT30stuPNm68JW+mGqtjUHHf9cIOWkXh3DCZwiUFo4vopOLDvk9O3/saO\nhfyYkRgwamC/gMCR7BF/o4q7p+HRlxYUzmKCrDjpq2CL988CAwEAATANBgkqhkiG\n9w0BAQUFAAOCAQEAfwxODo/74q6lPMURqiwijkAa6HcpLNojw9tcJqQ0fs28srZE\nuouwBWatoB85jOG7sz4R9Vrfw870NdRLkunB6NwtredpvA57Vr14z8LaDK6JRDgn\njMd+RVgBnMy4g3fxsjVZBmJNqZ98q3tyj5mZ0oV591kOmiKyX1ytUIjOj4yaWvmR\nH1qx/y9tGV+Eb5Jy6jbQLG16B+93zPl1fRf8BgPuLjbsjq+f0xvXUkL+8Gi9TBv3\nY2F2PrpyMw88ibt/qREHIIa3uIdNu3P0Tq0MvEY51PFkAWXC5J/eocGLZbLUwbVL\nSY7q0H0YJyD8xlGRdz+RsDK4pv1PWQ+9OilkLA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ifal.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ifal.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.ifal.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.ifal.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.ifal.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.ifal.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.ifal.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.ifal.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifal.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ifal.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFAL - Instituto Federal de Alagoas"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "IFAL - Instituto Federal de Alagoas"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFAL - Instituto Federal de Alagoas"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IFAL - Instituto Federal de Alagoas"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIID2DCCAsACAQAwDQYJKoZIhvcNAQEFBQAwgbExLDAqBgNVBAoTI0lGQUwgLSBJ\nbnN0aXR1dG8gRmVkZXJhbCBkZSBBbGFnb2FzMQwwCgYDVQQLEwNEVEkxKTAnBgkq\nhkiG9w0BCQEWGmFkcmlhbm8uYXJhdWpvQGlmYWwuZWR1LmJyMQ8wDQYDVQQHEwZN\nYWNlaW8xEDAOBgNVBAgTB0FsYWdvYXMxCzAJBgNVBAYTAkJSMRgwFgYDVQQDEw9p\nZHAuaWZhbC5lZHUuYnIwHhcNMTUwNTA2MTQyMjMxWhcNMTgwNTA1MTQyMjMxWjCB\nsTEsMCoGA1UEChMjSUZBTCAtIEluc3RpdHV0byBGZWRlcmFsIGRlIEFsYWdvYXMx\nDDAKBgNVBAsTA0RUSTEpMCcGCSqGSIb3DQEJARYaYWRyaWFuby5hcmF1am9AaWZh\nbC5lZHUuYnIxDzANBgNVBAcTBk1hY2VpbzEQMA4GA1UECBMHQWxhZ29hczELMAkG\nA1UEBhMCQlIxGDAWBgNVBAMTD2lkcC5pZmFsLmVkdS5icjCCASIwDQYJKoZIhvcN\nAQEBBQADggEPADCCAQoCggEBAKlJSdX8bYPSSIWiiMIkOc/eKEu3Oa1FiyK56Qtr\nGq1v4nQ8gNaasT0f/US6S6uWxacNv6/+Y5Z9gR30pMXHr76UW1u6D+5aag86g6VM\nFSB+Nx7gqyr7BClrpTBtheDRZzCjeSe1CBDNfCZ9srEs6tnzxABBoeptyKK5O/WT\nf9c159eHzMatZ5yr3GIP3UeQhaZKyRUcDGdStWk8goZ/kNw+4CKbRhTSDARLDPvH\nLvh63Z+oT30stuPNm68JW+mGqtjUHHf9cIOWkXh3DCZwiUFo4vopOLDvk9O3/saO\nhfyYkRgwamC/gMCR7BF/o4q7p+HRlxYUzmKCrDjpq2CL988CAwEAATANBgkqhkiG\n9w0BAQUFAAOCAQEAfwxODo/74q6lPMURqiwijkAa6HcpLNojw9tcJqQ0fs28srZE\nuouwBWatoB85jOG7sz4R9Vrfw870NdRLkunB6NwtredpvA57Vr14z8LaDK6JRDgn\njMd+RVgBnMy4g3fxsjVZBmJNqZ98q3tyj5mZ0oV591kOmiKyX1ytUIjOj4yaWvmR\nH1qx/y9tGV+Eb5Jy6jbQLG16B+93zPl1fRf8BgPuLjbsjq+f0xvXUkL+8Gi9TBv3\nY2F2PrpyMw88ibt/qREHIIa3uIdNu3P0Tq0MvEY51PFkAWXC5J/eocGLZbLUwbVL\nSY7q0H0YJyD8xlGRdz+RsDK4pv1PWQ+9OilkLA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFAL - Instituto Federal de Alagoas"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IFAL - Instituto Federal de Alagoas"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifal.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ifal.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFAL - Instituto Federal de Alagoas"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "IFAL - Instituto Federal de Alagoas"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso.legendonlineservices.co.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@legendware.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Robertson"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul.robertson@legendware.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.legendonlineservices.co.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_instant": "2011-08-12T08:07:20Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Serco Leisure Operating Limited: Legend Online Services"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.legendware.co.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Serco Leisure Operating Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.legendonlineservices.co.uk/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.legendonlineservices.co.uk/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.legendonlineservices.co.uk/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sso.legendonlineservices.co.uk/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.legendonlineservices.co.uk/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://sso.legendonlineservices.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://sso.legendonlineservices.co.uk/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIICzTCCAbWgAwIBAgIJAJobCx55lv5EMA0GCSqGSIb3DQEBBQUAMA0xCzAJBgNV\n\t\t\t\t\t\tBAMTAncxMB4XDTExMDgxMTA4NDkyNFoXDTIxMDgwODA4NDkyNFowDTELMAkGA1UE\n\t\t\t\t\t\tAxMCdzEwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDhMOvBTMzwJXzE\n\t\t\t\t\t\tJ59XFKXaqeI5zLdnA0YzdFsPnbLOlf/5+qjgRb86LlR1hYxDReSbKz1nm3H6eN9D\n\t\t\t\t\t\t5IHZ/fZgdnvDblKno/xK0emOGRQ7ILDoHm9HTrpcd+qwzOGsqhN3dtZxMvGHv+bz\n\t\t\t\t\t\tmULMepXiKk4KyqUp/pMuv52n0lshyJG5mJ0SctJEptUx/1IhXn6OhDg3fzvWiWQ9\n\t\t\t\t\t\t6lgDiCg5TZ9p6r0FgEaAfp+EKfLIQKohkD8j1r88sSzIqgTW8TR+k0IOgSKydpiL\n\t\t\t\t\t\tUPC8KqVFAATA7YisCxSwQL0Ol/km8h9M6I61U5sMzxQb96OjJNkJ0XkkqKpdJiQg\n\t\t\t\t\t\tI0m6HiVnAgMBAAGjMDAuMA0GA1UdEQQGMASCAncxMB0GA1UdDgQWBBTcBGviv7Uv\n\t\t\t\t\t\tSMf+iglk0SBxtdd8KzANBgkqhkiG9w0BAQUFAAOCAQEAicU/pEyeTf8EhIx3Hz/L\n\t\t\t\t\t\ttN0lUevjM3RX5cpXHPnHGeO6lidknaaBi7e0Wnkbkur8VuKh9aTOENV+yNH4cQA+\n\t\t\t\t\t\tePNQefs0FqlzHiVMNFrb6nTzA4IXHCqLKkLWilFuQ17z+wih38PFjzqucXKZViow\n\t\t\t\t\t\tMWaNgEGEyYBOyAKND5MtdS9WSQImqOn/fnx5PM6brLascO5a8ZBp96Zky7WvN28t\n\t\t\t\t\t\t/eV2xzqBtVt3O87D1ta+yIbw0p2yXlWogVQNc4u6OKOcA9Rv2dO1UVPCGCsQCtdp\n\t\t\t\t\t\tt3NdGb/WFfWxBSl2R2zNf9/vhRN+Senh5iasZaoZyaGSF1SZtyskYNDLshiBG/FS\n\t\t\t\t\t\t7Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.legendonlineservices.co.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sso.legendonlineservices.co.uk/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sso.legendonlineservices.co.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sso.legendonlineservices.co.uk/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sso.legendonlineservices.co.uk/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sso.legendonlineservices.co.uk/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.service4mobility.com/europe",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:support@sop.co.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Support"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Basedow"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:steffen.basedow@sop.co.at"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Steffen"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://www.service4mobility.com/europe",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-04-07T12:54:54Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Mobility-Online"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.service4mobility.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SOP Hilmbauer & Mauberger GmbH & Co.KG"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "response_location": "https://www.service4mobility.com/europe/saml/LogoutServiceHTTPRedirectResponse",
              "location": "https://www.service4mobility.com/europe/saml/LogoutServiceHTTPRedirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.service4mobility.com/europe/saml/LogoutServiceSOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "response_location": "https://www.service4mobility.com/europe/saml/LogoutServiceHTTPRedirectResponse",
              "location": "https://www.service4mobility.com/europe/saml/LogoutServiceHTTPPost",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "authn_requests_signed": "true",
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The High-End Standard Software for the web-based\n\t\t\t\t\tmanagement of international educational cooperation and all types of academic\n\t\t\t\t\tmobilities."
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.service4mobility.com/europe/images/mobility-online.png",
                    "height": "45",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "255"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Mobility-Online"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "want_assertions_signed": "true",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFtDCCBJygAwIBAgIQJF23Zp+qyEMZ5HUvD3iMRDANBgkqhkiG9w0BAQUFADCB\n\t\t\t\t\t\tvDELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMR8wHQYDVQQL\n\t\t\t\t\t\tExZWZXJpU2lnbiBUcnVzdCBOZXR3b3JrMTswOQYDVQQLEzJUZXJtcyBvZiB1c2Ug\n\t\t\t\t\t\tYXQgaHR0cHM6Ly93d3cudmVyaXNpZ24uY29tL3JwYSAoYykxMDE2MDQGA1UEAxMt\n\t\t\t\t\t\tVmVyaVNpZ24gQ2xhc3MgMyBJbnRlcm5hdGlvbmFsIFNlcnZlciBDQSAtIEczMB4X\n\t\t\t\t\t\tDTEyMDQxNzAwMDAwMFoXDTE4MDQxMTIzNTk1OVowgbcxCzAJBgNVBAYTAkFUMQ8w\n\t\t\t\t\t\tDQYDVQQIEwZWaWVubmExDzANBgNVBAcUBlZpZW5uYTEuMCwGA1UEChQlU09QIEhp\n\t\t\t\t\t\tbG1iYXVlciAmIE1hdWJlcmdlciBHbWJIICYgQ29LRzEzMDEGA1UECxQqVGVybXMg\n\t\t\t\t\t\tb2YgdXNlIGF0IHd3dy52ZXJpc2lnbi5jb20vcnBhIChjKTA1MSEwHwYDVQQDFBh3\n\t\t\t\t\t\td3cuc2VydmljZTRtb2JpbGl0eS5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQDImV6SV6GEilkTyCyeQyTBxPHlsbldKUPfLNpaAiyPBNZ0J5R9kC8q\n\t\t\t\t\t\tc+RG5tKxNRgcuEz3s2SIghle8MSEhjtaGOYf/XVAHKnNGaPRvxFa9AOlxa2xBUXP\n\t\t\t\t\t\tk9NIh1G0Zx/GBcKY0BHVv1898c3LlMAWjYHO4XWzjvtn4YYXM8m3m5gURinNLKev\n\t\t\t\t\t\tsVdchBYmaV+IWwpBRyx7KDEdiE94ibHbdf8IrP6hndX4HI1JWz8MdxQzHIVvASck\n\t\t\t\t\t\tm+jzQhSFuBx4GXDqmPFPfM58nrWBSJDcrOlf8a2WzfBYUJZNECttBK+9F4ORzn9y\n\t\t\t\t\t\tsiQdBeUEEca0zdP8A9KfWnDUIQ9T6FlvAgMBAAGjggGzMIIBrzAJBgNVHRMEAjAA\n\t\t\t\t\t\tMAsGA1UdDwQEAwIFoDBEBgNVHSAEPTA7MDkGC2CGSAGG+EUBBxcDMCowKAYIKwYB\n\t\t\t\t\t\tBQUHAgEWHGh0dHBzOi8vd3d3LnZlcmlzaWduLmNvbS9ycGEwQQYDVR0fBDowODA2\n\t\t\t\t\t\toDSgMoYwaHR0cDovL1NWUkludGwtRzMtY3JsLnZlcmlzaWduLmNvbS9TVlJJbnRs\n\t\t\t\t\t\tRzMuY3JsMCgGA1UdJQQhMB8GCCsGAQUFBwMBBggrBgEFBQcDAgYJYIZIAYb4QgQB\n\t\t\t\t\t\tMHIGCCsGAQUFBwEBBGYwZDAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AudmVyaXNp\n\t\t\t\t\t\tZ24uY29tMDwGCCsGAQUFBzAChjBodHRwOi8vU1ZSSW50bC1HMy1haWEudmVyaXNp\n\t\t\t\t\t\tZ24uY29tL1NWUkludGxHMy5jZXIwbgYIKwYBBQUHAQwEYjBgoV6gXDBaMFgwVhYJ\n\t\t\t\t\t\taW1hZ2UvZ2lmMCEwHzAHBgUrDgMCGgQUS2u5KJYGDLvQUjibKaxLB4shBRgwJhYk\n\t\t\t\t\t\taHR0cDovL2xvZ28udmVyaXNpZ24uY29tL3ZzbG9nbzEuZ2lmMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQAJgRv/2HJ0856/SkHlepMDyAnrr/uRF2LIRwONAAV2V0vt7dW0Te4e\n\t\t\t\t\t\tfvUtR/npPPcERdO5rZ729xswY/7uE2ZsK21PVqF+QMKSSTXcoFLe+47KcWaao2+U\n\t\t\t\t\t\tr9NQ4KIwJcbCqeXfTLqYq7Dxfn1UWBa6xMPflPZhYIevuF26t/nzgQLcmF4olosN\n\t\t\t\t\t\tqGTo2CaqSN1Cj9Bjydh74BUcamnmNdUFrQ0pU/29XMEFMtacoN8ohvXcwEn2oCB5\n\t\t\t\t\t\tmQ/83slRUxDdY+CTn/2Cb0FMFXcE6w4HBT4E5+aXDS+SRqtb/Bw/sGgCNPkIFYvg\n\t\t\t\t\t\tTp8UjvFkYCREanI8dOGH+8lgNMXPmYGk"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFtDCCBJygAwIBAgIQJF23Zp+qyEMZ5HUvD3iMRDANBgkqhkiG9w0BAQUFADCB\n\t\t\t\t\t\tvDELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMR8wHQYDVQQL\n\t\t\t\t\t\tExZWZXJpU2lnbiBUcnVzdCBOZXR3b3JrMTswOQYDVQQLEzJUZXJtcyBvZiB1c2Ug\n\t\t\t\t\t\tYXQgaHR0cHM6Ly93d3cudmVyaXNpZ24uY29tL3JwYSAoYykxMDE2MDQGA1UEAxMt\n\t\t\t\t\t\tVmVyaVNpZ24gQ2xhc3MgMyBJbnRlcm5hdGlvbmFsIFNlcnZlciBDQSAtIEczMB4X\n\t\t\t\t\t\tDTEyMDQxNzAwMDAwMFoXDTE4MDQxMTIzNTk1OVowgbcxCzAJBgNVBAYTAkFUMQ8w\n\t\t\t\t\t\tDQYDVQQIEwZWaWVubmExDzANBgNVBAcUBlZpZW5uYTEuMCwGA1UEChQlU09QIEhp\n\t\t\t\t\t\tbG1iYXVlciAmIE1hdWJlcmdlciBHbWJIICYgQ29LRzEzMDEGA1UECxQqVGVybXMg\n\t\t\t\t\t\tb2YgdXNlIGF0IHd3dy52ZXJpc2lnbi5jb20vcnBhIChjKTA1MSEwHwYDVQQDFBh3\n\t\t\t\t\t\td3cuc2VydmljZTRtb2JpbGl0eS5jb20wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\n\t\t\t\t\t\tggEKAoIBAQDImV6SV6GEilkTyCyeQyTBxPHlsbldKUPfLNpaAiyPBNZ0J5R9kC8q\n\t\t\t\t\t\tc+RG5tKxNRgcuEz3s2SIghle8MSEhjtaGOYf/XVAHKnNGaPRvxFa9AOlxa2xBUXP\n\t\t\t\t\t\tk9NIh1G0Zx/GBcKY0BHVv1898c3LlMAWjYHO4XWzjvtn4YYXM8m3m5gURinNLKev\n\t\t\t\t\t\tsVdchBYmaV+IWwpBRyx7KDEdiE94ibHbdf8IrP6hndX4HI1JWz8MdxQzHIVvASck\n\t\t\t\t\t\tm+jzQhSFuBx4GXDqmPFPfM58nrWBSJDcrOlf8a2WzfBYUJZNECttBK+9F4ORzn9y\n\t\t\t\t\t\tsiQdBeUEEca0zdP8A9KfWnDUIQ9T6FlvAgMBAAGjggGzMIIBrzAJBgNVHRMEAjAA\n\t\t\t\t\t\tMAsGA1UdDwQEAwIFoDBEBgNVHSAEPTA7MDkGC2CGSAGG+EUBBxcDMCowKAYIKwYB\n\t\t\t\t\t\tBQUHAgEWHGh0dHBzOi8vd3d3LnZlcmlzaWduLmNvbS9ycGEwQQYDVR0fBDowODA2\n\t\t\t\t\t\toDSgMoYwaHR0cDovL1NWUkludGwtRzMtY3JsLnZlcmlzaWduLmNvbS9TVlJJbnRs\n\t\t\t\t\t\tRzMuY3JsMCgGA1UdJQQhMB8GCCsGAQUFBwMBBggrBgEFBQcDAgYJYIZIAYb4QgQB\n\t\t\t\t\t\tMHIGCCsGAQUFBwEBBGYwZDAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AudmVyaXNp\n\t\t\t\t\t\tZ24uY29tMDwGCCsGAQUFBzAChjBodHRwOi8vU1ZSSW50bC1HMy1haWEudmVyaXNp\n\t\t\t\t\t\tZ24uY29tL1NWUkludGxHMy5jZXIwbgYIKwYBBQUHAQwEYjBgoV6gXDBaMFgwVhYJ\n\t\t\t\t\t\taW1hZ2UvZ2lmMCEwHzAHBgUrDgMCGgQUS2u5KJYGDLvQUjibKaxLB4shBRgwJhYk\n\t\t\t\t\t\taHR0cDovL2xvZ28udmVyaXNpZ24uY29tL3ZzbG9nbzEuZ2lmMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQAJgRv/2HJ0856/SkHlepMDyAnrr/uRF2LIRwONAAV2V0vt7dW0Te4e\n\t\t\t\t\t\tfvUtR/npPPcERdO5rZ729xswY/7uE2ZsK21PVqF+QMKSSTXcoFLe+47KcWaao2+U\n\t\t\t\t\t\tr9NQ4KIwJcbCqeXfTLqYq7Dxfn1UWBa6xMPflPZhYIevuF26t/nzgQLcmF4olosN\n\t\t\t\t\t\tqGTo2CaqSN1Cj9Bjydh74BUcamnmNdUFrQ0pU/29XMEFMtacoN8ohvXcwEn2oCB5\n\t\t\t\t\t\tmQ/83slRUxDdY+CTn/2Cb0FMFXcE6w4HBT4E5+aXDS+SRqtb/Bw/sGgCNPkIFYvg\n\t\t\t\t\t\tTp8UjvFkYCREanI8dOGH+8lgNMXPmYGk"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "0",
              "location": "https://www.service4mobility.com/europe/saml/SAMLAssertionConsumer",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "index": "1",
              "location": "https://www.service4mobility.com/europe/saml/SAMLAssertionConsumer",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "false"
            }
          ],
          "attribute_consuming_service": [
            {
              "service_name": [
                {
                  "lang": "en",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ServiceName",
                  "text": "https://www.service4mobility.com/europe"
                }
              ],
              "requested_attribute": [
                {
                  "friendly_name": "cn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "displayName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.16.840.1.113730.3.1.241",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "eduPersonPrincipalName",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:1.3.6.1.4.1.5923.1.1.1.6",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "mail",
                  "is_required": "true",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.3",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "o",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.10",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "ou",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.11",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "postalAddress",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.16",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "sn",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.4",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "title",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:2.5.4.12",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                },
                {
                  "friendly_name": "uid",
                  "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                  "name": "urn:oid:0.9.2342.19200300.100.1.1",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&RequestedAttribute"
                }
              ],
              "index": "0",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeConsumingService",
              "is_default": "true"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://www.test.grayzone.ladok.se/gui-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://www.test.grayzone.ladok.se/gui-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.test.grayzone.ladok.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.test.grayzone.ladok.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.test.grayzone.ladok.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.test.grayzone.ladok.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.test.grayzone.ladok.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://www.test.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://www.test.grayzone.ladok.se/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "information_url": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "https://www.ladok.se/"
                  }
                ],
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige (Ladok)"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Administration system for higher education in Sweden (Ladok)"
                  }
                ],
                "logo": [
                  {
                    "text": "https://www.test.grayzone.ladok.se/_system/00/images/logo-00.jpg",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.test.grayzone.ladok.se"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok www.test.grayzone.ladok.se"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://www.test.grayzone.ladok.se/gui-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "www.test.grayzone.ladok.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIJAMP0BTvafynIMA0GCSqGSIb3DQEBCwUAMCUxIzAhBgNV\nBAMTGnd3dy50ZXN0LmdyYXl6b25lLmxhZG9rLnNlMB4XDTE2MDMxNDA4NTMyMloX\nDTI2MDMxMjA4NTMyMlowJTEjMCEGA1UEAxMad3d3LnRlc3QuZ3JheXpvbmUubGFk\nb2suc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCT4AnqNkQ9YTwA\nuJQ1J+xHn/XkyKOGrnnvr3ELgMZNC9FCbb4T6WwsUMJbxdICG8SY+l9+VS7yhEXz\nZS252ilRyEDf5B9/gjvUosaNvoi2zPyXJWKsEXEj9dqTqOqpYBgVs15bOoh2NdVI\nuocLPJLzy3ot2gBG/sfH91mNeryQ6KxoMlEemZEe8ITh5wJFvTuukrzo08P1QbP0\n40AH6EzSyfZLIfyht75TNmJXQHVK8ECl9EtzAARJhH8JTw2BhYFEtnm6WiVLfStN\nshnKJXLoOaJxNK1cU0DOdOMnDtuO04CN0edU+lQmXlIJEveTP4qS1TldHvELZJ/R\n8zw9Dce/AgMBAAGjczBxMFAGA1UdEQRJMEeCGnd3dy50ZXN0LmdyYXl6b25lLmxh\nZG9rLnNlhilodHRwczovL3d3dy50ZXN0LmdyYXl6b25lLmxhZG9rLnNlL2d1aS1z\ncDAdBgNVHQ4EFgQUzi69O/vgiRvYYrKqVi5cPDNYR7AwDQYJKoZIhvcNAQELBQAD\nggEBADskNl+vv7YpipCp40BgN166XnBcfTilZvaN8yZ0XPARWTx1v84n4qERUw+s\nL3swnWDKTQ0bx8pn8LFVcgDX56onTNBMRzqNmJ0Bv1tgo8bVXk9Q0qPz/ANrx5TP\nRDeU+wX6TCxr2d0ggvqwaWQKQKK2y7Z9ij4ccimPSvdZBqRiGPjVaGKCB4hzotdZ\nFyb7Q2VzAorfD08QY9JIvT5Tv8P2xDxZHK/2l/QX/bDqUT+jY5wzW0ksFghkkPZD\nDD5IhrCh9D0g84j5WdUrRQS4/aT4nXGsSVLHkmAfsw0K23BDmU2hjhSqsoiyA470\n75H9o1PKSvHR9qX0uJ8HbrBxU54="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=www.test.grayzone.ladok.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://www.test.grayzone.ladok.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://www.test.grayzone.ladok.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.test.grayzone.ladok.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.test.grayzone.ladok.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://www.test.grayzone.ladok.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://www.test.grayzone.ladok.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://www.test.grayzone.ladok.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://www.test.grayzone.ladok.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://www.test.grayzone.ladok.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://copaiba.unifesspa.edu.br/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Fabio Torres"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "fabio.torres@unifesspa.edu.br"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://copaiba.unifesspa.edu.br/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "pt-br",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://www.rnp.br/_arquivo/servicos/Politica_CAFe_IDP_final.pdf"
              }
            ],
            "registration_instant": "2010-01-01T00:00:00Z",
            "registration_authority": "http://cafe.rnp.br",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEGDCCAwACAQAwDQYJKoZIhvcNAQEFBQAwgdExQjBABgNVBAoTOVVOSUZFU1NQ\nQSAtIFVuaXZlcnNpZGFkZSBGZWRlcmFsIGRvIFN1bCBlIFN1ZGVzdGUgZG8gUGFy\nYTENMAsGA1UECxMEQ1RJQzEsMCoGCSqGSIb3DQEJARYdZmFiaW8udG9ycmVzQHVu\naWZlc3NwYS5lZHUuYnIxDzANBgNVBAcTBk1hcmFiYTENMAsGA1UECBMEUGFyYTEL\nMAkGA1UEBhMCQlIxITAfBgNVBAMTGGNvcGFpYmEudW5pZmVzc3BhLmVkdS5icjAe\nFw0xNTAzMTgxODMzMzFaFw0xODAzMTcxODMzMzFaMIHRMUIwQAYDVQQKEzlVTklG\nRVNTUEEgLSBVbml2ZXJzaWRhZGUgRmVkZXJhbCBkbyBTdWwgZSBTdWRlc3RlIGRv\nIFBhcmExDTALBgNVBAsTBENUSUMxLDAqBgkqhkiG9w0BCQEWHWZhYmlvLnRvcnJl\nc0B1bmlmZXNzcGEuZWR1LmJyMQ8wDQYDVQQHEwZNYXJhYmExDTALBgNVBAgTBFBh\ncmExCzAJBgNVBAYTAkJSMSEwHwYDVQQDExhjb3BhaWJhLnVuaWZlc3NwYS5lZHUu\nYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDA9/SxMUM1/t4LVNmE\nK0uX5DRpSIajluqIyLtervchmWYWIIipzvzhogyi+Qc3xtkhbuNwISHoDyZK5z7e\nuJXFlhkCuqpR46iqHkgGDvxmes5wqv+oIJEYEEEjy4KZzAZTFty+dwoKXcPSGjbl\nThzuiM14eN052d1fZaKH0l+XezrW9+PUG1HNOviaLoCqy7lX6iFnXMN49XBQjrIB\nqqTejolR3sTyX9YY1JWlyavin+8eefgsqs2u6d/TTczXq/RmpzEXmFiMqV9bSjeM\nc3r2EmqNQRADHlmYgMD4Xze2pPnHgvVZkK/gCcHZvzmLcN54CucOanS/qNtmjbUH\nrjJpAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAAWUE/9T3spNcV2LRioyFcb/uOIs\n2pMFvdYAkkrAnKjnlJhnHbZAUOc7HbEvebz/4SGzk5K1pisN+q7g9EKJbrXhEzlc\neWjoWRqilX22VGozHP4rhVItvhLcxVQQk202lbR9APNkgg8gaM0psryDoHY7uxmV\nHIOIe/EC7oe2Z4esIxgEOGLJRyNflsWq5xfl1eVQjxiCbDKDn+e6P6q7vjltCH/+\nCywiNq03LuVqlu2qV6NkvtfBrIdSVRGJwt+LAyG92Mt5t/bQezKP795nBYD0LOjL\ndMOk+azuCRS1+NS4IGHJi+FSTujOGpOGTg/Hjw2Uo58c7dkfIjX0H8kAuBY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://copaiba.unifesspa.edu.br:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://copaiba.unifesspa.edu.br:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://copaiba.unifesspa.edu.br/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://copaiba.unifesspa.edu.br/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://copaiba.unifesspa.edu.br/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://copaiba.unifesspa.edu.br/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://copaiba.unifesspa.edu.br:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://copaiba.unifesspa.edu.br:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "edu.br"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unifesspa.edu.br"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unifesspa.edu.br"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNIFESSPA - Universidade Federal do Sul e Sudeste do Para"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "UNIFESSPA - Universidade Federal do Sul e Sudeste do Para"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNIFESSPA - Universidade Federal do Sul e Sudeste do Para"
                  },
                  {
                    "lang": "pt-br",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "UNIFESSPA - Universidade Federal do Sul e Sudeste do Para"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEGDCCAwACAQAwDQYJKoZIhvcNAQEFBQAwgdExQjBABgNVBAoTOVVOSUZFU1NQ\nQSAtIFVuaXZlcnNpZGFkZSBGZWRlcmFsIGRvIFN1bCBlIFN1ZGVzdGUgZG8gUGFy\nYTENMAsGA1UECxMEQ1RJQzEsMCoGCSqGSIb3DQEJARYdZmFiaW8udG9ycmVzQHVu\naWZlc3NwYS5lZHUuYnIxDzANBgNVBAcTBk1hcmFiYTENMAsGA1UECBMEUGFyYTEL\nMAkGA1UEBhMCQlIxITAfBgNVBAMTGGNvcGFpYmEudW5pZmVzc3BhLmVkdS5icjAe\nFw0xNTAzMTgxODMzMzFaFw0xODAzMTcxODMzMzFaMIHRMUIwQAYDVQQKEzlVTklG\nRVNTUEEgLSBVbml2ZXJzaWRhZGUgRmVkZXJhbCBkbyBTdWwgZSBTdWRlc3RlIGRv\nIFBhcmExDTALBgNVBAsTBENUSUMxLDAqBgkqhkiG9w0BCQEWHWZhYmlvLnRvcnJl\nc0B1bmlmZXNzcGEuZWR1LmJyMQ8wDQYDVQQHEwZNYXJhYmExDTALBgNVBAgTBFBh\ncmExCzAJBgNVBAYTAkJSMSEwHwYDVQQDExhjb3BhaWJhLnVuaWZlc3NwYS5lZHUu\nYnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDA9/SxMUM1/t4LVNmE\nK0uX5DRpSIajluqIyLtervchmWYWIIipzvzhogyi+Qc3xtkhbuNwISHoDyZK5z7e\nuJXFlhkCuqpR46iqHkgGDvxmes5wqv+oIJEYEEEjy4KZzAZTFty+dwoKXcPSGjbl\nThzuiM14eN052d1fZaKH0l+XezrW9+PUG1HNOviaLoCqy7lX6iFnXMN49XBQjrIB\nqqTejolR3sTyX9YY1JWlyavin+8eefgsqs2u6d/TTczXq/RmpzEXmFiMqV9bSjeM\nc3r2EmqNQRADHlmYgMD4Xze2pPnHgvVZkK/gCcHZvzmLcN54CucOanS/qNtmjbUH\nrjJpAgMBAAEwDQYJKoZIhvcNAQEFBQADggEBAAWUE/9T3spNcV2LRioyFcb/uOIs\n2pMFvdYAkkrAnKjnlJhnHbZAUOc7HbEvebz/4SGzk5K1pisN+q7g9EKJbrXhEzlc\neWjoWRqilX22VGozHP4rhVItvhLcxVQQk202lbR9APNkgg8gaM0psryDoHY7uxmV\nHIOIe/EC7oe2Z4esIxgEOGLJRyNflsWq5xfl1eVQjxiCbDKDn+e6P6q7vjltCH/+\nCywiNq03LuVqlu2qV6NkvtfBrIdSVRGJwt+LAyG92Mt5t/bQezKP795nBYD0LOjL\ndMOk+azuCRS1+NS4IGHJi+FSTujOGpOGTg/Hjw2Uo58c7dkfIjX0H8kAuBY="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNIFESSPA - Universidade Federal do Sul e Sudeste do Para"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "UNIFESSPA - Universidade Federal do Sul e Sudeste do Para"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unifesspa.edu.br"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unifesspa.edu.br"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNIFESSPA - Universidade Federal do Sul e Sudeste do Para"
          },
          {
            "lang": "pt-br",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "UNIFESSPA - Universidade Federal do Sul e Sudeste do Para"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://play.mdh.se/shibboleth",
    {
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/nren-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://play.mdh.se/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://play.mdh.se/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://play.mdh.se/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.mdh.se/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://play.mdh.se/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://play.mdh.se/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://play.mdh.se/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://play.mdh.se/Shibboleth.sso/DS/ds.sunet.se",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "play.mdh.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC9TCCAd2gAwIBAgIJAKvtXo7Z924eMA0GCSqGSIb3DQEBBQUAMBYxFDASBgNV\nBAMTC3BsYXkubWRoLnNlMB4XDTEyMDkyMTA4NTM0N1oXDTIyMDkxOTA4NTM0N1ow\nFjEUMBIGA1UEAxMLcGxheS5tZGguc2UwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAw\nggEKAoIBAQC1fDIENAaqctmukYnIMajTisvX74XzKa1c4ZrnlwaFgmKQIhmTeI3e\nuFNpYjVHfzpz7o19Q4vuFjogyfsi6cCahfvcLh7vvn3wplwTuA1Z1JNGlboybcmF\ntPOQnQTf1t0aSHaypOWNgZKnZuF87OM2bRDQ9LVHXgdAUIgjvC5PmIN0Rv0Ws7j5\nQj4Q1bpG6+byA0hFCOxa9KiQKs03XWB4SR0PZsSQDKVQh5HVwz8AdIxOhSg94bei\nOn0ztNMRcm4CNlmN5NNGhS+i02hZr3KPel6xe2SmqPmsLRLccowSQO8aLUPdde9o\nwDV0XtH69QzUg/GjLN8OT/Y2KyWcb90JAgMBAAGjRjBEMCMGA1UdEQQcMBqCC3Bs\nYXkubWRoLnNlhgtwbGF5Lm1kaC5zZTAdBgNVHQ4EFgQUZxpUfZYV6co1kdmJwlqA\nkSQ4uL8wDQYJKoZIhvcNAQEFBQADggEBAHi1snMpIi11/cGVH4V1Okzc5ucw1nbJ\nmexzUwM/wRLqiO3JLYmGZWqj0P7FFdRK6Ug9q5HmBqn4AGl1lbWTsjee2FGQQtxF\nXeZkZTKYKu3fI0aLFp4omw7m0vsDIYIVKUQPdEV2brqKQSeURtdTXxieCZsR9+8U\nv+Zu6RkWzLUWOly86hcChrLLHtFwpzcKXG5OaHnlFyODzRuwMw7LUQZ+YkQUQeiR\nUihuipaxEeF9qspOnUJEmpAXEoGo/fOueGF045k2Bw6fH6hBbu/6k59Je/aeFZIM\ncPl/udSDVhrtgjhhK6hPgDEpcIskofAJC6+DejW8PESi0qV/pDpG9Eo="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=play.mdh.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://play.mdh.se/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://play.mdh.se/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.mdh.se/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://play.mdh.se/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://play.mdh.se/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://play.mdh.se/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://play.mdh.se/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://play.mdh.se/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://play.mdh.se/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://play.mdh.se/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://hermes.kendal.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Clarke"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:donna.clarke@kendal.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Donna"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Clarke"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:donna.clarke@kendal.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Donna"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://hermes.kendal.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-10-06T16:19:57Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJjCCAg4CCQCftH7JV+1i/jANBgkqhkiG9w0BAQUFADBVMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEPMA0GA1UECBMGS2VuZGFsMRcwFQYDVQQKEw5LZW5kYWwgQ29sbGVnZTEcMBoG\n\t\t\t\t\t\tA1UEAxMTaGVybWVzLmtlbmRhbC5hYy51azAeFw0xNDA0MDkwNzQ1MjZaFw0zNDA0\n\t\t\t\t\t\tMDQwNzQ1MjZaMFUxCzAJBgNVBAYTAkdCMQ8wDQYDVQQIEwZLZW5kYWwxFzAVBgNV\n\t\t\t\t\t\tBAoTDktlbmRhbCBDb2xsZWdlMRwwGgYDVQQDExNoZXJtZXMua2VuZGFsLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuFaEIWh3r5giUZD7uIDh\n\t\t\t\t\t\tOoIuUVdZk1FGrFAjRqOHQFLy6Hn7nWTDvUs4TmrIk/iJUhQ+J9m03R+0b5lIvzyX\n\t\t\t\t\t\t6Ln8x4ROrEgNHjTAHexaISufWOD5n9Tpbb6Ty3B6KkoKHKbiwTQIULiAQ6kexY7n\n\t\t\t\t\t\tl7+ygcj8FgjMpf58SWplsBuvvBDf/2AZ8hAax9m3KSvF6JM31o49q+xdMmAlbr9t\n\t\t\t\t\t\tRGXgY4+SyRAu3k0cnJengS6IyiUU+xAMU6i5p6vOGMedXRega8cZ5brWVujIxFR0\n\t\t\t\t\t\tUWbdZF801hazxntEA60mENp5oe9XaGOVfx8mz43MTStI0Zu88MtcnXpHzjzf0wxY\n\t\t\t\t\t\tuQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCGEX09Mj8zeAGHJYoN9zulj6Clf8Ho\n\t\t\t\t\t\tZckCbIS9TmADXSzLi4WGrXT5MwRxWZAvyJM6tL2XqZDjLcRzoFZrqy6UHedbWPbk\n\t\t\t\t\t\tyI+BvWNcI+5qA6vzp102hh4oe9o6zQYnM/RnQHxWPLChdviskN+sjDk9vXi6ggAg\n\t\t\t\t\t\tZhXigT6XazIAF42mib9Cb2CWmT5DC5ELdUgZNPdkSeHEHcf3OTmMTfyuZM6P4woT\n\t\t\t\t\t\twKjIrfioxNzLdB35vkRFWWUDw1PdFn1kUq1VgjuEqbD38eUA4iNd6F6m3SvcQAqE\n\t\t\t\t\t\t0D/QX0C9pKDMUOwrgNQfQOdQBE6gPCqk5zaD8tc/WOKE8wia27HWDmH2"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kendal.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://hermes.kendal.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hermes.kendal.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://hermes.kendal.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://hermes.kendal.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://hermes.kendal.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://hermes.kendal.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://hermes.kendal.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://hermes.kendal.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "kendal.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJjCCAg4CCQCftH7JV+1i/jANBgkqhkiG9w0BAQUFADBVMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEPMA0GA1UECBMGS2VuZGFsMRcwFQYDVQQKEw5LZW5kYWwgQ29sbGVnZTEcMBoG\n\t\t\t\t\t\tA1UEAxMTaGVybWVzLmtlbmRhbC5hYy51azAeFw0xNDA0MDkwNzQ1MjZaFw0zNDA0\n\t\t\t\t\t\tMDQwNzQ1MjZaMFUxCzAJBgNVBAYTAkdCMQ8wDQYDVQQIEwZLZW5kYWwxFzAVBgNV\n\t\t\t\t\t\tBAoTDktlbmRhbCBDb2xsZWdlMRwwGgYDVQQDExNoZXJtZXMua2VuZGFsLmFjLnVr\n\t\t\t\t\t\tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAuFaEIWh3r5giUZD7uIDh\n\t\t\t\t\t\tOoIuUVdZk1FGrFAjRqOHQFLy6Hn7nWTDvUs4TmrIk/iJUhQ+J9m03R+0b5lIvzyX\n\t\t\t\t\t\t6Ln8x4ROrEgNHjTAHexaISufWOD5n9Tpbb6Ty3B6KkoKHKbiwTQIULiAQ6kexY7n\n\t\t\t\t\t\tl7+ygcj8FgjMpf58SWplsBuvvBDf/2AZ8hAax9m3KSvF6JM31o49q+xdMmAlbr9t\n\t\t\t\t\t\tRGXgY4+SyRAu3k0cnJengS6IyiUU+xAMU6i5p6vOGMedXRega8cZ5brWVujIxFR0\n\t\t\t\t\t\tUWbdZF801hazxntEA60mENp5oe9XaGOVfx8mz43MTStI0Zu88MtcnXpHzjzf0wxY\n\t\t\t\t\t\tuQIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCGEX09Mj8zeAGHJYoN9zulj6Clf8Ho\n\t\t\t\t\t\tZckCbIS9TmADXSzLi4WGrXT5MwRxWZAvyJM6tL2XqZDjLcRzoFZrqy6UHedbWPbk\n\t\t\t\t\t\tyI+BvWNcI+5qA6vzp102hh4oe9o6zQYnM/RnQHxWPLChdviskN+sjDk9vXi6ggAg\n\t\t\t\t\t\tZhXigT6XazIAF42mib9Cb2CWmT5DC5ELdUgZNPdkSeHEHcf3OTmMTfyuZM6P4woT\n\t\t\t\t\t\twKjIrfioxNzLdB35vkRFWWUDw1PdFn1kUq1VgjuEqbD38eUA4iNd6F6m3SvcQAqE\n\t\t\t\t\t\t0D/QX0C9pKDMUOwrgNQfQOdQBE6gPCqk5zaD8tc/WOKE8wia27HWDmH2"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Kendal College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.kendal.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Kendal College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.iastate.edu/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "shibboleth@iastate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Iowa State University Shibboleth Technical Team"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "solution@iastate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Iowa State University Solution Center"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "incommon-admins@iastate.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Iowa State University InCommon Admins"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.iastate.edu/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              },
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.iastate.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.iastate.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.iastate.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.iastate.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.iastate.edu/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.iastate.edu/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "iastate.edu"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "The Iowa State University of Science and Technology"
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth.iastate.edu/ISU_InCommon_Nameplate.png",
                    "lang": "en",
                    "height": "249",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "564"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Iowa State University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDSTCCAjGgAwIBAgIJANtndPl5456+MA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFnNoaWJib2xldGguaWFzdGF0ZS5lZHUwHhcNMTMwMTA4MjMwOTU3WhcNMjMw\nMTA2MjMwOTU3WjAhMR8wHQYDVQQDExZzaGliYm9sZXRoLmlhc3RhdGUuZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAscJCb7+nGki+XK32mLz0xJUY\nAMHPiDBnrepFglaTQ8YkI+FIlH2EWY0AFUCcIyNEXG2AXKhKhAVwv+HR+5WUQk5D\nmvApzDDkmiNTTEzMV8A/ZfHhTcDIHXXz3adLSqcAQBfhPCoOW2rr4KNwylAM3i/e\nPO5DXjQv2PHSYuHYJioki+OB9ISAnFxjlFfjoW8aipHwRs0UsQui13R7plYiM9F8\nPB53ywtGo1wKEyfz7PzA6amCm4ayaV8ffhdr+iVjoemESTBGT3vi0dSqtwQGMqzj\nZTDKNlg3QLrjT23ZMvhMD9E0WpM+XiDkLeAtwZJWe41FEQepR/pcATu15WAoDQID\nAQABo4GDMIGAMB0GA1UdDgQWBBQEUoHboQ66BZAv4K1HD+eV9R5ARTBRBgNVHSME\nSjBIgBQEUoHboQ66BZAv4K1HD+eV9R5ARaElpCMwITEfMB0GA1UEAxMWc2hpYmJv\nbGV0aC5pYXN0YXRlLmVkdYIJANtndPl5456+MAwGA1UdEwQFMAMBAf8wDQYJKoZI\nhvcNAQEFBQADggEBAEh/PmivdsKgKyAbGTSd0EtGBkZi4MIWNdxONJK/S3Yu3yDH\nJmGb092oQUWXuexwNad60fyC5vmjcDoIdc/abFIJ7ZlxO+mwnn91NTpE2KHT0w3G\nSDKQlbvCTERFwKju3CzNSVJgTm/8HcMiVg8Oh0UDtqBbIoWa1+z2vfVfFg42y8kb\nsdhfF/SwKY8OTQ2T5IBB4TX/pc374MeGzyztBkHWI0Wdit4SsqVBk5W/id/Xm6GK\nSjZyukCftG8fPGS9rzYyIHZef/SenG1Jx3H2SK0JfzACakpVnW8rLIz3pOVVn53W\n9X/7A6V/nF9hQCcovLsIvLhCKTmiRoiMQiboEOs="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Iowa State University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.iastate.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Iowa State University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.crous-poitiers.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "crous.informatique@crous-poitiers.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.crous-poitiers.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-07-19T15:27:20Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.crous-poitiers.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.crous-poitiers.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.crous-poitiers.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "crous-poitiers.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.ac-poitiers.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS de Poitiers"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS de Poitiers"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEdzCCA1+gAwIBAgIQN3OORXWc3cChLNqDZoOjGDANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDcxOTAwMDAwMFoXDTE2MDcxODIzNTk1OVowQzEhMB8GA1UE\nCxMYRG9tYWluIENvbnRyb2wgVmFsaWRhdGVkMR4wHAYDVQQDExVpZHAuY3JvdXMt\ncG9pdGllcnMuZnIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC8oGB5\nP3shavDXjX9yTT/z+7Or9BOJ6YB+bf34xX7Javtb4fze/7mA5dDijJ6khVaULAzT\nYbxZX4uTbnl0V1k8jJofjEv/0dNHJK7tARzS21jn8Uj9qdDnLf0kgNFI9KrzgSOA\nh8orYsEMO9JRaXO5adt9Y6fub/ePGnod73xC4LeG0jQIFJDEN1d/fOamalc4TDUe\n+Bts0Sa9vx/wx+oqBhhrxrgMzXMRDzdR/e2+2EbQITW0V1AIiX7AlX30N3lV4L3b\nLxU9jyHX2XOB5oo3Kaj7RerWSDgXWrgv8+fz8lc1jBd2fyXIKsiC/d7i7FTaTWwt\nr+YAZcyl8NNsxukdAgMBAAGjggFyMIIBbjAfBgNVHSMEGDAWgBQMvZNoDPPeq6NJ\nays3V0fqkOO57TAdBgNVHQ4EFgQUtazuewoiBQj6dX2wFmouplCmJwAwDgYDVR0P\nAQH/BAQDAgWgMAwGA1UdEwEB/wQCMAAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsG\nAQUFBwMCMCIGA1UdIAQbMBkwDQYLKwYBBAGyMQECAh0wCAYGZ4EMAQIBMDoGA1Ud\nHwQzMDEwL6AtoCuGKWh0dHA6Ly9jcmwudGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NM\nQ0EuY3JsMG0GCCsGAQUFBwEBBGEwXzA1BggrBgEFBQcwAoYpaHR0cDovL2NydC50\nY3MudGVyZW5hLm9yZy9URVJFTkFTU0xDQS5jcnQwJgYIKwYBBQUHMAGGGmh0dHA6\nLy9vY3NwLnRjcy50ZXJlbmEub3JnMCAGA1UdEQQZMBeCFWlkcC5jcm91cy1wb2l0\naWVycy5mcjANBgkqhkiG9w0BAQUFAAOCAQEAKJt2lulJryvECmZz04CvNsBtNs1X\nuL/vYf2XCnqNoiOR9UWTir/2Y1pyfq/MG7SdhNVtPia66gt88gU0RHpkgbuTqAjA\nVtMaW02SKhNTJ70Ujbi5YQfRewTA/efsTahZ5jx3qYhGelFuqTWtvRCDcCPjO/4f\noWltTXNqL752e4pY6MZyVkH1mOqbwnYAQoAxlT84lmnv5p58do2HqVTNikbigwXp\ncr+1iiW5RhIg3fiDuvvFXisB7MnGOJrwR1PDnEcm082UvdlErnvH0JZLvmW0uSJE\n6ybzwV5DMLR8VjRJBJU9KaoOA6dssc/ENDYdFaVc0cGdMhEXf/+KK0UWkg=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS de Poitiers"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ac-poitiers.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS de Poitiers"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.coleggwent.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mugleston"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul.mugleston@coleggwent.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Mugleston"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul.mugleston@coleggwent.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.coleggwent.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2014-06-17T13:52:25Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAPoQhjG640bUBDqHyzpK76yMFB02MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB8xHTAbBgNVBAMTFGlkcC5jb2xlZ2d3ZW50LmFjLnVrMB4XDTE0MDQyNTA4\n\t\t\t\t\t\tMzYyM1oXDTM0MDQyNTA4MzYyM1owHzEdMBsGA1UEAxMUaWRwLmNvbGVnZ3dlbnQu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC1MAfdEF6a0yIc\n\t\t\t\t\t\tNuS/2PRg5YVuRi2PezJggImTYVpNYZ9zd6RZGdBdWMs3jqPZUMJFUvK+RIdzMHp6\n\t\t\t\t\t\tzNXTIORDX0HNwaMmzhqDjpK3SrNj8V6R2YN9jeQPC4LCpxBDejems7eT+xch+QyZ\n\t\t\t\t\t\tdSR5N0aL6XWFfQdnDyJU/ADDlSTnegmyGaYZSxJ/7zwFjG5+mDhJVtVwrr/Bfbwi\n\t\t\t\t\t\tpOECsI9ZSYjnvA9FdeX8X8/mOs3RYXDVLFHEF/lSQiUffBH2CNXuy6v945tBaGk9\n\t\t\t\t\t\tBV9vw3UdKUFEZJ9v7POxIG2S6cN+gNd8BHOhcHLxJKVlDDbGpuEFNhAqRnTkLdg6\n\t\t\t\t\t\tnMYEMrg/AgMBAAGjbzBtMEwGA1UdEQRFMEOCFGlkcC5jb2xlZ2d3ZW50LmFjLnVr\n\t\t\t\t\t\thitodHRwczovL2lkcC5jb2xlZ2d3ZW50LmFjLnVrL2lkcC9zaGliYm9sZXRoMB0G\n\t\t\t\t\t\tA1UdDgQWBBSG0tN9RyOtbHWu1y8wN6J9tLIlbTANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tIFJqEr40T7U8Bz8oECDeUaeUacZZDgV50qoGegCDpcjbO4rxq0scjBtLNu/rd+1N\n\t\t\t\t\t\t3oOyfkhPPxGpDzFjezywMAn/6wfl6yAzOLU4ctTcs4Z41uYZYvGktwSEvVhKgK9k\n\t\t\t\t\t\t/BRzjmalx7FXZwnvUcVG+h2vCk6I+vN3/d6eEL2+CQumK9S32fS60pP7jAF8sYe+\n\t\t\t\t\t\tFfZmV1VDEv2FnYJkXRb5YIZd45OtU9xF+HdkAIhhHVf1s6Hl3HJR4SoU58iEK7Qy\n\t\t\t\t\t\tNlbpu18iaBSCPJEjejsFcA3LTDD5Iu2DNjxLLL5gBlq/n2ad9k4GB5ImwlXwA+cM\n\t\t\t\t\t\tzir7XsM02jLj1MPVeD9xgw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "coleggwent.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.coleggwent.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.coleggwent.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.coleggwent.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.coleggwent.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.coleggwent.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.coleggwent.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.coleggwent.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.coleggwent.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.coleggwent.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.coleggwent.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.coleggwent.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "coleggwent.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPDCCAiSgAwIBAgIVAPoQhjG640bUBDqHyzpK76yMFB02MA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMB8xHTAbBgNVBAMTFGlkcC5jb2xlZ2d3ZW50LmFjLnVrMB4XDTE0MDQyNTA4\n\t\t\t\t\t\tMzYyM1oXDTM0MDQyNTA4MzYyM1owHzEdMBsGA1UEAxMUaWRwLmNvbGVnZ3dlbnQu\n\t\t\t\t\t\tYWMudWswggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC1MAfdEF6a0yIc\n\t\t\t\t\t\tNuS/2PRg5YVuRi2PezJggImTYVpNYZ9zd6RZGdBdWMs3jqPZUMJFUvK+RIdzMHp6\n\t\t\t\t\t\tzNXTIORDX0HNwaMmzhqDjpK3SrNj8V6R2YN9jeQPC4LCpxBDejems7eT+xch+QyZ\n\t\t\t\t\t\tdSR5N0aL6XWFfQdnDyJU/ADDlSTnegmyGaYZSxJ/7zwFjG5+mDhJVtVwrr/Bfbwi\n\t\t\t\t\t\tpOECsI9ZSYjnvA9FdeX8X8/mOs3RYXDVLFHEF/lSQiUffBH2CNXuy6v945tBaGk9\n\t\t\t\t\t\tBV9vw3UdKUFEZJ9v7POxIG2S6cN+gNd8BHOhcHLxJKVlDDbGpuEFNhAqRnTkLdg6\n\t\t\t\t\t\tnMYEMrg/AgMBAAGjbzBtMEwGA1UdEQRFMEOCFGlkcC5jb2xlZ2d3ZW50LmFjLnVr\n\t\t\t\t\t\thitodHRwczovL2lkcC5jb2xlZ2d3ZW50LmFjLnVrL2lkcC9zaGliYm9sZXRoMB0G\n\t\t\t\t\t\tA1UdDgQWBBSG0tN9RyOtbHWu1y8wN6J9tLIlbTANBgkqhkiG9w0BAQUFAAOCAQEA\n\t\t\t\t\t\tIFJqEr40T7U8Bz8oECDeUaeUacZZDgV50qoGegCDpcjbO4rxq0scjBtLNu/rd+1N\n\t\t\t\t\t\t3oOyfkhPPxGpDzFjezywMAn/6wfl6yAzOLU4ctTcs4Z41uYZYvGktwSEvVhKgK9k\n\t\t\t\t\t\t/BRzjmalx7FXZwnvUcVG+h2vCk6I+vN3/d6eEL2+CQumK9S32fS60pP7jAF8sYe+\n\t\t\t\t\t\tFfZmV1VDEv2FnYJkXRb5YIZd45OtU9xF+HdkAIhhHVf1s6Hl3HJR4SoU58iEK7Qy\n\t\t\t\t\t\tNlbpu18iaBSCPJEjejsFcA3LTDD5Iu2DNjxLLL5gBlq/n2ad9k4GB5ImwlXwA+cM\n\t\t\t\t\t\tzir7XsM02jLj1MPVeD9xgw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Coleg Gwent"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.coleggwent.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Coleg Gwent"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://pymca-wg-gw01.sso.picturemaxx.com/shibboleth-sp",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Swinstead"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jon@pymca.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jon"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Swinstead"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:jon@pymca.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jon"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://pymca-wg-gw01.sso.picturemaxx.com/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "KINDIT LIMITED: PYMCA - Photographic, Youth, Music, Culture, Archive"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.pymca.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "KINDIT LIMITED"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://pymca-wg-gw01.sso.picturemaxx.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://pymca-wg-gw01.sso.picturemaxx.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pymca-wg-gw01.sso.picturemaxx.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://pymca-wg-gw01.sso.picturemaxx.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://pymca-wg-gw01.sso.picturemaxx.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://pymca-wg-gw01.sso.picturemaxx.com/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEszCCA5ugAwIBAgIDByqUMA0GCSqGSIb3DQEBBQUAMDwxCzAJBgNVBAYTAlVT\n\t\t\t\t\t\tMRcwFQYDVQQKEw5HZW9UcnVzdCwgSW5jLjEUMBIGA1UEAxMLUmFwaWRTU0wgQ0Ew\n\t\t\t\t\t\tHhcNMTIwNjI4MjIzNjIzWhcNMTQwODMxMDM1NDExWjCBxDEpMCcGA1UEBRMgSk8z\n\t\t\t\t\t\tcmM4bmcwZS04QW8yZEU0V0tnTW9yZDhDWjVVbnUxEzARBgNVBAsTCkdUNjYzMDAx\n\t\t\t\t\t\tNDYxMTAvBgNVBAsTKFNlZSB3d3cucmFwaWRzc2wuY29tL3Jlc291cmNlcy9jcHMg\n\t\t\t\t\t\tKGMpMTIxLzAtBgNVBAsTJkRvbWFpbiBDb250cm9sIFZhbGlkYXRlZCAtIFJhcGlk\n\t\t\t\t\t\tU1NMKFIpMR4wHAYDVQQDDBUqLnNzby5waWN0dXJlbWF4eC5jb20wggEiMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDaEVjXASuIZBhwoM8n9T5i/102ypwRzTRA\n\t\t\t\t\t\twTv7UWx2ja1W3EKVyU0Z5Jj/iVZ+5bSXjJj06OIqjB0i4wsKYqFjIx7Wn22EsOUq\n\t\t\t\t\t\t4kHr1wD1YNMxt2Ol6weE00h7KMyygDv4jZluYskfGJqx2QKs1TNNKlhQ4e+p1277\n\t\t\t\t\t\txnzRrRzd4cs6fXctINxFYugxxkedRHRJhqVyiphnuwIFxK9m04zSLhZOtJuybI5y\n\t\t\t\t\t\tmvAUCQjdU+ps6Sf618jP9LsivfpET3yVhbkapQLkgxB//BJmCunYyTfmdnW1890o\n\t\t\t\t\t\tpFtpvB6UsUOTQQ0Jj1zNKD9BwYFetSL3yWxbW2aKirAAxE4VTgnTAgMBAAGjggEz\n\t\t\t\t\t\tMIIBLzAfBgNVHSMEGDAWgBRraT1qGEJK3Y8CZTn9NSSGeJEWMDAOBgNVHQ8BAf8E\n\t\t\t\t\t\tBAMCBaAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMCAGA1UdEQQZMBeC\n\t\t\t\t\t\tFSouc3NvLnBpY3R1cmVtYXh4LmNvbTBDBgNVHR8EPDA6MDigNqA0hjJodHRwOi8v\n\t\t\t\t\t\tcmFwaWRzc2wtY3JsLmdlb3RydXN0LmNvbS9jcmxzL3JhcGlkc3NsLmNybDAdBgNV\n\t\t\t\t\t\tHQ4EFgQUiPqxey8W2LkPp0cqZhEBGOa7J5IwDAYDVR0TAQH/BAIwADBJBggrBgEF\n\t\t\t\t\t\tBQcBAQQ9MDswOQYIKwYBBQUHMAKGLWh0dHA6Ly9yYXBpZHNzbC1haWEuZ2VvdHJ1\n\t\t\t\t\t\tc3QuY29tL3JhcGlkc3NsLmNydDANBgkqhkiG9w0BAQUFAAOCAQEACCUxI/EBYHlX\n\t\t\t\t\t\tw158lYdvKKJsSwAUuUH3QIJskViLUjFmvY26aMk26Tni45pMV+2QwZ2Iwi3I6xJo\n\t\t\t\t\t\tuoE7GikGThGpOYsxb5gCSR/bb+Fs2lD+2gcvPIFINZFO+zqs2uaxvJxZJ3NKTOhg\n\t\t\t\t\t\t9dOoaTOjMQiUrmkFoNwHHHgkej/fNfaU5rSpYBcd7AhG4aNhKPMiplLvq7sbXuXa\n\t\t\t\t\t\tZcPCNSMoOVlUc+s8JOa8ukbBUx1yIxEShNdfO+X/DqA6Mbz9ZPmOhUVvjS+qEZ/u\n\t\t\t\t\t\toxvz+XRdsea4OEIBam0WyrOer7q31FJANo7wXWpW8vDF+Vv969sNJPmQ05QnYLjH\n\t\t\t\t\t\tPh2CEHrxjw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEszCCA5ugAwIBAgIDByqUMA0GCSqGSIb3DQEBBQUAMDwxCzAJBgNVBAYTAlVT\n\t\t\t\t\t\tMRcwFQYDVQQKEw5HZW9UcnVzdCwgSW5jLjEUMBIGA1UEAxMLUmFwaWRTU0wgQ0Ew\n\t\t\t\t\t\tHhcNMTIwNjI4MjIzNjIzWhcNMTQwODMxMDM1NDExWjCBxDEpMCcGA1UEBRMgSk8z\n\t\t\t\t\t\tcmM4bmcwZS04QW8yZEU0V0tnTW9yZDhDWjVVbnUxEzARBgNVBAsTCkdUNjYzMDAx\n\t\t\t\t\t\tNDYxMTAvBgNVBAsTKFNlZSB3d3cucmFwaWRzc2wuY29tL3Jlc291cmNlcy9jcHMg\n\t\t\t\t\t\tKGMpMTIxLzAtBgNVBAsTJkRvbWFpbiBDb250cm9sIFZhbGlkYXRlZCAtIFJhcGlk\n\t\t\t\t\t\tU1NMKFIpMR4wHAYDVQQDDBUqLnNzby5waWN0dXJlbWF4eC5jb20wggEiMA0GCSqG\n\t\t\t\t\t\tSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDaEVjXASuIZBhwoM8n9T5i/102ypwRzTRA\n\t\t\t\t\t\twTv7UWx2ja1W3EKVyU0Z5Jj/iVZ+5bSXjJj06OIqjB0i4wsKYqFjIx7Wn22EsOUq\n\t\t\t\t\t\t4kHr1wD1YNMxt2Ol6weE00h7KMyygDv4jZluYskfGJqx2QKs1TNNKlhQ4e+p1277\n\t\t\t\t\t\txnzRrRzd4cs6fXctINxFYugxxkedRHRJhqVyiphnuwIFxK9m04zSLhZOtJuybI5y\n\t\t\t\t\t\tmvAUCQjdU+ps6Sf618jP9LsivfpET3yVhbkapQLkgxB//BJmCunYyTfmdnW1890o\n\t\t\t\t\t\tpFtpvB6UsUOTQQ0Jj1zNKD9BwYFetSL3yWxbW2aKirAAxE4VTgnTAgMBAAGjggEz\n\t\t\t\t\t\tMIIBLzAfBgNVHSMEGDAWgBRraT1qGEJK3Y8CZTn9NSSGeJEWMDAOBgNVHQ8BAf8E\n\t\t\t\t\t\tBAMCBaAwHQYDVR0lBBYwFAYIKwYBBQUHAwEGCCsGAQUFBwMCMCAGA1UdEQQZMBeC\n\t\t\t\t\t\tFSouc3NvLnBpY3R1cmVtYXh4LmNvbTBDBgNVHR8EPDA6MDigNqA0hjJodHRwOi8v\n\t\t\t\t\t\tcmFwaWRzc2wtY3JsLmdlb3RydXN0LmNvbS9jcmxzL3JhcGlkc3NsLmNybDAdBgNV\n\t\t\t\t\t\tHQ4EFgQUiPqxey8W2LkPp0cqZhEBGOa7J5IwDAYDVR0TAQH/BAIwADBJBggrBgEF\n\t\t\t\t\t\tBQcBAQQ9MDswOQYIKwYBBQUHMAKGLWh0dHA6Ly9yYXBpZHNzbC1haWEuZ2VvdHJ1\n\t\t\t\t\t\tc3QuY29tL3JhcGlkc3NsLmNydDANBgkqhkiG9w0BAQUFAAOCAQEACCUxI/EBYHlX\n\t\t\t\t\t\tw158lYdvKKJsSwAUuUH3QIJskViLUjFmvY26aMk26Tni45pMV+2QwZ2Iwi3I6xJo\n\t\t\t\t\t\tuoE7GikGThGpOYsxb5gCSR/bb+Fs2lD+2gcvPIFINZFO+zqs2uaxvJxZJ3NKTOhg\n\t\t\t\t\t\t9dOoaTOjMQiUrmkFoNwHHHgkej/fNfaU5rSpYBcd7AhG4aNhKPMiplLvq7sbXuXa\n\t\t\t\t\t\tZcPCNSMoOVlUc+s8JOa8ukbBUx1yIxEShNdfO+X/DqA6Mbz9ZPmOhUVvjS+qEZ/u\n\t\t\t\t\t\toxvz+XRdsea4OEIBam0WyrOer7q31FJANo7wXWpW8vDF+Vv969sNJPmQ05QnYLjH\n\t\t\t\t\t\tPh2CEHrxjw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://pymca-wg-gw01.sso.picturemaxx.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://pymca-wg-gw01.sso.picturemaxx.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pymca-wg-gw01.sso.picturemaxx.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://pymca-wg-gw01.sso.picturemaxx.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://pymca-wg-gw01.sso.picturemaxx.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://pymca-wg-gw01.sso.picturemaxx.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://pymca-wg-gw01.sso.picturemaxx.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://pymca-wg-gw01.sso.picturemaxx.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://pymca-wg-gw01.sso.picturemaxx.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://pymca-wg-gw01.sso.picturemaxx.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://idp.strodes.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Disbury"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rdisbury@strodes.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roberts"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Disbury"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:rdisbury@strodes.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Roberts"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.strodes.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-09-22T16:02:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiwCCQDcWa6x9ZbwJjANBgkqhkiG9w0BAQUFADBkMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEPMA0GA1UECBMGU3VycmV5MQ4wDAYDVQQHEwVFZ2hhbTEYMBYGA1UEChMPU3Ry\n\t\t\t\t\t\tb2RlcyBDb2xsZWdlMRowGAYDVQQDExFpZHAuc3Ryb2Rlcy5hYy51azAeFw0xMzEw\n\t\t\t\t\t\tMzExNTE2MzVaFw0zMzEwMjYxNTE2MzVaMGQxCzAJBgNVBAYTAkdCMQ8wDQYDVQQI\n\t\t\t\t\t\tEwZTdXJyZXkxDjAMBgNVBAcTBUVnaGFtMRgwFgYDVQQKEw9TdHJvZGVzIENvbGxl\n\t\t\t\t\t\tZ2UxGjAYBgNVBAMTEWlkcC5zdHJvZGVzLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEF\n\t\t\t\t\t\tAAOCAQ8AMIIBCgKCAQEA3jJkDFSXCd1vT7ockIBT/j/ZNcRgrdhdstZVN7cycLDg\n\t\t\t\t\t\tzUijTZgqHZYmq7/PgDKRuH4/zgiFAZt4LZKxaro0fLK0CpZBal0pVpheqaCGtuCr\n\t\t\t\t\t\tFNtsP826Ks1dk2pMPSqqFrYdTO/UMofeUuxrNr836CL7x5ATCdVU9F/pljTeRr/V\n\t\t\t\t\t\tqCs1IQhdiE1o5mHYXJutpwnabHN/eYQB/xgM8awyr93lHOge2uu6ioKcfDASmL9+\n\t\t\t\t\t\tVKNak/4mYQEA3UW4BjhC6QHzXvRu2KbhVjcrH9qBgCJM73u+hkSEWPazXAcvmgFS\n\t\t\t\t\t\tQoCDgqelecT4Y0iCPTytn/ffIHKZR/lpWfbgmGTERQIDAQABMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQBXSwhT6WnbbLhQ432uwqOgM8xAH27q4ARxNLzTj7D9XNSbh1qxwc0o\n\t\t\t\t\t\t2z1pgHA05H/r6JFVoOd1hP03k34wv3Mt9B/kEiEP7x2iGukw5sQ8xk9JFIVNdjC0\n\t\t\t\t\t\tyiJFl9znjtl/UZZkYG6WgvOFr+HzK42Tvf3cBwcjn3amZbjTsIU7VbH0GvCqnB5B\n\t\t\t\t\t\tEc9fbn6h3RN9awbrMC6BqbRflyA4k8rAuZ4yxKUm/GTkhjaGoM8yNVJbmxOGonkV\n\t\t\t\t\t\tx5WyEEVfjbFIBjxXKUXp1zHdcCxDuL/GE0wKHpCffnk3e11MzT7KO1YaGQyXQEQ/\n\t\t\t\t\t\tfAFKolTZXDqFqiudmlPOb4sxvpmQ7jUs"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "strodes.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.strodes.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.strodes.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.strodes.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.strodes.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.strodes.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.strodes.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.strodes.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.strodes.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "strodes.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDRDCCAiwCCQDcWa6x9ZbwJjANBgkqhkiG9w0BAQUFADBkMQswCQYDVQQGEwJH\n\t\t\t\t\t\tQjEPMA0GA1UECBMGU3VycmV5MQ4wDAYDVQQHEwVFZ2hhbTEYMBYGA1UEChMPU3Ry\n\t\t\t\t\t\tb2RlcyBDb2xsZWdlMRowGAYDVQQDExFpZHAuc3Ryb2Rlcy5hYy51azAeFw0xMzEw\n\t\t\t\t\t\tMzExNTE2MzVaFw0zMzEwMjYxNTE2MzVaMGQxCzAJBgNVBAYTAkdCMQ8wDQYDVQQI\n\t\t\t\t\t\tEwZTdXJyZXkxDjAMBgNVBAcTBUVnaGFtMRgwFgYDVQQKEw9TdHJvZGVzIENvbGxl\n\t\t\t\t\t\tZ2UxGjAYBgNVBAMTEWlkcC5zdHJvZGVzLmFjLnVrMIIBIjANBgkqhkiG9w0BAQEF\n\t\t\t\t\t\tAAOCAQ8AMIIBCgKCAQEA3jJkDFSXCd1vT7ockIBT/j/ZNcRgrdhdstZVN7cycLDg\n\t\t\t\t\t\tzUijTZgqHZYmq7/PgDKRuH4/zgiFAZt4LZKxaro0fLK0CpZBal0pVpheqaCGtuCr\n\t\t\t\t\t\tFNtsP826Ks1dk2pMPSqqFrYdTO/UMofeUuxrNr836CL7x5ATCdVU9F/pljTeRr/V\n\t\t\t\t\t\tqCs1IQhdiE1o5mHYXJutpwnabHN/eYQB/xgM8awyr93lHOge2uu6ioKcfDASmL9+\n\t\t\t\t\t\tVKNak/4mYQEA3UW4BjhC6QHzXvRu2KbhVjcrH9qBgCJM73u+hkSEWPazXAcvmgFS\n\t\t\t\t\t\tQoCDgqelecT4Y0iCPTytn/ffIHKZR/lpWfbgmGTERQIDAQABMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAA4IBAQBXSwhT6WnbbLhQ432uwqOgM8xAH27q4ARxNLzTj7D9XNSbh1qxwc0o\n\t\t\t\t\t\t2z1pgHA05H/r6JFVoOd1hP03k34wv3Mt9B/kEiEP7x2iGukw5sQ8xk9JFIVNdjC0\n\t\t\t\t\t\tyiJFl9znjtl/UZZkYG6WgvOFr+HzK42Tvf3cBwcjn3amZbjTsIU7VbH0GvCqnB5B\n\t\t\t\t\t\tEc9fbn6h3RN9awbrMC6BqbRflyA4k8rAuZ4yxKUm/GTkhjaGoM8yNVJbmxOGonkV\n\t\t\t\t\t\tx5WyEEVfjbFIBjxXKUXp1zHdcCxDuL/GE0wKHpCffnk3e11MzT7KO1YaGQyXQEQ/\n\t\t\t\t\t\tfAFKolTZXDqFqiudmlPOb4sxvpmQ7jUs"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Strode's College"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.strodes.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Strode's College"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sp.igpublish.com/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hung"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:art@igroupnet.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Art"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hung"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:art@igroupnet.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Art"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sp.igpublish.com/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "IG Publishing Pte Ltd"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.igpublish.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Academic Rights Press Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.igpublish.com/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.igpublish.com/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.igpublish.com/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.igpublish.com/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.igpublish.com/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Established in Singapore since 2006, we work with many reputable publishers to represent their brands."
                  }
                ],
                "logo": [
                  {
                    "text": "https://sp.igpublish.com/logos/256.png",
                    "height": "99",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "256"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "IG Publishing Pte Ltd"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC5TCCAc2gAwIBAgIJAP+bL8Y9JiKWMA0GCSqGSIb3DQEBBQUAMBUxEzARBgNV\n\t\t\t\t\t\tBAMTClNFQVJDSFNSVkEwHhcNMTAxMTEyMDcyMzA4WhcNMjAxMTA5MDcyMzA4WjAV\n\t\t\t\t\t\tMRMwEQYDVQQDEwpTRUFSQ0hTUlZBMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEA3wqCYIkxitDSLy2yJdmPGTWLPB4MDvgRHEwT7ZiPsrPigXhAF3/ZOs/n\n\t\t\t\t\t\thMBNYwEUZZr0aFNoqxzsEk2gbWFedJXAQsU1bIX9ykDP0QfHLijVUv2KdWQfzKGw\n\t\t\t\t\t\tudm2WFSCFJArqpHcM8gvbLjvYxMMCgw5c5Ja8XWL6mjjRKMdBpTboJpsEZWsTL1h\n\t\t\t\t\t\tE6hHY9yFIKHsmGr69cMOCSSpfGx10ZKSQgugBMKq6JatdNPFLkEn2T0AzZOOQgL+\n\t\t\t\t\t\tTNQEpLLXZ/69j4DjYAB5kjr9cpvWZQReE7lP0lkSnALUVM7s+/fytV8lfGs7pDbR\n\t\t\t\t\t\tNE5VpOgewWdXpqX119X6LZPdQJgEKwIDAQABozgwNjAVBgNVHREEDjAMggpTRUFS\n\t\t\t\t\t\tQ0hTUlZBMB0GA1UdDgQWBBQoMgjN6ERGsRxlKhUylzN5II0OuTANBgkqhkiG9w0B\n\t\t\t\t\t\tAQUFAAOCAQEAOf1vokGaIZdmdbIk+HrncGML98lEQrjna4Wp4NiMOKuauszLFKEK\n\t\t\t\t\t\tYs6b42oL0NdaDM/9zu6lwxtJBGO2Hb7DKA6CwBRObDhbLOdaFynDGHq45roQN0gB\n\t\t\t\t\t\tR69V4ZFGxqrpFdyX1gp2P3YRGfdoZKFa+U9n4kZ7GGofaak15ZiCrWPh6GeRLCF/\n\t\t\t\t\t\txQfXQh802/FPY2tnqk2bs7LHIjGziCAjvvLVxHGIqoXUgmD89oQTYA8zB6b2jwWo\n\t\t\t\t\t\tMOkHFT1pJm1IeztRNZZ+4ARMt54WciOkwbYb1rxGCi2Mi3ex5avJPyQioHoezkKo\n\t\t\t\t\t\tZHd6NA1VwSUDsZ3pgZB//nGB5fZPi9SIJw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            },
            {
              "use": "encryption",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIC5TCCAc2gAwIBAgIJAP+bL8Y9JiKWMA0GCSqGSIb3DQEBBQUAMBUxEzARBgNV\n\t\t\t\t\t\tBAMTClNFQVJDSFNSVkEwHhcNMTAxMTEyMDcyMzA4WhcNMjAxMTA5MDcyMzA4WjAV\n\t\t\t\t\t\tMRMwEQYDVQQDEwpTRUFSQ0hTUlZBMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB\n\t\t\t\t\t\tCgKCAQEA3wqCYIkxitDSLy2yJdmPGTWLPB4MDvgRHEwT7ZiPsrPigXhAF3/ZOs/n\n\t\t\t\t\t\thMBNYwEUZZr0aFNoqxzsEk2gbWFedJXAQsU1bIX9ykDP0QfHLijVUv2KdWQfzKGw\n\t\t\t\t\t\tudm2WFSCFJArqpHcM8gvbLjvYxMMCgw5c5Ja8XWL6mjjRKMdBpTboJpsEZWsTL1h\n\t\t\t\t\t\tE6hHY9yFIKHsmGr69cMOCSSpfGx10ZKSQgugBMKq6JatdNPFLkEn2T0AzZOOQgL+\n\t\t\t\t\t\tTNQEpLLXZ/69j4DjYAB5kjr9cpvWZQReE7lP0lkSnALUVM7s+/fytV8lfGs7pDbR\n\t\t\t\t\t\tNE5VpOgewWdXpqX119X6LZPdQJgEKwIDAQABozgwNjAVBgNVHREEDjAMggpTRUFS\n\t\t\t\t\t\tQ0hTUlZBMB0GA1UdDgQWBBQoMgjN6ERGsRxlKhUylzN5II0OuTANBgkqhkiG9w0B\n\t\t\t\t\t\tAQUFAAOCAQEAOf1vokGaIZdmdbIk+HrncGML98lEQrjna4Wp4NiMOKuauszLFKEK\n\t\t\t\t\t\tYs6b42oL0NdaDM/9zu6lwxtJBGO2Hb7DKA6CwBRObDhbLOdaFynDGHq45roQN0gB\n\t\t\t\t\t\tR69V4ZFGxqrpFdyX1gp2P3YRGfdoZKFa+U9n4kZ7GGofaak15ZiCrWPh6GeRLCF/\n\t\t\t\t\t\txQfXQh802/FPY2tnqk2bs7LHIjGziCAjvvLVxHGIqoXUgmD89oQTYA8zB6b2jwWo\n\t\t\t\t\t\tMOkHFT1pJm1IeztRNZZ+4ARMt54WciOkwbYb1rxGCi2Mi3ex5avJPyQioHoezkKo\n\t\t\t\t\t\tZHd6NA1VwSUDsZ3pgZB//nGB5fZPi9SIJw=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sp.igpublish.com/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sp.igpublish.com/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.igpublish.com/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.igpublish.com/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sp.igpublish.com/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sp.igpublish.com/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://sp.igpublish.com/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://sp.igpublish.com/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://sp.igpublish.com/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://sp.igpublish.com/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.aber.ac.uk/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Services"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:is@aber.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Information"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Wiles"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:aew@aber.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Andrew"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.aber.ac.uk/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2007-08-08T07:11:05Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVANUFXICF+oFNmWD1BQ4+pBSTdfLiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCAxHjAcBgNVBAMTFXNoaWJib2xldGguYWJlci5hYy51azAeFw0xNjAyMTUx\n\t\t\t\t\t\tMjQ2NTZaFw0zNjAyMTUxMjQ2NTZaMCAxHjAcBgNVBAMTFXNoaWJib2xldGguYWJl\n\t\t\t\t\t\tci5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKG26zGeNxwr\n\t\t\t\t\t\tdf1mqabjwMlQLKL5IoucDg9QUaUdwZaDx1POccH8WicRwVGzFgsgu1whyWZP8mU5\n\t\t\t\t\t\t+1Y+syOMtKeIx1CtIze950UqfUoaYRbIqoZerD67EgrZUE5wll0mrRAV5xImV1hz\n\t\t\t\t\t\tWOIVyMid3Ze3ohYoegEbvDrS/Mkb2qIspRrAZGkV027JLVBar64qgYMgLMjKD/iO\n\t\t\t\t\t\trbEvMQT/+N6C+/hizqHIOq9uEFrWfx7OApJn+J36806TnhlgESqxzLTG0+PX86ZF\n\t\t\t\t\t\tJGQJ73B5t9NuRh7VY46XVZWckxjDBrUcbNyz0hooDP0ECjIknUhVaj0zD/V+lJc0\n\t\t\t\t\t\t0JGELS0335ECAwEAAaNxMG8wTgYDVR0RBEcwRYIVc2hpYmJvbGV0aC5hYmVyLmFj\n\t\t\t\t\t\tLnVrhixodHRwczovL3NoaWJib2xldGguYWJlci5hYy51ay9pZHAvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQU+I7oDbYkhMlHIAj30Ri9FwzMagswDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAI6Z/wmRpUo78wBenhCEjDwLltikfPmph4vHCfZZB9PAaETtVycjLOPLk3q0\n\t\t\t\t\t\tnCZ/lVpcuqhT+CR/Fy7jME/zyxkaN2BtHQfoO1IC9d1vro0FOw2q1jS/jJ55QE4b\n\t\t\t\t\t\tcxhbSaLkWyPbEdFbe+6NC/XigrKh+3oULjlLJ9VrcYIjGXM7ow/D1BZunFgZ0fEY\n\t\t\t\t\t\tKUlbufKEe4dXJhD2ohIJSEjo7UH/nmVbnt3uz+CCL4mtZom72KxmauZIpV/2Z9Uu\n\t\t\t\t\t\thUPrgxUBssSlFQCtZ3IJNB1NA8NG9tnrIaLyR1J+6I5NsfBfow5hDDuoYE9kDha3\n\t\t\t\t\t\t6tbiD66dhrK60oX7Sg2cPBc13Mo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aber.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.aber.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.aber.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.aber.ac.uk/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.aber.ac.uk/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.aber.ac.uk:8443/idp/profile/SAML2/SOAP/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.aber.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.aber.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.aber.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.aber.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.aber.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.aber.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "aber.ac.uk"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Login@Aber"
                  }
                ],
                "logo": [
                  {
                    "text": "https://shibboleth.aber.ac.uk/mdui/pau_264x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "264"
                  },
                  {
                    "text": "https://shibboleth.aber.ac.uk/mdui/pau_16x16.png",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Aberystwyth University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "aber.ac.uk"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:52.41806,-4.06576"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "144.124.0.0/16"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDQDCCAiigAwIBAgIVANUFXICF+oFNmWD1BQ4+pBSTdfLiMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMCAxHjAcBgNVBAMTFXNoaWJib2xldGguYWJlci5hYy51azAeFw0xNjAyMTUx\n\t\t\t\t\t\tMjQ2NTZaFw0zNjAyMTUxMjQ2NTZaMCAxHjAcBgNVBAMTFXNoaWJib2xldGguYWJl\n\t\t\t\t\t\tci5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKG26zGeNxwr\n\t\t\t\t\t\tdf1mqabjwMlQLKL5IoucDg9QUaUdwZaDx1POccH8WicRwVGzFgsgu1whyWZP8mU5\n\t\t\t\t\t\t+1Y+syOMtKeIx1CtIze950UqfUoaYRbIqoZerD67EgrZUE5wll0mrRAV5xImV1hz\n\t\t\t\t\t\tWOIVyMid3Ze3ohYoegEbvDrS/Mkb2qIspRrAZGkV027JLVBar64qgYMgLMjKD/iO\n\t\t\t\t\t\trbEvMQT/+N6C+/hizqHIOq9uEFrWfx7OApJn+J36806TnhlgESqxzLTG0+PX86ZF\n\t\t\t\t\t\tJGQJ73B5t9NuRh7VY46XVZWckxjDBrUcbNyz0hooDP0ECjIknUhVaj0zD/V+lJc0\n\t\t\t\t\t\t0JGELS0335ECAwEAAaNxMG8wTgYDVR0RBEcwRYIVc2hpYmJvbGV0aC5hYmVyLmFj\n\t\t\t\t\t\tLnVrhixodHRwczovL3NoaWJib2xldGguYWJlci5hYy51ay9pZHAvc2hpYmJvbGV0\n\t\t\t\t\t\taDAdBgNVHQ4EFgQU+I7oDbYkhMlHIAj30Ri9FwzMagswDQYJKoZIhvcNAQEFBQAD\n\t\t\t\t\t\tggEBAI6Z/wmRpUo78wBenhCEjDwLltikfPmph4vHCfZZB9PAaETtVycjLOPLk3q0\n\t\t\t\t\t\tnCZ/lVpcuqhT+CR/Fy7jME/zyxkaN2BtHQfoO1IC9d1vro0FOw2q1jS/jJ55QE4b\n\t\t\t\t\t\tcxhbSaLkWyPbEdFbe+6NC/XigrKh+3oULjlLJ9VrcYIjGXM7ow/D1BZunFgZ0fEY\n\t\t\t\t\t\tKUlbufKEe4dXJhD2ohIJSEjo7UH/nmVbnt3uz+CCL4mtZom72KxmauZIpV/2Z9Uu\n\t\t\t\t\t\thUPrgxUBssSlFQCtZ3IJNB1NA8NG9tnrIaLyR1J+6I5NsfBfow5hDDuoYE9kDha3\n\t\t\t\t\t\t6tbiD66dhrK60oX7Sg2cPBc13Mo="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Aberystwyth University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.aber.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Aberystwyth University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.sruc.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:SidIS@sruc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Service Desk"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Gowler"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Peter.Gowler@sruc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Peter"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:edinburghlibrary@sruc.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Edinburgh Library"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.sruc.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2013-09-09T16:10:42Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAMisBG8/pYaTN/dKjE96UJTj0pHnMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBkxFzAVBgNVBAMTDmlkcC5zcnVjLmFjLnVrMB4XDTEzMDgxNTE4MzUyMVoX\n\t\t\t\t\t\tDTMzMDgxNTE4MzUyMVowGTEXMBUGA1UEAxMOaWRwLnNydWMuYWMudWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQChYhV93CUW69tAVZOYdhzRX14Gtm8l\n\t\t\t\t\t\tCa8W4/EWAEqeVvoMT70fMMwCTPxHbSCkoEpk8RAwChzwGSTGJt8/dtyZWr6vmrHs\n\t\t\t\t\t\t8TzCIKRPo1wJymIPtONtojdZnERwbEr0brAzIw82QIOidzYueWHpbrYSaxwmaQNR\n\t\t\t\t\t\tLKwDIjf/0M7Zkm6t50vxu2XRttrxJ92x31U0P/mQa22DLlQs6gmJFoxO7jPc0gUj\n\t\t\t\t\t\tsvDsMTZXS6J4oXmnpqLHfGpGtiyGocunHRykIGX1cyxyJngRXVb6VCfnIb06nELH\n\t\t\t\t\t\t9s27b9t6/IhWgmH9rCxS522xTuQDe0DKD0YpmMIQK3fHAhF8RaMGcT+PAgMBAAGj\n\t\t\t\t\t\tYzBhMEAGA1UdEQQ5MDeCDmlkcC5zcnVjLmFjLnVrhiVodHRwczovL2lkcC5zcnVj\n\t\t\t\t\t\tLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTj1x9pT421ZN33j8y2qyC2\n\t\t\t\t\t\tz7tEnDANBgkqhkiG9w0BAQUFAAOCAQEAbRG6KPM1cS83t1nTr68n4o+SAawN6IBS\n\t\t\t\t\t\tyt0oSw7jL2eWsFZA3xgR3pePSiKdHXYLW3YEpJ+O3nS1Hs6Hz1lM3zwguJRSnJBk\n\t\t\t\t\t\ttS/2Mvk/LiS3TecJqawwvZ5M+MHPckzKP/2cZwJum6dZps9U3KuuLEwU3aDt6Ri+\n\t\t\t\t\t\t74AWwDm1DVM0AfuSOk+Gjjkh0mgoMCfMS1jFTRwJXxfH13/jq2ODCD7HlvlJ5eGD\n\t\t\t\t\t\tFknd4XDnhT0wz9uDxT1gTsXCRe/DP/Ql8iviaG1f9fENTz7MrcvKawLMqaRQpL6Z\n\t\t\t\t\t\t9rbQkno5Y20gWQLAD3AF1pceBNBCO/6G/GCzRkdsGCtVNNXfnnsc3Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sruc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sruc.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sruc.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.sruc.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.sruc.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.sruc.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.sruc.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.sruc.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.sruc.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "sruc.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDJDCCAgygAwIBAgIVAMisBG8/pYaTN/dKjE96UJTj0pHnMA0GCSqGSIb3DQEB\n\t\t\t\t\t\tBQUAMBkxFzAVBgNVBAMTDmlkcC5zcnVjLmFjLnVrMB4XDTEzMDgxNTE4MzUyMVoX\n\t\t\t\t\t\tDTMzMDgxNTE4MzUyMVowGTEXMBUGA1UEAxMOaWRwLnNydWMuYWMudWswggEiMA0G\n\t\t\t\t\t\tCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQChYhV93CUW69tAVZOYdhzRX14Gtm8l\n\t\t\t\t\t\tCa8W4/EWAEqeVvoMT70fMMwCTPxHbSCkoEpk8RAwChzwGSTGJt8/dtyZWr6vmrHs\n\t\t\t\t\t\t8TzCIKRPo1wJymIPtONtojdZnERwbEr0brAzIw82QIOidzYueWHpbrYSaxwmaQNR\n\t\t\t\t\t\tLKwDIjf/0M7Zkm6t50vxu2XRttrxJ92x31U0P/mQa22DLlQs6gmJFoxO7jPc0gUj\n\t\t\t\t\t\tsvDsMTZXS6J4oXmnpqLHfGpGtiyGocunHRykIGX1cyxyJngRXVb6VCfnIb06nELH\n\t\t\t\t\t\t9s27b9t6/IhWgmH9rCxS522xTuQDe0DKD0YpmMIQK3fHAhF8RaMGcT+PAgMBAAGj\n\t\t\t\t\t\tYzBhMEAGA1UdEQQ5MDeCDmlkcC5zcnVjLmFjLnVrhiVodHRwczovL2lkcC5zcnVj\n\t\t\t\t\t\tLmFjLnVrL2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBTj1x9pT421ZN33j8y2qyC2\n\t\t\t\t\t\tz7tEnDANBgkqhkiG9w0BAQUFAAOCAQEAbRG6KPM1cS83t1nTr68n4o+SAawN6IBS\n\t\t\t\t\t\tyt0oSw7jL2eWsFZA3xgR3pePSiKdHXYLW3YEpJ+O3nS1Hs6Hz1lM3zwguJRSnJBk\n\t\t\t\t\t\ttS/2Mvk/LiS3TecJqawwvZ5M+MHPckzKP/2cZwJum6dZps9U3KuuLEwU3aDt6Ri+\n\t\t\t\t\t\t74AWwDm1DVM0AfuSOk+Gjjkh0mgoMCfMS1jFTRwJXxfH13/jq2ODCD7HlvlJ5eGD\n\t\t\t\t\t\tFknd4XDnhT0wz9uDxT1gTsXCRe/DP/Ql8iviaG1f9fENTz7MrcvKawLMqaRQpL6Z\n\t\t\t\t\t\t9rbQkno5Y20gWQLAD3AF1pceBNBCO/6G/GCzRkdsGCtVNNXfnnsc3Q=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "SRUC"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.sruc.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "SRUC"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://login.uat.ezproxy.library.qmul.ac.uk/shibboleth-sp",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:lib-systems-team@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "ITS Library Systems Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Clark"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:j.p.clark@qmul.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Jez"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://login.uat.ezproxy.library.qmul.ac.uk/shibboleth-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2015-05-07T08:33:29Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Queen Mary, University of London UAT EZproxy Service"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.qmul.ac.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Queen Mary and Westfield College, University of London"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "index": "1",
              "location": "https://login.uat.ezproxy.library.qmul.ac.uk/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "is_default": "true"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://login.uat.ezproxy.library.qmul.ac.uk/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "2"
            }
          ],
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIFPTCCBCWgAwIBAgIRAI29zjKzu326VLd+tAYO77UwDQYJKoZIhvcNAQELBQAw\n\t\t\t\t\t\tZDELMAkGA1UEBhMCTkwxFjAUBgNVBAgTDU5vb3JkLUhvbGxhbmQxEjAQBgNVBAcT\n\t\t\t\t\t\tCUFtc3RlcmRhbTEPMA0GA1UEChMGVEVSRU5BMRgwFgYDVQQDEw9URVJFTkEgU1NM\n\t\t\t\t\t\tIENBIDIwHhcNMTUwMzMwMDAwMDAwWhcNMTgwMzI5MjM1OTU5WjCBzzELMAkGA1UE\n\t\t\t\t\t\tBhMCR0IxDzANBgNVBBETBkUxIDROUzEXMBUGA1UECBMOQ2VudHJhbCBMb25kb24x\n\t\t\t\t\t\tDzANBgNVBAcTBkxPTkRPTjEaMBgGA1UECRMRMzI3IE1pbGUgRW5kIFJvYWQxKDAm\n\t\t\t\t\t\tBgNVBAoTH1F1ZWVuIE1hcnkgVW5pdmVyc2l0eSBPZiBMb25kb24xFDASBgNVBAsT\n\t\t\t\t\t\tC0lUIFNlcnZpY2VzMSkwJwYDVQQDFCAqLnVhdC5lenByb3h5LmxpYnJhcnkucW11\n\t\t\t\t\t\tbC5hYy51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALNerg/8ZDXf\n\t\t\t\t\t\t2E2uegLLE8Rup8oZieeFaYMJLFhtdnAtBZQ8+yLvsXCg3MNO9utYc9xdcRQT3SeI\n\t\t\t\t\t\tC1SpMaLZEKr1vAngsgzMEZBaQzY+8SdAT+6lTYoUN9WpvkaCkghNjRkBMTLOhj67\n\t\t\t\t\t\t8vTZFYh6kt4MhNmFru9U/3suRs8SQA7cpvfdq+MS8JryHRLpmGVBjFroI+o87NEK\n\t\t\t\t\t\t1gMhJdkiAout8zryhIYvue4LPeALvkTzd07rFOPctIf4yAL7FaFZZH4QmB8jeKkg\n\t\t\t\t\t\tflyLzU//w38gPRNhyNUduXdKDPIGEK0J6DZvSgt7f/J/v6GOYH6xdGI8ztRRX2kU\n\t\t\t\t\t\t3aig7emsgC8CAwEAAaOCAXwwggF4MB8GA1UdIwQYMBaAFFvQihyaMlvgtd2WVBvh\n\t\t\t\t\t\thiiw/ba9MB0GA1UdDgQWBBQr62vcnCUzioq1WLaguy0tDZtdJjAOBgNVHQ8BAf8E\n\t\t\t\t\t\tBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggrBgEFBQcDAQYIKwYBBQUH\n\t\t\t\t\t\tAwIwIgYDVR0gBBswGTANBgsrBgEEAbIxAQICHTAIBgZngQwBAgIwOgYDVR0fBDMw\n\t\t\t\t\t\tMTAvoC2gK4YpaHR0cDovL2NybC51c2VydHJ1c3QuY29tL1RFUkVOQVNTTENBMi5j\n\t\t\t\t\t\tcmwwbAYIKwYBBQUHAQEEYDBeMDUGCCsGAQUFBzAChilodHRwOi8vY3J0LnVzZXJ0\n\t\t\t\t\t\tcnVzdC5jb20vVEVSRU5BU1NMQ0EyLmNydDAlBggrBgEFBQcwAYYZaHR0cDovL29j\n\t\t\t\t\t\tc3AudXNlcnRydXN0LmNvbTArBgNVHREEJDAigiAqLnVhdC5lenByb3h5LmxpYnJh\n\t\t\t\t\t\tcnkucW11bC5hYy51azANBgkqhkiG9w0BAQsFAAOCAQEAZJCnsTzsIUbT6bZCkwC6\n\t\t\t\t\t\tBcp/cDzfowiWCCjmOErNOwT+TZxrtA2AC5udcHFH0c0xGZFH08jrwAMdtppqCiRZ\n\t\t\t\t\t\tAq1oi7KS9+I6CLrDgFaOuOP4TNkbiQLVoGXZyAnFJK6JrErFJt42I/GhsVgP0U+B\n\t\t\t\t\t\tXLxYdCES3EROnNLRWwu07kyWUO5aIOxJtbnOsrgZCeMBE/9ScMRfM/k5tgXjdtSq\n\t\t\t\t\t\t/qh9bl3WMJx7NLoeH7PkqZdaX9IfoEhmpKkcfrc9F1yAomKd9Nq7TZ3tAgqnvf6J\n\t\t\t\t\t\thhhraoEgWp63qgLAS+jK7iUDzyY+dKS3pqTxsB0g7twOqb5QOJHGYnR2lg6qROOh\n\t\t\t\t\t\t/g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://login.uat.ezproxy.library.qmul.ac.uk/Shibboleth.sso/DS",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          }
        }
      ]
    }
  ],
  [
    "https://authenticate.bvdep.com/ukfederation",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Buelens"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Peter.Buelens@bvdinfo.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Peter"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Buelens"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:Peter.Buelens@bvdinfo.com"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Peter"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://authenticate.bvdep.com/ukfederation",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "http://ukfederation.org.uk/doc/mdrps-20130902"
              }
            ],
            "registration_instant": "2008-07-22T10:07:00Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bureau van Dijk: authentication service for the UK federation"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.bvdep.com/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Bureau Van Dijk - Electronic Publishing"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      },
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://authenticate.bvdep.com/ukfederation/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://authenticate.bvdep.com/ukfederation/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://authenticate.bvdep.com/ukfederation/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://authenticate.bvdep.com/ukfederation/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://authenticate.bvdep.com/ukfederation/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://authenticate.bvdep.com/ukfederation/Shibboleth.sso/WAYF",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://authenticate.bvdep.com/ukfederation/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://authenticate.bvdep.com/ukfederation/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Global, regional and domestic company information - including financials, corporate structures and other business intelligence."
                  }
                ],
                "logo": [
                  {
                    "text": "https://authenticate.bvdep.com/bvdlogo.gif",
                    "height": "76",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "198"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Bureau van Dijk"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEBjCCAu6gAwIBAgIJAMGyauP3kg2oMA0GCSqGSIb3DQEBBQUAMIGDMQswCQYD\n\t\t\t\t\t\tVQQGEwJCRTERMA8GA1UECBMIQnJ1c3NlbHMxETAPBgNVBAcTCEJydXNzZWxzMRgw\n\t\t\t\t\t\tFgYDVQQKEw9CdXJlYXUgdmFuIERpamsxEzARBgNVBAsTClNoaWJib2xldGgxHzAd\n\t\t\t\t\t\tBgNVBAMTFmF1dGhlbnRpY2F0ZS5idmRlcC5jb20wHhcNMTEwODAyMTUwODM2WhcN\n\t\t\t\t\t\tMzEwNzI4MTUwODM2WjCBgzELMAkGA1UEBhMCQkUxETAPBgNVBAgTCEJydXNzZWxz\n\t\t\t\t\t\tMREwDwYDVQQHEwhCcnVzc2VsczEYMBYGA1UEChMPQnVyZWF1IHZhbiBEaWprMRMw\n\t\t\t\t\t\tEQYDVQQLEwpTaGliYm9sZXRoMR8wHQYDVQQDExZhdXRoZW50aWNhdGUuYnZkZXAu\n\t\t\t\t\t\tY29tMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1UtrmJ9RcT+Of4xe\n\t\t\t\t\t\t+xWozbNe5JVuMOfZJ0kpeve2Hh30RHAzxJQjDkYBogjq+2aYPEqrlc8Zg7DO4wy4\n\t\t\t\t\t\tCRDkr4nEIUsicM2qAZv9vAuV3wf204QWPg944iPvEIwoCEwHCwEoUtdtEYZpeMAE\n\t\t\t\t\t\tEhP7RKc3UwbUbzaEnGBaqhAUlF+Fokq7INve7kca7AldsMTNPxelTISMO7eJLris\n\t\t\t\t\t\tt/ZMyEUkVrri2vHJR5wW0vNBHVCcDAGjGt4ckTKVB0Xmqi77sHPOyS05KndzElMs\n\t\t\t\t\t\tULcRVbOVNv7GSzYTHRQlaq6VWyoBVTWH+rht00/97vf265Yn1pC9mm82YqZNlvEI\n\t\t\t\t\t\tdRMsdwIDAQABo3sweTAJBgNVHRMEAjAAMCwGCWCGSAGG+EIBDQQfFh1PcGVuU1NM\n\t\t\t\t\t\tIEdlbmVyYXRlZCBDZXJ0aWZpY2F0ZTAdBgNVHQ4EFgQUJHFh2uJtwpARwv+xpu5j\n\t\t\t\t\t\tdRw5j4kwHwYDVR0jBBgwFoAUJHFh2uJtwpARwv+xpu5jdRw5j4kwDQYJKoZIhvcN\n\t\t\t\t\t\tAQEFBQADggEBALRsYutdOD2SKEi3MGju3pQeqhgGQJk5y4aQ06CJmXjz8TQmWCFJ\n\t\t\t\t\t\thbIwR6347FUyyLiGqDSbJsZuzaFKq5oGVL3QgERisKBsvabFLvaICb/cKbz98UVR\n\t\t\t\t\t\toe4ZfgFKWKxDJTTk7R2RXCL5rFJFQvLGii3booGdkrWqY8FVjq8BHawgydcyIlMp\n\t\t\t\t\t\tj/oj8ggh2OrS3vR6+8xasdDj5YqzG5rJgKP2fmnSOTVMfmPjAqEp/Yj37Wtl0NRR\n\t\t\t\t\t\tfN9RkMQvRV7pufGoIJC0iPtOy6Fb7Hwh+61ELiTt5NCTewiFrOUilqhnpiJBqfI5\n\t\t\t\t\t\tF3JhOKtgLsQEWD4nm3wzptv2ImHrjeaaNMA="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://authenticate.bvdep.com/ukfederation/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://authenticate.bvdep.com/ukfederation/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "7"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://authenticate.bvdep.com/ukfederation/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "8"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://authenticate.bvdep.com/ukfederation/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "9"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://authenticate.bvdep.com/ukfederation/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "10"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://authenticate.bvdep.com/ukfederation/Shibboleth.sso/SAML2/POST-SimpleSign",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "11"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://auth.crous-versailles.fr/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "service.informatique@crous-versailles.fr"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://auth.crous-versailles.fr/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://services.renater.fr/federation/en/metadata_registration_practice_statement"
              }
            ],
            "registration_instant": "2013-02-22T11:00:25Z",
            "registration_authority": "https://federation.renater.fr/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://auth.crous-versailles.fr/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://auth.crous-versailles.fr/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://auth.crous-versailles.fr/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "crous-versailles.fr"
              },
              {
                "information_url": [
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.crous-versailles.fr"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Versailles - Personnels"
                  },
                  {
                    "lang": "fr",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "CROUS Versailles - Personnels"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIEezCCA2OgAwIBAgIQBQGbJx8ycfocbzaW5m+L4DANBgkqhkiG9w0BAQUFADA2\nMQswCQYDVQQGEwJOTDEPMA0GA1UEChMGVEVSRU5BMRYwFAYDVQQDEw1URVJFTkEg\nU1NMIENBMB4XDTEzMDEzMTAwMDAwMFoXDTE2MDEzMTIzNTk1OVowTjELMAkGA1UE\nBhMCRlIxHDAaBgNVBAoTE0NST1VTIGRlIFZFUlNBSUxMRVMxITAfBgNVBAMTGGF1\ndGguY3JvdXMtdmVyc2FpbGxlcy5mcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC\nAQoCggEBALT8ahras1SsgYWcRaFEu8/MSACuZsYe74VljdqW/gsn55hUpRSd+hR2\nigczY3H6lmJrnbXMaaOmRwO8OqESSvmqUp6ZLky0UxXpBFf1ouXuBd5Ghis8CD/q\nV5E/loQEVrakpJ0bCtkrEZpFD+4RNSpOOoAQAP4tfz7YM34dal6xCxUBcuy8n5pI\nJnz5E9UmMAzFLvwr0iNMCR+SBunRFPjlYe+12UHu2cMsKPDWK89hgTfec3w1Tvux\n9/9/NCdRhiyQlnKiAXxmC+TWikrBZ1v9mV5VH9uLmfgRqZjgY648TIzMVVgCC2yo\nd+LTpATPAfmAMeY/uDpqK0IcEAvhtzUCAwEAAaOCAWswggFnMB8GA1UdIwQYMBaA\nFAy9k2gM896ro0lrKzdXR+qQ47ntMB0GA1UdDgQWBBRm9Gu4ap/VYe37uc/e4QCE\nq4D3gjAOBgNVHQ8BAf8EBAMCBaAwDAYDVR0TAQH/BAIwADAdBgNVHSUEFjAUBggr\nBgEFBQcDAQYIKwYBBQUHAwIwGAYDVR0gBBEwDzANBgsrBgEEAbIxAQICHTA6BgNV\nHR8EMzAxMC+gLaArhilodHRwOi8vY3JsLnRjcy50ZXJlbmEub3JnL1RFUkVOQVNT\nTENBLmNybDBtBggrBgEFBQcBAQRhMF8wNQYIKwYBBQUHMAKGKWh0dHA6Ly9jcnQu\ndGNzLnRlcmVuYS5vcmcvVEVSRU5BU1NMQ0EuY3J0MCYGCCsGAQUFBzABhhpodHRw\nOi8vb2NzcC50Y3MudGVyZW5hLm9yZzAjBgNVHREEHDAaghhhdXRoLmNyb3VzLXZl\ncnNhaWxsZXMuZnIwDQYJKoZIhvcNAQEFBQADggEBABQoWTgD8rOZ2cZ1DFXaR72R\nopGVuKwCxr2HuCD3L17jbfobHbWFVVMjbia5MGUozURJP6XEPFsPR6Gxuv38pI4B\ntySTtMz03p4hXk+q2ldOfQrJ+XergnpU/5r05DkELoqFjXb0qtHm3iUcR1ohRq17\nbApQ08Tt1gGKlZJauC1VqxBoDtYs7mnFLHPz7FOi0jilUsppcj6ph/N3QbBuwb7p\nVJwSJN4NmyTAZv/ErszB2z4hiHxOF/UwX1J38g93MBUSoLx/qMNtJOXkqOt7izen\n+kEx04VnOsKWgTu9oGK57dt1dlLPml8CX9BCHdJ64IL9aTDeJMD2X1IH1/YgJdU="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "CROUS Versailles - Personnels"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.crous-versailles.fr"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "CROUS Versailles - Personnels"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://ladok3-08.ladok.umu.se/student-frontend-sp",
    {
      "extensions": {
        "extension_elements": [
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmlenc#sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&DigestMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha224",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha512",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha384",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2009/xmldsig11#dsa-sha256",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#rsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "algorithm": "http://www.w3.org/2000/09/xmldsig#dsa-sha1",
            "__class__": "urn:oasis:names:tc:SAML:metadata:algsupport&SigningMethod"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/hei-service"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/research-and-education"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.swamid.se/category/sfs-1993-1153"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "entity_id": "https://ladok3-08.ladok.umu.se/student-frontend-sp",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "spsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/SLO/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/SLO/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/SLO/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/SLO/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/Artifact/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:request-init",
                "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:request-init&RequestInitiator"
              },
              {
                "binding": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol",
                "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/Login",
                "__class__": "urn:oasis:names:tc:SAML:profiles:SSO:idp-discovery-protocol&DiscoveryResponse",
                "index": "1"
              },
              {
                "description": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 \u00e4r n\u00e4sta generation av studieadministrativt systemst\u00f6d f\u00f6r universitet och h\u00f6gskolor i Sverige"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Ladok3 is the next generation of the administration system for higher education in Sweden."
                  }
                ],
                "logo": [
                  {
                    "text": "https://nya.ladok.umu.se/md/logos/ladok3_64x64.png",
                    "height": "64",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "64"
                  }
                ],
                "display_name": [
                  {
                    "lang": "sv",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsystem studentgr\u00e4nssnitt ladok3#x2011;08"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Ladok3 testsite student web ladok3#x2011;08"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "encryption_method": [
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes128-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes192-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#aes256-gcm",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes128-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes192-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#aes256-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#tripledes-cbc",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2009/xmlenc11#rsa-oaep",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                },
                {
                  "algorithm": "http://www.w3.org/2001/04/xmlenc#rsa-oaep-mgf1p",
                  "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EncryptionMethod"
                }
              ],
              "key_info": {
                "key_name": [
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "https://ladok3-08.ladok.umu.se/student-frontend-sp"
                  },
                  {
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyName",
                    "text": "ladok3-08.ladok.umu.se"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo",
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPTCCAiWgAwIBAgIJAO5uNSsUisnLMA0GCSqGSIb3DQEBBQUAMCExHzAdBgNV\nBAMTFmxhZG9rMy0wOC5sYWRvay51bXUuc2UwHhcNMTQxMDA3MTQ0MjU5WhcNMjQx\nMDA0MTQ0MjU5WjAhMR8wHQYDVQQDExZsYWRvazMtMDgubGFkb2sudW11LnNlMIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA17Ttikn7C8StJRcTZVkLKwpn\nB1bnBxXkW4Nmf/m1+Nt+nO+q/5Mn19h5+ALZqexBNue95/ikK3BnNTddwZE3RzkV\nJ2LPTV6fseinRwvhxZDsyeDxyrYPs5cBYVRbYP++XmD0dN31Pfg3WkoPtPEUQ3y+\niEbgwMv1LYK9hgSRrvA/2rlpbsFg3zI9lHwoum97sFIZxv1GFNhRws/D4MpOX65L\nz5vxAFQquVNQ52rGXwN7P3RDP/1IjqnsBuHUk+nChmrpe8NGjhfVNa/FdZd+iaNR\nGrh80AGencDGOKcbwwyLlkQ6oDEsWAoxmLnaVrZjR2dId9XmOgswcy+xp3mKKQID\nAQABo3gwdjBVBgNVHREETjBMghZsYWRvazMtMDgubGFkb2sudW11LnNlhjJodHRw\nczovL2xhZG9rMy0wOC5sYWRvay51bXUuc2Uvc3R1ZGVudC1mcm9udGVuZC1zcDAd\nBgNVHQ4EFgQUVPs+VHLQttdwq2k20jXjwE1QNaYwDQYJKoZIhvcNAQEFBQADggEB\nAIW42icVY8jhfhkbT7KEJcN3Ar+BxA7asqf9k2rddH/ivNJcUTx67VLf0hf7Znla\n3/OLPbqW0xBZzONpzqpEXVTB1H1ZIagfd9Z/5+I6tc2m5JLpFCG7aKj274rGxwpz\nolj/ZuLwEZp3zJBoWA9MMCiDGWAgzTS3H9Ys/QTUOVJR+B7HZ6FGTpcsT7IZUpuN\n7hR0zx92QePBX5nZv4p93vUOsj/SdwwgnyoT/c7mT5aUjvX6PtpqyK8sOMKwqrR3\nVmqhSIq31DIL5TJwnV8k1SJ95uWyflne1xoqht0IcL3QONAggkL14fVXx+nUSDVQ\n+IxJFSoCr7+UBhCVQpc1k5o="
                    },
                    "x509_subject_name": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509SubjectName",
                      "text": "CN=ladok3-08.ladok.umu.se"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ]
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SPSSODescriptor",
          "manage_name_id_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/NIM/SOAP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/NIM/Redirect",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/NIM/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/NIM/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ManageNameIDService"
            }
          ],
          "assertion_consumer_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/SAML2/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/SAML2/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "3"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:PAOS",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/SAML2/ECP",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "4"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:browser-post",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/SAML/POST",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "5"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:profiles:artifact-01",
              "location": "https://ladok3-08.ladok.umu.se:446/Shibboleth.sso/SAML/Artifact",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AssertionConsumerService",
              "index": "6"
            }
          ]
        }
      ]
    }
  ],
  [
    "https://shibboleth.rcn.org.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Jacklin"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:ian.jacklin@rcn.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Ian"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Forsyth"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:service.desk@rcn.org.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Richard"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://shibboleth.rcn.org.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_instant": "2012-08-24T08:40:57Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUXswXhO6uDK4MV7I9aly5vnD77ZcwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwIDEeMBwGA1UEAxMVc2hpYmJvbGV0aC5yY24ub3JnLnVrMB4XDTEyMDgxNTE1\n\t\t\t\t\t\tMTcwM1oXDTMyMDgxNTE1MTcwM1owIDEeMBwGA1UEAxMVc2hpYmJvbGV0aC5yY24u\n\t\t\t\t\t\tb3JnLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAwdOecQlpkznI\n\t\t\t\t\t\thj5OKgl7HSg1bcTEbk4t2l4CZ/nrQYqTr/y3eGM66v4+V/jU65iw989xVal3o65N\n\t\t\t\t\t\tbaDB1+eIAEtDadhCxVZrdqRFLm8M5XgCfZ9FHZyPmth02mh6ODrqHGpuK6g7rfYw\n\t\t\t\t\t\tRZ+1aU00kUoPTS3Ex95m9wufCai/IYpCLNF0uLqvgrPjHUdSkFBhJumUH8Km7HHo\n\t\t\t\t\t\tiJRLc3lCIBfnEDLHLgESNQ/R7H7t3bg0ncar6EvNXEJzG+2lfQqVSZcQh+cgl4Z8\n\t\t\t\t\t\t/O0w/C67yIop+NYlbP+H42NqHwWu5UNYvj1QFidh3UAD0kEGaCu6JLV8aBpKyoTR\n\t\t\t\t\t\thanCRBgPtwIDAQABo3EwbzBOBgNVHREERzBFghVzaGliYm9sZXRoLnJjbi5vcmcu\n\t\t\t\t\t\tdWuGLGh0dHBzOi8vc2hpYmJvbGV0aC5yY24ub3JnLnVrL2lkcC9zaGliYm9sZXRo\n\t\t\t\t\t\tMB0GA1UdDgQWBBQWbyOjE1aj+Hbxix3s/WCO8tOA9zANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAm20IB4KT5TykwOLIRbEhNK9+ccd0EcRKkTc91w/J7JCU64n69AJZ/xeXCo5E\n\t\t\t\t\t\t8YxmkJSO/SQSTzXrWFR+lGo0brO622Uc9YxUdbTIfiiq/bZIDqTiEiIkpfUoBTkB\n\t\t\t\t\t\tl5LenKSFfnvnty697DGOKJ5ZCyvuEiitdYyIrXU09wrVw+03FnhMwkUKOaZ0WFxl\n\t\t\t\t\t\tjbsZ5ut9IHExbGMJJDg+dMBS7B9dlekzYvzdcqJaF3YMUgF4mCuKvM52VxCaJeHg\n\t\t\t\t\t\tZKFO8alq69naYWxQ8zjYygPSpM3wZ+U+ympl8A/SWz2nAYYAMHeRiHy5+HxqtRoH\n\t\t\t\t\t\tvGxcw0jItQ4SQ9/nHEbArNfwkQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rcn.org.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.rcn.org.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.rcn.org.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://shibboleth.rcn.org.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://shibboleth.rcn.org.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://shibboleth.rcn.org.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://shibboleth.rcn.org.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://shibboleth.rcn.org.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://shibboleth.rcn.org.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "rcn.org.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDPzCCAiegAwIBAgIUXswXhO6uDK4MV7I9aly5vnD77ZcwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwIDEeMBwGA1UEAxMVc2hpYmJvbGV0aC5yY24ub3JnLnVrMB4XDTEyMDgxNTE1\n\t\t\t\t\t\tMTcwM1oXDTMyMDgxNTE1MTcwM1owIDEeMBwGA1UEAxMVc2hpYmJvbGV0aC5yY24u\n\t\t\t\t\t\tb3JnLnVrMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAwdOecQlpkznI\n\t\t\t\t\t\thj5OKgl7HSg1bcTEbk4t2l4CZ/nrQYqTr/y3eGM66v4+V/jU65iw989xVal3o65N\n\t\t\t\t\t\tbaDB1+eIAEtDadhCxVZrdqRFLm8M5XgCfZ9FHZyPmth02mh6ODrqHGpuK6g7rfYw\n\t\t\t\t\t\tRZ+1aU00kUoPTS3Ex95m9wufCai/IYpCLNF0uLqvgrPjHUdSkFBhJumUH8Km7HHo\n\t\t\t\t\t\tiJRLc3lCIBfnEDLHLgESNQ/R7H7t3bg0ncar6EvNXEJzG+2lfQqVSZcQh+cgl4Z8\n\t\t\t\t\t\t/O0w/C67yIop+NYlbP+H42NqHwWu5UNYvj1QFidh3UAD0kEGaCu6JLV8aBpKyoTR\n\t\t\t\t\t\thanCRBgPtwIDAQABo3EwbzBOBgNVHREERzBFghVzaGliYm9sZXRoLnJjbi5vcmcu\n\t\t\t\t\t\tdWuGLGh0dHBzOi8vc2hpYmJvbGV0aC5yY24ub3JnLnVrL2lkcC9zaGliYm9sZXRo\n\t\t\t\t\t\tMB0GA1UdDgQWBBQWbyOjE1aj+Hbxix3s/WCO8tOA9zANBgkqhkiG9w0BAQUFAAOC\n\t\t\t\t\t\tAQEAm20IB4KT5TykwOLIRbEhNK9+ccd0EcRKkTc91w/J7JCU64n69AJZ/xeXCo5E\n\t\t\t\t\t\t8YxmkJSO/SQSTzXrWFR+lGo0brO622Uc9YxUdbTIfiiq/bZIDqTiEiIkpfUoBTkB\n\t\t\t\t\t\tl5LenKSFfnvnty697DGOKJ5ZCyvuEiitdYyIrXU09wrVw+03FnhMwkUKOaZ0WFxl\n\t\t\t\t\t\tjbsZ5ut9IHExbGMJJDg+dMBS7B9dlekzYvzdcqJaF3YMUgF4mCuKvM52VxCaJeHg\n\t\t\t\t\t\tZKFO8alq69naYWxQ8zjYygPSpM3wZ+U+ympl8A/SWz2nAYYAMHeRiHy5+HxqtRoH\n\t\t\t\t\t\tvGxcw0jItQ4SQ9/nHEbArNfwkQ=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Royal College of Nursing"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.rcn.org.uk/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Royal College of Nursing"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.cambridgeimaging.co.uk/entity",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Hemington"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:graham.hemington@cambridgeimaging.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Graham"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "McConkey"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:paul.mcconkey@cambridgeimaging.co.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Paul"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.cambridgeimaging.co.uk/entity",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/hide-from-discovery"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          },
          {
            "registration_instant": "2013-03-22T14:39:45Z",
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUFqyUnksKx2uVyCZeWl+JRq1o2rcwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJTEjMCEGA1UEAxMaaWRwLmNhbWJyaWRnZWltYWdpbmcuY28udWswHhcNMTMw\n\t\t\t\t\t\tMjIxMTA0NDQ4WhcNMzMwMjIxMTA0NDQ4WjAlMSMwIQYDVQQDExppZHAuY2FtYnJp\n\t\t\t\t\t\tZGdlaW1hZ2luZy5jby51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAMoKTCTiBT2WdSJHckKjl5POvjT+j37fzENQRrdyTtU7OAI4EPZ4RXTC38K2hPFQ\n\t\t\t\t\t\t09pK904bqaWP4y/Kvg7cXLJ7+//lJQZDFFO7TFKLsUJK086hkEsKrWUx9ykU4kFG\n\t\t\t\t\t\tP2LdBxvYcZvtdthzfVtDrdmiJwVwgrCHmhqxX1ICGiz4oXC8FTRSGmgkBZesaD33\n\t\t\t\t\t\taItvb4WK78dpQdcCmaZkFFLGUsFcSTCLKwYVcTJeBJ5HSdOvBPJ8Kcvd6RUFbp5N\n\t\t\t\t\t\tjBk68T4sfH1tsKHqnGHg+UK22WOtpGgIt8zT5pS2l17EJ2s3hz0snJF3c6Lh8eMO\n\t\t\t\t\t\tnzpq+MFhVFQpV/ZOm920iZ0CAwEAAaN7MHkwWAYDVR0RBFEwT4IaaWRwLmNhbWJy\n\t\t\t\t\t\taWRnZWltYWdpbmcuY28udWuGMWh0dHBzOi8vaWRwLmNhbWJyaWRnZWltYWdpbmcu\n\t\t\t\t\t\tY28udWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFJcUHacY77LJTqyMRSqeZtkF\n\t\t\t\t\t\tDbr6MA0GCSqGSIb3DQEBBQUAA4IBAQAFXd/wFyF3UWF5q1NMFqCPPjyqk1jL60WO\n\t\t\t\t\t\tE0NBCfM9VX24CgrL3QSYTLeVHKwJ/qGznh7/pbMhfAsPFAiX0vQyYTBeKeP1o2V/\n\t\t\t\t\t\tDq16b525gritaMhhPg+205Bf3MpD0oJWfM3YwDboC49bqN2/pe2l0QG5+hVp6YN9\n\t\t\t\t\t\tHem1W9OFrByZNezVqUxqtWzkShG9xUdsB2DlaRGkakzYz4NY4hAYcsNjQQ7DLXsx\n\t\t\t\t\t\tjAAuZz8W5S4RMFM1Poe4uEhH5A8dUr31EBcsNTygQOyphzfB/UQmg+Zc4aoDJOqq\n\t\t\t\t\t\tHNe8mt/HQOesfG/fANyKI7HUpXtIeIqRt/hbk8X+Dy3Dn+lxCmUW"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cambridgeimaging.co.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cambridgeimaging.co.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cambridgeimaging.co.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.cambridgeimaging.co.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.cambridgeimaging.co.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.cambridgeimaging.co.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.cambridgeimaging.co.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.cambridgeimaging.co.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.cambridgeimaging.co.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "cambridgeimaging.co.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDUzCCAjugAwIBAgIUFqyUnksKx2uVyCZeWl+JRq1o2rcwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwJTEjMCEGA1UEAxMaaWRwLmNhbWJyaWRnZWltYWdpbmcuY28udWswHhcNMTMw\n\t\t\t\t\t\tMjIxMTA0NDQ4WhcNMzMwMjIxMTA0NDQ4WjAlMSMwIQYDVQQDExppZHAuY2FtYnJp\n\t\t\t\t\t\tZGdlaW1hZ2luZy5jby51azCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEB\n\t\t\t\t\t\tAMoKTCTiBT2WdSJHckKjl5POvjT+j37fzENQRrdyTtU7OAI4EPZ4RXTC38K2hPFQ\n\t\t\t\t\t\t09pK904bqaWP4y/Kvg7cXLJ7+//lJQZDFFO7TFKLsUJK086hkEsKrWUx9ykU4kFG\n\t\t\t\t\t\tP2LdBxvYcZvtdthzfVtDrdmiJwVwgrCHmhqxX1ICGiz4oXC8FTRSGmgkBZesaD33\n\t\t\t\t\t\taItvb4WK78dpQdcCmaZkFFLGUsFcSTCLKwYVcTJeBJ5HSdOvBPJ8Kcvd6RUFbp5N\n\t\t\t\t\t\tjBk68T4sfH1tsKHqnGHg+UK22WOtpGgIt8zT5pS2l17EJ2s3hz0snJF3c6Lh8eMO\n\t\t\t\t\t\tnzpq+MFhVFQpV/ZOm920iZ0CAwEAAaN7MHkwWAYDVR0RBFEwT4IaaWRwLmNhbWJy\n\t\t\t\t\t\taWRnZWltYWdpbmcuY28udWuGMWh0dHBzOi8vaWRwLmNhbWJyaWRnZWltYWdpbmcu\n\t\t\t\t\t\tY28udWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFJcUHacY77LJTqyMRSqeZtkF\n\t\t\t\t\t\tDbr6MA0GCSqGSIb3DQEBBQUAA4IBAQAFXd/wFyF3UWF5q1NMFqCPPjyqk1jL60WO\n\t\t\t\t\t\tE0NBCfM9VX24CgrL3QSYTLeVHKwJ/qGznh7/pbMhfAsPFAiX0vQyYTBeKeP1o2V/\n\t\t\t\t\t\tDq16b525gritaMhhPg+205Bf3MpD0oJWfM3YwDboC49bqN2/pe2l0QG5+hVp6YN9\n\t\t\t\t\t\tHem1W9OFrByZNezVqUxqtWzkShG9xUdsB2DlaRGkakzYz4NY4hAYcsNjQQ7DLXsx\n\t\t\t\t\t\tjAAuZz8W5S4RMFM1Poe4uEhH5A8dUr31EBcsNTygQOyphzfB/UQmg+Zc4aoDJOqq\n\t\t\t\t\t\tHNe8mt/HQOesfG/fANyKI7HUpXtIeIqRt/hbk8X+Dy3Dn+lxCmUW"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Cambridge Imaging Systems (test only)"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://cambridgeimaging.co.uk/identity_provider"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Cambridge Imaging Systems Limited"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.radford.edu/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "tjoyce@radford.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Todd Joyce"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.radford.edu/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://id.incommon.org/category/registered-by-incommon"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "idpsso_descriptor": [
        {
          "single_logout_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.radford.edu/idp/profile/SAML2/Redirect/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.radford.edu/idp/profile/SAML2/POST/SLO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleLogoutService"
            }
          ],
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://sso.radford.edu/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://sso.radford.edu/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://sso.radford.edu/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://sso.radford.edu/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://sso.radford.edu:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://sso.radford.edu:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "radford.edu"
              },
              {
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Radford University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDpTCCAo2gAwIBAgIJANeIL5N/K7s2MA0GCSqGSIb3DQEBBQUAMGkxCzAJBgNV\nBAYTAlVTMQswCQYDVQQIDAJWQTEQMA4GA1UEBwwHUmFkZm9yZDEUMBIGA1UECgwL\ncmFkZm9yZC5lZHUxCzAJBgNVBAsMAklUMRgwFgYDVQQDDA9zc28ucmFkZm9yZC5l\nZHUwHhcNMTQwNTI4MTczMzA4WhcNMzQwNTI4MTczMzA4WjBpMQswCQYDVQQGEwJV\nUzELMAkGA1UECAwCVkExEDAOBgNVBAcMB1JhZGZvcmQxFDASBgNVBAoMC3JhZGZv\ncmQuZWR1MQswCQYDVQQLDAJJVDEYMBYGA1UEAwwPc3NvLnJhZGZvcmQuZWR1MIIB\nIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA1TGYutWcsJGFBi3p23QrfDKy\nfPMTemhzbpwf2WoyaMqKOogc/NqqdBpQXji0jU05y0yjxGv6Jx7Ey88EnHGVNOJp\n3CeiElOqBJ/hRl+S4l6zmHfofgQWHEhtR2SawRv90Pj/Za5+TiIvfsifvjFWdFSJ\nsOaQ9Z7/SSuXn1Ft9iH844OBcrpYQPYsA0Xk5EgMvv7cXxJjerq5UHdlZlglN96M\nlMD8U6gzAi7rmyhcBTZ50zD01FMZzOyWLjf1zfvwyj6JvRE2e3FGwY6RQt/Y7mXy\nxu7RCtxVKiA+40YM+HN6A9p9A/+srf9tOgNLyjZ0ogNCWp+cFD1mLIzcKNuWqwID\nAQABo1AwTjAdBgNVHQ4EFgQUlzH3pb2TBuySahzZbUNiEFuNT7EwHwYDVR0jBBgw\nFoAUlzH3pb2TBuySahzZbUNiEFuNT7EwDAYDVR0TBAUwAwEB/zANBgkqhkiG9w0B\nAQUFAAOCAQEAaq6hZya9JWF5HPxy+PvAkr6XQQLzVs9j00FxAICKrPlgXW3CFvqj\nIbkzsRG0eKtotoQRO3GakOhO2gzyiVCI/6aR/6MX/c9OFwt0qe5HUNsiTiMGOq4V\ntb8i7csaCB49cfwD5tewWQdeIidg7OhPqO5S2FNrdM6jVpEg5kDuI0UIHazdmBOZ\nFDELTQ+nBfCrIa9letM+SoIU4znIvOfd4Z6k4uU11aDaZKej6/9rwMuo4EfgUFTR\n16SeaJX8wNydS4+68Ch9U5Z3saWWuC3aU4pNnMQW1VUt0bqVhtgPkcTaS7uZeYhC\n5ZxW63cQCq8Tt4xwbP8uzhoMCBiAWn+H1g=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Radford University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.radford.edu/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Radford University"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://gateway.ncl.ac.uk/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:webmaster@ncl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Helpline"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Franks"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:chris.franks@ncl.ac.uk"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Chris"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://gateway.ncl.ac.uk/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "http://ukfederation.org.uk",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIULMVH+d794/0tHGBCoqe7TG75FeMwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHDEaMBgGA1UEAxMRZ2F0ZXdheS5uY2wuYWMudWswHhcNMDkwMzMxMDgzNjQy\n\t\t\t\t\t\tWhcNMjkwMzMxMDgzNjQyWjAcMRowGAYDVQQDExFnYXRld2F5Lm5jbC5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALm01D6AF7BDlk72DEDkVOfV\n\t\t\t\t\t\thJYOTQUmgZlVj2LYKhX4hA+3/qT5h3J18Q5ap5++HbgqyGW3vDWoqBWZb/MY3eal\n\t\t\t\t\t\tnhhVv/EPr/ArGThyTOy1pXUBsCH18EpbXsgqP+VTG4LrS5usYLP/3RFqFgb/KxmT\n\t\t\t\t\t\tkbVGK5lxXFjHgYIegfF/QYIQ9VYCNSxl2DgE1/bl3XxoDEf2Jckh3vrjfDIYxhsb\n\t\t\t\t\t\tJYmK9QQymOqCZSwBB9t4HvUEGjSQBidaBvfpLEciztWHCaYVoRoeupA53Unl5xnC\n\t\t\t\t\t\tH/4+Ds1nUg7Kjn6dxHZI5U65U3054ev5hOJjGeal/ebUjAH1TfVFWRdrM1rnnUEC\n\t\t\t\t\t\tAwEAAaNpMGcwRgYDVR0RBD8wPYIRZ2F0ZXdheS5uY2wuYWMudWuGKGh0dHBzOi8v\n\t\t\t\t\t\tZ2F0ZXdheS5uY2wuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFGAesT0R\n\t\t\t\t\t\toVezoU/7a8tsnsNtS3waMA0GCSqGSIb3DQEBBQUAA4IBAQC3ksC1VClv88voWcgq\n\t\t\t\t\t\tl4BZ6fjIoFTiXGWD26lbm2earRfkSigJY1incBZ75rF7zpuUHLPs3rnVqoNf91PX\n\t\t\t\t\t\tPoGx9HcJXjzm4EXtNznjjWfHbzr5R18YFOJL8VrTwBlB8PMbPIH/Tmq+g0+EAdMf\n\t\t\t\t\t\tX4FAN+ZuyeVOUh7U4vKP5VdtJhuFduepCTR7rz+Pwcwr1EgN2LyXQ+5wuUScw5iF\n\t\t\t\t\t\tHSiU3gRV6PZDcbhausvsBGCpIdgwl5dgieqgoLBaQqpR7KrSgpT12wUPHSFSzPGD\n\t\t\t\t\t\tEFniPxIMoZkVwLWNjfP2R2s2cg1B3LL3H3I72IGqFJegGqrgJgHuHbanWJwIMAtl\n\t\t\t\t\t\tB8/r"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ncl.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://gateway.ncl.ac.uk:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://gateway.ncl.ac.uk:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://gateway.ncl.ac.uk/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://gateway.ncl.ac.uk/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://gateway.ncl.ac.uk/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://gateway.ncl.ac.uk/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://gateway.ncl.ac.uk:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://gateway.ncl.ac.uk:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "logo": [
                  {
                    "text": "https://gateway.ncl.ac.uk/images/gateway_ncl_logo.gif",
                    "height": "69",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "186"
                  },
                  {
                    "text": "https://gateway.ncl.ac.uk/images/gateway_ncl.ico",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Newcastle University"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "ncl.ac.uk"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDLzCCAhegAwIBAgIULMVH+d794/0tHGBCoqe7TG75FeMwDQYJKoZIhvcNAQEF\n\t\t\t\t\t\tBQAwHDEaMBgGA1UEAxMRZ2F0ZXdheS5uY2wuYWMudWswHhcNMDkwMzMxMDgzNjQy\n\t\t\t\t\t\tWhcNMjkwMzMxMDgzNjQyWjAcMRowGAYDVQQDExFnYXRld2F5Lm5jbC5hYy51azCC\n\t\t\t\t\t\tASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALm01D6AF7BDlk72DEDkVOfV\n\t\t\t\t\t\thJYOTQUmgZlVj2LYKhX4hA+3/qT5h3J18Q5ap5++HbgqyGW3vDWoqBWZb/MY3eal\n\t\t\t\t\t\tnhhVv/EPr/ArGThyTOy1pXUBsCH18EpbXsgqP+VTG4LrS5usYLP/3RFqFgb/KxmT\n\t\t\t\t\t\tkbVGK5lxXFjHgYIegfF/QYIQ9VYCNSxl2DgE1/bl3XxoDEf2Jckh3vrjfDIYxhsb\n\t\t\t\t\t\tJYmK9QQymOqCZSwBB9t4HvUEGjSQBidaBvfpLEciztWHCaYVoRoeupA53Unl5xnC\n\t\t\t\t\t\tH/4+Ds1nUg7Kjn6dxHZI5U65U3054ev5hOJjGeal/ebUjAH1TfVFWRdrM1rnnUEC\n\t\t\t\t\t\tAwEAAaNpMGcwRgYDVR0RBD8wPYIRZ2F0ZXdheS5uY2wuYWMudWuGKGh0dHBzOi8v\n\t\t\t\t\t\tZ2F0ZXdheS5uY2wuYWMudWsvaWRwL3NoaWJib2xldGgwHQYDVR0OBBYEFGAesT0R\n\t\t\t\t\t\toVezoU/7a8tsnsNtS3waMA0GCSqGSIb3DQEBBQUAA4IBAQC3ksC1VClv88voWcgq\n\t\t\t\t\t\tl4BZ6fjIoFTiXGWD26lbm2earRfkSigJY1incBZ75rF7zpuUHLPs3rnVqoNf91PX\n\t\t\t\t\t\tPoGx9HcJXjzm4EXtNznjjWfHbzr5R18YFOJL8VrTwBlB8PMbPIH/Tmq+g0+EAdMf\n\t\t\t\t\t\tX4FAN+ZuyeVOUh7U4vKP5VdtJhuFduepCTR7rz+Pwcwr1EgN2LyXQ+5wuUScw5iF\n\t\t\t\t\t\tHSiU3gRV6PZDcbhausvsBGCpIdgwl5dgieqgoLBaQqpR7KrSgpT12wUPHSFSzPGD\n\t\t\t\t\t\tEFniPxIMoZkVwLWNjfP2R2s2cg1B3LL3H3I72IGqFJegGqrgJgHuHbanWJwIMAtl\n\t\t\t\t\t\tB8/r"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Newcastle University"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.ncl.ac.uk/itservice/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "University of Newcastle upon Tyne"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://idp.unibocconi-prod.it/idp/shibboleth",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:idem@unibocconi.it"
            }
          ],
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://idp.unibocconi-prod.it/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.idem.garr.it/idem-metadata-registration-practice-statement"
              }
            ],
            "registration_instant": "2014-08-29T10:00:00Z",
            "registration_authority": "http://www.idem.garr.it/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAIwE2/JkvYoJZcBwpAXXselfihnEMA0GCSqGSIb3DQEB\nBQUAMBwxGjAYBgNVBAMTEWlkcC51bmlib2Njb25pLml0MB4XDTEwMDIxNzEzMjAx\nNloXDTMwMDIxNzEzMjAxNlowHDEaMBgGA1UEAxMRaWRwLnVuaWJvY2NvbmkuaXQw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCccPuV4oaBTT+Pg8czitby\nif616ZGLNOcdn58FvjPTx7/bgqy1KoFEnkQyzskglkxQTeVzo0cw3vhydJmnu0/4\njAmS4AleN5k8RqK/JVDseUYPev6LOgtaghlmaiVBwozRf7iGuiMfwj9ZC4iavaOh\ndbqzGyvbx2SREifRNYGgWrUOwrFdAdbwbT5fmEfxnRm81RdYFFmjYARSKgQdbXTG\niLa4+117OU19ybxVvdWU0nnz+b0YfcE7F/JtbaMwt27JKx2X67+N7z/6Hjg/kQme\nktt+pXdqYNKk1km8sMa21Tfb9mBufLwgbgVTUXN/ZoaDWHCV8QiX1ydiaekrX1Q/\nAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEWlkcC51bmlib2Njb25pLml0hihodHRwczov\nL2lkcC51bmlib2Njb25pLml0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSo5rDb\nl8qPk/l/4PTC/gsy6kVagzANBgkqhkiG9w0BAQUFAAOCAQEAb0iBvtK+sxUDPRsh\n7mkuz7da4Cbd6YqX3CB5eQ3quBqo7/EjVbyu3o+BwOHBQwjv3PcTd0xv5axZ4jft\nBCyUTpp6lEHTRQw5e3AC46tOBM/pnioN3qVz7AuKZK9GOCNK4LwlRKck8QtvrDc9\nuPLi1pZq4lUAe9cGV5cBKinnpcMl4acTzqOWJ1ddEIR6KFiPiYE+uwxm6Jfrvydp\n9lYG4I0gNd31pe3fVIsHCpD7NDVYFmk7AJ7GIyXxjbzPFkcY7xqHMb8RlZutzQa2\nuo9UEg+bZsGyqWbheDSr5LT8Dc6JLI7PzMH0Q5O/ejDBq+gEuXcQxAKl/esAeLLp\nK93oKA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unibocconi.it"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unibocconi.it/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unibocconi.it/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://idp.unibocconi.it/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://idp.unibocconi.it/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://idp.unibocconi.it/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://idp.unibocconi.it/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://idp.unibocconi.it/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://idp.unibocconi.it/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unibocconi.it"
              },
              {
                "information_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unibocconi.eu/idem"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&InformationURL",
                    "text": "http://www.unibocconi.it/idem"
                  }
                ],
                "description": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider for Bocconi University users"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Identity provider per gli utenti dell'Universita' Bocconi"
                  }
                ],
                "privacy_statement_url": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.unibocconi.eu/idem-privacy"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&PrivacyStatementURL",
                    "text": "http://www.unibocconi.it/idem-privacy"
                  }
                ],
                "display_name": [
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Bocconi University"
                  },
                  {
                    "lang": "it",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universita' Bocconi"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "key_descriptor": [
            {
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIDMDCCAhigAwIBAgIVAIwE2/JkvYoJZcBwpAXXselfihnEMA0GCSqGSIb3DQEB\nBQUAMBwxGjAYBgNVBAMTEWlkcC51bmlib2Njb25pLml0MB4XDTEwMDIxNzEzMjAx\nNloXDTMwMDIxNzEzMjAxNlowHDEaMBgGA1UEAxMRaWRwLnVuaWJvY2NvbmkuaXQw\nggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCccPuV4oaBTT+Pg8czitby\nif616ZGLNOcdn58FvjPTx7/bgqy1KoFEnkQyzskglkxQTeVzo0cw3vhydJmnu0/4\njAmS4AleN5k8RqK/JVDseUYPev6LOgtaghlmaiVBwozRf7iGuiMfwj9ZC4iavaOh\ndbqzGyvbx2SREifRNYGgWrUOwrFdAdbwbT5fmEfxnRm81RdYFFmjYARSKgQdbXTG\niLa4+117OU19ybxVvdWU0nnz+b0YfcE7F/JtbaMwt27JKx2X67+N7z/6Hjg/kQme\nktt+pXdqYNKk1km8sMa21Tfb9mBufLwgbgVTUXN/ZoaDWHCV8QiX1ydiaekrX1Q/\nAgMBAAGjaTBnMEYGA1UdEQQ/MD2CEWlkcC51bmlib2Njb25pLml0hihodHRwczov\nL2lkcC51bmlib2Njb25pLml0L2lkcC9zaGliYm9sZXRoMB0GA1UdDgQWBBSo5rDb\nl8qPk/l/4PTC/gsy6kVagzANBgkqhkiG9w0BAQUFAAOCAQEAb0iBvtK+sxUDPRsh\n7mkuz7da4Cbd6YqX3CB5eQ3quBqo7/EjVbyu3o+BwOHBQwjv3PcTd0xv5axZ4jft\nBCyUTpp6lEHTRQw5e3AC46tOBM/pnioN3qVz7AuKZK9GOCNK4LwlRKck8QtvrDc9\nuPLi1pZq4lUAe9cGV5cBKinnpcMl4acTzqOWJ1ddEIR6KFiPiYE+uwxm6Jfrvydp\n9lYG4I0gNd31pe3fVIsHCpD7NDVYFmk7AJ7GIyXxjbzPFkcY7xqHMb8RlZutzQa2\nuo9UEg+bZsGyqWbheDSr5LT8Dc6JLI7PzMH0Q5O/ejDBq+gEuXcQxAKl/esAeLLp\nK93oKA=="
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Bocconi University"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universita' Bocconi"
          }
        ],
        "organization_url": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unibocconi.eu/"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unibocconi.it/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Bocconi University"
          },
          {
            "lang": "it",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "Universita' Bocconi"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://aai-idp.unibe.ch/idp/shibboleth",
    {
      "contact_person": [
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Admins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:admins@campus.unibe.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Campus"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "sur_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SurName",
            "text": "Admins"
          },
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "mailto:admins@campus.unibe.ch"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Campus"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://aai-idp.unibe.ch/idp/shibboleth",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_policy": [
              {
                "lang": "en",
                "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationPolicy",
                "text": "https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt"
              }
            ],
            "registration_instant": "2016-04-03T17:33:26Z",
            "registration_authority": "http://rr.aai.switch.ch/",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://www.geant.net/uri/dataprotection-code-of-conduct/v1"
                  },
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "xs:string"
                    },
                    "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&AttributeValue",
                    "text": "http://refeds.org/category/research-and-scholarship"
                  }
                ],
                "name_format": "urn:oasis:names:tc:SAML:2.0:attrname-format:uri",
                "name": "http://macedir.org/entity-category-support",
                "__class__": "urn:oasis:names:tc:SAML:2.0:assertion&Attribute"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:metadata:attribute&EntityAttributes"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
      },
      "attribute_authority_descriptor": [
        {
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIG+zCCBeOgAwIBAgIUOrQAYeOcXpth7KRM0gOthXuLykAwDQYJKoZIhvcNAQEL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\n4wi7C/Egi1A6aNxzjqwb"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeAuthorityDescriptor",
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unibe.ch"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "attribute_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-idp.unibe.ch:8443/idp/profile/SAML1/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-idp.unibe.ch:8443/idp/profile/SAML2/SOAP/AttributeQuery",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&AttributeService"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            }
          ]
        }
      ],
      "idpsso_descriptor": [
        {
          "single_sign_on_service": [
            {
              "binding": "urn:mace:shibboleth:1.0:profiles:AuthnRequest",
              "location": "https://aai-idp.unibe.ch/idp/profile/Shibboleth/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
              "location": "https://aai-idp.unibe.ch/idp/profile/SAML2/Redirect/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
              "location": "https://aai-idp.unibe.ch/idp/profile/SAML2/POST/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST-SimpleSign",
              "location": "https://aai-idp.unibe.ch/idp/profile/SAML2/POST-SimpleSign/SSO",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&SingleSignOnService"
            }
          ],
          "protocol_support_enumeration": "urn:oasis:names:tc:SAML:2.0:protocol",
          "artifact_resolution_service": [
            {
              "binding": "urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding",
              "location": "https://aai-idp.unibe.ch:8443/idp/profile/SAML1/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "1"
            },
            {
              "binding": "urn:oasis:names:tc:SAML:2.0:bindings:SOAP",
              "location": "https://aai-idp.unibe.ch:8443/idp/profile/SAML2/SOAP/ArtifactResolution",
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ArtifactResolutionService",
              "index": "2"
            }
          ],
          "extensions": {
            "extension_elements": [
              {
                "regexp": "false",
                "__class__": "urn:mace:shibboleth:metadata:1.0&Scope",
                "text": "unibe.ch"
              },
              {
                "description": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Universit\u00e4t Bern"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Description",
                    "text": "Universit\u00e4t Bern"
                  }
                ],
                "logo": [
                  {
                    "text": "data:image/png;base64, ",
                    "height": "16",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "16"
                  },
                  {
                    "text": "data:image/png;base64, ",
                    "height": "60",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&Logo",
                    "width": "80"
                  }
                ],
                "display_name": [
                  {
                    "lang": "de",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e4t Bern"
                  },
                  {
                    "lang": "en",
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DisplayName",
                    "text": "Universit\u00e4t Bern"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&UIInfo"
              },
              {
                "domain_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DomainHint",
                    "text": "unibe.ch"
                  }
                ],
                "geolocation_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&GeolocationHint",
                    "text": "geo:46.950509,7.438155"
                  }
                ],
                "ip_hint": [
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.0.128/28"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.3.0/26"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "195.176.3.128/28"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.41.149.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.41.152.0/21"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "192.41.160.0/24"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "2001:620:400::/48"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "86.118.0.0/15"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "86.118.149.0/26"
                  },
                  {
                    "__class__": "urn:oasis:names:tc:SAML:metadata:ui&IPHint",
                    "text": "130.92.0.0/16"
                  }
                ],
                "__class__": "urn:oasis:names:tc:SAML:metadata:ui&DiscoHints"
              }
            ],
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Extensions"
          },
          "error_url": "http://www.helpdesk.unibe.ch/",
          "key_descriptor": [
            {
              "use": "signing",
              "key_info": {
                "x509_data": [
                  {
                    "x509_certificate": {
                      "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Certificate",
                      "text": "MIIG+zCCBeOgAwIBAgIUOrQAYeOcXpth7KRM0gOthXuLykAwDQYJKoZIhvcNAQEL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\n4wi7C/Egi1A6aNxzjqwb"
                    },
                    "__class__": "http://www.w3.org/2000/09/xmldsig#&X509Data"
                  }
                ],
                "__class__": "http://www.w3.org/2000/09/xmldsig#&KeyInfo"
              },
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&KeyDescriptor"
            }
          ],
          "name_id_format": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:mace:shibboleth:1.0:nameIdentifier"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient"
            },
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&NameIDFormat",
              "text": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
            }
          ],
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&IDPSSODescriptor"
        }
      ],
      "organization": {
        "organization_display_name": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e4t Bern"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationDisplayName",
            "text": "Universit\u00e4t Bern"
          }
        ],
        "organization_url": [
          {
            "lang": "de",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unibe.ch/"
          },
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationURL",
            "text": "http://www.unibe.ch/"
          }
        ],
        "organization_name": [
          {
            "lang": "en",
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&OrganizationName",
            "text": "unibe.ch"
          }
        ],
        "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&Organization"
      }
    }
  ],
  [
    "https://sso.cc.lehigh.edu/sso/saml2/idp/metadata.php",
    {
      "contact_person": [
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "das1@lehigh.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Dan Schwartz"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kbe2@lehigh.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Keith Erekson"
          },
          "contact_type": "technical",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kkh288@lehigh.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Keith Hartranft"
          },
          "contact_type": "other",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson",
          "extension_attributes": {
            "{http://id.incommon.org/metadata}contactType": "http://id.incommon.org/metadata/contactType/security"
          }
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "iniam@Lehigh.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Identity and Access Management Team"
          },
          "contact_type": "support",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        },
        {
          "email_address": [
            {
              "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EmailAddress",
              "text": "kkh288@lehigh.edu"
            }
          ],
          "given_name": {
            "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&GivenName",
            "text": "Keith Hartranft"
          },
          "contact_type": "administrative",
          "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&ContactPerson"
        }
      ],
      "entity_id": "https://sso.cc.lehigh.edu/sso/saml2/idp/metadata.php",
      "__class__": "urn:oasis:names:tc:SAML:2.0:metadata&EntityDescriptor",
      "extensions": {
        "extension_elements": [
          {
            "registration_authority": "https://incommon.org",
            "__class__": "urn:oasis:names:tc:SAML:metadata:rpi&RegistrationInfo"
          },
          {
            "attribute": [
              {
                "attribute_value": [
                  {
                    "extension_attributes": {
                      "{http://www.w3.org/2001/XMLSchema-instance}type": "x